# Import main utility functions to expose at the module level
from process_sanskrit.utils.transliterationUtils import transliterate
from process_sanskrit.utils.detectTransliteration import detect
from process_sanskrit.utils.loadResources import get_resource_path
