"""
Sanskrit/Pali Dictionary Cross-References

This module provides a mapping between words in IAST format and the dictionaries
that contain them. The included dictionaries are:

- mw: Monier-Williams Sanskrit-English Dictionary
- gra: Grassmann Dictionary
- ap90: Apte Practical Sanskrit-English Dictionary
- bhs: Buddhist Hybrid Sanskrit Dictionary
- cped: Concise Pali-English Dictionary
- cae: Cappeller Sanskrit-English Dictionary
- ddsa: MacDonnell The practical Sanskrit-English dictionary

The dictionary provides fast lookup of which dictionaries contain a given word.
Example usage:
    >>> from dictionary_references import DICTIONARY_REFERENCES
    >>> DICTIONARY_REFERENCES['dharma']
    ['mw', 'bhs', 'ap90']  # Example output
"""

from typing import Dict, List



# Dictionary mapping words to the list of dictionaries containing them
DICTIONARY_REFERENCES: Dict[str, List[str]] = {
    "*ai": ['ddsa'],
    "-ñña": ['cped'],
    "-ññu": ['cped'],
    ">darvi": ['ddsa'],
    "a": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ab": ['ap90', 'mw'],
    "ababa": ['cped'],
    "abaddha": ['ap90', 'cae', 'ddsa', 'mw'],
    "abaddhaka": ['mw'],
    "abaddhamukha": ['mw'],
    "abaddhamūla": ['mw'],
    "abaddhapralāpa": ['bhs'],
    "abaddhavat": ['mw'],
    "abadha": ['ap90', 'mw'],
    "abadhira": ['gra', 'mw'],
    "abadhra": ['ap90'],
    "abadhya": ['mw'],
    "abadhā": ['mw'],
    "abahir": ['mw'],
    "abahirdhā": ['mw'],
    "abahirvāsas": ['mw'],
    "abahiṣkārya": ['cae', 'ddsa'],
    "abahu": ['mw'],
    "abahubhāṣin": ['ddsa'],
    "abahumāna": ['bhs'],
    "abahvac": ['mw'],
    "abahvakṣara": ['mw'],
    "abala": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "abalabala": ['cped'],
    "abaladhanvan": ['mw'],
    "abalavat": ['mw'],
    "abalaṃkartar": ['bhs'],
    "abaliman": ['mw'],
    "abaliṣṭha": ['mw'],
    "abalya": ['cae', 'mw'],
    "abalyaṃ": ['ap90'],
    "abalā": ['mw'],
    "abalābala": ['mw'],
    "abalāgni": ['mw'],
    "abalāsa": ['ap90', 'mw'],
    "abalīyas": ['ddsa', 'mw'],
    "abalīyastva": ['mw'],
    "abalīyaṃs": ['cae'],
    "abanddhra": ['mw'],
    "abandhaka": ['mw'],
    "abandhana": ['gra', 'mw'],
    "abandhra": ['ddsa', 'mw'],
    "abandhu": ['ddsa', 'gra', 'mw'],
    "abandhukṛt": ['mw'],
    "abandhura": ['ddsa', 'mw'],
    "abandhuram": ['mw'],
    "abandhya": ['cae', 'ddsa', 'mw'],
    "abarha": ['cae', 'ddsa'],
    "abaḷabaḷa": ['cped'],
    "abaṃdhaka": ['ap90'],
    "abaṃdhana": ['ap90'],
    "abaṃdhra": ['ap90'],
    "abaṃdhu": ['ap90'],
    "abaṇḍa": ['mw'],
    "abbahana": ['cped'],
    "abbahati": ['cped'],
    "abbahi": ['cped'],
    "abbahitvā": ['cped'],
    "abbajati": ['cped'],
    "abbha": ['cped'],
    "abbhaghana": ['cped'],
    "abbhakkhāna": ['cped'],
    "abbhakṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "abbhakṣaṇa": ['mw'],
    "abbhakṣaṇaṃ": ['ap90'],
    "abbhamatta": ['cped'],
    "abbhamātta": ['cped'],
    "abbhantara": ['cped'],
    "abbhantarapassaya": ['cped'],
    "abbhantarika": ['cped'],
    "abbhantarima": ['cped'],
    "abbhanujānāti": ['cped'],
    "abbhanumodati": ['cped'],
    "abbhanumodi": ['cped'],
    "abbhanumodita": ['cped'],
    "abbhanumoditar": ['cped'],
    "abbhasama": ['cped'],
    "abbhasampilāpa": ['cped'],
    "abbhatireka": ['cped'],
    "abbhatthaṁ": ['cped'],
    "abbhatthaṁ gacchati": ['cped'],
    "abbhatthaṁ yāti": ['cped'],
    "abbhatīta": ['cped'],
    "abbhañjana": ['cped'],
    "abbhañjati": ['cped'],
    "abbhañjitvā": ['cped'],
    "abbhañjiṁsu": ['cped'],
    "abbhaññāsi": ['cped'],
    "abbhaññāsuṁ": ['cped'],
    "abbhenta": ['cped'],
    "abbhetabba": ['cped'],
    "abbheti": ['cped'],
    "abbhita": ['cped'],
    "abbhiññāsi": ['cped'],
    "abbhokāsa": ['cped'],
    "abbhokāsi": ['cped'],
    "abbhokāsika": ['cped'],
    "abbhokāsin": ['cped'],
    "abbhra": ['ap90'],
    "abbhu": ['cped'],
    "abbhucittajāta": ['cped'],
    "abbhudayati": ['cped'],
    "abbhudeti": ['cped'],
    "abbhudāhasi": ['cped'],
    "abbhudīrayati": ['cped'],
    "abbhudīrayi": ['cped'],
    "abbhudīresuṁ": ['cped'],
    "abbhudīreti": ['cped'],
    "abbhuggacchati": ['cped'],
    "abbhuggacchi": ['cped'],
    "abbhuggacchissati": ['cped'],
    "abbhuggacchuṁ": ['cped'],
    "abbhuggahetvā": ['cped'],
    "abbhuggantvā": ['cped'],
    "abbhuggata": ['cped'],
    "abbhuggañchi": ['cped'],
    "abbhuggañchuṁ": ['cped'],
    "abbhuggañchīti": ['cped'],
    "abbhujjalana": ['cped'],
    "abbhukkirati": ['cped'],
    "abbhunnadita": ['cped'],
    "abbhunnamati": ['cped'],
    "abbhunnameti": ['cped'],
    "abbhunnamitvā": ['cped'],
    "abbhunnāmeti": ['cped'],
    "abbhussahana": ['cped'],
    "abbhussakkamāna": ['cped'],
    "abbhussukkamāna": ['cped'],
    "abbhusūyaka": ['cped'],
    "abbhuta": ['cped'],
    "abbhutadhamma": ['cped'],
    "abbhutaṁ": ['cped'],
    "abbhutaṁ karoti": ['cped'],
    "abbhuyyāsi": ['cped'],
    "abbhuyyāta": ['cped'],
    "abbhuyyāti": ['cped'],
    "abbhuṁ": ['cped'],
    "abbhuṭṭhāsi": ['cped'],
    "abbhuṭṭhāti": ['cped'],
    "abbhācikkhanta": ['cped'],
    "abbhācikkhati": ['cped'],
    "abbhācikkhi": ['cped'],
    "abbhācikkhiṁ": ['cped'],
    "abbhāgamana": ['cped'],
    "abbhāgata": ['cped'],
    "abbhāghātanissita": ['cped'],
    "abbhāhata": ['cped'],
    "abbhāna": ['cped'],
    "abbindu": ['mw'],
    "abbocchinna": ['cped'],
    "abbudda": ['cped'],
    "abbuhana": ['cped'],
    "abbuhati": ['cped'],
    "abbuhi": ['cped'],
    "abbuhitvā": ['cped'],
    "abbuyha": ['cped'],
    "abbuḷha": ['cped'],
    "abbuḷhasalla": ['cped'],
    "abbā": ['mw'],
    "abbāhi": ['cped'],
    "abbāhitvā": ['cped'],
    "abbūhana": ['cped'],
    "abbūhati": ['cped'],
    "abbūḷha": ['cped'],
    "abbūḷhasalla": ['cped'],
    "abda": ['ap90', 'cae', 'ddsa', 'mw'],
    "abdabhū": ['ddsa', 'mw'],
    "abdaivata": ['cae', 'ddsa', 'mw'],
    "abdaparyaya": ['cae', 'mw'],
    "abdasahasra": ['mw'],
    "abdasāra": ['mw'],
    "abdatantra": ['mw'],
    "abdavāhana": ['mw'],
    "abdayā": ['ap90', 'cae', 'gra', 'mw'],
    "abdaśata": ['mw'],
    "abdevatāka": ['ap90'],
    "abdhi": ['cae', 'ddsa', 'mw'],
    "abdhidvīpā": ['mw'],
    "abdhija": ['mw'],
    "abdhijau": ['mw'],
    "abdhijhaṣa": ['mw'],
    "abdhijā": ['mw'],
    "abdhijīvin": ['mw'],
    "abdhikanyā": ['mw'],
    "abdhikapha": ['mw'],
    "abdhimathana": ['mw'],
    "abdhimaṇḍūkī": ['mw'],
    "abdhinagarī": ['mw'],
    "abdhinavanītaka": ['mw'],
    "abdhiphena": ['mw'],
    "abdhisāra": ['mw'],
    "abdhitanaya": ['mw'],
    "abdhivastrā": ['mw'],
    "abdhiśayana": ['mw'],
    "abdhiḥ": ['ap90'],
    "abdhyagni": ['mw'],
    "abdimat": ['gra', 'mw'],
    "abdiḥ": ['ap90'],
    "abdurga": ['cae', 'ddsa', 'mw'],
    "abdurgaḥ": ['ap90'],
    "abdā": ['mw'],
    "abdārdha": ['cae', 'mw'],
    "abhadra": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhaga": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhagna": ['mw'],
    "abhagnakāma": ['ddsa', 'mw'],
    "abhaiṣajya": ['bhs', 'mw'],
    "abhajyamāna": ['ddsa', 'mw'],
    "abhakta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhaktacchanda": ['mw'],
    "abhaktaruci": ['mw'],
    "abhakti": ['mw'],
    "abhaktimat": ['mw'],
    "abhaktiḥ": ['ap90'],
    "abhakṣa": ['mw'],
    "abhakṣaḥ": ['ap90'],
    "abhakṣaṇa": ['mw'],
    "abhakṣita": ['mw'],
    "abhakṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhakṣyabhakṣaṇa": ['mw'],
    "abhakṣyabhakṣin": ['cae', 'mw'],
    "abhartṛkā": ['ap90', 'mw'],
    "abhastra": ['mw'],
    "abhastrakā": ['ap90', 'mw'],
    "abhastrikā": ['mw'],
    "abhaujiṣya": ['mw'],
    "abhauma": ['ap90'],
    "abhauti": ['bhs'],
    "abhautika": ['ap90', 'mw'],
    "abhava": ['mw'],
    "abhavadīya": ['ddsa', 'mw'],
    "abhavani": ['mw'],
    "abhavanmatasambandha": ['mw'],
    "abhavanmatayoga": ['mw'],
    "abhavanīya": ['mw'],
    "abhavat": ['ap90'],
    "abhavaḥ": ['ap90'],
    "abhavya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "abhavyahaṃsa": ['mw'],
    "abhavyatā": ['bhs'],
    "abhaya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "abhayada": ['cae', 'mw'],
    "abhayadakṣiṇā": ['cae', 'mw'],
    "abhayadatta": ['mw'],
    "abhayadeva": ['bhs'],
    "abhayadāna": ['mw'],
    "abhayagaṇa": ['mw'],
    "abhayagirivihāra": ['mw'],
    "abhayagirivāsin": ['bhs', 'mw'],
    "abhayajāta": ['mw'],
    "abhayapattra": ['mw'],
    "abhayaprada": ['cae', 'mw'],
    "abhayapradāna": ['mw'],
    "abhayapradāyin": ['cae'],
    "abhayapurā": ['bhs'],
    "abhayasani": ['mw'],
    "abhayatama": ['mw'],
    "abhayavacana": ['mw'],
    "abhayavāc": ['mw'],
    "abhayayācanā": ['mw'],
    "abhayaḍiṇḍima": ['ddsa', 'mw'],
    "abhayaṃdada": ['bhs', 'mw'],
    "abhayaṃkara": ['ap90', 'cae', 'gra', 'mw'],
    "abhayaṃkarā": ['bhs'],
    "abhayaṃkṛt": ['cae', 'mw'],
    "abhayaṅkara": ['ddsa'],
    "abhayā": ['bhs', 'mw'],
    "abhayākaragupta": ['bhs'],
    "abhayānanda": ['mw'],
    "abhaṃga": ['ap90'],
    "abhaṃgura": ['ap90'],
    "abhaṅgaśleṣa": ['mw'],
    "abhaṅgura": ['mw'],
    "abhaṇita": ['cae', 'ddsa'],
    "abhaṇitvā": ['cae'],
    "abheda": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhedaka": ['mw'],
    "abhedin": ['mw'],
    "abhedya": ['ap90', 'cae', 'mw'],
    "abhedyatva": ['mw'],
    "abhedyatā": ['mw'],
    "abhejja": ['cped'],
    "abhettṛ": ['cae', 'ddsa'],
    "abhi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhi-uggantvā": ['cped'],
    "abhi-uggañchi": ['cped'],
    "abhi-uyyāta": ['cped'],
    "abhiardhayajvan": ['gra'],
    "abhiañjana": ['gra'],
    "abhibala": ['mw'],
    "abhibalaṃ": ['ap90'],
    "abhibhaj": ['mw'],
    "abhibhakkayitvā": ['cped'],
    "abhibhakṣaṇa": ['bhs'],
    "abhibharts": ['mw'],
    "abhibhartṛ": ['ddsa', 'mw'],
    "abhibhava": ['cae', 'mw'],
    "abhibhavana": ['cped', 'mw'],
    "abhibhavanaṃ": ['ap90'],
    "abhibhavanīya": ['mw'],
    "abhibhavati": ['bhs'],
    "abhibhavaḥ": ['ap90'],
    "abhibhañj": ['mw'],
    "abhibhaṃgaḥ": ['ap90'],
    "abhibhaṅga": ['gra', 'mw'],
    "abhibhinatti": ['bhs'],
    "abhibhosmi": ['cped'],
    "abhibhu": ['cae', 'ddsa', 'mw'],
    "abhibhuj": ['mw'],
    "abhibhuyya": ['cped'],
    "abhibhuyyacāri": ['cped'],
    "abhibhuyyacārin": ['cped'],
    "abhibhuḥ": ['ap90'],
    "abhibhvāyatana": ['bhs'],
    "abhibhā": ['ap90', 'gra', 'mw'],
    "abhibhāna": ['bhs'],
    "abhibhāra": ['ap90', 'mw'],
    "abhibhāvaka": ['mw'],
    "abhibhāvana": ['bhs', 'mw'],
    "abhibhāvanaṃ": ['ap90'],
    "abhibhāvin": ['ap90', 'mw'],
    "abhibhāvuka": ['mw'],
    "abhibhāyatana": ['cped', 'mw'],
    "abhibhāṣ": ['ap90', 'mw'],
    "abhibhāṣati": ['bhs'],
    "abhibhāṣaṇa": ['ddsa', 'mw'],
    "abhibhāṣaṇaṃ": ['ap90'],
    "abhibhāṣin": ['ap90', 'cae', 'mw'],
    "abhibhāṣita": ['mw'],
    "abhibhāṣya": ['mw'],
    "abhibhāṣyamāṇa": ['mw'],
    "abhibhū": ['ap90', 'bhs', 'cae', 'cped', 'gra', 'mw'],
    "abhibhūta": ['cped', 'mw'],
    "abhibhūti": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhibhūtiojas": ['gra'],
    "abhibhūtyojas": ['cae', 'ddsa', 'gra', 'mw'],
    "abhibhūvan": ['ap90', 'gra', 'mw'],
    "abhibhūya": ['mw'],
    "abhibhūyayaśa": ['bhs'],
    "abhibhūyaṃ": ['ap90'],
    "abhibhūṣ": ['mw'],
    "abhibhṛ": ['mw'],
    "abhibrū": ['mw'],
    "abhibuddhi": ['mw'],
    "abhibuddhiḥ": ['ap90'],
    "abhibudhyati": ['bhs'],
    "abhibādh": ['mw'],
    "abhibādhitṛ": ['mw'],
    "abhicaidyam": ['ddsa', 'mw'],
    "abhicakṣ": ['ap90', 'mw'],
    "abhicakṣaṇa": ['ddsa', 'mw'],
    "abhicakṣaṇaṃ": ['ap90'],
    "abhicakṣaṇā": ['mw'],
    "abhicakṣe": ['cae'],
    "abhicakṣya": ['mw'],
    "abhicar": ['ap90', 'mw'],
    "abhicara": ['mw'],
    "abhicaraḥ": ['ap90'],
    "abhicaraṇa": ['cped', 'mw'],
    "abhicaraṇaṃ": ['ap90'],
    "abhicaraṇīya": ['ap90', 'mw'],
    "abhicarita": ['mw'],
    "abhicarituḥ": ['ap90'],
    "abhicchad": ['mw'],
    "abhicchanna": ['cped'],
    "abhicchāya": ['ap90'],
    "abhicchāyam": ['mw'],
    "abhicchāyā": ['mw'],
    "abhiceṣṭā": ['mw'],
    "abhichanna": ['cped'],
    "abhichāda": ['bhs'],
    "abhichādana": ['bhs'],
    "abhichādayati": ['bhs'],
    "abhicihnaya": ['mw'],
    "abhicint": ['mw'],
    "abhicud": ['mw'],
    "abhicumb": ['mw'],
    "abhicākaś": ['mw'],
    "abhicāra": ['cae', 'ddsa', 'mw'],
    "abhicārahoma": ['mw'],
    "abhicārajvara": ['mw'],
    "abhicāraka": ['ap90', 'mw'],
    "abhicārakalpa": ['mw'],
    "abhicāramantra": ['mw'],
    "abhicārayajña": ['mw'],
    "abhicāraḥ": ['ap90'],
    "abhicāraṇīya": ['mw'],
    "abhicārin": ['mw'],
    "abhicārita": ['mw'],
    "abhicārya": ['mw'],
    "abhidadhat": ['mw'],
    "abhidadi": ['mw'],
    "abhidah": ['mw'],
    "abhidakṣiṇam": ['mw'],
    "abhidakṣiṇati": ['bhs'],
    "abhidakṣiṇaṃ": ['ap90'],
    "abhidanta": ['cped'],
    "abhidantaṁ": ['cped'],
    "abhidarśana": ['cae', 'ddsa', 'mw'],
    "abhidarśanaṃ": ['ap90'],
    "abhidarśanīya": ['bhs'],
    "abhidaśati": ['bhs'],
    "abhidaṣṭa": ['mw'],
    "abhidevaghoṣaghuṣṭa": ['bhs'],
    "abhidevana": ['mw'],
    "abhidham": ['mw'],
    "abhidhamati": ['cped'],
    "abhidhamma": ['cped'],
    "abhidhammakatha": ['cped'],
    "abhidhamme": ['cped'],
    "abhidhanv": ['mw'],
    "abhidharma": ['bhs', 'ddsa', 'mw'],
    "abhidharmakośa": ['mw'],
    "abhidharmapiṭaka": ['mw'],
    "abhidharmasaṃyukta": ['bhs'],
    "abhidharmaḥ": ['ap90'],
    "abhidharṣaṇa": ['mw'],
    "abhidharṣaṇaṃ": ['ap90'],
    "abhidheya": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhidheyarahita": ['mw'],
    "abhidheyatā": ['mw'],
    "abhidhi": ['mw'],
    "abhidhitsā": ['mw'],
    "abhidhmāta": ['mw'],
    "abhidhvan": ['mw'],
    "abhidhvasta": ['mw'],
    "abhidhvaṃs": ['mw'],
    "abhidhyai": ['ap90', 'mw'],
    "abhidhyeya": ['mw'],
    "abhidhyā": ['ap90', 'bhs', 'mw'],
    "abhidhyālu": ['bhs', 'mw'],
    "abhidhyāna": ['cae', 'ddsa', 'mw'],
    "abhidhyānaṃ": ['ap90'],
    "abhidhyāyati": ['bhs'],
    "abhidhyāyin": ['mw'],
    "abhidhā": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhidhādhvaṃsin": ['mw'],
    "abhidhāmūla": ['mw'],
    "abhidhāna": ['cae', 'mw'],
    "abhidhānacintāmaṇi": ['mw'],
    "abhidhānaka": ['mw'],
    "abhidhānakaṃ": ['ap90'],
    "abhidhānakoṃśa": ['cae'],
    "abhidhānamālā": ['mw'],
    "abhidhānaratnamālā": ['mw'],
    "abhidhānatva": ['mw'],
    "abhidhānaṃ": ['ap90'],
    "abhidhānī": ['ap90', 'mw'],
    "abhidhānīya": ['mw'],
    "abhidhārayati": ['bhs'],
    "abhidhātavya": ['mw'],
    "abhidhātṛ": ['mw'],
    "abhidhāv": ['ap90', 'mw'],
    "abhidhāvaka": ['ap90', 'mw'],
    "abhidhāvana": ['mw'],
    "abhidhāvanaṃ": ['ap90'],
    "abhidhāvati": ['cped'],
    "abhidhāvi": ['cped'],
    "abhidhāya": ['mw'],
    "abhidhāyaka": ['ap90', 'mw'],
    "abhidhāyakatva": ['mw'],
    "abhidhāyam": ['mw'],
    "abhidhāyi": ['cped'],
    "abhidhāyin": ['cped', 'mw'],
    "abhidhī": ['mw'],
    "abhidhū": ['mw'],
    "abhidhṛ": ['mw'],
    "abhidhṛṣ": ['mw'],
    "abhidhṛṣṇu": ['ap90', 'mw'],
    "abhidigdha": ['mw'],
    "abhidih": ['mw'],
    "abhidipsu": ['gra', 'mw'],
    "abhidiś": ['mw'],
    "abhido": ['cped'],
    "abhidohana": ['mw'],
    "abhidohya": ['mw'],
    "abhidosaṁkālakata": ['cped'],
    "abhidosaṁkālaṅkata": ['cped'],
    "abhidosika": ['cped'],
    "abhidoṣam": ['mw'],
    "abhidravaḥ": ['ap90'],
    "abhidroha": ['cae', 'gra', 'mw'],
    "abhidrohaḥ": ['ap90'],
    "abhidru": ['ap90', 'mw'],
    "abhidrugdha": ['mw'],
    "abhidruh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhidruhyamāṇa": ['mw'],
    "abhidruta": ['ap90', 'mw'],
    "abhidrutya": ['mw'],
    "abhidrā": ['mw'],
    "abhidu": ['mw'],
    "abhiduh": ['mw'],
    "abhiduṣ": ['mw'],
    "abhiduṣṭa": ['mw'],
    "abhidyotana": ['bhs'],
    "abhidyotayati": ['bhs'],
    "abhidyu": ['ap90', 'cae', 'gra', 'mw'],
    "abhidā": ['mw'],
    "abhidāpana": ['mw'],
    "abhidāpanaṃ": ['ap90'],
    "abhidās": ['mw'],
    "abhidī": ['mw'],
    "abhidīkṣ": ['mw'],
    "abhidīp": ['mw'],
    "abhidūtam": ['ddsa', 'mw'],
    "abhidūti": ['mw'],
    "abhidūṣita": ['mw'],
    "abhidṛś": ['ap90', 'mw'],
    "abhidṛḍha": ['bhs'],
    "abhigacchat": ['mw'],
    "abhigai": ['ap90', 'mw'],
    "abhigajja": ['cped'],
    "abhigajjat": ['cped'],
    "abhigajjati": ['cped'],
    "abhigajji": ['cped'],
    "abhigajjin": ['cped'],
    "abhigam": ['ap90', 'mw'],
    "abhigama": ['cae', 'mw'],
    "abhigamana": ['mw'],
    "abhigamaḥ": ['ap90'],
    "abhigamya": ['ap90', 'cae', 'mw'],
    "abhigantavya": ['ddsa'],
    "abhigantṛ": ['mw'],
    "abhigara": ['mw'],
    "abhigaraḥ": ['ap90'],
    "abhigarj": ['ap90', 'mw'],
    "abhigarjana": ['cae', 'mw'],
    "abhigarjanaṃ": ['ap90'],
    "abhigarjin": ['ddsa'],
    "abhigarjita": ['cae', 'mw'],
    "abhigata": ['mw'],
    "abhigaṃtṛ": ['ap90'],
    "abhigeṣṇa": ['ap90', 'mw'],
    "abhigharṣaṇa": ['mw'],
    "abhigharṣaṇaṃ": ['ap90'],
    "abhighoṣa": ['bhs'],
    "abhighoṣam": ['mw'],
    "abhighrā": ['ap90', 'mw'],
    "abhighrāṇa": ['mw'],
    "abhighrāṇaṃ": ['ap90'],
    "abhighāra": ['mw'],
    "abhighāraḥ": ['ap90'],
    "abhighāraṇa": ['mw'],
    "abhighāraṇaṃ": ['ap90'],
    "abhighārita": ['mw'],
    "abhighārya": ['mw'],
    "abhighāta": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhighātaka": ['ap90', 'mw'],
    "abhighātaḥ": ['ap90'],
    "abhighātin": ['ap90', 'cae', 'mw'],
    "abhighātita": ['mw'],
    "abhighṛ": ['ap90', 'mw'],
    "abhighṛta": ['cae', 'mw'],
    "abhigijjhati": ['cped'],
    "abhigoptṛ": ['ap90', 'mw'],
    "abhigopāya": ['mw'],
    "abhigrah": ['ap90', 'mw'],
    "abhigraha": ['mw'],
    "abhigrahaḥ": ['ap90'],
    "abhigrahaṇa": ['bhs', 'mw'],
    "abhigrahaṇaṃ": ['ap90'],
    "abhigrahītṛ": ['mw'],
    "abhigrasta": ['bhs', 'mw'],
    "abhigrāhin": ['mw'],
    "abhigumphita": ['mw'],
    "abhigup": ['ap90'],
    "abhigupta": ['cae', 'mw'],
    "abhigupti": ['mw'],
    "abhiguptiḥ": ['ap90'],
    "abhigur": ['ap90', 'mw'],
    "abhigā": ['ap90', 'mw'],
    "abhigāh": ['mw'],
    "abhigāmi": ['cped'],
    "abhigāmin": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "abhigāmuka": ['ap90'],
    "abhigīta": ['ap90', 'bhs', 'mw'],
    "abhigūrta": ['ap90', 'mw'],
    "abhigūrti": ['ddsa', 'gra', 'mw'],
    "abhigūrtiḥ": ['ap90'],
    "abhigūryā": ['mw'],
    "abhigṛdhna": ['mw'],
    "abhigṛhīta": ['mw'],
    "abhigṛhītapāṇi": ['mw'],
    "abhigṛhṇati": ['bhs'],
    "abhigṝ": ['ap90', 'mw'],
    "abhihan": ['ap90', 'mw'],
    "abhihara": ['mw'],
    "abhiharati": ['cped'],
    "abhiharaḥ": ['ap90'],
    "abhiharaṇa": ['mw'],
    "abhiharaṇaṃ": ['ap90'],
    "abhiharaṇīya": ['mw'],
    "abhihariyitthā": ['cped'],
    "abhihariṁsu": ['cped'],
    "abhihartavya": ['mw'],
    "abhihartṛ": ['ap90', 'mw'],
    "abhihary": ['mw'],
    "abhihasati": ['cped'],
    "abhihasya": ['ap90', 'cae', 'mw'],
    "abhihata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "abhihati": ['mw'],
    "abhihatiḥ": ['ap90'],
    "abhihatya": ['mw'],
    "abhihava": ['mw'],
    "abhihavana": ['mw'],
    "abhihavaḥ": ['ap90'],
    "abhihaṭa": ['cped'],
    "abhihaṭṭhuṁ": ['cped'],
    "abhiheṣ": ['mw'],
    "abhihita": ['ap90', 'cae', 'mw'],
    "abhihitatva": ['mw'],
    "abhihitatā": ['mw'],
    "abhihiti": ['mw'],
    "abhihitiḥ": ['ap90'],
    "abhihiṁsamāna": ['cped'],
    "abhihiṃsana": ['mw'],
    "abhihiṅkāra": ['mw'],
    "abhihiṅkṛ": ['mw'],
    "abhihoma": ['mw'],
    "abhihomaḥ": ['ap90'],
    "abhihotavai": ['mw'],
    "abhihrut": ['ap90', 'cae', 'gra', 'mw'],
    "abhihruti": ['ap90', 'cae', 'gra', 'mw'],
    "abhihu": ['ap90', 'mw'],
    "abhihuta": ['mw'],
    "abhihvara": ['ap90'],
    "abhihve": ['mw'],
    "abhihvāra": ['mw'],
    "abhihā": ['mw'],
    "abhihāra": ['bhs', 'cped', 'mw'],
    "abhihārayati": ['cped'],
    "abhihārayi": ['cped'],
    "abhihārayiṁ": ['cped'],
    "abhihāraḥ": ['ap90'],
    "abhihāresi": ['cped'],
    "abhihāreti": ['cped'],
    "abhihārya": ['mw'],
    "abhihāsa": ['mw'],
    "abhihāsana": ['cped'],
    "abhihāsaḥ": ['ap90'],
    "abhihūti": ['mw'],
    "abhihūtiḥ": ['ap90'],
    "abhihṛ": ['ap90', 'mw'],
    "abhihṛṣ": ['mw'],
    "abhija": ['ap90', 'mw'],
    "abhijabh": ['mw'],
    "abhijalp": ['mw'],
    "abhijan": ['ap90', 'mw'],
    "abhijana": ['cae', 'ddsa', 'mw'],
    "abhijanana": ['ap90'],
    "abhijanavat": ['ap90', 'mw'],
    "abhijanaḥ": ['ap90'],
    "abhijanituḥ": ['ap90'],
    "abhijap": ['mw'],
    "abhijappa": ['cped'],
    "abhijappana": ['cped'],
    "abhijappapadāraṇa": ['cped'],
    "abhijappati": ['cped'],
    "abhijappayati": ['cped'],
    "abhijappi": ['cped'],
    "abhijappin": ['cped'],
    "abhijappā": ['cped'],
    "abhijavati": ['cped'],
    "abhijaya": ['mw'],
    "abhijayaḥ": ['ap90'],
    "abhijañña": ['cped'],
    "abhiji": ['ap90', 'bhs', 'mw'],
    "abhijidviśvajitau": ['mw'],
    "abhijighrat": ['mw'],
    "abhijighraṇa": ['mw'],
    "abhijigiṁsati": ['cped'],
    "abhijigīsati": ['cped'],
    "abhijinmuhūrta": ['mw'],
    "abhijit": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhijita": ['mw'],
    "abhijitaḥ": ['ap90'],
    "abhijiti": ['mw'],
    "abhijitiḥ": ['ap90'],
    "abhijjhati": ['cped'],
    "abhijjhita": ['cped'],
    "abhijjhitar": ['cped'],
    "abhijjhā": ['cped'],
    "abhijjhālu": ['cped'],
    "abhijjhāta": ['cped'],
    "abhijjhātar": ['cped'],
    "abhijjhāyanta": ['cped'],
    "abhijjhāyati": ['cped'],
    "abhijjhāyiṁsu": ['cped'],
    "abhijuṣ": ['ap90', 'mw'],
    "abhijuṣṭa": ['ap90', 'mw'],
    "abhijval": ['mw'],
    "abhijña": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhijñatva": ['mw'],
    "abhijñatā": ['mw'],
    "abhijñetara": ['mw'],
    "abhijñu": ['ap90', 'cae', 'gra', 'mw'],
    "abhijñā": ['ap90', 'bhs', 'mw'],
    "abhijñājñānābhibhū": ['bhs'],
    "abhijñāketu": ['bhs'],
    "abhijñāna": ['cae', 'ddsa', 'mw'],
    "abhijñānapattra": ['mw'],
    "abhijñānaśakuntala": ['mw'],
    "abhijñānaṃ": ['ap90'],
    "abhijñāpaka": ['ap90', 'mw'],
    "abhijñāta": ['bhs', 'mw'],
    "abhijñāvatī": ['bhs'],
    "abhijñāyam": ['mw'],
    "abhijānā": ['cped'],
    "abhijānānta": ['cped'],
    "abhijānāt": ['cped'],
    "abhijānāti": ['bhs', 'cped'],
    "abhijāta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "abhijātatā": ['mw'],
    "abhijātavāc": ['mw'],
    "abhijāti": ['cae', 'cped', 'mw'],
    "abhijātiḥ": ['ap90'],
    "abhijātīya": ['mw'],
    "abhijāyati": ['cped'],
    "abhijāyitvā": ['cped'],
    "abhijīvanika": ['cped'],
    "abhijīvin": ['bhs'],
    "abhijṛmbh": ['mw'],
    "abhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhikam": ['ap90', 'mw'],
    "abhikamp": ['mw'],
    "abhikara": ['mw'],
    "abhikaraṇa": ['mw'],
    "abhikaraṇaṃ": ['ap90'],
    "abhikarman": ['mw'],
    "abhikarṇakūpam": ['mw'],
    "abhikaṃp": ['ap90'],
    "abhikaṃpanaṃ": ['ap90'],
    "abhikaṅkhamāna": ['cped'],
    "abhikaṅkhanta": ['cped'],
    "abhikaṅkhat": ['cped'],
    "abhikaṅkhati": ['cped'],
    "abhikaṅkhatt": ['cped'],
    "abhikhan": ['mw'],
    "abhikhya": ['mw'],
    "abhikhyā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhikhyāna": ['mw'],
    "abhikhyānaṃ": ['ap90'],
    "abhikhyāta": ['ap90', 'cae', 'mw'],
    "abhikhyātṛ": ['ap90', 'gra', 'mw'],
    "abhikirati": ['cped'],
    "abhikiraṇa": ['bhs'],
    "abhikkama": ['cped'],
    "abhikkamana": ['cped'],
    "abhikkamanta": ['cped'],
    "abhikkamanīya": ['cped'],
    "abhikkamati": ['cped'],
    "abhikkanta": ['cped'],
    "abhikkantadassāvi": ['cped'],
    "abhikkantadassāvin": ['cped'],
    "abhikkantatara": ['cped'],
    "abhikkantavaṇṇa": ['cped'],
    "abhikkantaṁ": ['cped'],
    "abhikkhaṇa": ['cped'],
    "abhikkhaṇanta": ['cped'],
    "abhikkhaṇati": ['cped'],
    "abhikkhaṇaṁ": ['cped'],
    "abhikkhaṇaṁātaṅka": ['cped'],
    "abhikkāmi": ['cped'],
    "abhikkāmuṁ": ['cped'],
    "abhiknūyam": ['mw'],
    "abhikram": ['ap90', 'mw'],
    "abhikrama": ['cae', 'ddsa', 'mw'],
    "abhikramanāśa": ['mw'],
    "abhikramaḥ": ['ap90'],
    "abhikramaṇa": ['mw'],
    "abhikramaṇaṃ": ['ap90'],
    "abhikrand": ['mw'],
    "abhikranda": ['mw'],
    "abhikratu": ['ap90', 'gra', 'mw'],
    "abhikraṃd": ['ap90'],
    "abhikraṃdaḥ": ['ap90'],
    "abhikrośaka": ['mw'],
    "abhikrośakaḥ": ['ap90'],
    "abhikrośaḥ": ['ap90'],
    "abhikruddha": ['mw'],
    "abhikrudh": ['mw'],
    "abhikruś": ['ap90', 'mw'],
    "abhikrāmam": ['mw'],
    "abhikrānta": ['bhs', 'mw'],
    "abhikrānti": ['mw'],
    "abhikrāntin": ['mw'],
    "abhikrāṃtin": ['ap90'],
    "abhikrī": ['mw'],
    "abhikuts": ['mw'],
    "abhikuṣ": ['mw'],
    "abhikāla": ['mw'],
    "abhikāma": ['ap90', 'cae', 'mw'],
    "abhikāmam": ['mw'],
    "abhikāmi": ['cped'],
    "abhikāmika": ['ap90'],
    "abhikāmin": ['cped'],
    "abhikāś": ['mw'],
    "abhikāṃkṣ": ['ap90'],
    "abhikāṃkṣin": ['ap90'],
    "abhikāṃkṣā": ['ap90'],
    "abhikāṅkṣ": ['mw'],
    "abhikāṅkṣin": ['cae', 'mw'],
    "abhikāṅkṣita": ['mw'],
    "abhikāṅkṣā": ['cae', 'ddsa', 'mw'],
    "abhikīrati": ['cped'],
    "abhikīrtana": ['bhs'],
    "abhikīrṇīkṛta": ['bhs'],
    "abhikūj": ['mw'],
    "abhikḷp": ['mw'],
    "abhikḷpta": ['cae', 'mw'],
    "abhikṛ": ['ap90', 'mw'],
    "abhikṛti": ['mw'],
    "abhikṛtiḥ": ['ap90'],
    "abhikṛtvan": ['ap90'],
    "abhikṛtvarī": ['mw'],
    "abhikṛṣ": ['mw'],
    "abhikṛṣṇam": ['ddsa', 'mw'],
    "abhikṝ": ['mw'],
    "abhikṣada": ['ap90'],
    "abhikṣadā": ['cae', 'ddsa', 'gra', 'mw'],
    "abhikṣam": ['mw'],
    "abhikṣar": ['mw'],
    "abhikṣattṛ": ['ap90', 'gra', 'mw'],
    "abhikṣepa": ['mw'],
    "abhikṣip": ['ap90', 'mw'],
    "abhikṣipta": ['ap90'],
    "abhikṣita": ['mw'],
    "abhikṣuka": ['bhs'],
    "abhilabh": ['mw'],
    "abhilagna": ['bhs'],
    "abhilakkhita": ['cped'],
    "abhilakṣ": ['mw'],
    "abhilakṣaṇa": ['bhs', 'mw'],
    "abhilakṣita": ['ap90', 'bhs', 'mw'],
    "abhilakṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhilakṣyam": ['cae', 'ddsa', 'mw'],
    "abhilakṣyīkṛtya": ['mw'],
    "abhilambha": ['mw'],
    "abhilap": ['ap90', 'mw'],
    "abhilapanatā": ['bhs'],
    "abhilapya": ['mw'],
    "abhilaṃgh": ['ap90'],
    "abhilaṃghanaṃ": ['ap90'],
    "abhilaṅgh": ['mw'],
    "abhilaṅghana": ['cae', 'ddsa', 'mw'],
    "abhilaṅghin": ['cae', 'mw'],
    "abhilaṣ": ['ap90', 'mw'],
    "abhilaṣaṇa": ['mw'],
    "abhilaṣaṇaṃ": ['ap90'],
    "abhilaṣaṇīya": ['mw'],
    "abhilaṣita": ['ap90', 'mw'],
    "abhilaṣitārthacintāmaṇi": ['mw'],
    "abhilekhana": ['mw'],
    "abhilekhita": ['ddsa', 'mw'],
    "abhilepana": ['cped'],
    "abhilikh": ['mw'],
    "abhilikhati": ['bhs'],
    "abhilikhita": ['ap90'],
    "abhilip": ['mw'],
    "abhilipsā": ['mw'],
    "abhilok": ['mw'],
    "abhilokana": ['bhs'],
    "abhilubh": ['mw'],
    "abhilulita": ['ap90', 'cae', 'mw'],
    "abhilup": ['mw'],
    "abhilupta": ['mw'],
    "abhilābhi": ['cped'],
    "abhilābhin": ['cped'],
    "abhilāpa": ['cped', 'ddsa', 'mw'],
    "abhilāpaḥ": ['ap90'],
    "abhilāpya": ['bhs'],
    "abhilāsa": ['mw'],
    "abhilāsi": ['cped'],
    "abhilāsin": ['cped'],
    "abhilāva": ['mw'],
    "abhilāvaḥ": ['ap90'],
    "abhilāṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "abhilāṣaka": ['ap90', 'mw'],
    "abhilāṣapūrayitṛka": ['cae'],
    "abhilāṣaḥ": ['ap90'],
    "abhilāṣika": ['bhs'],
    "abhilāṣin": ['mw'],
    "abhilāṣuka": ['mw'],
    "abhilī": ['ap90', 'mw'],
    "abhilīna": ['ap90', 'cae', 'mw'],
    "abhilīnaka": ['bhs'],
    "abhilīyati": ['bhs'],
    "abhilūtā": ['ap90', 'mw'],
    "abhimad": ['ap90', 'mw'],
    "abhimaddati": ['cped'],
    "abhimaddita": ['cped'],
    "abhiman": ['ap90', 'mw'],
    "abhimana": ['cped'],
    "abhimanas": ['ap90', 'mw'],
    "abhimanasya": ['mw'],
    "abhimand": ['mw'],
    "abhimantavya": ['mw'],
    "abhimanth": ['mw'],
    "abhimantha": ['mw'],
    "abhimanthana": ['mw'],
    "abhimanthati": ['cped'],
    "abhimanthenta": ['cped'],
    "abhimantos": ['mw'],
    "abhimantr": ['mw'],
    "abhimantraṇa": ['mw'],
    "abhimantrita": ['mw'],
    "abhimantṛ": ['cae', 'mw'],
    "abhimanyanatā": ['bhs'],
    "abhimanyati": ['bhs'],
    "abhimanyatā": ['bhs'],
    "abhimanyu": ['cae', 'ddsa', 'mw'],
    "abhimanyupura": ['mw'],
    "abhimanyusvāmin": ['mw'],
    "abhimanyuḥ": ['ap90'],
    "abhimanāya": ['mw'],
    "abhimanāyate": ['ap90'],
    "abhimara": ['cae', 'mw'],
    "abhimaraḥ": ['ap90'],
    "abhimarda": ['mw'],
    "abhimardana": ['ap90', 'mw'],
    "abhimardaḥ": ['ap90'],
    "abhimardin": ['mw'],
    "abhimarśa": ['cae', 'ddsa', 'mw'],
    "abhimarśaka": ['ap90', 'mw'],
    "abhimarśana": ['mw'],
    "abhimarśaḥ": ['ap90'],
    "abhimarśin": ['mw'],
    "abhimarśā": ['mw'],
    "abhimarṣa": ['mw'],
    "abhimarṣaka": ['mw'],
    "abhimarṣaṇa": ['mw'],
    "abhimata": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhimatatā": ['mw'],
    "abhimati": ['mw'],
    "abhimatiḥ": ['ap90'],
    "abhimatta": ['cae'],
    "abhimatthana": ['cped'],
    "abhimatthati": ['cped'],
    "abhimatthenta": ['cped'],
    "abhimaṃthaḥ": ['ap90'],
    "abhimaṃtr": ['ap90'],
    "abhimaṃtraṇaṃ": ['ap90'],
    "abhimaṃtuḥ": ['ap90'],
    "abhimaṃtṛ": ['ap90'],
    "abhimaṅgala": ['mw'],
    "abhimaṅgalasammata": ['cped'],
    "abhimehya": ['ap90'],
    "abhimethana": ['mw'],
    "abhimethika": ['ap90'],
    "abhimethikā": ['mw'],
    "abhimih": ['mw'],
    "abhimihya": ['ap90', 'mw'],
    "abhimith": ['mw'],
    "abhimlāta": ['ap90', 'mw'],
    "abhimrakṣ": ['mw'],
    "abhimuc": ['mw'],
    "abhimuh": ['mw'],
    "abhimukha": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhimukham": ['mw'],
    "abhimukhatā": ['ap90', 'mw'],
    "abhimukhaya": ['mw'],
    "abhimukhe": ['mw'],
    "abhimukhī": ['bhs', 'mw'],
    "abhimukhībhūta": ['mw'],
    "abhimukhīkaraṇa": ['mw'],
    "abhimukhīkaraṇaṃ": ['ap90'],
    "abhimukhīkṛ": ['ap90', 'ddsa', 'mw'],
    "abhimuni": ['mw'],
    "abhimā": ['mw'],
    "abhimāda": ['mw'],
    "abhimādaḥ": ['ap90'],
    "abhimādyatka": ['ap90', 'mw'],
    "abhimāna": ['cae', 'gra', 'mw'],
    "abhimānatā": ['mw'],
    "abhimānavat": ['mw'],
    "abhimānaśālin": ['mw'],
    "abhimānaśūnya": ['mw'],
    "abhimānaḥ": ['ap90'],
    "abhimānika": ['bhs'],
    "abhimānikā": ['bhs'],
    "abhimānin": ['ap90', 'cae', 'mw'],
    "abhimānita": ['mw'],
    "abhimānitaṃ": ['ap90'],
    "abhimānitva": ['cae', 'mw'],
    "abhimānitā": ['mw'],
    "abhimānuka": ['ap90', 'mw'],
    "abhimārgaṇā": ['mw'],
    "abhimārutam": ['ddsa', 'mw'],
    "abhimāti": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhimātihan": ['gra', 'mw'],
    "abhimātijit": ['mw'],
    "abhimātin": ['ap90', 'cae', 'gra', 'mw'],
    "abhimātiṣāh": ['gra', 'mw'],
    "abhimātiṣāha": ['gra', 'mw'],
    "abhimātiṣāhia": ['gra'],
    "abhimātiṣāhya": ['gra', 'mw'],
    "abhimāya": ['ap90', 'mw'],
    "abhimūrchita": ['ap90', 'mw'],
    "abhimṛ": ['mw'],
    "abhimṛd": ['ap90', 'mw'],
    "abhimṛj": ['mw'],
    "abhimṛkṣ": ['mw'],
    "abhimṛta": ['mw'],
    "abhimṛś": ['ap90', 'mw'],
    "abhimṛḍ": ['mw'],
    "abhimṛṣṭa": ['ap90', 'mw'],
    "abhimṛṣṭaja": ['mw'],
    "abhinabhas": ['mw'],
    "abhinabhaḥ": ['ap90'],
    "abhinabhya": ['gra'],
    "abhinabhyam": ['cae', 'ddsa', 'mw'],
    "abhinad": ['mw'],
    "abhinadati": ['cped'],
    "abhinadatā": ['bhs'],
    "abhinaddha": ['mw'],
    "abhinaddhākṣa": ['mw'],
    "abhinadita": ['bhs'],
    "abhinah": ['ap90'],
    "abhinahana": ['ddsa', 'mw'],
    "abhinahanaṃ": ['ap90'],
    "abhinakṣ": ['mw'],
    "abhinam": ['ap90', 'mw'],
    "abhinamana": ['bhs'],
    "abhinamitā": ['bhs'],
    "abhinamra": ['ap90', 'mw'],
    "abhinand": ['mw'],
    "abhinanda": ['cae', 'cped', 'mw'],
    "abhinandamāna": ['cped'],
    "abhinandana": ['bhs', 'cped', 'mw'],
    "abhinandanīya": ['cae', 'ddsa', 'mw'],
    "abhinandat": ['cped'],
    "abhinandati": ['bhs', 'cped'],
    "abhinandi": ['cped'],
    "abhinandin": ['cae', 'mw'],
    "abhinandita": ['cped', 'mw'],
    "abhinanditṛ": ['mw'],
    "abhinandiṁsu": ['cped'],
    "abhinanduṁ": ['cped'],
    "abhinandya": ['cae', 'mw'],
    "abhinandā": ['mw'],
    "abhinard": ['mw'],
    "abhinata": ['cped', 'mw'],
    "abhinava": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhinavacandrārghavidhi": ['mw'],
    "abhinavagupta": ['mw'],
    "abhinavakālidāsa": ['mw'],
    "abhinavavaiyākaraṇa": ['mw'],
    "abhinavayauvana": ['mw'],
    "abhinavaśākaṭāyana": ['mw'],
    "abhinavodbhid": ['mw'],
    "abhinavībhū": ['mw'],
    "abhinaya": ['cae', 'mw'],
    "abhinayaḥ": ['ap90'],
    "abhinaś": ['mw'],
    "abhinaṃd": ['ap90'],
    "abhinaṃda": ['ap90'],
    "abhinaṃdanaṃ": ['ap90'],
    "abhinaṃdanīya": ['ap90'],
    "abhinaṃdin": ['ap90'],
    "abhindasroto": ['bhs'],
    "abhinetabba": ['cped'],
    "abhinetavya": ['mw'],
    "abhineti": ['cped'],
    "abhinetṛ": ['ap90', 'mw'],
    "abhineya": ['ap90', 'mw'],
    "abhinibbajjayati": ['cped'],
    "abhinibbatta": ['cped'],
    "abhinibbattaka": ['cped'],
    "abhinibbattati": ['cped'],
    "abhinibbattaya": ['cped'],
    "abhinibbattayat": ['cped'],
    "abhinibbattayati": ['cped'],
    "abhinibbattenta": ['cped'],
    "abhinibbattesuṁ": ['cped'],
    "abhinibbatteti": ['cped'],
    "abhinibbatti": ['cped'],
    "abhinibbhidā": ['cped'],
    "abhinibbhijja": ['cped'],
    "abhinibbhijjati": ['cped'],
    "abhinibbijja": ['cped'],
    "abhinibbijjayati": ['cped'],
    "abhinibbutatta": ['cped'],
    "abhiniddisati": ['cped'],
    "abhinidhana": ['ap90', 'mw'],
    "abhinidhyai": ['mw'],
    "abhinidhā": ['mw'],
    "abhinidhāna": ['mw'],
    "abhinidhānaṃ": ['ap90'],
    "abhinigad": ['mw'],
    "abhinigadana": ['mw'],
    "abhiniggaṇha": ['cped'],
    "abhiniggaṇhanā": ['cped'],
    "abhiniggaṇhat": ['cped'],
    "abhiniggaṇhitabba": ['cped'],
    "abhiniggaṇhāti": ['cped'],
    "abhinigūḍha": ['bhs'],
    "abhinigṛhṇati": ['bhs'],
    "abhinihan": ['mw'],
    "abhinihanati": ['cped'],
    "abhinihata": ['mw'],
    "abhinihita": ['ddsa', 'mw'],
    "abhinihnava": ['mw'],
    "abhinihnavaḥ": ['ap90'],
    "abhinikkhamana": ['cped'],
    "abhinikkhamati": ['cped'],
    "abhinikkhamitvā": ['cped'],
    "abhinikkhamma": ['cped'],
    "abhinikram": ['mw'],
    "abhinikūjati": ['bhs'],
    "abhinikūjita": ['bhs'],
    "abhinilīnaka": ['bhs'],
    "abhinilīyamānaka": ['mw'],
    "abhinimantana": ['cped'],
    "abhinimanteti": ['cped'],
    "abhinimantr": ['mw'],
    "abhinimlocana": ['mw'],
    "abhinimluc": ['mw'],
    "abhinimlupta": ['mw'],
    "abhinimmadana": ['cped'],
    "abhinimmina": ['cped'],
    "abhinimminanta": ['cped'],
    "abhinimmini": ['cped'],
    "abhinimminitvā": ['cped'],
    "abhinimmināti": ['cped'],
    "abhinimmitvā": ['cped'],
    "abhinimna": ['bhs'],
    "abhinimroka": ['mw'],
    "abhinimruc": ['mw'],
    "abhinimrukta": ['cae', 'mw'],
    "abhininartam": ['mw'],
    "abhininnāmesi": ['cped'],
    "abhininnāmesiṁ": ['cped'],
    "abhininnāmeti": ['cped'],
    "abhininī": ['mw'],
    "abhinipajjati": ['cped'],
    "abhinipajjayamāna": ['cped'],
    "abhinipajjitabba": ['cped'],
    "abhinipajjāpeti": ['cped'],
    "abhinipat": ['mw'],
    "abhinipatati": ['bhs'],
    "abhinipphajjati": ['cped'],
    "abhinipphanna": ['cped'],
    "abhinipphādenta": ['cped'],
    "abhinipphādesi": ['cped'],
    "abhinipphādesuṁ": ['cped'],
    "abhinipphādeti": ['cped'],
    "abhinipphādita": ['cped'],
    "abhinippīḷana": ['cped'],
    "abhinippīḷaya": ['cped'],
    "abhinippīḷayat": ['cped'],
    "abhinippīḷayati": ['cped'],
    "abhinippīḷetabba": ['cped'],
    "abhinippīḷeti": ['cped'],
    "abhinipuṇa": ['cped'],
    "abhinipāta": ['mw'],
    "abhinipātana": ['cped'],
    "abhinipāti": ['cped'],
    "abhinipātin": ['cped'],
    "abhinipīḍ": ['mw'],
    "abhinipīḍita": ['mw'],
    "abhiniras": ['mw'],
    "abhinirbharts": ['mw'],
    "abhinirbheda": ['bhs'],
    "abhinirbhidya": ['bhs'],
    "abhinirdiś": ['mw'],
    "abhinirgam": ['mw'],
    "abhinirghoṣa": ['bhs'],
    "abhinirharati": ['bhs'],
    "abhinirharaṇa": ['bhs'],
    "abhinirhāra": ['bhs'],
    "abhinirhāraka": ['bhs'],
    "abhinirhṛ": ['mw'],
    "abhinirjayati": ['bhs'],
    "abhinirjita": ['mw'],
    "abhinirmi": ['mw'],
    "abhinirmita": ['mw'],
    "abhinirmiṇoti": ['bhs'],
    "abhinirmukta": ['ap90', 'mw'],
    "abhinirnāmayati": ['bhs'],
    "abhiniropanā": ['cped'],
    "abhinirvad": ['mw'],
    "abhinirvap": ['mw'],
    "abhinirvarjya": ['bhs'],
    "abhinirvartaka": ['bhs'],
    "abhinirvartana": ['bhs'],
    "abhinirvāṇa": ['bhs'],
    "abhinirvṛt": ['mw'],
    "abhinirvṛti": ['bhs'],
    "abhinirvṛtta": ['bhs', 'mw'],
    "abhinirvṛtti": ['mw'],
    "abhinirvṛttiḥ": ['ap90'],
    "abhiniryā": ['mw'],
    "abhiniryāṇa": ['mw'],
    "abhiniryāṇaṃ": ['ap90'],
    "abhinirūpayati": ['bhs'],
    "abhinirūpaṇā": ['bhs'],
    "abhinirṇud": ['mw'],
    "abhinisinna": ['cped'],
    "abhinissaṭa": ['cped'],
    "abhinistāna": ['mw'],
    "abhinisyand": ['mw'],
    "abhinisīdanta": ['cped'],
    "abhinisīdati": ['cped'],
    "abhinisīdeti": ['cped'],
    "abhinisīdi": ['cped'],
    "abhinisīditabba": ['cped'],
    "abhinisīdituṁ": ['cped'],
    "abhinisīditvā": ['cped'],
    "abhinisīdiyamāna": ['cped'],
    "abhinisīdiṁsu": ['cped'],
    "abhinisīdāpeti": ['cped'],
    "abhinivajjayati": ['cped'],
    "abhinivajjeti": ['cped'],
    "abhinivajjetvā": ['cped'],
    "abhinivartam": ['mw'],
    "abhinivartate": ['bhs'],
    "abhinivartaḥ": ['ap90'],
    "abhinivasati": ['bhs'],
    "abhinivatteti": ['cped'],
    "abhinivattetvā": ['cped'],
    "abhinivaṭṭeti": ['cped'],
    "abhinivesa": ['cped'],
    "abhiniveseti": ['cped'],
    "abhiniveśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "abhiniveśana": ['bhs', 'mw'],
    "abhiniveśaḥ": ['ap90'],
    "abhiniveśin": ['ap90', 'cae', 'mw'],
    "abhiniveśita": ['mw'],
    "abhiniveṣyati": ['bhs'],
    "abhinivisati": ['cped'],
    "abhinivissa": ['cped'],
    "abhiniviś": ['ap90', 'mw'],
    "abhiniviśati": ['bhs'],
    "abhiniviṣṭa": ['ap90', 'cae', 'mw'],
    "abhiniviṣṭaka": ['mw'],
    "abhiniviṣṭatā": ['ap90', 'mw'],
    "abhiniviṣṭi": ['bhs'],
    "abhinivuttha": ['cped'],
    "abhinivutthapubba": ['cped'],
    "abhinivuṭṭha": ['cped'],
    "abhinivṛt": ['mw'],
    "abhinivṛtta": ['bhs'],
    "abhinivṛtti": ['bhs'],
    "abhiniyama": ['mw'],
    "abhiniyogaḥ": ['ap90'],
    "abhiniyukta": ['ap90', 'mw'],
    "abhiniśam": ['mw'],
    "abhiniścaya": ['bhs'],
    "abhiniścikramiṣā": ['mw'],
    "abhiniścita": ['cae', 'mw'],
    "abhiniśri": ['mw'],
    "abhiniḥstan": ['mw'],
    "abhiniḥsṛ": ['mw'],
    "abhiniḥsṛj": ['mw'],
    "abhiniḥsṛp": ['mw'],
    "abhiniḥsṛta": ['mw'],
    "abhiniṣad": ['mw'],
    "abhiniṣic": ['mw'],
    "abhiniṣkram": ['mw'],
    "abhiniṣkramati": ['bhs'],
    "abhiniṣkramaṇa": ['bhs', 'mw'],
    "abhiniṣkramaṇaṃ": ['ap90'],
    "abhiniṣkrānta": ['mw'],
    "abhiniṣkrāntagṛhāvāsa": ['mw'],
    "abhiniṣkārin": ['ap90', 'mw'],
    "abhiniṣkṛta": ['mw'],
    "abhiniṣpad": ['ap90', 'mw'],
    "abhiniṣpadyate": ['bhs'],
    "abhiniṣpat": ['ap90', 'mw'],
    "abhiniṣpatana": ['mw'],
    "abhiniṣpatanaṃ": ['ap90'],
    "abhiniṣpatti": ['mw'],
    "abhiniṣpattiḥ": ['ap90'],
    "abhiniṣpeṣayati": ['bhs'],
    "abhiniṣpīḍayati": ['bhs'],
    "abhiniṣyand": ['mw'],
    "abhiniṣyanda": ['mw'],
    "abhiniṣyandana": ['bhs'],
    "abhiniṣīdati": ['bhs'],
    "abhiniṣṭhiv": ['mw'],
    "abhiniṣṭāna": ['mw'],
    "abhiniṣṭānaḥ": ['ap90'],
    "abhinna": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "abhinnagati": ['mw'],
    "abhinnakāla": ['mw'],
    "abhinnaparikarmāṣṭaka": ['mw'],
    "abhinnaparivārā": ['bhs'],
    "abhinnarāṣṭra": ['bhs'],
    "abhinnasthiti": ['mw'],
    "abhinnataraka": ['mw'],
    "abhinnatva": ['mw'],
    "abhinnatā": ['mw'],
    "abhinnavela": ['mw'],
    "abhinnābha": ['bhs'],
    "abhinnātman": ['mw'],
    "abhinnāṇḍa": ['mw'],
    "abhinu": ['mw'],
    "abhinud": ['mw'],
    "abhinyas": ['mw'],
    "abhinyubj": ['mw'],
    "abhinyāsa": ['mw'],
    "abhinyāsaḥ": ['ap90'],
    "abhināmadheya": ['mw'],
    "abhināmayati": ['bhs'],
    "abhināmin": ['mw'],
    "abhināsikāvivaram": ['ddsa', 'mw'],
    "abhinī": ['ap90', 'mw'],
    "abhinīhanati": ['cped'],
    "abhinīharati": ['cped'],
    "abhinīhāra": ['cped'],
    "abhinīla": ['bhs', 'mw'],
    "abhinīla-m-āyata": ['cped'],
    "abhinīlanetratā": ['mw'],
    "abhinīlanetta": ['cped'],
    "abhinīra": ['bhs'],
    "abhinīta": ['ap90', 'cae', 'cped', 'mw'],
    "abhinīti": ['mw'],
    "abhinītiḥ": ['ap90'],
    "abhinṛmṇa": ['mw'],
    "abhinṛt": ['mw'],
    "abhipac": ['mw'],
    "abhipad": ['ap90', 'mw'],
    "abhipadma": ['ap90', 'mw'],
    "abhipale": ['mw'],
    "abhipanna": ['ap90', 'mw'],
    "abhipare": ['mw'],
    "abhipariglāna": ['mw'],
    "abhiparigrah": ['mw'],
    "abhiparihan": ['mw'],
    "abhiparihāra": ['mw'],
    "abhiparihṛ": ['mw'],
    "abhiparipluta": ['ap90', 'cae', 'mw'],
    "abhipariṣvañj": ['mw'],
    "abhiparye": ['mw'],
    "abhiparyādhā": ['mw'],
    "abhiparyāsic": ['mw'],
    "abhiparyāvarta": ['mw'],
    "abhiparyāvṛt": ['mw'],
    "abhiparyūh": ['mw'],
    "abhiparāvad": ['mw'],
    "abhiparīta": ['mw'],
    "abhiparīvṛta": ['mw'],
    "abhipassa": ['cped'],
    "abhipassat": ['cped'],
    "abhipassati": ['cped'],
    "abhipat": ['ap90', 'mw'],
    "abhipatana": ['ddsa', 'mw'],
    "abhipatanaṃ": ['ap90'],
    "abhipatthaya": ['cped'],
    "abhipatthayana": ['cped'],
    "abhipatthayat": ['cped'],
    "abhipatthayati": ['cped'],
    "abhipattheti": ['cped'],
    "abhipatthita": ['cped'],
    "abhipatti": ['mw'],
    "abhipattimat": ['mw'],
    "abhipattiḥ": ['ap90'],
    "abhipaś": ['mw'],
    "abhipaścāt": ['bhs'],
    "abhipaśya": ['bhs'],
    "abhipaṭhita": ['mw'],
    "abhipitva": ['cae', 'ddsa', 'gra', 'mw'],
    "abhipitvaṃ": ['ap90'],
    "abhipiś": ['mw'],
    "abhipiṅgala": ['mw'],
    "abhiplava": ['ddsa', 'mw'],
    "abhiplavaḥ": ['ap90'],
    "abhiplu": ['ap90', 'mw'],
    "abhipluta": ['cae', 'ddsa', 'mw'],
    "abhippahāri": ['cped'],
    "abhippahārin": ['cped'],
    "abhippakirati": ['cped'],
    "abhippalambati": ['cped'],
    "abhippamodati": ['cped'],
    "abhippamodaya": ['cped'],
    "abhippamodayat": ['cped'],
    "abhippasanna": ['cped'],
    "abhippasādeti": ['cped'],
    "abhippasāreti": ['cped'],
    "abhippasīdati": ['cped'],
    "abhippasīdiṁsu": ['cped'],
    "abhippavaṭṭa": ['cped'],
    "abhippavaṭṭha": ['cped'],
    "abhippavuṭṭha": ['cped'],
    "abhipphuṭṭha": ['cped'],
    "abhiprabhaṅgin": ['gra', 'mw'],
    "abhiprabhū": ['mw'],
    "abhiprabhṛ": ['mw'],
    "abhiprabudh": ['mw'],
    "abhipracakṣ": ['mw'],
    "abhipracakṣe": ['cae', 'ddsa'],
    "abhiprach": ['mw'],
    "abhipracud": ['mw'],
    "abhipracyu": ['mw'],
    "abhipradakṣiṇam": ['mw'],
    "abhipradakṣiṇaṃ": ['ap90'],
    "abhipradakṣiṇīkaroti": ['bhs'],
    "abhipradarśana": ['mw'],
    "abhipradarśayati": ['bhs'],
    "abhipradharṣaṇa": ['mw'],
    "abhipradiś": ['mw'],
    "abhipradru": ['mw'],
    "abhipradrā": ['mw'],
    "abhipradṛś": ['mw'],
    "abhipradṝ": ['mw'],
    "abhipragai": ['mw'],
    "abhipragāh": ['mw'],
    "abhiprahan": ['mw'],
    "abhiprahata": ['mw'],
    "abhiprahita": ['mw'],
    "abhiprahā": ['mw'],
    "abhiprajan": ['mw'],
    "abhiprajval": ['mw'],
    "abhiprajñā": ['ap90'],
    "abhiprakamp": ['mw'],
    "abhiprakirati": ['bhs'],
    "abhiprakram": ['mw'],
    "abhiprakramya": ['mw'],
    "abhiprakāś": ['mw'],
    "abhiprakṣal": ['mw'],
    "abhiprakṣar": ['mw'],
    "abhiprakṣarita": ['mw'],
    "abhipralamba": ['bhs'],
    "abhipralambate": ['bhs'],
    "abhipraman": ['mw'],
    "abhipramand": ['mw'],
    "abhipramath": ['mw'],
    "abhipramodana": ['bhs'],
    "abhipramur": ['ap90', 'gra', 'mw'],
    "abhipramṛś": ['mw'],
    "abhiprapac": ['mw'],
    "abhiprapad": ['ap90', 'mw'],
    "abhiprapanna": ['mw'],
    "abhiprapaś": ['mw'],
    "abhiprapīḍ": ['mw'],
    "abhiprapūraṇa": ['bhs'],
    "abhiprapṝ": ['mw'],
    "abhipraruh": ['mw'],
    "abhiprasad": ['mw'],
    "abhiprasah": ['mw'],
    "abhiprasanna": ['bhs', 'mw'],
    "abhiprasarati": ['bhs'],
    "abhipraskand": ['mw'],
    "abhiprasthita": ['mw'],
    "abhiprasthā": ['mw'],
    "abhiprastu": ['mw'],
    "abhiprastṛ": ['mw'],
    "abhiprasupta": ['mw'],
    "abhiprasāda": ['bhs'],
    "abhiprasāraṇa": ['mw'],
    "abhiprasīdati": ['bhs'],
    "abhiprasū": ['mw'],
    "abhiprasūta": ['mw'],
    "abhiprasṛ": ['mw'],
    "abhiprasṛp": ['mw'],
    "abhiprasṛta": ['mw'],
    "abhipratan": ['mw'],
    "abhipratapta": ['ap90', 'mw'],
    "abhiprath": ['mw'],
    "abhiprathana": ['mw'],
    "abhiprathanaṃ": ['ap90'],
    "abhipratigṝ": ['mw'],
    "abhipratipad": ['mw'],
    "abhipratipiṣ": ['mw'],
    "abhipratyavaruh": ['mw'],
    "abhipratyave": ['mw'],
    "abhipratye": ['mw'],
    "abhipratārin": ['mw'],
    "abhiprava": ['mw'],
    "abhipravah": ['mw'],
    "abhipravartana": ['mw'],
    "abhipravartanaṃ": ['ap90'],
    "abhipravarṣayitar": ['bhs'],
    "abhipravarṣaṇa": ['bhs'],
    "abhipraveśa": ['mw'],
    "abhipravip": ['mw'],
    "abhipraviś": ['mw'],
    "abhipraviṣṭa": ['mw'],
    "abhipravraj": ['mw'],
    "abhipravrajana": ['mw'],
    "abhipravādayati": ['bhs'],
    "abhipravṛdh": ['mw'],
    "abhipravṛt": ['ap90', 'mw'],
    "abhipravṛtta": ['ap90', 'cae', 'mw'],
    "abhipravṛṣ": ['mw'],
    "abhiprayojana": ['bhs'],
    "abhiprayuj": ['mw'],
    "abhiprayā": ['mw'],
    "abhiprayāyam": ['mw'],
    "abhiprayāyin": ['mw'],
    "abhipraśaṃs": ['mw'],
    "abhipraśnin": ['ap90', 'mw'],
    "abhipraśudh": ['mw'],
    "abhipraśvas": ['mw'],
    "abhipraṇad": ['mw'],
    "abhipraṇakṣ": ['mw'],
    "abhipraṇam": ['mw'],
    "abhipraṇamati": ['bhs'],
    "abhipraṇata": ['mw'],
    "abhipraṇaya": ['mw'],
    "abhipraṇayanaṃ": ['ap90'],
    "abhipraṇayaḥ": ['ap90'],
    "abhipraṇu": ['mw'],
    "abhipraṇī": ['ap90', 'mw'],
    "abhipraṇīta": ['mw'],
    "abhipre": ['ap90', 'mw'],
    "abhiprekṣ": ['mw'],
    "abhiprepsu": ['cae', 'mw'],
    "abhiprer": ['mw'],
    "abhipreraṇa": ['mw'],
    "abhipreta": ['ap90', 'mw'],
    "abhipretya": ['mw'],
    "abhipreṣ": ['mw'],
    "abhipreṣaṇa": ['mw'],
    "abhipreṣita": ['mw'],
    "abhipriya": ['bhs'],
    "abhipriyatamam": ['mw'],
    "abhiprokṣaṇa": ['mw'],
    "abhiprokṣaṇaṃ": ['ap90'],
    "abhipru": ['mw'],
    "abhipruṣ": ['mw'],
    "abhiprāp": ['ap90', 'mw'],
    "abhiprāpaṇa": ['mw'],
    "abhiprāpta": ['mw'],
    "abhiprāpti": ['mw'],
    "abhiprārc": ['mw'],
    "abhiprārth": ['mw'],
    "abhiprās": ['mw'],
    "abhiprātar": ['mw'],
    "abhiprāya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "abhiprāś": ['mw'],
    "abhiprāṇ": ['mw'],
    "abhiprāṇana": ['mw'],
    "abhiprāṇanaṃ": ['ap90'],
    "abhiprī": ['gra', 'mw'],
    "abhiprīta": ['mw'],
    "abhiprīti": ['mw'],
    "abhiprītiḥ": ['ap90'],
    "abhiputh": ['mw'],
    "abhipuṣpa": ['ap90', 'mw'],
    "abhipyai": ['mw'],
    "abhipā": ['mw'],
    "abhipāla": ['mw'],
    "abhipālana": ['mw'],
    "abhipāleti": ['cped'],
    "abhipālin": ['mw'],
    "abhipāraga": ['bhs'],
    "abhipāta": ['ddsa', 'mw'],
    "abhipātin": ['mw'],
    "abhipāṇḍu": ['mw'],
    "abhipāṇḍutā": ['mw'],
    "abhipīta": ['mw'],
    "abhipīḍ": ['mw'],
    "abhipīḍita": ['mw'],
    "abhipū": ['mw'],
    "abhipūj": ['ap90', 'mw'],
    "abhipūjana": ['bhs'],
    "abhipūjanaṃ": ['ap90'],
    "abhipūjita": ['cae', 'mw'],
    "abhipūraṇa": ['mw'],
    "abhipūraṇaṃ": ['ap90'],
    "abhipūrta": ['mw'],
    "abhipūrva": ['mw'],
    "abhipūrvam": ['mw'],
    "abhipūrvaṃ": ['ap90'],
    "abhipūrveṇa": ['mw'],
    "abhipūrya": ['mw'],
    "abhipūrṇa": ['cae', 'mw'],
    "abhipṛṣṭa": ['mw'],
    "abhipṛṣṭhe": ['ddsa', 'mw'],
    "abhipṝ": ['ap90', 'mw'],
    "abhirabh": ['mw'],
    "abhiracita": ['bhs'],
    "abhiraddha": ['cped'],
    "abhirai": ['mw'],
    "abhirakta": ['ap90', 'mw'],
    "abhiraktaka": ['bhs'],
    "abhirakṣ": ['ap90', 'mw'],
    "abhirakṣaṇa": ['ddsa', 'mw'],
    "abhirakṣita": ['mw'],
    "abhirakṣitṛ": ['ap90', 'mw'],
    "abhirakṣya": ['mw'],
    "abhirakṣā": ['ap90', 'mw'],
    "abhiram": ['ap90', 'mw'],
    "abhirama": ['cped'],
    "abhiramanta": ['cped'],
    "abhiramanā": ['cped'],
    "abhiramati": ['cped'],
    "abhiramaṇa": ['mw'],
    "abhiramaṇaṃ": ['ap90'],
    "abhiramaṇā": ['cped'],
    "abhiramaṇīya": ['mw'],
    "abhirambhita": ['mw'],
    "abhirami": ['cped'],
    "abhiramittha": ['cped'],
    "abhiramiṁ": ['cped'],
    "abhiramya": ['bhs'],
    "abhiramāpana": ['cped'],
    "abhiranta": ['cped'],
    "abhiras": ['mw'],
    "abhirata": ['ap90', 'cped', 'mw'],
    "abhiratarūpa": ['cped'],
    "abhirati": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "abhiratiḥ": ['ap90'],
    "abhiratta": ['cped'],
    "abhirañj": ['mw'],
    "abhirañjita": ['mw'],
    "abhiraśmimāli": ['mw'],
    "abhiraṃj": ['ap90'],
    "abhiraṃjanaṃ": ['ap90'],
    "abhiraṅga": ['bhs'],
    "abhiribh": ['mw'],
    "abhiriṣ": ['mw'],
    "abhirocana": ['bhs'],
    "abhirocate": ['bhs'],
    "abhiroddhṛ": ['mw'],
    "abhirohaṇa": ['bhs'],
    "abhiropayati": ['cped'],
    "abhiropeti": ['cped'],
    "abhiroruda": ['ap90', 'mw'],
    "abhiru": ['mw'],
    "abhiruc": ['ap90', 'mw'],
    "abhiruci": ['cae', 'ddsa', 'mw'],
    "abhirucira": ['ap90', 'mw'],
    "abhirucita": ['ap90', 'cae', 'cped', 'mw'],
    "abhirucitaka": ['bhs'],
    "abhiruciḥ": ['ap90'],
    "abhirudati": ['bhs'],
    "abhirudh": ['mw'],
    "abhirudita": ['mw'],
    "abhiruh": ['mw'],
    "abhiruhana": ['cped'],
    "abhiruhati": ['cped'],
    "abhiruhi": ['cped'],
    "abhiruhitvā": ['cped'],
    "abhiruhya": ['mw'],
    "abhiruta": ['ap90', 'cae', 'mw'],
    "abhiruṣita": ['cae', 'mw'],
    "abhirāddha": ['ap90', 'cae', 'mw'],
    "abhirādh": ['ap90', 'mw'],
    "abhirādha": ['bhs'],
    "abhirādhana": ['cae', 'cped'],
    "abhirādhanā": ['bhs'],
    "abhirādhi": ['cped'],
    "abhirādhin": ['cped'],
    "abhirādhita": ['cped'],
    "abhirādhya": ['bhs'],
    "abhirāj": ['ap90', 'mw'],
    "abhirāja": ['cped', 'mw'],
    "abhirājan": ['cped'],
    "abhirāma": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhirāmam": ['mw'],
    "abhirāmamaṇi": ['mw'],
    "abhirāmapaśupati": ['mw'],
    "abhirāmatva": ['mw'],
    "abhirāmatā": ['mw'],
    "abhirāmavartā": ['bhs'],
    "abhirāmaśrīvaktrā": ['bhs'],
    "abhirāṣṭra": ['ap90', 'gra', 'mw'],
    "abhirūha": ['bhs'],
    "abhirūhana": ['cped'],
    "abhirūhanta": ['cped'],
    "abhirūhati": ['cped'],
    "abhirūhi": ['cped'],
    "abhirūhitabba": ['cped'],
    "abhirūhitvā": ['cped'],
    "abhirūhiya": ['cped'],
    "abhirūpa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "abhirūpabhūyiṣṭha": ['mw'],
    "abhirūpaka": ['ap90', 'mw'],
    "abhirūpapati": ['cae', 'mw'],
    "abhirūpaprajāyinī": ['mw'],
    "abhirūpatara": ['cped'],
    "abhirūpatā": ['mw'],
    "abhirūpavat": ['mw'],
    "abhirūḷha": ['cped'],
    "abhisac": ['mw'],
    "abhisaddaha": ['cped'],
    "abhisaddahanta": ['cped'],
    "abhisaddahat": ['cped'],
    "abhisaddahati": ['cped'],
    "abhisajati": ['cped'],
    "abhisajjanā": ['cped'],
    "abhisajjati": ['cped'],
    "abhisajji": ['cped'],
    "abhisallekhika": ['cped'],
    "abhisamas": ['mw'],
    "abhisamavāya": ['mw'],
    "abhisamavāyaḥ": ['ap90'],
    "abhisamaya": ['bhs', 'cped', 'mw'],
    "abhisamayati": ['bhs'],
    "abhisambaddha": ['mw'],
    "abhisambandh": ['mw'],
    "abhisambandha": ['mw'],
    "abhisambhagna": ['mw'],
    "abhisambhava": ['mw'],
    "abhisambhavana": ['cped', 'mw'],
    "abhisambhavati": ['cped'],
    "abhisambhavitvā": ['cped'],
    "abhisambhonta": ['cped'],
    "abhisambhosi": ['cped'],
    "abhisambhoti": ['cped'],
    "abhisambhutvā": ['cped'],
    "abhisambhū": ['cped', 'mw'],
    "abhisambhṛta": ['mw'],
    "abhisambodha": ['cped'],
    "abhisambodhana": ['mw'],
    "abhisambodhi": ['cped'],
    "abhisambuddha": ['cped', 'mw'],
    "abhisambudh": ['mw'],
    "abhisambudhāna": ['cped'],
    "abhisambujjhati": ['cped'],
    "abhisambujjhitvā": ['cped'],
    "abhisambujjhiṁsu": ['cped'],
    "abhisambādha": ['mw'],
    "abhisame": ['mw'],
    "abhisamecca": ['cped'],
    "abhisamesuṁ": ['cped'],
    "abhisameta": ['cped', 'mw'],
    "abhisameti": ['bhs', 'cped'],
    "abhisametvā": ['cped'],
    "abhisametāvi": ['cped'],
    "abhisametāvin": ['cped'],
    "abhisami": ['mw'],
    "abhisamindh": ['mw'],
    "abhisamita": ['cped'],
    "abhisamitavant": ['bhs'],
    "abhisamitāvin": ['bhs'],
    "abhisammata": ['mw'],
    "abhisammukha": ['mw'],
    "abhisammūrch": ['mw'],
    "abhisammūḍha": ['mw'],
    "abhisampac": ['mw'],
    "abhisampad": ['mw'],
    "abhisampanna": ['mw'],
    "abhisamparāya": ['cped', 'mw'],
    "abhisamparāyaṁ": ['cped'],
    "abhisampat": ['mw'],
    "abhisampatti": ['mw'],
    "abhisamplava": ['mw'],
    "abhisamplu": ['mw'],
    "abhisampluta": ['mw'],
    "abhisamprahā": ['mw'],
    "abhisamprapad": ['mw'],
    "abhisampravṛt": ['mw'],
    "abhisampravṛtta": ['mw'],
    "abhisamprayā": ['mw'],
    "abhisamprekṣ": ['mw'],
    "abhisamprāp": ['mw'],
    "abhisampāta": ['mw'],
    "abhisampū": ['mw'],
    "abhisampūj": ['mw'],
    "abhisamubj": ['mw'],
    "abhisamācita": ['cped'],
    "abhisamācāra": ['cped'],
    "abhisamācārika": ['cped'],
    "abhisamāgacchati": ['bhs'],
    "abhisamāgam": ['mw'],
    "abhisamāhita": ['mw'],
    "abhisamāhṛ": ['mw'],
    "abhisamāpad": ['mw'],
    "abhisamāruh": ['mw'],
    "abhisamāsic": ['mw'],
    "abhisamāvṛt": ['mw'],
    "abhisamāyam": ['mw'],
    "abhisamāyukta": ['mw'],
    "abhisamāyā": ['mw'],
    "abhisamīkṣya": ['mw'],
    "abhisamīr": ['mw'],
    "abhisamūh": ['mw'],
    "abhisamūḍha": ['bhs'],
    "abhisamṛ": ['mw'],
    "abhisandahati": ['cped'],
    "abhisandahitvā": ['cped'],
    "abhisandayati": ['cped'],
    "abhisandeti": ['cped'],
    "abhisandhaka": ['ddsa', 'mw'],
    "abhisanna": ['cped'],
    "abhisantāpaya": ['cped'],
    "abhisantāpayat": ['cped'],
    "abhisantāpetabba": ['cped'],
    "abhisantāpeti": ['cped'],
    "abhisantāyati": ['cped'],
    "abhisap": ['mw'],
    "abhisapanta": ['cped'],
    "abhisapati": ['cped'],
    "abhisapi": ['cped'],
    "abhisapita": ['cped'],
    "abhisapitvā": ['cped'],
    "abhisara": ['ap90', 'ddsa', 'mw'],
    "abhisaraḥ": ['ap90'],
    "abhisaraṇa": ['bhs', 'mw'],
    "abhisaraṇaṃ": ['ap90'],
    "abhisarga": ['mw'],
    "abhisargaḥ": ['ap90'],
    "abhisarjana": ['mw'],
    "abhisarjanaṃ": ['ap90'],
    "abhisarpaṇa": ['mw'],
    "abhisarpaṇaṃ": ['ap90'],
    "abhisartṛ": ['ap90', 'mw'],
    "abhisatkṛ": ['mw'],
    "abhisatkṛta": ['mw'],
    "abhisatta": ['cped'],
    "abhisatvan": ['ap90', 'gra', 'mw'],
    "abhisañcetayati": ['cped'],
    "abhisañcetayita": ['cped'],
    "abhisañchanna": ['cped'],
    "abhisañjanī": ['bhs'],
    "abhisaññanirodha": ['cped'],
    "abhisaṁhati": ['cped'],
    "abhisaṁvisati": ['cped'],
    "abhisaṃbandha": ['cae'],
    "abhisaṃbaṃdh": ['ap90'],
    "abhisaṃbaṃdhaḥ": ['ap90'],
    "abhisaṃbhava": ['bhs'],
    "abhisaṃbhinna": ['bhs'],
    "abhisaṃbhuṇa": ['bhs'],
    "abhisaṃbhuṇati": ['bhs'],
    "abhisaṃbhāvayati": ['bhs'],
    "abhisaṃbodha": ['bhs'],
    "abhisaṃbodhana": ['bhs'],
    "abhisaṃbodhi": ['bhs'],
    "abhisaṃbuddhana": ['bhs'],
    "abhisaṃbudhyate": ['bhs'],
    "abhisaṃbādha": ['ap90'],
    "abhisaṃcar": ['mw'],
    "abhisaṃci": ['mw'],
    "abhisaṃcint": ['mw'],
    "abhisaṃcārin": ['ap90', 'mw'],
    "abhisaṃcūrṇ": ['mw'],
    "abhisaṃdarśayati": ['bhs'],
    "abhisaṃdaṣṭa": ['mw'],
    "abhisaṃdeha": ['mw'],
    "abhisaṃdehaḥ": ['ap90'],
    "abhisaṃdham": ['mw'],
    "abhisaṃdhaḥ": ['ap90'],
    "abhisaṃdhi": ['cae', 'mw'],
    "abhisaṃdhikṛta": ['mw'],
    "abhisaṃdhipūrva": ['mw'],
    "abhisaṃdhipūrvakam": ['mw'],
    "abhisaṃdhiḥ": ['ap90'],
    "abhisaṃdhā": ['ap90', 'mw'],
    "abhisaṃdhāna": ['cae', 'mw'],
    "abhisaṃdhānaṃ": ['ap90'],
    "abhisaṃdhāya": ['mw'],
    "abhisaṃdhāyaḥ": ['ap90'],
    "abhisaṃdṛṣṭa": ['ap90'],
    "abhisaṃgam": ['mw'],
    "abhisaṃgata": ['mw'],
    "abhisaṃgrah": ['mw'],
    "abhisaṃgupta": ['mw'],
    "abhisaṃgṝ": ['mw'],
    "abhisaṃhan": ['mw'],
    "abhisaṃhata": ['mw'],
    "abhisaṃhatya": ['cae'],
    "abhisaṃhita": ['cae', 'mw'],
    "abhisaṃhāra": ['bhs'],
    "abhisaṃhṛtya": ['mw'],
    "abhisaṃjvar": ['mw'],
    "abhisaṃjñita": ['mw'],
    "abhisaṃjñā": ['mw'],
    "abhisaṃjāta": ['mw'],
    "abhisaṃkaroti": ['bhs'],
    "abhisaṃkhya": ['ap90', 'mw'],
    "abhisaṃkhyeya": ['mw'],
    "abhisaṃkhyā": ['ap90', 'mw'],
    "abhisaṃkruddha": ['mw'],
    "abhisaṃkrudh": ['mw'],
    "abhisaṃkruś": ['mw'],
    "abhisaṃkṣepa": ['bhs', 'mw'],
    "abhisaṃkṣepaṇatā": ['bhs'],
    "abhisaṃkṣepika": ['bhs'],
    "abhisaṃkṣip": ['ap90', 'mw'],
    "abhisaṃkṣipati": ['bhs'],
    "abhisaṃkṣipta": ['mw'],
    "abhisaṃmodayati": ['bhs'],
    "abhisaṃmukha": ['ap90'],
    "abhisaṃnaddha": ['mw'],
    "abhisaṃnah": ['mw'],
    "abhisaṃnam": ['mw'],
    "abhisaṃniviṣṭa": ['mw'],
    "abhisaṃnu": ['mw'],
    "abhisaṃnī": ['mw'],
    "abhisaṃpad": ['ap90'],
    "abhisaṃpanna": ['ap90', 'bhs'],
    "abhisaṃparāya": ['bhs'],
    "abhisaṃparāyaḥ": ['ap90'],
    "abhisaṃpat": ['ap90'],
    "abhisaṃpattiḥ": ['ap90'],
    "abhisaṃprasthita": ['bhs'],
    "abhisaṃpratyaya": ['bhs'],
    "abhisaṃpravarṣaṇatā": ['bhs'],
    "abhisaṃprārthayate": ['bhs'],
    "abhisaṃpātaḥ": ['ap90'],
    "abhisaṃrabdha": ['mw'],
    "abhisaṃrabh": ['mw'],
    "abhisaṃrakta": ['mw'],
    "abhisaṃrambha": ['mw'],
    "abhisaṃrādhana": ['mw'],
    "abhisaṃrādhayati": ['bhs'],
    "abhisaṃskaroti": ['bhs'],
    "abhisaṃskāra": ['bhs', 'mw'],
    "abhisaṃskāraḥ": ['ap90'],
    "abhisaṃskārika": ['bhs'],
    "abhisaṃskṛ": ['ap90', 'mw'],
    "abhisaṃskṛta": ['bhs', 'mw'],
    "abhisaṃsmṛ": ['mw'],
    "abhisaṃsphuṭati": ['bhs'],
    "abhisaṃspṛś": ['mw'],
    "abhisaṃsru": ['mw'],
    "abhisaṃstambh": ['mw'],
    "abhisaṃstava": ['mw'],
    "abhisaṃstavaḥ": ['ap90'],
    "abhisaṃstham": ['mw'],
    "abhisaṃsthita": ['mw'],
    "abhisaṃsthā": ['mw'],
    "abhisaṃstu": ['mw'],
    "abhisaṃstuta": ['mw'],
    "abhisaṃstīrṇa": ['mw'],
    "abhisaṃsu": ['mw'],
    "abhisaṃsvañj": ['mw'],
    "abhisaṃsvṛ": ['mw'],
    "abhisaṃsāram": ['mw'],
    "abhisaṃsāraḥ": ['ap90'],
    "abhisaṃsṛ": ['mw'],
    "abhisaṃsṛta": ['mw'],
    "abhisaṃtan": ['mw'],
    "abhisaṃtap": ['ap90', 'mw'],
    "abhisaṃtapta": ['mw'],
    "abhisaṃtata": ['mw'],
    "abhisaṃtrasta": ['mw'],
    "abhisaṃtyaj": ['mw'],
    "abhisaṃtāpaḥ": ['ap90'],
    "abhisaṃtṝ": ['mw'],
    "abhisaṃvas": ['mw'],
    "abhisaṃvid": ['mw'],
    "abhisaṃviś": ['mw'],
    "abhisaṃvāñch": ['mw'],
    "abhisaṃvīkṣ": ['mw'],
    "abhisaṃvṛ": ['mw'],
    "abhisaṃvṛddha": ['mw'],
    "abhisaṃvṛt": ['mw'],
    "abhisaṃvṛta": ['ap90', 'mw'],
    "abhisaṃvṛtta": ['mw'],
    "abhisaṃyam": ['mw'],
    "abhisaṃyatta": ['mw'],
    "abhisaṃyoga": ['mw'],
    "abhisaṃyogaḥ": ['ap90'],
    "abhisaṃyuj": ['mw'],
    "abhisaṃyujyate": ['bhs'],
    "abhisaṃyukta": ['mw'],
    "abhisaṃyā": ['mw'],
    "abhisaṃśliṣ": ['mw'],
    "abhisaṃśraya": ['mw'],
    "abhisaṃśrayaḥ": ['ap90'],
    "abhisaṃśri": ['mw'],
    "abhisaṃśrita": ['mw'],
    "abhisaṃśru": ['mw'],
    "abhisaṃśyāna": ['mw'],
    "abhisaṃśīna": ['ap90', 'mw'],
    "abhisaṅgi": ['cped'],
    "abhisaṅgin": ['cped'],
    "abhisaṅkhacca": ['cped'],
    "abhisaṅkharesi": ['cped'],
    "abhisaṅkhareti": ['cped'],
    "abhisaṅkharitvā": ['cped'],
    "abhisaṅkharo": ['cped'],
    "abhisaṅkharot": ['cped'],
    "abhisaṅkharoti": ['cped'],
    "abhisaṅkhata": ['cped'],
    "abhisaṅkhaṭa": ['cped'],
    "abhisaṅkhita": ['cped'],
    "abhisaṅkhitta": ['cped'],
    "abhisaṅkhāra": ['cped'],
    "abhisaṅkhāri": ['cped'],
    "abhisaṅkhārika": ['cped'],
    "abhisaṅkhārituṁ": ['cped'],
    "abhisaṅkhāsi": ['cped'],
    "abhisaṭa": ['cped'],
    "abhiseka": ['cped'],
    "abhisekika": ['cped'],
    "abhisekiya": ['cped'],
    "abhisevana": ['cped', 'mw'],
    "abhisevanaṃ": ['ap90'],
    "abhisiddhi": ['mw'],
    "abhisidh": ['mw'],
    "abhisisārayiṣu": ['mw'],
    "abhisitta": ['cped'],
    "abhisiñcapeti": ['cped'],
    "abhisiñcati": ['cped'],
    "abhisiñcayati": ['cped'],
    "abhisiñciṁsu": ['cped'],
    "abhiskambh": ['mw'],
    "abhiskand": ['mw'],
    "abhiskanda": ['mw'],
    "abhiskandam": ['mw'],
    "abhiskaṃdaḥ": ['ap90'],
    "abhismi": ['mw'],
    "abhisneha": ['ddsa', 'mw'],
    "abhisnehaḥ": ['ap90'],
    "abhisnigdha": ['mw'],
    "abhisobhita": ['cped'],
    "abhisphurita": ['ap90', 'mw'],
    "abhisphūrj": ['mw'],
    "abhispṛś": ['mw'],
    "abhisraṃs": ['mw'],
    "abhisru": ['mw'],
    "abhissanna": ['cped'],
    "abhistanita": ['bhs'],
    "abhistaraṇa": ['mw'],
    "abhistavati": ['bhs'],
    "abhisthiram": ['mw'],
    "abhisthiti": ['bhs'],
    "abhistṛ": ['mw'],
    "abhisusūṣ": ['mw'],
    "abhisvar": ['ap90', 'cae', 'gra', 'mw'],
    "abhisvara": ['bhs'],
    "abhisvaraḥ": ['ap90'],
    "abhisvare": ['cae', 'ddsa', 'gra', 'mw'],
    "abhisvartṛ": ['ap90', 'cae', 'gra', 'mw'],
    "abhisvayamātṛṇṇam": ['mw'],
    "abhisvṛ": ['ap90', 'mw'],
    "abhisyand": ['mw'],
    "abhisyanda": ['mw'],
    "abhisyandin": ['mw'],
    "abhisyandiramaṇa": ['mw'],
    "abhisyaṃdaḥ": ['ap90'],
    "abhisyaṃdin": ['ap90'],
    "abhisāhita": ['bhs'],
    "abhisāntv": ['mw'],
    "abhisāntva": ['mw'],
    "abhisāntvita": ['mw'],
    "abhisāpa": ['cped'],
    "abhisāpayati": ['cped'],
    "abhisāpeti": ['cped'],
    "abhisāra": ['bhs', 'cae', 'mw'],
    "abhisārasthāna": ['mw'],
    "abhisāraḥ": ['ap90'],
    "abhisāraṇaṃ": ['ap90'],
    "abhisārikā": ['ap90', 'cae', 'mw'],
    "abhisārin": ['ap90', 'cae', 'mw'],
    "abhisāriṇī": ['mw'],
    "abhisārī": ['mw'],
    "abhisāvaka": ['mw'],
    "abhisāvakīya": ['mw'],
    "abhisāyam": ['mw'],
    "abhisāyaṃ": ['ap90'],
    "abhisāṃtv": ['ap90'],
    "abhisāṃtvaḥ": ['ap90'],
    "abhisū": ['mw'],
    "abhisūcita": ['mw'],
    "abhisūrya": ['bhs'],
    "abhisṛ": ['ap90', 'mw'],
    "abhisṛj": ['ap90', 'mw'],
    "abhisṛp": ['mw'],
    "abhisṛta": ['cae', 'mw'],
    "abhisṛtya": ['mw'],
    "abhisṛṣṭa": ['cae', 'mw'],
    "abhitan": ['mw'],
    "abhitap": ['ap90', 'mw'],
    "abhitapta": ['ap90', 'mw'],
    "abhitaram": ['mw'],
    "abhitarj": ['mw'],
    "abhitarpaṇaṃ": ['ap90'],
    "abhitarām": ['ddsa', 'mw'],
    "abhitarāṃ": ['ap90'],
    "abhitas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhitatta": ['cped'],
    "abhitaścara": ['ddsa', 'mw'],
    "abhitaḍ": ['ap90', 'mw'],
    "abhitaḥsara": ['mw'],
    "abhitaṃs": ['mw'],
    "abhitaṣṭīya": ['mw'],
    "abhitigmaraśmi": ['ddsa', 'mw'],
    "abhitiṭṭhati": ['cped'],
    "abhito": ['cped', 'mw'],
    "abhitobhāvin": ['mw'],
    "abhitodevayajanamātradeśa": ['mw'],
    "abhitorātram": ['mw'],
    "abhitosaya": ['cped'],
    "abhitosayat": ['cped'],
    "abhitosayati": ['cped'],
    "abhitosthi": ['mw'],
    "abhitripiṣṭapa": ['mw'],
    "abhitrāsa": ['mw'],
    "abhitsar": ['mw'],
    "abhitsāra": ['mw'],
    "abhittharati": ['cped'],
    "abhitthavati": ['cped'],
    "abhitthavi": ['cped'],
    "abhitti": ['ddsa', 'mw'],
    "abhitunna": ['bhs'],
    "abhituṣ": ['mw'],
    "abhitvar": ['mw'],
    "abhitvaraṇatā": ['bhs'],
    "abhityaj": ['mw'],
    "abhitāmra": ['ap90', 'mw'],
    "abhitāpa": ['cae', 'cped', 'mw'],
    "abhitāpaḥ": ['ap90'],
    "abhitāpin": ['mw'],
    "abhitāḍana": ['ddsa', 'mw'],
    "abhitāḍanaṃ": ['ap90'],
    "abhitāḍita": ['mw'],
    "abhitāḷita": ['cped'],
    "abhitūrṇa": ['bhs'],
    "abhitṛd": ['mw'],
    "abhitṛp": ['ap90', 'mw'],
    "abhitṛpta": ['mw'],
    "abhitṛtti": ['mw'],
    "abhitṝ": ['mw'],
    "abhivac": ['mw'],
    "abhivad": ['ap90', 'mw'],
    "abhivada": ['cped'],
    "abhivadana": ['ddsa', 'mw'],
    "abhivadanaṃ": ['ap90'],
    "abhivadat": ['cped'],
    "abhivadati": ['cped'],
    "abhivadh": ['mw'],
    "abhivadita": ['cped'],
    "abhivaditabba": ['cped'],
    "abhivadiṁ": ['cped'],
    "abhivagga": ['cped'],
    "abhivah": ['mw'],
    "abhivaha": ['ap90'],
    "abhivahana": ['mw'],
    "abhivahanaṃ": ['ap90'],
    "abhivalg": ['mw'],
    "abhivam": ['mw'],
    "abhivan": ['mw'],
    "abhivand": ['mw'],
    "abhivandaka": ['mw'],
    "abhivandana": ['cae', 'mw'],
    "abhivandati": ['cped'],
    "abhivandita": ['cped'],
    "abhivandya": ['mw'],
    "abhivap": ['mw'],
    "abhivardhana": ['mw'],
    "abhivarta": ['mw'],
    "abhivartanaṃ": ['ap90'],
    "abhivartin": ['ap90', 'mw'],
    "abhivarṇana": ['mw'],
    "abhivarṇita": ['mw'],
    "abhivarṣa": ['mw'],
    "abhivarṣaṇa": ['mw'],
    "abhivarṣaṇaṃ": ['ap90'],
    "abhivarṣika": ['bhs'],
    "abhivarṣin": ['ap90', 'mw'],
    "abhivas": ['mw'],
    "abhivasana": ['cped'],
    "abhivasanavaratara": ['cped'],
    "abhivassa": ['cped'],
    "abhivassaka": ['cped'],
    "abhivassat": ['cped'],
    "abhivassati": ['cped'],
    "abhivat": ['mw'],
    "abhivatsala": ['bhs'],
    "abhivayas": ['ap90', 'gra', 'mw'],
    "abhivañcita": ['mw'],
    "abhivaś": ['mw'],
    "abhivaḍḍhati": ['cped'],
    "abhivaḍḍhi": ['cped'],
    "abhivaṃd": ['ap90'],
    "abhivaṃdanaṃ": ['ap90'],
    "abhivaṇṇayati": ['cped'],
    "abhivaṇṇeti": ['cped'],
    "abhivaṭṭha": ['cped'],
    "abhivedana": ['bhs'],
    "abhivedhin": ['mw'],
    "abhivega": ['gra', 'mw'],
    "abhivegaḥ": ['ap90'],
    "abhiveṣṭ": ['mw'],
    "abhivibhaj": ['mw'],
    "abhivibhā": ['mw'],
    "abhivibudh": ['mw'],
    "abhivicakṣ": ['mw'],
    "abhivicar": ['mw'],
    "abhivicitrita": ['bhs'],
    "abhivid": ['mw'],
    "abhividdha": ['mw'],
    "abhividhau": ['mw'],
    "abhividhi": ['mw'],
    "abhividhiḥ": ['ap90'],
    "abhividhā": ['mw'],
    "abhividhāv": ['mw'],
    "abhividruta": ['mw'],
    "abhividyut": ['mw'],
    "abhividīpita": ['mw'],
    "abhividṛś": ['mw'],
    "abhivihacca": ['cped'],
    "abhivihita": ['mw'],
    "abhivihṛ": ['mw'],
    "abhivij": ['mw'],
    "abhivijaṃh": ['mw'],
    "abhivijinati": ['bhs'],
    "abhivijinituṁ": ['cped'],
    "abhivijinitvā": ['cped'],
    "abhivijināti": ['cped'],
    "abhivijiya": ['cped'],
    "abhivijval": ['mw'],
    "abhivijñapta": ['mw'],
    "abhivijñeya": ['mw'],
    "abhivijñā": ['mw'],
    "abhivijñāpayati": ['bhs'],
    "abhivijñāya": ['mw'],
    "abhivikhyā": ['mw'],
    "abhivikhyāta": ['ap90', 'cae', 'mw'],
    "abhivikrama": ['ddsa', 'mw'],
    "abhivikṣepa": ['mw'],
    "abhivikṣip": ['mw'],
    "abhivilokanā": ['bhs'],
    "abhivilokayati": ['bhs'],
    "abhivilī": ['mw'],
    "abhivimanth": ['mw'],
    "abhivimāna": ['ap90', 'mw'],
    "abhivimṛj": ['mw'],
    "abhivinad": ['mw'],
    "abhivinaya": ['cped'],
    "abhivinayati": ['bhs'],
    "abhivinaye": ['cped'],
    "abhivindati": ['cped'],
    "abhivinde": ['cped'],
    "abhivinud": ['mw'],
    "abhivinī": ['ap90'],
    "abhivinīta": ['ap90', 'cae', 'mw'],
    "abhivipaś": ['mw'],
    "abhivipaṇyu": ['mw'],
    "abhiviruc": ['mw'],
    "abhivirāj": ['mw'],
    "abhivirājetvā": ['cped'],
    "abhivirājita": ['mw'],
    "abhivisajati": ['cped'],
    "abhivisaji": ['cped'],
    "abhivissattha": ['cped'],
    "abhivisṛj": ['mw'],
    "abhivitan": ['mw'],
    "abhivitarati": ['cped'],
    "abhivitaritvā": ['cped'],
    "abhivivas": ['mw'],
    "abhivivṛddhi": ['mw'],
    "abhiviyā": ['mw'],
    "abhiviññāpesi": ['cped'],
    "abhiviññāpeti": ['cped'],
    "abhiviś": ['mw'],
    "abhiviśaṃs": ['mw'],
    "abhiviśaṅkin": ['mw'],
    "abhiviśruta": ['ap90', 'cae', 'mw'],
    "abhiviśrāṇayati": ['bhs'],
    "abhiviśvas": ['mw'],
    "abhiviśṝ": ['mw'],
    "abhiviṣañj": ['mw'],
    "abhiviṣyand": ['mw'],
    "abhiviṣṭa": ['cae', 'mw'],
    "abhiviṣṭhā": ['mw'],
    "abhivlaṃgaḥ": ['ap90'],
    "abhivlaṅga": ['mw'],
    "abhivlaṅgha": ['gra'],
    "abhivlī": ['mw'],
    "abhivoḍhṛ": ['mw'],
    "abhivraj": ['mw'],
    "abhivratin": ['mw'],
    "abhivusta": ['bhs'],
    "abhivuṭṭha": ['cped'],
    "abhivyadh": ['mw'],
    "abhivyakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhivyaktam": ['mw'],
    "abhivyakti": ['cae', 'mw'],
    "abhivyaktiḥ": ['ap90'],
    "abhivyan": ['mw'],
    "abhivyañj": ['mw'],
    "abhivyañjaka": ['mw'],
    "abhivyañjana": ['mw'],
    "abhivyaṃj": ['ap90'],
    "abhivyaṃjaka": ['ap90'],
    "abhivyaṃjanaṃ": ['ap90'],
    "abhivye": ['mw'],
    "abhivyudas": ['mw'],
    "abhivyukṣ": ['mw'],
    "abhivyādhin": ['ap90', 'mw'],
    "abhivyādā": ['mw'],
    "abhivyādāna": ['mw'],
    "abhivyādānaṃ": ['ap90'],
    "abhivyāharaṇa": ['cae', 'mw'],
    "abhivyāharaṇaṃ": ['ap90'],
    "abhivyāhāra": ['mw'],
    "abhivyāhārin": ['ap90', 'mw'],
    "abhivyāhṛ": ['ap90', 'mw'],
    "abhivyāhṛta": ['cae', 'mw'],
    "abhivyāhṛtya": ['mw'],
    "abhivyāp": ['ap90', 'mw'],
    "abhivyāpaka": ['ap90', 'mw'],
    "abhivyāpin": ['mw'],
    "abhivyāpta": ['mw'],
    "abhivyāpti": ['mw'],
    "abhivyāptiḥ": ['ap90'],
    "abhivyāpya": ['ap90', 'mw'],
    "abhivyūhita": ['bhs'],
    "abhivā": ['mw'],
    "abhivāda": ['cae', 'ddsa', 'mw'],
    "abhivādaka": ['ap90', 'mw'],
    "abhivādana": ['cae', 'cped', 'mw'],
    "abhivādanasīlī": ['cped'],
    "abhivādanasīlīn": ['cped'],
    "abhivādanaśīla": ['mw'],
    "abhivādanā": ['bhs'],
    "abhivādanīya": ['mw'],
    "abhivādayati": ['cped'],
    "abhivādayitvā": ['cped'],
    "abhivādayitṛ": ['ap90', 'mw'],
    "abhivādaḥ": ['ap90'],
    "abhivādenta": ['cped'],
    "abhivādesi": ['cped'],
    "abhivādesiṁ": ['cped'],
    "abhivādesuṁ": ['cped'],
    "abhivādetabba": ['cped'],
    "abhivādeti": ['cped'],
    "abhivādetvā": ['cped'],
    "abhivādimha": ['cped'],
    "abhivādin": ['ap90', 'mw'],
    "abhivādita": ['cped', 'mw'],
    "abhivādya": ['ap90', 'mw'],
    "abhivādāpayati": ['cped'],
    "abhivādāpetabba": ['cped'],
    "abhivādāpeti": ['cped'],
    "abhivāhatas": ['mw'],
    "abhivāhayati": ['bhs'],
    "abhivāhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhivānyavatsā": ['mw'],
    "abhivānyā": ['ap90', 'mw'],
    "abhivāsa": ['mw'],
    "abhivāsana": ['mw'],
    "abhivāsas": ['ap90', 'mw'],
    "abhivāsaḥ": ['ap90'],
    "abhivāsya": ['mw'],
    "abhivāta": ['cae', 'mw'],
    "abhivātam": ['mw'],
    "abhivātā": ['mw'],
    "abhivāñch": ['mw'],
    "abhivāñchita": ['cae', 'mw'],
    "abhivāñchā": ['ddsa', 'mw'],
    "abhivāś": ['mw'],
    "abhivāśat": ['mw'],
    "abhivāśin": ['mw'],
    "abhivī": ['mw'],
    "abhivīj": ['mw'],
    "abhivīkṣ": ['ap90', 'mw'],
    "abhivīkṣaṇaṃ": ['ap90'],
    "abhivīkṣita": ['mw'],
    "abhivīkṣya": ['mw'],
    "abhivīra": ['ap90', 'gra', 'mw'],
    "abhivīta": ['cae', 'mw'],
    "abhivṛ": ['mw'],
    "abhivṛddha": ['mw'],
    "abhivṛddhi": ['cae', 'ddsa', 'mw'],
    "abhivṛddhiḥ": ['ap90'],
    "abhivṛdh": ['ap90', 'mw'],
    "abhivṛh": ['mw'],
    "abhivṛt": ['ap90', 'mw'],
    "abhivṛta": ['cae', 'mw'],
    "abhivṛtti": ['mw'],
    "abhivṛṣ": ['ap90', 'mw'],
    "abhivṛṣṭa": ['ap90', 'bhs', 'mw'],
    "abhiya": ['bhs'],
    "abhiyaj": ['mw'],
    "abhiyajñaḥ": ['ap90'],
    "abhiyaśa": ['bhs'],
    "abhiyaṁsu": ['cped'],
    "abhiyaṣṭavya": ['mw'],
    "abhiyiṁsu": ['cped'],
    "abhiyobbana": ['cped'],
    "abhiyoga": ['cae', 'mw'],
    "abhiyogapattra": ['mw'],
    "abhiyogaḥ": ['ap90'],
    "abhiyogi": ['cped'],
    "abhiyogin": ['ap90', 'cped', 'mw'],
    "abhiyogya": ['mw'],
    "abhiyojana": ['mw'],
    "abhiyojanaṃ": ['ap90'],
    "abhiyojya": ['mw'],
    "abhiyoktavya": ['ap90', 'ddsa', 'mw'],
    "abhiyoktṛ": ['ap90', 'cae', 'mw'],
    "abhiyudh": ['mw'],
    "abhiyugvan": ['ap90', 'gra', 'mw'],
    "abhiyuj": ['ap90', 'gra', 'mw'],
    "abhiyujvan": ['ap90'],
    "abhiyujyamāna": ['mw'],
    "abhiyujyate": ['bhs'],
    "abhiyukta": ['ap90', 'cae', 'mw'],
    "abhiyuktaka": ['bhs'],
    "abhiyuta": ['cae', 'mw'],
    "abhiyuñjati": ['cped'],
    "abhiyā": ['ap90', 'mw'],
    "abhiyāc": ['ap90', 'mw'],
    "abhiyācana": ['mw'],
    "abhiyācanaṃ": ['ap90'],
    "abhiyācanā": ['bhs'],
    "abhiyācati": ['cped'],
    "abhiyācita": ['mw'],
    "abhiyācñā": ['mw'],
    "abhiyāna": ['cae', 'ddsa', 'mw'],
    "abhiyānaṃ": ['ap90'],
    "abhiyāta": ['mw'],
    "abhiyāti": ['cped', 'mw'],
    "abhiyātin": ['mw'],
    "abhiyātiḥ": ['ap90'],
    "abhiyātṛ": ['ap90', 'mw'],
    "abhiyāyin": ['cae', 'mw'],
    "abhiññatara": ['cped'],
    "abhiññeyya": ['cped'],
    "abhiññā": ['cped'],
    "abhiññāta": ['cped'],
    "abhiññātakolañña": ['cped'],
    "abhiññāvosita": ['cped'],
    "abhiññāya": ['cped'],
    "abhiśabdaya": ['mw'],
    "abhiśabdita": ['ap90', 'mw'],
    "abhiśam": ['mw'],
    "abhiśap": ['ap90', 'mw'],
    "abhiśapana": ['mw'],
    "abhiśapanaṃ": ['ap90'],
    "abhiśapta": ['mw'],
    "abhiśas": ['ap90', 'cae', 'gra', 'mw'],
    "abhiśasta": ['ap90', 'cae', 'mw'],
    "abhiśastaka": ['ap90', 'mw'],
    "abhiśastenya": ['mw'],
    "abhiśasti": ['cae', 'gra', 'mw'],
    "abhiśasticātana": ['gra', 'mw'],
    "abhiśastikṛt": ['mw'],
    "abhiśastipā": ['gra', 'mw'],
    "abhiśastipāvan": ['gra', 'mw'],
    "abhiśastiḥ": ['ap90'],
    "abhiśastṛ": ['ap90'],
    "abhiśatru": ['ddsa', 'mw'],
    "abhiśauri": ['mw'],
    "abhiśaṃk": ['ap90'],
    "abhiśaṃkita": ['ap90'],
    "abhiśaṃkā": ['ap90'],
    "abhiśaṃs": ['ap90', 'mw'],
    "abhiśaṃsaka": ['ap90', 'mw'],
    "abhiśaṃsana": ['cae', 'ddsa', 'mw'],
    "abhiśaṃsanaṃ": ['ap90'],
    "abhiśaṃsin": ['mw'],
    "abhiśaṅk": ['mw'],
    "abhiśaṅkin": ['mw'],
    "abhiśaṅkita": ['cae', 'mw'],
    "abhiśaṅkitam": ['mw'],
    "abhiśaṅkya": ['mw'],
    "abhiśaṅkā": ['cae', 'mw'],
    "abhiścut": ['mw'],
    "abhiśikṣ": ['mw'],
    "abhiśirogra": ['ap90', 'mw'],
    "abhiśleṣaṇaṃ": ['ap90'],
    "abhiśnath": ['gra', 'mw'],
    "abhiśobhita": ['mw'],
    "abhiśoca": ['ap90', 'mw'],
    "abhiśocana": ['mw'],
    "abhiśocanaṃ": ['ap90'],
    "abhiśocayiṣṇu": ['ap90', 'mw'],
    "abhiśoka": ['mw'],
    "abhiśokaḥ": ['ap90'],
    "abhiśraddadhānatā": ['bhs'],
    "abhiśraddadhāti": ['bhs'],
    "abhiśraddhā": ['mw'],
    "abhiśravaṇa": ['mw'],
    "abhiśravaṇaṃ": ['ap90'],
    "abhiśri": ['mw'],
    "abhiśriṣ": ['ap90', 'gra', 'mw'],
    "abhiśru": ['mw'],
    "abhiśruta": ['cae', 'mw'],
    "abhiśrutya": ['mw'],
    "abhiśrāva": ['ddsa', 'gra', 'mw'],
    "abhiśrāvaḥ": ['ap90'],
    "abhiśrī": ['ap90', 'gra', 'mw'],
    "abhiśubh": ['mw'],
    "abhiśuc": ['mw'],
    "abhiśuna": ['mw'],
    "abhiśvas": ['ap90', 'mw'],
    "abhiśvasa": ['gra'],
    "abhiśvasaḥ": ['ap90'],
    "abhiśvāsa": ['mw'],
    "abhiśvāsaḥ": ['ap90'],
    "abhiśyāna": ['mw'],
    "abhiśyāta": ['mw'],
    "abhiśāpa": ['ddsa', 'mw'],
    "abhiśāpajvara": ['mw'],
    "abhiśāpana": ['mw'],
    "abhiśāpanaṃ": ['ap90'],
    "abhiśās": ['mw'],
    "abhiśāstṛ": ['mw'],
    "abhiśāṃtv": ['ap90'],
    "abhiśī": ['cae', 'mw'],
    "abhiśīna": ['ap90', 'mw'],
    "abhiśīta": ['ap90', 'mw'],
    "abhiḍīna": ['mw'],
    "abhiḍīnaṃ": ['ap90'],
    "abhiṇata": ['cped'],
    "abhiṇhadassana": ['cped'],
    "abhiṇhasannipāta": ['cped'],
    "abhiṇhaso": ['cped'],
    "abhiṇhaṁ": ['cped'],
    "abhiṇhaṁdassana": ['cped'],
    "abhiṇhaṁkāraṇa": ['cped'],
    "abhiṇhaṁsannipāta": ['cped'],
    "abhiṇhaṁāpattika": ['cped'],
    "abhiṣac": ['mw'],
    "abhiṣad": ['mw'],
    "abhiṣah": ['mw'],
    "abhiṣaha": ['mw'],
    "abhiṣahya": ['ap90', 'mw'],
    "abhiṣajjana": ['bhs'],
    "abhiṣajyate": ['bhs'],
    "abhiṣakta": ['bhs', 'mw'],
    "abhiṣava": ['ap90', 'cae', 'mw'],
    "abhiṣavaḥ": ['ap90'],
    "abhiṣavaṇa": ['mw'],
    "abhiṣavaṇaṃ": ['ap90'],
    "abhiṣavaṇī": ['ap90'],
    "abhiṣavaṇīs": ['mw'],
    "abhiṣavaṇīya": ['mw'],
    "abhiṣañj": ['mw'],
    "abhiṣaṃgaḥ": ['ap90'],
    "abhiṣaṃj": ['ap90'],
    "abhiṣaṃjanaṃ": ['ap90'],
    "abhiṣaṅga": ['cae', 'mw'],
    "abhiṣaṅgajvara": ['mw'],
    "abhiṣaṅgin": ['mw'],
    "abhiṣaṇṇa": ['bhs', 'mw'],
    "abhiṣecana": ['mw'],
    "abhiṣecanaṃ": ['ap90'],
    "abhiṣecanī": ['bhs'],
    "abhiṣecanīya": ['ap90', 'cae', 'mw'],
    "abhiṣecita": ['mw'],
    "abhiṣecya": ['mw'],
    "abhiṣeka": ['bhs', 'cae', 'mw'],
    "abhiṣekabhūmipratilambha": ['mw'],
    "abhiṣekavatī": ['bhs'],
    "abhiṣekaśālā": ['mw'],
    "abhiṣekaḥ": ['ap90'],
    "abhiṣektavya": ['mw'],
    "abhiṣektṛ": ['ap90', 'mw'],
    "abhiṣekya": ['mw'],
    "abhiṣekāha": ['mw'],
    "abhiṣekārdraśiras": ['mw'],
    "abhiṣeṇa": ['ap90', 'gra', 'mw'],
    "abhiṣeṇana": ['mw'],
    "abhiṣeṇanaṃ": ['ap90'],
    "abhiṣeṇaya": ['ddsa', 'mw'],
    "abhiṣeṇayati": ['ap90'],
    "abhiṣic": ['ap90', 'mw'],
    "abhiṣiddha": ['mw'],
    "abhiṣidh": ['mw'],
    "abhiṣikta": ['ddsa', 'mw'],
    "abhiṣiv": ['mw'],
    "abhiṣiṣeṇayiṣu": ['ddsa', 'mw'],
    "abhiṣo": ['mw'],
    "abhiṣotṛ": ['ddsa', 'mw'],
    "abhiṣu": ['ap90', 'mw'],
    "abhiṣuka": ['mw'],
    "abhiṣuta": ['ap90', 'mw'],
    "abhiṣvakta": ['bhs'],
    "abhiṣvañj": ['mw'],
    "abhiṣvaṃgaḥ": ['ap90'],
    "abhiṣvaṅga": ['cae', 'ddsa', 'mw'],
    "abhiṣvaṅgin": ['mw'],
    "abhiṣyand": ['mw'],
    "abhiṣyanda": ['bhs', 'ddsa', 'mw'],
    "abhiṣyandamāna": ['mw'],
    "abhiṣyandana": ['bhs'],
    "abhiṣyandati": ['bhs'],
    "abhiṣyandayati": ['bhs'],
    "abhiṣyandin": ['mw'],
    "abhiṣyandiramaṇa": ['mw'],
    "abhiṣyat": ['mw'],
    "abhiṣyaṃd": ['ap90'],
    "abhiṣyaṃdaḥ": ['ap90'],
    "abhiṣyaṃdin": ['ap90'],
    "abhiṣyaṇṇa": ['bhs'],
    "abhiṣāc": ['ap90', 'gra'],
    "abhiṣāh": ['ap90'],
    "abhiṣāta": ['cae', 'mw'],
    "abhiṣāvaka": ['mw'],
    "abhiṣāvakaḥ": ['ap90'],
    "abhiṣū": ['mw'],
    "abhiṣūd": ['mw'],
    "abhiṣūyate": ['bhs'],
    "abhiṣṇam": ['bhs'],
    "abhiṣṇāta": ['mw'],
    "abhiṣṭambh": ['mw'],
    "abhiṣṭan": ['mw'],
    "abhiṣṭana": ['gra', 'mw'],
    "abhiṣṭanaḥ": ['ap90'],
    "abhiṣṭava": ['mw'],
    "abhiṣṭavaḥ": ['ap90'],
    "abhiṣṭhita": ['cae', 'mw'],
    "abhiṣṭhiv": ['mw'],
    "abhiṣṭhā": ['mw'],
    "abhiṣṭi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhiṣṭidyumna": ['gra', 'mw'],
    "abhiṣṭikṛt": ['gra', 'mw'],
    "abhiṣṭimat": ['ap90', 'gra', 'mw'],
    "abhiṣṭipā": ['gra', 'mw'],
    "abhiṣṭiśavas": ['cae', 'gra', 'mw'],
    "abhiṣṭu": ['ap90', 'mw'],
    "abhiṣṭubh": ['mw'],
    "abhiṣṭuta": ['mw'],
    "abhiṣṭuvat": ['mw'],
    "abhiṣṭuvāna": ['mw'],
    "abhiṣṭūya": ['mw'],
    "abhiṭhāna": ['cped'],
    "abhoga": ['cae', 'ddsa', 'mw'],
    "abhogaḥ": ['ap90'],
    "abhogghan": ['cae', 'gra', 'mw'],
    "abhogya": ['ddsa', 'mw'],
    "abhoj": ['ap90', 'gra'],
    "abhojana": ['cae', 'ddsa', 'mw'],
    "abhojanaṃ": ['ap90'],
    "abhojayant": ['cae'],
    "abhojin": ['ap90', 'mw'],
    "abhojita": ['mw'],
    "abhojya": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhojyānna": ['cae', 'mw'],
    "abhoktavya": ['mw'],
    "abhoktṛ": ['ap90', 'mw'],
    "abhr": ['ap90', 'mw'],
    "abhra": ['cae', 'ddsa', 'gra', 'mw'],
    "abhracchāyā": ['ddsa'],
    "abhraga": ['mw'],
    "abhragaṅgā": ['ddsa', 'mw'],
    "abhraghana": ['mw'],
    "abhragiri": ['mw'],
    "abhrajā": ['mw'],
    "abhraka": ['mw'],
    "abhrakabhasman": ['mw'],
    "abhrakasattva": ['mw'],
    "abhrakaṃ": ['ap90'],
    "abhrakhaṇḍa": ['cae', 'mw'],
    "abhrakūṭa": ['cae', 'mw'],
    "abhralipta": ['mw'],
    "abhrama": ['ap90', 'mw'],
    "abhramaya": ['mw'],
    "abhramu": ['mw'],
    "abhramujīviteśa": ['mw'],
    "abhramupriya": ['mw'],
    "abhramuvallabha": ['mw'],
    "abhramuḥ": ['ap90'],
    "abhramālā": ['mw'],
    "abhramātaṅga": ['mw'],
    "abhramāṃsī": ['mw'],
    "abhramūpati": ['mw'],
    "abhranāga": ['mw'],
    "abhrapatha": ['mw'],
    "abhraphullaka": ['mw'],
    "abhrapiśāca": ['mw'],
    "abhrapiśācaka": ['mw'],
    "abhrapruṣ": ['cae', 'gra', 'mw'],
    "abhrapuṣpa": ['mw'],
    "abhraroha": ['mw'],
    "abhrasani": ['mw'],
    "abhrataru": ['mw'],
    "abhrati": ['bhs'],
    "abhravarṣa": ['gra', 'mw'],
    "abhravilipta": ['mw'],
    "abhravāṭika": ['mw'],
    "abhravṛkṣa": ['mw'],
    "abhrayantī": ['mw'],
    "abhrayaḥ": ['ap90'],
    "abhraśiras": ['mw'],
    "abhraṃ": ['ap90'],
    "abhraṃga": ['mw'],
    "abhraṃkaṣa": ['ap90', 'mw'],
    "abhraṃliha": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhraṅkaṣa": ['ddsa'],
    "abhreṣa": ['mw'],
    "abhreṣaḥ": ['ap90'],
    "abhri": ['cae', 'ddsa', 'mw'],
    "abhrikhāta": ['mw'],
    "abhrita": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhriya": ['ap90', 'cae', 'gra', 'mw'],
    "abhriḥ": ['ap90'],
    "abhrottha": ['mw'],
    "abhrya": ['mw'],
    "abhrāgama": ['cae', 'mw'],
    "abhrāja": ['mw'],
    "abhrānadhyāya": ['mw'],
    "abhrānta": ['mw'],
    "abhrānti": ['mw'],
    "abhrātṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "abhrātṛghnī": ['mw'],
    "abhrātṛka": ['mw'],
    "abhrātṛmatī": ['mw'],
    "abhrātṛvya": ['ap90', 'ddsa', 'gra', 'mw'],
    "abhrāvakāśika": ['cae', 'ddsa', 'mw'],
    "abhrāvakāśin": ['cae', 'mw'],
    "abhrāya": ['mw'],
    "abhrāyate": ['ap90'],
    "abhrāyita": ['mw'],
    "abhrāṃta": ['ap90'],
    "abhrāṃtiḥ": ['ap90'],
    "abhrīya": ['mw'],
    "abhrūvilāsa": ['ddsa'],
    "abhu": ['cped'],
    "abhugna": ['ap90', 'bhs', 'mw'],
    "abhugnakukṣitā": ['mw'],
    "abhuj": ['ap90', 'gra', 'mw'],
    "abhuja": ['ap90', 'mw'],
    "abhujaṃgavat": ['mw'],
    "abhujiṣya": ['cae', 'mw'],
    "abhujiṣyā": ['ap90'],
    "abhujiṣyātva": ['mw'],
    "abhukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhuktapūrva": ['mw'],
    "abhuktavat": ['mw'],
    "abhuva": ['mw'],
    "abhuñjat": ['gra', 'mw'],
    "abhuñjāna": ['ddsa', 'mw'],
    "abhuṁ": ['cped'],
    "abhuṃjat": ['ap90'],
    "abhva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhyabhistutya": ['bhs'],
    "abhyac": ['gra'],
    "abhyadbhuta": ['bhs'],
    "abhyadhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhyadhikam": ['mw'],
    "abhyadhikādhika": ['mw'],
    "abhyadhvam": ['mw'],
    "abhyadhvaṃ": ['ap90'],
    "abhyadhve": ['mw'],
    "abhyadhyayana": ['mw'],
    "abhyaghāya": ['mw'],
    "abhyagni": ['mw'],
    "abhyagra": ['ap90', 'ddsa', 'mw'],
    "abhyaj": ['mw'],
    "abhyakta": ['ap90', 'cae', 'mw'],
    "abhyalaṃkāra": ['cae', 'mw'],
    "abhyalaṃkṛta": ['mw'],
    "abhyalpa": ['ddsa', 'mw'],
    "abhyam": ['ap90', 'mw'],
    "abhyamana": ['mw'],
    "abhyamanavat": ['mw'],
    "abhyamanaṃ": ['ap90'],
    "abhyamin": ['ap90', 'mw'],
    "abhyamita": ['ap90', 'mw'],
    "abhyamitra": ['mw'],
    "abhyamitram": ['ddsa', 'mw'],
    "abhyamitraṃ": ['ap90'],
    "abhyamitrya": ['mw'],
    "abhyamitrīya": ['mw'],
    "abhyamitrīṇa": ['mw'],
    "abhyamitrīṇatā": ['ddsa', 'mw'],
    "abhyamitrīṇaḥ": ['ap90'],
    "abhyanta": ['bhs'],
    "abhyantara": ['cae', 'ddsa', 'mw'],
    "abhyantaracārin": ['cae', 'mw'],
    "abhyantaradoṣakṛt": ['mw'],
    "abhyantaraka": ['mw'],
    "abhyantarakalpa": ['bhs'],
    "abhyantarakalā": ['mw'],
    "abhyantaram": ['mw'],
    "abhyantaratas": ['mw'],
    "abhyantarima": ['bhs'],
    "abhyantarimaka": ['bhs'],
    "abhyantarita": ['bhs'],
    "abhyantaroṣṭha": ['bhs'],
    "abhyantarā": ['bhs'],
    "abhyantarāgra": ['bhs'],
    "abhyantarāyāma": ['mw'],
    "abhyantarī": ['mw'],
    "abhyantarībhūta": ['bhs'],
    "abhyantarīkaraṇa": ['mw'],
    "abhyantarīkṛ": ['cae', 'ddsa', 'mw'],
    "abhyantarīkṛta": ['mw'],
    "abhyanujñeya": ['mw'],
    "abhyanujñā": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhyanujñāna": ['mw'],
    "abhyanujñāpana": ['cae', 'mw'],
    "abhyanujñāta": ['cae', 'mw'],
    "abhyanumodana": ['bhs', 'mw'],
    "abhyanumud": ['mw'],
    "abhyanuprach": ['mw'],
    "abhyanusṛ": ['mw'],
    "abhyanusṛj": ['mw'],
    "abhyanuvac": ['mw'],
    "abhyanuvad": ['mw'],
    "abhyanuyuj": ['mw'],
    "abhyanuśās": ['mw'],
    "abhyanūkta": ['ap90', 'mw'],
    "abhyapakram": ['mw'],
    "abhyapaśri": ['mw'],
    "abhyapān": ['mw'],
    "abhyarc": ['ap90', 'mw'],
    "abhyarcana": ['cae', 'ddsa', 'mw'],
    "abhyarcanaṃ": ['ap90'],
    "abhyarcanīya": ['mw'],
    "abhyarcita": ['mw'],
    "abhyarcya": ['mw'],
    "abhyarcā": ['mw'],
    "abhyard": ['mw'],
    "abhyardanaṃ": ['ap90'],
    "abhyardha": ['ap90', 'gra', 'mw'],
    "abhyardham": ['mw'],
    "abhyardhas": ['mw'],
    "abhyardhayajvan": ['cae', 'gra', 'mw'],
    "abhyardita": ['mw'],
    "abhyarh": ['ap90'],
    "abhyarhaṇa": ['cae', 'mw'],
    "abhyarhaṇā": ['ap90'],
    "abhyarhaṇīya": ['ap90', 'cae', 'mw'],
    "abhyarhaṇīyatā": ['mw'],
    "abhyarhita": ['ap90', 'mw'],
    "abhyari": ['mw'],
    "abhyarkabimbam": ['cae', 'ddsa', 'mw'],
    "abhyart": ['mw'],
    "abhyarth": ['ap90', 'mw'],
    "abhyarthana": ['cae', 'ddsa', 'mw'],
    "abhyarthanaṃ": ['ap90'],
    "abhyarthanā": ['mw'],
    "abhyarthanīya": ['ap90', 'mw'],
    "abhyarthin": ['ap90', 'mw'],
    "abhyarthita": ['mw'],
    "abhyarthya": ['mw'],
    "abhyarṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhyarṇatā": ['ap90', 'mw'],
    "abhyarṇṇa": ['mw'],
    "abhyarṣ": ['mw'],
    "abhyas": ['ap90', 'mw'],
    "abhyasana": ['ddsa', 'mw'],
    "abhyasanaṃ": ['ap90'],
    "abhyasanīya": ['mw'],
    "abhyasitavya": ['mw'],
    "abhyasta": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhyastaguṇa": ['cae'],
    "abhyastam": ['ddsa', 'mw'],
    "abhyastamaya": ['mw'],
    "abhyastamayaḥ": ['ap90'],
    "abhyastamita": ['ap90', 'mw'],
    "abhyastaṃ": ['ap90'],
    "abhyasūya": ['ap90', 'mw'],
    "abhyasūyaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhyasūyati": ['ap90'],
    "abhyasūyā": ['ap90', 'cae', 'mw'],
    "abhyatikram": ['mw'],
    "abhyatikṣar": ['mw'],
    "abhyatinī": ['mw'],
    "abhyatiric": ['mw'],
    "abhyatisṛj": ['mw'],
    "abhyatita": ['mw'],
    "abhyativad": ['mw'],
    "abhyativṛt": ['mw'],
    "abhyatyṛj": ['mw'],
    "abhyatī": ['mw'],
    "abhyatīta": ['ap90', 'cae', 'mw'],
    "abhyav": ['mw'],
    "abhyavacar": ['mw'],
    "abhyavadhā": ['mw'],
    "abhyavadugdha": ['mw'],
    "abhyavadā": ['mw'],
    "abhyavadānya": ['ap90', 'mw'],
    "abhyavagāh": ['mw'],
    "abhyavagāhya": ['bhs'],
    "abhyavaharaṇa": ['cae', 'ddsa', 'mw'],
    "abhyavaharaṇaṃ": ['ap90'],
    "abhyavahita": ['ap90'],
    "abhyavahāra": ['cae', 'mw'],
    "abhyavahāraḥ": ['ap90'],
    "abhyavahārin": ['mw'],
    "abhyavahārya": ['ap90', 'cae', 'mw'],
    "abhyavahṛ": ['ap90', 'mw'],
    "abhyavahṛta": ['mw'],
    "abhyavajval": ['mw'],
    "abhyavakarṣaṇa": ['mw'],
    "abhyavakarṣaṇaṃ": ['ap90'],
    "abhyavakrand": ['mw'],
    "abhyavakāśa": ['bhs', 'mw'],
    "abhyavakāśaḥ": ['ap90'],
    "abhyavakāśika": ['bhs'],
    "abhyavakīrati": ['bhs'],
    "abhyavakīrṇa": ['mw'],
    "abhyavakṝ": ['mw'],
    "abhyavaman": ['mw'],
    "abhyavanam": ['mw'],
    "abhyavanij": ['mw'],
    "abhyavanī": ['mw'],
    "abhyavapat": ['mw'],
    "abhyavapāta": ['mw'],
    "abhyavaruh": ['mw'],
    "abhyavaskand": ['mw'],
    "abhyavaskanda": ['mw'],
    "abhyavaskandana": ['mw'],
    "abhyavaskaṃd": ['ap90'],
    "abhyavaskaṃdaḥ": ['ap90'],
    "abhyavasthita": ['mw'],
    "abhyavasyand": ['mw'],
    "abhyavasṛ": ['mw'],
    "abhyavasṛj": ['mw'],
    "abhyavatan": ['mw'],
    "abhyavavṛt": ['mw'],
    "abhyave": ['ap90', 'mw'],
    "abhyavekṣ": ['mw'],
    "abhyavās": ['mw'],
    "abhyavāyana": ['mw'],
    "abhyavāyanaṃ": ['ap90'],
    "abhyavāyin": ['mw'],
    "abhyaya": ['ap90', 'bhs', 'mw'],
    "abhyayaḥ": ['ap90'],
    "abhyayodhyam": ['mw'],
    "abhyañj": ['mw'],
    "abhyañjaka": ['mw'],
    "abhyañjana": ['cae', 'gra', 'mw'],
    "abhyañjanya": ['mw'],
    "abhyañjya": ['mw'],
    "abhyaś": ['ap90', 'mw'],
    "abhyaśana": ['mw'],
    "abhyaśanaṃ": ['ap90'],
    "abhyaṃgaḥ": ['ap90'],
    "abhyaṃj": ['ap90'],
    "abhyaṃjanaṃ": ['ap90'],
    "abhyaṃka": ['ap90'],
    "abhyaṃtara": ['ap90'],
    "abhyaṃtarakaḥ": ['ap90'],
    "abhyaṃtarīkaraṇaṃ": ['ap90'],
    "abhyaṃtarīkṛ": ['ap90'],
    "abhyaṅga": ['cae', 'mw'],
    "abhyaṅgati": ['bhs'],
    "abhyaṅka": ['mw'],
    "abhye": ['mw'],
    "abhyetya": ['mw'],
    "abhyeṣaṇa": ['mw'],
    "abhyeṣaṇaṃ": ['ap90'],
    "abhyeṣaṇīya": ['mw'],
    "abhyoṣa": ['mw'],
    "abhyoṣya": ['mw'],
    "abhyoṣīya": ['mw'],
    "abhyuc": ['mw'],
    "abhyuccadeva": ['bhs'],
    "abhyuccagāmin": ['bhs'],
    "abhyuccar": ['mw'],
    "abhyuccaya": ['mw'],
    "abhyuccayaḥ": ['ap90'],
    "abhyucchraya": ['mw'],
    "abhyucchrayavat": ['mw'],
    "abhyucchrita": ['ap90', 'cae', 'mw'],
    "abhyucchritakara": ['mw'],
    "abhyucci": ['mw'],
    "abhyuccita": ['mw'],
    "abhyucita": ['ap90', 'mw'],
    "abhyud": ['mw'],
    "abhyudan": ['mw'],
    "abhyudavaso": ['mw'],
    "abhyudaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhyudayeṣṭi": ['mw'],
    "abhyudayin": ['ap90', 'mw'],
    "abhyudayāvaha": ['mw'],
    "abhyuddhara": ['bhs'],
    "abhyuddharaṇa": ['bhs', 'mw'],
    "abhyuddhā": ['mw'],
    "abhyuddhāra": ['bhs', 'mw'],
    "abhyuddhāraṇa": ['bhs'],
    "abhyuddhṛ": ['mw'],
    "abhyuddhṛta": ['ap90', 'mw'],
    "abhyuddidhīrṣā": ['bhs'],
    "abhyuddiś": ['mw'],
    "abhyuddravaṇa": ['mw'],
    "abhyuddru": ['mw'],
    "abhyuddṛṣṭa": ['cae', 'mw'],
    "abhyuddṛṣṭaṃ": ['ap90'],
    "abhyuddṛṣṭeṣṭi": ['mw'],
    "abhyuddṛṣṭā": ['mw'],
    "abhyude": ['mw'],
    "abhyudga": ['ap90', 'mw'],
    "abhyudgacchati": ['bhs'],
    "abhyudgam": ['ap90'],
    "abhyudgama": ['mw'],
    "abhyudgamana": ['bhs', 'mw'],
    "abhyudgamaḥ": ['ap90'],
    "abhyudgata": ['ap90', 'bhs', 'mw'],
    "abhyudgatakarman": ['bhs'],
    "abhyudgataprabhaśrī": ['bhs'],
    "abhyudgatarāja": ['bhs', 'mw'],
    "abhyudgati": ['mw'],
    "abhyudgatoṣṇīṣa": ['bhs'],
    "abhyudgatābha": ['bhs'],
    "abhyudgā": ['mw'],
    "abhyudi": ['ap90', 'mw'],
    "abhyudita": ['ap90', 'mw'],
    "abhyuditaśāyitā": ['mw'],
    "abhyuditeṣṭi": ['mw'],
    "abhyuditā": ['mw'],
    "abhyudyam": ['ap90'],
    "abhyudyata": ['ap90', 'cae', 'mw'],
    "abhyudācārin": ['mw'],
    "abhyudāharaṇa": ['mw'],
    "abhyudāharaṇaṃ": ['ap90'],
    "abhyudāhṛ": ['mw'],
    "abhyudānī": ['mw'],
    "abhyudīkṣ": ['mw'],
    "abhyudīr": ['mw'],
    "abhyudīraṇa": ['bhs'],
    "abhyudīrita": ['mw'],
    "abhyudīrite": ['mw'],
    "abhyudūh": ['mw'],
    "abhyuhya": ['bhs'],
    "abhyujjayini": ['mw'],
    "abhyujji": ['mw'],
    "abhyujjval": ['mw'],
    "abhyujjīv": ['mw'],
    "abhyukta": ['ap90', 'mw'],
    "abhyukṣ": ['ap90', 'mw'],
    "abhyukṣaṇa": ['ddsa', 'mw'],
    "abhyukṣaṇaṃ": ['ap90'],
    "abhyukṣita": ['mw'],
    "abhyullasat": ['mw'],
    "abhyunmodanīya": ['mw'],
    "abhyunnata": ['ap90', 'bhs', 'cae', 'mw'],
    "abhyunnatiḥ": ['ap90'],
    "abhyunnāmya": ['bhs'],
    "abhyunnī": ['mw'],
    "abhyupadhā": ['mw'],
    "abhyupagam": ['ap90', 'mw'],
    "abhyupagama": ['cae', 'ddsa', 'mw'],
    "abhyupagamasiddhānta": ['mw'],
    "abhyupagamaḥ": ['ap90'],
    "abhyupagamita": ['ap90', 'mw'],
    "abhyupagantavya": ['mw'],
    "abhyupagantṛ": ['mw'],
    "abhyupagata": ['ap90', 'mw'],
    "abhyupakāla": ['bhs'],
    "abhyupalakṣ": ['mw'],
    "abhyupamantr": ['mw'],
    "abhyupanivṛt": ['mw'],
    "abhyupapad": ['ap90', 'mw'],
    "abhyupapanna": ['cae', 'mw'],
    "abhyupapatti": ['cae', 'mw'],
    "abhyupapattiḥ": ['ap90'],
    "abhyupapattṛ": ['mw'],
    "abhyupapādana": ['mw'],
    "abhyupapādanaṃ": ['ap90'],
    "abhyupasad": ['mw'],
    "abhyupasev": ['mw'],
    "abhyupasthita": ['ap90', 'cae', 'mw'],
    "abhyupasthā": ['mw'],
    "abhyupasṛ": ['mw'],
    "abhyupaviś": ['mw'],
    "abhyupayukta": ['mw'],
    "abhyupayā": ['mw'],
    "abhyupaśānta": ['cae', 'mw'],
    "abhyupe": ['ap90', 'mw'],
    "abhyupekṣ": ['mw'],
    "abhyupekṣya": ['bhs'],
    "abhyupeta": ['cae', 'mw'],
    "abhyupetavya": ['mw'],
    "abhyupetya": ['ap90', 'mw'],
    "abhyupetyāśuśrūṣā": ['mw'],
    "abhyupeyivas": ['mw'],
    "abhyupādā": ['mw'],
    "abhyupāgata": ['mw'],
    "abhyupāhṛ": ['mw'],
    "abhyupākṛ": ['mw'],
    "abhyupākṛta": ['ap90'],
    "abhyupākṛṣ": ['mw'],
    "abhyupāvahṛ": ['mw'],
    "abhyupāvṛt": ['mw'],
    "abhyupāvṛtta": ['cae', 'mw'],
    "abhyupāya": ['cae', 'mw'],
    "abhyupāyana": ['mw'],
    "abhyupāyanaṃ": ['ap90'],
    "abhyupāyaḥ": ['ap90'],
    "abhyupāyā": ['mw'],
    "abhyutkram": ['mw'],
    "abhyutkrośana": ['mw'],
    "abhyutkrośanamantra": ['mw'],
    "abhyutkrośanaṃ": ['ap90'],
    "abhyutkruś": ['mw'],
    "abhyutkruṣṭa": ['ap90', 'mw'],
    "abhyutkṣipati": ['bhs'],
    "abhyutpat": ['ap90', 'mw'],
    "abhyutpatana": ['mw'],
    "abhyutpatanaṃ": ['ap90'],
    "abhyutsad": ['mw'],
    "abhyutsada": ['bhs'],
    "abhyutsah": ['mw'],
    "abhyutsarj": ['mw'],
    "abhyutsic": ['mw'],
    "abhyutsmi": ['mw'],
    "abhyutsāha": ['bhs', 'mw'],
    "abhyutsāhatā": ['bhs'],
    "abhyutsāhayati": ['bhs'],
    "abhyutsṛj": ['mw'],
    "abhyuttheya": ['mw'],
    "abhyutthita": ['ap90', 'cae', 'mw'],
    "abhyutthiti": ['mw'],
    "abhyutthā": ['ap90', 'mw'],
    "abhyutthāna": ['cae', 'mw'],
    "abhyutthānaṃ": ['ap90'],
    "abhyutthāyin": ['ap90', 'mw'],
    "abhyuttṝ": ['mw'],
    "abhyuṣ": ['mw'],
    "abhyuṣa": ['mw'],
    "abhyuṣaḥ": ['ap90'],
    "abhyuṣita": ['ap90', 'cae', 'mw'],
    "abhyuṣya": ['ap90', 'mw'],
    "abhyuṣīya": ['mw'],
    "abhyuṣṭamiśra": ['mw'],
    "abhyābhū": ['mw'],
    "abhyācakṣ": ['mw'],
    "abhyācar": ['ap90', 'mw'],
    "abhyācare": ['mw'],
    "abhyācikṣati": ['bhs'],
    "abhyācāra": ['mw'],
    "abhyācāraḥ": ['ap90'],
    "abhyācāre": ['mw'],
    "abhyādhā": ['ap90', 'mw'],
    "abhyādhāna": ['cae', 'mw'],
    "abhyādhānaṃ": ['ap90'],
    "abhyādiś": ['mw'],
    "abhyādru": ['mw'],
    "abhyādā": ['ap90', 'mw'],
    "abhyādāna": ['mw'],
    "abhyādānaṃ": ['ap90'],
    "abhyādāvya": ['mw'],
    "abhyāgam": ['ap90', 'mw'],
    "abhyāgama": ['cae', 'ddsa', 'mw'],
    "abhyāgamana": ['mw'],
    "abhyāgamanaṃ": ['ap90'],
    "abhyāgamaḥ": ['ap90'],
    "abhyāgata": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhyāghāram": ['mw'],
    "abhyāghāta": ['cae', 'ddsa', 'mw'],
    "abhyāghātaḥ": ['ap90'],
    "abhyāghātin": ['ap90', 'mw'],
    "abhyāghātya": ['mw'],
    "abhyāgā": ['mw'],
    "abhyāgāmin": ['mw'],
    "abhyāgāram": ['mw'],
    "abhyāgāre": ['mw'],
    "abhyāgārika": ['mw'],
    "abhyāgārikaḥ": ['ap90'],
    "abhyāhan": ['ap90', 'mw'],
    "abhyāhanana": ['mw'],
    "abhyāhananaṃ": ['ap90'],
    "abhyāhata": ['ap90', 'mw'],
    "abhyāhita": ['ap90', 'mw'],
    "abhyāhitapaśu": ['mw'],
    "abhyāhitāgni": ['mw'],
    "abhyāhve": ['mw'],
    "abhyāhāra": ['mw'],
    "abhyāhāraḥ": ['ap90'],
    "abhyāhārya": ['ap90'],
    "abhyāhṛ": ['ap90', 'mw'],
    "abhyāj": ['mw'],
    "abhyājñāya": ['mw'],
    "abhyājñāyaḥ": ['ap90'],
    "abhyākarṣa": ['mw'],
    "abhyākarṣaḥ": ['ap90'],
    "abhyākhyā": ['mw'],
    "abhyākhyāna": ['bhs', 'mw'],
    "abhyākhyānaṃ": ['ap90'],
    "abhyākhyāta": ['ap90', 'mw'],
    "abhyākirati": ['bhs'],
    "abhyākruś": ['mw'],
    "abhyākrāmam": ['mw'],
    "abhyākrāmaṃ": ['ap90'],
    "abhyākāram": ['ddsa', 'mw'],
    "abhyākāraṃ": ['ap90'],
    "abhyākāṃkṣitaṃ": ['ap90'],
    "abhyākāṅkṣita": ['mw'],
    "abhyāmarda": ['mw'],
    "abhyāmardaḥ": ['ap90'],
    "abhyāmnāya": ['mw'],
    "abhyānana": ['mw'],
    "abhyānandya": ['bhs', 'mw'],
    "abhyānta": ['mw'],
    "abhyānī": ['mw'],
    "abhyānṛt": ['mw'],
    "abhyāp": ['mw'],
    "abhyāpad": ['mw'],
    "abhyāpat": ['mw'],
    "abhyāpti": ['cae', 'mw'],
    "abhyāpādam": ['mw'],
    "abhyāpāta": ['mw'],
    "abhyāpātaḥ": ['ap90'],
    "abhyārabh": ['mw'],
    "abhyāram": ['cae', 'gra', 'mw'],
    "abhyārambha": ['cae', 'mw'],
    "abhyāraṃ": ['ap90'],
    "abhyāroha": ['cae', 'mw'],
    "abhyārohaḥ": ['ap90'],
    "abhyārohaṇīya": ['mw'],
    "abhyārohaṇīyaḥ": ['ap90'],
    "abhyārohuka": ['mw'],
    "abhyārohya": ['mw'],
    "abhyāruh": ['ap90', 'mw'],
    "abhyārūḍha": ['ap90', 'cae', 'mw'],
    "abhyāsa": ['cae', 'ddsa', 'mw'],
    "abhyāsad": ['ap90', 'mw'],
    "abhyāsakta": ['mw'],
    "abhyāsanimitta": ['mw'],
    "abhyāsanna": ['bhs'],
    "abhyāsannībhavati": ['bhs'],
    "abhyāsaparivartin": ['mw'],
    "abhyāsatā": ['mw'],
    "abhyāsavat": ['mw'],
    "abhyāsavyavāya": ['mw'],
    "abhyāsayoga": ['mw'],
    "abhyāsaḥ": ['ap90'],
    "abhyāsaṅgya": ['mw'],
    "abhyāsic": ['mw'],
    "abhyāsin": ['ap90', 'ddsa', 'mw'],
    "abhyāsāda": ['bhs'],
    "abhyāsādana": ['mw'],
    "abhyāsādanaṃ": ['ap90'],
    "abhyāsādayitavya": ['mw'],
    "abhyāsādeti": ['bhs'],
    "abhyāsākūpāra": ['mw'],
    "abhyāsāriṇī": ['mw'],
    "abhyāsībhavati": ['bhs'],
    "abhyātan": ['ap90', 'mw'],
    "abhyātap": ['mw'],
    "abhyātma": ['ap90', 'cae', 'mw'],
    "abhyātmam": ['mw'],
    "abhyātmataram": ['mw'],
    "abhyātmāgra": ['ddsa', 'mw'],
    "abhyātta": ['ap90', 'mw'],
    "abhyātāna": ['mw'],
    "abhyātānatva": ['mw'],
    "abhyātānaḥ": ['ap90'],
    "abhyātṝ": ['mw'],
    "abhyāvadh": ['mw'],
    "abhyāvah": ['mw'],
    "abhyāvartam": ['mw'],
    "abhyāvartaḥ": ['ap90'],
    "abhyāvartin": ['ap90', 'gra', 'mw'],
    "abhyāvasati": ['bhs'],
    "abhyāviś": ['mw'],
    "abhyāvṛt": ['ap90', 'mw'],
    "abhyāvṛtta": ['ap90', 'cae', 'mw'],
    "abhyāvṛtti": ['ddsa', 'mw'],
    "abhyāvṛttiḥ": ['ap90'],
    "abhyāvṛtya": ['mw'],
    "abhyāyam": ['ap90', 'mw'],
    "abhyāyata": ['bhs'],
    "abhyāyaṃsenya": ['ap90', 'gra', 'mw'],
    "abhyāyu": ['mw'],
    "abhyāyuka": ['mw'],
    "abhyāyā": ['mw'],
    "abhyāśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhyāśam": ['mw'],
    "abhyāśe": ['mw'],
    "abhyāśrāvaṇa": ['mw'],
    "abhyāśāt": ['mw'],
    "abhyāśībhū": ['mw'],
    "abhyāṃta": ['ap90'],
    "abhyūh": ['ap90', 'mw'],
    "abhyūha": ['cae', 'ddsa', 'mw'],
    "abhyūhanā": ['bhs'],
    "abhyūhaḥ": ['ap90'],
    "abhyūhitavya": ['mw'],
    "abhyūhya": ['mw'],
    "abhyūrṇu": ['mw'],
    "abhyūḍha": ['ap90', 'mw'],
    "abhyūḍhi": ['mw'],
    "abhyūṣa": ['mw'],
    "abhyūṣakhādikā": ['mw'],
    "abhyūṣya": ['mw'],
    "abhyūṣīya": ['mw'],
    "abhyṛ": ['mw'],
    "abhyṛch": ['mw'],
    "abhyṛñj": ['mw'],
    "abhyṛṣ": ['mw'],
    "abhāga": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhāgadheya": ['ddsa', 'mw'],
    "abhāgin": ['ddsa', 'mw'],
    "abhāgya": ['cae', 'ddsa', 'mw'],
    "abhājana": ['cae', 'ddsa', 'mw'],
    "abhājanabhūta": ['bhs'],
    "abhājanībhavati": ['bhs'],
    "abhāna": ['cae', 'ddsa', 'mw'],
    "abhārya": ['cae', 'ddsa'],
    "abhāsitvā": ['cped'],
    "abhāva": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhāvanā": ['ap90', 'mw'],
    "abhāvanīya": ['ap90', 'mw'],
    "abhāvasamudgata": ['bhs'],
    "abhāvavat": ['ddsa'],
    "abhāvayant": ['cae'],
    "abhāvayat": ['ddsa', 'mw'],
    "abhāvayitṛ": ['ap90', 'mw'],
    "abhāvin": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhāvya": ['mw'],
    "abhāṣaṇa": ['mw'],
    "abhāṣaṇaṃ": ['ap90'],
    "abhāṣita": ['ap90'],
    "abhī": ['ap90', 'ddsa', 'mw'],
    "abhīcāra": ['mw'],
    "abhīddha": ['ap90', 'mw'],
    "abhīga": ['ddsa', 'mw'],
    "abhīghāta": ['ap90'],
    "abhījya": ['ap90', 'mw'],
    "abhīka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhīke": ['mw'],
    "abhīkṣ": ['mw'],
    "abhīkṣṇa": ['ap90', 'mw'],
    "abhīkṣṇam": ['cae', 'ddsa', 'mw'],
    "abhīkṣṇaśas": ['mw'],
    "abhīkṣṇaśaḥ": ['ap90'],
    "abhīkṣṇāpattika": ['bhs'],
    "abhīlaṃ": ['ap90'],
    "abhīlu": ['ap90'],
    "abhīlāpalap": ['mw'],
    "abhīlāpaḥ": ['ap90'],
    "abhīma": ['ap90', 'mw'],
    "abhīmodamud": ['mw'],
    "abhīmodaḥ": ['ap90'],
    "abhīmāna": ['ap90', 'mw'],
    "abhīmānin": ['mw'],
    "abhīndh": ['mw'],
    "abhīpa": ['gra', 'mw'],
    "abhīpada": ['mw'],
    "abhīpat": ['ap90'],
    "abhīpatas": ['gra', 'mw'],
    "abhīps": ['mw'],
    "abhīpsat": ['mw'],
    "abhīpsin": ['ap90', 'mw'],
    "abhīpsita": ['ap90', 'cae', 'mw'],
    "abhīpsu": ['cae', 'ddsa', 'mw'],
    "abhīpāda": ['mw'],
    "abhīr": ['mw'],
    "abhīra": ['mw'],
    "abhīraḥ": ['ap90'],
    "abhīraṇī": ['ap90', 'mw'],
    "abhīru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abhīruka": ['mw'],
    "abhīrupattrī": ['mw'],
    "abhīruṇa": ['ap90', 'mw'],
    "abhīrā": ['bhs'],
    "abhīrājī": ['ap90', 'mw'],
    "abhīsāra": ['mw'],
    "abhīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhītavat": ['mw'],
    "abhīti": ['cae', 'ddsa', 'gra', 'mw'],
    "abhītiḥ": ['ap90'],
    "abhītvan": ['ap90', 'mw'],
    "abhīvarga": ['cae', 'mw'],
    "abhīvargaḥ": ['ap90'],
    "abhīvarta": ['cae', 'gra', 'mw'],
    "abhīvartaḥ": ['ap90'],
    "abhīvṛt": ['ap90', 'mw'],
    "abhīvṛta": ['ap90', 'mw'],
    "abhīśu": ['cae', 'ddsa', 'gra', 'mw'],
    "abhīśuḥ": ['ap90'],
    "abhīśāpa": ['ddsa', 'mw'],
    "abhīśāpaḥ": ['ap90'],
    "abhīṣ": ['ap90', 'mw'],
    "abhīṣah": ['mw'],
    "abhīṣahā": ['mw'],
    "abhīṣayā": ['ap90'],
    "abhīṣaṃga": ['ap90'],
    "abhīṣaṅga": ['mw'],
    "abhīṣaṇa": ['bhs'],
    "abhīṣmadroṇa": ['ddsa', 'mw'],
    "abhīṣu": ['mw'],
    "abhīṣumat": ['mw'],
    "abhīṣāh": ['ap90', 'gra'],
    "abhīṣāha": ['mw'],
    "abhīṣṇam": ['bhs'],
    "abhīṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhīṣṭadevatā": ['mw'],
    "abhīṣṭalābha": ['mw'],
    "abhīṣṭasiddhi": ['mw'],
    "abhīṣṭatama": ['mw'],
    "abhīṣṭatā": ['mw'],
    "abhīṣṭatṛtīyā": ['mw'],
    "abhīṣṭi": ['ap90', 'mw'],
    "abhīṣṭā": ['mw'],
    "abhū": ['mw'],
    "abhūmi": ['bhs', 'cae', 'ddsa', 'mw'],
    "abhūmija": ['mw'],
    "abhūmisāhvaya": ['mw'],
    "abhūmiḥ": ['ap90'],
    "abhūri": ['ap90', 'mw'],
    "abhūta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "abhūtadoṣa": ['mw'],
    "abhūtalasparśa": ['cae', 'ddsa'],
    "abhūtalasparśatā": ['mw'],
    "abhūtaprādurbhāva": ['mw'],
    "abhūtapūrva": ['mw'],
    "abhūtarajas": ['mw'],
    "abhūtatadbhāva": ['mw'],
    "abhūtatva": ['mw'],
    "abhūtaśatru": ['mw'],
    "abhūti": ['cae', 'ddsa', 'mw'],
    "abhūtiḥ": ['ap90'],
    "abhūtopamā": ['cae', 'ddsa', 'mw'],
    "abhūtvāśraddhā": ['bhs'],
    "abhūtāharaṇa": ['mw'],
    "abhūtārtha": ['ddsa', 'mw'],
    "abhūyaḥsannivṛtti": ['ddsa'],
    "abhūyaḥsaṃnivṛtti": ['mw'],
    "abhūyiṣṭha": ['ddsa', 'mw'],
    "abhūḥ": ['ap90'],
    "abhūṣa": ['mw'],
    "abhūṣita": ['mw'],
    "abhṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "abhṛtaka": ['mw'],
    "abhṛtyātman": ['ddsa', 'mw'],
    "abhṛśa": ['ap90', 'mw'],
    "abibhyat": ['cae', 'gra', 'mw'],
    "abibhīvas": ['ap90', 'gra', 'mw'],
    "abibhīvaṃs": ['cae'],
    "abindhana": ['ddsa', 'mw'],
    "abiṃdhanaḥ": ['ap90'],
    "abja": ['ap90', 'cae', 'ddsa', 'mw'],
    "abjabhava": ['mw'],
    "abjabhoga": ['mw'],
    "abjabhū": ['mw'],
    "abjabāndhava": ['mw'],
    "abjadṛś": ['mw'],
    "abjahasta": ['mw'],
    "abjaja": ['mw'],
    "abjala": ['mw'],
    "abjanayana": ['mw'],
    "abjanetra": ['mw'],
    "abjanābha": ['mw'],
    "abjapāṇi": ['mw'],
    "abjas": ['ap90'],
    "abjasambhava": ['mw'],
    "abjasamudgata": ['mw'],
    "abjasaras": ['cae', 'mw'],
    "abjavāhana": ['mw'],
    "abjayoni": ['mw'],
    "abjinī": ['ap90', 'ddsa', 'mw'],
    "abjinīpati": ['mw'],
    "abjit": ['ap90', 'gra', 'mw'],
    "abjā": ['ap90', 'cae', 'gra', 'mw'],
    "abjāda": ['mw'],
    "abjāsana": ['mw'],
    "abliṃgaṃ": ['ap90'],
    "abliṅga": ['ddsa', 'mw'],
    "abliṅgā": ['mw'],
    "abodha": ['ap90', 'cae', 'ddsa', 'mw'],
    "abodhagamya": ['mw'],
    "abodhanīya": ['mw'],
    "abodhika": ['bhs'],
    "abodhya": ['ap90'],
    "abrahmabandhūka": ['mw'],
    "abrahmacarya": ['ap90', 'mw'],
    "abrahmacaryaka": ['mw'],
    "abrahmacaryaṃvāda": ['bhs'],
    "abrahman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abrahmatā": ['gra', 'mw'],
    "abrahmavarcasin": ['mw'],
    "abrahmavid": ['mw'],
    "abrahmaṇya": ['ap90', 'cae', 'ddsa', 'mw'],
    "abrajas": ['bhs'],
    "abruvant": ['cae'],
    "abruvat": ['ddsa', 'mw'],
    "abrāhmaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "abrāhmaṇya": ['bhs', 'mw'],
    "abrāhmaṇyaṃ": ['ap90'],
    "abrāhmaṇī": ['mw'],
    "abrūkṛtaṃ": ['ap90'],
    "abrūpa": ['ddsa'],
    "abuddha": ['ap90', 'ddsa', 'mw'],
    "abuddhatva": ['mw'],
    "abuddhi": ['cae', 'ddsa', 'mw'],
    "abuddhimat": ['mw'],
    "abuddhipūrva": ['mw'],
    "abuddhipūrvaka": ['mw'],
    "abuddhipūrvakam": ['mw'],
    "abuddhipūrvam": ['mw'],
    "abuddhistha": ['mw'],
    "abuddhiḥ": ['ap90'],
    "abuddhyā": ['mw'],
    "abudh": ['ap90', 'cae', 'mw'],
    "abudha": ['cae', 'ddsa', 'mw'],
    "abudhna": ['ap90', 'ddsa', 'gra', 'mw'],
    "abudhya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "abudhyamāna": ['cae', 'ddsa', 'gra', 'mw'],
    "abādha": ['ap90', 'cae', 'ddsa', 'mw'],
    "abādhaka": ['cae', 'mw'],
    "abādhita": ['cae', 'gra', 'mw'],
    "abādhya": ['mw'],
    "abādhā": ['mw'],
    "abāhya": ['ap90', 'mw'],
    "abāla": ['ap90', 'mw'],
    "abālasattva": ['cae', 'ddsa'],
    "abālendu": ['ddsa', 'mw'],
    "abāliśa": ['ddsa', 'mw'],
    "abāndhava": ['cae', 'ddsa', 'mw'],
    "abāndhavakṛta": ['cae', 'mw'],
    "abībhatsā": ['mw'],
    "abīja": ['cae', 'ddsa', 'mw'],
    "abījaka": ['cae', 'mw'],
    "abṛha": ['bhs'],
    "ac": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "acaitanya": ['ddsa', 'mw'],
    "acaitanyaṃ": ['ap90'],
    "acakita": ['ddsa'],
    "acakkhuka": ['cped'],
    "acakra": ['ap90', 'gra', 'mw'],
    "acakravarta": ['mw'],
    "acakṛvas": ['mw'],
    "acakṣurviṣaya": ['cae', 'ddsa', 'mw'],
    "acakṣus": ['ap90', 'cae', 'ddsa', 'mw'],
    "acakṣuṣka": ['mw'],
    "acakṣuṣṭva": ['mw'],
    "acala": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "acalabhrātṛ": ['mw'],
    "acaladatta": ['ddsa'],
    "acaladeva": ['bhs'],
    "acaladhṛti": ['mw'],
    "acalakīlā": ['mw'],
    "acalamati": ['bhs', 'mw'],
    "acalana": ['cae', 'ddsa'],
    "acalapratiṣṭha": ['cae'],
    "acalapura": ['ddsa', 'mw'],
    "acalaskandha": ['bhs'],
    "acalatviṣ": ['mw'],
    "acalaśreṣṭha": ['mw'],
    "acalaśrī": ['bhs'],
    "acalaṭakkirāja": ['bhs'],
    "acalendra": ['ddsa'],
    "acalendrarāja": ['bhs'],
    "acaleśvara": ['ddsa'],
    "acalitasumana": ['bhs'],
    "acalopāsikāvimokṣa": ['bhs'],
    "acalā": ['bhs', 'mw'],
    "acalācala": ['bhs'],
    "acalādhipa": ['mw'],
    "acalāsaptamī": ['mw'],
    "acandana": ['cae', 'ddsa'],
    "acandra": ['mw'],
    "acapala": ['mw'],
    "acara": ['ap90', 'cae', 'ddsa', 'mw'],
    "acarama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "acaramavayas": ['ddsa', 'mw'],
    "acarat": ['gra', 'mw'],
    "acaraṇa": ['mw'],
    "acaraṇīya": ['mw'],
    "acaraṭarkirāja": ['bhs'],
    "acarita": ['ddsa', 'mw'],
    "acariṣyat": ['mw'],
    "acarmaka": ['mw'],
    "acatura": ['ap90', 'mw'],
    "acaura": ['cae'],
    "acaṃḍa": ['ap90'],
    "acaṇḍa": ['ddsa', 'mw'],
    "acaṇḍamarīci": ['mw'],
    "acaṇḍī": ['mw'],
    "acc-": ['cped'],
    "accagamā": ['cped'],
    "accaguṁ": ['cped'],
    "accanta": ['cped'],
    "accantabrahmacāri": ['cped'],
    "accantabrahmacārin": ['cped'],
    "accantadussīlya": ['cped'],
    "accantaniṭṭha": ['cped'],
    "accantapariyosāna": ['cped'],
    "accantaruci": ['cped'],
    "accantayogakkhemi": ['cped'],
    "accantayogakkhemin": ['cped'],
    "accarucī": ['cped'],
    "accasarā": ['cped'],
    "accasarī": ['cped'],
    "accatari": ['cped'],
    "accatāri": ['cped'],
    "accaya": ['cped'],
    "accayati": ['cped'],
    "accaṅkusa": ['cped'],
    "acceka": ['cped'],
    "accekacīvara": ['cped'],
    "accepts": ['cped'],
    "accha": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "acchabhalla": ['mw'],
    "acchakañjīka": ['cped'],
    "acchala": ['cae', 'ddsa'],
    "acchambaṭkārāya": ['mw'],
    "acchambhin": ['bhs'],
    "acchambhita": ['bhs'],
    "acchanda": ['ddsa'],
    "acchandagāmin": ['bhs'],
    "acchandaska": ['mw'],
    "acchanna": ['cped'],
    "acchara": ['cped'],
    "accharikā": ['cped'],
    "acchariya": ['cped'],
    "acchariyamanussa": ['cped'],
    "acchariyaṁ": ['cped'],
    "accharā": ['cped'],
    "accharāsaṅghāta": ['cped'],
    "acchati": ['bhs'],
    "acchayā": ['mw'],
    "acchaṃdas": ['ap90'],
    "acchaṭa": ['bhs'],
    "acchaṭā": ['bhs'],
    "acchaṭāsaṃghāta": ['mw'],
    "acchaṭāśabda": ['mw'],
    "acchedika": ['ap90', 'mw'],
    "acchedya": ['ap90', 'cae', 'ddsa', 'mw'],
    "acchejja": ['cped'],
    "acchera": ['mw'],
    "accheta": ['mw'],
    "accheti": ['cped'],
    "acchetya": ['mw'],
    "acchi": ['cped'],
    "acchibaddha": ['cped'],
    "acchidra": ['ap90', 'cae', 'ddsa', 'mw'],
    "acchidrakāṇḍa": ['mw'],
    "acchidreṇa": ['mw'],
    "acchidrodhnī": ['mw'],
    "acchidroktha": ['mw'],
    "acchidroti": ['mw'],
    "acchidyamāna": ['mw'],
    "acchijja": ['cped'],
    "acchila": ['bhs'],
    "acchindati": ['bhs', 'cped'],
    "acchindi": ['cped'],
    "acchindimsu": ['cped'],
    "acchinditvā": ['cped'],
    "acchindāpesuṁ": ['cped'],
    "acchindāpeti": ['cped'],
    "acchinna": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "acchinnacīvara": ['cped'],
    "acchinnacīvaraka": ['cped'],
    "acchinnadhāra": ['bhs'],
    "acchinnaparṇa": ['mw'],
    "acchinnapattra": ['mw'],
    "acchisaṁ": ['cped'],
    "acchitabba": ['cped'],
    "acchoda": ['mw'],
    "acchodaka": ['cped'],
    "acchodi": ['cped'],
    "acchodika": ['cped'],
    "acchodā": ['mw'],
    "acchokti": ['cae', 'mw'],
    "acchoṭanaṃ": ['ap90'],
    "acchupeti": ['cped'],
    "acchuptā": ['ap90', 'mw'],
    "acchupīyati": ['cped'],
    "acchā": ['cae'],
    "acchābrū": ['mw'],
    "acchācar": ['mw'],
    "acchāccha": ['ddsa'],
    "acchādana": ['cped'],
    "acchādayati": ['cped'],
    "acchādesi": ['cped'],
    "acchādesuṁ": ['cped'],
    "acchādetvā": ['cped'],
    "acchādhanv": ['mw'],
    "acchādita": ['cped'],
    "acchādru": ['mw'],
    "acchādāpetvā": ['cped'],
    "acchāgam": ['mw'],
    "acchāi": ['mw'],
    "acchānakṣ": ['mw'],
    "acchānaś": ['mw'],
    "acchānta": ['ddsa'],
    "acchānu": ['mw'],
    "acchānī": ['mw'],
    "acchāpat": ['mw'],
    "acchāsyand": ['mw'],
    "acchāsṛ": ['mw'],
    "acchāvac": ['mw'],
    "acchāvad": ['mw'],
    "acchāvañc": ['mw'],
    "acchāvāka": ['mw'],
    "acchāvākaḥ": ['ap90'],
    "acchāvākya": ['ap90'],
    "acchāvākīya": ['ap90', 'mw'],
    "acchāvṛt": ['mw'],
    "acchāya": ['mw'],
    "acchāyā": ['mw'],
    "acchūrikā": ['mw'],
    "acchūrī": ['mw'],
    "accodāta": ['cped'],
    "accogāḷha": ['cped'],
    "accokkaṭṭha": ['cped'],
    "accuggamamma": ['cped'],
    "accuggata": ['cped'],
    "accukkaṭṭha": ['cped'],
    "accussanna": ['cped'],
    "accuṇha": ['cped'],
    "accādhāya": ['cped'],
    "accāraddha": ['cped'],
    "accāraddhaviriya": ['cped'],
    "accāsanna": ['cped'],
    "accāsanne": ['cped'],
    "accāvadanta": ['cped'],
    "accāvadati": ['cped'],
    "accāvadimha": ['cped'],
    "accāvadittha": ['cped'],
    "accāyata": ['cped'],
    "accāyika": ['cped'],
    "accī": ['cped'],
    "accīma": ['cped'],
    "accīmat": ['cped'],
    "acela": ['bhs'],
    "acelaka": ['bhs'],
    "acetana": ['ap90', 'cae', 'ddsa', 'mw'],
    "acetas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "acetita": ['ddsa'],
    "acetāna": ['ap90', 'gra', 'mw'],
    "aceṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aceṣṭatā": ['mw'],
    "acha": ['gra'],
    "achaukti": ['gra'],
    "achidra": ['gra'],
    "achidrayāman": ['gra'],
    "achidraūdhan": ['gra'],
    "achidrodhan": ['gra'],
    "achidroti": ['gra'],
    "achidyamāna": ['gra'],
    "achinnapatra": ['gra'],
    "achokti": ['gra'],
    "achā": ['gra'],
    "achāya": ['gra'],
    "acikitsanīya": ['ddsa'],
    "acikitvas": ['gra', 'mw'],
    "acintanīya": ['cae', 'ddsa'],
    "acinti": ['bhs'],
    "acintia": ['bhs'],
    "acintika": ['bhs'],
    "acintikamadhyabuddhivikrīḍita": ['bhs'],
    "acintita": ['cae', 'ddsa', 'mw'],
    "acintiya": ['bhs'],
    "acintya": ['bhs', 'cae', 'ddsa', 'mw'],
    "acintyaguṇānuttaradharmagocara": ['bhs'],
    "acintyaka": ['bhs'],
    "acintyakarman": ['mw'],
    "acintyaparivarta": ['bhs'],
    "acintyaparākrama": ['cae'],
    "acintyarūpa": ['cae', 'mw'],
    "acintyaśrī": ['bhs'],
    "acintā": ['cae', 'ddsa', 'mw'],
    "acira": ['ap90', 'cae', 'ddsa', 'mw'],
    "acirabhās": ['mw'],
    "aciraciracireṇā": ['bhs'],
    "aciradyuti": ['cae', 'ddsa', 'mw'],
    "aciram": ['mw'],
    "aciramṛta": ['mw'],
    "aciraprabhā": ['cae', 'mw'],
    "aciraprabhās": ['cae'],
    "aciraprasūtā": ['mw'],
    "acirapravrajita": ['cae'],
    "acirarocis": ['mw'],
    "acirasthita": ['cae'],
    "acirasthitikatā": ['bhs'],
    "acirayānasaṃprasthita": ['bhs'],
    "acireṇa": ['mw'],
    "acirodita": ['cae'],
    "aciroḍhā": ['ddsa', 'mw'],
    "acirā": ['mw'],
    "acirābhā": ['mw'],
    "acirāt": ['mw'],
    "acirāṃśu": ['mw'],
    "acit": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "acita": ['ap90', 'mw'],
    "acitra": ['ddsa', 'gra', 'mw'],
    "acitta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "acittaka": ['cped'],
    "acittamanas": ['mw'],
    "acittapājas": ['mw'],
    "acitti": ['cae', 'ddsa', 'gra', 'mw'],
    "acittiḥ": ['ap90'],
    "acitvas": ['ap90'],
    "aciṃtita": ['ap90'],
    "aciṃtya": ['ap90'],
    "aciṣṇu": ['ap90'],
    "aciṣṭu": ['mw'],
    "acodas": ['ap90', 'gra', 'mw'],
    "acodat": ['gra', 'mw'],
    "acodita": ['cae'],
    "acodyamāna": ['cae', 'ddsa'],
    "acyuta": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "acyutacakravartin": ['mw'],
    "acyutacyut": ['cae', 'gra', 'mw'],
    "acyutadanta": ['mw'],
    "acyutaja": ['mw'],
    "acyutajallakin": ['mw'],
    "acyutakṣit": ['mw'],
    "acyutamanas": ['mw'],
    "acyutamūrti": ['mw'],
    "acyutanta": ['mw'],
    "acyutapājas": ['mw'],
    "acyutaruṣ": ['mw'],
    "acyutasthala": ['mw'],
    "acyutavāsa": ['mw'],
    "acyutopādhyāya": ['mw'],
    "acyutāgraja": ['mw'],
    "acyāvin": ['mw'],
    "acākrika": ['mw'],
    "acākrikatā": ['mw'],
    "acāpala": ['ap90', 'cae'],
    "acāpalya": ['ddsa', 'mw'],
    "acāra": ['bhs'],
    "acāru": ['mw'],
    "acīrṇadaṇḍatā": ['bhs'],
    "acīvaraka": ['cped'],
    "ad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ada": ['cped', 'mw'],
    "adabdha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adabdhacakṣus": ['mw'],
    "adabdhadhīti": ['gra', 'mw'],
    "adabdhavrata": ['gra'],
    "adabdhavratapramati": ['gra', 'mw'],
    "adabdhāsu": ['mw'],
    "adabdhāyu": ['mw'],
    "adabha": ['cae', 'ddsa', 'gra', 'mw'],
    "adabhra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adadat": ['cae', 'ddsa'],
    "adadhi": ['ddsa'],
    "adadhryaṃc": ['ap90'],
    "adadryañc": ['mw'],
    "adagdha": ['ap90', 'mw'],
    "adainya": ['ap90'],
    "adaiteya": ['mw'],
    "adaiva": ['ap90', 'cae', 'ddsa', 'mw'],
    "adaka": ['cped', 'mw'],
    "adakṣa": ['mw'],
    "adakṣiṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adakṣiṇatva": ['mw'],
    "adakṣiṇatā": ['cae'],
    "adakṣiṇya": ['mw'],
    "adakṣiṇīya": ['ap90', 'mw'],
    "adala": ['ap90', 'mw'],
    "adalā": ['mw'],
    "adambha": ['cae', 'ddsa', 'mw'],
    "adambhin": ['ddsa'],
    "adambhitva": ['cae', 'mw'],
    "adamudryañc": ['mw'],
    "adamuyañc": ['mw'],
    "adamya": ['mw'],
    "adamūyañc": ['mw'],
    "adana": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "adant": ['cae', 'ddsa'],
    "adanta": ['ddsa', 'mw'],
    "adantajāta": ['ddsa', 'mw'],
    "adantaka": ['mw'],
    "adantya": ['mw'],
    "adantāghātin": ['mw'],
    "adanīya": ['mw'],
    "adara": ['mw'],
    "adaraka": ['mw'],
    "adaridra": ['cae', 'mw'],
    "adarpa": ['cae'],
    "adarsamukha": ['bhs'],
    "adarśa": ['mw'],
    "adarśana": ['cae', 'ddsa', 'mw'],
    "adarśanapatha": ['mw'],
    "adarśanaṃ": ['ap90'],
    "adarśanībhū": ['ddsa', 'mw'],
    "adarśanīya": ['ddsa', 'mw'],
    "adarśayant": ['cae'],
    "adarśayitvā": ['cae'],
    "adarśaḥ": ['ap90'],
    "adas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adasaka": ['cped'],
    "adasta": ['mw'],
    "adasya": ['mw'],
    "adasyati": ['ap90'],
    "adasīya": ['mw'],
    "adat": ['ap90', 'ddsa', 'gra', 'mw'],
    "adatka": ['mw'],
    "adatra": ['ap90'],
    "adatrayā": ['mw'],
    "adatrā": ['gra'],
    "adatta": ['ap90', 'cae', 'ddsa', 'mw'],
    "adattadāyin": ['cae'],
    "adattaphala": ['cae'],
    "adattapūrvā": ['cae'],
    "adattvā": ['ddsa', 'mw'],
    "adattā": ['mw'],
    "adattādāna": ['ddsa', 'mw'],
    "adattādāsyatha": ['bhs'],
    "adattādāyika": ['bhs', 'mw'],
    "adattādāyin": ['mw'],
    "adaya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adayam": ['mw'],
    "adayālu": ['mw'],
    "adaśamāsya": ['mw'],
    "adaśan": ['mw'],
    "adaḥkṛtya": ['mw'],
    "adaṁsu": ['cped'],
    "adaṃbha": ['ap90'],
    "adaṃta": ['ap90'],
    "adaṃtya": ['ap90'],
    "adaṃḍa": ['ap90'],
    "adaṃḍya": ['ap90'],
    "adaṃṣṭra": ['ap90'],
    "adaṃṣṭrin": ['cae'],
    "adaṇḍa": ['mw'],
    "adaṇḍana": ['mw'],
    "adaṇḍanīya": ['mw'],
    "adaṇḍavāsika": ['mw'],
    "adaṇḍayant": ['cae'],
    "adaṇḍya": ['cae', 'ddsa', 'mw'],
    "adbhis": ['ddsa'],
    "adbhuta": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "adbhutabhīmakarman": ['mw'],
    "adbhutabrāhmaṇa": ['mw'],
    "adbhutadarpaṇa": ['mw'],
    "adbhutadarśana": ['mw'],
    "adbhutadharma": ['mw'],
    "adbhutagandha": ['mw'],
    "adbhutainas": ['cae', 'gra', 'mw'],
    "adbhutakarman": ['mw'],
    "adbhutakratu": ['gra', 'mw'],
    "adbhutakṛṣṇarāja": ['mw'],
    "adbhutarasa": ['mw'],
    "adbhutaraṅga": ['mw'],
    "adbhutarāmāyaṇa": ['mw'],
    "adbhutarūpa": ['mw'],
    "adbhutasaṃkāśa": ['mw'],
    "adbhutasvana": ['mw'],
    "adbhutasāra": ['mw'],
    "adbhutatama": ['mw'],
    "adbhutatva": ['mw'],
    "adbhutaśānti": ['mw'],
    "adbhutopama": ['mw'],
    "adbhutopamā": ['cae', 'mw'],
    "adbhutotpāta": ['mw'],
    "adbhutottarakāṇḍa": ['mw'],
    "adbhutārtha": ['mw'],
    "adbhutāya": ['ddsa'],
    "adbhyas": ['ddsa'],
    "addavalepana": ['cped'],
    "addha": ['cped'],
    "addhabhaveti": ['cped'],
    "addhabhavi": ['cped'],
    "addhabhūta": ['cped'],
    "addhagata": ['cped'],
    "addhagū": ['cped'],
    "addhan": ['cped'],
    "addhanīya": ['cped'],
    "addhariya": ['cped'],
    "addhika": ['cped'],
    "addhikaraṇavūpasamana": ['cped'],
    "addhyālohakarṇa": ['mw'],
    "addhā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "addhābhavanta": ['cped'],
    "addhābodheya": ['mw'],
    "addhāhina": ['cped'],
    "addhāna": ['cped'],
    "addhānakkhama": ['cped'],
    "addhānamagga": ['cped'],
    "addhāpuruṣa": ['mw'],
    "addhātama": ['mw'],
    "addhātamām": ['mw'],
    "addhāti": ['gra', 'mw'],
    "addhātiḥ": ['ap90'],
    "addhāyu": ['cped'],
    "addhāṁ": ['cped'],
    "addita": ['cped'],
    "addiyati": ['cped'],
    "adeha": ['mw'],
    "adehabandha": ['ddsa'],
    "adekṣiya": ['bhs'],
    "adeva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adevajuṣṭa": ['ddsa'],
    "adevaka": ['mw'],
    "adevamātṛka": ['mw'],
    "adevara": ['ddsa'],
    "adevatra": ['gra', 'mw'],
    "adevatā": ['mw'],
    "adevayat": ['ap90', 'gra', 'mw'],
    "adevayu": ['gra', 'mw'],
    "adevṛghnī": ['mw'],
    "adeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "adeyadāna": ['mw'],
    "adeśa": ['cae', 'ddsa', 'mw'],
    "adeśaja": ['mw'],
    "adeśajña": ['ddsa'],
    "adeśakāla": ['cae', 'ddsa', 'mw'],
    "adeśastha": ['mw'],
    "adeśaḥ": ['ap90'],
    "adeśika": ['mw'],
    "adeśya": ['ap90', 'cae', 'mw'],
    "adga": ['cae', 'ddsa', 'mw'],
    "adgaḥ": ['ap90'],
    "adha": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "adhagama": ['cped'],
    "adhagāmi": ['cped'],
    "adhagāmin": ['cped'],
    "adhairya": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhakkha": ['cped'],
    "adhakkhaka": ['cped'],
    "adhakkhakaṁ": ['cped'],
    "adhama": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "adhamabhṛta": ['mw'],
    "adhamabhṛtaka": ['mw'],
    "adhamaceṣṭa": ['cae'],
    "adhamadhī": ['cae'],
    "adhamarṇa": ['cae', 'mw'],
    "adhamarṇika": ['cae', 'mw'],
    "adhamayonija": ['cae'],
    "adhamaśākha": ['mw'],
    "adhamā": ['mw'],
    "adhamācāra": ['mw'],
    "adhamādhama": ['ddsa', 'mw'],
    "adhamārdha": ['mw'],
    "adhamārdhya": ['mw'],
    "adhamāṅga": ['mw'],
    "adhamūrdhva": ['bhs'],
    "adhana": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhandha": ['bhs'],
    "adhandhāyamāna": ['bhs'],
    "adhanya": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhanyatā": ['cae'],
    "adhapriya": ['gra', 'mw'],
    "adhara": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adharadala": ['mw'],
    "adharahanu": ['mw'],
    "adharaka": ['bhs'],
    "adharakaya": ['cped'],
    "adharakaṇṭha": ['mw'],
    "adharakāya": ['mw'],
    "adharamadhu": ['mw'],
    "adharamūla": ['mw'],
    "adharapāna": ['mw'],
    "adhararucaka": ['mw'],
    "adharasapatna": ['mw'],
    "adharasmāt": ['ap90', 'mw'],
    "adharastāt": ['mw'],
    "adharasvastika": ['mw'],
    "adharatas": ['bhs', 'mw'],
    "adharauṣṭha": ['cae', 'mw'],
    "adharauṣṭharucaka": ['mw'],
    "adharaya": ['mw'],
    "adhardiś": ['bhs'],
    "adharedyus": ['mw'],
    "adharedyuḥ": ['ap90'],
    "adharima": ['bhs', 'mw'],
    "adharma": ['cae', 'ddsa', 'mw'],
    "adharmabhīru": ['cae'],
    "adharmacaraṇa": ['mw'],
    "adharmacaryā": ['mw'],
    "adharmacārin": ['mw'],
    "adharmadaṇḍana": ['cae', 'mw'],
    "adharmajña": ['cae'],
    "adharmamaya": ['mw'],
    "adharmatas": ['mw'],
    "adharmaḥ": ['ap90'],
    "adharmaṇa": ['ddsa'],
    "adharmika": ['ddsa'],
    "adharmin": ['ap90', 'mw'],
    "adharmiṣṭha": ['cae', 'ddsa', 'mw'],
    "adharmottaratā": ['mw'],
    "adharmya": ['ap90', 'cae', 'ddsa', 'mw'],
    "adharmā": ['mw'],
    "adharmāstikāya": ['mw'],
    "adharmātman": ['mw'],
    "adharottara": ['cae', 'ddsa', 'mw'],
    "adharoṣṭha": ['cae', 'mw'],
    "adharā": ['mw'],
    "adharāc": ['gra'],
    "adharācya": ['mw'],
    "adharācīna": ['ap90', 'gra', 'mw'],
    "adharāk": ['mw'],
    "adharāmbara": ['ddsa', 'mw'],
    "adharāmṛta": ['mw'],
    "adharāraṇi": ['cae', 'ddsa', 'mw'],
    "adharāt": ['ddsa', 'gra', 'mw'],
    "adharāttāt": ['gra', 'mw'],
    "adharāvalopa": ['mw'],
    "adharāñc": ['ddsa', 'mw'],
    "adharāṃc": ['ap90'],
    "adharībhū": ['ap90'],
    "adharībhūta": ['mw'],
    "adharīkṛ": ['ap90', 'ddsa'],
    "adharīkṛta": ['mw'],
    "adharīṇa": ['ap90', 'mw'],
    "adharṣaṇa": ['ddsa'],
    "adharṣaṇīya": ['ddsa'],
    "adharṣikatā": ['bhs'],
    "adhas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adhasakṣa": ['gra'],
    "adhaspada": ['cae', 'gra', 'mw'],
    "adhaspadam": ['mw'],
    "adhasta": ['bhs'],
    "adhastala": ['ddsa', 'mw'],
    "adhastamām": ['ap90'],
    "adhastana": ['ap90', 'mw'],
    "adhastarām": ['ap90', 'mw'],
    "adhastāddiś": ['mw'],
    "adhastāllakṣman": ['mw'],
    "adhastānnirbādham": ['mw'],
    "adhastānnābhi": ['mw'],
    "adhastāt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adhaupāsana": ['mw'],
    "adhauta": ['cae', 'ddsa'],
    "adhavā": ['ap90', 'mw'],
    "adhaīṣa": ['mw'],
    "adhaścara": ['mw'],
    "adhaścaraṇāvapāta": ['cae', 'ddsa'],
    "adhaūrdhvadigjñānāvabhāsa": ['bhs'],
    "adhaḥ": ['mw'],
    "adhaḥkara": ['mw'],
    "adhaḥkhanana": ['ddsa', 'mw'],
    "adhaḥkhāta": ['mw'],
    "adhaḥkriyā": ['ddsa', 'mw'],
    "adhaḥkumba": ['mw'],
    "adhaḥkāya": ['mw'],
    "adhaḥkṛta": ['mw'],
    "adhaḥkṛṣṇājinam": ['mw'],
    "adhaḥpadma": ['mw'],
    "adhaḥprastara": ['mw'],
    "adhaḥpravāha": ['mw'],
    "adhaḥprāṅśāyin": ['mw'],
    "adhaḥpuṣpī": ['mw'],
    "adhaḥpāta": ['ddsa', 'mw'],
    "adhaḥpātita": ['ddsa'],
    "adhaḥsaṃveśin": ['mw'],
    "adhaḥstha": ['cae', 'ddsa', 'mw'],
    "adhaḥsthita": ['mw'],
    "adhaḥsthānāsana": ['mw'],
    "adhaḥsvastika": ['mw'],
    "adhaḥśaya": ['cae', 'ddsa', 'mw'],
    "adhaḥśayya": ['cae', 'mw'],
    "adhaḥśayyā": ['cae', 'mw'],
    "adhaḥśiras": ['mw'],
    "adhaḥśākha": ['cae'],
    "adhaḥśāyin": ['cae', 'ddsa', 'mw'],
    "adhaḥśāyitā": ['mw'],
    "adhenu": ['cae', 'ddsa', 'gra', 'mw'],
    "adhenuḥ": ['ap90'],
    "adhi": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "adhibala": ['mw'],
    "adhibalaṃ": ['ap90'],
    "adhibhojana": ['gra', 'mw'],
    "adhibhojanaṃ": ['ap90'],
    "adhibhoti": ['cped'],
    "adhibhuj": ['mw'],
    "adhibhāṣati": ['bhs'],
    "adhibhū": ['cped', 'ddsa', 'mw'],
    "adhibhūta": ['cae', 'cped', 'ddsa', 'mw'],
    "adhibhūtam": ['mw'],
    "adhibhūtaṃ": ['ap90'],
    "adhibhūḥ": ['ap90'],
    "adhibrahma": ['cped'],
    "adhibrahman": ['cped'],
    "adhibrū": ['mw'],
    "adhibubhūṣu": ['ddsa'],
    "adhibādh": ['mw'],
    "adhibādhitṛ": ['ddsa'],
    "adhicar": ['ap90', 'mw'],
    "adhicara": ['mw'],
    "adhicaraṇa": ['mw'],
    "adhicaraṇaṃ": ['ap90'],
    "adhicaṅkrama": ['mw'],
    "adhicca": ['cped'],
    "adhiccasamuppanna": ['cped'],
    "adhiccasamuppannika": ['cped'],
    "adhiccāpattika": ['cped'],
    "adhiceta": ['cped'],
    "adhicetas": ['cped'],
    "adhici": ['mw'],
    "adhicitta": ['bhs'],
    "adhicittasikkhā": ['cped'],
    "adhicittaśikṣā": ['mw'],
    "adhicittaṁ": ['cped'],
    "adhicitte": ['cped'],
    "adhiciṇṇa": ['cped'],
    "adhidaiva": ['cae', 'ddsa', 'mw'],
    "adhidaivam": ['mw'],
    "adhidaivata": ['cae', 'mw'],
    "adhidaivatya": ['mw'],
    "adhidaivaṃ": ['ap90'],
    "adhidaivika": ['mw'],
    "adhidanta": ['mw'],
    "adhidaṃtaḥ": ['ap90'],
    "adhidaṃḍanetṛ": ['ap90'],
    "adhidaṇḍanetṛ": ['mw'],
    "adhideva": ['cae', 'cped', 'ddsa', 'mw'],
    "adhidevam": ['mw'],
    "adhidevana": ['mw'],
    "adhidevanaṃ": ['ap90'],
    "adhidevatam": ['mw'],
    "adhidevatā": ['mw'],
    "adhidevaḥ": ['ap90'],
    "adhidhā": ['mw'],
    "adhidhṛ": ['mw'],
    "adhidina": ['mw'],
    "adhidiś": ['mw'],
    "adhidru": ['mw'],
    "adhidyo": ['mw'],
    "adhidārva": ['ap90', 'mw'],
    "adhidīdhiti": ['ap90', 'ddsa', 'mw'],
    "adhigacchati": ['cped'],
    "adhigacchi": ['cped'],
    "adhigacchissaṁ": ['cped'],
    "adhigacchiṁ": ['cped'],
    "adhigam": ['ap90', 'mw'],
    "adhigama": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "adhigamana": ['bhs', 'mw'],
    "adhigamanīya": ['cped', 'mw'],
    "adhigamaḥ": ['ap90'],
    "adhigamissati": ['cped'],
    "adhigamma": ['cped'],
    "adhigamya": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhigantabba": ['cped'],
    "adhigantavya": ['cae', 'ddsa', 'mw'],
    "adhigantvā": ['cped'],
    "adhigantṛ": ['mw'],
    "adhigartia": ['gra'],
    "adhigartya": ['gra', 'mw'],
    "adhigata": ['ap90', 'cped', 'mw'],
    "adhigava": ['ap90', 'mw'],
    "adhigañchi": ['cped'],
    "adhigaṁ": ['cped'],
    "adhigaṃtṛ": ['ap90'],
    "adhigaṇ": ['mw'],
    "adhiggahetvā": ['cped'],
    "adhiggahita": ['cped'],
    "adhiggaṇhāti": ['cped'],
    "adhigopam": ['mw'],
    "adhigoptṛ": ['ddsa', 'mw'],
    "adhigrīvam": ['mw'],
    "adhigupta": ['cae', 'mw'],
    "adhiguṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhigā": ['cped', 'mw'],
    "adhigṛham": ['mw'],
    "adhihari": ['mw'],
    "adhihasti": ['ddsa', 'mw'],
    "adhihastya": ['mw'],
    "adhihu": ['mw'],
    "adhihṛ": ['mw'],
    "adhija": ['mw'],
    "adhijan": ['mw'],
    "adhijanana": ['cae', 'ddsa', 'mw'],
    "adhijananaṃ": ['ap90'],
    "adhijarāyu": ['mw'],
    "adhijaṅgham": ['mw'],
    "adhijegucchaṁ": ['cped'],
    "adhijegucche": ['cped'],
    "adhiji": ['mw'],
    "adhijigāṃsu": ['mw'],
    "adhijihva": ['mw'],
    "adhijihvaḥ": ['ap90'],
    "adhijihvikā": ['mw'],
    "adhijya": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhijyadhanvan": ['cae'],
    "adhijyakārmuka": ['cae'],
    "adhijyatā": ['ap90'],
    "adhijyotiṣam": ['mw'],
    "adhijāgṛ": ['mw'],
    "adhijānu": ['ddsa', 'mw'],
    "adhika": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "adhikadanta": ['mw'],
    "adhikadina": ['mw'],
    "adhikaguṇa": ['cae'],
    "adhikakṣayakārin": ['mw'],
    "adhikalpin": ['mw'],
    "adhikam": ['mw'],
    "adhikamāsa": ['mw'],
    "adhikamāṃsārman": ['mw'],
    "adhikandharam": ['ddsa', 'mw'],
    "adhikaraṇa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "adhikaraṇabhoja": ['cae'],
    "adhikaraṇabhojaka": ['cae', 'mw'],
    "adhikaraṇaitāvattva": ['mw'],
    "adhikaraṇakārika": ['cped'],
    "adhikaraṇalekhaka": ['mw'],
    "adhikaraṇamaṇḍapa": ['cae', 'mw'],
    "adhikaraṇamālā": ['mw'],
    "adhikaraṇasamatha": ['cped'],
    "adhikaraṇasiddhānta": ['mw'],
    "adhikaraṇaṃ": ['ap90'],
    "adhikaraṇika": ['cae', 'cped', 'mw'],
    "adhikaraṇikaḥ": ['ap90'],
    "adhikaraṇya": ['mw'],
    "adhikaraṇyaṃ": ['ap90'],
    "adhikarddhi": ['mw'],
    "adhikarmakara": ['mw'],
    "adhikarmakṛt": ['mw'],
    "adhikarmakṛta": ['mw'],
    "adhikarman": ['ap90', 'mw'],
    "adhikarmika": ['mw'],
    "adhikarmikaḥ": ['ap90'],
    "adhikarūpavat": ['ddsa'],
    "adhikarṇa": ['mw'],
    "adhikarṇam": ['ddsa', 'mw'],
    "adhikasatasahassa": ['cped'],
    "adhikasaṃvatsara": ['mw'],
    "adhikasāptatika": ['mw'],
    "adhikatithi": ['mw'],
    "adhikatva": ['mw'],
    "adhikatā": ['mw'],
    "adhikavayas": ['ddsa', 'mw'],
    "adhikavākyokti": ['mw'],
    "adhikaṇṭham": ['cae', 'mw'],
    "adhikaṣāṣṭika": ['mw'],
    "adhikaṣṭa": ['ddsa', 'mw'],
    "adhiketanam": ['ddsa', 'mw'],
    "adhikokti": ['ddsa'],
    "adhikopama": ['mw'],
    "adhikram": ['ap90', 'mw'],
    "adhikrama": ['mw'],
    "adhikramaḥ": ['ap90'],
    "adhikramaṇa": ['mw'],
    "adhikrīḍ": ['mw'],
    "adhikusala": ['cped'],
    "adhikuṭṭana": ['cped'],
    "adhikādhi": ['mw'],
    "adhikādhika": ['cae', 'mw'],
    "adhikākṣara": ['mw'],
    "adhikālam": ['bhs'],
    "adhikāma": ['ap90'],
    "adhikāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "adhikāraka": ['mw'],
    "adhikārapuruṣa": ['mw'],
    "adhikārasaṃgraha": ['mw'],
    "adhikārastha": ['mw'],
    "adhikāravat": ['mw'],
    "adhikāraḥ": ['ap90'],
    "adhikārika": ['bhs'],
    "adhikārin": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhikāritva": ['mw'],
    "adhikāritā": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhikārma": ['mw'],
    "adhikārtha": ['mw'],
    "adhikārthavacana": ['mw'],
    "adhikārāḍhya": ['mw'],
    "adhikāṅga": ['cae', 'ddsa', 'mw'],
    "adhikṛ": ['ap90', 'mw'],
    "adhikṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhikṛtatva": ['mw'],
    "adhikṛti": ['mw'],
    "adhikṛtiḥ": ['ap90'],
    "adhikṛtya": ['ap90', 'cae', 'mw'],
    "adhikṣepa": ['ddsa', 'mw'],
    "adhikṣepaḥ": ['ap90'],
    "adhikṣi": ['mw'],
    "adhikṣip": ['ap90', 'mw'],
    "adhikṣipadabjanetra": ['mw'],
    "adhikṣipta": ['mw'],
    "adhikṣit": ['ap90', 'gra', 'mw'],
    "adhikṣiti": ['mw'],
    "adhilavaṅgam": ['ddsa'],
    "adhilaya": ['bhs'],
    "adhilaṅkam": ['ddsa', 'mw'],
    "adhiloka": ['cae', 'ddsa'],
    "adhilokam": ['mw'],
    "adhilokanātha": ['mw'],
    "adhiluṭh": ['mw'],
    "adhimakham": ['mw'],
    "adhiman": ['mw'],
    "adhimana": ['cped'],
    "adhimanassa": ['cped'],
    "adhimantha": ['mw'],
    "adhimanthana": ['cae', 'ddsa', 'gra', 'mw'],
    "adhimanthita": ['mw'],
    "adhimanyati": ['bhs'],
    "adhimatta": ['cped'],
    "adhimattakasimāna": ['cped'],
    "adhimaṃthanaṃ": ['ap90'],
    "adhimaṃthaḥ": ['ap90'],
    "adhimaṃthita": ['ap90'],
    "adhimitra": ['mw'],
    "adhimitratā": ['mw'],
    "adhimoca": ['bhs'],
    "adhimoceti": ['cped'],
    "adhimocita": ['cped'],
    "adhimokkha": ['cped'],
    "adhimokṣa": ['bhs', 'mw'],
    "adhimokṣati": ['bhs'],
    "adhimuccamāna": ['cped'],
    "adhimuccati": ['cped'],
    "adhimucchita": ['cped'],
    "adhimucci": ['cped'],
    "adhimuccita": ['cped'],
    "adhimuccitar": ['cped'],
    "adhimuccitvā": ['cped'],
    "adhimucyanatā": ['bhs'],
    "adhimucyanā": ['bhs'],
    "adhimucyate": ['bhs'],
    "adhimuhya": ['mw'],
    "adhimuhyaḥ": ['ap90'],
    "adhimukta": ['bhs', 'mw'],
    "adhimuktaka": ['bhs'],
    "adhimukti": ['bhs', 'mw'],
    "adhimukticaryā": ['bhs'],
    "adhimuktika": ['bhs', 'mw'],
    "adhimuktikatā": ['bhs'],
    "adhimuktitejas": ['bhs'],
    "adhimuktiḥ": ['ap90'],
    "adhimutta": ['cped'],
    "adhimuttacitta": ['cped'],
    "adhimuṣyanti": ['bhs'],
    "adhimāna": ['bhs', 'cped'],
    "adhimānika": ['bhs', 'cped'],
    "adhimānin": ['bhs'],
    "adhimāsa": ['mw'],
    "adhimāsaḥ": ['ap90'],
    "adhimātra": ['ap90', 'ddsa', 'mw'],
    "adhimātrakāruṇika": ['bhs', 'mw'],
    "adhimātram": ['mw'],
    "adhimāṃsa": ['mw'],
    "adhimāṃsaka": ['mw'],
    "adhimāṃsakaḥ": ['ap90'],
    "adhimāṃsaḥ": ['ap90'],
    "adhimāṃsārman": ['mw'],
    "adhimūrchita": ['bhs'],
    "adhinam": ['mw'],
    "adhinidhā": ['mw'],
    "adhinirhan": ['mw'],
    "adhinirmuc": ['mw'],
    "adhinirṇij": ['ap90', 'gra', 'mw'],
    "adhinivas": ['mw'],
    "adhinivyadh": ['mw'],
    "adhiniśam": ['ddsa', 'mw'],
    "adhiniṣad": ['mw'],
    "adhinyas": ['mw'],
    "adhināgam": ['ddsa', 'mw'],
    "adhināmayati": ['bhs'],
    "adhinātha": ['mw'],
    "adhināthaḥ": ['ap90'],
    "adhināyaḥ": ['ap90'],
    "adhinī": ['ap90', 'mw'],
    "adhinṛt": ['mw'],
    "adhipa": ['cae', 'ddsa', 'mw'],
    "adhipajjati": ['cped'],
    "adhipanna": ['cped'],
    "adhipatati": ['cped'],
    "adhipatham": ['mw'],
    "adhipati": ['bhs', 'cae', 'cped', 'gra', 'mw'],
    "adhipatitvā": ['cped'],
    "adhipativatī": ['mw'],
    "adhipatiḥ": ['ap90'],
    "adhipatnī": ['ap90', 'mw'],
    "adhipatthita": ['cped'],
    "adhipatya": ['bhs'],
    "adhipauruṣa": ['ddsa'],
    "adhipaññāsikkhā": ['cped'],
    "adhipaññātti": ['cped'],
    "adhipaññāya": ['cped'],
    "adhipaññāṁ": ['cped'],
    "adhipaśya": ['mw'],
    "adhipaḥ": ['ap90'],
    "adhipeṣaṇa": ['cae', 'mw'],
    "adhipeṣaṇaṃ": ['ap90'],
    "adhippayāsa": ['cped'],
    "adhippeta": ['cped'],
    "adhippāya": ['cped'],
    "adhipradhāv": ['mw'],
    "adhipraja": ['ap90'],
    "adhiprajam": ['mw'],
    "adhiprajñam": ['mw'],
    "adhiprajñā": ['bhs'],
    "adhiprajñāśikṣā": ['mw'],
    "adhiprasū": ['mw'],
    "adhipraṣṭiyuga": ['mw'],
    "adhipraṣṭiyugaṃ": ['ap90'],
    "adhipurandhri": ['mw'],
    "adhipuruṣa": ['cae', 'ddsa', 'mw'],
    "adhipuruṣaḥ": ['ap90'],
    "adhipā": ['cae', 'gra', 'mw'],
    "adhipālayati": ['bhs'],
    "adhipāta": ['cped'],
    "adhipātaka": ['cped'],
    "adhipātetvā": ['cped'],
    "adhipāti": ['cped'],
    "adhipātikā": ['cped'],
    "adhipātimokkha": ['cped'],
    "adhipātimokkhe": ['cped'],
    "adhipātin": ['cped'],
    "adhipāśa": ['mw'],
    "adhipāḥ": ['ap90'],
    "adhipāṃsula": ['mw'],
    "adhipāṃśula": ['ap90', 'mw'],
    "adhipāṇi": ['mw'],
    "adhipūruṣa": ['cae', 'mw'],
    "adhipūruṣaḥ": ['ap90'],
    "adhipūtabhṛtam": ['mw'],
    "adhirajani": ['ddsa', 'mw'],
    "adhirajju": ['ap90', 'mw'],
    "adhiratha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adhirathyam": ['mw'],
    "adhiroha": ['ddsa', 'mw'],
    "adhirohaḥ": ['ap90'],
    "adhirohaṇa": ['cae', 'mw'],
    "adhirohaṇaṃ": ['ap90'],
    "adhirohaṇī": ['mw'],
    "adhirohin": ['ap90', 'ddsa', 'mw'],
    "adhirohiṇī": ['mw'],
    "adhiropayati": ['bhs'],
    "adhiropaṇa": ['cae', 'ddsa', 'mw'],
    "adhiropaṇaṃ": ['ap90'],
    "adhiropita": ['mw'],
    "adhiroḍhavya": ['ddsa', 'mw'],
    "adhiruh": ['ap90', 'ddsa', 'mw'],
    "adhirukma": ['ap90', 'gra', 'mw'],
    "adhirukmamandiragavākṣam": ['ddsa'],
    "adhirāj": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhirāja": ['cae', 'gra', 'mw'],
    "adhirājan": ['mw'],
    "adhirājya": ['cae', 'mw'],
    "adhirājyabhāj": ['mw'],
    "adhirājyaṃ": ['ap90'],
    "adhirāṣṭra": ['mw'],
    "adhirūḍha": ['ap90', 'cae', 'mw'],
    "adhirūḍhaka": ['bhs', 'mw'],
    "adhirūḍhasamādhiyoga": ['mw'],
    "adhirūḍhi": ['mw'],
    "adhirūḍhā": ['mw'],
    "adhirūḍhākarṇa": ['mw'],
    "adhisallikhati": ['cped'],
    "adhisaṃdhā": ['mw'],
    "adhisaṃvas": ['mw'],
    "adhisaṃvṛt": ['mw'],
    "adhisenāpati": ['ddsa', 'mw'],
    "adhiseti": ['cped'],
    "adhisevā": ['bhs'],
    "adhispardh": ['mw'],
    "adhispṛś": ['mw'],
    "adhisru": ['mw'],
    "adhisseti": ['cped'],
    "adhisthāna": ['bhs'],
    "adhistri": ['ap90', 'mw'],
    "adhistrī": ['mw'],
    "adhisyada": ['mw'],
    "adhisyaṃdaṃ": ['ap90'],
    "adhisīlasikkhā": ['cped'],
    "adhisīlaṁ": ['cped'],
    "adhisīle": ['cped'],
    "adhisṛp": ['mw'],
    "adhitalpam": ['ddsa'],
    "adhitanaya": ['bhs'],
    "adhitapta": ['bhs'],
    "adhitiṣṭhati": ['bhs', 'mw'],
    "adhitiṭṭhati": ['cped'],
    "adhityakā": ['ap90', 'ddsa', 'mw'],
    "adhivac": ['ap90', 'mw'],
    "adhivacana": ['bhs', 'cped', 'mw'],
    "adhivacanapatha": ['cped'],
    "adhivacanapraveśa": ['bhs'],
    "adhivacanaṃ": ['ap90'],
    "adhivad": ['mw'],
    "adhivaktṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adhivakṣas": ['ddsa', 'mw'],
    "adhivap": ['mw'],
    "adhivapana": ['ddsa'],
    "adhivarcas": ['ddsa', 'mw'],
    "adhivarjana": ['ddsa', 'mw'],
    "adhivartana": ['mw'],
    "adhivartati": ['bhs'],
    "adhivas": ['ap90', 'mw'],
    "adhivasati": ['ddsa', 'mw'],
    "adhivastra": ['ap90', 'gra', 'mw'],
    "adhivattati": ['cped'],
    "adhivattha": ['cped'],
    "adhivedam": ['mw'],
    "adhivedana": ['mw'],
    "adhivedanaṃ": ['ap90'],
    "adhivedanīyā": ['mw'],
    "adhivedaḥ": ['ap90'],
    "adhivedyā": ['cae', 'mw'],
    "adhivelam": ['ddsa', 'mw'],
    "adhivettavyā": ['cae', 'ddsa', 'mw'],
    "adhivettṛ": ['ap90', 'mw'],
    "adhiveśma": ['ddsa', 'mw'],
    "adhivid": ['ap90', 'mw'],
    "adhividhā": ['mw'],
    "adhividyam": ['mw'],
    "adhivijñāna": ['ddsa', 'mw'],
    "adhivikartana": ['gra', 'mw'],
    "adhivikartanaṃ": ['ap90'],
    "adhivikram": ['mw'],
    "adhivimutti": ['cped'],
    "adhivinna": ['ddsa'],
    "adhivinnā": ['ap90', 'cae', 'mw'],
    "adhivirāj": ['mw'],
    "adhivivuttipada": ['cped'],
    "adhivivāham": ['ddsa', 'mw'],
    "adhiviyat": ['mw'],
    "adhiviś": ['mw'],
    "adhiviśuddha": ['bhs'],
    "adhivrata": ['mw'],
    "adhivuttha": ['cped'],
    "adhivyatikrama": ['mw'],
    "adhivye": ['mw'],
    "adhivāda": ['cae', 'ddsa', 'mw'],
    "adhivāha": ['mw'],
    "adhivāhana": ['mw'],
    "adhivāhanaṃ": ['ap90'],
    "adhivāhi": ['cped'],
    "adhivāhin": ['cped'],
    "adhivājyakulādya": ['mw'],
    "adhivāka": ['cae', 'ddsa', 'gra', 'mw'],
    "adhivākaḥ": ['ap90'],
    "adhivās": ['ap90', 'mw'],
    "adhivāsa": ['bhs', 'cae', 'ddsa', 'mw'],
    "adhivāsabhūmi": ['mw'],
    "adhivāsakajātika": ['cped'],
    "adhivāsana": ['bhs', 'cae', 'cped', 'mw'],
    "adhivāsanaṃ": ['ap90'],
    "adhivāsanā": ['mw'],
    "adhivāsanīya": ['mw'],
    "adhivāsaya": ['cped'],
    "adhivāsayat": ['cped'],
    "adhivāsayati": ['bhs', 'cped'],
    "adhivāsaye": ['cped'],
    "adhivāsayeyya": ['cped'],
    "adhivāsaḥ": ['ap90'],
    "adhivāsenta": ['cped'],
    "adhivāsesi": ['cped'],
    "adhivāsesuṁ": ['cped'],
    "adhivāsetabba": ['cped'],
    "adhivāseyya": ['cped'],
    "adhivāsin": ['ap90', 'cae', 'mw'],
    "adhivāsita": ['ap90', 'mw'],
    "adhivāsitatā": ['bhs'],
    "adhivāsitā": ['mw'],
    "adhivīra": ['ddsa', 'mw'],
    "adhivīta": ['mw'],
    "adhivṛdh": ['mw'],
    "adhivṛj": ['mw'],
    "adhivṛkṣasūrye": ['mw'],
    "adhivṛt": ['mw'],
    "adhiyajña": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhiyajñam": ['mw'],
    "adhiyam": ['mw'],
    "adhiyat": ['mw'],
    "adhiyodhaḥ": ['ap90'],
    "adhiyoga": ['mw'],
    "adhiyogaḥ": ['ap90'],
    "adhiyuj": ['mw'],
    "adhiyyati": ['cped'],
    "adhiyā": ['mw'],
    "adhiyāṃga": ['ap90'],
    "adhiśasta": ['mw'],
    "adhiśaya": ['mw'],
    "adhiśayana": ['mw'],
    "adhiśayita": ['ap90', 'mw'],
    "adhiśiras": ['mw'],
    "adhiśirodharam": ['mw'],
    "adhiśraya": ['mw'],
    "adhiśrayaḥ": ['ap90'],
    "adhiśrayaṇa": ['mw'],
    "adhiśrayaṇaṃ": ['ap90'],
    "adhiśrayaṇī": ['mw'],
    "adhiśrayaṇīya": ['mw'],
    "adhiśri": ['ap90', 'mw'],
    "adhiśrita": ['cae', 'mw'],
    "adhiśrotram": ['ddsa', 'mw'],
    "adhiśrī": ['ap90', 'ddsa', 'mw'],
    "adhiśī": ['ap90', 'mw'],
    "adhiśīla": ['bhs'],
    "adhiśīlaśikṣā": ['mw'],
    "adhiḥ": ['ap90'],
    "adhiṣavaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "adhiṣavaṇaphalaka": ['mw'],
    "adhiṣavaṇaṃ": ['ap90'],
    "adhiṣavaṇia": ['gra'],
    "adhiṣavaṇya": ['gra', 'mw'],
    "adhiṣavaṇyā": ['ap90'],
    "adhiṣkand": ['mw'],
    "adhiṣkannā": ['mw'],
    "adhiṣu": ['mw'],
    "adhiṣvan": ['mw'],
    "adhiṣādam": ['mw'],
    "adhiṣṭa": ['bhs'],
    "adhiṣṭha": ['bhs'],
    "adhiṣṭhahati": ['bhs'],
    "adhiṣṭheya": ['mw'],
    "adhiṣṭhihati": ['bhs'],
    "adhiṣṭhita": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "adhiṣṭhā": ['ap90', 'mw'],
    "adhiṣṭhāna": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "adhiṣṭhānadeha": ['mw'],
    "adhiṣṭhānaka": ['bhs'],
    "adhiṣṭhānaśarīra": ['mw'],
    "adhiṣṭhānaṃ": ['ap90'],
    "adhiṣṭhātṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhiṣṭhāya": ['cae'],
    "adhiṣṭhāyaka": ['mw'],
    "adhiṣṭhāyika": ['bhs'],
    "adhiṭṭhaha": ['cped'],
    "adhiṭṭhahanta": ['cped'],
    "adhiṭṭhahat": ['cped'],
    "adhiṭṭhahati": ['cped'],
    "adhiṭṭhahi": ['cped'],
    "adhiṭṭhahitva": ['cped'],
    "adhiṭṭheti": ['cped'],
    "adhiṭṭhita": ['cped'],
    "adhiṭṭhāna": ['cped'],
    "adhiṭṭhātabba": ['cped'],
    "adhiṭṭhāti": ['cped'],
    "adhiṭṭhātuṁ": ['cped'],
    "adhiṭṭhāya": ['cped'],
    "adho": ['cped'],
    "adhoakṣa": ['cae', 'gra'],
    "adhobandhana": ['mw'],
    "adhobhakta": ['mw'],
    "adhobhava": ['mw'],
    "adhobhuvana": ['mw'],
    "adhobhāga": ['cae', 'cped', 'mw'],
    "adhobhāgadoṣahara": ['mw'],
    "adhobhāvaṅgamanīya": ['cped'],
    "adhobhūmi": ['mw'],
    "adhobāṇa": ['mw'],
    "adhodeśa": ['mw'],
    "adhodiś": ['mw'],
    "adhodvāra": ['mw'],
    "adhodāru": ['mw'],
    "adhodṛṣṭi": ['cae', 'mw'],
    "adhogama": ['mw'],
    "adhogamana": ['mw'],
    "adhogata": ['cae', 'ddsa', 'mw'],
    "adhogati": ['cae', 'mw'],
    "adhoghaṇṭā": ['mw'],
    "adhogāmin": ['mw'],
    "adhojihvikā": ['mw'],
    "adhojānu": ['mw'],
    "adhojānumaṇḍalami": ['cped'],
    "adhojānumaṇḍalamin": ['cped'],
    "adhokṣa": ['ap90', 'mw'],
    "adhokṣaja": ['mw'],
    "adhokṣam": ['mw'],
    "adhokṣeṇa": ['mw'],
    "adholamba": ['mw'],
    "adholoka": ['mw'],
    "adhomarman": ['mw'],
    "adhomayūkha": ['mw'],
    "adhomukha": ['cae', 'cped', 'mw'],
    "adhomukhaṁ": ['cped'],
    "adhomukhā": ['mw'],
    "adhonilaya": ['mw'],
    "adhonivīta": ['mw'],
    "adhonābham": ['mw'],
    "adhonābhi": ['mw'],
    "adhonābhiṁ": ['cped'],
    "adhonāpita": ['mw'],
    "adhonīvī": ['mw'],
    "adhopahāsa": ['mw'],
    "adhopahāsaḥ": ['ap90'],
    "adhopara": ['mw'],
    "adhoraktapitta": ['mw'],
    "adhorāma": ['mw'],
    "adhosira": ['cped'],
    "adhosrapitta": ['mw'],
    "adhovadana": ['mw'],
    "adhovarcas": ['mw'],
    "adhovaśa": ['mw'],
    "adhovekṣin": ['mw'],
    "adhovirecana": ['cped'],
    "adhovāsas": ['mw'],
    "adhovātaṁ": ['cped'],
    "adhovāte": ['cped'],
    "adhovāyu": ['mw'],
    "adhovāṇa": ['bhs'],
    "adhoyantra": ['mw'],
    "adhośuka": ['cae'],
    "adhośvam": ['mw'],
    "adhoṃśuka": ['mw'],
    "adhoṅga": ['mw'],
    "adho’kṣa": ['ddsa'],
    "adho’kṣaja": ['ddsa'],
    "adho’vekṣin": ['ddsa'],
    "adho’ṃśuka": ['ddsa'],
    "adhri": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adhrigu": ['cae', 'gra', 'mw'],
    "adhrija": ['gra', 'mw'],
    "adhripuṣpalikā": ['mw'],
    "adhriyamāṇa": ['ap90', 'mw'],
    "adhruva": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhruṣa": ['mw'],
    "adhruṣaḥ": ['ap90'],
    "adhunbhisita": ['cped'],
    "adhunā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "adhunāgata": ['cped'],
    "adhunātana": ['ap90', 'mw'],
    "adhunūpapanna": ['cped'],
    "adhura": ['ap90', 'mw'],
    "adhva": ['mw'],
    "adhvadarśin": ['mw'],
    "adhvaga": ['cae', 'gra', 'mw'],
    "adhvagabhogya": ['mw'],
    "adhvagacchat": ['mw'],
    "adhvagamana": ['mw'],
    "adhvagantavya": ['mw'],
    "adhvagat": ['mw'],
    "adhvagata": ['bhs'],
    "adhvagati": ['mw'],
    "adhvagatyanta": ['mw'],
    "adhvagaṇa": ['mw'],
    "adhvagā": ['mw'],
    "adhvagāmin": ['mw'],
    "adhvajā": ['mw'],
    "adhvakheda": ['ddsa'],
    "adhvaloṣṭa": ['mw'],
    "adhvamārga": ['bhs'],
    "adhvan": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "adhvanya": ['cae', 'ddsa', 'mw'],
    "adhvanīna": ['ap90', 'mw'],
    "adhvapa": ['ddsa'],
    "adhvapati": ['mw'],
    "adhvara": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adhvaradhiṣṇya": ['mw'],
    "adhvaradīkṣaṇīyā": ['mw'],
    "adhvaraga": ['mw'],
    "adhvaraguru": ['mw'],
    "adhvarakalpa": ['mw'],
    "adhvarakalpā": ['mw'],
    "adhvarakarman": ['mw'],
    "adhvarakāṇḍa": ['mw'],
    "adhvarakṛt": ['mw'],
    "adhvaraprāyaścitti": ['mw'],
    "adhvaras": ['mw'],
    "adhvarasamiṣṭayajus": ['mw'],
    "adhvarastha": ['mw'],
    "adhvaratha": ['mw'],
    "adhvaravat": ['mw'],
    "adhvaraśrī": ['cae', 'gra', 'mw'],
    "adhvareṣṭhā": ['cae', 'gra', 'mw'],
    "adhvartavya": ['mw'],
    "adhvary": ['gra'],
    "adhvarya": ['mw'],
    "adhvaryu": ['cae', 'ddsa', 'gra', 'mw'],
    "adhvaryukratu": ['mw'],
    "adhvaryukāṇḍa": ['mw'],
    "adhvaryupatha": ['mw'],
    "adhvaryupātra": ['mw'],
    "adhvaryuveda": ['mw'],
    "adhvaryuḥ": ['ap90'],
    "adhvarīy": ['cae', 'gra'],
    "adhvarīya": ['mw'],
    "adhvarīyati": ['ap90'],
    "adhvasaha": ['mw'],
    "adhvasman": ['ap90', 'cae', 'gra', 'mw'],
    "adhvaśalya": ['mw'],
    "adhvaśrama": ['ddsa', 'mw'],
    "adhvaśīla": ['mw'],
    "adhveśa": ['mw'],
    "adhvādhipa": ['ddsa', 'mw'],
    "adhvāna": ['mw'],
    "adhvānta": ['mw'],
    "adhvāntaśātrava": ['mw'],
    "adhvānīya": ['bhs'],
    "adhvāpanna": ['mw'],
    "adhvāṃtaṃ": ['ap90'],
    "adhyabhāṣati": ['bhs'],
    "adhyadhi": ['ap90', 'mw'],
    "adhyadhikṣepa": ['ddsa', 'mw'],
    "adhyadhikṣepaḥ": ['ap90'],
    "adhyadhvam": ['ddsa', 'mw'],
    "adhyadhīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhyagni": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhyagnyupāgata": ['mw'],
    "adhyagnīkṛta": ['mw'],
    "adhyah": ['mw'],
    "adhyakta": ['mw'],
    "adhyakṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adhyakṣaram": ['mw'],
    "adhyakṣaraṃ": ['ap90'],
    "adhyantena": ['cae', 'ddsa', 'mw'],
    "adhyapavic": ['mw'],
    "adhyarbuda": ['mw'],
    "adhyarbudaṃ": ['ap90'],
    "adhyardha": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhyardhaka": ['mw'],
    "adhyardhakaṃsa": ['mw'],
    "adhyardhakhārīka": ['mw'],
    "adhyardhakākiṇīka": ['mw'],
    "adhyardhakārṣāpaṇa": ['mw'],
    "adhyardhakārṣāpaṇika": ['mw'],
    "adhyardhamāṣya": ['mw'],
    "adhyardhapaṇya": ['mw'],
    "adhyardhapratika": ['mw'],
    "adhyardhapādya": ['mw'],
    "adhyardhasahasra": ['mw'],
    "adhyardhasauvarṇika": ['mw'],
    "adhyardhasuvarṇa": ['mw'],
    "adhyardhasāhasra": ['mw'],
    "adhyardhaviṃśatikīna": ['mw'],
    "adhyardhaśata": ['mw'],
    "adhyardhaśataka": ['bhs'],
    "adhyardhaśatamāna": ['mw'],
    "adhyardhaśatya": ['mw'],
    "adhyardhaśātamāna": ['mw'],
    "adhyardhaśāṇa": ['mw'],
    "adhyardhaśāṇya": ['mw'],
    "adhyardhaśūrpa": ['mw'],
    "adhyardhopā": ['mw'],
    "adhyarvuda": ['mw'],
    "adhyas": ['ap90', 'mw'],
    "adhyasta": ['ap90', 'mw'],
    "adhyastha": ['mw'],
    "adhyasthi": ['ap90', 'mw'],
    "adhyavagacchati": ['bhs'],
    "adhyavahan": ['mw'],
    "adhyavahanana": ['cae', 'mw'],
    "adhyavahananaṃ": ['ap90'],
    "adhyavakirati": ['bhs'],
    "adhyavaruh": ['mw'],
    "adhyavaseya": ['mw'],
    "adhyavasita": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "adhyavasiti": ['mw'],
    "adhyavaso": ['ap90', 'mw'],
    "adhyavasyati": ['bhs'],
    "adhyavasāna": ['bhs', 'cae', 'ddsa', 'mw'],
    "adhyavasānaṃ": ['ap90'],
    "adhyavasāya": ['bhs', 'mw'],
    "adhyavasāyayukta": ['mw'],
    "adhyavasāyaḥ": ['ap90'],
    "adhyavasāyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhyavasāyita": ['ddsa', 'mw'],
    "adhyaya": ['ap90'],
    "adhyayana": ['cae', 'ddsa', 'mw'],
    "adhyayanapuṇya": ['mw'],
    "adhyayanasaṃvṛtti": ['mw'],
    "adhyayanatapasī": ['mw'],
    "adhyayanaṃ": ['ap90'],
    "adhyayanādāna": ['cae'],
    "adhyayanīya": ['mw'],
    "adhyayaḥ": ['ap90'],
    "adhyayitā": ['bhs'],
    "adhyañc": ['mw'],
    "adhyaśana": ['mw'],
    "adhyaśanaṃ": ['ap90'],
    "adhyaṃc": ['ap90'],
    "adhyaṃsa": ['ddsa', 'mw'],
    "adhyaṃḍā": ['ap90'],
    "adhyaṇḍā": ['mw'],
    "adhyedh": ['mw'],
    "adhyetavya": ['ddsa', 'mw'],
    "adhyetṛ": ['ap90', 'mw'],
    "adhyeya": ['cae', 'mw'],
    "adhyeṣaka": ['bhs'],
    "adhyeṣati": ['bhs'],
    "adhyeṣaṇa": ['bhs', 'ddsa', 'mw'],
    "adhyeṣaṇaṃ": ['ap90'],
    "adhyeṣyamāṇa": ['mw'],
    "adhyeṣā": ['bhs'],
    "adhyeṣṭa": ['bhs'],
    "adhyo": ['bhs'],
    "adhyoharati": ['bhs'],
    "adhyoḍha": ['mw'],
    "adhyudbhṛ": ['mw'],
    "adhyuddhi": ['mw'],
    "adhyuddhṛ": ['mw'],
    "adhyudyam": ['mw'],
    "adhyupekṣ": ['mw'],
    "adhyupekṣati": ['bhs'],
    "adhyupekṣaṇa": ['bhs'],
    "adhyupekṣā": ['bhs', 'mw'],
    "adhyuras": ['ddsa', 'mw'],
    "adhyutthā": ['mw'],
    "adhyuṣa": ['mw'],
    "adhyuṣita": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhyuṣite": ['mw'],
    "adhyuṣṭa": ['ap90', 'bhs', 'mw'],
    "adhyuṣṭavalaya": ['mw'],
    "adhyuṣṭra": ['mw'],
    "adhyuṣṭraḥ": ['ap90'],
    "adhyābhṛ": ['mw'],
    "adhyācar": ['mw'],
    "adhyācara": ['bhs'],
    "adhyācarati": ['bhs'],
    "adhyācaraṇa": ['bhs'],
    "adhyācāra": ['bhs', 'ddsa', 'mw'],
    "adhyādhā": ['mw'],
    "adhyāgacchati": ['bhs'],
    "adhyāgam": ['mw'],
    "adhyāharaṇa": ['mw'],
    "adhyāharaṇīya": ['mw'],
    "adhyāhartavya": ['mw'],
    "adhyāhāra": ['ddsa', 'mw'],
    "adhyāhāraḥ": ['ap90'],
    "adhyāhāriṇī": ['mw'],
    "adhyāhāriṇīlipi": ['bhs'],
    "adhyāhārya": ['ddsa'],
    "adhyāhṛta": ['mw'],
    "adhyājya": ['mw'],
    "adhyākram": ['ap90', 'mw'],
    "adhyākramaṇa": ['bhs', 'mw'],
    "adhyākrānta": ['cae'],
    "adhyākrāṃta": ['ap90'],
    "adhyākāśam": ['ddsa', 'mw'],
    "adhyālamba": ['bhs'],
    "adhyālambana": ['bhs'],
    "adhyālambanatā": ['bhs'],
    "adhyālambate": ['bhs'],
    "adhyālambati": ['bhs'],
    "adhyāpadyate": ['bhs'],
    "adhyāpaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhyāpakaḥ": ['ap90'],
    "adhyāpakodita": ['mw'],
    "adhyāpana": ['cae', 'ddsa', 'mw'],
    "adhyāpanaṃ": ['ap90'],
    "adhyāpatti": ['bhs'],
    "adhyāpaya": ['ddsa'],
    "adhyāpayitṛ": ['ap90', 'mw'],
    "adhyāpaṭyati": ['bhs'],
    "adhyāpita": ['mw'],
    "adhyāpya": ['cae', 'ddsa', 'mw'],
    "adhyārohati": ['bhs'],
    "adhyārohaṇa": ['mw'],
    "adhyāropa": ['cae', 'ddsa', 'mw'],
    "adhyāropaḥ": ['ap90'],
    "adhyāropaṇa": ['mw'],
    "adhyāropaṇaṃ": ['ap90'],
    "adhyāropita": ['ap90', 'mw'],
    "adhyāruh": ['ap90', 'mw'],
    "adhyārāma": ['bhs'],
    "adhyārūḍha": ['ap90', 'mw'],
    "adhyās": ['ap90', 'mw'],
    "adhyāsa": ['cae', 'ddsa', 'mw'],
    "adhyāsad": ['mw'],
    "adhyāsana": ['mw'],
    "adhyāsanaṃ": ['ap90'],
    "adhyāsañj": ['mw'],
    "adhyāsaḥ": ['ap90'],
    "adhyāsin": ['ddsa', 'mw'],
    "adhyāsita": ['cae', 'ddsa', 'mw'],
    "adhyāsitavya": ['ddsa'],
    "adhyāsyā": ['mw'],
    "adhyāsīna": ['mw'],
    "adhyātma": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhyātmacetas": ['cae', 'mw'],
    "adhyātmacintāmaṇi": ['mw'],
    "adhyātmadṛś": ['mw'],
    "adhyātmajñāna": ['mw'],
    "adhyātmam": ['mw'],
    "adhyātmarati": ['cae', 'mw'],
    "adhyātmarāmāyaṇa": ['mw'],
    "adhyātmavid": ['mw'],
    "adhyātmavidyā": ['mw'],
    "adhyātmaśāstra": ['mw'],
    "adhyātmika": ['ap90', 'cae', 'mw'],
    "adhyātmottarakāṇḍa": ['mw'],
    "adhyāvap": ['mw'],
    "adhyāvara": ['bhs'],
    "adhyāvas": ['mw'],
    "adhyāviśati": ['bhs'],
    "adhyāvāhanika": ['cae', 'ddsa', 'mw'],
    "adhyāvāhanikaṃ": ['ap90'],
    "adhyāvāpa": ['mw'],
    "adhyāvāpaḥ": ['ap90'],
    "adhyāvāsagata": ['bhs'],
    "adhyāya": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhyāyaśatapāṭha": ['mw'],
    "adhyāyin": ['ap90', 'mw'],
    "adhyāyopākarman": ['mw'],
    "adhyāśana": ['bhs'],
    "adhyāśaya": ['bhs', 'mw'],
    "adhyāśayana": ['bhs'],
    "adhyāśayasaṃcodanasūtra": ['bhs'],
    "adhyāśayati": ['bhs'],
    "adhyāṇḍā": ['ddsa', 'mw'],
    "adhyūdhnī": ['ap90', 'mw'],
    "adhyūh": ['ap90', 'mw'],
    "adhyūhana": ['mw'],
    "adhyūhanaṃ": ['ap90'],
    "adhyūḍha": ['ap90', 'ddsa', 'mw'],
    "adhyūḍhaja": ['mw'],
    "adhyūḍhā": ['mw'],
    "adhyūṣivas": ['mw'],
    "adhyṛdh": ['mw'],
    "adhā": ['cae', 'mw'],
    "adhāmārgava": ['mw'],
    "adhāmārgavaḥ": ['ap90'],
    "adhārayamāṇa": ['mw'],
    "adhāraṇaka": ['ap90', 'ddsa', 'mw'],
    "adhārmika": ['cae', 'ddsa', 'mw'],
    "adhārya": ['cae', 'ddsa', 'mw'],
    "adhārāgraha": ['mw'],
    "adhārāvarṣa": ['ddsa'],
    "adhāsanaśāyin": ['mw'],
    "adhī": ['ap90', 'mw'],
    "adhīk": ['ddsa'],
    "adhīkāra": ['cae', 'ddsa', 'mw'],
    "adhīkāraḥ": ['ap90'],
    "adhīkṣ": ['mw'],
    "adhīkṣepa": ['mw'],
    "adhīlohakarṇa": ['mw'],
    "adhīmantha": ['mw'],
    "adhīmaṃtha": ['ap90'],
    "adhīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhīnatva": ['mw'],
    "adhīnatā": ['mw'],
    "adhīra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adhīram": ['ddsa'],
    "adhīratā": ['mw'],
    "adhīrā": ['mw'],
    "adhīrākṣa": ['cae', 'ddsa'],
    "adhīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhītarasa": ['mw'],
    "adhītaveda": ['mw'],
    "adhīti": ['cae', 'ddsa', 'gra', 'mw'],
    "adhītin": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhītiḥ": ['ap90'],
    "adhītya": ['mw'],
    "adhīvāsa": ['ddsa', 'gra', 'mw'],
    "adhīvāsas": ['mw'],
    "adhīvāsaḥ": ['ap90'],
    "adhīyamāna": ['cped'],
    "adhīyanta": ['cped'],
    "adhīyat": ['mw'],
    "adhīyitvā": ['cped'],
    "adhīyāna": ['mw'],
    "adhīyānaḥ": ['ap90'],
    "adhīśa": ['cae', 'ddsa', 'mw'],
    "adhīśaḥ": ['ap90'],
    "adhīśitṛ": ['ddsa', 'mw'],
    "adhīśvara": ['mw'],
    "adhīśvaraḥ": ['ap90'],
    "adhīṣ": ['mw'],
    "adhīṣṭa": ['ap90', 'bhs', 'mw'],
    "adhūmaka": ['cae', 'mw'],
    "adhūmakaḥ": ['ap90'],
    "adhūnvat": ['mw'],
    "adhṛta": ['ap90', 'mw'],
    "adhṛti": ['cae', 'ddsa', 'mw'],
    "adhṛtiḥ": ['ap90'],
    "adhṛṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "adhṛṣyā": ['mw'],
    "adhṛṣṭa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adikka": ['ap90', 'mw'],
    "adinna": ['bhs'],
    "adinnādāna": ['bhs'],
    "adiprabhṛti": ['ddsa', 'mw'],
    "adipsat": ['mw'],
    "aditi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aditija": ['mw'],
    "aditikuṇḍalāharaṇa": ['mw'],
    "aditinandana": ['mw'],
    "adititva": ['gra', 'mw'],
    "aditsant": ['cae'],
    "aditsat": ['ddsa', 'gra', 'mw'],
    "aditsu": ['cae', 'ddsa', 'mw'],
    "adivā": ['mw'],
    "adivāsvāpin": ['mw'],
    "adivāśin": ['mw'],
    "adma": ['mw'],
    "adman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "admani": ['mw'],
    "admaniḥ": ['ap90'],
    "admara": ['ap90', 'mw'],
    "admasad": ['cae', 'ddsa', 'gra', 'mw'],
    "admasadvan": ['gra', 'mw'],
    "admasadya": ['gra', 'mw'],
    "adobhavati": ['mw'],
    "adogdhṛ": ['ap90', 'mw'],
    "adoha": ['mw'],
    "adohaḥ": ['ap90'],
    "adomada": ['ap90', 'mw'],
    "adomadha": ['mw'],
    "adomaya": ['mw'],
    "adomūla": ['mw'],
    "adoṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "adoṣadarśin": ['mw'],
    "adoṣajña": ['cae'],
    "adoṣavant": ['cae'],
    "adrava": ['ap90', 'mw'],
    "adravya": ['cae', 'ddsa', 'mw'],
    "adravyaṃ": ['ap90'],
    "adreśya": ['ap90', 'mw'],
    "adri": ['cae', 'ddsa', 'gra', 'mw'],
    "adribarhas": ['gra', 'mw'],
    "adribhedana": ['mw'],
    "adribhid": ['gra', 'mw'],
    "adribhū": ['mw'],
    "adribudhna": ['cae', 'gra', 'mw'],
    "adridhṛt": ['mw'],
    "adridugdha": ['cae', 'gra', 'mw'],
    "adridviṣ": ['mw'],
    "adrija": ['mw'],
    "adrijā": ['cae', 'gra', 'mw'],
    "adrijūta": ['gra', 'mw'],
    "adrikarṇī": ['mw'],
    "adrikā": ['mw'],
    "adrikīlā": ['mw'],
    "adrikṛtasthalī": ['mw'],
    "adrimātṛ": ['gra', 'mw'],
    "adrimūrdhan": ['mw'],
    "adrinandinī": ['mw'],
    "adripati": ['mw'],
    "adrirāj": ['mw'],
    "adrirāja": ['mw'],
    "adrisaṃhata": ['gra', 'mw'],
    "adrisānu": ['gra', 'mw'],
    "adrisāra": ['mw'],
    "adrisāramaya": ['mw'],
    "adritanayā": ['mw'],
    "adrivahni": ['mw'],
    "adrivant": ['cae'],
    "adrivat": ['ap90', 'ddsa', 'gra', 'mw'],
    "adriśayya": ['mw'],
    "adriśṛṅga": ['mw'],
    "adriḥ": ['ap90'],
    "adriṣuta": ['gra', 'mw'],
    "adrogha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adrogham": ['mw'],
    "adroghavāc": ['cae', 'gra', 'mw'],
    "adroghāvita": ['mw'],
    "adroha": ['cae', 'ddsa', 'mw'],
    "adrohacetas": ['cae'],
    "adrohavṛtti": ['mw'],
    "adrohaḥ": ['ap90'],
    "adrohin": ['mw'],
    "adruh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adruhvan": ['gra', 'mw'],
    "adruhāṇa": ['mw'],
    "adruta": ['mw'],
    "adrutalipi": ['bhs'],
    "adrākṣaṇīya": ['bhs'],
    "adrīndra": ['mw'],
    "adrīśa": ['mw'],
    "aducchuna": ['ap90', 'mw'],
    "aduchuna": ['gra'],
    "adugdha": ['gra', 'mw'],
    "aduhāna": ['mw'],
    "aduka": ['bhs'],
    "adurga": ['ap90', 'ddsa', 'mw'],
    "adurgaviṣaya": ['mw'],
    "adurmakha": ['gra', 'mw'],
    "adurmaṅgala": ['ddsa', 'gra', 'mw'],
    "adurmukha": ['ap90'],
    "adurvṛtta": ['ddsa', 'mw'],
    "adurāgata": ['cped'],
    "aduḥkha": ['ap90', 'mw'],
    "aduḥkhanavamī": ['mw'],
    "aduḥkhasukhavedanā": ['mw'],
    "aduṣkṛt": ['gra', 'mw'],
    "aduṣprāpa": ['cae', 'ddsa'],
    "aduṣṭa": ['cae', 'ddsa', 'mw'],
    "aduṣṭatva": ['cae', 'mw'],
    "advaidha": ['ddsa', 'mw'],
    "advaita": ['ap90', 'cae', 'ddsa', 'mw'],
    "advaitabrahmasiddhi": ['mw'],
    "advaitadīpikā": ['mw'],
    "advaitamakaranda": ['mw'],
    "advaitavādin": ['mw'],
    "advaitena": ['mw'],
    "advaitin": ['mw'],
    "advaitopaniṣad": ['mw'],
    "advaitānanda": ['mw'],
    "advan": ['gra', 'mw'],
    "advaya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "advayant": ['cae'],
    "advayas": ['cae', 'gra', 'mw'],
    "advayat": ['ap90', 'gra', 'mw'],
    "advayatva": ['cae'],
    "advayavajra": ['bhs'],
    "advayavāda": ['mw'],
    "advayavādin": ['bhs', 'mw'],
    "advayu": ['ap90', 'cae', 'gra', 'mw'],
    "advayānanda": ['cae', 'mw'],
    "advayāvin": ['ap90', 'cae', 'gra', 'mw'],
    "advaṃdva": ['ap90'],
    "adveṣa": ['ap90', 'gra', 'mw'],
    "adveṣarāgin": ['cae', 'ddsa', 'mw'],
    "adveṣas": ['ap90', 'cae', 'gra', 'mw'],
    "adveṣin": ['mw'],
    "adveṣṭṛ": ['cae', 'ddsa', 'mw'],
    "advija": ['cae', 'mw'],
    "advitīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "advivarṣa": ['ddsa', 'mw'],
    "adviyoni": ['mw'],
    "adviṣeṇia": ['gra'],
    "adviṣeṇya": ['ap90', 'gra', 'mw'],
    "advādaśāha": ['mw'],
    "advār": ['cae', 'mw'],
    "advāra": ['cae', 'mw'],
    "advāraṃ": ['ap90'],
    "advīpa": ['mw'],
    "adya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adyadina": ['ddsa', 'mw'],
    "adyadiva": ['cae'],
    "adyadivasa": ['ddsa', 'mw'],
    "adyaiva": ['mw'],
    "adyaprabhṛti": ['mw'],
    "adyapūrvam": ['mw'],
    "adyasutyā": ['mw'],
    "adyatana": ['ap90', 'cae', 'ddsa', 'mw'],
    "adyatanabhūta": ['mw'],
    "adyatanī": ['mw'],
    "adyatanīya": ['ap90', 'mw'],
    "adyatas": ['mw'],
    "adyatva": ['mw'],
    "adyatve": ['bhs'],
    "adyaut": ['ddsa'],
    "adyayajña": ['mw'],
    "adyaśva": ['mw'],
    "adyaśvīna": ['mw'],
    "adyaśvīnā": ['mw'],
    "adyotaka": ['mw'],
    "adyu": ['ap90', 'gra', 'mw'],
    "adyut": ['ap90', 'gra', 'mw'],
    "adyā": ['cae'],
    "adyādagre": ['bhs'],
    "adyāgre": ['bhs'],
    "adyāgreṇa": ['mw'],
    "adyāpi": ['mw'],
    "adyāvadhi": ['mw'],
    "adyāśva": ['mw'],
    "adyūtia": ['gra'],
    "adyūtya": ['ap90', 'gra', 'mw'],
    "adābhia": ['gra'],
    "adābhya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adādi": ['ap90', 'mw'],
    "adāditva": ['ddsa'],
    "adāhuka": ['mw'],
    "adāhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "adākṣiṇya": ['ddsa', 'mw'],
    "adākṣiṇātya": ['mw'],
    "adāman": ['ap90', 'gra', 'mw'],
    "adāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "adānava": ['cae', 'mw'],
    "adānta": ['mw'],
    "adāntadamaka": ['bhs'],
    "adānya": ['ap90', 'mw'],
    "adānīya": ['mw'],
    "adāra": ['mw'],
    "adārasṛt": ['mw'],
    "adāraḥ": ['ap90'],
    "adāruṇa": ['cae', 'ddsa'],
    "adāsa": ['cae', 'ddsa', 'mw'],
    "adāsaḥ": ['ap90'],
    "adāsyat": ['mw'],
    "adātṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "adāya": ['ap90'],
    "adāyika": ['ap90', 'mw'],
    "adāyin": ['ap90', 'mw'],
    "adāyāda": ['ap90', 'cae', 'ddsa', 'mw'],
    "adāśu": ['ap90', 'gra', 'mw'],
    "adāśuri": ['ap90', 'gra', 'mw'],
    "adāśvas": ['ap90', 'gra', 'mw'],
    "adīkṣita": ['mw'],
    "adīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "adīnagāmin": ['bhs'],
    "adīnagātratā": ['mw'],
    "adīnakusuma": ['bhs'],
    "adīnamanas": ['cae'],
    "adīnasattva": ['cae', 'mw'],
    "adīnātman": ['cae', 'mw'],
    "adīpita": ['mw'],
    "adīrgha": ['ap90', 'cae', 'ddsa', 'mw'],
    "adīrghadarśin": ['mw'],
    "adīrghasūtra": ['mw'],
    "adīyamāna": ['cae', 'ddsa'],
    "adū": ['ap90', 'gra', 'mw'],
    "adūna": ['cae', 'ddsa', 'mw'],
    "adūra": ['ap90', 'cae', 'ddsa', 'mw'],
    "adūrabhava": ['mw'],
    "adūratas": ['mw'],
    "adūre": ['mw'],
    "adūrāt": ['mw'],
    "adūṣaṇa": ['ddsa'],
    "adūṣin": ['bhs'],
    "adūṣita": ['ap90', 'cae', 'ddsa', 'mw'],
    "adūṣitadhī": ['mw'],
    "adṛpita": ['cae', 'ddsa', 'gra', 'mw'],
    "adṛpta": ['ap90', 'cae', 'gra', 'mw'],
    "adṛptakratu": ['gra', 'mw'],
    "adṛpyat": ['gra', 'mw'],
    "adṛś": ['ap90', 'mw'],
    "adṛśya": ['ap90', 'cae', 'ddsa', 'mw'],
    "adṛśyakaraṇa": ['mw'],
    "adṛśyamāna": ['cae'],
    "adṛśyat": ['mw'],
    "adṛśyatī": ['mw'],
    "adṛśyā": ['bhs'],
    "adṛḍha": ['cae', 'ddsa', 'mw'],
    "adṛṣṭa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "adṛṣṭahan": ['gra', 'mw'],
    "adṛṣṭaja": ['mw'],
    "adṛṣṭakarman": ['mw'],
    "adṛṣṭakāma": ['mw'],
    "adṛṣṭanara": ['mw'],
    "adṛṣṭaparasāmarthya": ['mw'],
    "adṛṣṭaphala": ['mw'],
    "adṛṣṭapuruṣa": ['mw'],
    "adṛṣṭapūrva": ['cae', 'mw'],
    "adṛṣṭarūpa": ['mw'],
    "adṛṣṭavat": ['mw'],
    "adṛṣṭi": ['mw'],
    "adṛṣṭidāna": ['ddsa'],
    "adṛṣṭikā": ['mw'],
    "adṛṣṭiḥ": ['ap90'],
    "adṛṣṭvā": ['cae', 'ddsa'],
    "adṛṣṭārtha": ['mw'],
    "adṛṣṭāśrutapūrvatva": ['mw'],
    "ag": ['ap90', 'mw'],
    "aga": ['ap90', 'cae', 'ddsa', 'mw'],
    "agaccha": ['ap90', 'mw'],
    "agada": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "agadaveda": ['mw'],
    "agadaṃkāra": ['mw'],
    "agadaṃkāraḥ": ['ap90'],
    "agadaṅgāra": ['cped'],
    "agadita": ['ddsa', 'mw'],
    "agadya": ['mw'],
    "agadyati": ['ap90'],
    "agaja": ['mw'],
    "agajā": ['mw'],
    "agalita": ['bhs'],
    "agama": ['ap90', 'cae', 'ddsa', 'mw'],
    "agamya": ['ap90', 'cae', 'ddsa', 'mw'],
    "agamyagā": ['mw'],
    "agamyarūpa": ['ddsa', 'mw'],
    "agamyā": ['ap90', 'mw'],
    "agamyāgamana": ['cae', 'ddsa', 'mw'],
    "agamyāgamanīya": ['mw'],
    "agamyāgāmin": ['mw'],
    "agan": ['ddsa'],
    "agandha": ['cae', 'ddsa', 'mw'],
    "agandhaka": ['cped'],
    "agandhasevin": ['mw'],
    "agandhavant": ['cae'],
    "agandhi": ['mw'],
    "agandhin": ['mw'],
    "agarbha": ['mw'],
    "agarbhā": ['mw'],
    "agarhita": ['cae', 'ddsa', 'mw'],
    "agariyabhūta": ['cped'],
    "agartamit": ['mw'],
    "agartaskandya": ['mw'],
    "agaru": ['ap90', 'cped', 'mw'],
    "agarva": ['ddsa', 'mw'],
    "agarī": ['ap90', 'mw'],
    "agasmahi": ['ddsa'],
    "agasti": ['ap90', 'cae', 'ddsa', 'mw'],
    "agastia": ['gra'],
    "agastidru": ['mw'],
    "agastiharītakī": ['bhs'],
    "agastya": ['cae', 'ddsa', 'gra', 'mw'],
    "agastyacāra": ['mw'],
    "agastyagītā": ['mw'],
    "agastyagṛhaspatika": ['mw'],
    "agastyamārga": ['mw'],
    "agastyasaṃhitā": ['mw'],
    "agastyaśāsta": ['mw'],
    "agastyaḥ": ['ap90'],
    "agastyodaya": ['mw'],
    "agastī": ['ap90', 'mw'],
    "agastīya": ['mw'],
    "agata": ['cae', 'mw'],
    "agati": ['ddsa', 'mw'],
    "agatika": ['ap90', 'bhs', 'ddsa', 'mw'],
    "agatikagati": ['mw'],
    "agatiḥ": ['ap90'],
    "agatyā": ['mw'],
    "agatāsu": ['cae', 'mw'],
    "agatīka": ['ap90', 'mw'],
    "agaukas": ['mw'],
    "agava": ['bhs'],
    "agavyūti": ['ap90', 'gra', 'mw'],
    "agaṇanīya": ['bhs'],
    "agaṇanīyaparivarta": ['bhs'],
    "agaṇayant": ['cae'],
    "agaṇayat": ['ddsa'],
    "agaṇeya": ['bhs', 'ddsa'],
    "agaṇeyaparivarta": ['bhs'],
    "agaṇhanta": ['cped'],
    "agaṇita": ['mw'],
    "agaṇitalajja": ['mw'],
    "agaṇitapratiyāta": ['ddsa', 'mw'],
    "agaṇiya": ['bhs'],
    "agaṇya": ['ap90', 'bhs', 'ddsa'],
    "agdhād": ['mw'],
    "agga": ['cped'],
    "agga-m-agga": ['cped'],
    "aggabīja": ['cped'],
    "aggadana": ['cped'],
    "aggadhamma": ['cped'],
    "aggadvāra": ['cped'],
    "aggahesi": ['cped'],
    "aggahesiṁ": ['cped'],
    "aggahesum": ['cped'],
    "aggahetvā": ['cped'],
    "aggahīta": ['cped'],
    "aggakulika": ['cped'],
    "aggakārikā": ['cped'],
    "aggala": ['cped'],
    "aggalaphalaka": ['cped'],
    "aggalasūci": ['cped'],
    "aggalavaṭṭi": ['cped'],
    "aggalaṭṭhapana": ['cped'],
    "agganagara": ['cped'],
    "agganakha": ['cped'],
    "aggapada": ['cped'],
    "aggapasāda": ['cped'],
    "aggapaññati": ['cped'],
    "aggapiṇḍa": ['cped'],
    "aggappasāda": ['cped'],
    "aggapuggala": ['cped'],
    "aggapurisa": ['cped'],
    "aggarasaparititta": ['cped'],
    "aggasavaka": ['cped'],
    "aggato": ['cped'],
    "aggatā": ['cped'],
    "aggava": ['cped'],
    "aggavat": ['cped'],
    "aggavādi": ['cped'],
    "aggavādin": ['cped'],
    "aggañña": ['cped'],
    "aggaḷa": ['cped'],
    "aggaṅkuraka": ['cped'],
    "aggha": ['cped'],
    "agghanaka": ['cped'],
    "agghanikā": ['cped'],
    "agghati": ['cped'],
    "agghāpenta": ['cped'],
    "agghāpesi": ['cped'],
    "aggi": ['cped'],
    "aggi-m-āsīna": ['cped'],
    "aggihoma": ['cped'],
    "aggihutta": ['cped'],
    "aggihuttamissa": ['cped'],
    "aggihuttamukha": ['cped'],
    "aggika": ['cped'],
    "aggikkhandha": ['cped'],
    "agginisama": ['cped'],
    "aggipajjota": ['cped'],
    "aggiparicitta": ['cped'],
    "aggiparijita": ['cped'],
    "aggipāricariyā": ['cped'],
    "aggipāricārika": ['cped'],
    "aggisikhā": ['cped'],
    "aggisādhārana": ['cped'],
    "aggisālā": ['cped'],
    "aggiya": ['cped'],
    "aggiṭṭhāna": ['cped'],
    "aggupaṭṭhāka": ['cped'],
    "aggāsana": ['cped'],
    "agh": ['ap90', 'mw'],
    "agha": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "aghaaśva": ['gra'],
    "aghadeva": ['mw'],
    "aghagata": ['cped'],
    "aghaghna": ['mw'],
    "aghagāmi": ['cped'],
    "aghagāmin": ['cped'],
    "aghaharaṇa": ['mw'],
    "aghahāra": ['mw'],
    "aghakṛt": ['mw'],
    "aghala": ['ap90', 'mw'],
    "aghamarṣaṇa": ['cae', 'ddsa', 'mw'],
    "aghamāra": ['mw'],
    "aghana": ['mw'],
    "aghaniṣṭha": ['bhs'],
    "aghanāśaka": ['mw'],
    "agharikā": ['bhs', 'mw'],
    "agharma": ['ap90', 'ddsa', 'mw'],
    "agharmadhāman": ['mw'],
    "agharud": ['mw'],
    "aghaughamarṣaṇa": ['mw'],
    "aghavat": ['mw'],
    "aghavighātakartṛ": ['cae', 'ddsa'],
    "aghaviṣa": ['mw'],
    "aghaya": ['mw'],
    "aghaśaṃsa": ['cae', 'ddsa', 'gra', 'mw'],
    "aghaśaṃsahan": ['gra', 'mw'],
    "aghaśaṃsin": ['ddsa', 'mw'],
    "aghaṇṭa": ['mw'],
    "aghaṭamāna": ['mw'],
    "aghaṭita": ['ddsa'],
    "aghaṭitaghaṭita": ['mw'],
    "aghnat": ['ddsa', 'gra', 'mw'],
    "aghnia": ['gra'],
    "aghnya": ['ap90', 'cae', 'gra', 'mw'],
    "aghnyatva": ['mw'],
    "aghnyā": ['mw'],
    "aghodaka": ['mw'],
    "aghora": ['ap90', 'ddsa', 'mw'],
    "aghoracakṣus": ['gra', 'mw'],
    "aghoraghaṇṭa": ['cae', 'ddsa', 'mw'],
    "aghoraghorarūpa": ['mw'],
    "aghoraghoratara": ['mw'],
    "aghoramārga": ['mw'],
    "aghorapathin": ['mw'],
    "aghorapramāṇa": ['mw'],
    "aghorā": ['mw'],
    "aghos": ['ap90', 'mw'],
    "aghoṣa": ['ap90', 'mw'],
    "aghreya": ['ap90', 'cae', 'ddsa', 'mw'],
    "aghrya": ['ddsa'],
    "aghā": ['mw'],
    "aghāhan": ['cae', 'mw'],
    "aghārin": ['ap90', 'mw'],
    "aghāsaka": ['mw'],
    "aghāsura": ['mw'],
    "aghāta": ['mw'],
    "aghātin": ['mw'],
    "aghātuka": ['mw'],
    "aghāvi": ['cped'],
    "aghāvin": ['bhs', 'cped'],
    "aghāy": ['cae', 'gra'],
    "aghāya": ['mw'],
    "aghāyati": ['ap90'],
    "aghāyu": ['ap90', 'ddsa', 'gra', 'mw'],
    "aghāśva": ['gra', 'mw'],
    "aghūrṇa": ['mw'],
    "aghṛṇa": ['cae', 'ddsa', 'mw'],
    "aghṛṇin": ['ddsa', 'mw'],
    "agiha": ['cped'],
    "agira": ['mw'],
    "agiraukas": ['gra', 'mw'],
    "agiraḥ": ['ap90'],
    "agman": ['ap90', 'mw'],
    "agnaukaraṇa": ['ddsa', 'mw'],
    "agneya": ['bhs'],
    "agneyānī": ['mw'],
    "agni": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "agnibala": ['bhs'],
    "agnibha": ['mw'],
    "agnibhrājas": ['cae', 'gra', 'mw'],
    "agnibhu": ['ddsa', 'mw'],
    "agnibhāṇḍa": ['bhs', 'mw'],
    "agnibhū": ['mw'],
    "agnibhūti": ['mw'],
    "agnibāhu": ['mw'],
    "agnibīja": ['mw'],
    "agnicakra": ['mw'],
    "agnicaya": ['cae', 'mw'],
    "agnicayana": ['mw'],
    "agnicit": ['mw'],
    "agniciti": ['mw'],
    "agnicitvat": ['mw'],
    "agnicityā": ['mw'],
    "agnida": ['cae', 'mw'],
    "agnidagdha": ['cae', 'gra', 'mw'],
    "agnidaivata": ['mw'],
    "agnidamanī": ['mw'],
    "agnidatta": ['bhs', 'mw'],
    "agnideva": ['mw'],
    "agnidevata": ['mw'],
    "agnidevā": ['mw'],
    "agnidh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "agnidhāna": ['gra', 'mw'],
    "agnidiś": ['mw'],
    "agnidāha": ['mw'],
    "agnidāyaka": ['mw'],
    "agnidīpana": ['mw'],
    "agnidīpta": ['mw'],
    "agnidīpti": ['mw'],
    "agnidīptā": ['mw'],
    "agnidūta": ['cae', 'ddsa', 'gra', 'mw'],
    "agnidūṣita": ['cae', 'mw'],
    "agnigarbha": ['ddsa', 'mw'],
    "agnigarbhā": ['mw'],
    "agnighaṭa": ['bhs', 'mw'],
    "agnigodāna": ['mw'],
    "agnigrantha": ['mw'],
    "agnigṛha": ['cae', 'ddsa', 'mw'],
    "agnihavana": ['mw'],
    "agnihoma": ['mw'],
    "agnihotra": ['cae', 'ddsa', 'mw'],
    "agnihotradevatā": ['mw'],
    "agnihotrahavanī": ['mw'],
    "agnihotrahavaṇī": ['cae', 'ddsa'],
    "agnihotrahoma": ['mw'],
    "agnihotrahut": ['mw'],
    "agnihotraprāyaṇa": ['mw'],
    "agnihotrasthālī": ['mw'],
    "agnihotratva": ['mw'],
    "agnihotravelā": ['mw'],
    "agnihotreṣṭi": ['mw'],
    "agnihotrika": ['bhs'],
    "agnihotrin": ['cae', 'ddsa', 'mw'],
    "agnihotroccheṣaṇa": ['mw'],
    "agnihotrocchiṣṭa": ['mw'],
    "agnihotrāhuti": ['mw'],
    "agnihotrāvṛt": ['mw'],
    "agnihotrāyaṇin": ['mw'],
    "agnihotrī": ['mw'],
    "agnihotrīvatsa": ['mw'],
    "agnihotṛ": ['gra', 'mw'],
    "agnihotṛbrāhmaṇa": ['mw'],
    "agnihut": ['mw'],
    "agnihuta": ['bhs', 'mw'],
    "agnihvara": ['mw'],
    "agnija": ['mw'],
    "agnijanman": ['mw'],
    "agnijihva": ['cae', 'gra', 'mw'],
    "agnijihvā": ['mw'],
    "agnijuha": ['bhs'],
    "agnijvalitatejana": ['cae', 'mw'],
    "agnijvāla": ['mw'],
    "agnijvālā": ['mw'],
    "agnijyeṣṭha": ['mw'],
    "agnijyotis": ['mw'],
    "agnijā": ['mw'],
    "agnijāla": ['mw'],
    "agnijāra": ['mw'],
    "agnika": ['mw'],
    "agnikalpa": ['cae', 'mw'],
    "agnikarman": ['cae', 'ddsa', 'mw'],
    "agnikarṣu": ['bhs'],
    "agnikaḥ": ['ap90'],
    "agnikaṇa": ['ddsa', 'mw'],
    "agniketu": ['ddsa', 'mw'],
    "agnikhadā": ['bhs', 'mw'],
    "agnikoṇa": ['mw'],
    "agnikriyā": ['ddsa'],
    "agnikrīḍā": ['mw'],
    "agnikukkuṭa": ['mw'],
    "agnikumāra": ['mw'],
    "agnikuṇḍa": ['ddsa', 'mw'],
    "agnikāma": ['cae'],
    "agnikārikā": ['mw'],
    "agnikārya": ['cae', 'ddsa', 'mw'],
    "agnikāṣṭha": ['mw'],
    "agnikṛta": ['mw'],
    "agnikṣetra": ['mw'],
    "agnilocana": ['mw'],
    "agniloka": ['mw'],
    "agnimadana": ['mw'],
    "agniman": ['mw'],
    "agnimant": ['cae'],
    "agnimantha": ['mw'],
    "agnimanthana": ['mw'],
    "agnimanthanīya": ['mw'],
    "agnimat": ['ap90', 'mw'],
    "agnimaya": ['mw'],
    "agnimaṇi": ['mw'],
    "agnimindha": ['ddsa', 'gra', 'mw'],
    "agnimitra": ['cae', 'mw'],
    "agnimukha": ['bhs', 'ddsa', 'mw'],
    "agnimukhī": ['mw'],
    "agnimālin": ['bhs'],
    "agnimāndya": ['mw'],
    "agnimāruti": ['mw'],
    "agnimāṭhara": ['mw'],
    "agnimīyāma": ['mw'],
    "agnimūḍha": ['gra', 'mw'],
    "agninakṣatra": ['mw'],
    "agninayana": ['mw'],
    "agninetra": ['mw'],
    "agninidhāna": ['mw'],
    "agniniryāsa": ['mw'],
    "agninunna": ['mw'],
    "agninya": ['bhs'],
    "agninyakta": ['mw'],
    "agnināman": ['mw'],
    "agninārāyaṇa": ['mw'],
    "agnipada": ['mw'],
    "agnipakva": ['cae', 'ddsa', 'mw'],
    "agniparicchada": ['cae', 'mw'],
    "agniparidhāna": ['mw'],
    "agniparikriyā": ['cae', 'mw'],
    "agniparvata": ['mw'],
    "agniparīkṣā": ['mw'],
    "agnipatana": ['mw'],
    "agniprabhā": ['bhs', 'mw'],
    "agnipradāna": ['mw'],
    "agniprastara": ['mw'],
    "agnipratiṣṭhā": ['mw'],
    "agnipraveśa": ['cae', 'mw'],
    "agnipraveśana": ['mw'],
    "agnipraṇayana": ['mw'],
    "agnipraṇayanīya": ['mw'],
    "agniprāyaścitta": ['mw'],
    "agniprāyaścitti": ['mw'],
    "agnipuccha": ['mw'],
    "agnipurogama": ['mw'],
    "agnipurā": ['mw'],
    "agnipurāṇa": ['cae', 'mw'],
    "agniputra": ['mw'],
    "agnipānīya": ['mw'],
    "agnipāta": ['mw'],
    "agnirahasya": ['mw'],
    "agnirahasyakāṇḍa": ['mw'],
    "agniraja": ['mw'],
    "agnirajas": ['mw'],
    "agnirakṣaṇa": ['mw'],
    "agnirakṣitikā": ['bhs'],
    "agniretasa": ['mw'],
    "agnirohiṇī": ['mw'],
    "agniruhā": ['mw'],
    "agnirājan": ['mw'],
    "agnirāśi": ['mw'],
    "agnirūpa": ['gra', 'mw'],
    "agnisahāya": ['mw'],
    "agnisajjā": ['mw'],
    "agnisakha": ['mw'],
    "agnisambhava": ['mw'],
    "agnisamādhāna": ['mw'],
    "agnisaras": ['mw'],
    "agnisava": ['mw'],
    "agnisaṃcaya": ['mw'],
    "agnisaṃdīpana": ['mw'],
    "agnisaṃkāśa": ['mw'],
    "agnisaṃskāra": ['cae', 'ddsa', 'mw'],
    "agnisiṃha": ['mw'],
    "agnisparśa": ['mw'],
    "agnistambha": ['mw'],
    "agnistambhana": ['mw'],
    "agnisthala": ['mw'],
    "agnistoka": ['mw'],
    "agnisvāmin": ['cae', 'ddsa'],
    "agnisvātta": ['mw'],
    "agnisāda": ['mw'],
    "agnisākṣika": ['mw'],
    "agnisākṣikamaryāda": ['mw'],
    "agnisāra": ['mw'],
    "agnisāt": ['ap90', 'cae', 'mw'],
    "agnisātkṛ": ['ddsa'],
    "agnisāvarṇi": ['mw'],
    "agnisūtra": ['mw'],
    "agnitanu": ['mw'],
    "agnitap": ['gra', 'mw'],
    "agnitapas": ['gra', 'mw'],
    "agnitapta": ['gra', 'mw'],
    "agnitejas": ['mw'],
    "agnitraya": ['cae', 'ddsa', 'mw'],
    "agnitretā": ['mw'],
    "agnitrā": ['gra', 'mw'],
    "agnituṇḍa": ['mw'],
    "agnitā": ['mw'],
    "agnivaha": ['mw'],
    "agnivaiśyāyana": ['bhs'],
    "agnivallabha": ['mw'],
    "agnivalukā": ['bhs'],
    "agnivant": ['cae'],
    "agnivarcas": ['mw'],
    "agnivardhaka": ['mw'],
    "agnivardhana": ['mw'],
    "agnivarṇa": ['bhs', 'cae', 'mw'],
    "agnivat": ['gra', 'mw'],
    "agnivelā": ['mw'],
    "agnivetāla": ['mw'],
    "agniveśa": ['gra', 'mw'],
    "agniveśman": ['mw'],
    "agniveśya": ['bhs', 'mw'],
    "agnividhā": ['mw'],
    "agniviharaṇa": ['mw'],
    "agnivimocana": ['mw'],
    "agnivisarpa": ['mw'],
    "agniviś": ['mw'],
    "agnivādin": ['mw'],
    "agnivāha": ['mw'],
    "agnivārtta": ['mw'],
    "agnivāsas": ['mw'],
    "agnivāṇa": ['mw'],
    "agnivīrya": ['mw'],
    "agnivṛddhi": ['mw'],
    "agniyauna": ['mw'],
    "agniyojana": ['mw'],
    "agniyuta": ['mw'],
    "agniśakaṭī": ['mw'],
    "agniśakti": ['mw'],
    "agniśaraṇa": ['cae', 'mw'],
    "agniśarman": ['mw'],
    "agniśaucavastra": ['mw'],
    "agniśekhara": ['mw'],
    "agniśeṣa": ['mw'],
    "agniśikha": ['cae', 'ddsa', 'mw'],
    "agniśikhā": ['mw'],
    "agniśroṇi": ['mw'],
    "agniśrī": ['bhs', 'gra', 'mw'],
    "agniśuddhi": ['cae', 'ddsa'],
    "agniśuśrūṣā": ['cae', 'mw'],
    "agniśāla": ['mw'],
    "agniśālā": ['mw'],
    "agniḥ": ['ap90'],
    "agniṣvātta": ['cae', 'gra', 'mw'],
    "agniṣṭha": ['mw'],
    "agniṣṭhikā": ['mw'],
    "agniṣṭhā": ['mw'],
    "agniṣṭoma": ['cae', 'mw'],
    "agniṣṭomahotra": ['mw'],
    "agniṣṭomasad": ['mw'],
    "agniṣṭomasadya": ['mw'],
    "agniṣṭomasāma": ['mw'],
    "agniṣṭomasāman": ['mw'],
    "agniṣṭomayājin": ['mw'],
    "agniṣṭut": ['cae', 'ddsa', 'mw'],
    "agnyabhāva": ['mw'],
    "agnyagāra": ['ddsa', 'mw'],
    "agnyarci": ['mw'],
    "agnyarcis": ['mw'],
    "agnyedha": ['mw'],
    "agnyuddharaṇa": ['mw'],
    "agnyupasthāna": ['mw'],
    "agnyutpāta": ['mw'],
    "agnyutsādin": ['mw'],
    "agnyādheya": ['cae', 'mw'],
    "agnyādheyadevatā": ['mw'],
    "agnyādhāna": ['cae', 'mw'],
    "agnyādhānahavis": ['mw'],
    "agnyādhānarūpa": ['mw'],
    "agnyādhānaśarkarā": ['mw'],
    "agnyāgāra": ['cae', 'mw'],
    "agnyāhita": ['cae', 'mw'],
    "agnyālaya": ['mw'],
    "agnyātmaka": ['mw'],
    "agnyāyatana": ['mw'],
    "agnā": ['mw'],
    "agnāmarutau": ['mw'],
    "agnāviṣṇū": ['mw'],
    "agnāyī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "agnīdh": ['cae', 'gra', 'mw'],
    "agnīdhra": ['mw'],
    "agnīdhraḥ": ['ap90'],
    "agnīndhana": ['cae', 'ddsa', 'mw'],
    "agnīndra": ['cae', 'ddsa'],
    "agnīndrau": ['mw'],
    "agnīparjanya": ['gra'],
    "agnīparjanyau": ['mw'],
    "agnīvaruṇau": ['mw'],
    "agnīya": ['ap90', 'mw'],
    "agnīśvara": ['bhs'],
    "agnīṣoma": ['ap90', 'cae', 'ddsa', 'gra'],
    "agnīṣomabhūta": ['ddsa'],
    "agnīṣomapraṇayana": ['mw'],
    "agnīṣomau": ['mw'],
    "agnīṣomā": ['mw'],
    "agnīṣomīya": ['ap90', 'ddsa', 'mw'],
    "agnīṣomīyaikādaśakapāla": ['mw'],
    "agnīṣomīyanirvāpa": ['mw'],
    "agnīṣomīyapaśu": ['mw'],
    "agnīṣomīyapaśvanuṣṭhāna": ['mw'],
    "agnīṣomīyapuroḍāśa": ['mw'],
    "agnīṣomīyayāga": ['mw'],
    "ago": ['gra', 'mw'],
    "agocara": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "agocareṇa": ['mw'],
    "agocarīkṛ": ['mw'],
    "agohia": ['gra'],
    "agohya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "agopā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "agopāla": ['cae', 'ddsa'],
    "agorudha": ['ap90', 'ddsa', 'gra', 'mw'],
    "agotā": ['ap90', 'gra', 'mw'],
    "agoḥprāpaṇam": ['mw'],
    "agra": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "agrabhaṇa": ['ap90', 'gra', 'mw'],
    "agrabhojya": ['mw'],
    "agrabhuj": ['mw'],
    "agrabhāga": ['cae', 'mw'],
    "agrabhū": ['mw'],
    "agrabhūmi": ['mw'],
    "agrabodhi": ['mw'],
    "agrabīja": ['mw'],
    "agracchada": ['mw'],
    "agradevī": ['mw'],
    "agradharma": ['mw'],
    "agradidhiṣu": ['mw'],
    "agradravasaṃhati": ['mw'],
    "agradānin": ['mw'],
    "agradātṛ": ['mw'],
    "agraga": ['mw'],
    "agragaṇanā": ['mw'],
    "agragaṇya": ['mw'],
    "agragrāsikā": ['mw'],
    "agragāmin": ['mw'],
    "agraha": ['ddsa', 'mw'],
    "agrahasta": ['cae', 'ddsa', 'mw'],
    "agrahaṇa": ['ddsa', 'mw'],
    "agrahāra": ['cae', 'ddsa', 'mw'],
    "agrahāyaṇa": ['mw'],
    "agraja": ['cae', 'mw'],
    "agrajanman": ['cae', 'mw'],
    "agrajaṅghā": ['mw'],
    "agrajihva": ['mw'],
    "agrajyā": ['mw'],
    "agrajā": ['gra', 'mw'],
    "agrajātaka": ['mw'],
    "agrajāti": ['mw'],
    "agrakara": ['cae', 'ddsa', 'mw'],
    "agrakulika": ['bhs'],
    "agrakāya": ['mw'],
    "agralohitā": ['mw'],
    "agram": ['mw'],
    "agramahiṣī": ['mw'],
    "agramaticitracūḍa": ['bhs'],
    "agramukha": ['cae'],
    "agramāṃsa": ['mw'],
    "agranakha": ['ddsa', 'mw'],
    "agranirūpaṇa": ['mw'],
    "agranāsikā": ['mw'],
    "agrapada": ['bhs'],
    "agraparṇī": ['mw'],
    "agrapeya": ['mw'],
    "agrapradāyin": ['mw'],
    "agraprajñapti": ['bhs'],
    "agrapraśīrṇa": ['mw'],
    "agrapuruṣa": ['bhs'],
    "agrapā": ['mw'],
    "agrapāda": ['mw'],
    "agrapāka": ['mw'],
    "agrapāṇi": ['mw'],
    "agrapūjā": ['mw'],
    "agrasandhyā": ['ddsa', 'mw'],
    "agrasara": ['ddsa', 'mw'],
    "agrasaṃdhānī": ['mw'],
    "agrasaṃkhyā": ['mw'],
    "agrasena": ['mw'],
    "agrasta": ['mw'],
    "agrasānu": ['mw'],
    "agrasānumati": ['bhs'],
    "agrasārā": ['bhs', 'mw'],
    "agrasūcī": ['mw'],
    "agratalasaṃcāra": ['mw'],
    "agratas": ['cae', 'ddsa', 'gra', 'mw'],
    "agrataḥ": ['ap90'],
    "agrataḥkṛ": ['mw'],
    "agrataḥsara": ['mw'],
    "agrataḥsthāpayitvā": ['bhs'],
    "agratoratha": ['ddsa'],
    "agratāsūtra": ['bhs'],
    "agratīrtha": ['mw'],
    "agravaktra": ['mw'],
    "agravat": ['mw'],
    "agravīrabāhu": ['bhs'],
    "agrayodhin": ['mw'],
    "agrayāna": ['bhs', 'mw'],
    "agrayāvan": ['gra', 'mw'],
    "agrayāyin": ['cae', 'mw'],
    "agraśas": ['ddsa', 'mw'],
    "agraśikha": ['mw'],
    "agraśrāvaka": ['mw'],
    "agraṇī": ['cae', 'ddsa', 'mw'],
    "agraṇīkṛ": ['mw'],
    "agraṇīti": ['gra', 'mw'],
    "agre": ['ap90', 'bhs', 'mw'],
    "agrebhrū": ['mw'],
    "agredadhiṣu": ['mw'],
    "agredadhus": ['mw'],
    "agredidhiṣu": ['cae', 'ddsa', 'mw'],
    "agrega": ['cae', 'ddsa', 'gra', 'mw'],
    "agregā": ['cae', 'mw'],
    "agregū": ['cae', 'mw'],
    "agrepā": ['cae', 'ddsa', 'gra', 'mw'],
    "agrepū": ['cae', 'mw'],
    "agresara": ['cae', 'ddsa', 'mw'],
    "agresarika": ['mw'],
    "agretana": ['mw'],
    "agretvan": ['mw'],
    "agrevadha": ['mw'],
    "agrevaṇa": ['mw'],
    "agreṇa": ['bhs', 'mw'],
    "agreṇī": ['mw'],
    "agri": ['mw'],
    "agrima": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "agrimavatī": ['mw'],
    "agrimā": ['mw'],
    "agriya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "agriyavat": ['mw'],
    "agrodaka": ['bhs'],
    "agrodikā": ['bhs'],
    "agropaharaṇīya": ['mw'],
    "agru": ['cae', 'ddsa', 'gra', 'mw'],
    "agruḥ": ['ap90'],
    "agrya": ['ap90', 'cae', 'ddsa', 'mw'],
    "agryatapas": ['ddsa', 'mw'],
    "agryā": ['mw'],
    "agrā": ['mw'],
    "agrādvan": ['gra', 'mw'],
    "agrāgra": ['mw'],
    "agrāha": ['bhs'],
    "agrāhayitvā": ['cae'],
    "agrāhin": ['cae', 'ddsa', 'mw'],
    "agrāhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "agrāhyaka": ['mw'],
    "agrākṣan": ['ddsa', 'mw'],
    "agrāmya": ['ap90', 'mw'],
    "agrāmyabhojin": ['ddsa'],
    "agrānta": ['mw'],
    "agrānīka": ['cae', 'ddsa', 'mw'],
    "agrāsana": ['mw'],
    "agrāsanika": ['bhs'],
    "agrāyaṇīya": ['mw'],
    "agrāśana": ['ddsa', 'mw'],
    "agrāṃśa": ['mw'],
    "agrāṃśu": ['mw'],
    "agrāṅguli": ['mw'],
    "agrāṭavika": ['bhs'],
    "agrīya": ['ap90', 'mw'],
    "agrū": ['gra', 'mw'],
    "agu": ['ap90', 'cae', 'gra', 'mw'],
    "agupta": ['cae', 'ddsa', 'mw'],
    "aguru": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "aguruprayukta": ['ddsa'],
    "agurusāra": ['ddsa'],
    "aguṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aguṇajña": ['ddsa'],
    "aguṇatva": ['mw'],
    "aguṇatā": ['mw'],
    "aguṇavat": ['mw'],
    "aguṇavādin": ['mw'],
    "aguṇaśīla": ['mw'],
    "aguṇin": ['ddsa', 'mw'],
    "aguṇībhūta": ['cae', 'ddsa'],
    "agyantarāya": ['cped'],
    "agyāgāra": ['cped'],
    "agā": ['ap90', 'mw'],
    "agādha": ['ap90', 'cae', 'ddsa', 'mw'],
    "agādhajala": ['mw'],
    "agādharudhira": ['ddsa', 'mw'],
    "agādhitva": ['mw'],
    "agāgra": ['cae', 'ddsa'],
    "agāha": ['bhs'],
    "agālita": ['mw'],
    "agāmaka": ['cped'],
    "agāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "agāradāhin": ['ddsa', 'mw'],
    "agārastha": ['bhs'],
    "agārasthūṇāvirohaṇa": ['mw'],
    "agārastūpa": ['mw'],
    "agāravasa": ['cped'],
    "agāravinoda": ['mw'],
    "agāraṃ": ['ap90'],
    "agārikabhūta": ['cped'],
    "agārin": ['mw'],
    "agāriya": ['cped'],
    "agārā": ['cped'],
    "agārāvakāśa": ['mw'],
    "agātmajā": ['ddsa', 'mw'],
    "agātṛ": ['mw'],
    "agāvaha": ['mw'],
    "agīta": ['mw'],
    "agūḍha": ['ap90', 'mw'],
    "agūḍhabhāva": ['mw'],
    "agūḍhagandha": ['mw'],
    "agṛbhīta": ['ap90', 'cae', 'gra', 'mw'],
    "agṛbhītaśocis": ['gra', 'mw'],
    "agṛdhnu": ['ddsa'],
    "agṛha": ['mw'],
    "agṛhatā": ['mw'],
    "agṛhaḥ": ['ap90'],
    "agṛhlat": ['ddsa'],
    "agṛhya": ['cae', 'ddsa', 'mw'],
    "agṛhīta": ['cae', 'ddsa', 'mw'],
    "agṛhītadiś": ['mw'],
    "agṛhītvā": ['cae'],
    "agṛhṇant": ['cae'],
    "agṛhṇat": ['mw'],
    "ah": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aha": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ahabhūna": ['mw'],
    "ahaha": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "ahahā": ['mw'],
    "ahahāre": ['mw'],
    "ahaituka": ['ap90', 'cae', 'ddsa', 'mw'],
    "ahaitukam": ['mw'],
    "ahaitukya": ['mw'],
    "ahakam": ['mw'],
    "ahala": ['ap90', 'mw'],
    "ahali": ['mw'],
    "ahallika": ['mw'],
    "ahallikaḥ": ['ap90'],
    "ahalya": ['ap90'],
    "ahalyeśvaratīrtha": ['mw'],
    "ahalyā": ['cae', 'ddsa', 'mw'],
    "ahalyāhrada": ['mw'],
    "ahalyājāra": ['mw'],
    "ahalyākāmadhenu": ['mw'],
    "ahalyāpati": ['mw'],
    "ahalyāsaṃkrandana": ['mw'],
    "aham": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ahamada": ['mw'],
    "ahamagrikā": ['mw'],
    "ahamahamikā": ['mw'],
    "ahambhadra": ['mw'],
    "ahambhāva": ['mw'],
    "ahambuddhi": ['mw'],
    "ahamindra": ['mw'],
    "ahammamatā": ['mw'],
    "ahammamābhimāna": ['mw'],
    "ahammati": ['mw'],
    "ahammāna": ['mw'],
    "ahampadārtha": ['mw'],
    "ahamprathamikā": ['mw'],
    "ahampūrva": ['gra', 'mw'],
    "ahampūrvikā": ['mw'],
    "ahamuttara": ['mw'],
    "ahamuttaratva": ['mw'],
    "ahan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ahana": ['gra'],
    "ahania": ['gra'],
    "ahannāman": ['ddsa'],
    "ahanti": ['mw'],
    "ahantva": ['mw'],
    "ahantya": ['mw'],
    "ahantā": ['ddsa'],
    "ahanya": ['cae', 'ddsa', 'mw'],
    "ahanyamāna": ['mw'],
    "ahanā": ['ap90', 'mw'],
    "ahar": ['cae', 'ddsa', 'gra', 'mw'],
    "ahara": ['ap90', 'mw'],
    "aharahar": ['mw'],
    "aharahaḥkarman": ['mw'],
    "aharaṇīya": ['ap90', 'mw'],
    "aharbhāj": ['mw'],
    "aharbāndhava": ['mw'],
    "ahardala": ['mw'],
    "ahardiva": ['mw'],
    "ahardivam": ['mw'],
    "ahardivi": ['gra', 'mw'],
    "ahardṛś": ['gra', 'mw'],
    "ahargaṇa": ['mw'],
    "aharita": ['mw'],
    "aharjaram": ['mw'],
    "aharjāta": ['mw'],
    "aharlokā": ['mw'],
    "aharmaṇi": ['mw'],
    "aharmukha": ['mw'],
    "aharniśa": ['cae', 'mw'],
    "aharniśam": ['mw'],
    "aharpati": ['mw'],
    "aharvid": ['cae', 'gra', 'mw'],
    "aharvyatyāsam": ['mw'],
    "aharādi": ['mw'],
    "aharāgama": ['cae', 'mw'],
    "aharīta": ['mw'],
    "aharṣa": ['mw'],
    "aharṣamaya": ['mw'],
    "ahas": ['cae', 'ddsa', 'mw'],
    "ahasitakeśa": ['bhs'],
    "ahaskara": ['mw'],
    "ahasta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ahastriyāma": ['mw'],
    "ahata": ['ap90', 'cae', 'ddsa', 'mw'],
    "ahatamārga": ['cae', 'mw'],
    "ahatatā": ['mw'],
    "ahatavāsas": ['mw'],
    "ahati": ['gra', 'mw'],
    "ahatiḥ": ['ap90'],
    "ahatvā": ['cae'],
    "ahavi": ['ap90'],
    "ahaviryājin": ['mw'],
    "ahavis": ['gra', 'mw'],
    "ahaviṣya": ['mw'],
    "ahavyavah": ['mw'],
    "ahaś": ['mw'],
    "ahaścara": ['mw'],
    "ahaśśas": ['mw'],
    "ahaḥ": ['mw'],
    "ahaḥkṣānta": ['mw'],
    "ahaḥpati": ['mw'],
    "ahaḥsahasra": ['mw'],
    "ahaḥsaṃsthā": ['mw'],
    "ahaḥstoma": ['mw'],
    "ahaḥsāman": ['mw'],
    "ahaḥśeṣa": ['cae', 'ddsa', 'mw'],
    "ahaṁ": ['cped'],
    "ahaṃ": ['mw'],
    "ahaṃcandrasūri": ['mw'],
    "ahaṃdhī": ['mw'],
    "ahaṃghāta": ['bhs', 'mw'],
    "ahaṃjuṣ": ['mw'],
    "ahaṃkaraṇa": ['mw'],
    "ahaṃkartavya": ['mw'],
    "ahaṃkriyā": ['mw'],
    "ahaṃkāra": ['cae', 'mw'],
    "ahaṃkāravat": ['mw'],
    "ahaṃkārin": ['mw'],
    "ahaṃkārya": ['cae', 'mw'],
    "ahaṃkṛ": ['mw'],
    "ahaṃkṛta": ['cae', 'mw'],
    "ahaṃkṛti": ['cae', 'mw'],
    "ahaṃnāman": ['mw'],
    "ahaṃpūrva": ['mw'],
    "ahaṃsana": ['gra', 'mw'],
    "ahaṃtva": ['mw'],
    "ahaṃtya": ['ap90'],
    "ahaṃtā": ['mw'],
    "ahaṃvādin": ['ddsa', 'mw'],
    "ahaṃyu": ['ap90', 'cae', 'gra', 'mw'],
    "ahaṃyāti": ['mw'],
    "ahaṃśreyas": ['mw'],
    "ahaṃśreyasa": ['mw'],
    "ahaṃśreṣṭhikā": ['mw'],
    "ahaṅkāra": ['ddsa'],
    "ahaṇkāra": ['cped'],
    "ahaṇkārapasuta": ['cped'],
    "ahe": ['ap90', 'mw'],
    "ahedhma": ['mw'],
    "ahelin": ['mw'],
    "ahelā": ['ddsa'],
    "ahel̤amāna": ['mw'],
    "ahel̤at": ['ap90', 'mw'],
    "ahel̤ayat": ['mw'],
    "aheru": ['mw'],
    "aheruḥ": ['ap90'],
    "ahetu": ['ap90', 'mw'],
    "ahetuka": ['ap90', 'cped', 'ddsa', 'mw'],
    "ahetukavāda": ['cped'],
    "ahetusama": ['mw'],
    "ahetutva": ['mw'],
    "ahetuvāda": ['mw'],
    "ahetuvādin": ['mw'],
    "aheḍamāna": ['gra', 'mw'],
    "aheḍat": ['gra'],
    "aheḍayat": ['gra'],
    "aheṭhaka": ['bhs'],
    "ahi": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ahibhaya": ['mw'],
    "ahibhayadā": ['mw'],
    "ahibhuj": ['mw'],
    "ahibhānu": ['cae', 'gra', 'mw'],
    "ahibhānurāga": ['bhs'],
    "ahibhṛt": ['mw'],
    "ahibradhna": ['mw'],
    "ahicakra": ['mw'],
    "ahicchattaka": ['cped'],
    "ahicchattra": ['mw'],
    "ahicchattraka": ['mw'],
    "ahicchattrā": ['mw'],
    "ahicumbaka": ['mw'],
    "ahicumbakāyani": ['mw'],
    "ahidaivata": ['mw'],
    "ahidanta": ['mw'],
    "ahidat": ['mw'],
    "ahideva": ['mw'],
    "ahidviṣ": ['mw'],
    "ahigandha": ['cae', 'ddsa'],
    "ahighna": ['gra', 'mw'],
    "ahigopā": ['gra', 'mw'],
    "ahihan": ['gra', 'mw'],
    "ahihatya": ['cae', 'ddsa', 'gra', 'mw'],
    "ahihrada": ['mw'],
    "ahijambhana": ['mw'],
    "ahijit": ['mw'],
    "ahikañcuka": ['mw'],
    "ahikaḥ": ['ap90'],
    "ahikośa": ['mw'],
    "ahikā": ['mw'],
    "ahikānta": ['mw'],
    "ahikṣatra": ['mw'],
    "ahilatā": ['mw'],
    "ahilocana": ['mw'],
    "ahilolikā": ['mw'],
    "ahima": ['ap90', 'cae', 'mw'],
    "ahimadīdhiti": ['ddsa', 'mw'],
    "ahimakara": ['mw'],
    "ahimakiraṇa": ['mw'],
    "ahimamayūkha": ['mw'],
    "ahimanyu": ['cae', 'gra', 'mw'],
    "ahimaraśmi": ['mw'],
    "ahimardanī": ['mw'],
    "ahimarocis": ['mw'],
    "ahimaruci": ['mw'],
    "ahimat": ['mw'],
    "ahimatviṣ": ['mw'],
    "ahimeda": ['mw'],
    "ahimedaka": ['mw'],
    "ahimekhalikā": ['cped'],
    "ahimāra": ['mw'],
    "ahimāraka": ['mw'],
    "ahimāya": ['ddsa', 'gra', 'mw'],
    "ahimāṃśu": ['mw'],
    "ahina": ['mw'],
    "ahinakulikā": ['mw'],
    "ahinas": ['mw'],
    "ahinilvayanī": ['mw'],
    "ahinirvlayanī": ['mw'],
    "ahināmabhṛt": ['mw'],
    "ahināman": ['gra', 'mw'],
    "ahipati": ['ddsa', 'mw'],
    "ahipatāka": ['mw'],
    "ahiphena": ['mw'],
    "ahiputraka": ['mw'],
    "ahipuṣpa": ['mw'],
    "ahipūtana": ['mw'],
    "ahipūtanā": ['mw'],
    "ahipṛṣṭha": ['mw'],
    "ahiraṇya": ['mw'],
    "ahiraṇyava": ['mw'],
    "ahiraṇyavat": ['mw'],
    "ahirbudhnya": ['mw'],
    "ahirbudhnyadevatya": ['mw'],
    "ahirbudhnyadevatā": ['mw'],
    "ahirbudhnyas": ['mw'],
    "ahirika": ['cped'],
    "ahiripu": ['mw'],
    "ahirodaka": ['bhs'],
    "ahirī": ['bhs'],
    "ahirīka": ['cped'],
    "ahita": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ahitakārin": ['mw'],
    "ahitamanas": ['mw'],
    "ahitanāman": ['mw'],
    "ahitecchu": ['mw'],
    "ahituṇḍika": ['bhs', 'mw'],
    "ahitā": ['mw'],
    "ahivallī": ['mw'],
    "ahividviṣ": ['mw'],
    "ahivijjā": ['cped'],
    "ahiviṣāpahā": ['mw'],
    "ahivratin": ['mw'],
    "ahivātakaroga": ['cped'],
    "ahiśuṣma": ['gra'],
    "ahiśuṣmasatvan": ['gra', 'mw'],
    "ahiṃkāra": ['mw'],
    "ahiṃkṛti": ['mw'],
    "ahiṃsaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "ahiṃsant": ['cae'],
    "ahiṃsat": ['gra', 'mw'],
    "ahiṃsra": ['ap90', 'cae', 'mw'],
    "ahiṃsrā": ['mw'],
    "ahiṃsya": ['mw'],
    "ahiṃsyamāna": ['gra', 'mw'],
    "ahiṃsā": ['ap90', 'cae', 'mw'],
    "ahiṃsāna": ['ap90', 'gra', 'mw'],
    "ahiṃsānirata": ['mw'],
    "ahiṃḍukā": ['ap90'],
    "ahiṇḍukā": ['mw'],
    "ahna": ['cae', 'ddsa', 'gra', 'mw'],
    "ahnavāyia": ['gra'],
    "ahnavāyya": ['ap90', 'gra', 'mw'],
    "ahnaḥ": ['ap90'],
    "ahnija": ['mw'],
    "ahnya": ['mw'],
    "ahnāya": ['ap90', 'mw'],
    "aho": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "ahobala": ['mw'],
    "aholūkhalamekhalā": ['bhs'],
    "ahoma": ['mw'],
    "ahonāma": ['bhs'],
    "ahopuruṣikā": ['mw'],
    "ahorathantara": ['mw'],
    "ahoratna": ['mw'],
    "ahoratta": ['cped'],
    "ahorattanusikkhi": ['cped'],
    "ahorattanusikkhin": ['cped'],
    "ahorattaṁ": ['cped'],
    "ahoratti": ['cped'],
    "ahorātra": ['cae', 'ddsa', 'gra', 'mw'],
    "ahorātram": ['mw'],
    "ahorūpa": ['mw'],
    "ahotṛ": ['mw'],
    "ahovīrya": ['mw'],
    "ahoḍima": ['bhs'],
    "ahrasta": ['mw'],
    "ahrasva": ['cae', 'ddsa'],
    "ahraya": ['ap90', 'cae', 'gra', 'mw'],
    "ahrayāṇa": ['cae', 'gra', 'mw'],
    "ahri": ['ap90', 'cae', 'gra', 'mw'],
    "ahruta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ahrutapsu": ['cae', 'gra', 'mw'],
    "ahrī": ['mw'],
    "ahrīka": ['ap90', 'bhs', 'mw'],
    "ahu": ['ap90', 'bhs', 'mw'],
    "ahura": ['mw'],
    "ahuta": ['ap90', 'cae', 'ddsa', 'mw'],
    "ahutābhyudite": ['mw'],
    "ahutād": ['mw'],
    "ahutāśa": ['mw'],
    "ahvala": ['ap90'],
    "ahvalā": ['cae', 'ddsa', 'mw'],
    "ahyarṣu": ['cae', 'ddsa', 'gra', 'mw'],
    "ahāpayat": ['ddsa', 'mw'],
    "ahārayat": ['ddsa', 'mw'],
    "ahārin": ['mw'],
    "ahārya": ['cae', 'mw'],
    "ahāryahāriṇī": ['bhs'],
    "ahāryatva": ['mw'],
    "ahāvas": ['mw'],
    "ahī": ['cae', 'gra', 'mw'],
    "ahīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "ahīnagu": ['mw'],
    "ahīnakarman": ['mw'],
    "ahīnara": ['mw'],
    "ahīnavādin": ['mw'],
    "ahīndra": ['mw'],
    "ahīnāha": ['mw'],
    "ahīra": ['mw'],
    "ahīramaṇi": ['mw'],
    "ahīraḥ": ['ap90'],
    "ahīraṇi": ['mw'],
    "ahīraṇiḥ": ['ap90'],
    "ahīvatī": ['mw'],
    "ahīśruvaḥ": ['ap90'],
    "ahīśuva": ['gra', 'mw'],
    "ahīśvara": ['mw'],
    "ahūta": ['gra', 'mw'],
    "ahṛdaya": ['ap90', 'mw'],
    "ahṛdayajña": ['mw'],
    "ahṛdya": ['ap90', 'mw'],
    "ahṛsvara": ['bhs'],
    "ahṛta": ['ddsa', 'mw'],
    "ahṛṇāna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ahṛṇīyamāna": ['ap90', 'gra', 'mw'],
    "ahṛṇīyamānam": ['mw'],
    "ai": ['cae', 'mw'],
    "aibha": ['ap90', 'cae', 'ddsa', 'mw'],
    "aibhāvata": ['mw'],
    "aibhī": ['mw'],
    "aicchika": ['ap90', 'mw'],
    "aidamparya": ['ddsa'],
    "aidaṃparya": ['cae', 'mw'],
    "aidaṃparyaṃ": ['ap90'],
    "aidaṃyugīna": ['ap90', 'mw'],
    "aidha": ['cae', 'mw'],
    "aidhā": ['gra'],
    "aihalaukika": ['ap90', 'cae', 'mw'],
    "aihika": ['ap90', 'cae', 'ddsa', 'mw'],
    "aihipaśyika": ['bhs'],
    "aika": ['ap90', 'mw'],
    "aikabhautika": ['mw'],
    "aikabhāvya": ['mw'],
    "aikabhāvyaṃ": ['ap90'],
    "aikadhya": ['mw'],
    "aikadhyam": ['ddsa', 'mw'],
    "aikadhyatas": ['mw'],
    "aikadhyaṃ": ['ap90'],
    "aikadyaṃ": ['ap90'],
    "aikagavika": ['mw'],
    "aikaguṇya": ['mw'],
    "aikakarmya": ['mw'],
    "aikakālya": ['mw'],
    "aikalava": ['mw'],
    "aikalavya": ['mw'],
    "aikamantrya": ['mw'],
    "aikamatya": ['cae', 'mw'],
    "aikamatyaṃ": ['ap90'],
    "aikamukhya": ['mw'],
    "aikapadika": ['ap90', 'mw'],
    "aikapadya": ['mw'],
    "aikapadyaṃ": ['ap90'],
    "aikapatya": ['mw'],
    "aikapatyaṃ": ['ap90'],
    "aikarājya": ['mw'],
    "aikarājyaṃ": ['ap90'],
    "aikarātrika": ['mw'],
    "aikarūpya": ['mw'],
    "aikasahasrika": ['ap90', 'mw'],
    "aikasvarya": ['mw'],
    "aikavarṇika": ['mw'],
    "aikaśabdya": ['mw'],
    "aikaśapha": ['ap90', 'cae', 'ddsa', 'mw'],
    "aikaśatika": ['ap90', 'mw'],
    "aikaśrutya": ['cae', 'mw'],
    "aikaśrutyaṃ": ['ap90'],
    "aikaśālika": ['mw'],
    "aikya": ['cae', 'ddsa', 'mw'],
    "aikyaṃ": ['ap90'],
    "aikyāropa": ['mw'],
    "aikādaśina": ['mw'],
    "aikādaśākṣa": ['mw'],
    "aikādhikaraṇya": ['ddsa', 'mw'],
    "aikādhikaraṇyaṃ": ['ap90'],
    "aikāgnika": ['mw'],
    "aikāgra": ['ap90'],
    "aikāgrya": ['cae', 'ddsa', 'mw'],
    "aikāgryaṃ": ['ap90'],
    "aikāgārika": ['ddsa', 'mw'],
    "aikāgārikaḥ": ['ap90'],
    "aikāhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "aikāhya": ['mw'],
    "aikāntika": ['cae', 'ddsa', 'mw'],
    "aikāntya": ['cae', 'mw'],
    "aikānyika": ['mw'],
    "aikānyikaḥ": ['ap90'],
    "aikāra": ['cae', 'ddsa', 'mw'],
    "aikārthya": ['cae', 'ddsa', 'mw'],
    "aikārthyaṃ": ['ap90'],
    "aikāsanika": ['bhs'],
    "aikātmya": ['cae', 'mw'],
    "aikātmyaṃ": ['ap90'],
    "aikāyana": ['mw'],
    "aikāśramya": ['ddsa', 'mw'],
    "aikāṃgaḥ": ['ap90'],
    "aikāṃtika": ['ap90'],
    "aikāṅga": ['ddsa', 'mw'],
    "aikāṅkāyana": ['mw'],
    "aikṣava": ['ap90', 'cae', 'ddsa', 'mw'],
    "aikṣavya": ['ap90', 'cae', 'mw'],
    "aikṣubhārika": ['ap90', 'mw'],
    "aikṣuka": ['ap90', 'mw'],
    "aikṣvāka": ['ap90', 'cae', 'ddsa', 'mw'],
    "aikṣvāku": ['mw'],
    "aila": ['cae', 'ddsa', 'mw'],
    "ailaba": ['cae', 'ddsa', 'mw'],
    "ailabakāra": ['mw'],
    "ailabṛda": ['mw'],
    "ailadhāna": ['mw'],
    "ailadhānī": ['mw'],
    "ailaka": ['ddsa', 'mw'],
    "ailamṛḍa": ['mw'],
    "ailavaḥ": ['ap90'],
    "ailavaṃśa": ['mw'],
    "ailavila": ['mw'],
    "ailavilaḥ": ['ap90'],
    "ailaviḍaḥ": ['ap90'],
    "ailavāluka": ['mw'],
    "ailavālukaḥ": ['ap90'],
    "ailaḥ": ['ap90'],
    "aileya": ['mw'],
    "aileyaḥ": ['ap90'],
    "ailika": ['mw'],
    "ailā": ['mw'],
    "ailāka": ['mw'],
    "ailākya": ['mw'],
    "ailūṣa": ['mw'],
    "aina": ['mw'],
    "ainasa": ['mw'],
    "ainasaṃ": ['ap90'],
    "aindava": ['cae', 'ddsa', 'mw'],
    "aindavī": ['mw'],
    "aindhana": ['mw'],
    "aindhāyana": ['mw'],
    "aindra": ['cae', 'ddsa', 'mw'],
    "aindradyumna": ['mw'],
    "aindradyumni": ['mw'],
    "aindrahava": ['mw'],
    "aindrahavya": ['mw'],
    "aindrajāla": ['cae', 'ddsa', 'mw'],
    "aindrajālika": ['cae', 'mw'],
    "aindraluptika": ['mw'],
    "aindralājya": ['mw'],
    "aindramahika": ['mw'],
    "aindramārga": ['bhs'],
    "aindramāruta": ['mw'],
    "aindranighanṭu": ['mw'],
    "aindranīla": ['mw'],
    "aindraseni": ['mw'],
    "aindraturīya": ['mw'],
    "aindravāyava": ['mw'],
    "aindraśira": ['mw'],
    "aindri": ['ddsa', 'mw'],
    "aindriya": ['cae', 'ddsa', 'mw'],
    "aindriyaka": ['mw'],
    "aindriyakatva": ['mw'],
    "aindriyedhī": ['mw'],
    "aindroti": ['mw'],
    "aindrābārhaspatya": ['mw'],
    "aindrādṛśa": ['mw'],
    "aindrāgna": ['mw'],
    "aindrāgnakulāya": ['mw'],
    "aindrāgnya": ['mw'],
    "aindrājāgata": ['mw'],
    "aindrāliśa": ['mw'],
    "aindrāmāruta": ['mw'],
    "aindrānairṛta": ['mw'],
    "aindrāpauṣṇa": ['mw'],
    "aindrārbhava": ['mw'],
    "aindrāsaumya": ['mw'],
    "aindrāvaiṣṇava": ['mw'],
    "aindrāvaruṇa": ['mw'],
    "aindrāvasāna": ['mw'],
    "aindrāvāruṇa": ['mw'],
    "aindrāyaṇa": ['mw'],
    "aindrāyaṇaka": ['mw'],
    "aindrāyaṇī": ['mw'],
    "aindrāyudha": ['mw'],
    "aindrī": ['mw'],
    "aindumateya": ['mw'],
    "ainduśekhara": ['mw'],
    "ainvaka": ['mw'],
    "ainya": ['ap90', 'mw'],
    "aira": ['mw'],
    "airayam": ['ddsa'],
    "airaṃmada": ['mw'],
    "aireya": ['mw'],
    "aireyaṃ": ['ap90'],
    "airiṇa": ['mw'],
    "airiṇaṃ": ['ap90'],
    "airmya": ['mw'],
    "airmyaṃ": ['ap90'],
    "airyāpatha": ['bhs'],
    "airyāpathikī": ['mw'],
    "airāvata": ['bhs', 'cae', 'ddsa', 'mw'],
    "airāvataka": ['bhs', 'mw'],
    "airāvataḥ": ['ap90'],
    "airāvatī": ['bhs', 'mw'],
    "airāvaṇa": ['cae', 'ddsa', 'mw'],
    "airāvaṇaḥ": ['ap90'],
    "aitadātmya": ['cae', 'ddsa', 'mw'],
    "aitadātmyaṃ": ['ap90'],
    "aitara": ['mw'],
    "aitareya": ['ap90', 'cae', 'ddsa', 'mw'],
    "aitareyabrāhmana": ['cae'],
    "aitareyabrāhmaṇa": ['mw'],
    "aitareyaka": ['cae', 'mw'],
    "aitareyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "aitareyopaniṣad": ['mw'],
    "aitareyopaniṣadbhāṣya": ['mw'],
    "aitareyāraṇyaka": ['mw'],
    "aitaśa": ['mw'],
    "aitaśapralāpa": ['mw'],
    "aitaśāyana": ['mw'],
    "aitiha": ['mw'],
    "aitihya": ['cae', 'mw'],
    "aitihyaṃ": ['ap90'],
    "aitihāsika": ['ap90', 'cae', 'ddsa', 'mw'],
    "aitikāyana": ['mw'],
    "aitikāyanīya": ['mw'],
    "aitiśāyana": ['mw'],
    "aitva": ['ddsa'],
    "aivamarthya": ['mw'],
    "aiyatya": ['mw'],
    "aiyatyaṃ": ['ap90'],
    "aiyes": ['gra'],
    "aiśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aiśi": ['cae', 'ddsa', 'mw'],
    "aiśika": ['mw'],
    "aiśvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "aiśvarakāraṇika": ['mw'],
    "aiśvari": ['mw'],
    "aiśvarika": ['mw'],
    "aiśvarikaḥ": ['ap90'],
    "aiśvarya": ['cae', 'mw'],
    "aiśvaryakādambinī": ['mw'],
    "aiśvaryamatta": ['cae'],
    "aiśvaryavat": ['mw'],
    "aiśvaryavivaraṇa": ['mw'],
    "aiśvaryaṃ": ['ap90'],
    "aiśvarī": ['mw'],
    "aiśya": ['cae', 'ddsa', 'mw'],
    "aiśāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "aiśānaja": ['mw'],
    "aiśānī": ['mw'],
    "aiḍa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aiḍaka": ['ap90', 'mw'],
    "aiḍakautsa": ['mw'],
    "aiḍakrauñca": ['mw'],
    "aiḍakāva": ['mw'],
    "aiḍasaindhukṣita": ['mw'],
    "aiḍasauparṇa": ['mw'],
    "aiḍaviḍa": ['mw'],
    "aiḍaviḍaḥ": ['ap90'],
    "aiḍavāsiṣṭha": ['mw'],
    "aiḍayāma": ['mw'],
    "aiḍaśuddhāśuddhīya": ['mw'],
    "aiḍukaṃ": ['ap90'],
    "aiḍādadha": ['mw'],
    "aiḍūka": ['mw'],
    "aiḍūkaṃ": ['ap90'],
    "aiḥ": ['ap90'],
    "aiṃdava": ['ap90'],
    "aiṃdhana": ['ap90'],
    "aiṃdra": ['ap90'],
    "aiṃdrajālika": ['ap90'],
    "aiṃdraluptika": ['ap90'],
    "aiṃdraturīyaḥ": ['ap90'],
    "aiṃdraśiraḥ": ['ap90'],
    "aiṃdriya": ['ap90'],
    "aiṃdriyedhī": ['ap90'],
    "aiṃdriḥ": ['ap90'],
    "aiṃdrāgna": ['ap90'],
    "aiṃguda": ['ap90'],
    "aiṅguda": ['mw'],
    "aiṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aiṇeya": ['ap90', 'cae', 'mw'],
    "aiṇeyajaṅgha": ['bhs'],
    "aiṇeyajaṅghatā": ['mw'],
    "aiṇika": ['ap90', 'mw'],
    "aiṇikīya": ['mw'],
    "aiṇīpacana": ['mw'],
    "aiṣa": ['mw'],
    "aiṣamas": ['ap90', 'cae', 'mw'],
    "aiṣamastana": ['ap90', 'mw'],
    "aiṣamastya": ['mw'],
    "aiṣikā": ['bhs'],
    "aiṣira": ['mw'],
    "aiṣukāri": ['mw'],
    "aiṣukāribhakta": ['mw'],
    "aiṣukāryādi": ['mw'],
    "aiṣumata": ['mw'],
    "aiṣāvīra": ['ap90', 'mw'],
    "aiṣīka": ['ap90', 'cae', 'ddsa', 'mw'],
    "aiṣīrathi": ['mw'],
    "aiṣṭaka": ['cae', 'ddsa', 'mw'],
    "aiṣṭakaṃ": ['ap90'],
    "aiṣṭika": ['ap90', 'mw'],
    "aiṣṭikapaurtika": ['cae', 'ddsa', 'mw'],
    "aiṭata": ['mw'],
    "aj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aja": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ajababhru": ['mw'],
    "ajabhakṣa": ['mw'],
    "ajadaṇḍī": ['mw'],
    "ajaddhuka": ['cped'],
    "ajaddhumārikā": ['cped'],
    "ajadevatā": ['mw'],
    "ajagalastana": ['ddsa'],
    "ajagallikā": ['mw'],
    "ajagandhikā": ['mw'],
    "ajagandhinī": ['mw'],
    "ajagandhā": ['mw'],
    "ajagara": ['ap90', 'cae', 'ddsa', 'mw'],
    "ajagarī": ['mw'],
    "ajagati": ['mw'],
    "ajagava": ['mw'],
    "ajagavaṃ": ['ap90'],
    "ajagaṃ": ['ap90'],
    "ajaghanvas": ['gra'],
    "ajaghanya": ['ddsa', 'mw'],
    "ajaghnivas": ['mw'],
    "ajagāva": ['mw'],
    "ajagāvaḥ": ['ap90'],
    "ajahakṣaṇā": ['cae'],
    "ajahallakṣaṇā": ['ddsa'],
    "ajahalliṃgaṃ": ['ap90'],
    "ajahalliṅga": ['mw'],
    "ajahat": ['mw'],
    "ajahatsvārthā": ['ap90', 'mw'],
    "ajahā": ['ap90', 'mw'],
    "ajaikapād": ['ddsa', 'mw'],
    "ajaiḍaka": ['mw'],
    "ajajīvana": ['mw'],
    "ajajīvika": ['mw'],
    "ajaka": ['cped', 'mw'],
    "ajakarṇa": ['bhs', 'mw'],
    "ajakarṇaka": ['mw'],
    "ajakava": ['mw'],
    "ajakavaḥ": ['ap90'],
    "ajakā": ['ap90', 'mw'],
    "ajakājāta": ['mw'],
    "ajakāva": ['gra', 'mw'],
    "ajakāvaḥ": ['ap90'],
    "ajakūlā": ['mw'],
    "ajakṣīra": ['mw'],
    "ajalakkhaṇa": ['cped'],
    "ajalambana": ['mw'],
    "ajaloma": ['mw'],
    "ajaloman": ['mw'],
    "ajalomī": ['mw'],
    "ajalpant": ['cae'],
    "ajalpat": ['ddsa'],
    "ajambha": ['mw'],
    "ajameru": ['mw'],
    "ajamoda": ['mw'],
    "ajamodikā": ['mw'],
    "ajamodā": ['mw'],
    "ajamukha": ['mw'],
    "ajamukhī": ['mw'],
    "ajamāra": ['mw'],
    "ajamāyu": ['cae', 'ddsa', 'gra', 'mw'],
    "ajamīl̤ha": ['mw'],
    "ajamīḍha": ['cae', 'gra', 'mw'],
    "ajana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ajanani": ['ddsa', 'mw'],
    "ajananiḥ": ['ap90'],
    "ajanayonija": ['mw'],
    "ajanaṃ": ['ap90'],
    "ajani": ['mw'],
    "ajaniḥ": ['ap90'],
    "ajanman": ['ap90', 'ddsa', 'mw'],
    "ajanta": ['mw'],
    "ajanya": ['ap90', 'bhs', 'mw'],
    "ajanāgrīya": ['ddsa'],
    "ajanāmaka": ['mw'],
    "ajapa": ['cae', 'ddsa', 'mw'],
    "ajapada": ['cped', 'mw'],
    "ajapadakadaṇḍa": ['bhs'],
    "ajapatha": ['mw'],
    "ajapaḥ": ['ap90'],
    "ajapā": ['mw'],
    "ajapād": ['mw'],
    "ajapāda": ['mw'],
    "ajapāla": ['cae', 'mw'],
    "ajapālaka": ['cped'],
    "ajapālanyagrodha": ['bhs'],
    "ajapārśva": ['mw'],
    "ajara": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ajaraka": ['mw'],
    "ajarant": ['cae'],
    "ajaras": ['mw'],
    "ajarat": ['ap90', 'ddsa', 'mw'],
    "ajarayu": ['gra', 'mw'],
    "ajareḍakā": ['bhs'],
    "ajarya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ajarā": ['mw'],
    "ajarāja": ['ddsa'],
    "ajarāmara": ['cae', 'mw'],
    "ajarāmaratva": ['ddsa'],
    "ajarṣabha": ['mw'],
    "ajasra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ajasram": ['mw'],
    "ajasreṇa": ['mw'],
    "ajastunda": ['mw'],
    "ajastuṃdaṃ": ['ap90'],
    "ajathyā": ['ap90', 'mw'],
    "ajatva": ['mw'],
    "ajatā": ['mw'],
    "ajava": ['bhs'],
    "ajavas": ['ap90', 'gra', 'mw'],
    "ajavasti": ['mw'],
    "ajavisāṇavaddhikā": ['cped'],
    "ajavāha": ['mw'],
    "ajavīthī": ['ddsa', 'mw'],
    "ajaya": ['ap90', 'mw'],
    "ajayapāla": ['mw'],
    "ajayasiṃha": ['mw'],
    "ajayavarman": ['mw'],
    "ajayya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ajayā": ['bhs', 'mw'],
    "ajaśṛṅgī": ['mw'],
    "ajaḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ajaḍadhī": ['mw'],
    "ajaḍā": ['mw'],
    "ajaṃbha": ['ap90'],
    "ajaṭā": ['ap90', 'mw'],
    "ajetavya": ['mw'],
    "ajeya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ajeḷakā": ['cped'],
    "aji": ['ap90'],
    "ajigīṣa": ['ddsa'],
    "ajihma": ['ap90', 'cae', 'ddsa', 'mw'],
    "ajihmaga": ['cae', 'ddsa', 'mw'],
    "ajihmakukṣi": ['bhs'],
    "ajihmāgra": ['mw'],
    "ajihmīkaraṇa": ['bhs'],
    "ajihva": ['mw'],
    "ajihvaka": ['mw'],
    "ajihvaḥ": ['ap90'],
    "ajihvikā": ['cae', 'mw'],
    "ajikakkhāyita": ['cped'],
    "ajikā": ['cped', 'mw'],
    "ajikākhīra": ['cped'],
    "ajina": ['cae', 'cped', 'ddsa', 'mw'],
    "ajinaka": ['bhs'],
    "ajinakhipa": ['bhs'],
    "ajinakkhipa": ['cped'],
    "ajinapattrikā": ['mw'],
    "ajinapattrā": ['mw'],
    "ajinapattrī": ['mw'],
    "ajinaphalā": ['mw'],
    "ajinappaveṇī": ['cped'],
    "ajinaratna": ['mw'],
    "ajinasandha": ['mw'],
    "ajinasāṭī": ['cped'],
    "ajinavāsin": ['mw'],
    "ajinayoni": ['mw'],
    "ajinaṃ": ['ap90'],
    "ajināvatī": ['ddsa'],
    "ajira": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ajiram": ['mw'],
    "ajiravatī": ['bhs', 'mw'],
    "ajiraśocis": ['gra', 'mw'],
    "ajirā": ['mw'],
    "ajirādhirāja": ['mw'],
    "ajirādi": ['mw'],
    "ajirāy": ['cae', 'gra'],
    "ajirāya": ['mw'],
    "ajirīya": ['ap90', 'mw'],
    "ajita": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ajitabala": ['bhs'],
    "ajitabalā": ['mw'],
    "ajitacakra": ['bhs'],
    "ajitakeśakambala": ['bhs', 'mw'],
    "ajitapuṣya": ['bhs'],
    "ajitasena": ['bhs'],
    "ajitasenarājan": ['bhs'],
    "ajitavatigandha": ['bhs'],
    "ajitavikrama": ['mw'],
    "ajitaṃjaya": ['bhs'],
    "ajitendriya": ['cae', 'ddsa', 'mw'],
    "ajitā": ['bhs'],
    "ajitāpīḍa": ['ddsa', 'mw'],
    "ajitātman": ['cae', 'ddsa', 'mw'],
    "ajitāvati": ['bhs'],
    "ajja": ['cped'],
    "ajjadagge": ['cped'],
    "ajjasaṭṭhim": ['cped'],
    "ajjatagge": ['cped'],
    "ajjatana": ['cped'],
    "ajjatā": ['cped'],
    "ajjh-": ['cped'],
    "ajjhabhavi": ['cped'],
    "ajjhabhāsi": ['cped'],
    "ajjhabhāsiṁ": ['cped'],
    "ajjhabhāsiṁsu": ['cped'],
    "ajjhabhū": ['cped'],
    "ajjhagamaṁ": ['cped'],
    "ajjhagamaṁsu": ['cped'],
    "ajjhagamiṁ": ['cped'],
    "ajjhagamuṁ": ['cped'],
    "ajjhagamā": ['cped'],
    "ajjhagaṁ": ['cped'],
    "ajjhagaṁsu": ['cped'],
    "ajjhagā": ['cped'],
    "ajjhagū": ['cped'],
    "ajjhala": ['mw'],
    "ajjhalaṃ": ['ap90'],
    "ajjhappattā": ['cped'],
    "ajjhatta": ['cped'],
    "ajjhattabahiddhā": ['cped'],
    "ajjhattaṁ": ['cped'],
    "ajjhattika": ['cped'],
    "ajjhaṭā": ['ap90', 'mw'],
    "ajjhena": ['cped'],
    "ajjhesana": ['cped'],
    "ajjhesati": ['cped'],
    "ajjhesi": ['cped'],
    "ajjhesitabba": ['cped'],
    "ajjheti": ['cped'],
    "ajjhiṭṭha": ['cped'],
    "ajjhiṭṭhapañha": ['cped'],
    "ajjhogāhati": ['cped'],
    "ajjhogāhitvā": ['cped'],
    "ajjhogāḷha": ['cped'],
    "ajjhogāḷhappatta": ['cped'],
    "ajjhoharati": ['cped'],
    "ajjhoharaṇa": ['cped'],
    "ajjhoharitabba": ['cped'],
    "ajjhoharī": ['cped'],
    "ajjhohāra": ['cped'],
    "ajjhokirati": ['cped'],
    "ajjhokāsa": ['cped'],
    "ajjhokāsagata": ['cped'],
    "ajjhokāse": ['cped'],
    "ajjholambati": ['cped'],
    "ajjhomaddati": ['cped'],
    "ajjhomucchita": ['cped'],
    "ajjhopanna": ['cped'],
    "ajjhosa": ['cped'],
    "ajjhosati": ['cped'],
    "ajjhosita": ['cped'],
    "ajjhositabba": ['cped'],
    "ajjhosāna": ['cped'],
    "ajjhosāya": ['cped'],
    "ajjhotharīyati": ['cped'],
    "ajjhottharati": ['cped'],
    "ajjhottharatitabba": ['cped'],
    "ajjhupagacchati": ['cped'],
    "ajjhupagamana": ['cped'],
    "ajjhupekkha": ['cped'],
    "ajjhupekkhat": ['cped'],
    "ajjhupekkhita": ['cped'],
    "ajjhupekkhitabba": ['cped'],
    "ajjhupekkhitar": ['cped'],
    "ajjhupekkhitvā": ['cped'],
    "ajjhupekkhiṁsu": ['cped'],
    "ajjhupesi": ['cped'],
    "ajjhupeti": ['cped'],
    "ajjhupeyyaṁ": ['cped'],
    "ajjhācarati": ['cped'],
    "ajjhācare": ['cped'],
    "ajjhāciṇṇa": ['cped'],
    "ajjhācāra": ['cped'],
    "ajjhāgamuṁ": ['cped'],
    "ajjhāgāre": ['cped'],
    "ajjhājapajjanta": ['cped'],
    "ajjhājapatti": ['cped'],
    "ajjhājīve": ['cped'],
    "ajjhāpanna": ['cped'],
    "ajjhāpannaka": ['cped'],
    "ajjhāruḷha": ['cped'],
    "ajjhārāma": ['cped'],
    "ajjhārāme": ['cped'],
    "ajjhārūha": ['cped'],
    "ajjhārūhati": ['cped'],
    "ajjhāsayaṁ": ['cped'],
    "ajjhāvasa": ['cped'],
    "ajjhāvasanta": ['cped'],
    "ajjhāvasat": ['cped'],
    "ajjhāvasatha": ['cped'],
    "ajjhāvasathe": ['cped'],
    "ajjhāvasati": ['cped'],
    "ajjhāvasaṁ": ['cped'],
    "ajjhāvasī": ['cped'],
    "ajjhāvuttha": ['cped'],
    "ajjhāyaka": ['cped'],
    "ajjhūpagata": ['cped'],
    "ajjhūpekkhati": ['cped'],
    "ajjuka": ['cped'],
    "ajjukā": ['ap90', 'cae', 'ddsa', 'mw'],
    "ajjuṇho": ['cped'],
    "ajjū": ['mw'],
    "ajjūkā": ['ap90'],
    "ajma": ['cae', 'ddsa', 'gra', 'mw'],
    "ajman": ['ap90', 'gra', 'mw'],
    "ajoṣa": ['ap90', 'gra', 'mw'],
    "ajoṣia": ['gra'],
    "ajoṣya": ['gra', 'mw'],
    "ajra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ajria": ['gra'],
    "ajrya": ['gra', 'mw'],
    "ajugupsita": ['ddsa', 'mw'],
    "ajur": ['cae', 'ddsa', 'gra', 'mw'],
    "ajura": ['ap90'],
    "ajurya": ['cae', 'ddsa', 'gra', 'mw'],
    "ajuṣṭa": ['cae', 'ddsa', 'gra', 'mw'],
    "ajuṣṭi": ['gra', 'mw'],
    "ajuṣṭiḥ": ['ap90'],
    "ajvin": ['ap90', 'cae', 'mw'],
    "ajya": ['gra'],
    "ajyeyatā": ['mw'],
    "ajyeṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ajyeṣṭhavṛtti": ['mw'],
    "ajyāni": ['ddsa', 'mw'],
    "ajyāyas": ['mw'],
    "ajña": ['ap90', 'cae', 'ddsa', 'mw'],
    "ajñakā": ['ap90', 'mw'],
    "ajñatva": ['mw'],
    "ajñatā": ['cae', 'ddsa', 'mw'],
    "ajñeya": ['cae', 'ddsa', 'mw'],
    "ajñikā": ['mw'],
    "ajñāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "ajñānabandhana": ['mw'],
    "ajñānabodhinī": ['mw'],
    "ajñānaja": ['cae'],
    "ajñānakṛta": ['mw'],
    "ajñānatas": ['ddsa', 'mw'],
    "ajñānatva": ['mw'],
    "ajñānatā": ['mw'],
    "ajñānavidhvaṃsana": ['bhs', 'mw'],
    "ajñānin": ['ap90', 'mw'],
    "ajñānārtha": ['ddsa'],
    "ajñānāt": ['mw'],
    "ajñās": ['cae', 'ddsa', 'gra', 'mw'],
    "ajñāta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ajñātabhukta": ['mw'],
    "ajñātaka": ['mw'],
    "ajñātaketa": ['gra', 'mw'],
    "ajñātakulaśīla": ['mw'],
    "ajñātam": ['mw'],
    "ajñātavāsa": ['mw'],
    "ajñātayakṣma": ['gra', 'mw'],
    "ajñātaśīla": ['mw'],
    "ajñāti": ['cae', 'ddsa', 'mw'],
    "ajñātiḥ": ['ap90'],
    "ajñātvā": ['ddsa', 'mw'],
    "ajā": ['ap90', 'cped', 'ddsa', 'mw'],
    "ajāda": ['mw'],
    "ajādanī": ['mw'],
    "ajādi": ['mw'],
    "ajāgala": ['mw'],
    "ajāgalastana": ['mw'],
    "ajāgara": ['ap90', 'mw'],
    "ajāji": ['mw'],
    "ajājiḥ": ['ap90'],
    "ajājī": ['mw'],
    "ajājīva": ['mw'],
    "ajākṛpāṇīya": ['mw'],
    "ajākṣīra": ['mw'],
    "ajāmi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ajāmitva": ['mw'],
    "ajāmitā": ['mw'],
    "ajānaka": ['bhs'],
    "ajānanaka": ['bhs'],
    "ajānant": ['cae'],
    "ajānat": ['ddsa', 'mw'],
    "ajāneya": ['ap90'],
    "ajāni": ['mw'],
    "ajānika": ['ap90'],
    "ajāniḥ": ['ap90'],
    "ajāntrī": ['mw'],
    "ajāpakvaṃ": ['ap90'],
    "ajāpayas": ['mw'],
    "ajāpālaka": ['mw'],
    "ajāta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ajātaka": ['bhs'],
    "ajātakakud": ['mw'],
    "ajātaloman": ['mw'],
    "ajātapakṣa": ['cae', 'ddsa', 'mw'],
    "ajātaulvali": ['mw'],
    "ajātavyavahāra": ['mw'],
    "ajātavyañjana": ['mw'],
    "ajātaśatru": ['bhs', 'cae', 'gra', 'mw'],
    "ajātaśatrukaukṛtyavinodana": ['bhs'],
    "ajāti": ['ap90', 'ddsa', 'mw'],
    "ajātva": ['mw'],
    "ajātākhya": ['bhs'],
    "ajātānuśaya": ['mw'],
    "ajātāri": ['ddsa', 'mw'],
    "ajāvi": ['cae', 'ddsa', 'gra', 'mw'],
    "ajāvika": ['mw'],
    "ajāyamāna": ['mw'],
    "ajāśua": ['gra'],
    "ajāśva": ['ddsa', 'gra', 'mw'],
    "ajīgar": ['ddsa'],
    "ajīgarta": ['cae', 'ddsa', 'mw'],
    "ajīgartaḥ": ['ap90'],
    "ajīkava": ['mw'],
    "ajīkavaṃ": ['ap90'],
    "ajīrti": ['ddsa', 'mw'],
    "ajīryat": ['mw'],
    "ajīryattā": ['mw'],
    "ajīryatā": ['cae'],
    "ajīrṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ajīrṇi": ['mw'],
    "ajīrṇin": ['ddsa', 'mw'],
    "ajīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "ajītapunarvaṇya": ['mw'],
    "ajīti": ['ddsa', 'gra', 'mw'],
    "ajītiḥ": ['ap90'],
    "ajīva": ['ap90', 'cae', 'ddsa', 'mw'],
    "ajīvana": ['ap90', 'mw'],
    "ajīvani": ['mw'],
    "ajīvaniḥ": ['ap90'],
    "ajīvant": ['cae'],
    "ajīvat": ['ddsa', 'mw'],
    "ajīvika": ['bhs'],
    "ajīvita": ['cae', 'ddsa', 'mw'],
    "ajū": ['mw'],
    "ajūryat": ['gra', 'mw'],
    "ak": ['ap90', 'mw'],
    "aka": ['ap90', 'cae', 'ddsa', 'mw'],
    "akabara": ['mw'],
    "akabbara": ['mw'],
    "akaca": ['ap90', 'mw'],
    "akaddama": ['cped'],
    "akadvada": ['ddsa'],
    "akaitava": ['cae', 'ddsa'],
    "akakkasa": ['cped'],
    "akala": ['ap90', 'mw'],
    "akalaha": ['cae', 'cped'],
    "akalaṅka": ['ddsa', 'mw'],
    "akali": ['ddsa', 'mw'],
    "akaliprasara": ['ddsa'],
    "akalita": ['cae', 'ddsa', 'mw'],
    "akalka": ['ap90', 'mw'],
    "akalkakalila": ['ddsa'],
    "akalkala": ['mw'],
    "akalkana": ['ap90', 'mw'],
    "akalkatā": ['ap90', 'ddsa', 'mw'],
    "akalkā": ['mw'],
    "akalla": ['cped'],
    "akallarūpa": ['cped'],
    "akalmaṣa": ['cae', 'mw'],
    "akalmāṣa": ['bhs', 'mw'],
    "akalpa": ['ap90', 'cae', 'gra', 'mw'],
    "akalpika": ['bhs'],
    "akalpita": ['ap90', 'mw'],
    "akalpya": ['bhs'],
    "akaluṣa": ['bhs'],
    "akalya": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "akalyaka": ['cped'],
    "akalyāṇa": ['ap90', 'mw'],
    "akamma": ['cped'],
    "akammaniya": ['cped'],
    "akammañña": ['cped'],
    "akammāsa": ['cped'],
    "akampana": ['mw'],
    "akampi": ['cped'],
    "akampin": ['cped'],
    "akampita": ['cae', 'cped', 'ddsa', 'mw'],
    "akampitasāgara": ['bhs'],
    "akampittha": ['cped'],
    "akampiya": ['bhs'],
    "akampya": ['bhs', 'mw'],
    "akampyanetra": ['bhs'],
    "akandasamutthita": ['cae'],
    "akaniṣṭha": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "akaniṣṭhaga": ['mw'],
    "akaniṣṭhapa": ['mw'],
    "akaniṣṭhika": ['bhs'],
    "akaniṭṭha": ['cped'],
    "akaniṭṭhagāmi": ['cped'],
    "akaniṭṭhagāmin": ['cped'],
    "akanta": ['cped'],
    "akantehi": ['cped'],
    "akantena": ['cped'],
    "akantika": ['cped'],
    "akantiya": ['cped'],
    "akanyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "akapilacchavi": ['ddsa'],
    "akappakata": ['cped'],
    "akappayi": ['cped'],
    "akappayiṁsu": ['cped'],
    "akappayuṁ": ['cped'],
    "akappiya": ['cped'],
    "akapīvat": ['mw'],
    "akara": ['ap90', 'mw'],
    "akaramha": ['cped'],
    "akaraṇa": ['cae', 'cped', 'ddsa', 'mw'],
    "akaraṇaṃ": ['ap90'],
    "akaraṇi": ['mw'],
    "akaraṇiḥ": ['ap90'],
    "akaraṇīya": ['cped', 'mw'],
    "akardama": ['bhs'],
    "akarimha": ['cped'],
    "akaritvā": ['cped'],
    "akariṣyat": ['mw'],
    "akarkaśa": ['mw'],
    "akarmabhoga": ['mw'],
    "akarmaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "akarmakṛt": ['cae', 'ddsa'],
    "akarman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akarmaprāpti": ['ddsa'],
    "akarmaśrānta": ['ddsa'],
    "akarmaśīla": ['ddsa'],
    "akarmaṇya": ['ap90', 'ddsa', 'mw'],
    "akarmikā": ['mw'],
    "akarmānvita": ['mw'],
    "akaronta": ['cped'],
    "akartana": ['ap90', 'mw'],
    "akartavya": ['cae', 'ddsa'],
    "akartṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "akartṛtva": ['mw'],
    "akaruṁ": ['cped'],
    "akaruṇa": ['cae', 'ddsa', 'mw'],
    "akaruṇatva": ['mw'],
    "akarā": ['mw'],
    "akarāma": ['cped'],
    "akarī": ['cped'],
    "akarṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "akarṇadhāra": ['ddsa', 'mw'],
    "akarṇaka": ['mw'],
    "akarṇya": ['ap90', 'mw'],
    "akarṇīya": ['mw'],
    "akasiralābhin": ['cped'],
    "akasmādāgantu": ['ddsa'],
    "akasmāt": ['ap90', 'cae', 'ddsa', 'mw'],
    "akasyavid": ['mw'],
    "akasāva": ['cped'],
    "akata": ['cped'],
    "akatabhīruttāṇa": ['cped'],
    "akatahattha": ['cped'],
    "akataludda": ['cped'],
    "akatamallaka": ['cped'],
    "akatavedi": ['cped'],
    "akatavedin": ['cped'],
    "akataññu": ['cped'],
    "akathaha": ['mw'],
    "akatham": ['ddsa'],
    "akathaṁkathi": ['cped'],
    "akathaṁkathin": ['cped'],
    "akathita": ['ap90', 'cae', 'ddsa'],
    "akathya": ['mw'],
    "akatigāthā": ['bhs'],
    "akattha": ['cped'],
    "akatthana": ['ddsa', 'mw'],
    "akatupāsana": ['cped'],
    "akausīdya": ['bhs'],
    "akauśala": ['ddsa', 'mw'],
    "akava": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akavaca": ['mw'],
    "akavara": ['mw'],
    "akavi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akavāri": ['gra', 'mw'],
    "akavātaka": ['cped'],
    "akavāṭa": ['cped'],
    "akavāṭābaddha": ['cped'],
    "akaḍama": ['mw'],
    "akaḍamacakra": ['mw'],
    "akaḍamaṃ": ['ap90'],
    "akaṁ": ['cped'],
    "akaṁsu": ['cped'],
    "akaṃ": ['ap90'],
    "akaṃpana": ['ap90'],
    "akaṃpita": ['ap90'],
    "akaṅkha": ['cped'],
    "akaṅkhi": ['cped'],
    "akaṅkhin": ['cped'],
    "akaṇa": ['bhs', 'cped'],
    "akaṇaka": ['bhs', 'mw'],
    "akaṇha": ['cped'],
    "akaṇika": ['cped'],
    "akaṇṭaka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "akaṇṭha": ['ddsa', 'mw'],
    "akaṭa": ['cped'],
    "akaṭavidha": ['cped'],
    "akaṭayūsa": ['cped'],
    "akaṭhora": ['cae', 'mw'],
    "akaṭuka": ['ddsa', 'mw'],
    "akaṭuphala": ['mw'],
    "akaṭānudhamma": ['cped'],
    "akaṭṭhapāka": ['cped'],
    "aketana": ['mw'],
    "aketu": ['ap90', 'cae', 'gra', 'mw'],
    "akevala": ['cped'],
    "akevali": ['cped'],
    "akevalin": ['cped'],
    "akeśa": ['ap90', 'mw'],
    "akeśava": ['ddsa'],
    "akeṭubhi": ['cped'],
    "akeṭubhin": ['cped'],
    "akhalita": ['bhs', 'cped'],
    "akhanat": ['gra', 'mw'],
    "akharva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akharvan": ['mw'],
    "akharvā": ['mw'],
    "akhañja": ['ddsa'],
    "akhaṃḍa": ['ap90'],
    "akhaṃḍana": ['ap90'],
    "akhaṃḍita": ['ap90'],
    "akhaṇḍa": ['cae', 'cped', 'ddsa', 'mw'],
    "akhaṇḍacārin": ['bhs'],
    "akhaṇḍakala": ['cae', 'mw'],
    "akhaṇḍamaṇḍala": ['mw'],
    "akhaṇḍana": ['mw'],
    "akhaṇḍita": ['cae', 'ddsa', 'mw'],
    "akhaṇḍitacāritra": ['cae'],
    "akhaṇḍitartu": ['mw'],
    "akhaṇḍitājña": ['ddsa'],
    "akhaṇḍopadhi": ['mw'],
    "akhaṭṭa": ['mw'],
    "akhaṭṭaḥ": ['ap90'],
    "akhaṭṭi": ['mw'],
    "akhaṭṭiḥ": ['ap90'],
    "akheda": ['cae', 'ddsa'],
    "akhedin": ['ap90', 'mw'],
    "akheditva": ['mw'],
    "akhettaññu": ['cped'],
    "akheṭika": ['mw'],
    "akheṭikaḥ": ['ap90'],
    "akhidra": ['ap90', 'cae', 'mw'],
    "akhidrayāman": ['cae', 'gra', 'mw'],
    "akhila": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "akhilajāta": ['cped'],
    "akhilena": ['mw'],
    "akhilātman": ['mw'],
    "akhilīkṛ": ['mw'],
    "akhinna": ['ap90', 'ddsa', 'mw'],
    "akhinnavacana": ['bhs'],
    "akhkhala": ['ap90', 'ddsa', 'mw'],
    "akhkhalī": ['cae'],
    "akhkhalīkṛ": ['gra'],
    "akhkhalīkṛtyā": ['mw'],
    "akhyāta": ['mw'],
    "akhyāti": ['mw'],
    "akhyātikara": ['mw'],
    "akhyātiḥ": ['ap90'],
    "akhādana": ['cped'],
    "akhādita": ['cae'],
    "akhādya": ['mw'],
    "akhārika": ['cped'],
    "akhāta": ['ap90', 'mw'],
    "akhīṇāsava": ['cped'],
    "akicca": ['cped'],
    "akiccakāri": ['cped'],
    "akiccakārin": ['cped'],
    "akiccha": ['cped'],
    "akicchalābhi": ['cped'],
    "akicchalābhin": ['cped'],
    "akicchena": ['cped'],
    "akilanta": ['cped'],
    "akilina": ['ddsa', 'mw'],
    "akilviṣa": ['mw'],
    "akilāntaka": ['bhs'],
    "akilāsin": ['bhs'],
    "akilāsitā": ['bhs'],
    "akilāsu": ['cped'],
    "akiriyavāda": ['cped'],
    "akiriyavādi": ['cped'],
    "akiriyavādin": ['cped'],
    "akiriyā": ['cped'],
    "akisaralābhin": ['bhs'],
    "akissava": ['cped'],
    "akitava": ['mw'],
    "akittayi": ['cped'],
    "akitti": ['cped'],
    "akittisañjanana": ['cped'],
    "akittisañjananī": ['cped'],
    "akiñcana": ['cped', 'ddsa', 'mw'],
    "akiñcanatva": ['mw'],
    "akiñcanatā": ['mw'],
    "akiñcaniman": ['mw'],
    "akiñcijjña": ['ddsa'],
    "akiñcitkara": ['ddsa'],
    "akiṃcana": ['ap90', 'cae'],
    "akiṃcanatā": ['ap90'],
    "akiṃcaniman": ['ap90'],
    "akiṃcid": ['mw'],
    "akiṃcijjña": ['ap90'],
    "akiṃcitkara": ['ap90', 'mw'],
    "akiṃcitkurvāṇa": ['cae'],
    "akka": ['cped'],
    "akkamati": ['cped'],
    "akkamitabba": ['cped'],
    "akkamitvā": ['cped'],
    "akkamiṁsu": ['cped'],
    "akkanta": ['cped'],
    "akkanāla": ['cped'],
    "akkha": ['cped'],
    "akkhadassa": ['cped'],
    "akkhadhutta": ['cped'],
    "akkhama": ['cped'],
    "akkhambiya": ['cped'],
    "akkhantī": ['cped'],
    "akkhara": ['cped'],
    "akkharappabheda": ['cped'],
    "akkharikā": ['cped'],
    "akkhata": ['cped'],
    "akkhayita": ['cped'],
    "akkhaṇa": ['cped'],
    "akkhaṇavedhi": ['cped'],
    "akkhaṇavedhin": ['cped'],
    "akkhaṇdakāri": ['cped'],
    "akkhaṇdakārin": ['cped'],
    "akkhaṇḍa": ['cped'],
    "akkheyya": ['cped'],
    "akkhi": ['cped'],
    "akkhigūthaka": ['cped'],
    "akkhikahāraka": ['cped'],
    "akkhikūpa": ['cped'],
    "akkhissaṁ": ['cped'],
    "akkhitta": ['cped'],
    "akkhittacitta": ['cped'],
    "akkhitārakā": ['cped'],
    "akkhudda": ['cped'],
    "akkhuddāvakāsa": ['cped'],
    "akkhāhata": ['cped'],
    "akkhāna": ['cped'],
    "akkhāsi": ['cped'],
    "akkhāta": ['cped'],
    "akkhātar": ['cped'],
    "akkhāti": ['cped'],
    "akkhātā": ['cped'],
    "akkhāya": ['cped'],
    "akkhāyati": ['cped'],
    "akkhāyita": ['cped'],
    "akkhīṇāsava": ['cped'],
    "akkocchi": ['cped'],
    "akkodha": ['cped'],
    "akkodhana": ['cped'],
    "akkodhupāyāsi": ['cped'],
    "akkodhupāyāsin": ['cped'],
    "akkosa": ['cped'],
    "akkosaka": ['cped'],
    "akkosakaparibhāsika": ['cped'],
    "akkosanta": ['cped'],
    "akkosavatthu": ['cped'],
    "akkoseti": ['cped'],
    "akkositabba": ['cped'],
    "akkosiyamāna": ['cped'],
    "akkudhasanta": ['cped'],
    "akkulo": ['cped'],
    "akkuṭṭha": ['cped'],
    "akkuṭṭhasanta": ['cped'],
    "akkuṭṭhavandita": ['cped'],
    "akkā": ['ap90', 'mw'],
    "akkādevī": ['mw'],
    "aklama": ['mw'],
    "akledya": ['ddsa', 'mw'],
    "akleśa": ['cae', 'ddsa', 'mw'],
    "aklikā": ['ap90', 'mw'],
    "aklinna": ['ap90'],
    "aklinnagātra": ['bhs'],
    "aklinnavartman": ['mw'],
    "akliṣṭa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "akliṣṭakarman": ['mw'],
    "akliṣṭakāra": ['ddsa'],
    "akliṣṭakārin": ['mw'],
    "akliṣṭavrata": ['mw'],
    "aklāntaka": ['bhs'],
    "aklība": ['ddsa', 'mw'],
    "akna": ['ddsa'],
    "aknopana": ['mw'],
    "akopa": ['cped', 'mw'],
    "akopana": ['mw'],
    "akopayant": ['cae'],
    "akopitā": ['ddsa'],
    "akopiyamāna": ['cped'],
    "akopya": ['bhs', 'mw'],
    "akotūhalamaṅgalika": ['cped'],
    "akovida": ['cped', 'mw'],
    "akoṭa": ['mw'],
    "akoṭaḥ": ['ap90'],
    "akoṭi": ['bhs'],
    "akra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akrama": ['ap90', 'cae', 'mw'],
    "akramam": ['mw'],
    "akramaśas": ['mw'],
    "akramoḍhā": ['mw'],
    "akrandita": ['mw'],
    "akrata": ['ddsa'],
    "akratu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akravihasta": ['gra', 'mw'],
    "akravyād": ['cae', 'ddsa', 'mw'],
    "akravyāda": ['cae', 'mw'],
    "akriya": ['ap90', 'mw'],
    "akriyamāṇa": ['ddsa'],
    "akriyā": ['cae', 'cped', 'ddsa', 'mw'],
    "akriyāka": ['ddsa'],
    "akrodha": ['ap90', 'cae', 'ddsa', 'mw'],
    "akrodhamaya": ['mw'],
    "akrodhana": ['ap90', 'cae', 'mw'],
    "akrudhyanatā": ['bhs'],
    "akrudhyat": ['mw'],
    "akrānta": ['mw'],
    "akrāntā": ['mw'],
    "akrāṃta": ['ap90'],
    "akrīta": ['cae', 'mw'],
    "akrīḍat": ['gra', 'mw'],
    "akrūra": ['ap90', 'cae', 'ddsa', 'mw'],
    "akta": ['ap90', 'ddsa', 'mw'],
    "akti": ['mw'],
    "aktos": ['mw'],
    "aktraṃ": ['ap90'],
    "aktu": ['cae', 'ddsa', 'gra', 'mw'],
    "aktubhis": ['mw'],
    "aktuḥ": ['ap90'],
    "aktā": ['cae', 'gra', 'mw'],
    "akubba": ['cped'],
    "akubbamāna": ['cped'],
    "akubbat": ['cped'],
    "akudhriac": ['gra'],
    "akudhryac": ['gra'],
    "akudhryak": ['ddsa'],
    "akudhryañc": ['mw'],
    "akudhryaṃc": ['ap90'],
    "akuha": ['ap90', 'cped', 'mw'],
    "akuhaka": ['cped', 'mw'],
    "akujjana": ['cped'],
    "akukkucca": ['cped'],
    "akukkuccaka": ['cped'],
    "akukkuccakajāta": ['cped'],
    "akukkukajāta": ['cped'],
    "akukkukata": ['cped'],
    "akula": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "akulaja": ['ddsa'],
    "akulaka": ['mw'],
    "akulaputta": ['cped'],
    "akulatā": ['cae', 'mw'],
    "akulejyeṣṭhāpacāyaka": ['bhs'],
    "akulika": ['bhs'],
    "akulā": ['mw'],
    "akulīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "akumbha": ['bhs', 'mw'],
    "akumāra": ['gra', 'mw'],
    "akuppa": ['cped'],
    "akuppadhamma": ['cped'],
    "akuppamāna": ['cped'],
    "akupya": ['mw'],
    "akupyaka": ['mw'],
    "akupyat": ['mw'],
    "akupyaṃ": ['ap90'],
    "akurvant": ['cae'],
    "akurvāṇa": ['cae'],
    "akusala": ['cped'],
    "akusalabhāgiya": ['cped'],
    "akusalapakkhika": ['cped'],
    "akusalā dhammā": ['cped'],
    "akusuma": ['mw'],
    "akusumita": ['cae', 'ddsa'],
    "akusīda": ['mw'],
    "akusīta": ['cped'],
    "akutas": ['ddsa', 'mw'],
    "akutaścala": ['mw'],
    "akutaścana": ['mw'],
    "akutaścid": ['mw'],
    "akutaścidbhaya": ['ddsa', 'mw'],
    "akutaḥ": ['ap90'],
    "akutobhaya": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "akutomṛtyu": ['mw'],
    "akutra": ['gra', 'mw'],
    "akutracabhaya": ['ddsa', 'mw'],
    "akutrā": ['gra', 'mw'],
    "akutsayant": ['cae'],
    "akutsayat": ['mw'],
    "akutsita": ['ddsa', 'mw'],
    "akutūhala": ['mw'],
    "akuñcita": ['ddsa'],
    "akuśala": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "akuśalamūla": ['bhs'],
    "akuśīda": ['mw'],
    "akuśīdavartin": ['bhs'],
    "akuṃṭha": ['ap90'],
    "akuṃṭhita": ['ap90'],
    "akuṇḍala": ['mw'],
    "akuṇṭha": ['mw'],
    "akuṇṭhadhiṣṇya": ['mw'],
    "akuṇṭhita": ['ddsa', 'mw'],
    "akuṣṭhipṛṣat": ['mw'],
    "akuṭila": ['ddsa'],
    "akāca": ['bhs', 'cped'],
    "akākolīna": ['bhs'],
    "akāku": ['ddsa'],
    "akāla": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "akālacaryā": ['ddsa'],
    "akālacāri": ['cped'],
    "akālacārin": ['cped'],
    "akālacīvara": ['cped'],
    "akāladarśana": ['bhs'],
    "akāladurdina": ['cae'],
    "akālahīnam": ['cae', 'ddsa', 'mw'],
    "akālaja": ['mw'],
    "akālajaladodaya": ['mw'],
    "akālajāta": ['mw'],
    "akālaka": ['bhs', 'mw'],
    "akālakaumudī": ['bhs', 'mw'],
    "akālakhādyaka": ['bhs'],
    "akālakusuma": ['ddsa', 'mw'],
    "akālakuṣmāṇḍa": ['mw'],
    "akālakṣepam": ['cae', 'ddsa', 'mw'],
    "akālamegha": ['cped'],
    "akālameghodaya": ['mw'],
    "akālaniyama": ['ddsa'],
    "akālapuppha": ['cped'],
    "akālasaha": ['ddsa', 'mw'],
    "akālatas": ['mw'],
    "akālavelā": ['ddsa', 'mw'],
    "akālavādi": ['cped'],
    "akālavādin": ['cped'],
    "akālaññu": ['cped'],
    "akāle": ['cped', 'mw'],
    "akālena": ['cped'],
    "akālika": ['bhs', 'cped'],
    "akālikam": ['mw'],
    "akālotpanna": ['mw'],
    "akālya": ['mw'],
    "akāma": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "akāmahata": ['mw'],
    "akāmaka": ['bhs', 'cped'],
    "akāmakarśana": ['gra', 'mw'],
    "akāmakāmi": ['cped'],
    "akāmakāmin": ['bhs', 'cped'],
    "akāmam": ['bhs'],
    "akāmasaṃjñapana": ['mw'],
    "akāmatas": ['ddsa', 'mw'],
    "akāmataḥ": ['ap90'],
    "akāmatā": ['ap90', 'ddsa', 'mw'],
    "akāmin": ['ddsa', 'mw'],
    "akāmā": ['cped'],
    "akāpurisasevita": ['cped'],
    "akāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "akāraka": ['cae', 'cped', 'ddsa'],
    "akārayi": ['cped'],
    "akārayiṁ": ['cped'],
    "akāraṇa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "akāraṇabandhu": ['cae'],
    "akāraṇam": ['mw'],
    "akāraṇamāraka": ['cae'],
    "akāraṇe": ['mw'],
    "akāraṇena": ['mw'],
    "akāraṇotpanna": ['mw'],
    "akāraṇāt": ['mw'],
    "akāresi": ['cped'],
    "akārin": ['mw'],
    "akāriya": ['cped'],
    "akārpaṇya": ['ap90', 'ddsa'],
    "akārya": ['ap90', 'cae', 'ddsa', 'mw'],
    "akāryakaraṇa": ['ddsa'],
    "akāryakārin": ['cae', 'ddsa', 'mw'],
    "akāryopaka": ['bhs'],
    "akārṇaveṣṭakika": ['ap90', 'mw'],
    "akārṣṇya": ['mw'],
    "akāsi": ['cped'],
    "akāsika": ['cped'],
    "akāsiṁ": ['cped'],
    "akāsāra": ['mw'],
    "akātara": ['ddsa', 'mw'],
    "akāvaṅka": ['mw'],
    "akāya": ['ap90', 'mw'],
    "akāyabandhana": ['cped'],
    "akāyikā": ['bhs', 'mw'],
    "akāyūpaga": ['cped'],
    "akāṃḍa": ['ap90'],
    "akāṃḍe": ['ap90'],
    "akāṇa": ['mw'],
    "akāṇḍa": ['cae', 'ddsa', 'mw'],
    "akāṇḍapātajāta": ['mw'],
    "akāṇḍaśūla": ['mw'],
    "akāṇḍe": ['mw'],
    "akīrtana": ['ddsa'],
    "akīrtanīya": ['ddsa'],
    "akīrti": ['cae', 'ddsa', 'mw'],
    "akīrtikara": ['mw'],
    "akīrtita": ['cae', 'ddsa'],
    "akīrtiḥ": ['ap90'],
    "akūhaka": ['bhs'],
    "akūja": ['mw'],
    "akūjana": ['cped', 'mw'],
    "akūpāra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akūpārā": ['mw'],
    "akūrca": ['ap90', 'mw'],
    "akūrmapṛṣat": ['mw'],
    "akūta": ['cped'],
    "akūvāra": ['ap90', 'mw'],
    "akūṭa": ['ddsa', 'mw'],
    "akṛcchra": ['ap90', 'mw'],
    "akṛcchralaṅghya": ['ddsa'],
    "akṛcchralābhin": ['bhs'],
    "akṛcchrin": ['ddsa', 'mw'],
    "akṛmiparisṛpta": ['mw'],
    "akṛpa": ['ddsa', 'mw'],
    "akṛpaṇa": ['cae', 'ddsa', 'mw'],
    "akṛpaṇam": ['bhs'],
    "akṛta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akṛtabuddhi": ['cae', 'ddsa', 'mw'],
    "akṛtabuddhitva": ['mw'],
    "akṛtacūḍa": ['cae', 'mw'],
    "akṛtajña": ['bhs', 'cae', 'ddsa', 'mw'],
    "akṛtajñatā": ['mw'],
    "akṛtaka": ['bhs', 'ddsa'],
    "akṛtakāram": ['mw'],
    "akṛtakārya": ['mw'],
    "akṛtakṛtya": ['ddsa', 'mw'],
    "akṛtalakṣaṇa": ['ddsa'],
    "akṛtaprasāda": ['cae'],
    "akṛtapuṇya": ['cae', 'ddsa'],
    "akṛtapūrva": ['cae', 'ddsa'],
    "akṛtasatkāra": ['cae'],
    "akṛtasaṅkalpa": ['ddsa'],
    "akṛtavaira": ['cae'],
    "akṛtavidya": ['ddsa'],
    "akṛtavraṇa": ['mw'],
    "akṛtaśmaśāna": ['mw'],
    "akṛtaśrama": ['ddsa'],
    "akṛtin": ['ap90', 'mw'],
    "akṛtitva": ['mw'],
    "akṛtrima": ['ddsa', 'mw'],
    "akṛtsna": ['cae', 'ddsa', 'mw'],
    "akṛtsnavid": ['cae', 'ddsa'],
    "akṛtta": ['ap90', 'gra', 'mw'],
    "akṛttaruc": ['gra', 'mw'],
    "akṛtvā": ['ddsa'],
    "akṛtya": ['ap90', 'cae', 'ddsa', 'mw'],
    "akṛtyakārin": ['mw'],
    "akṛtā": ['mw'],
    "akṛtāhnika": ['cae'],
    "akṛtānna": ['cae'],
    "akṛtārtha": ['cae', 'ddsa', 'mw'],
    "akṛtāstra": ['mw'],
    "akṛtātman": ['cae', 'ddsa', 'mw'],
    "akṛśa": ['ap90', 'mw'],
    "akṛśakīrti": ['mw'],
    "akṛśalakṣmī": ['ddsa', 'mw'],
    "akṛśāśva": ['mw'],
    "akṛṣīvala": ['cae', 'ddsa', 'gra', 'mw'],
    "akṛṣṇa": ['ap90'],
    "akṛṣṇakarman": ['mw'],
    "akṛṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "akṛṣṭapacya": ['mw'],
    "akṣ": ['ap90', 'ddsa', 'gra', 'mw'],
    "akṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "akṣabhaṅga": ['cae'],
    "akṣabhā": ['mw'],
    "akṣabhāga": ['mw'],
    "akṣabhāra": ['mw'],
    "akṣabhūmi": ['ddsa', 'mw'],
    "akṣacaraṇa": ['mw'],
    "akṣadarśaka": ['mw'],
    "akṣadevana": ['mw'],
    "akṣadevin": ['mw'],
    "akṣadhara": ['mw'],
    "akṣadharma": ['mw'],
    "akṣadhur": ['mw'],
    "akṣadhurā": ['mw'],
    "akṣadhūrta": ['mw'],
    "akṣadhūrtila": ['mw'],
    "akṣadrugdha": ['mw'],
    "akṣadvāra": ['mw'],
    "akṣadyū": ['mw'],
    "akṣadyūta": ['cae', 'ddsa', 'mw'],
    "akṣadyūtādi": ['mw'],
    "akṣadāya": ['mw'],
    "akṣadṛkkarman": ['mw'],
    "akṣadṛś": ['mw'],
    "akṣaglaha": ['mw'],
    "akṣahṛdaya": ['cae', 'mw'],
    "akṣahṛdayajña": ['mw'],
    "akṣaitrajñya": ['mw'],
    "akṣaja": ['mw'],
    "akṣajña": ['ddsa'],
    "akṣaka": ['mw'],
    "akṣakarṇa": ['mw'],
    "akṣakaḥ": ['ap90'],
    "akṣakitava": ['mw'],
    "akṣakuśala": ['mw'],
    "akṣakāma": ['mw'],
    "akṣakī": ['mw'],
    "akṣakṣapaṇa": ['mw'],
    "akṣala": ['bhs'],
    "akṣama": ['ap90', 'cae', 'ddsa', 'mw'],
    "akṣamada": ['ddsa', 'mw'],
    "akṣamatā": ['mw'],
    "akṣamaṇa": ['bhs'],
    "akṣamin": ['ddsa', 'mw'],
    "akṣamā": ['ddsa', 'mw'],
    "akṣamālikā": ['ddsa', 'mw'],
    "akṣamālin": ['mw'],
    "akṣamālā": ['cae', 'ddsa', 'mw'],
    "akṣamātra": ['bhs', 'ddsa', 'mw'],
    "akṣan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akṣanaipuṇa": ['cae', 'ddsa', 'mw'],
    "akṣanaipuṇya": ['mw'],
    "akṣanvat": ['mw'],
    "akṣapad": ['mw'],
    "akṣapari": ['mw'],
    "akṣaparājaya": ['mw'],
    "akṣapaṭala": ['ddsa', 'mw'],
    "akṣaprapātana": ['mw'],
    "akṣapriya": ['cae', 'ddsa', 'mw'],
    "akṣapāda": ['mw'],
    "akṣapāta": ['mw'],
    "akṣapātana": ['mw'],
    "akṣapāṭa": ['mw'],
    "akṣapāṭaka": ['mw'],
    "akṣapāṭika": ['mw'],
    "akṣapīḍa": ['mw'],
    "akṣapīḍā": ['mw'],
    "akṣara": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akṣarabhāj": ['mw'],
    "akṣaracana": ['mw'],
    "akṣaracañcu": ['mw'],
    "akṣaracaṇa": ['mw'],
    "akṣaracchandas": ['cae'],
    "akṣarachandas": ['mw'],
    "akṣaracuñcu": ['mw'],
    "akṣaracyutaka": ['mw'],
    "akṣarajananī": ['mw'],
    "akṣarajīvaka": ['mw'],
    "akṣarajīvika": ['mw'],
    "akṣarajīvin": ['mw'],
    "akṣaraka": ['mw'],
    "akṣarakara": ['mw'],
    "akṣarakaṃ": ['ap90'],
    "akṣaramukha": ['mw'],
    "akṣaramuṣṭikā": ['mw'],
    "akṣaranyāsa": ['mw'],
    "akṣarapada": ['cae'],
    "akṣarapaṅkti": ['cae', 'mw'],
    "akṣarasadhātu": ['mw'],
    "akṣarasampad": ['mw'],
    "akṣarasamāmnāya": ['mw'],
    "akṣarasaṃghāta": ['mw'],
    "akṣarasaṃhitā": ['mw'],
    "akṣarasaṃhāta": ['mw'],
    "akṣarasaṃsthāna": ['mw'],
    "akṣaratūlikā": ['mw'],
    "akṣaravat": ['mw'],
    "akṣaravinyāsa": ['mw'],
    "akṣaraśas": ['mw'],
    "akṣaraśaḥ": ['ap90'],
    "akṣaraśikṣā": ['mw'],
    "akṣaraśūnya": ['mw'],
    "akṣaresthā": ['mw'],
    "akṣarya": ['ap90', 'mw'],
    "akṣaryaṃrevat": ['mw'],
    "akṣarā": ['cae', 'gra', 'mw'],
    "akṣarāja": ['mw'],
    "akṣarākṣara": ['mw'],
    "akṣarāntara": ['mw'],
    "akṣarāpagata": ['bhs'],
    "akṣarāṅga": ['mw'],
    "akṣarī": ['ap90'],
    "akṣasaṅgam": ['mw'],
    "akṣastuṣa": ['mw'],
    "akṣasūkta": ['mw'],
    "akṣasūtra": ['mw'],
    "akṣasūtravalayin": ['mw'],
    "akṣat": ['ddsa'],
    "akṣata": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akṣatabuddhi": ['bhs'],
    "akṣatakeśara": ['ddsa'],
    "akṣatattva": ['mw'],
    "akṣatattvavid": ['mw'],
    "akṣatayoni": ['cae', 'mw'],
    "akṣatra": ['ap90', 'cae', 'ddsa', 'mw'],
    "akṣatā": ['mw'],
    "akṣatāmaya": ['mw'],
    "akṣauhiṇī": ['ap90', 'cae', 'ddsa', 'mw'],
    "akṣavat": ['mw'],
    "akṣavatī": ['ap90', 'cae', 'ddsa', 'mw'],
    "akṣavid": ['mw'],
    "akṣavāma": ['mw'],
    "akṣavāpa": ['mw'],
    "akṣavāṭa": ['mw'],
    "akṣavṛtta": ['mw'],
    "akṣaya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "akṣayabuddhavaṃśanirdeśā": ['bhs'],
    "akṣayabuddhavaṃśavyūha": ['bhs'],
    "akṣayaguṇa": ['mw'],
    "akṣayakaraṇḍa": ['bhs'],
    "akṣayakaraṇḍā": ['bhs'],
    "akṣayaloka": ['mw'],
    "akṣayamati": ['bhs', 'mw'],
    "akṣayamatinirdeśa": ['bhs'],
    "akṣayamatiparipṛcchā": ['bhs'],
    "akṣayamatisūtra": ['bhs'],
    "akṣayamukta": ['bhs'],
    "akṣayanikā": ['bhs'],
    "akṣayanīvī": ['mw'],
    "akṣayaphala": ['cae'],
    "akṣayapuruhūta": ['mw'],
    "akṣayatva": ['mw'],
    "akṣayatā": ['mw'],
    "akṣayatṛtīyā": ['mw'],
    "akṣayavaṭa": ['mw'],
    "akṣayin": ['mw'],
    "akṣayiṇī": ['ap90', 'mw'],
    "akṣayya": ['ap90', 'cae', 'ddsa', 'mw'],
    "akṣayyam": ['mw'],
    "akṣayyanavamī": ['mw'],
    "akṣayyodaka": ['mw'],
    "akṣayā": ['mw'],
    "akṣayālalitā": ['ap90'],
    "akṣaśabda": ['mw'],
    "akṣaśauṇḍa": ['mw'],
    "akṣaśikṣā": ['mw'],
    "akṣaśīla": ['mw'],
    "akṣaḥ": ['ap90'],
    "akṣaṇa": ['ap90', 'bhs', 'mw'],
    "akṣaṇavedha": ['bhs'],
    "akṣaṇavedhin": ['bhs'],
    "akṣaṇavedhitva": ['bhs'],
    "akṣaṇika": ['ap90'],
    "akṣaṇvant": ['cae'],
    "akṣaṇvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "akṣetra": ['ap90', 'cae', 'ddsa', 'mw'],
    "akṣetrajña": ['mw'],
    "akṣetratara": ['ddsa'],
    "akṣetravid": ['gra', 'mw'],
    "akṣetrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "akṣi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akṣiba": ['mw'],
    "akṣibandha": ['mw'],
    "akṣibheṣaja": ['mw'],
    "akṣibhruva": ['mw'],
    "akṣibhū": ['mw'],
    "akṣigata": ['ddsa', 'mw'],
    "akṣigola": ['mw'],
    "akṣijāha": ['mw'],
    "akṣika": ['mw'],
    "akṣikaḥ": ['ap90'],
    "akṣikūṭa": ['ddsa', 'mw'],
    "akṣikūṭaka": ['mw'],
    "akṣilakṣīkṛ": ['mw'],
    "akṣiloman": ['mw'],
    "akṣimat": ['mw'],
    "akṣinikāṇam": ['mw'],
    "akṣinimeṣa": ['mw'],
    "akṣipakṣman": ['mw'],
    "akṣipat": ['cae', 'ddsa', 'gra', 'mw'],
    "akṣipaṭala": ['mw'],
    "akṣipāka": ['mw'],
    "akṣiroga": ['cae'],
    "akṣisaṃskāra": ['mw'],
    "akṣisaṃtarjana": ['mw'],
    "akṣit": ['mw'],
    "akṣita": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "akṣitaraṃ": ['ap90'],
    "akṣitavya": ['mw'],
    "akṣiti": ['ap90', 'cae', 'gra', 'mw'],
    "akṣitoti": ['gra', 'mw'],
    "akṣitārā": ['mw'],
    "akṣitāvasu": ['gra', 'mw'],
    "akṣivaḥ": ['ap90'],
    "akṣivikūṇita": ['mw'],
    "akṣiyat": ['ap90', 'gra', 'mw'],
    "akṣiśiromukha": ['cae'],
    "akṣiṇvant": ['cae'],
    "akṣiṇvat": ['mw'],
    "akṣiṇī": ['ap90', 'mw'],
    "akṣobha": ['ap90', 'mw'],
    "akṣobhiṇī": ['bhs'],
    "akṣobhya": ['ap90', 'bhs', 'ddsa', 'mw'],
    "akṣobhyarāja": ['bhs'],
    "akṣobhyatīrtha": ['mw'],
    "akṣobhyendriya": ['bhs'],
    "akṣobhyā": ['mw'],
    "akṣodhuka": ['ddsa', 'mw'],
    "akṣoḍa": ['ddsa', 'mw'],
    "akṣoḍaka": ['mw'],
    "akṣoḍaḥ": ['ap90'],
    "akṣoṭa": ['mw'],
    "akṣoṭaḥ": ['ap90'],
    "akṣu": ['ap90', 'cae', 'gra', 'mw'],
    "akṣudh": ['ap90', 'mw'],
    "akṣudhya": ['ap90', 'mw'],
    "akṣudra": ['ap90', 'bhs', 'ddsa', 'mw'],
    "akṣudrāvakāśa": ['bhs'],
    "akṣuṇa": ['bhs', 'cae', 'ddsa'],
    "akṣuṇṇa": ['ap90', 'bhs', 'mw'],
    "akṣuṇṇatā": ['mw'],
    "akṣuṇṇavedha": ['mw'],
    "akṣyāmaya": ['mw'],
    "akṣyāmayin": ['mw'],
    "akṣāgra": ['mw'],
    "akṣāgrakīla": ['mw'],
    "akṣāgrakīlaka": ['mw'],
    "akṣālita": ['ddsa'],
    "akṣānah": ['ap90', 'gra', 'mw'],
    "akṣānta": ['mw'],
    "akṣānti": ['ddsa', 'mw'],
    "akṣāra": ['ap90', 'mw'],
    "akṣāralavaṇa": ['cae', 'ddsa', 'mw'],
    "akṣāralavaṇāśin": ['mw'],
    "akṣāramadyamāṃsāda": ['mw'],
    "akṣātivāpa": ['mw'],
    "akṣāvalī": ['ddsa', 'mw'],
    "akṣāvapana": ['mw'],
    "akṣāvāpa": ['mw'],
    "akṣāṃsa": ['mw'],
    "akṣāṃtiḥ": ['ap90'],
    "akṣī": ['cae', 'ddsa'],
    "akṣība": ['mw'],
    "akṣīka": ['ap90', 'mw'],
    "akṣīva": ['ap90'],
    "akṣīyamāṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "akṣīṇa": ['cae', 'ddsa', 'mw'],
    "akṣūṇa": ['bhs'],
    "akṣṇa": ['ap90', 'mw'],
    "akṣṇayā": ['ap90', 'cae', 'ddsa', 'mw'],
    "akṣṇayādeśa": ['mw'],
    "akṣṇayādruh": ['gra', 'mw'],
    "akṣṇayākṛta": ['mw'],
    "akṣṇayāpacchedana": ['mw'],
    "akṣṇayārajju": ['mw'],
    "akṣṇayāstomīyā": ['mw'],
    "akṣṇayāvan": ['ap90', 'cae', 'gra', 'mw'],
    "al": ['ap90', 'mw'],
    "ala": ['cped', 'mw'],
    "alabdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "alabdhabhūmikatva": ['mw'],
    "alabdhagādha": ['mw'],
    "alabdhanidra": ['mw'],
    "alabdhanātha": ['mw'],
    "alabdhapada": ['mw'],
    "alabdhābhīpsita": ['mw'],
    "alabhamāna": ['cae', 'ddsa', 'mw'],
    "alabhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "alacchinna": ['cped'],
    "alagadda": ['cped'],
    "alagarda": ['cae', 'ddsa', 'mw'],
    "alagardaḥ": ['ap90'],
    "alagardha": ['mw'],
    "alagardā": ['mw'],
    "alaghu": ['ap90', 'cae', 'ddsa', 'mw'],
    "alaghupratijña": ['mw'],
    "alaghīyas": ['mw'],
    "alaghūpala": ['mw'],
    "alaghūṣman": ['mw'],
    "alagla": ['ap90'],
    "alaglam": ['mw'],
    "alagna": ['mw'],
    "alaja": ['cae', 'mw'],
    "alajacit": ['mw'],
    "alajacita": ['mw'],
    "alajaḥ": ['ap90'],
    "alaji": ['cae', 'mw'],
    "alajja": ['ap90', 'cae', 'ddsa', 'mw'],
    "alajjin": ['bhs'],
    "alajjita": ['bhs'],
    "alajjitavya": ['bhs'],
    "alajī": ['ap90', 'cae', 'mw'],
    "alaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "alakam": ['cae', 'ddsa', 'gra', 'mw'],
    "alakanandā": ['mw'],
    "alakaprabhā": ['mw'],
    "alakapriya": ['mw'],
    "alakasaṃhati": ['mw'],
    "alakaśīrṣa": ['bhs'],
    "alakaḥ": ['ap90'],
    "alakaṃ": ['ap90'],
    "alakeśvara": ['ddsa', 'mw'],
    "alakhāna": ['ddsa', 'mw'],
    "alakta": ['cae', 'ddsa', 'mw'],
    "alaktaka": ['mw'],
    "alaktakāṅka": ['cae', 'ddsa'],
    "alaktarasa": ['mw'],
    "alaktaḥ": ['ap90'],
    "alakuṇḍalabhaṭṭiya": ['bhs'],
    "alakā": ['mw'],
    "alakādhipa": ['mw'],
    "alakādhipati": ['mw'],
    "alakānta": ['mw'],
    "alakāpura": ['bhs'],
    "alakāvatī": ['bhs'],
    "alakṣaṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "alakṣaṇaka": ['bhs', 'mw'],
    "alakṣita": ['ap90', 'cae', 'mw'],
    "alakṣitopasthita": ['mw'],
    "alakṣitāntaka": ['mw'],
    "alakṣman": ['mw'],
    "alakṣmī": ['ddsa', 'mw'],
    "alakṣmīḥ": ['ap90'],
    "alakṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "alakṣyagati": ['mw'],
    "alakṣyajanmatā": ['mw'],
    "alakṣyaliṅga": ['mw'],
    "alale": ['ap90', 'mw'],
    "alalābhavant": ['cae'],
    "alalābhavat": ['ddsa', 'gra', 'mw'],
    "alam": ['ap90', 'cae', 'ddsa', 'mw'],
    "alamariya": ['cped'],
    "alamarthatva": ['mw'],
    "alamarthatā": ['mw'],
    "alamarthavacas": ['ddsa', 'mw'],
    "alamatta": ['cped'],
    "alamattha": ['cped'],
    "alamatthadasatara": ['cped'],
    "alamatthatara": ['cped'],
    "alamatthavicintaka": ['cped'],
    "alambhaviṣṇu": ['mw'],
    "alambu": ['bhs'],
    "alambuṣa": ['mw'],
    "alambuṣā": ['bhs', 'ddsa', 'mw'],
    "alamma": ['mw'],
    "alampateyyā": ['cped'],
    "alampañña": ['cped'],
    "alampaśu": ['mw'],
    "alampaṭa": ['mw'],
    "alamārya": ['bhs', 'mw'],
    "alamātardana": ['mw'],
    "alantarām": ['ddsa'],
    "alapas": ['ap90'],
    "alapat": ['mw'],
    "alarka": ['cae', 'ddsa', 'mw'],
    "alarkaḥ": ['ap90'],
    "alarti": ['mw'],
    "alarṣirāti": ['mw'],
    "alas": ['ap90', 'mw'],
    "alasa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "alasagamana": ['mw'],
    "alasajātīka": ['cped'],
    "alasaka": ['ap90', 'cped', 'mw'],
    "alasatva": ['mw'],
    "alasatā": ['mw'],
    "alasaya": ['mw'],
    "alasekṣaṇa": ['mw'],
    "alasya": ['ap90'],
    "alasā": ['mw'],
    "alasālā": ['mw'],
    "alasībhū": ['mw'],
    "alati": ['mw'],
    "alatikā": ['ddsa', 'mw'],
    "alatiḥ": ['ap90'],
    "alattakakata": ['cped'],
    "alaukika": ['ap90', 'cae', 'ddsa', 'mw'],
    "alaukikatva": ['mw'],
    "alavas": ['mw'],
    "alavaṇa": ['mw'],
    "alavaṇaka": ['bhs'],
    "alavaṇāśin": ['mw'],
    "alavāla": ['mw'],
    "alavālaka": ['mw'],
    "alavālaṃ": ['ap90'],
    "alaya": ['ap90', 'ddsa', 'mw'],
    "alayana": ['bhs'],
    "alayas": ['mw'],
    "alañjara": ['mw'],
    "alaṁ": ['cped'],
    "alaṁsamakkhāta": ['cped'],
    "alaṁsamakkhātar": ['cped'],
    "alaṁsājīva": ['cped'],
    "alaṁsākaccha": ['cped'],
    "alaṁvacanīya": ['cped'],
    "alaṃ": ['ap90', 'mw'],
    "alaṃbala": ['mw'],
    "alaṃbhūṣṇu": ['mw'],
    "alaṃbusā": ['ap90'],
    "alaṃbuṣaḥ": ['ap90'],
    "alaṃdhana": ['cae', 'mw'],
    "alaṃdhūma": ['mw'],
    "alaṃghanaṃ": ['ap90'],
    "alaṃghanīya": ['ap90'],
    "alaṃghanīyatā": ['ap90'],
    "alaṃghya": ['ap90'],
    "alaṃgāmin": ['mw'],
    "alaṃjaraḥ": ['ap90'],
    "alaṃjuṣa": ['mw'],
    "alaṃjīvika": ['mw'],
    "alaṃkaraṇa": ['cae', 'mw'],
    "alaṃkaraṇaratna": ['cae'],
    "alaṃkaraṇaṃ": ['ap90'],
    "alaṃkaraṇin": ['mw'],
    "alaṃkaraṇīya": ['bhs'],
    "alaṃkariṣṇu": ['ap90', 'cae', 'mw'],
    "alaṃkarmīṇa": ['mw'],
    "alaṃkartṛ": ['ap90', 'cae', 'mw'],
    "alaṃkriyā": ['ap90', 'cae', 'mw'],
    "alaṃkumāri": ['mw'],
    "alaṃkāla": ['mw'],
    "alaṃkāra": ['cae', 'mw'],
    "alaṃkārabhāṇḍa": ['cae', 'mw'],
    "alaṃkārabhūṣita": ['bhs'],
    "alaṃkāracandrikā": ['mw'],
    "alaṃkāracūḍāmaṇi": ['mw'],
    "alaṃkārahīna": ['mw'],
    "alaṃkāraka": ['cae', 'mw'],
    "alaṃkārakaustubha": ['mw'],
    "alaṃkārakaḥ": ['ap90'],
    "alaṃkārakārikā": ['mw'],
    "alaṃkārakārin": ['cae'],
    "alaṃkāramañjarī": ['mw'],
    "alaṃkāramuktāvalī": ['mw'],
    "alaṃkāramālā": ['mw'],
    "alaṃkāraratnākara": ['mw'],
    "alaṃkārasarvasva": ['mw'],
    "alaṃkārasuvarṇa": ['mw'],
    "alaṃkārasūra": ['mw'],
    "alaṃkāravatī": ['mw'],
    "alaṃkāraśubha": ['bhs'],
    "alaṃkāraśāstra": ['mw'],
    "alaṃkāraśīla": ['mw'],
    "alaṃkāraḥ": ['ap90'],
    "alaṃkārika": ['bhs'],
    "alaṃkārin": ['cae'],
    "alaṃkārya": ['mw'],
    "alaṃkārānusāriṇī": ['mw'],
    "alaṃkṛ": ['ap90', 'mw'],
    "alaṃkṛta": ['bhs', 'mw'],
    "alaṃkṛtaka": ['bhs'],
    "alaṃkṛti": ['cae', 'mw'],
    "alaṃkṛtiḥ": ['ap90'],
    "alaṃkṛtvā": ['mw'],
    "alaṃkṛtya": ['mw'],
    "alaṃmanas": ['mw'],
    "alaṃpaśu": ['mw'],
    "alaṃpaṭa": ['ap90'],
    "alaṃprajanana": ['mw'],
    "alaṃpuruṣīṇa": ['mw'],
    "alaṃpūrva": ['mw'],
    "alaṃtama": ['mw'],
    "alaṃtarām": ['mw'],
    "alaṃvarṣā": ['bhs'],
    "alaṅghana": ['mw'],
    "alaṅghanīya": ['cae', 'ddsa', 'mw'],
    "alaṅghanīyatā": ['mw'],
    "alaṅghayat": ['mw'],
    "alaṅghita": ['cae', 'ddsa', 'mw'],
    "alaṅghitapūrva": ['cae', 'mw'],
    "alaṅghitātman": ['mw'],
    "alaṅghya": ['cae', 'ddsa', 'mw'],
    "alaṅkammanīya": ['cped'],
    "alaṅkaraṇa": ['ddsa'],
    "alaṅkaroti": ['cped'],
    "alaṅkata": ['cped'],
    "alaṅkatapaṭiyatta": ['cped'],
    "alaṅkāra": ['cped', 'ddsa'],
    "alaṅkṛta": ['ddsa'],
    "ale": ['ap90', 'mw'],
    "alekhya": ['ddsa'],
    "alele": ['ap90', 'mw'],
    "alena": ['bhs'],
    "alepa": ['mw'],
    "alepaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "aleśa": ['ap90', 'mw'],
    "aleśaija": ['ap90', 'mw'],
    "aleśam": ['mw'],
    "alga": ['cae', 'ddsa', 'mw'],
    "algaṇḍu": ['mw'],
    "ali": ['cae', 'ddsa', 'mw'],
    "alidūrvā": ['mw'],
    "aligarda": ['mw'],
    "aligardaḥ": ['ap90'],
    "aligardha": ['mw'],
    "aligu": ['mw'],
    "alijihvikā": ['mw'],
    "alijihvā": ['mw'],
    "alika": ['bhs', 'cped', 'ddsa', 'mw'],
    "alikalekhā": ['mw'],
    "alikaṃ": ['ap90'],
    "aliklava": ['mw'],
    "aliklavaḥ": ['ap90'],
    "alikula": ['mw'],
    "alikulapriyā": ['mw'],
    "alikulasaṃkulā": ['mw'],
    "alimaka": ['mw'],
    "alimakaḥ": ['ap90'],
    "alimanmatha": ['bhs'],
    "alimat": ['ddsa', 'mw'],
    "alimbaka": ['mw'],
    "alimodā": ['mw'],
    "alimohinī": ['mw'],
    "alimpaka": ['mw'],
    "alimālā": ['cae', 'mw'],
    "alin": ['ap90', 'cae', 'ddsa', 'mw'],
    "alina": ['ap90', 'gra', 'mw'],
    "alinda": ['bhs', 'cae', 'ddsa', 'mw'],
    "alindaka": ['mw'],
    "alindā": ['bhs'],
    "alinī": ['mw'],
    "alipaka": ['mw'],
    "alipakaḥ": ['ap90'],
    "aliparṇī": ['mw'],
    "alipattrikā": ['mw'],
    "alipi": ['mw'],
    "alipriya": ['mw'],
    "alipriyā": ['mw'],
    "alipsā": ['ap90', 'mw'],
    "alivallabhā": ['mw'],
    "aliviruta": ['mw'],
    "alivirāva": ['mw'],
    "aliñjara": ['cae', 'mw'],
    "aliḥ": ['ap90'],
    "aliṃdaḥ": ['ap90'],
    "aliṃga": ['ap90'],
    "aliṃgin": ['ap90'],
    "aliṃjaraḥ": ['ap90'],
    "aliṃpaka": ['ap90'],
    "aliṃśa": ['mw'],
    "aliṃśaḥ": ['ap90'],
    "aliṅaga": ['ddsa'],
    "aliṅga": ['cae', 'mw'],
    "aliṅgin": ['cae', 'ddsa', 'mw'],
    "alkaḥ": ['ap90'],
    "alla": ['cped'],
    "allaṭa": ['mw'],
    "allika": ['cped'],
    "alliyati": ['cped'],
    "alluka": ['bhs'],
    "allā": ['ap90', 'mw'],
    "allāpadīna": ['mw'],
    "allāpayati": ['bhs'],
    "allāḍalaharī": ['mw'],
    "allīna": ['cped'],
    "allīyati": ['bhs', 'cped'],
    "alobha": ['cae', 'ddsa', 'mw'],
    "alobhaḥ": ['ap90'],
    "alobhin": ['ap90', 'mw'],
    "alocana": ['mw'],
    "aloha": ['mw'],
    "alohinī": ['bhs'],
    "alohita": ['ap90', 'ddsa', 'mw'],
    "aloka": ['ap90', 'bhs', 'cae', 'mw'],
    "alokanaṃ": ['ap90'],
    "alokanīya": ['ap90', 'mw'],
    "alokasāmānya": ['cae', 'ddsa', 'mw'],
    "alokita": ['ap90', 'mw'],
    "alokya": ['ap90', 'cae', 'ddsa', 'mw'],
    "alokyatā": ['mw'],
    "alola": ['ap90', 'ddsa', 'mw'],
    "alolatva": ['cae', 'mw'],
    "alolu": ['ap90'],
    "alolupa": ['ap90', 'mw'],
    "alolupatva": ['mw'],
    "aloluptva": ['mw'],
    "alolupyamāna": ['ddsa', 'mw'],
    "alolā": ['mw'],
    "alomaharṣaṇa": ['mw'],
    "alomaka": ['cae', 'ddsa', 'mw'],
    "aloman": ['ddsa', 'mw'],
    "alopa": ['mw'],
    "alopayat": ['ddsa'],
    "alopāṃga": ['ap90'],
    "alopāṅga": ['mw'],
    "alopī": ['mw'],
    "aloṇaka": ['bhs'],
    "alpa": ['ap90', 'cae', 'ddsa', 'mw'],
    "alpabahutva": ['mw'],
    "alpabala": ['mw'],
    "alpabalaprāṇa": ['mw'],
    "alpabhikṣuka": ['bhs'],
    "alpabhujāntara": ['cae', 'mw'],
    "alpabhāgya": ['cae', 'mw'],
    "alpabhāṣin": ['mw'],
    "alpabuddha": ['cae'],
    "alpabuddhi": ['cae', 'mw'],
    "alpabādha": ['mw'],
    "alpacchada": ['cae', 'mw'],
    "alpacetas": ['cae'],
    "alpaceṣṭita": ['mw'],
    "alpadakṣiṇa": ['cae', 'mw'],
    "alpadarśana": ['mw'],
    "alpadeśavṛttitva": ['mw'],
    "alpadhana": ['cae', 'mw'],
    "alpadhī": ['cae', 'mw'],
    "alpadroha": ['cae'],
    "alpadṛṣṭi": ['mw'],
    "alpagandha": ['mw'],
    "alpaguṇa": ['bhs'],
    "alpahariṇa": ['mw'],
    "alpajña": ['cae', 'mw'],
    "alpajñāta": ['bhs'],
    "alpaka": ['ap90', 'cae', 'mw'],
    "alpakam": ['mw'],
    "alpakaṇṭha": ['mw'],
    "alpakeśī": ['mw'],
    "alpakisareṇa": ['bhs'],
    "alpakleśa": ['cae'],
    "alpakrīta": ['mw'],
    "alpakālatva": ['cae'],
    "alpakārya": ['mw'],
    "alpakāt": ['mw'],
    "alpakāya": ['mw'],
    "alpakāyatva": ['mw'],
    "alpam": ['mw'],
    "alpamadhyama": ['mw'],
    "alpamanyate": ['bhs'],
    "alpamati": ['mw'],
    "alpamedhas": ['cae', 'mw'],
    "alpampaca": ['mw'],
    "alpamāriṣa": ['mw'],
    "alpamātra": ['mw'],
    "alpamūlya": ['cae', 'mw'],
    "alpamūrti": ['mw'],
    "alpanidāna": ['mw'],
    "alpaniṣpatti": ['mw'],
    "alpapadma": ['mw'],
    "alpaparicchada": ['mw'],
    "alpaparīvāra": ['ddsa', 'mw'],
    "alpapattra": ['mw'],
    "alpapattrī": ['mw'],
    "alpapaśu": ['mw'],
    "alpaphala": ['mw'],
    "alpaprabhāva": ['mw'],
    "alpaprabhāvatva": ['mw'],
    "alpaprabhāvatā": ['mw'],
    "alpaprajas": ['mw'],
    "alpapramāṇa": ['mw'],
    "alpapramāṇaka": ['mw'],
    "alpaprayoga": ['mw'],
    "alpaprāṇa": ['mw'],
    "alpapuṇya": ['cae', 'mw'],
    "alpapuṣpaka": ['mw'],
    "alpapuṣpakā": ['mw'],
    "alpapāyin": ['cae', 'mw'],
    "alparajaska": ['bhs'],
    "alparuj": ['mw'],
    "alparuja": ['mw'],
    "alpasambhāra": ['mw'],
    "alpasambhāratama": ['mw'],
    "alpasaras": ['mw'],
    "alpasattva": ['mw'],
    "alpasaṃnicaya": ['mw'],
    "alpasnāyu": ['mw'],
    "alpasparśa": ['mw'],
    "alpasva": ['mw'],
    "alpasvamat": ['mw'],
    "alpasvara": ['mw'],
    "alpasāra": ['cae', 'mw'],
    "alpatanu": ['mw'],
    "alpatara": ['mw'],
    "alpataraka": ['bhs'],
    "alpatejas": ['cae'],
    "alpatva": ['mw'],
    "alpatā": ['ap90', 'cae', 'mw'],
    "alpavat": ['mw'],
    "alpavayas": ['mw'],
    "alpavid": ['mw'],
    "alpavidya": ['cae', 'ddsa', 'mw'],
    "alpavittavat": ['mw'],
    "alpaviṣaya": ['mw'],
    "alpavyāhārin": ['mw'],
    "alpavādin": ['mw'],
    "alpaya": ['ddsa', 'mw'],
    "alpaśakti": ['ddsa', 'mw'],
    "alpaśarīra": ['mw'],
    "alpaśas": ['cae', 'mw'],
    "alpaśayu": ['mw'],
    "alpaśaḥ": ['ap90'],
    "alpaśaḥpaṅkti": ['mw'],
    "alpaśeṣa": ['cae', 'mw'],
    "alpaṃpaca": ['ap90'],
    "alpeccha": ['mw'],
    "alpecchu": ['ddsa', 'mw'],
    "alpena": ['mw'],
    "alpetara": ['mw'],
    "alpetaratva": ['mw'],
    "alpeśākhya": ['bhs', 'mw'],
    "alpeśākhyatva": ['bhs'],
    "alpita": ['ap90', 'mw'],
    "alpiṣṭha": ['ap90', 'mw'],
    "alpiṣṭhakīrti": ['mw'],
    "alpona": ['mw'],
    "alpopāya": ['mw'],
    "alpotsuka": ['bhs'],
    "alpotsukatva": ['bhs'],
    "alpotsukatā": ['bhs'],
    "alpābādha": ['bhs', 'mw'],
    "alpābādhatā": ['bhs'],
    "alpāhāra": ['mw'],
    "alpāhārin": ['mw'],
    "alpājya": ['mw'],
    "alpākāṅkṣin": ['mw'],
    "alpālpa": ['cae', 'mw'],
    "alpālpabhās": ['cae', 'mw'],
    "alpāmbutīrtha": ['mw'],
    "alpārambha": ['mw'],
    "alpārtha": ['bhs'],
    "alpāsthi": ['mw'],
    "alpāsvāda": ['bhs'],
    "alpāt": ['mw'],
    "alpātaṅka": ['bhs', 'mw'],
    "alpātaṅkatā": ['bhs'],
    "alpātyaya": ['mw'],
    "alpāvaśeṣa": ['mw'],
    "alpāvaśiṣṭa": ['cae', 'mw'],
    "alpāvaśiṣṭatva": ['mw'],
    "alpāyus": ['cae', 'mw'],
    "alpāyuṣka": ['bhs'],
    "alpāyuṣkatā": ['bhs'],
    "alpāyāsa": ['cae'],
    "alpāñji": ['mw'],
    "alpāṅga": ['cae', 'ddsa', 'mw'],
    "alpāṅgatva": ['mw'],
    "alpībhāva": ['mw'],
    "alpībhū": ['ddsa', 'mw'],
    "alpībhūta": ['ap90'],
    "alpīkṛ": ['ap90', 'mw'],
    "alpīyas": ['ap90', 'ddsa', 'mw'],
    "alpīyaḥkhā": ['mw'],
    "alu": ['mw'],
    "alubdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "alubdhatva": ['mw'],
    "alubhyat": ['mw'],
    "aluk": ['ap90'],
    "aluma": ['mw'],
    "alupta": ['ap90', 'mw'],
    "aluptamahiman": ['mw'],
    "aluptasattvakośa": ['ddsa'],
    "aluñca": ['mw'],
    "aluḍita": ['bhs'],
    "aluḥ": ['ap90'],
    "alābha": ['ap90', 'cae', 'ddsa', 'mw'],
    "alābhaka": ['cped'],
    "alābhalābha": ['mw'],
    "alābu": ['cae', 'cped', 'ddsa', 'mw'],
    "alābugandhi": ['mw'],
    "alābuka": ['mw'],
    "alābukeśvara": ['mw'],
    "alābukā": ['mw'],
    "alābulomasa": ['cped'],
    "alābumaya": ['ap90', 'mw'],
    "alābupātra": ['mw'],
    "alābusuhṛd": ['mw'],
    "alābuvīṇā": ['mw'],
    "alābuḥ": ['ap90'],
    "alābū": ['mw'],
    "alābūkaṭa": ['mw'],
    "alāghava": ['cae', 'ddsa', 'mw'],
    "alāghavaṃ": ['ap90'],
    "alāka": ['mw'],
    "alāmbu": ['bhs'],
    "alāpu": ['cped'],
    "alāra": ['mw'],
    "alāraṃ": ['ap90'],
    "alāsa": ['mw'],
    "alāsaḥ": ['ap90'],
    "alāsya": ['ap90', 'ddsa', 'mw'],
    "alāta": ['cae', 'cped', 'ddsa', 'mw'],
    "alātacakra": ['bhs', 'mw'],
    "alātacakravat": ['mw'],
    "alātaśanti": ['mw'],
    "alātaḥ": ['ap90'],
    "alātākṣī": ['mw'],
    "alātṛṇa": ['ap90', 'cae', 'gra', 'mw'],
    "alāyia": ['gra'],
    "alāyudha": ['cae', 'mw'],
    "alāyya": ['ap90', 'cae', 'gra', 'mw'],
    "alāñchana": ['mw'],
    "alāṃḍuḥ": ['ap90'],
    "alāṇḍu": ['cae', 'mw'],
    "alīgarda": ['mw'],
    "alīgardaḥ": ['ap90'],
    "alīka": ['ap90', 'cae', 'ddsa', 'mw'],
    "alīkadākṣiṇya": ['cae'],
    "alīkamatsya": ['mw'],
    "alīkanirbandha": ['cae'],
    "alīkapaṇḍita": ['cae'],
    "alīkasupta": ['cae', 'mw'],
    "alīkasuptaka": ['mw'],
    "alīkatā": ['mw'],
    "alīkavādaśīla": ['mw'],
    "alīkayu": ['mw'],
    "alīkin": ['ap90', 'mw'],
    "alīkya": ['ap90', 'mw'],
    "alīkā": ['mw'],
    "alīkāya": ['mw'],
    "alīkāyate": ['ap90'],
    "alīna": ['bhs', 'ddsa'],
    "alūha": ['bhs'],
    "alūkha": ['bhs'],
    "alūkṣa": ['ap90', 'mw'],
    "alūkṣāntatva": ['mw'],
    "alūna": ['cae', 'ddsa', 'mw'],
    "am": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "am, añc": ['ddsa'],
    "ama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "amacca": ['cped'],
    "amada": ['ap90', 'mw'],
    "amadana": ['mw'],
    "amaddhamaddhat": ['ddsa'],
    "amadgu": ['bhs'],
    "amadhavya": ['ap90', 'ddsa', 'mw'],
    "amadhu": ['mw'],
    "amadhyama": ['bhs', 'cae', 'gra', 'mw'],
    "amadhyastha": ['mw'],
    "amadyapa": ['mw'],
    "amadyapamadyat": ['mw'],
    "amahātman": ['cae', 'ddsa'],
    "amahīyamāna": ['cae', 'ddsa', 'gra', 'mw'],
    "amahīyu": ['mw'],
    "amajjaka": ['mw'],
    "amajjana": ['ddsa'],
    "amala": ['ap90', 'cae', 'ddsa', 'mw'],
    "amalagarbha": ['bhs', 'mw'],
    "amalamaṇi": ['mw'],
    "amalapakṣavihaṃgama": ['mw'],
    "amalapatatrin": ['mw'],
    "amalaratna": ['mw'],
    "amalasaṃyuta": ['mw'],
    "amalaya": ['ddsa', 'mw'],
    "amalayati": ['ap90'],
    "amalina": ['ap90', 'cae', 'ddsa', 'mw'],
    "amalinadhī": ['mw'],
    "amalodarī": ['mw'],
    "amalā": ['bhs', 'mw'],
    "amalānaka": ['mw'],
    "amalānakaṃ": ['ap90'],
    "amalānanda": ['mw'],
    "amalānvaya": ['cae', 'mw'],
    "amalātaka": ['mw'],
    "amalātman": ['mw'],
    "amalīkṛ": ['mw'],
    "amalīmasa": ['mw'],
    "amama": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "amamatva": ['mw'],
    "amamatā": ['ap90', 'mw'],
    "amamri": ['ap90', 'mw'],
    "amamrī": ['mw'],
    "amanas": ['ap90', 'cae', 'ddsa', 'mw'],
    "amanasikāra": ['bhs'],
    "amanaska": ['ddsa', 'mw'],
    "amanasvin": ['ap90'],
    "amanaāpa": ['bhs'],
    "amanda": ['cae', 'ddsa', 'gra', 'mw'],
    "amandam": ['mw'],
    "amani": ['mw'],
    "amaniḥ": ['ap90'],
    "amano": ['mw'],
    "amanojña": ['mw'],
    "amanorama": ['ddsa'],
    "amanoramatā": ['mw'],
    "amanoratha": ['bhs'],
    "amantra": ['bhs', 'cae', 'ddsa', 'mw'],
    "amantrajña": ['cae', 'mw'],
    "amantraka": ['cae', 'ddsa', 'mw'],
    "amantravat": ['mw'],
    "amantravid": ['cae', 'mw'],
    "amantu": ['cae', 'ddsa', 'gra', 'mw'],
    "amantṛ": ['mw'],
    "amanussika": ['cped'],
    "amanussikābādha": ['cped'],
    "amanuṣya": ['ap90', 'bhs', 'mw'],
    "amanuṣyaka": ['bhs'],
    "amanuṣyaniṣevit": ['ddsa'],
    "amanuṣyaniṣevita": ['mw'],
    "amanuṣyatā": ['mw'],
    "amanyamāna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "amanyanatā": ['bhs'],
    "amanyuta": ['ap90', 'mw'],
    "amanāk": ['ap90', 'mw'],
    "amanāpa": ['bhs'],
    "amanāpika": ['bhs'],
    "amanī": ['mw'],
    "amanībhāva": ['mw'],
    "amara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "amarabhartṛ": ['mw'],
    "amaracandra": ['mw'],
    "amaradatta": ['mw'],
    "amaradeva": ['bhs', 'mw'],
    "amaradruma": ['mw'],
    "amaradvija": ['mw'],
    "amaradviṣ": ['mw'],
    "amaradāru": ['mw'],
    "amaragarbha": ['mw'],
    "amaragaṇa": ['mw'],
    "amaragaṇanālekhya": ['mw'],
    "amaragiri": ['mw'],
    "amaraguru": ['mw'],
    "amaraja": ['mw'],
    "amarakaṇṭaka": ['mw'],
    "amarakoṣa": ['mw'],
    "amarakoṣakaumudī": ['mw'],
    "amarakoṭa": ['mw'],
    "amaraloka": ['cae', 'ddsa'],
    "amaralokatā": ['mw'],
    "amaramaya": ['mw'],
    "amarammanya": ['ddsa'],
    "amaramālā": ['mw'],
    "amaramṛgīdṛś": ['mw'],
    "amarantapa": ['cped'],
    "amarapa": ['mw'],
    "amarapakṣapātin": ['cae'],
    "amaraparpaṭa": ['bhs'],
    "amaraparvata": ['mw'],
    "amarapati": ['mw'],
    "amaraprabha": ['cae', 'mw'],
    "amaraprabhu": ['mw'],
    "amaraprakhya": ['mw'],
    "amarapura": ['mw'],
    "amarapurī": ['mw'],
    "amarapuṣpa": ['mw'],
    "amarapuṣpaka": ['mw'],
    "amarapuṣpikā": ['mw'],
    "amararatna": ['mw'],
    "amararāj": ['mw'],
    "amararāja": ['mw'],
    "amararājamantrin": ['mw'],
    "amararājaśatru": ['mw'],
    "amarasadas": ['cae', 'mw'],
    "amarasarit": ['mw'],
    "amarasiṃha": ['mw'],
    "amarastrī": ['mw'],
    "amaratapa": ['cped'],
    "amarataṭinī": ['mw'],
    "amaratva": ['mw'],
    "amaratā": ['ap90', 'mw'],
    "amaravadhū": ['mw'],
    "amaravallarī": ['mw'],
    "amaravarṇin": ['cae', 'mw'],
    "amaravat": ['mw'],
    "amaraśakti": ['mw'],
    "amaraṃjaya": ['mw'],
    "amaraṇa": ['mw'],
    "amaraṇaṃ": ['ap90'],
    "amaraṇīya": ['mw'],
    "amaraṇīyatā": ['mw'],
    "amardhant": ['cae'],
    "amardhat": ['ddsa', 'gra', 'mw'],
    "amardita": ['mw'],
    "amarejya": ['mw'],
    "amareśa": ['cae', 'mw'],
    "amareśvara": ['cae', 'ddsa', 'mw'],
    "amareśvaratīrtha": ['mw'],
    "amariṣṇu": ['ap90', 'gra', 'mw'],
    "amarma": ['mw'],
    "amarmajāta": ['mw'],
    "amarman": ['ap90', 'ddsa', 'gra', 'mw'],
    "amarmavedhitā": ['mw'],
    "amaropama": ['cae', 'mw'],
    "amarottama": ['ddsa'],
    "amarta": ['cae', 'gra', 'mw'],
    "amartia": ['gra'],
    "amartya": ['ap90', 'cae', 'gra', 'mw'],
    "amartyabhuvana": ['mw'],
    "amartyabhāva": ['ddsa', 'mw'],
    "amartyatva": ['mw'],
    "amartyatā": ['mw'],
    "amaru": ['cae', 'mw'],
    "amaruśataka": ['mw'],
    "amaruḥ": ['ap90'],
    "amaryāda": ['ap90', 'ddsa', 'mw'],
    "amarā": ['bhs', 'mw'],
    "amarācārya": ['mw'],
    "amarādhipa": ['mw'],
    "amarādri": ['mw'],
    "amarāgāra": ['ddsa', 'mw'],
    "amarāpagā": ['mw'],
    "amarāri": ['mw'],
    "amarāripūjya": ['mw'],
    "amarāvatī": ['ap90', 'cae', 'ddsa', 'mw'],
    "amarāvikkhepa": ['cped'],
    "amarāvikkhepika": ['cped'],
    "amarāṅganā": ['mw'],
    "amarī": ['mw'],
    "amarībhū": ['mw'],
    "amarṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "amarṣahāsa": ['mw'],
    "amarṣaja": ['mw'],
    "amarṣavat": ['mw'],
    "amarṣaṇa": ['ap90', 'cae', 'mw'],
    "amarṣin": ['cae', 'mw'],
    "amarṣita": ['cae', 'mw'],
    "amasa": ['mw'],
    "amasaḥ": ['ap90'],
    "amastaka": ['mw'],
    "amastu": ['ap90', 'mw'],
    "amasvan": ['mw'],
    "amasṛṇa": ['ap90', 'mw'],
    "amata": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "amatapadārtha": ['mw'],
    "amataḥ": ['ap90'],
    "amateya": ['bhs'],
    "amati": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "amatipūrva": ['mw'],
    "amatipūrvaka": ['mw'],
    "amatiḥ": ['ap90'],
    "amatra": ['ap90', 'cae', 'gra', 'mw'],
    "amatraka": ['mw'],
    "amatrin": ['ap90', 'gra', 'mw'],
    "amatsara": ['ap90', 'cae', 'ddsa', 'mw'],
    "amatsarin": ['mw'],
    "amatsyamāṃsaka": ['bhs'],
    "amatta": ['ap90'],
    "amatyā": ['mw'],
    "amatīvan": ['gra', 'mw'],
    "amauktika": ['cae', 'ddsa', 'mw'],
    "amauna": ['mw'],
    "amaunaṃ": ['ap90'],
    "amautradhauta": ['mw'],
    "amavant": ['cae'],
    "amavat": ['ap90', 'ddsa', 'gra', 'mw'],
    "amaviṣṇu": ['ap90', 'gra', 'mw'],
    "amaṃda": ['ap90'],
    "amaṃgala": ['ap90'],
    "amaṃtra": ['ap90'],
    "amaṃtu": ['ap90'],
    "amaṃḍa": ['ap90'],
    "amaṅgala": ['cae', 'ddsa', 'mw'],
    "amaṅgalya": ['cae', 'mw'],
    "amaṅkubhūta": ['bhs'],
    "amaṇdanā": ['cped'],
    "amaṇiva": ['mw'],
    "amaṇḍa": ['mw'],
    "amaṇḍita": ['cae', 'ddsa', 'mw'],
    "amaṭha": ['mw'],
    "amb": ['mw'],
    "amba": ['cped', 'gra', 'mw'],
    "ambacoraka": ['cped'],
    "ambaka": ['cae', 'mw'],
    "ambakamaddarī": ['cped'],
    "ambakapañña": ['cped'],
    "ambakoṭa": ['bhs'],
    "ambakā": ['bhs', 'cped'],
    "ambapesikā": ['cped'],
    "ambapālaka": ['cped'],
    "ambapālī": ['mw'],
    "ambara": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ambaracara": ['mw'],
    "ambaracārin": ['mw'],
    "ambarada": ['mw'],
    "ambaraga": ['mw'],
    "ambarakhaṇḍa": ['cae', 'mw'],
    "ambaralekhin": ['mw'],
    "ambaramaṇi": ['mw'],
    "ambaramālā": ['mw'],
    "ambaranagarī": ['mw'],
    "ambaraprabhā": ['mw'],
    "ambarapuṣpa": ['mw'],
    "ambarasthalī": ['mw'],
    "ambaraukas": ['ddsa', 'mw'],
    "ambarayuga": ['mw'],
    "ambaraśaila": ['mw'],
    "ambarya": ['mw'],
    "ambarādhikārin": ['mw'],
    "ambarānta": ['mw'],
    "ambarīṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "ambarīṣaputra": ['mw'],
    "ambayā": ['mw'],
    "ambaṣṭha": ['cae', 'ddsa', 'mw'],
    "ambaṣṭhakī": ['mw'],
    "ambaṣṭhikā": ['mw'],
    "ambaṣṭhā": ['mw'],
    "ambaṣṭhī": ['mw'],
    "ambeka": ['mw'],
    "ambh": ['mw'],
    "ambhas": ['cae', 'ddsa', 'gra', 'mw'],
    "ambhastas": ['mw'],
    "ambhaḥ": ['mw'],
    "ambhaḥpati": ['mw'],
    "ambhaḥstha": ['mw'],
    "ambhaḥsāra": ['mw'],
    "ambhaḥsū": ['mw'],
    "ambhaḥśyāmāka": ['mw'],
    "ambhaṇa": ['mw'],
    "ambhiṇī": ['mw'],
    "ambho": ['cped', 'mw'],
    "ambhoda": ['mw'],
    "ambhodhara": ['mw'],
    "ambhodhi": ['cae', 'mw'],
    "ambhodhipallava": ['mw'],
    "ambhodhivallabha": ['mw'],
    "ambhogarbha": ['cae', 'mw'],
    "ambhoja": ['cae', 'ddsa', 'mw'],
    "ambhojabandhu": ['mw'],
    "ambhojajanman": ['mw'],
    "ambhojakhaṇḍa": ['mw'],
    "ambhojanmajani": ['mw'],
    "ambhojanman": ['mw'],
    "ambhojavadanā": ['mw'],
    "ambhojayoni": ['mw'],
    "ambhojinī": ['mw'],
    "ambhomuc": ['mw'],
    "ambhonidhi": ['cae', 'mw'],
    "ambhoruh": ['cae', 'mw'],
    "ambhoruha": ['cae', 'mw'],
    "ambhorāśi": ['mw'],
    "ambhīrya": ['bhs'],
    "ambhṛṇa": ['cae', 'gra', 'mw'],
    "ambi": ['cae', 'gra', 'mw'],
    "ambika": ['mw'],
    "ambikeya": ['mw'],
    "ambikā": ['cae', 'ddsa', 'mw'],
    "ambikākhaṇḍa": ['mw'],
    "ambikāmāhātmya": ['mw'],
    "ambikāpariṇaya": ['mw'],
    "ambikāpati": ['mw'],
    "ambikāputra": ['mw'],
    "ambikāsuta": ['mw'],
    "ambikāvana": ['mw'],
    "ambila": ['cped'],
    "ambilagga": ['cped'],
    "ambu": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ambubhakṣya": ['mw'],
    "ambubhṛt": ['mw'],
    "ambucara": ['mw'],
    "ambucāmara": ['mw'],
    "ambucārin": ['cae', 'mw'],
    "ambuda": ['cae', 'ddsa', 'mw'],
    "ambudaiva": ['mw'],
    "ambudeva": ['mw'],
    "ambudhakāminī": ['mw'],
    "ambudhara": ['mw'],
    "ambudhi": ['cae', 'mw'],
    "ambudhikāminī": ['mw'],
    "ambudhisravā": ['mw'],
    "ambudhāra": ['mw'],
    "ambudhārā": ['cae'],
    "ambudāraṇya": ['mw'],
    "ambuga": ['mw'],
    "ambughana": ['mw'],
    "ambuhasta": ['mw'],
    "ambuja": ['cae', 'cped', 'ddsa', 'mw'],
    "ambujabhū": ['mw'],
    "ambujabāndhava": ['mw'],
    "ambujanman": ['mw'],
    "ambujastha": ['mw'],
    "ambujinī": ['mw'],
    "ambujākṣa": ['mw'],
    "ambujānanā": ['mw'],
    "ambujāsanā": ['mw'],
    "ambujīvin": ['mw'],
    "ambukapha": ['mw'],
    "ambukapi": ['mw'],
    "ambukaṇa": ['mw'],
    "ambukaṇṭaka": ['mw'],
    "ambukeśara": ['mw'],
    "ambukirāta": ['mw'],
    "ambukriyā": ['mw'],
    "ambukukkuṭa": ['mw'],
    "ambukāntāra": ['mw'],
    "ambukīśa": ['mw'],
    "ambukūrma": ['mw'],
    "ambulima": ['bhs'],
    "ambulīlāgeha": ['mw'],
    "ambumat": ['mw'],
    "ambumatī": ['mw'],
    "ambumaya": ['mw'],
    "ambumuc": ['mw'],
    "ambumātraja": ['mw'],
    "ambunidhi": ['mw'],
    "ambunivaha": ['cae', 'mw'],
    "ambunātha": ['mw'],
    "ambupa": ['mw'],
    "ambupaddhati": ['mw'],
    "ambupakṣin": ['mw'],
    "ambupati": ['mw'],
    "ambupattrā": ['mw'],
    "ambuprasāda": ['mw'],
    "ambuprasādana": ['mw'],
    "ambupriya": ['mw'],
    "ambupāta": ['mw'],
    "amburaya": ['cae', 'mw'],
    "amburohiṇī": ['mw'],
    "amburuha": ['cae', 'mw'],
    "amburuhiṇī": ['mw'],
    "amburuhā": ['mw'],
    "amburāja": ['mw'],
    "amburāśi": ['cae', 'mw'],
    "ambusamplava": ['mw'],
    "ambusarpiṇī": ['mw'],
    "ambusecanī": ['mw'],
    "ambusūkara": ['mw'],
    "ambutaskara": ['mw'],
    "ambutāla": ['mw'],
    "ambuvallī": ['mw'],
    "ambuvardhana": ['mw'],
    "ambuvega": ['mw'],
    "ambuvetasa": ['mw'],
    "ambuvācī": ['mw'],
    "ambuvācīprada": ['mw'],
    "ambuvācītyāga": ['mw'],
    "ambuvāha": ['cae', 'mw'],
    "ambuvāhin": ['mw'],
    "ambuvāhinī": ['mw'],
    "ambuvāsa": ['mw'],
    "ambuvāsinī": ['mw'],
    "ambuvāsī": ['mw'],
    "ambuyantra": ['mw'],
    "ambuśirīṣikā": ['mw'],
    "ambuśītā": ['mw'],
    "ambya": ['mw'],
    "ambā": ['cae', 'ddsa', 'gra', 'mw'],
    "ambāgaṅgā": ['mw'],
    "ambājanman": ['mw'],
    "ambālikā": ['cae', 'mw'],
    "ambālā": ['mw'],
    "ambālī": ['mw'],
    "ambāsanaka": ['bhs'],
    "ambāḍā": ['mw'],
    "ambī": ['cae', 'mw'],
    "ambūkṛta": ['cae', 'ddsa', 'mw'],
    "ambūrmigata": ['mw'],
    "amedaska": ['ap90', 'mw'],
    "amedhas": ['ap90', 'mw'],
    "amedhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "amedhyakuṇapāśin": ['cae', 'mw'],
    "amedhyalepa": ['mw'],
    "amedhyalipta": ['mw'],
    "amedhyapratimantraṇa": ['mw'],
    "amedhyatva": ['mw'],
    "amedhyatā": ['mw'],
    "amedhyayukta": ['mw'],
    "amedhyākta": ['cae', 'mw'],
    "ameghopaplava": ['mw'],
    "ameha": ['mw'],
    "amekṣaṇa": ['mw'],
    "amena": ['ap90', 'cae', 'gra', 'mw'],
    "ameni": ['cae', 'mw'],
    "ameya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ameyaparivarta": ['bhs'],
    "ameyātman": ['mw'],
    "ameṣṭa": ['ap90', 'mw'],
    "amha": ['cped'],
    "amhamaya": ['cped'],
    "amhan": ['cped'],
    "amhā": ['cped'],
    "ami": ['ddsa'],
    "amila": ['bhs'],
    "amilāna": ['bhs'],
    "amilātaka": ['mw'],
    "amilātakaṃ": ['ap90'],
    "amin": ['ap90', 'mw'],
    "amina": ['ap90', 'cae', 'gra', 'mw'],
    "aminant": ['cae'],
    "aminat": ['ap90', 'ddsa', 'gra', 'mw'],
    "amita": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "amitabuddhimant": ['cae'],
    "amitadhvaja": ['bhs', 'mw'],
    "amitadyuti": ['mw'],
    "amitagati": ['mw'],
    "amitakratu": ['gra', 'mw'],
    "amitalocana": ['bhs'],
    "amitam": ['mw'],
    "amitamati": ['mw'],
    "amitanātha": ['bhs'],
    "amitaprabha": ['bhs', 'mw'],
    "amitaprabhāsa": ['mw'],
    "amitaruci": ['mw'],
    "amitaskandha": ['bhs', 'mw'],
    "amitateja": ['bhs'],
    "amitatejas": ['cae', 'mw'],
    "amitatosala": ['bhs'],
    "amitatva": ['mw'],
    "amitauja": ['bhs'],
    "amitaujas": ['cae', 'ddsa', 'gra', 'mw'],
    "amitavikrama": ['cae', 'mw'],
    "amitavyūhavatī": ['bhs'],
    "amitavīrya": ['mw'],
    "amithita": ['ap90', 'gra', 'mw'],
    "amithuna": ['mw'],
    "amithyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "amithyākṛ": ['mw'],
    "amiti": ['mw'],
    "amitodana": ['mw'],
    "amitra": ['cae', 'ddsa', 'gra', 'mw'],
    "amitradambhana": ['gra', 'mw'],
    "amitraghna": ['cae', 'mw'],
    "amitraghāta": ['mw'],
    "amitraghātin": ['cae', 'mw'],
    "amitrahan": ['cae', 'gra', 'mw'],
    "amitrahū": ['mw'],
    "amitrajit": ['mw'],
    "amitraka": ['bhs'],
    "amitrakarman": ['ddsa', 'mw'],
    "amitrakarṣaṇa": ['cae', 'mw'],
    "amitrakarṣin": ['mw'],
    "amitrakhāda": ['gra', 'mw'],
    "amitrasaha": ['mw'],
    "amitrasenā": ['mw'],
    "amitrasāha": ['mw'],
    "amitratapana": ['mw'],
    "amitratā": ['ap90', 'mw'],
    "amitravarman": ['mw'],
    "amitravinibarhin": ['cae'],
    "amitray": ['gra'],
    "amitraya": ['mw'],
    "amitrayant": ['cae'],
    "amitrayati": ['ap90'],
    "amitrayu": ['cae', 'mw'],
    "amitraḥ": ['ap90'],
    "amitrin": ['ap90', 'cae', 'gra', 'mw'],
    "amitriya": ['cae', 'gra', 'mw'],
    "amitrāya": ['ddsa', 'mw'],
    "amitrāyudh": ['gra', 'mw'],
    "amitrīya": ['ap90'],
    "amitā": ['bhs'],
    "amitābha": ['bhs', 'mw'],
    "amitākṣara": ['mw'],
    "amitātman": ['mw'],
    "amitāyu": ['bhs'],
    "amitāyurdhyānasūtra": ['mw'],
    "amitāyurjñānaviniścayarāja": ['bhs'],
    "amitāyurjñānaviniścayarājendra": ['bhs'],
    "amitāyurvatī": ['bhs'],
    "amitāyus": ['bhs', 'mw'],
    "amitāyuviniścayarājendra": ['bhs'],
    "amitāśanā": ['mw'],
    "amiśra": ['ap90', 'mw'],
    "amiśraṇa": ['mw'],
    "amiśraṇīya": ['mw'],
    "amiśrita": ['mw'],
    "amiṣa": ['ap90', 'mw'],
    "amla": ['ap90', 'cae', 'ddsa', 'mw'],
    "amlabhedana": ['mw'],
    "amlacukrikā": ['mw'],
    "amlacūḍa": ['mw'],
    "amladrava": ['mw'],
    "amlaharidrā": ['mw'],
    "amlajambīra": ['mw'],
    "amlajuṇḍī": ['mw'],
    "amlaka": ['mw'],
    "amlakavaṭaka": ['mw'],
    "amlakaḥ": ['ap90'],
    "amlakeśara": ['mw'],
    "amlakāṇḍa": ['mw'],
    "amlalolikā": ['mw'],
    "amlaloṇikā": ['mw'],
    "amlaloṇī": ['mw'],
    "amlameha": ['mw'],
    "amlanimbūka": ['mw'],
    "amlaniśā": ['mw'],
    "amlanāyaka": ['mw'],
    "amlapanasa": ['mw'],
    "amlapattra": ['mw'],
    "amlapañcaka": ['mw'],
    "amlapañcaphala": ['mw'],
    "amlaphala": ['mw'],
    "amlapitta": ['mw'],
    "amlarasa": ['mw'],
    "amlaruhā": ['mw'],
    "amlasāra": ['mw'],
    "amlatiktakaṣāya": ['mw'],
    "amlatā": ['mw'],
    "amlavallī": ['mw'],
    "amlavarga": ['mw'],
    "amlavetasa": ['mw'],
    "amlavāstūka": ['mw'],
    "amlavāṭaka": ['mw'],
    "amlavāṭikā": ['mw'],
    "amlavṛkṣa": ['mw'],
    "amlaśāka": ['mw'],
    "amlikā": ['ap90', 'mw'],
    "amliman": ['ap90', 'mw'],
    "amlodgāra": ['mw'],
    "amloṭa": ['mw'],
    "amlādhyuṣita": ['mw'],
    "amlāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "amlāni": ['ap90', 'ddsa', 'mw'],
    "amlānin": ['ap90', 'mw'],
    "amlāninī": ['mw'],
    "amlāyin": ['mw'],
    "amlāṅkuśa": ['mw'],
    "amlī": ['mw'],
    "amlībhū": ['ddsa'],
    "amlībhūta": ['mw'],
    "amlīkā": ['ap90', 'mw'],
    "ammarā": ['mw'],
    "ammaya": ['ap90', 'ddsa', 'mw'],
    "ammā": ['cped'],
    "amnas": ['ap90', 'cae', 'mw'],
    "amocana": ['mw'],
    "amocanaṃ": ['ap90'],
    "amocanīya": ['mw'],
    "amocita": ['mw'],
    "amocya": ['cae', 'ddsa', 'mw'],
    "amogha": ['ap90', 'cae', 'ddsa', 'mw'],
    "amoghabala": ['mw'],
    "amoghabhūti": ['mw'],
    "amoghacaṇḍa": ['bhs'],
    "amoghadarśana": ['bhs', 'cae', 'mw'],
    "amoghadarśin": ['bhs', 'mw'],
    "amoghadaṇḍa": ['mw'],
    "amoghadeva": ['mw'],
    "amoghadṛś": ['mw'],
    "amoghakiraṇa": ['mw'],
    "amoghanandinī": ['mw'],
    "amoghapatana": ['mw'],
    "amoghapāśa": ['mw'],
    "amogharāghava": ['mw'],
    "amogharāja": ['bhs', 'mw'],
    "amoghasiddhi": ['bhs', 'mw'],
    "amoghatā": ['mw'],
    "amoghavacana": ['cae'],
    "amoghavarṣa": ['mw'],
    "amoghavatī": ['mw'],
    "amoghavikrama": ['mw'],
    "amoghavāc": ['mw'],
    "amoghavāñchita": ['mw'],
    "amoghā": ['mw'],
    "amoghācārya": ['mw'],
    "amoghākṣī": ['mw'],
    "amoghārtha": ['cae', 'mw'],
    "amoha": ['mw'],
    "amohadharmeśvara": ['bhs'],
    "amoham": ['bhs'],
    "amokya": ['ap90', 'mw'],
    "amokṣa": ['ap90', 'mw'],
    "amokṣayat": ['mw'],
    "amota": ['ap90', 'mw'],
    "amotaka": ['mw'],
    "amotakaḥ": ['ap90'],
    "amotaputraka": ['mw'],
    "amra": ['ap90', 'mw'],
    "amrapālī": ['bhs'],
    "amrāta": ['mw'],
    "amrātaka": ['mw'],
    "amrātaḥ": ['ap90'],
    "amu": ['cae', 'ddsa', 'gra', 'mw'],
    "amuc": ['ap90', 'mw'],
    "amucī": ['ap90', 'mw'],
    "amudra": ['ddsa', 'mw'],
    "amudryañc": ['mw'],
    "amudā": ['mw'],
    "amugdha": ['mw'],
    "amuka": ['ap90', 'cped', 'ddsa', 'mw'],
    "amukha": ['ddsa', 'mw'],
    "amukhara": ['bhs'],
    "amukhya": ['mw'],
    "amukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "amuktahasta": ['cae', 'mw'],
    "amuktahastatā": ['mw'],
    "amuktaviśrambha": ['mw'],
    "amukti": ['mw'],
    "amuktiḥ": ['ap90'],
    "amukīya": ['mw'],
    "amumuyañc": ['mw'],
    "amurhi": ['ap90', 'cae', 'mw'],
    "amutas": ['cae', 'ddsa', 'gra', 'mw'],
    "amutaḥ": ['ap90'],
    "amutaḥpradāna": ['mw'],
    "amuthā": ['ap90', 'cae', 'ddsa', 'mw'],
    "amutra": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "amutrabhūya": ['mw'],
    "amutratya": ['ap90'],
    "amutrārtham": ['mw'],
    "amuvat": ['ap90', 'mw'],
    "amuyā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "amuñcat": ['ddsa'],
    "amuñciyaṃ": ['bhs'],
    "amuṣmin": ['mw'],
    "amuṣya": ['ap90', 'mw'],
    "amuṣyakula": ['mw'],
    "amuṣyaputra": ['mw'],
    "amvlaḥ": ['ap90'],
    "amyak": ['ap90', 'mw'],
    "amā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "amāhaṭha": ['mw'],
    "amājur": ['cae', 'ddsa', 'gra', 'mw'],
    "amākṛ": ['mw'],
    "amāmasī": ['ap90', 'mw'],
    "amāmāsī": ['ap90', 'mw'],
    "amāna": ['mw'],
    "amānana": ['ddsa', 'mw'],
    "amānanaṃ": ['ap90'],
    "amānasya": ['mw'],
    "amānasyaṃ": ['ap90'],
    "amānatā": ['mw'],
    "amānava": ['ap90', 'ddsa', 'mw'],
    "amānayant": ['cae'],
    "amānin": ['ap90', 'cae', 'mw'],
    "amānita": ['ddsa'],
    "amānitva": ['cae', 'ddsa', 'mw'],
    "amānitā": ['ap90', 'mw'],
    "amānta": ['mw'],
    "amānussika": ['cped'],
    "amānuṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "amānuṣaloka": ['mw'],
    "amānuṣya": ['ap90', 'mw'],
    "amānuṣī": ['mw'],
    "amāputra": ['mw'],
    "amāputrā": ['mw'],
    "amāpya": ['bhs', 'mw'],
    "amāpyaparivarta": ['bhs'],
    "amāra": ['ddsa', 'mw'],
    "amāraka": ['mw'],
    "amāraḥ": ['ap90'],
    "amārga": ['ap90', 'ddsa', 'mw'],
    "amārgaprasṛt": ['mw'],
    "amārgeṇa": ['mw'],
    "amārjita": ['cae', 'ddsa', 'mw'],
    "amāt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "amātia": ['gra'],
    "amātra": ['ap90', 'bhs', 'gra', 'mw'],
    "amātrajña": ['bhs'],
    "amātrajñata": ['bhs'],
    "amātravatvaṃ": ['ap90'],
    "amātrayā": ['mw'],
    "amātrā": ['ddsa'],
    "amātsarya": ['mw'],
    "amātsaryatā": ['mw'],
    "amātva": ['mw'],
    "amātya": ['cae', 'ddsa', 'gra', 'mw'],
    "amātyaprekṣita": ['bhs'],
    "amātyaḥ": ['ap90'],
    "amātāputra": ['mw'],
    "amātāputrādhyāpaka": ['mw'],
    "amātāputtika": ['cped'],
    "amātṛ": ['ap90', 'mw'],
    "amātṛbhogīṇa": ['ap90'],
    "amātṛjña": ['bhs'],
    "amātṛka": ['mw'],
    "amāvasu": ['cae', 'mw'],
    "amāvasyā": ['ap90', 'mw'],
    "amāvasī": ['mw'],
    "amāvāsya": ['ap90', 'mw'],
    "amāvāsyaka": ['mw'],
    "amāvāsyā": ['cae', 'mw'],
    "amāvāsī": ['cae', 'ddsa', 'mw'],
    "amāya": ['ap90', 'cae', 'ddsa', 'mw'],
    "amāyayā": ['mw'],
    "amāyika": ['ap90', 'mw'],
    "amāyin": ['mw'],
    "amāyā": ['cae', 'ddsa', 'mw'],
    "amāṃsa": ['ap90', 'mw'],
    "amāṃsabhakṣa": ['ddsa', 'mw'],
    "amāṃsaka": ['mw'],
    "amāṃsāśana": ['mw'],
    "amāṃsāśin": ['mw'],
    "amāṣa": ['mw'],
    "amī": ['ddsa', 'gra'],
    "amīmāṃsaka": ['mw'],
    "amīmāṃsasya": ['ddsa'],
    "amīmāṃsya": ['cae', 'mw'],
    "amīmāṃsā": ['mw'],
    "amīta": ['ap90', 'gra'],
    "amītavarṇa": ['ddsa', 'gra', 'mw'],
    "amīva": ['cae', 'ddsa', 'gra', 'mw'],
    "amīvacātana": ['cae', 'gra', 'mw'],
    "amīvahan": ['gra', 'mw'],
    "amīvā": ['ap90', 'gra', 'mw'],
    "amūdṛkṣa": ['mw'],
    "amūdṛś": ['ap90', 'mw'],
    "amūdṛśa": ['mw'],
    "amūla": ['ap90', 'cae', 'ddsa', 'mw'],
    "amūlaka": ['bhs'],
    "amūlya": ['ap90', 'cae', 'mw'],
    "amūlyaka": ['bhs'],
    "amūlā": ['bhs', 'mw'],
    "amūra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "amūrta": ['ap90', 'ddsa', 'mw'],
    "amūrtarajas": ['mw'],
    "amūrtarajasa": ['mw'],
    "amūrtarayasa": ['mw'],
    "amūrti": ['ap90', 'mw'],
    "amūrtimat": ['ap90', 'mw'],
    "amūḍha": ['cae', 'ddsa', 'mw'],
    "amūḍhavinaya": ['bhs'],
    "amṇas": ['cae', 'mw'],
    "amṛdhra": ['ap90', 'cae', 'gra', 'mw'],
    "amṛkta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "amṛnmaya": ['mw'],
    "amṛnmayapa": ['mw'],
    "amṛnmayapāyin": ['mw'],
    "amṛta": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "amṛtabandhu": ['gra', 'mw'],
    "amṛtabhavana": ['mw'],
    "amṛtabhojana": ['cae', 'mw'],
    "amṛtabhuj": ['mw'],
    "amṛtabhāṣaṇa": ['mw'],
    "amṛtabindūpaniṣad": ['mw'],
    "amṛtacit": ['mw'],
    "amṛtaciti": ['mw'],
    "amṛtadhārā": ['mw'],
    "amṛtadhāyin": ['cae', 'mw'],
    "amṛtadrava": ['mw'],
    "amṛtadyuti": ['mw'],
    "amṛtadīdhiti": ['mw'],
    "amṛtagarbha": ['mw'],
    "amṛtagati": ['mw'],
    "amṛtaharītakī": ['mw'],
    "amṛtahrada": ['mw'],
    "amṛtajaṭā": ['mw'],
    "amṛtajā": ['mw'],
    "amṛtaka": ['mw'],
    "amṛtakalpa": ['cae'],
    "amṛtakara": ['mw'],
    "amṛtakaṃ": ['ap90'],
    "amṛtakeśava": ['mw'],
    "amṛtakiraṇa": ['mw'],
    "amṛtakuṇḍa": ['mw'],
    "amṛtakuṇḍalī": ['bhs'],
    "amṛtakṣāra": ['mw'],
    "amṛtalatikā": ['mw'],
    "amṛtalatā": ['mw'],
    "amṛtaloka": ['mw'],
    "amṛtamanthana": ['mw'],
    "amṛtamati": ['mw'],
    "amṛtamaya": ['ap90', 'cae', 'mw'],
    "amṛtamegha": ['cae', 'mw'],
    "amṛtamālinī": ['mw'],
    "amṛtanādopaniṣad": ['mw'],
    "amṛtapa": ['mw'],
    "amṛtapakṣa": ['mw'],
    "amṛtaparvataprabhāteja": ['bhs'],
    "amṛtaphala": ['bhs', 'mw'],
    "amṛtaphalā": ['mw'],
    "amṛtaplavana": ['cae', 'mw'],
    "amṛtaprabha": ['mw'],
    "amṛtaprabhā": ['mw'],
    "amṛtaprāsin": ['mw'],
    "amṛtaprāśana": ['mw'],
    "amṛtapāyin": ['mw'],
    "amṛtarasa": ['mw'],
    "amṛtarasā": ['mw'],
    "amṛtaraśmi": ['cae', 'mw'],
    "amṛtasahodara": ['mw'],
    "amṛtasambhava": ['mw'],
    "amṛtasambhavā": ['mw'],
    "amṛtasaras": ['mw'],
    "amṛtasodara": ['mw'],
    "amṛtasravā": ['mw'],
    "amṛtasrut": ['mw'],
    "amṛtasrāva": ['mw'],
    "amṛtasāraja": ['mw'],
    "amṛtasū": ['mw'],
    "amṛtataraṅgiṇī": ['mw'],
    "amṛtatejas": ['mw'],
    "amṛtatva": ['cae', 'gra', 'mw'],
    "amṛtatā": ['ap90', 'mw'],
    "amṛtavallarī": ['mw'],
    "amṛtavallī": ['mw'],
    "amṛtavapus": ['mw'],
    "amṛtavardhana": ['mw'],
    "amṛtavarti": ['cae'],
    "amṛtavarṣin": ['mw'],
    "amṛtavindu": ['bhs'],
    "amṛtavindūpaniṣad": ['mw'],
    "amṛtavākā": ['mw'],
    "amṛtayajña": ['mw'],
    "amṛtayoga": ['mw'],
    "amṛtayoni": ['mw'],
    "amṛtaśāstra": ['mw'],
    "amṛteśa": ['mw'],
    "amṛteśaya": ['mw'],
    "amṛteśayaḥ": ['ap90'],
    "amṛteśvara": ['ddsa', 'mw'],
    "amṛteṣṭakā": ['mw'],
    "amṛtikā": ['ddsa'],
    "amṛtodana": ['bhs', 'mw'],
    "amṛtodbhava": ['cae', 'mw'],
    "amṛtopama": ['cae', 'ddsa', 'mw'],
    "amṛtopastaraṇa": ['mw'],
    "amṛtotpanna": ['mw'],
    "amṛtotpannā": ['mw'],
    "amṛtotpatti": ['mw'],
    "amṛtpātrapa": ['mw'],
    "amṛtyu": ['ap90', 'cae', 'gra', 'mw'],
    "amṛtā": ['mw'],
    "amṛtābhiṣikta": ['mw'],
    "amṛtāharaṇa": ['mw'],
    "amṛtāhuti": ['ddsa', 'mw'],
    "amṛtāhva": ['mw'],
    "amṛtākara": ['mw'],
    "amṛtākṣara": ['mw'],
    "amṛtānanda": ['mw'],
    "amṛtāndhas": ['mw'],
    "amṛtāphala": ['mw'],
    "amṛtāphalaṃ": ['ap90'],
    "amṛtāpidhāna": ['mw'],
    "amṛtāsaṅga": ['mw'],
    "amṛtāsu": ['mw'],
    "amṛtātman": ['mw'],
    "amṛtāya": ['ddsa', 'mw'],
    "amṛtāyana": ['mw'],
    "amṛtāyate": ['ap90'],
    "amṛtāśa": ['mw'],
    "amṛtāśana": ['mw'],
    "amṛtāśma": ['mw'],
    "amṛtāśmagarbha": ['bhs'],
    "amṛtāṃsu": ['ddsa'],
    "amṛtāṃśu": ['cae', 'mw'],
    "amṛtāṣṭamītapas": ['mw'],
    "amṛtībhū": ['ddsa', 'mw'],
    "amṛtīkaraṇa": ['mw'],
    "amṛḍaya": ['mw'],
    "amṛṇāla": ['mw'],
    "amṛṇālaṃ": ['ap90'],
    "amṛṣodya": ['mw'],
    "amṛṣyamāṇa": ['cae', 'ddsa', 'mw'],
    "amṛṣā": ['ap90', 'cae', 'mw'],
    "amṛṣābhāṣitva": ['mw'],
    "amṛṣṭa": ['ap90', 'mw'],
    "amṛṣṭabhojin": ['mw'],
    "amṛṣṭabhuj": ['mw'],
    "amṛṣṭamṛja": ['mw'],
    "an": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ana": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "anabbhakkhātukama": ['cped'],
    "anabbhita": ['cped'],
    "anabhibhavagandha": ['cae', 'ddsa'],
    "anabhibhuyya": ['cped'],
    "anabhibhāṣin": ['cae', 'ddsa'],
    "anabhibhūta": ['cped', 'mw'],
    "anabhibhūtamakuṭa": ['bhs'],
    "anabhibhūtayaśas": ['bhs'],
    "anabhicaraṇīya": ['ddsa'],
    "anabhidhyeya": ['ddsa'],
    "anabhidhyā": ['ddsa'],
    "anabhidhyālu": ['bhs'],
    "anabhidhāna": ['cae', 'ddsa'],
    "anabhidhāyaka": ['ddsa'],
    "anabhidroha": ['ddsa'],
    "anabhidrohin": ['bhs'],
    "anabhidruh": ['gra', 'mw'],
    "anabhigamanīya": ['cae', 'ddsa'],
    "anabhigata": ['mw'],
    "anabhighāta": ['ddsa'],
    "anabhihita": ['ap90', 'cae', 'ddsa', 'mw'],
    "anabhihitavācya": ['mw'],
    "anabhihiṁsamāna": ['cped'],
    "anabhihuta": ['ddsa'],
    "anabhijita": ['mw'],
    "anabhijjhita": ['cped'],
    "anabhijjhā": ['cped'],
    "anabhijjhālu": ['cped'],
    "anabhijjhāta": ['cped'],
    "anabhijjhātar": ['cped'],
    "anabhijña": ['ap90', 'cae', 'ddsa', 'mw'],
    "anabhijñeya": ['ddsa'],
    "anabhijñāta": ['cae', 'ddsa'],
    "anabhijānā": ['cped'],
    "anabhijānāt": ['cped'],
    "anabhijāta": ['ddsa'],
    "anabhikhyāta": ['cae'],
    "anabhikhyātadoṣa": ['ddsa'],
    "anabhilakṣita": ['bhs', 'mw'],
    "anabhilakṣitaḥ": ['ap90'],
    "anabhilapanīya": ['bhs'],
    "anabhilapya": ['bhs'],
    "anabhilulita": ['cae', 'ddsa', 'mw'],
    "anabhilāpya": ['bhs'],
    "anabhilāpyaparivarta": ['bhs'],
    "anabhilāpyodgata": ['bhs'],
    "anabhilāpyānabhilāpya": ['bhs'],
    "anabhilāpyānabhilāpyaparivarta": ['bhs'],
    "anabhilāpyānabhilāpyaparivartanirdeśa": ['bhs'],
    "anabhilāṣa": ['ap90', 'mw'],
    "anabhilāṣin": ['mw'],
    "anabhimata": ['cae', 'ddsa', 'mw'],
    "anabhimlāna": ['ap90', 'mw'],
    "anabhimlāta": ['gra', 'mw'],
    "anabhimlātavarṇa": ['gra', 'mw'],
    "anabhimukha": ['ddsa'],
    "anabhimānuka": ['ddsa', 'mw'],
    "anabhinanda": ['cped'],
    "anabhinandamāna": ['cped'],
    "anabhinandana": ['cped'],
    "anabhinandat": ['cped'],
    "anabhinandita": ['cped'],
    "anabhinata": ['cped'],
    "anabhineyya": ['cped'],
    "anabhinibbatti": ['cped'],
    "anabhinirvṛtta": ['bhs'],
    "anabhinivesa": ['cped'],
    "anabhiniveśana": ['bhs'],
    "anabhiniviṣṭi": ['bhs'],
    "anabhinivṛttitā": ['bhs'],
    "anabhipreta": ['mw'],
    "anabhiprīta": ['ddsa'],
    "anabhiraddha": ['cped'],
    "anabhiraddhi": ['cped'],
    "anabhiramanta": ['cped'],
    "anabhiramya": ['bhs'],
    "anabhirata": ['cped'],
    "anabhirati": ['cped'],
    "anabhirūpa": ['ddsa', 'mw'],
    "anabhisaddahati": ['cped'],
    "anabhisamaya": ['cped'],
    "anabhisambandha": ['mw'],
    "anabhisambhava": ['cped'],
    "anabhisambhavanīya": ['cped'],
    "anabhisambhavat": ['cped'],
    "anabhisambhuṇāti": ['cped'],
    "anabhisambuddha": ['cped'],
    "anabhisamecca": ['cped'],
    "anabhisameta": ['cped'],
    "anabhisandhi": ['ddsa', 'mw'],
    "anabhisandhikṛta": ['mw'],
    "anabhisandhāna": ['ddsa', 'mw'],
    "anabhisaraṇa": ['bhs'],
    "anabhisañcetayanta": ['cped'],
    "anabhisaṃdhi": ['cae'],
    "anabhisaṃdhānaṃ": ['ap90'],
    "anabhisaṃdhāya": ['cae'],
    "anabhisaṃhitam": ['cae', 'ddsa'],
    "anabhisaṃskāra": ['bhs'],
    "anabhisaṃskārikā": ['bhs'],
    "anabhisaṃskṛta": ['bhs'],
    "anabhisaṅkhacca": ['cped'],
    "anabhisaṅkharonta": ['cped'],
    "anabhisitta": ['cped'],
    "anabhisneha": ['cae', 'ddsa', 'mw'],
    "anabhissara": ['cped'],
    "anabhitāpa": ['ddsa'],
    "anabhivada": ['cped'],
    "anabhivadat": ['cped'],
    "anabhivitaritvā": ['cped'],
    "anabhivyakta": ['cae', 'ddsa', 'mw'],
    "anabhivāduka": ['mw'],
    "anabhivādya": ['ddsa', 'mw'],
    "anabhiyukta": ['ddsa'],
    "anabhiññāta": ['cped'],
    "anabhiññāya": ['cped'],
    "anabhiśasta": ['ap90', 'gra', 'mw'],
    "anabhiśastenya": ['mw'],
    "anabhiśasti": ['ddsa', 'mw'],
    "anabhiśastya": ['mw'],
    "anabhiśastī": ['mw'],
    "anabhiśaṅka": ['ddsa'],
    "anabhiśaṅkya": ['ddsa'],
    "anabhiṇata": ['cped'],
    "anabhiṣaṅga": ['cae', 'mw'],
    "anabhiṣecanīya": ['ddsa', 'mw'],
    "anabhiṣekya": ['mw'],
    "anabhiṣvaṅga": ['cae', 'ddsa', 'mw'],
    "anabhra": ['ap90', 'cae', 'ddsa', 'mw'],
    "anabhraka": ['bhs', 'mw'],
    "anabhravṛṣṭi": ['mw'],
    "anabhri": ['ap90', 'mw'],
    "anabhyantara": ['cae', 'ddsa'],
    "anabhyanujñā": ['ddsa', 'mw'],
    "anabhyanujñāta": ['cae', 'ddsa'],
    "anabhyarcya": ['cae'],
    "anabhyarthanīya": ['cae', 'ddsa'],
    "anabhyasūyikayā": ['bhs'],
    "anabhyavacāruka": ['mw'],
    "anabhyupāya": ['ddsa'],
    "anabhyutkruṣṭa": ['ddsa'],
    "anabhyutthāyin": ['ddsa'],
    "anabhyāroha": ['mw'],
    "anabhyārohya": ['mw'],
    "anabhyārūḍha": ['mw'],
    "anabhyāsa": ['cae', 'ddsa', 'mw'],
    "anabhyāsamitya": ['mw'],
    "anabhyāvartin": ['ddsa'],
    "anabhyāvṛtti": ['ddsa'],
    "anabhyāvṛttiḥ": ['ap90'],
    "anabhyāśa": ['ap90', 'mw'],
    "anabhāva": ['cped'],
    "anabhāvakata": ['cped'],
    "anabhāvaṅgata": ['cped'],
    "anabhāvaṅkata": ['cped'],
    "anabhīkṣṇa": ['ddsa'],
    "anabhīśu": ['cae', 'ddsa', 'gra', 'mw'],
    "anaccekacīvara": ['cped'],
    "anaccha": ['ap90', 'mw'],
    "anacchariya": ['cped'],
    "anacchariyaṁ": ['cped'],
    "anadant": ['cae'],
    "anadat": ['ddsa', 'gra', 'mw'],
    "anadbhuta": ['ddsa'],
    "anaddhā": ['ap90', 'cae', 'mw'],
    "anaddhāpuruṣa": ['mw'],
    "anadhas": ['mw'],
    "anadhibhū": ['cped'],
    "anadhibhūta": ['cped'],
    "anadhigama": ['cped'],
    "anadhigamanīya": ['ddsa', 'mw'],
    "anadhigamya": ['mw'],
    "anadhigata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "anadhigatamanoratha": ['mw'],
    "anadhigataśāstra": ['mw'],
    "anadhika": ['ap90', 'cped', 'mw'],
    "anadhikāra": ['mw'],
    "anadhikāracarcā": ['mw'],
    "anadhikāraḥ": ['ap90'],
    "anadhikārin": ['ap90', 'mw'],
    "anadhikṛta": ['ddsa', 'mw'],
    "anadhimokṣa": ['bhs'],
    "anadhimucchita": ['cped'],
    "anadhimūrchita": ['bhs'],
    "anadhivāsaya": ['cped'],
    "anadhivāsayat": ['cped'],
    "anadhivāsenta": ['cped'],
    "anadhiṣṭhita": ['mw'],
    "anadhiṣṭhāna": ['ddsa', 'mw'],
    "anadhiṣṭhāpada": ['bhs'],
    "anadhiṭṭhita": ['cped'],
    "anadhiṭṭhāna": ['cped'],
    "anadhiṭṭhāya": ['cped'],
    "anadhvanya": ['ddsa'],
    "anadhyakṣa": ['ap90', 'ddsa', 'mw'],
    "anadhyavasita": ['bhs', 'mw'],
    "anadhyavasāna": ['bhs'],
    "anadhyayana": ['cae', 'ddsa', 'mw'],
    "anadhyupekṣā": ['bhs'],
    "anadhyācāra": ['bhs'],
    "anadhyāpatti": ['bhs'],
    "anadhyāsa": ['mw'],
    "anadhyātmavid": ['cae', 'ddsa', 'mw'],
    "anadhyāya": ['cae', 'ddsa', 'mw'],
    "anadhyāyadivasa": ['mw'],
    "anadhyāyaḥ": ['ap90'],
    "anadhyāyin": ['ddsa'],
    "anadhīna": ['ap90', 'mw'],
    "anadhīnaka": ['mw'],
    "anadhītya": ['cae', 'mw'],
    "anadhīyant": ['cae'],
    "anadhīyat": ['mw'],
    "anadhīyāna": ['cae', 'mw'],
    "anadhīṣṭa": ['mw'],
    "anadyatana": ['ap90', 'cae', 'ddsa', 'mw'],
    "anadyaḥ": ['ap90'],
    "anagga": ['cped'],
    "anaggahīta": ['cped'],
    "anaggahītacitta": ['cped'],
    "anaggava": ['cped'],
    "anaggavat": ['cped'],
    "anagha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "anaghāṣṭamī": ['mw'],
    "anagna": ['ddsa', 'gra', 'mw'],
    "anagnatā": ['mw'],
    "anagni": ['ap90', 'cae', 'ddsa', 'mw'],
    "anagnidagdha": ['cae', 'gra', 'mw'],
    "anagnitrā": ['gra', 'mw'],
    "anagniṣvātta": ['mw'],
    "anagāra": ['ap90', 'mw'],
    "anagārikā": ['ap90', 'bhs', 'mw'],
    "anagārā": ['cped'],
    "anaha": ['mw'],
    "anahambuddhi": ['mw'],
    "anahan": ['ap90', 'mw'],
    "anaharjāta": ['ddsa'],
    "anahaṃkāra": ['cae', 'mw'],
    "anahaṃkṛta": ['cae', 'mw'],
    "anahaṃkṛti": ['mw'],
    "anahaṃvādin": ['cae', 'mw'],
    "anahaṅkṛta": ['ddsa'],
    "anaibhṛtya": ['mw'],
    "anaikya": ['mw'],
    "anaikyaṃ": ['ap90'],
    "anaikānta": ['mw'],
    "anaikāntika": ['mw'],
    "anaikāntikatva": ['mw'],
    "anaikāntikatā": ['mw'],
    "anaikāṃta": ['ap90'],
    "anaikāṃtika": ['ap90'],
    "anaikāṃtyaṃ": ['ap90'],
    "anaindava": ['mw'],
    "anaipuṇa": ['mw'],
    "anaipuṇya": ['mw'],
    "anairyānika": ['bhs'],
    "anaitihya": ['mw'],
    "anaitihyaṃ": ['ap90'],
    "anaiścārika": ['mw'],
    "anaiśvarya": ['mw'],
    "anaiḍaka": ['mw'],
    "anaiṣpeṣikatā": ['bhs'],
    "anajakā": ['ap90', 'mw'],
    "anajikā": ['mw'],
    "anajjhagaṁ": ['cped'],
    "anajjhopanna": ['cped'],
    "anajjhosita": ['cped'],
    "anajjhosāna": ['cped'],
    "anajjhosāya": ['cped'],
    "anajjhāpanna": ['cped'],
    "anajjhāpatti": ['cped'],
    "anajjhārūha": ['cped'],
    "anajjhāyaka": ['cped'],
    "anaka": ['ap90', 'mw'],
    "anakadundubha": ['mw'],
    "anakadundubhi": ['mw'],
    "anakaduṃdubhiḥ": ['ap90'],
    "anakasmāt": ['ap90', 'mw'],
    "anakkhāna": ['cped'],
    "anakkhāta": ['cped'],
    "anakkosakaparibhāsika": ['cped'],
    "anakāmamāra": ['ddsa', 'mw'],
    "anakṣ": ['ap90', 'gra', 'mw'],
    "anakṣa": ['ap90', 'gra', 'mw'],
    "anakṣara": ['ap90', 'ddsa', 'mw'],
    "anakṣasaṅgam": ['mw'],
    "anakṣastambham": ['mw'],
    "anakṣi": ['ap90', 'mw'],
    "anakṣika": ['mw'],
    "anakṣita": ['mw'],
    "anala": ['bhs', 'cae', 'ddsa', 'mw'],
    "analada": ['mw'],
    "analadīpana": ['mw'],
    "analam": ['ddsa', 'mw'],
    "analaprabhā": ['mw'],
    "analapriyā": ['mw'],
    "analasa": ['ap90', 'cped', 'ddsa', 'mw'],
    "analasakha": ['ddsa', 'mw'],
    "analasāda": ['mw'],
    "analavāṭa": ['mw'],
    "analaḥ": ['ap90'],
    "analaṁ": ['cped'],
    "analaṃkariṣṇu": ['mw'],
    "analaṃkṛta": ['cae'],
    "analaṅkaritvā": ['cped'],
    "analaṅkata": ['cped'],
    "analaṅkṛta": ['ddsa'],
    "anali": ['mw'],
    "analiḥ": ['ap90'],
    "analopala": ['mw'],
    "analpa": ['ap90', 'ddsa', 'mw'],
    "analpaghoṣa": ['mw'],
    "analpaka": ['bhs'],
    "analpamanyu": ['mw'],
    "analāya": ['ddsa', 'mw'],
    "anama": ['ddsa', 'mw'],
    "anamasyu": ['mw'],
    "anamatagga": ['cped'],
    "anamaḥ": ['ap90'],
    "anambara": ['mw'],
    "anambu": ['mw'],
    "anamin": ['mw'],
    "anamitampaca": ['mw'],
    "anamitapūrva": ['ddsa'],
    "anamitaṃpaca": ['ap90'],
    "anamitra": ['ap90', 'cae', 'mw'],
    "anamitralābha": ['cae', 'ddsa'],
    "anamra": ['ap90', 'ddsa'],
    "anamutra": ['ddsa'],
    "anamīva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anana": ['mw'],
    "ananaṃ": ['ap90'],
    "ananaṅgamejaya": ['mw'],
    "ananda": ['cae', 'mw'],
    "anandha": ['cae', 'cped', 'ddsa', 'mw'],
    "anandhakaraṇa": ['cped'],
    "ananna": ['mw'],
    "anannaṃ": ['ap90'],
    "ananta": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "anantabalavighuṣṭanināditaśrīsaṃbhavamati": ['bhs'],
    "anantabhaṭṭa": ['mw'],
    "anantabuddhi": ['bhs'],
    "anantabāhu": ['cae'],
    "anantacaturdaśī": ['mw'],
    "anantachattra": ['bhs'],
    "anantacāritra": ['bhs', 'mw'],
    "anantadassi": ['cped'],
    "anantadassin": ['cped'],
    "anantadeva": ['mw'],
    "anantadṛṣṭi": ['mw'],
    "anantaga": ['mw'],
    "anantaghoṣa": ['bhs'],
    "anantagupta": ['bhs'],
    "anantaguṇa": ['mw'],
    "anantagāhikā": ['cped'],
    "anantajit": ['mw'],
    "anantajñānottara": ['bhs'],
    "anantaka": ['bhs', 'cped', 'mw'],
    "anantakara": ['mw'],
    "anantakośa": ['bhs'],
    "anantamadhya": ['bhs'],
    "anantamati": ['bhs', 'mw'],
    "anantamukhadevāsuranetrāsura": ['bhs'],
    "anantamukhanirhāradhāraṇī": ['bhs'],
    "anantamāyin": ['mw'],
    "anantamāyā": ['bhs'],
    "anantamūla": ['mw'],
    "anantanemi": ['bhs', 'mw'],
    "anantanirdeśapratiṣṭhāna": ['bhs'],
    "anantaparikarasāgarameghavyūhatejomaṇḍalachattrākārarāja": ['bhs'],
    "anantapañña": ['cped'],
    "anantaprabha": ['bhs'],
    "anantapratibhāna": ['bhs'],
    "anantapāla": ['mw'],
    "anantapāpa": ['cae'],
    "anantapāra": ['mw'],
    "anantapīlu": ['bhs'],
    "anantara": ['cae', 'cped', 'ddsa', 'mw'],
    "anantaradhāna": ['cped'],
    "anantarahita": ['cped'],
    "anantaraja": ['cae', 'ddsa', 'mw'],
    "anantarajāta": ['cae', 'mw'],
    "anantaram": ['mw'],
    "anantaraya": ['mw'],
    "anantaraśmidharmadhātusamalaṃkṛtadharmarāja": ['bhs'],
    "anantaraṁ": ['cped'],
    "anantarhita": ['mw'],
    "anantarhiti": ['mw'],
    "anantarika": ['cped'],
    "anantarita": ['mw'],
    "anantariti": ['mw'],
    "anantariya": ['bhs'],
    "anantarya": ['bhs'],
    "anantaryasamādhi": ['bhs'],
    "anantarā": ['cped'],
    "anantarāma": ['mw'],
    "anantarāya": ['cae', 'ddsa'],
    "anantarāyam": ['mw'],
    "anantarāyika": ['bhs', 'cped'],
    "anantarāyikinī": ['cped'],
    "anantarāśi": ['mw'],
    "anantarīya": ['mw'],
    "anantarūpa": ['cae', 'mw'],
    "anantatva": ['mw'],
    "anantatā": ['cae', 'mw'],
    "anantatāna": ['mw'],
    "anantatīrtha": ['mw'],
    "anantatīrthakṛt": ['mw'],
    "anantatṛtīyā": ['mw'],
    "anantatṛtīyāvrata": ['mw'],
    "anantaujas": ['bhs'],
    "anantava": ['bhs', 'cped'],
    "anantavarman": ['mw'],
    "anantavarṇaratna": ['bhs'],
    "anantavarṇā": ['bhs'],
    "anantavat": ['cped', 'mw'],
    "anantavijaya": ['cae', 'ddsa', 'mw'],
    "anantavikramin": ['mw'],
    "anantavikrāmin": ['bhs'],
    "anantavrata": ['mw'],
    "anantavāta": ['mw'],
    "anantavīrya": ['bhs', 'cae', 'mw'],
    "anantayaśas": ['bhs'],
    "anantaśakti": ['mw'],
    "anantaśayana": ['mw'],
    "anantaśira": ['bhs'],
    "anantaśubhanayanakesarin": ['bhs'],
    "anantaśuṣma": ['cae', 'gra', 'mw'],
    "anantaśāyin": ['mw'],
    "anantaśīrṣā": ['mw'],
    "anantaḥpādam": ['mw'],
    "anantevāsika": ['cped'],
    "ananteśvara": ['mw'],
    "anantikastha": ['ddsa'],
    "anantya": ['cae', 'ddsa', 'mw'],
    "anantā": ['mw'],
    "anantāsana": ['bhs'],
    "anantātman": ['mw'],
    "anantāvabhāsarājendra": ['bhs'],
    "anantāvarta": ['bhs'],
    "anantāvartā": ['bhs'],
    "anantāśrama": ['mw'],
    "ananubhodha": ['cped'],
    "ananubhāvaka": ['ddsa', 'mw'],
    "ananubhāvakatā": ['mw'],
    "ananubhāvuka": ['ap90'],
    "ananubhāṣaṇa": ['mw'],
    "ananubhāṣaṇaṃ": ['ap90'],
    "ananubhūta": ['cae', 'cped', 'ddsa', 'mw'],
    "ananucchavika": ['cped'],
    "ananucchaviya": ['cped'],
    "ananudhyāyin": ['ddsa', 'mw'],
    "ananugatantara": ['cped'],
    "ananugiddha": ['cped'],
    "ananujñāpya": ['cae'],
    "ananujñāta": ['cae', 'ddsa', 'mw'],
    "ananukampanīya": ['ddsa'],
    "ananukhyāti": ['mw'],
    "ananukūla": ['ddsa'],
    "ananulomika": ['cped'],
    "ananulomiya": ['cped'],
    "ananumata": ['mw'],
    "ananumeya": ['ddsa'],
    "ananumodaka": ['cped'],
    "ananuppatta": ['cped'],
    "ananuruddha": ['cped'],
    "ananurūpa": ['cae', 'ddsa'],
    "ananusandhāna": ['ddsa'],
    "ananusaraṇa": ['ddsa'],
    "ananusaya": ['cped'],
    "ananusiṭṭha": ['cped'],
    "ananussarita": ['cped'],
    "ananussuta": ['cped'],
    "ananutappa": ['cped'],
    "ananutiṣṭhat": ['ddsa'],
    "ananuvajja": ['cped'],
    "ananuvejja": ['cped'],
    "ananuvicca": ['cped'],
    "ananuvrata": ['cae', 'ddsa'],
    "ananuvāda": ['cped'],
    "ananuvākya": ['mw'],
    "ananuvṛtti": ['ddsa'],
    "ananuyoga": ['cped', 'mw'],
    "ananuyujya": ['bhs'],
    "ananuyukta": ['bhs'],
    "ananuyutta": ['cped'],
    "ananuyāja": ['mw'],
    "ananuññāta": ['cped'],
    "ananuśruta": ['bhs'],
    "ananuṣaṅgin": ['mw'],
    "ananuṣṭhāna": ['cae', 'ddsa', 'mw'],
    "ananuṣṭhātṛ": ['ddsa'],
    "ananvagbhāva": ['mw'],
    "ananvavacāra": ['mw'],
    "ananvavajaya": ['mw'],
    "ananvavāya": ['mw'],
    "ananvavāyana": ['mw'],
    "ananvaya": ['cped', 'mw'],
    "ananvayaḥ": ['ap90'],
    "ananvita": ['ap90', 'mw'],
    "ananviṣyant": ['cae'],
    "ananviṣyat": ['ddsa'],
    "ananvābhakta": ['mw'],
    "ananvāgama": ['mw'],
    "ananvāgata": ['mw'],
    "ananvāhataceta": ['cped'],
    "ananvāhatacetas": ['cped'],
    "ananya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ananyabhava": ['mw'],
    "ananyabhāj": ['cae'],
    "ananyabhāva": ['mw'],
    "ananyacetas": ['cae', 'mw'],
    "ananyacitta": ['cae', 'mw'],
    "ananyacodita": ['mw'],
    "ananyadeva": ['bhs', 'mw'],
    "ananyadṛṣṭi": ['cae', 'mw'],
    "ananyagati": ['mw'],
    "ananyagatika": ['mw'],
    "ananyaguru": ['mw'],
    "ananyagāmin": ['bhs', 'ddsa', 'mw'],
    "ananyahṛta": ['mw'],
    "ananyaja": ['mw'],
    "ananyajanman": ['cae'],
    "ananyajāni": ['mw'],
    "ananyakārya": ['mw'],
    "ananyamanas": ['cae', 'mw'],
    "ananyamanaska": ['mw'],
    "ananyamānasa": ['cae', 'mw'],
    "ananyaneya": ['bhs'],
    "ananyaniṣpādya": ['mw'],
    "ananyapakṣika": ['bhs'],
    "ananyapara": ['cae'],
    "ananyaparāyaṇa": ['cae', 'mw'],
    "ananyapratikriya": ['mw'],
    "ananyapūrvā": ['mw'],
    "ananyaruci": ['cae'],
    "ananyarādhas": ['mw'],
    "ananyasama": ['cae'],
    "ananyasādhāraṇa": ['cae', 'mw'],
    "ananyasāmānya": ['cae'],
    "ananyatha": ['bhs'],
    "ananyathāvṛtti": ['ddsa'],
    "ananyatva": ['mw'],
    "ananyatā": ['ap90', 'mw'],
    "ananyavandin": ['mw'],
    "ananyaviṣaya": ['cae', 'mw'],
    "ananyaviṣayātman": ['mw'],
    "ananyavṛtti": ['mw'],
    "ananyayoga": ['cae', 'mw'],
    "ananyayogam": ['mw'],
    "ananyādṛśa": ['ap90', 'ddsa', 'mw'],
    "ananyānubhava": ['mw'],
    "ananyārtha": ['mw'],
    "ananyāśrita": ['mw'],
    "ananūcya": ['ddsa'],
    "ananūkta": ['cae', 'ddsa', 'mw'],
    "ananūkti": ['ddsa'],
    "ananūtthāna": ['ddsa', 'mw'],
    "ananūyāja": ['mw'],
    "ananṛta": ['ddsa', 'mw'],
    "anapa": ['ap90', 'mw'],
    "anapabhraṃśaḥ": ['ap90'],
    "anapacyuta": ['cae', 'gra', 'mw'],
    "anapacāyitṛ": ['mw'],
    "anapacāyyamāna": ['mw'],
    "anapadesa": ['cped'],
    "anapadeśa": ['mw'],
    "anapadeśya": ['ddsa'],
    "anapadhṛṣya": ['mw'],
    "anapadoṣya": ['mw'],
    "anapadāna": ['cped'],
    "anapaga": ['mw'],
    "anapagata": ['cped'],
    "anapahanana": ['mw'],
    "anapahatapāpman": ['mw'],
    "anapajayya": ['ap90'],
    "anapajayyam": ['mw'],
    "anapakaraṇa": ['mw'],
    "anapakaraṇaṃ": ['ap90'],
    "anapakarman": ['cae', 'ddsa', 'mw'],
    "anapakarṣa": ['mw'],
    "anapakrama": ['ddsa', 'mw'],
    "anapakramin": ['ddsa', 'mw'],
    "anapakriyā": ['cae', 'ddsa', 'mw'],
    "anapakrāma": ['ddsa', 'mw'],
    "anapakrāmuka": ['mw'],
    "anapakāra": ['mw'],
    "anapakāraḥ": ['ap90'],
    "anapakārin": ['cae', 'ddsa', 'mw'],
    "anapakṛta": ['ddsa', 'mw'],
    "anapakṣepya": ['mw'],
    "anapaloketvā": ['cped'],
    "anapalokita": ['cped'],
    "anapalāṣuka": ['mw'],
    "anapanaya": ['ddsa'],
    "anapanihita": ['ap90'],
    "anapanihitam": ['mw'],
    "anapara": ['ap90', 'mw'],
    "anaparodha": ['ddsa'],
    "anaparuddha": ['mw'],
    "anaparāddha": ['cae', 'mw'],
    "anaparāddham": ['mw'],
    "anaparādha": ['ap90', 'cae', 'ddsa', 'mw'],
    "anaparādhatva": ['mw'],
    "anaparādhin": ['cae', 'mw'],
    "anaparāmṛśant": ['bhs'],
    "anapasara": ['ap90', 'cae', 'ddsa', 'mw'],
    "anapasaraṇa": ['mw'],
    "anapasphur": ['ap90', 'cae', 'gra', 'mw'],
    "anapasphura": ['cae', 'gra', 'mw'],
    "anapasphurant": ['cae'],
    "anapasphurat": ['ddsa', 'gra', 'mw'],
    "anapaspṛś": ['ap90', 'mw'],
    "anapasādetvā": ['cped'],
    "anapatnīka": ['bhs'],
    "anapatrapa": ['ap90', 'mw'],
    "anapatrapā": ['mw'],
    "anapatrāpya": ['bhs'],
    "anapatya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anapatyaka": ['mw'],
    "anapatyatā": ['mw'],
    "anapatyavat": ['mw'],
    "anapaviddha": ['cped'],
    "anapaviddhakarṇa": ['bhs'],
    "anapavyayat": ['ap90', 'gra', 'mw'],
    "anapavācana": ['ap90', 'mw'],
    "anapavṛjya": ['gra', 'mw'],
    "anapayati": ['ap90', 'mw'],
    "anapaśabdam": ['ddsa'],
    "anapekha": ['cped'],
    "anapekhava": ['cped'],
    "anapekhavat": ['cped'],
    "anapekkha": ['cped'],
    "anapekkhava": ['cped'],
    "anapekkhavat": ['cped'],
    "anapekkhi": ['cped'],
    "anapekkhin": ['cped'],
    "anapekṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "anapekṣam": ['ddsa', 'mw'],
    "anapekṣamāṇa": ['ddsa', 'mw'],
    "anapekṣatva": ['mw'],
    "anapekṣatvāt": ['mw'],
    "anapekṣin": ['ddsa', 'mw'],
    "anapekṣita": ['cae', 'ddsa', 'mw'],
    "anapekṣya": ['mw'],
    "anapekṣā": ['cae', 'ddsa', 'mw'],
    "anapeta": ['ap90', 'cped', 'ddsa', 'mw'],
    "anaphā": ['ap90', 'mw'],
    "anapinaddha": ['gra', 'mw'],
    "anapnas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anapoddhārya": ['mw'],
    "anapoḍha": ['ddsa'],
    "anappaka": ['cped'],
    "anappameyya": ['cped'],
    "anapsaras": ['ap90', 'cae', 'ddsa', 'mw'],
    "anapta": ['ap90', 'gra', 'mw'],
    "anapuṃsaka": ['mw'],
    "anapākaraṇa": ['mw'],
    "anapākarman": ['ddsa', 'mw'],
    "anapākṛtya": ['cae'],
    "anapākṛṣṭa": ['ddsa'],
    "anapāvṛt": ['ap90', 'gra', 'mw'],
    "anapāya": ['ap90', 'cped', 'mw'],
    "anapāyadṛṣṭa": ['mw'],
    "anapāyi": ['cped'],
    "anapāyin": ['ap90', 'cped', 'ddsa', 'mw'],
    "anapāśraya": ['mw'],
    "anapūpya": ['mw'],
    "anapūpīya": ['mw'],
    "anaraha": ['cped'],
    "anarahat": ['cped'],
    "anaraṇya": ['ddsa', 'mw'],
    "anaraṇyaḥ": ['ap90'],
    "anarcita": ['cae', 'ddsa'],
    "anardhuka": ['ddsa', 'mw'],
    "anargala": ['ap90', 'cae', 'ddsa', 'mw'],
    "anargha": ['ap90', 'cae', 'ddsa', 'mw'],
    "anargharāghava": ['cae', 'mw'],
    "anarghatvaṃ": ['ap90'],
    "anarghya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anarghyatva": ['mw'],
    "anarghyeya": ['bhs'],
    "anarha": ['ap90', 'cae', 'ddsa', 'mw'],
    "anarhant": ['cae'],
    "anarhat": ['mw'],
    "anarhyatā": ['mw'],
    "anariya": ['cped'],
    "anariyavohāra": ['cped'],
    "anarjuna": ['mw'],
    "anarman": ['mw'],
    "anarpaṇa": ['mw'],
    "anartha": ['ap90', 'cae', 'ddsa', 'mw'],
    "anarthabhāva": ['mw'],
    "anarthabhīru": ['mw'],
    "anarthabuddhi": ['mw'],
    "anarthadarśin": ['mw'],
    "anarthaka": ['mw'],
    "anarthakara": ['mw'],
    "anarthakāma": ['mw'],
    "anarthakārin": ['cae'],
    "anarthalupta": ['mw'],
    "anarthanāśin": ['mw'],
    "anarthapaṇḍita": ['cae'],
    "anarthasaṃśaya": ['mw'],
    "anarthatva": ['mw'],
    "anarthika": ['bhs'],
    "anarthikatā": ['bhs'],
    "anarthitva": ['ddsa'],
    "anarthya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anarthāntara": ['cae'],
    "anarthāvekṣa": ['mw'],
    "anarus": ['ap90', 'mw'],
    "anarva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anarvan": ['ap90', 'cae', 'gra', 'mw'],
    "anarvaṇa": ['cae', 'gra', 'mw'],
    "anarviś": ['ap90', 'gra', 'mw'],
    "anarāla": ['cae'],
    "anarśa": ['gra'],
    "anarśani": ['gra', 'mw'],
    "anarśarāti": ['ap90', 'gra', 'mw'],
    "anas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anasamuttara": ['bhs'],
    "anasana": ['cped'],
    "anasita": ['cped'],
    "anassava": ['cped'],
    "anassāsaka": ['cped'],
    "anassāsika": ['cped'],
    "anassāvi": ['cped'],
    "anassāvin": ['cped'],
    "anastamita": ['ddsa', 'mw'],
    "anastha": ['ap90', 'cae', 'gra', 'mw'],
    "anasthaka": ['cae', 'mw'],
    "anasthan": ['cae', 'ddsa', 'gra', 'mw'],
    "anasthi": ['cae', 'mw'],
    "anasthika": ['cae', 'ddsa', 'mw'],
    "anasthimat": ['mw'],
    "anasvat": ['gra', 'mw'],
    "anasvin": ['mw'],
    "anasūri": ['mw'],
    "anasūya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anasūyaka": ['cae', 'mw'],
    "anasūyu": ['ap90', 'mw'],
    "anasūyā": ['cae', 'mw'],
    "anata": ['mw'],
    "anati": ['ap90', 'mw'],
    "anatibhaṅgura": ['ddsa'],
    "anatibhoga": ['ddsa'],
    "anaticariyā": ['cped'],
    "anaticāri": ['cped'],
    "anaticārin": ['cped'],
    "anatidagdha": ['cae', 'ddsa', 'mw'],
    "anatidarśana": ['ddsa'],
    "anatidbhuta": ['ddsa', 'gra', 'mw'],
    "anatidāha": ['mw'],
    "anatidūre": ['ddsa'],
    "anatidṛśna": ['mw'],
    "anatidṛśya": ['mw'],
    "anatikkamana": ['cped'],
    "anatikkamanīya": ['cped'],
    "anatikkamitvā": ['cped'],
    "anatikrama": ['cae', 'ddsa', 'mw'],
    "anatikramaṇīya": ['cae', 'ddsa', 'mw'],
    "anatikruddha": ['cae', 'ddsa'],
    "anatikrāmat": ['ddsa'],
    "anatikṛcchreṇa": ['cae', 'ddsa'],
    "anatilambin": ['cae', 'ddsa'],
    "anatilolam": ['ddsa'],
    "anatilulita": ['cae', 'ddsa'],
    "anatimaññamāna": ['cped'],
    "anatimāna": ['cped'],
    "anatimāni": ['cped'],
    "anatimānin": ['cped', 'mw'],
    "anatineda": ['mw'],
    "anatipakva": ['ddsa'],
    "anatiprakāśaka": ['cae', 'ddsa'],
    "anatiprauḍha": ['cae', 'ddsa'],
    "anatipraśnya": ['mw'],
    "anatipātya": ['cae', 'ddsa'],
    "anatipīḍam": ['ddsa'],
    "anatireca": ['mw'],
    "anatirikta": ['ddsa', 'mw'],
    "anatiritta": ['cped'],
    "anatisadṛśa": ['bhs'],
    "anatisāra": ['cped'],
    "anatisṛṣṭa": ['mw'],
    "anatithi": ['ddsa'],
    "anatitrasnu": ['ddsa'],
    "anativalita": ['ddsa'],
    "anativara": ['bhs'],
    "anativyādhya": ['mw'],
    "anativṛtti": ['mw'],
    "anatiśayanīya": ['ddsa'],
    "anatta": ['cped'],
    "anattadhīna": ['cped'],
    "anattamana": ['cped'],
    "anattan": ['cped'],
    "anattaneyya": ['cped'],
    "anattanupassi": ['cped'],
    "anattanupassin": ['cped'],
    "anattha": ['cped'],
    "anatthadassi": ['cped'],
    "anatthadassin": ['cped'],
    "anatthajanana": ['cped'],
    "anatthaka": ['cped'],
    "anatthakāma": ['cped'],
    "anatthasaṁhita": ['cped'],
    "anatthata": ['cped'],
    "anatthavādi": ['cped'],
    "anatthavādin": ['cped'],
    "anatthika": ['cped'],
    "anattukkaṁsana": ['cped'],
    "anatyantagati": ['mw'],
    "anatyaya": ['mw'],
    "anatyudya": ['mw'],
    "anatyārdra": ['ddsa'],
    "anatyāśa": ['ddsa'],
    "anatīta": ['bhs', 'cae', 'cped', 'ddsa'],
    "anaucitya": ['ddsa', 'mw'],
    "anaucityaṃ": ['ap90'],
    "anaucitī": ['mw'],
    "anauddhatya": ['mw'],
    "anauddhatyaṃ": ['ap90'],
    "anaujasya": ['mw'],
    "anaujasyaṃ": ['ap90'],
    "anaupama": ['mw'],
    "anaupamya": ['bhs', 'mw'],
    "anaupaśamika": ['bhs'],
    "anaupādhika": ['mw'],
    "anaurasa": ['ap90', 'mw'],
    "anauśīra": ['cae'],
    "anauṣadha": ['mw'],
    "anavabhra": ['ap90', 'gra'],
    "anavabhrarādhas": ['cae', 'gra', 'mw'],
    "anavabhāsa": ['cae', 'ddsa'],
    "anavabrava": ['ap90', 'gra', 'mw'],
    "anavabuddha": ['ddsa'],
    "anavabudhyamāna": ['mw'],
    "anavaccheda": ['cae'],
    "anavacchinna": ['ap90', 'cae', 'ddsa', 'mw'],
    "anavacchinnahāsa": ['mw'],
    "anavacchitti": ['mw'],
    "anavadharṣya": ['mw'],
    "anavadhi": ['ap90', 'mw'],
    "anavadhāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "anavadhānatā": ['mw'],
    "anavadhīṣṭha": ['bhs'],
    "anavadhṛṣya": ['mw'],
    "anavadrāṇa": ['ap90', 'mw'],
    "anavadya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "anavadyabhīru": ['bhs'],
    "anavadyarūpa": ['gra', 'mw'],
    "anavadyatva": ['mw'],
    "anavadyatā": ['mw'],
    "anavadyā": ['mw'],
    "anavadyāṅga": ['cae', 'ddsa', 'mw'],
    "anavadānīya": ['mw'],
    "anavagata": ['cae', 'ddsa', 'mw'],
    "anavaglāyat": ['mw'],
    "anavagraha": ['ap90', 'cae', 'mw'],
    "anavagāhin": ['mw'],
    "anavagāhya": ['mw'],
    "anavagīta": ['mw'],
    "anavagṛhīta": ['cae'],
    "anavahita": ['ddsa', 'mw'],
    "anavahiṃsita": ['ddsa'],
    "anavahvara": ['ap90', 'gra', 'mw'],
    "anavajja": ['cped'],
    "anavakarṇita": ['ddsa'],
    "anavakkanta": ['cped'],
    "anavaklṛpta": ['ddsa'],
    "anavaklṛpti": ['ddsa'],
    "anavakrāmam": ['mw'],
    "anavakāra": ['bhs'],
    "anavakāsa": ['cped'],
    "anavakāśa": ['ap90', 'bhs', 'mw'],
    "anavakāśin": ['ddsa'],
    "anavakīrṇa": ['bhs'],
    "anavakḷpta": ['cae'],
    "anavalamba": ['mw'],
    "anavalambana": ['cae', 'ddsa', 'mw'],
    "anavalambita": ['mw'],
    "anavalaṃba": ['ap90'],
    "anavalepa": ['cae', 'ddsa', 'mw'],
    "anavalobhana": ['mw'],
    "anavalobhanaṃ": ['ap90'],
    "anavalokayant": ['cae'],
    "anavalokayat": ['ddsa'],
    "anavalokita": ['cae'],
    "anavalopa": ['mw'],
    "anavalīna": ['bhs'],
    "anavalīnatā": ['bhs'],
    "anavalīyanatā": ['bhs'],
    "anavama": ['ap90', 'cae', 'ddsa', 'mw'],
    "anavamadarśin": ['mw'],
    "anavamardabalaketu": ['bhs'],
    "anavamardanīya": ['bhs'],
    "anavamardya": ['bhs'],
    "anavamarśam": ['mw'],
    "anavamata": ['cped'],
    "anavamānanā": ['cped'],
    "anavamūḍhyatā": ['bhs'],
    "anavamṛdya": ['bhs'],
    "anavamṛdyatā": ['bhs'],
    "anavamṛśya": ['mw'],
    "anavana": ['ap90', 'ddsa', 'mw'],
    "anavanamana": ['bhs'],
    "anavanāmita": ['ap90'],
    "anavanāmitavaijayanta": ['mw'],
    "anavanāmitavaijayantī": ['bhs'],
    "anavapṛgṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anavara": ['cae', 'ddsa', 'mw'],
    "anavarata": ['ap90', 'cae', 'ddsa', 'mw'],
    "anavaratam": ['mw'],
    "anavaratha": ['mw'],
    "anavarodhya": ['ddsa', 'mw'],
    "anavarti": ['mw'],
    "anavaruddha": ['mw'],
    "anavarāgra": ['bhs', 'mw'],
    "anavarāgratā": ['bhs'],
    "anavarārdhya": ['ap90', 'mw'],
    "anavarṇa": ['mw'],
    "anavasa": ['ap90', 'cae', 'gra', 'mw'],
    "anavasara": ['ap90', 'cae', 'ddsa', 'mw'],
    "anavasesa": ['cped'],
    "anavasesadohi": ['cped'],
    "anavasesadohin": ['cped'],
    "anavasesaṁ": ['cped'],
    "anavasita": ['ap90', 'cae', 'mw'],
    "anavasitā": ['ddsa', 'mw'],
    "anavaskara": ['ap90', 'mw'],
    "anavasnātā": ['mw'],
    "anavassava": ['cped'],
    "anavassuta": ['cped'],
    "anavastha": ['ap90', 'cae', 'mw'],
    "anavasthita": ['ap90', 'cae', 'ddsa', 'mw'],
    "anavasthitacitta": ['mw'],
    "anavasthitacittatva": ['mw'],
    "anavasthitatva": ['mw'],
    "anavasthiti": ['ddsa', 'mw'],
    "anavasthā": ['cae', 'ddsa', 'mw'],
    "anavasthāna": ['ap90', 'cae', 'mw'],
    "anavasthāyin": ['cae', 'mw'],
    "anavasyat": ['gra', 'mw'],
    "anavasādya": ['mw'],
    "anavasāna": ['ap90', 'mw'],
    "anavatapta": ['bhs', 'mw'],
    "anavataptanāgarājaparipṛcchā": ['bhs'],
    "anavattha": ['cped'],
    "anavatthacārikā": ['cped'],
    "anavattva": ['mw'],
    "anavatāra": ['bhs'],
    "anavaya": ['cped'],
    "anavaññattikāma": ['cped'],
    "anavaññāta": ['cped'],
    "anavaśruta": ['bhs'],
    "anavaṭṭhita": ['cped'],
    "anavekṣa": ['ap90', 'mw'],
    "anavekṣaka": ['ap90', 'ddsa'],
    "anavekṣam": ['mw'],
    "anavekṣaṇa": ['cae', 'mw'],
    "anavekṣaṇaṃ": ['ap90'],
    "anavekṣitam": ['mw'],
    "anavekṣya": ['cae'],
    "anavekṣā": ['ddsa', 'mw'],
    "anaveta": ['mw'],
    "anaveṣṭa": ['mw'],
    "anavithya": ['mw'],
    "anavosita": ['cped'],
    "anavositatta": ['cped'],
    "anavrata": ['ap90', 'mw'],
    "anavāc": ['mw'],
    "anavānam": ['mw'],
    "anavānat": ['mw'],
    "anavānatā": ['mw'],
    "anavānaṃ": ['ap90'],
    "anavāpta": ['cae', 'ddsa', 'mw'],
    "anavāpti": ['cae', 'ddsa', 'mw'],
    "anavāpya": ['cae', 'ddsa'],
    "anavāya": ['ap90', 'gra', 'mw'],
    "anavāñc": ['mw'],
    "anavāṃc": ['ap90'],
    "anavīkaroti": ['bhs'],
    "anavīkṛta": ['mw'],
    "anavṛtta": ['mw'],
    "anaya": ['cae', 'cped', 'ddsa', 'mw'],
    "anayaka": ['bhs'],
    "anayavyasana": ['bhs'],
    "anayaḥ": ['ap90'],
    "anayaṃgata": ['mw'],
    "anañjana": ['mw'],
    "anañña": ['cped'],
    "anaññaneyya": ['cped'],
    "anaññatha": ['cped'],
    "anaññathā": ['cped'],
    "anaññathābhāvi": ['cped'],
    "anaññathābhāvin": ['cped'],
    "anaśana": ['cae', 'ddsa', 'mw'],
    "anaśanatā": ['mw'],
    "anaśanaṃ": ['ap90'],
    "anaśanāya": ['ap90', 'mw'],
    "anaśita": ['cae', 'ddsa', 'mw'],
    "anaśnant": ['cae'],
    "anaśnantsāṅgamana": ['mw'],
    "anaśnat": ['ap90', 'ddsa', 'gra', 'mw'],
    "anaśnuvāna": ['ddsa'],
    "anaśnāna": ['mw'],
    "anaśru": ['cae', 'ddsa', 'gra', 'mw'],
    "anaśva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anaśvadā": ['cae', 'gra', 'mw'],
    "anaśvan": ['mw'],
    "anaśvara": ['ap90', 'ddsa', 'mw'],
    "anaḍud": ['mw'],
    "anaḍudarha": ['mw'],
    "anaḍudda": ['cae', 'ddsa', 'mw'],
    "anaḍudyajña": ['mw'],
    "anaḍuh": ['ap90', 'mw'],
    "anaḍuha": ['cae', 'ddsa', 'mw'],
    "anaḍuhaḥ": ['ap90'],
    "anaḍuhī": ['mw'],
    "anaḍujjihvā": ['mw'],
    "anaḍutka": ['ap90', 'mw'],
    "anaḍvah": ['cae', 'ddsa', 'gra'],
    "anaḍvāhī": ['mw'],
    "anaḥ": ['ap90'],
    "anaṃbara": ['ap90'],
    "anaṃda": ['ap90'],
    "anaṃga": ['ap90'],
    "anaṃgakaṃ": ['ap90'],
    "anaṃguri": ['ap90'],
    "anaṃjana": ['ap90'],
    "anaṃkuśa": ['ap90'],
    "anaṃta": ['ap90'],
    "anaṃtaka": ['ap90'],
    "anaṃtara": ['ap90'],
    "anaṃtarayaḥ": ['ap90'],
    "anaṃtargarbhin": ['ap90'],
    "anaṃtarāya": ['ap90'],
    "anaṃtarīya": ['ap90'],
    "anaṃtavat": ['ap90'],
    "anaṃtya": ['ap90'],
    "anaṃśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "anaṃśin": ['mw'],
    "anaṃśumatphalā": ['ap90', 'mw'],
    "anaṅga": ['bhs', 'cae', 'ddsa', 'mw'],
    "anaṅgabhīma": ['mw'],
    "anaṅgadevī": ['mw'],
    "anaṅgaharṣa": ['mw'],
    "anaṅgaka": ['mw'],
    "anaṅgakrīḍā": ['cae', 'mw'],
    "anaṅgalatikā": ['mw'],
    "anaṅgalekhā": ['mw'],
    "anaṅgamaṅgala": ['mw'],
    "anaṅgamejaya": ['mw'],
    "anaṅgapāla": ['mw'],
    "anaṅgarati": ['cae'],
    "anaṅgaraṅga": ['mw'],
    "anaṅgasenā": ['mw'],
    "anaṅgatva": ['cae'],
    "anaṅgavidyā": ['mw'],
    "anaṅgaśekhara": ['mw'],
    "anaṅgaṇa": ['bhs', 'cped'],
    "anaṅguri": ['mw'],
    "anaṅguṣṭha": ['mw'],
    "anaṅgāpīḍa": ['mw'],
    "anaṅgāsuhṛd": ['mw'],
    "anaṅgīkṛta": ['ddsa'],
    "anaṅkurita": ['ddsa'],
    "anaṅkuśa": ['mw'],
    "anaṇa": ['cped'],
    "anaṇu": ['ap90', 'cae', 'ddsa', 'mw'],
    "anaṇīyas": ['mw'],
    "anaṣṭa": ['gra', 'mw'],
    "anaṣṭapaśu": ['ddsa', 'gra', 'mw'],
    "anaṣṭavedas": ['gra', 'mw'],
    "and": ['mw'],
    "andh": ['mw'],
    "andha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "andhabhūta": ['cped'],
    "andhabāla": ['cped'],
    "andhacaṭakanyāya": ['mw'],
    "andhadhī": ['mw'],
    "andhaka": ['cae', 'cped', 'ddsa', 'mw'],
    "andhakaghātin": ['mw'],
    "andhakaraṇa": ['cped'],
    "andhakaripu": ['mw'],
    "andhakavarta": ['mw'],
    "andhakavṛṣṇi": ['mw'],
    "andhakāla": ['bhs', 'mw'],
    "andhakāntaka": ['mw'],
    "andhakāra": ['cae', 'cped', 'ddsa', 'mw'],
    "andhakāraka": ['cped'],
    "andhakāramaya": ['mw'],
    "andhakārasaṃcaya": ['mw'],
    "andhakāratamisrita": ['bhs'],
    "andhakāratamisrā": ['bhs'],
    "andhakāratimisā": ['cped'],
    "andhakāri": ['mw'],
    "andhakārin": ['mw'],
    "andhakārita": ['ddsa', 'mw'],
    "andhakārāpitatva": ['bhs'],
    "andhakāsuhṛd": ['mw'],
    "andhakī": ['mw'],
    "andhakūpa": ['cae', 'ddsa', 'mw'],
    "andhala": ['bhs'],
    "andhambhaviṣṇu": ['mw'],
    "andhambhāvuka": ['mw'],
    "andhamehala": ['mw'],
    "andhamūṣikā": ['mw'],
    "andhamūṣā": ['mw'],
    "andhandhaṁ": ['cped'],
    "andhaparamparānyāya": ['mw'],
    "andhapūtanā": ['mw'],
    "andharātrī": ['mw'],
    "andhas": ['cae', 'ddsa', 'gra', 'mw'],
    "andhatamasa": ['mw'],
    "andhatva": ['mw'],
    "andhatā": ['cae', 'mw'],
    "andhatāmasa": ['mw'],
    "andhatāmisra": ['cae', 'mw'],
    "andhavat": ['ddsa'],
    "andhaveṇi": ['cped'],
    "andhavyūha": ['mw'],
    "andhaya": ['ddsa'],
    "andhaṃkaraṇa": ['mw'],
    "andhikata": ['cped'],
    "andhikā": ['mw'],
    "andhra": ['cae', 'ddsa', 'mw'],
    "andhrabhṛtya": ['mw'],
    "andhrajāti": ['mw'],
    "andhrajātīya": ['mw'],
    "andhu": ['cae', 'ddsa', 'mw'],
    "andhula": ['mw'],
    "andhāhi": ['mw'],
    "andhālajī": ['mw'],
    "andhāra": ['bhs'],
    "andhārasundarī": ['bhs'],
    "andhāravāsinī": ['bhs'],
    "andhībhū": ['mw'],
    "andhībhūta": ['mw'],
    "andhīgu": ['mw'],
    "andhīkaraṇa": ['mw'],
    "andhīkata": ['cped'],
    "andhīkṛ": ['cae', 'ddsa', 'mw'],
    "andhīkṛta": ['mw'],
    "andhīkṛtātman": ['mw'],
    "andikā": ['mw'],
    "andm, andū": ['ddsa'],
    "andolana": ['cae', 'ddsa', 'mw'],
    "andolay": ['cae'],
    "andolaya": ['ddsa', 'mw'],
    "andolita": ['mw'],
    "andolāy": ['cae'],
    "andraka": ['mw'],
    "andu": ['cae', 'cped', 'mw'],
    "andubhandana": ['cped'],
    "anduka": ['mw'],
    "andū": ['cped', 'mw'],
    "andūka": ['mw'],
    "anedhas": ['mw'],
    "anedia": ['gra'],
    "anedya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anehas": ['ap90', 'cae', 'gra', 'mw'],
    "aneja": ['cped'],
    "anejat": ['ap90', 'mw'],
    "aneka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "anekabhāga": ['cped'],
    "anekabhārya": ['mw'],
    "anekacara": ['mw'],
    "anekacittamantra": ['mw'],
    "anekadharmakathā": ['mw'],
    "anekadhā": ['ap90', 'mw'],
    "anekadhāprayoga": ['mw'],
    "anekadhṛt": ['mw'],
    "anekagotra": ['mw'],
    "anekaja": ['mw'],
    "anekakālam": ['mw'],
    "anekakālāvadhi": ['mw'],
    "anekakāma": ['mw'],
    "anekakṛt": ['mw'],
    "anekalocana": ['mw'],
    "anekamukha": ['mw'],
    "anekapa": ['mw'],
    "anekapariyāyena": ['cped'],
    "anekarandhra": ['mw'],
    "anekarūpa": ['cae', 'cped', 'mw'],
    "anekasahassa": ['cped'],
    "anekasata": ['cped'],
    "anekasaṃkhya": ['mw'],
    "anekasaṃsthāna": ['cae', 'mw'],
    "anekasārīrika": ['cped'],
    "anekatra": ['mw'],
    "anekatva": ['mw'],
    "anekatā": ['mw'],
    "anekavacana": ['mw'],
    "anekavarṇa": ['cae', 'mw'],
    "anekavassagaṇika": ['cped'],
    "anekavidha": ['cae', 'cped', 'mw'],
    "anekavihita": ['cped'],
    "anekavāram": ['mw'],
    "anekavārṣika": ['mw'],
    "anekayuddhavijayin": ['mw'],
    "anekaśabda": ['mw'],
    "anekaśapha": ['mw'],
    "anekaśas": ['cae', 'mw'],
    "anekaśaḥ": ['ap90'],
    "anekaṁsika": ['cped'],
    "anekaṁsikata": ['cped'],
    "anekopavāsa": ['ddsa'],
    "anekāc": ['mw'],
    "anekāgra": ['mw'],
    "anekākin": ['ap90', 'mw'],
    "anekākāra": ['mw'],
    "anekākṣara": ['mw'],
    "anekāl": ['mw'],
    "anekānta": ['ddsa', 'mw'],
    "anekāntatva": ['mw'],
    "anekāntavāda": ['mw'],
    "anekāntavādin": ['mw'],
    "anekārtha": ['mw'],
    "anekārthadhvanimañjarī": ['mw'],
    "anekārthasaṃgraha": ['mw'],
    "anekātmavādin": ['mw'],
    "anekāśraya": ['mw'],
    "anekāśrita": ['mw'],
    "anekībhavat": ['mw'],
    "anekīkaraṇa": ['mw'],
    "anekīkṛ": ['ap90'],
    "anekīya": ['mw'],
    "anela": ['bhs'],
    "anelagala": ['cped'],
    "anelaka": ['cped'],
    "anelamūga": ['cped'],
    "anelamūka": ['mw'],
    "aneman": ['ap90', 'mw'],
    "anena": ['ap90', 'cae', 'gra', 'mw'],
    "anenas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anenasya": ['mw'],
    "anenaḥ": ['ap90'],
    "anesana": ['cped'],
    "anesanā": ['cped'],
    "aneva": ['mw'],
    "anevam": ['mw'],
    "anevaṃvid": ['cae', 'mw'],
    "anevaṃvidvas": ['mw'],
    "aneya": ['bhs'],
    "aneñja": ['bhs', 'cped'],
    "aneñjya": ['bhs'],
    "aneḍa": ['bhs', 'mw'],
    "aneḍaka": ['bhs'],
    "aneḍamūka": ['mw'],
    "aneḍaḥ": ['ap90'],
    "aneḷagala": ['cped'],
    "aneḷagaḷa": ['cped'],
    "aneḷaka": ['cped'],
    "aneḷamūga": ['cped'],
    "aneṣa": ['bhs'],
    "ani": ['mw'],
    "ania": ['gra'],
    "anibaddha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anibaddhapralāpin": ['mw'],
    "anibaddhavacana": ['bhs'],
    "anibandhana": ['mw'],
    "anibbisa": ['cped'],
    "anibbisat": ['cped'],
    "anibbisaṁ": ['cped'],
    "anibhya": ['ap90', 'mw'],
    "anibhṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "anibhṛṣṭa": ['ap90', 'gra', 'mw'],
    "anibhṛṣṭataviṣi": ['gra', 'mw'],
    "anibādha": ['ap90', 'gra', 'mw'],
    "anicaya": ['ddsa', 'mw'],
    "aniccha": ['ap90', 'cped', 'mw'],
    "anicchaka": ['mw'],
    "anicchant": ['cae'],
    "anicchanta": ['cped'],
    "anicchantikatā": ['bhs'],
    "anicchat": ['ddsa', 'mw'],
    "anicchu": ['mw'],
    "anicchā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "anicchāpūraka": ['cae'],
    "anidhma": ['gra', 'mw'],
    "anidhārya": ['bhs'],
    "anidhāya": ['cae'],
    "anidhṛṣṭa": ['ap90', 'mw'],
    "anidit": ['ddsa'],
    "anidra": ['ap90', 'cae', 'ddsa', 'mw'],
    "anidrita": ['mw'],
    "anidrā": ['ddsa', 'mw'],
    "anidāghadīdhiti": ['ddsa', 'mw'],
    "anidāna": ['ddsa', 'mw'],
    "anigaḍa": ['cae', 'ddsa'],
    "anigha": ['bhs'],
    "anighāteṣu": ['mw'],
    "anigraha": ['ap90', 'ddsa', 'mw'],
    "anigrahasthāna": ['mw'],
    "anigupta": ['mw'],
    "anigīrṇa": ['ap90', 'mw'],
    "aniha": ['ddsa', 'mw'],
    "anihata": ['bhs', 'ddsa'],
    "anihatamalla": ['bhs'],
    "anihatatejas": ['bhs'],
    "anihatavarṇa": ['bhs'],
    "anihita": ['mw'],
    "anihitamati": ['bhs'],
    "anihīnārtha": ['bhs'],
    "anihūta": ['mw'],
    "anijaka": ['mw'],
    "aniketa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "aniketacārin": ['bhs'],
    "aniketana": ['mw'],
    "aniketasthita": ['bhs'],
    "anikkasāva": ['cped'],
    "anikāmatas": ['mw'],
    "anikāṣam": ['mw'],
    "anikīḷitāvi": ['cped'],
    "anikīḷitāvin": ['cped'],
    "anikṛti": ['mw'],
    "anikṣeptṛ": ['cae'],
    "anikṣipta": ['cae', 'ddsa'],
    "anikṣiptabhāra": ['bhs'],
    "anikṣiptadhura": ['bhs'],
    "anikṣiptadhūra": ['mw'],
    "anikṣipya": ['cae', 'mw'],
    "anikṣu": ['mw'],
    "anikṣuḥ": ['ap90'],
    "anila": ['cae', 'cped', 'ddsa', 'mw'],
    "anilaghna": ['mw'],
    "anilaghnaka": ['mw'],
    "anilahan": ['mw'],
    "anilahṛt": ['mw'],
    "anilakumāra": ['mw'],
    "anilambha": ['bhs', 'mw'],
    "anilambhacakṣurvairocana": ['bhs'],
    "anilambhacakṣus": ['bhs'],
    "anilambhamati": ['bhs'],
    "anilambhaniketanirata": ['bhs'],
    "anilambhasamādhi": ['mw'],
    "anilambhasunirmita": ['bhs'],
    "anilanama": ['bhs'],
    "anilapaka": ['bhs'],
    "anilaparyaya": ['mw'],
    "anilaparyāya": ['mw'],
    "anilaprakṛti": ['mw'],
    "anilasakha": ['mw'],
    "anilasārathi": ['mw'],
    "anilavegaśrī": ['bhs'],
    "anilavyādhi": ['mw'],
    "anilaya": ['ddsa', 'mw'],
    "anilayajñāna": ['bhs'],
    "anilayana": ['mw'],
    "anilaśrī": ['bhs'],
    "anilaḥ": ['ap90'],
    "aniloḍita": ['ap90'],
    "anilāhata": ['mw'],
    "anilāhati": ['cae', 'ddsa'],
    "anilāmaya": ['mw'],
    "anilānala": ['cae'],
    "anilāntaka": ['mw'],
    "anilāpaha": ['mw'],
    "anilātmaja": ['ddsa', 'mw'],
    "anilāyana": ['mw'],
    "anilāśana": ['mw'],
    "anilāśin": ['mw'],
    "animakaḥ": ['ap90'],
    "animan": ['mw'],
    "animantrita": ['mw'],
    "animantritabhojin": ['mw'],
    "animeṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "animeṣam": ['mw'],
    "animitta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "animittalipi": ['mw'],
    "animittaliṅganāśa": ['mw'],
    "animittanirākṛta": ['mw'],
    "animittatas": ['mw'],
    "animiṣ": ['ddsa', 'gra', 'mw'],
    "animiṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "animiṣam": ['cae', 'mw'],
    "animiṣanta": ['cae'],
    "animiṣat": ['ddsa', 'gra', 'mw'],
    "animiṣatā": ['bhs'],
    "animiṣaṃ": ['ap90'],
    "animiṣekṣaṇa": ['cae'],
    "animiṣita": ['mw'],
    "animiṣā": ['bhs', 'cae', 'mw'],
    "animiṣācārya": ['mw'],
    "animiṣākṣa": ['mw'],
    "animiṣīya": ['ap90'],
    "animāna": ['ap90', 'gra', 'mw'],
    "anina": ['ap90', 'gra', 'mw'],
    "anindanīya": ['mw'],
    "anindat": ['ddsa'],
    "anindia": ['gra'],
    "anindita": ['cae', 'ddsa', 'mw'],
    "aninditagāminī": ['cae'],
    "aninditā": ['bhs'],
    "anindra": ['gra', 'mw'],
    "anindriya": ['mw'],
    "anindya": ['cae', 'gra', 'mw'],
    "anindā": ['ddsa', 'mw'],
    "anipadyamāna": ['ap90', 'gra', 'mw'],
    "anipuṇa": ['ddsa', 'mw'],
    "anipāna": ['mw'],
    "anipāta": ['cae', 'mw'],
    "anipātaḥ": ['ap90'],
    "anira": ['ap90', 'cae', 'gra', 'mw'],
    "aniraśita": ['mw'],
    "anirbandharuṣ": ['ddsa'],
    "anirbhara": ['mw'],
    "anirbheda": ['ddsa', 'mw'],
    "anirbhinna": ['ddsa'],
    "anirdaya": ['cae', 'ddsa', 'mw'],
    "anirdaśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "anirdaśam": ['mw'],
    "anirdaśāha": ['cae', 'mw'],
    "anirdeśa": ['ddsa', 'mw'],
    "anirdeśaḥ": ['ap90'],
    "anirdeśya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anirdhārita": ['ap90', 'mw'],
    "anirdhārya": ['mw'],
    "anirdiśya": ['mw'],
    "anirdiṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "anirdāhuka": ['mw'],
    "anirghāta": ['mw'],
    "anirghātya": ['mw'],
    "anirhata": ['mw'],
    "anirhrādin": ['cae', 'ddsa'],
    "anirhāṇarca": ['ddsa'],
    "anirjita": ['cae', 'ddsa', 'mw'],
    "anirlocita": ['mw'],
    "anirloḍita": ['ap90', 'ddsa', 'mw'],
    "anirmala": ['ap90', 'mw'],
    "anirmuktaka": ['bhs'],
    "anirmuktā": ['bhs'],
    "anirmālyā": ['mw'],
    "anirmārga": ['mw'],
    "aniruddha": ['ap90', 'bhs', 'mw'],
    "aniruddhabhāvinī": ['mw'],
    "aniruddhapatha": ['mw'],
    "anirukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "aniruktagāna": ['mw'],
    "anirupta": ['mw'],
    "anirvacanīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anirvartin": ['mw'],
    "anirvartyamāna": ['mw'],
    "anirvarṇanīya": ['cae', 'ddsa'],
    "anirveda": ['cae', 'ddsa', 'mw'],
    "anirvedaḥ": ['ap90'],
    "anirvedita": ['cae', 'ddsa', 'mw'],
    "anirveśa": ['ap90', 'ddsa', 'mw'],
    "anirvid": ['mw'],
    "anirvida": ['ap90'],
    "anirviṇṇa": ['ap90', 'mw'],
    "anirviṇṇacetas": ['cae'],
    "anirvyūha": ['bhs'],
    "anirvācya": ['ddsa', 'mw'],
    "anirvāha": ['bhs', 'mw'],
    "anirvāhanaśīla": ['cae'],
    "anirvāhaḥ": ['ap90'],
    "anirvāhaṇaśīla": ['mw'],
    "anirvāhya": ['cae', 'mw'],
    "anirvāpa": ['mw'],
    "anirvāṇa": ['ap90', 'cae', 'mw'],
    "anirvṛta": ['ap90', 'ddsa', 'mw'],
    "anirvṛti": ['cae', 'mw'],
    "anirvṛtiḥ": ['ap90'],
    "anirvṛtta": ['cae', 'ddsa', 'mw'],
    "anirvṛttamūlā": ['bhs'],
    "anirvṛtti": ['mw'],
    "aniryātayant": ['cae'],
    "aniryāṇa": ['bhs'],
    "aniryūha": ['bhs'],
    "anirā": ['gra', 'mw'],
    "anirāhita": ['mw'],
    "anirākaraṇa": ['mw'],
    "anirākaraṇaṃ": ['ap90'],
    "anirākariṣṇu": ['mw'],
    "anirākṛta": ['mw'],
    "anirākṛtin": ['mw'],
    "anirāmagandha": ['cped'],
    "anirīkṣaka": ['ddsa'],
    "anirūpita": ['ddsa', 'mw'],
    "anirṇaya": ['mw'],
    "anirṇayaḥ": ['ap90'],
    "anirṇeya": ['mw'],
    "anirṇikta": ['cae', 'ddsa'],
    "anirṇīta": ['cae', 'ddsa', 'mw'],
    "anisarga": ['mw'],
    "anissara": ['cped'],
    "anissuka": ['cped'],
    "anissuki": ['cped'],
    "anissukin": ['cped'],
    "anissā": ['cped'],
    "anissāmanaka": ['cped'],
    "anistabdha": ['mw'],
    "anistiṣṭhat": ['mw'],
    "anistīrṇa": ['ap90', 'mw'],
    "anistīrṇābhiyoga": ['mw'],
    "anisṛṣṭa": ['cae', 'mw'],
    "anita": ['ap90', 'mw'],
    "anitabhā": ['cae', 'gra', 'mw'],
    "anitthaṃvid": ['mw'],
    "anitthi": ['cped'],
    "anitya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anityabhāva": ['mw'],
    "anityadatrima": ['mw'],
    "anityadatta": ['mw'],
    "anityadattaka": ['mw'],
    "anityakarman": ['mw'],
    "anityakriyā": ['mw'],
    "anityam": ['ddsa', 'mw'],
    "anityapratyavekṣā": ['mw'],
    "anityasama": ['mw'],
    "anityasamaprakaraṇa": ['mw'],
    "anityasamāsa": ['mw'],
    "anityatva": ['mw'],
    "anityatā": ['mw'],
    "anityātman": ['ddsa'],
    "anivarta": ['bhs'],
    "anivartaka": ['ddsa'],
    "anivartana": ['ap90', 'mw'],
    "anivartanacaryā": ['bhs'],
    "anivartika": ['bhs'],
    "anivartikabala": ['bhs'],
    "anivartin": ['ap90', 'bhs', 'cae', 'mw'],
    "anivartitva": ['cae', 'ddsa', 'mw'],
    "anivartiya": ['bhs'],
    "anivatti": ['cped'],
    "anivattin": ['cped'],
    "anivedita": ['mw'],
    "aniveditavijñāta": ['mw'],
    "anivedya": ['cae', 'ddsa', 'mw'],
    "aniveśana": ['ap90', 'gra', 'mw'],
    "aniveṣṭyamāna": ['mw'],
    "anividdhavarṇa": ['bhs'],
    "aniviśamāna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anivāraṇa": ['cae', 'ddsa'],
    "anivārita": ['mw'],
    "anivārya": ['mw'],
    "anivṛta": ['gra', 'mw'],
    "anivṛtta": ['mw'],
    "anivṛttamāṃsa": ['ddsa'],
    "anivṛttamūla": ['bhs'],
    "anivṛtti": ['ddsa'],
    "aniyama": ['cae', 'ddsa', 'mw'],
    "aniyamaḥ": ['ap90'],
    "aniyamita": ['mw'],
    "aniyamopamā": ['ddsa', 'mw'],
    "aniyantraṇa": ['cae', 'ddsa'],
    "aniyantraṇam": ['mw'],
    "aniyantraṇā": ['ddsa'],
    "aniyantraṇānuyoga": ['mw'],
    "aniyantṛkartṛka": ['cae'],
    "aniyasita": ['mw'],
    "aniyata": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "aniyatapuṃskā": ['mw'],
    "aniyatavelam": ['cae'],
    "aniyatavṛtti": ['mw'],
    "aniyatātman": ['ddsa', 'mw'],
    "aniyatāṅka": ['mw'],
    "aniyavanta": ['bhs'],
    "aniyaṃtraṇa": ['ap90'],
    "aniyoga": ['mw'],
    "aniyogin": ['mw'],
    "aniyojya": ['cae'],
    "aniyujyamāna": ['ddsa'],
    "aniyukta": ['cae', 'ddsa', 'mw'],
    "aniyuktaḥ": ['ap90'],
    "aniyūha": ['bhs'],
    "aniñja": ['bhs'],
    "aniñjana": ['bhs'],
    "aniñjita": ['bhs', 'cped'],
    "aniñjya": ['bhs'],
    "aniśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aniśam": ['cae', 'mw'],
    "aniścara": ['bhs', 'mw'],
    "aniścaya": ['cae', 'ddsa'],
    "aniśceya": ['ddsa', 'mw'],
    "aniścintya": ['ddsa', 'mw'],
    "aniścita": ['mw'],
    "aniścitya": ['mw'],
    "aniśita": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aniśitam": ['mw'],
    "aniśitasarga": ['gra', 'mw'],
    "aniśrita": ['bhs'],
    "aniśānta": ['ddsa', 'mw'],
    "aniḥsarat": ['ddsa'],
    "aniḥsaraṇa": ['bhs'],
    "aniḥsṛta": ['bhs'],
    "aniḥśasta": ['gra', 'mw'],
    "aniḥśeṣita": ['ddsa'],
    "aniḥṣṭubdha": ['mw'],
    "aniḷaka": ['cped'],
    "aniṃdra": ['ap90'],
    "aniṃdriyaṃ": ['ap90'],
    "aniṃgya": ['ap90'],
    "aniṅga": ['mw'],
    "aniṅgana": ['mw'],
    "aniṅgayat": ['mw'],
    "aniṅgyamāna": ['mw'],
    "aniṣavya": ['cae', 'ddsa', 'gra', 'mw'],
    "aniṣaṅga": ['gra', 'mw'],
    "aniṣeddhra": ['mw'],
    "aniṣiddha": ['ap90', 'cae', 'ddsa', 'mw'],
    "aniṣkaṣāya": ['ddsa'],
    "aniṣkāsin": ['mw'],
    "aniṣkāsita": ['mw'],
    "aniṣkṛta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aniṣkṛtainas": ['cae', 'mw'],
    "aniṣpanna": ['cae', 'ddsa', 'mw'],
    "aniṣpannatva": ['mw'],
    "aniṣpatraṃ": ['ap90'],
    "aniṣpatti": ['mw'],
    "aniṣpattiḥ": ['ap90'],
    "aniṣpattram": ['mw'],
    "aniṣu": ['mw'],
    "aniṣucārin": ['ddsa', 'mw'],
    "aniṣudhanva": ['mw'],
    "aniṣṇa": ['mw'],
    "aniṣṇāta": ['mw'],
    "aniṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aniṣṭacintana": ['cae'],
    "aniṣṭaduṣṭadhī": ['mw'],
    "aniṣṭagandha": ['cae', 'ddsa'],
    "aniṣṭagraha": ['mw'],
    "aniṣṭahetu": ['mw'],
    "aniṣṭaikabuddhi": ['cae'],
    "aniṣṭaka": ['mw'],
    "aniṣṭaphala": ['mw'],
    "aniṣṭaprasaṅga": ['mw'],
    "aniṣṭasūcaka": ['mw'],
    "aniṣṭayajña": ['mw'],
    "aniṣṭaśaṅkā": ['mw'],
    "aniṣṭhura": ['cae', 'ddsa', 'mw'],
    "aniṣṭhā": ['mw'],
    "aniṣṭhāpada": ['bhs'],
    "aniṣṭin": ['ap90', 'mw'],
    "aniṣṭotprekṣaṇa": ['mw'],
    "aniṣṭvā": ['cae'],
    "aniṣṭā": ['mw'],
    "aniṣṭāpti": ['mw'],
    "aniṣṭāpādana": ['mw'],
    "aniṣṭāśaṃsin": ['mw'],
    "aniṣṭṛta": ['ap90', 'gra', 'mw'],
    "aniṭ": ['ddsa'],
    "aniṭkārikā": ['mw'],
    "aniṭṭha": ['cped'],
    "anna": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "annabhakṣa": ['mw'],
    "annabhakṣaṇa": ['mw'],
    "annabhuj": ['mw'],
    "annabhāga": ['mw'],
    "annabhāra": ['cped'],
    "annabhāranesādā": ['cped'],
    "annabrahman": ['mw'],
    "annabubhukṣu": ['mw'],
    "annada": ['cae', 'cped', 'mw'],
    "annadevatā": ['mw'],
    "annadoṣa": ['cae', 'mw'],
    "annadravaśūla": ['mw'],
    "annadveṣa": ['mw'],
    "annadāna": ['mw'],
    "annadātṛ": ['mw'],
    "annadāyin": ['mw'],
    "annagandhi": ['mw'],
    "annagati": ['mw'],
    "annahartṛ": ['cae', 'mw'],
    "annahoma": ['mw'],
    "annahāra": ['mw'],
    "annaja": ['mw'],
    "annajala": ['mw'],
    "annajit": ['mw'],
    "annajā": ['mw'],
    "annajāta": ['mw'],
    "annajīvana": ['mw'],
    "annakaraṇa": ['mw'],
    "annakoṣṭhaka": ['mw'],
    "annakāla": ['mw'],
    "annakāma": ['cae', 'ddsa', 'gra', 'mw'],
    "annakāśin": ['mw'],
    "annalipsā": ['mw'],
    "annamala": ['mw'],
    "annamaya": ['ap90', 'cae', 'mw'],
    "annamayakośa": ['mw'],
    "annambhaṭṭa": ['mw'],
    "annapakti": ['cae'],
    "annaparyāyam": ['mw'],
    "annapati": ['cae', 'mw'],
    "annapatnī": ['mw'],
    "annapatya": ['mw'],
    "annapeya": ['mw'],
    "annapiṇḍa": ['cae'],
    "annaprada": ['mw'],
    "annapralaya": ['mw'],
    "annaprāśa": ['mw'],
    "annaprāśana": ['cae', 'mw'],
    "annapāna": ['cae'],
    "annapāśa": ['mw'],
    "annapū": ['mw'],
    "annapūrṇa": ['mw'],
    "annapūrṇā": ['mw'],
    "annarakṣā": ['mw'],
    "annarasa": ['cae', 'mw'],
    "annarasamaya": ['cae'],
    "annasaṃdeha": ['mw'],
    "annasaṃskartṛ": ['mw'],
    "annasaṃskāra": ['mw'],
    "annatejas": ['mw'],
    "annavastra": ['mw'],
    "annavat": ['gra', 'mw'],
    "annavid": ['mw'],
    "annavidveṣa": ['mw'],
    "annavikāra": ['cae', 'mw'],
    "annavikṛti": ['mw'],
    "annavāhisrotas": ['mw'],
    "annayoni": ['mw'],
    "annaśeṣa": ['cae', 'mw'],
    "annaśubha": ['mw'],
    "annaṃ": ['ap90'],
    "annikā": ['mw'],
    "anniy": ['gra'],
    "anniyat": ['mw'],
    "annābhiruci": ['mw'],
    "annācchādana": ['mw'],
    "annāda": ['cae', 'ddsa', 'mw'],
    "annādana": ['mw'],
    "annādin": ['mw'],
    "annādya": ['cae', 'mw'],
    "annādyaja": ['cae'],
    "annādyakāma": ['mw'],
    "annāhārin": ['mw'],
    "annākāla": ['mw'],
    "annārtha": ['cae', 'ddsa'],
    "annārthin": ['mw'],
    "annāttṛ": ['mw'],
    "annāvṛdh": ['ap90', 'ddsa', 'gra', 'mw'],
    "annāyu": ['mw'],
    "annāśana": ['mw'],
    "annīya": ['mw'],
    "ano": ['ap90', 'mw'],
    "anodaka": ['bhs', 'cped'],
    "anodana": ['ap90'],
    "anodarikatta": ['cped'],
    "anodhijina": ['cped'],
    "anodhikatvā": ['cped'],
    "anodhiṁ karitvā": ['cped'],
    "anodissa": ['cped'],
    "anoggata": ['cped'],
    "anohitasota": ['cped'],
    "anojagghati": ['cped'],
    "anojas": ['mw'],
    "anojaska": ['mw'],
    "anojava": ['cped'],
    "anojavat": ['cped'],
    "anoka": ['cped'],
    "anokaha": ['ap90', 'cae', 'mw'],
    "anokasāri": ['cped'],
    "anokasārin": ['cped'],
    "anokaśāyin": ['ap90', 'mw'],
    "anokāsaṁ kata": ['cped'],
    "anokāsaṁ kārāpetvā": ['cped'],
    "anokāśa": ['bhs'],
    "anolīna": ['bhs'],
    "anomajja": ['cped'],
    "anomajjanta": ['cped'],
    "anomajjat": ['cped'],
    "anomajjati": ['cped'],
    "anomananta": ['cped'],
    "anomanikkama": ['cped'],
    "anomanāma": ['cped'],
    "anomiya": ['bhs'],
    "anopa": ['bhs'],
    "anopalambha": ['bhs'],
    "anopalipta": ['bhs'],
    "anopama": ['bhs', 'cped'],
    "anopapanna": ['bhs'],
    "anopārambha": ['cped'],
    "anoratha": ['ddsa', 'mw'],
    "anosita": ['cped'],
    "anosāna": ['bhs'],
    "anosārita": ['cped'],
    "anotaptagātra": ['bhs'],
    "anotiṇṇa": ['cped'],
    "anotrapa": ['bhs'],
    "anotrāpin": ['bhs'],
    "anottappa": ['cped'],
    "anottappi": ['cped'],
    "anottappin": ['cped'],
    "anottāpi": ['cped'],
    "anottāpin": ['cped'],
    "anovadiyamāna": ['cped'],
    "anovassa": ['cped'],
    "anovassaka": ['cped'],
    "anovassika": ['cped'],
    "anovaṭa": ['cped'],
    "anovādi": ['cped'],
    "anovādin": ['cped'],
    "anovāha": ['mw'],
    "anovāhya": ['ap90', 'cae', 'mw'],
    "anovāhyam": ['mw'],
    "anoyukta": ['mw'],
    "anoññāta": ['cped'],
    "anoñāta": ['cped'],
    "anoṃkṛta": ['ap90', 'cae', 'mw'],
    "ant": ['mw'],
    "anta": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "anta-m-anta": ['cped'],
    "antabhava": ['mw'],
    "antabhāj": ['mw'],
    "antacara": ['mw'],
    "antadvīpa": ['mw'],
    "antadvīpin": ['mw'],
    "antadīpaka": ['mw'],
    "antaga": ['cped', 'mw'],
    "antagamana": ['mw'],
    "antagata": ['mw'],
    "antagati": ['mw'],
    "antagaṇṭhi": ['cped'],
    "antaggāhikā": ['cped'],
    "antagiri": ['bhs'],
    "antagrāhadṛṣṭi": ['bhs'],
    "antagāmin": ['mw'],
    "antagū": ['cped'],
    "antaja": ['mw'],
    "antajana": ['bhs', 'cped'],
    "antajāti": ['mw'],
    "antaka": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "antakadruh": ['gra', 'mw'],
    "antakapura": ['mw'],
    "antakara": ['cae', 'cped', 'ddsa', 'mw'],
    "antakaraṇa": ['cae', 'mw'],
    "antakarman": ['mw'],
    "antakiriyā": ['cped'],
    "antakośa": ['bhs'],
    "antakoṭa": ['bhs'],
    "antakāla": ['cae', 'ddsa', 'mw'],
    "antakāmana": ['mw'],
    "antakārin": ['mw'],
    "antakṛddaśā": ['mw'],
    "antakṛt": ['mw'],
    "antalopa": ['mw'],
    "antalīna": ['mw'],
    "antam": ['mw'],
    "antama": ['cae', 'ddsa', 'gra', 'mw'],
    "antamaso": ['cped'],
    "antamasthā": ['mw'],
    "antamaśas": ['bhs'],
    "antamaśato": ['bhs'],
    "antananta": ['cped'],
    "antanantika": ['cped'],
    "antanetra": ['mw'],
    "antanāman": ['mw'],
    "antapluta": ['mw'],
    "antapāla": ['cae', 'mw'],
    "antapūti": ['bhs'],
    "antar": ['cae', 'ddsa', 'gra', 'mw'],
    "antara": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "antarabhogika": ['cped'],
    "antarabhāvanā": ['mw'],
    "antaracakra": ['mw'],
    "antarada": ['mw'],
    "antaradhāna": ['cped'],
    "antaradhāpayati": ['cped'],
    "antaradhāpeti": ['cped'],
    "antaradhāyamāna": ['cped'],
    "antaradhāyati": ['bhs', 'cped'],
    "antaradhāyi": ['cped'],
    "antaradhāyituṁ": ['cped'],
    "antaradhāyiṁsu": ['cped'],
    "antaradhāytha": ['cped'],
    "antaradiśā": ['mw'],
    "antaradvīpa": ['bhs', 'mw'],
    "antaragata": ['cae', 'ddsa'],
    "antaragharaṁ": ['cped'],
    "antaraghare": ['cped'],
    "antaragni": ['mw'],
    "antarahita": ['cped'],
    "antarahāpayati": ['bhs'],
    "antarahāyate": ['bhs'],
    "antarahāyita": ['bhs'],
    "antarahīyati": ['bhs'],
    "antarajña": ['ddsa', 'mw'],
    "antarakalpa": ['bhs'],
    "antarakappa": ['cped'],
    "antarakośa": ['mw'],
    "antaram": ['mw'],
    "antarantaḥstha": ['mw'],
    "antarapatita": ['mw'],
    "antaraprabhava": ['cae', 'mw'],
    "antarapraśna": ['mw'],
    "antaraprekṣin": ['mw'],
    "antarapūruṣa": ['cae', 'mw'],
    "antarastha": ['cae', 'mw'],
    "antarasthita": ['cae', 'mw'],
    "antarasthāyin": ['mw'],
    "antarata": ['mw'],
    "antaratama": ['mw'],
    "antaratara": ['mw'],
    "antaratas": ['cae', 'mw'],
    "antarato": ['cped'],
    "antaravassa": ['cped'],
    "antaravayava": ['mw'],
    "antaravāsaka": ['cped', 'mw'],
    "antaray": ['cae'],
    "antaraya": ['mw'],
    "antarayana": ['mw'],
    "antarayaṇa": ['mw'],
    "antarañj": ['mw'],
    "antaraṁ karoti": ['cped'],
    "antaraṅga": ['cae', 'ddsa', 'mw'],
    "antaraṅgatva": ['mw'],
    "antaraṭṭhaka": ['cped'],
    "antarbhauma": ['mw'],
    "antarbhava": ['mw'],
    "antarbhavana": ['cae', 'mw'],
    "antarbheda": ['mw'],
    "antarbhinna": ['cae', 'mw'],
    "antarbhāva": ['cae', 'mw'],
    "antarbhāvanā": ['mw'],
    "antarbhāvita": ['mw'],
    "antarbhū": ['mw'],
    "antarbhūmi": ['mw'],
    "antarbhūta": ['cae', 'mw'],
    "antarbhūtatva": ['mw'],
    "antarbāṣpa": ['cae', 'ddsa', 'mw'],
    "antardadhana": ['mw'],
    "antardadhāna": ['mw'],
    "antardagdha": ['mw'],
    "antardaśā": ['mw'],
    "antardaśāha": ['cae', 'ddsa', 'mw'],
    "antardaśāhāt": ['mw'],
    "antardeśa": ['mw'],
    "antardhairya": ['mw'],
    "antardhana": ['mw'],
    "antardhi": ['cae', 'mw'],
    "antardhināman": ['mw'],
    "antardhita": ['bhs'],
    "antardhvānta": ['mw'],
    "antardhyāna": ['mw'],
    "antardhā": ['mw'],
    "antardhāna": ['cae', 'mw'],
    "antardhānacara": ['mw'],
    "antardhānagata": ['mw'],
    "antardhāni": ['bhs'],
    "antardhānika": ['bhs'],
    "antardhāpita": ['mw'],
    "antardhāyaka": ['mw'],
    "antardivākīrtya": ['mw'],
    "antardiś": ['mw'],
    "antarduḥkha": ['mw'],
    "antarduṣṭa": ['mw'],
    "antardvāra": ['mw'],
    "antardāha": ['mw'],
    "antardāva": ['mw'],
    "antardīpa": ['cae'],
    "antardṛṣṭi": ['mw'],
    "antare": ['bhs', 'mw'],
    "antarena": ['cped'],
    "antareṇa": ['bhs', 'mw'],
    "antareṣa": ['mw'],
    "antargalagata": ['mw'],
    "antargam": ['mw'],
    "antargarbha": ['mw'],
    "antargata": ['bhs', 'cae', 'ddsa', 'mw'],
    "antargatamanas": ['mw'],
    "antargatopamā": ['mw'],
    "antargaḍu": ['mw'],
    "antargaṅgā": ['mw'],
    "antargaṇa": ['mw'],
    "antargeha": ['mw'],
    "antargeham": ['mw'],
    "antarghana": ['mw'],
    "antarghaṇa": ['mw'],
    "antarghāta": ['mw'],
    "antargiri": ['mw'],
    "antargoṣṭha": ['mw'],
    "antargudavalaya": ['mw'],
    "antargā": ['mw'],
    "antargāmin": ['mw'],
    "antargūḍhaviṣa": ['mw'],
    "antargṛha": ['mw'],
    "antargṛham": ['mw'],
    "antarhan": ['mw'],
    "antarhanana": ['mw'],
    "antarhastam": ['mw'],
    "antarhastīna": ['mw'],
    "antarhaṇana": ['mw'],
    "antarhita": ['cae', 'ddsa', 'mw'],
    "antarhiti": ['mw'],
    "antarhitātman": ['mw'],
    "antarhāpayati": ['bhs'],
    "antarhāsa": ['cae', 'ddsa', 'mw'],
    "antarhāsam": ['mw'],
    "antarhṛdaya": ['mw'],
    "antari": ['mw'],
    "antarika": ['bhs'],
    "antarikā": ['bhs', 'cped'],
    "antarikṣa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "antarikṣacara": ['mw'],
    "antarikṣaga": ['cae', 'ddsa', 'mw'],
    "antarikṣagata": ['cae'],
    "antarikṣakṣit": ['mw'],
    "antarikṣaloka": ['mw'],
    "antarikṣanāman": ['mw'],
    "antarikṣaprut": ['gra', 'mw'],
    "antarikṣaprā": ['gra', 'mw'],
    "antarikṣasad": ['cae', 'gra', 'mw'],
    "antarikṣasadya": ['mw'],
    "antarikṣasaṃśita": ['mw'],
    "antarikṣayānī": ['mw'],
    "antarikṣia": ['gra'],
    "antarikṣodara": ['mw'],
    "antarikṣya": ['gra', 'mw'],
    "antarikṣāsana": ['mw'],
    "antarikṣāyatana": ['mw'],
    "antarindriya": ['cae', 'ddsa', 'mw'],
    "antarita": ['cae', 'ddsa', 'mw'],
    "antariti": ['mw'],
    "antariṣ": ['mw'],
    "antarja": ['mw'],
    "antarjalacara": ['cae', 'ddsa', 'mw'],
    "antarjalanivāsin": ['cae'],
    "antarjalaugha": ['cae', 'mw'],
    "antarjambha": ['mw'],
    "antarjana": ['bhs', 'mw'],
    "antarjanman": ['mw'],
    "antarjaṭhara": ['mw'],
    "antarjvalana": ['mw'],
    "antarjyotis": ['cae', 'mw'],
    "antarjñāna": ['mw'],
    "antarjānu": ['ddsa', 'mw'],
    "antarjāta": ['mw'],
    "antarlamba": ['mw'],
    "antarloma": ['mw'],
    "antarlīna": ['mw'],
    "antarmadāvastha": ['mw'],
    "antarmanas": ['mw'],
    "antarmandira": ['mw'],
    "antarmanmatha": ['cae'],
    "antarmarman": ['mw'],
    "antarmoda": ['cae', 'mw'],
    "antarmudra": ['mw'],
    "antarmukha": ['bhs', 'mw'],
    "antarmukham": ['mw'],
    "antarmṛta": ['mw'],
    "antarnagara": ['cae', 'mw'],
    "antarnihita": ['mw'],
    "antarnikhāta": ['cae', 'mw'],
    "antarniveśana": ['cae', 'mw'],
    "antarniviṣṭa": ['mw'],
    "antarniviṣṭapada": ['ddsa'],
    "antarniṣṭha": ['mw'],
    "antaroddāna": ['bhs'],
    "antarpūti": ['bhs'],
    "antarubbhāra": ['cped'],
    "antarupātī": ['mw'],
    "antaruṣya": ['cae', 'ddsa', 'gra', 'mw'],
    "antarvacana": ['mw'],
    "antarvaktra": ['cae'],
    "antarvami": ['mw'],
    "antarvant": ['cae'],
    "antarvarta": ['mw'],
    "antarvartin": ['mw'],
    "antarvartinī": ['bhs', 'mw'],
    "antarvarṣā": ['bhs'],
    "antarvas": ['mw'],
    "antarvasat": ['mw'],
    "antarvastra": ['mw'],
    "antarvasu": ['mw'],
    "antarvat": ['gra', 'mw'],
    "antarvaṃśa": ['mw'],
    "antarvaṃśika": ['ddsa', 'mw'],
    "antarvaṇa": ['mw'],
    "antarvaṇam": ['mw'],
    "antarvedi": ['cae', 'mw'],
    "antarvedī": ['cae', 'mw'],
    "antarvega": ['mw'],
    "antarveśman": ['cae', 'mw'],
    "antarveśmika": ['mw'],
    "antarvidvas": ['mw'],
    "antarvigāhana": ['mw'],
    "antarvāsas": ['mw'],
    "antarvāsika": ['bhs'],
    "antarvāvat": ['gra', 'mw'],
    "antarvāṇi": ['mw'],
    "antarvṛtti": ['cae', 'mw'],
    "antarya": ['mw'],
    "antaryajana": ['mw'],
    "antaryakṣa": ['mw'],
    "antaryam": ['mw'],
    "antaryoga": ['mw'],
    "antaryāga": ['mw'],
    "antaryāma": ['ddsa', 'mw'],
    "antaryāmagraha": ['mw'],
    "antaryāmin": ['cae', 'mw'],
    "antarā": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "antarā-hosi": ['cped'],
    "antarābhakta": ['mw'],
    "antarābhara": ['gra', 'mw'],
    "antarābhava": ['bhs'],
    "antarābhavadeha": ['mw'],
    "antarābhavasattva": ['mw'],
    "antarābhavika": ['bhs'],
    "antarādhā": ['mw'],
    "antarādhāna": ['mw'],
    "antarādiś": ['mw'],
    "antarāgama": ['mw'],
    "antarāgamana": ['cae', 'ddsa', 'mw'],
    "antarāgiri": ['bhs'],
    "antarāgāra": ['ddsa', 'mw'],
    "antarākathā": ['bhs', 'cped'],
    "antarākāja": ['cped'],
    "antarākāśa": ['mw'],
    "antarākūṭa": ['mw'],
    "antarāla": ['cae', 'ddsa', 'mw'],
    "antarālaka": ['mw'],
    "antarālake": ['mw'],
    "antarāle": ['mw'],
    "antarāmaggato": ['cped'],
    "antarāmagge": ['cped'],
    "antarāmarśana": ['bhs'],
    "antarāmuttaka": ['cped'],
    "antarāntara": ['cped'],
    "antarāntaram": ['bhs'],
    "antarāntarāt": ['mw'],
    "antarānveṣin": ['cae', 'ddsa', 'mw'],
    "antarāparinibbāyi": ['cped'],
    "antarāparinibbāyin": ['cped'],
    "antarāparinirvāyin": ['bhs'],
    "antarāpatti": ['bhs'],
    "antarāpatyā": ['mw'],
    "antarāpaṇa": ['cped', 'mw'],
    "antarāppati": ['cped'],
    "antarāpūrṇatā": ['bhs'],
    "antarārāma": ['cae', 'mw'],
    "antarās": ['mw'],
    "antarāt": ['bhs'],
    "antarātmaka": ['mw'],
    "antarātman": ['cae', 'mw'],
    "antarātmeṣṭakam": ['mw'],
    "antarāvedi": ['ddsa'],
    "antarāvedī": ['mw'],
    "antarāvosāna": ['cped'],
    "antarāvāsa": ['bhs'],
    "antarāya": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "antarāyakara": ['cped'],
    "antarāyaṁ karoti": ['cped'],
    "antarāyaṇa": ['bhs'],
    "antarāyika": ['bhs', 'cped'],
    "antarāśṛṅgam": ['mw'],
    "antarāśṛṅgīya": ['mw'],
    "antarāṃsa": ['mw'],
    "antarī": ['bhs'],
    "antarīkṛ": ['ddsa', 'mw'],
    "antarīkṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "antarīkṣadevalipi": ['bhs'],
    "antarīkṣastha": ['cae'],
    "antarīkṣecara": ['bhs'],
    "antarīpa": ['mw'],
    "antarīya": ['bhs', 'cae', 'ddsa', 'mw'],
    "antarīyaka": ['bhs'],
    "antas": ['mw'],
    "antasad": ['mw'],
    "antasatkriyā": ['ddsa', 'mw'],
    "antaspatha": ['cae', 'gra', 'mw'],
    "antastapta": ['cae', 'mw'],
    "antastha": ['mw'],
    "antastoya": ['cae', 'mw'],
    "antastuṣāra": ['cae', 'mw'],
    "antastya": ['mw'],
    "antastāpa": ['cae', 'ddsa', 'mw'],
    "antasvarita": ['mw'],
    "antatas": ['bhs', 'cae', 'mw'],
    "antatvāṣṭrī": ['mw'],
    "antava": ['cped'],
    "antavahni": ['mw'],
    "antavant": ['cae'],
    "antavat": ['cped', 'ddsa', 'mw'],
    "antavelā": ['mw'],
    "antavāsin": ['bhs', 'mw'],
    "antaya": ['mw'],
    "antayugika": ['bhs'],
    "antaśalya": ['bhs'],
    "antaśas": ['bhs', 'mw'],
    "antaśayyā": ['mw'],
    "antaścakṣus": ['mw'],
    "antaścar": ['mw'],
    "antaścara": ['ddsa', 'mw'],
    "antaścaṇḍāla": ['mw'],
    "antaśchid": ['mw'],
    "antaścālin": ['bhs'],
    "antaḥ": ['mw'],
    "antaḥkalpa": ['bhs', 'mw'],
    "antaḥkaraṇa": ['cae', 'ddsa', 'mw'],
    "antaḥkhyā": ['mw'],
    "antaḥkopa": ['mw'],
    "antaḥkośa": ['mw'],
    "antaḥkoṇa": ['mw'],
    "antaḥkoṭarapuṣpī": ['mw'],
    "antaḥkratu": ['mw'],
    "antaḥkraurya": ['mw'],
    "antaḥkuṭila": ['mw'],
    "antaḥkṛmi": ['mw'],
    "antaḥpadam": ['mw'],
    "antaḥpade": ['mw'],
    "antaḥparidhi": ['mw'],
    "antaḥparidhāna": ['mw'],
    "antaḥparimārjana": ['mw'],
    "antaḥparśavya": ['mw'],
    "antaḥpavitra": ['mw'],
    "antaḥpaś": ['mw'],
    "antaḥpaśu": ['mw'],
    "antaḥpaṭa": ['mw'],
    "antaḥpeya": ['gra', 'mw'],
    "antaḥpracalita": ['cae', 'mw'],
    "antaḥprajña": ['mw'],
    "antaḥprakṛti": ['mw'],
    "antaḥpramoda": ['cae', 'mw'],
    "antaḥpratihāram": ['mw'],
    "antaḥpratiṣṭhita": ['mw'],
    "antaḥpratiṣṭhāna": ['mw'],
    "antaḥpraveśa": ['mw'],
    "antaḥprāṇa": ['cae'],
    "antaḥprāṇin": ['mw'],
    "antaḥpura": ['cae', 'mw'],
    "antaḥpuracara": ['mw'],
    "antaḥpuracārikā": ['mw'],
    "antaḥpurajana": ['mw'],
    "antaḥpurapracāra": ['mw'],
    "antaḥpurarakṣaka": ['mw'],
    "antaḥpurasahāya": ['mw'],
    "antaḥpuravartin": ['mw'],
    "antaḥpuravṛddhā": ['mw'],
    "antaḥpurevāsa": ['mw'],
    "antaḥpurika": ['mw'],
    "antaḥpurikā": ['cae', 'mw'],
    "antaḥpurādhipatya": ['mw'],
    "antaḥpurādhyakṣa": ['mw'],
    "antaḥpurāvacara": ['mw'],
    "antaḥpurīya": ['mw'],
    "antaḥpādam": ['mw'],
    "antaḥpāla": ['mw'],
    "antaḥpārśva": ['mw'],
    "antaḥpārśvya": ['mw'],
    "antaḥpāta": ['mw'],
    "antaḥpātin": ['mw'],
    "antaḥpātita": ['mw'],
    "antaḥpātra": ['mw'],
    "antaḥpātya": ['mw'],
    "antaḥpūjā": ['mw'],
    "antaḥpūti": ['bhs'],
    "antaḥpūya": ['mw'],
    "antaḥsadas": ['mw'],
    "antaḥsadasam": ['mw'],
    "antaḥsalila": ['cae', 'mw'],
    "antaḥsalilam": ['mw'],
    "antaḥsalilastha": ['mw'],
    "antaḥsattva": ['mw'],
    "antaḥsattvā": ['mw'],
    "antaḥsañjña": ['ddsa'],
    "antaḥsaṃjña": ['cae', 'mw'],
    "antaḥsenam": ['mw'],
    "antaḥsmayin": ['mw'],
    "antaḥsmera": ['mw'],
    "antaḥsmita": ['mw'],
    "antaḥspandya": ['mw'],
    "antaḥstha": ['cae', 'mw'],
    "antaḥsthamudgara": ['mw'],
    "antaḥsthā": ['mw'],
    "antaḥsthāchandas": ['mw'],
    "antaḥsthībhāva": ['mw'],
    "antaḥstobha": ['mw'],
    "antaḥstomabhāgam": ['mw'],
    "antaḥsukha": ['cae', 'mw'],
    "antaḥsuṣirin": ['mw'],
    "antaḥsveda": ['mw'],
    "antaḥsāma": ['mw'],
    "antaḥsāmika": ['mw'],
    "antaḥsānu": ['mw'],
    "antaḥsāra": ['cae', 'mw'],
    "antaḥśailaja": ['mw'],
    "antaḥśalya": ['bhs', 'ddsa', 'mw'],
    "antaḥśara": ['mw'],
    "antaḥśarīra": ['mw'],
    "antaḥśarīrastha": ['cae'],
    "antaḥśava": ['mw'],
    "antaḥśilā": ['mw'],
    "antaḥśleṣa": ['cae', 'mw'],
    "antaḥśleṣaṇa": ['mw'],
    "antaḥśri": ['mw'],
    "antaḥśānti": ['mw'],
    "antaḥśīrṇa": ['cae', 'mw'],
    "antaḷikkha": ['cped'],
    "antaḷikkhacara": ['cped'],
    "antaḷikkhaga": ['cped'],
    "antaḷikkhecara": ['cped'],
    "anta’anta": ['cped'],
    "ante": ['bhs', 'mw'],
    "antena": ['cped', 'mw'],
    "antepura": ['bhs', 'cped'],
    "antevasāyin": ['mw'],
    "antevāsa": ['cae', 'ddsa', 'mw'],
    "antevāsi": ['cped', 'mw'],
    "antevāsika": ['bhs', 'cped'],
    "antevāsin": ['cae', 'cped', 'mw'],
    "antevāsinikamyatā": ['cped'],
    "antevāsinī": ['cped'],
    "anti": ['cae', 'ddsa', 'gra', 'mw'],
    "antideva": ['gra', 'mw'],
    "antigṛha": ['gra', 'mw'],
    "antika": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "antikacara": ['cae'],
    "antikagati": ['mw'],
    "antikam": ['mw'],
    "antikatā": ['mw'],
    "antike": ['bhs', 'mw'],
    "antikena": ['mw'],
    "antikā": ['mw'],
    "antikāt": ['bhs', 'mw'],
    "antikāvacara": ['bhs'],
    "antikāśraya": ['mw'],
    "antima": ['cae', 'cped', 'ddsa', 'mw'],
    "antimadehadhara": ['cped'],
    "antimadehadhāri": ['cped'],
    "antimadehadhārin": ['cped'],
    "antimapurisa": ['cped'],
    "antimasārīra": ['cped'],
    "antimavattu": ['cped'],
    "antimitra": ['mw'],
    "antimāṅka": ['mw'],
    "antisumna": ['mw'],
    "antitama": ['mw'],
    "antitara": ['mw'],
    "antitas": ['cae', 'ddsa', 'gra', 'mw'],
    "antivāma": ['gra', 'mw'],
    "antiūti": ['gra'],
    "antiṣad": ['mw'],
    "antiṣṭha": ['bhs'],
    "anto": ['cped'],
    "anto-aruna": ['cped'],
    "anto-ārāma": ['cped'],
    "anto-āvasatha": ['cped'],
    "antodaka": ['bhs'],
    "antodātta": ['ddsa', 'mw'],
    "antogadha": ['cped'],
    "antogata": ['bhs', 'cped'],
    "antojana": ['cped'],
    "antojaṭa": ['cped'],
    "antojaṭā": ['cped'],
    "antojālīkata": ['cped'],
    "antojāta": ['cped'],
    "antokasambu": ['cped'],
    "antokoṭṭhāgārika": ['cped'],
    "antomana": ['cped'],
    "antomanas": ['cped'],
    "antonimuggaposi": ['cped'],
    "antonimuggaposin": ['cped'],
    "antoparisoka": ['cped'],
    "antopūti": ['cped'],
    "antosimaṁ": ['cped'],
    "antosoka": ['cped'],
    "antosīmāya": ['cped'],
    "antovana": ['cped'],
    "antovassaṁ": ['cped'],
    "antovaṇṇa": ['cped'],
    "antośalya": ['bhs'],
    "antra": ['cae', 'ddsa', 'gra', 'mw'],
    "antraguṇa": ['bhs'],
    "antrakūja": ['mw'],
    "antrakūjana": ['mw'],
    "antramaya": ['mw'],
    "antrapācaka": ['mw'],
    "antrasraj": ['mw'],
    "antravardhman": ['mw'],
    "antravikūjana": ['mw'],
    "antravṛddhi": ['mw'],
    "antraśilā": ['mw'],
    "antraṃdhami": ['mw'],
    "antrā": ['bhs'],
    "antrāda": ['mw'],
    "antrī": ['mw'],
    "antu": ['mw'],
    "antya": ['cae', 'ddsa', 'mw'],
    "antyabha": ['mw'],
    "antyadhana": ['mw'],
    "antyaja": ['cae', 'mw'],
    "antyajagamana": ['mw'],
    "antyajanman": ['cae', 'mw'],
    "antyajāgamana": ['mw'],
    "antyajāti": ['cae', 'mw'],
    "antyajātīya": ['mw'],
    "antyaka": ['mw'],
    "antyakarman": ['cae', 'mw'],
    "antyakriyā": ['mw'],
    "antyamaṇḍana": ['mw'],
    "antyamūla": ['mw'],
    "antyapada": ['mw'],
    "antyastrī": ['cae'],
    "antyavarṇa": ['mw'],
    "antyavipulā": ['mw'],
    "antyayoni": ['cae', 'mw'],
    "antyayuga": ['mw'],
    "antyeṣṭi": ['mw'],
    "antyeṣṭikriyā": ['mw'],
    "antyāhuti": ['mw'],
    "antyārdha": ['mw'],
    "antyāvasāyin": ['cae', 'mw'],
    "antyūti": ['gra', 'mw'],
    "antābādha": ['cped'],
    "antādi": ['mw'],
    "antāt": ['mw'],
    "antāvasāyin": ['ddsa', 'mw'],
    "antāvaśāyin": ['mw'],
    "antāya": ['mw'],
    "antī": ['mw'],
    "anu": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "anu-aya": ['cped'],
    "anu-esanta": ['cped'],
    "anu-esati": ['cped'],
    "anu-eti": ['cped'],
    "anu-iti": ['cped'],
    "anu-otthaṭa": ['cped'],
    "anu-āgata": ['cped'],
    "anu-ānayati": ['cped'],
    "anubaddha": ['ap90', 'cae', 'cped', 'mw'],
    "anubadha": ['bhs'],
    "anubadhnat": ['mw'],
    "anubala": ['mw'],
    "anubalappādana": ['cped'],
    "anubalaṃ": ['ap90'],
    "anubandh": ['mw'],
    "anubandha": ['cae', 'cped', 'ddsa', 'mw'],
    "anubandhaka": ['mw'],
    "anubandhana": ['mw'],
    "anubandhanta": ['cped'],
    "anubandhati": ['cped'],
    "anubandhi": ['cped'],
    "anubandhin": ['cae', 'mw'],
    "anubandhissāmi": ['cped'],
    "anubandhisuṁ": ['cped'],
    "anubandhitabba": ['cped'],
    "anubandhitva": ['mw'],
    "anubandhitvā": ['cped'],
    "anubandhiṁsu": ['cped'],
    "anubandhya": ['mw'],
    "anubandhī": ['mw'],
    "anubaṃdh": ['ap90'],
    "anubaṃdhaka": ['ap90'],
    "anubaṃdhanaṃ": ['ap90'],
    "anubaṃdhaḥ": ['ap90'],
    "anubaṃdhin": ['ap90'],
    "anubaṃdhya": ['ap90'],
    "anubbigga": ['cped'],
    "anubha": ['mw'],
    "anubhaj": ['mw'],
    "anubhartsyanti": ['bhs'],
    "anubhartṛ": ['ap90', 'cae', 'gra', 'mw'],
    "anubhava": ['ap90', 'cae', 'ddsa', 'mw'],
    "anubhavam": ['mw'],
    "anubhavanatā": ['bhs'],
    "anubhavasiddha": ['mw'],
    "anubhavati": ['bhs', 'cped'],
    "anubhavaḥ": ['ap90'],
    "anubhavi": ['cped'],
    "anubhavissati": ['cped'],
    "anubhavissāma": ['cped'],
    "anubhavārūḍha": ['mw'],
    "anubhaya": ['mw'],
    "anubhayātman": ['mw'],
    "anubhayātmatā": ['mw'],
    "anubhaṇanā": ['cped'],
    "anubhid": ['mw'],
    "anubhitti": ['mw'],
    "anubhoga": ['mw'],
    "anubhogaḥ": ['ap90'],
    "anubhohisi": ['cped'],
    "anubhoktar": ['bhs'],
    "anubhokti": ['bhs'],
    "anubhoti": ['cped'],
    "anubhrama": ['bhs'],
    "anubhramati": ['bhs'],
    "anubhrāj": ['mw'],
    "anubhrātṛ": ['ap90', 'mw'],
    "anubhuj": ['ap90', 'mw'],
    "anubhā": ['mw'],
    "anubhāga": ['cae', 'cped'],
    "anubhāsa": ['mw'],
    "anubhāsati": ['bhs', 'cped'],
    "anubhāsaḥ": ['ap90'],
    "anubhāva": ['cae', 'mw'],
    "anubhāvaka": ['ap90', 'mw'],
    "anubhāvakatā": ['mw'],
    "anubhāvana": ['mw'],
    "anubhāvanaṃ": ['ap90'],
    "anubhāvaḥ": ['ap90'],
    "anubhāvin": ['ap90', 'cae', 'mw'],
    "anubhāvya": ['mw'],
    "anubhāṣ": ['mw'],
    "anubhāṣaṇa": ['mw'],
    "anubhāṣaṇaṃ": ['ap90'],
    "anubhāṣita": ['mw'],
    "anubhāṣitṛ": ['ap90', 'mw'],
    "anubhū": ['ap90', 'mw'],
    "anubhūta": ['bhs', 'cped', 'mw'],
    "anubhūti": ['gra', 'mw'],
    "anubhūtiprakāśa": ['mw'],
    "anubhūtisvarūpācārya": ['mw'],
    "anubhūtiḥ": ['ap90'],
    "anubhūya": ['mw'],
    "anubhūyamāna": ['mw'],
    "anubhṛ": ['ap90', 'mw'],
    "anubimba": ['mw'],
    "anubimbana": ['mw'],
    "anubimbita": ['mw'],
    "anubodha": ['bhs', 'cae', 'mw'],
    "anubodhana": ['bhs', 'mw'],
    "anubodhanaṃ": ['ap90'],
    "anubodhaḥ": ['ap90'],
    "anubodhita": ['mw'],
    "anubodhiṁ": ['cped'],
    "anubrāhmaṇa": ['mw'],
    "anubrāhmaṇam": ['mw'],
    "anubrāhmaṇaṃ": ['ap90'],
    "anubrāhmaṇika": ['mw'],
    "anubrāhmaṇin": ['ap90', 'mw'],
    "anubrū": ['mw'],
    "anubrūhati": ['cped'],
    "anubrūhaya": ['cped'],
    "anubrūhayamāna": ['cped'],
    "anubrūhayat": ['cped'],
    "anubrūhayati": ['cped'],
    "anubrūheti": ['cped'],
    "anubrūhita": ['cped'],
    "anubuddha": ['cped'],
    "anubuddhi": ['bhs'],
    "anubudh": ['ap90', 'mw'],
    "anubudhyana": ['bhs'],
    "anubujjhati": ['cped'],
    "anubādh": ['mw'],
    "anubṛṃhayati": ['bhs'],
    "anubṛṃhaṇatā": ['bhs'],
    "anucakṣ": ['mw'],
    "anucalati": ['bhs'],
    "anucar": ['ap90', 'mw'],
    "anucara": ['cae', 'ddsa', 'mw'],
    "anucarati": ['cped'],
    "anucaraḥ": ['ap90'],
    "anucaraṇa": ['mw'],
    "anucaraṇacarita": ['mw'],
    "anucarci": ['mw'],
    "anucarciḥ": ['ap90'],
    "anucarita": ['ap90'],
    "anucariyamāna": ['cped'],
    "anucariyā": ['cped'],
    "anucarā": ['mw'],
    "anucarī": ['mw'],
    "anucaṅkamamāna": ['cped'],
    "anucaṅkamanta": ['cped'],
    "anucaṅkamati": ['cped'],
    "anucaṅkamiṁ": ['cped'],
    "anucaṅkamiṁsu": ['cped'],
    "anucaṅkamāpeti": ['cped'],
    "anucaṅkramyati": ['bhs'],
    "anucca": ['ddsa', 'mw'],
    "anuccais": ['mw'],
    "anuccalana": ['bhs'],
    "anuccalant": ['cae'],
    "anuccalat": ['mw'],
    "anucchava": ['cped'],
    "anucchavi": ['cped'],
    "anucchavika": ['cped'],
    "anucchaviya": ['cped'],
    "anuccheda": ['mw'],
    "anucchedya": ['mw'],
    "anucchid": ['mw'],
    "anucchindat": ['mw'],
    "anucchinna": ['mw'],
    "anucchitti": ['mw'],
    "anucchittidharman": ['mw'],
    "anucchittiḥ": ['ap90'],
    "anucchiṣṭa": ['ap90', 'mw'],
    "anuccho": ['mw'],
    "anucchāda": ['mw'],
    "anucchādaḥ": ['ap90'],
    "anuccāra": ['mw'],
    "anuccāraṇa": ['mw'],
    "anuccāritakamma": ['cped'],
    "anuccāvaca": ['bhs'],
    "anuci": ['mw'],
    "anucint": ['mw'],
    "anucintana": ['cae', 'cped', 'ddsa', 'mw'],
    "anucintita": ['mw'],
    "anucintā": ['mw'],
    "anucira": ['bhs'],
    "anucita": ['ap90', 'cae', 'ddsa', 'mw'],
    "anucitārtha": ['mw'],
    "anuciṃt": ['ap90'],
    "anuciṃtā": ['ap90'],
    "anuciṇṇa": ['cped'],
    "anucālin": ['bhs'],
    "anucāra": ['bhs'],
    "anucāraka": ['mw'],
    "anucārakaḥ": ['ap90'],
    "anucārikā": ['mw'],
    "anucārin": ['mw'],
    "anucīrṇa": ['bhs'],
    "anuda": ['ap90', 'gra', 'mw'],
    "anudadhyamāna": ['bhs'],
    "anudagra": ['ap90', 'mw'],
    "anudah": ['mw'],
    "anudahati": ['cped'],
    "anudairghya": ['ap90', 'mw'],
    "anudaka": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "anudakam": ['mw'],
    "anudapāna": ['mw'],
    "anudara": ['ap90', 'mw'],
    "anudarśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "anudarśana": ['cae', 'mw'],
    "anudarśanaṃ": ['ap90'],
    "anudarśin": ['mw'],
    "anudasseti": ['cped'],
    "anudatta": ['mw'],
    "anudaya": ['cae', 'mw'],
    "anudayatā": ['cped'],
    "anudayā": ['cped'],
    "anudaṇḍi": ['mw'],
    "anudbhaṭa": ['ap90', 'mw'],
    "anuddayatā": ['cped'],
    "anuddayā": ['cped'],
    "anuddhacca": ['cped'],
    "anuddharaṇa": ['mw'],
    "anuddharaṇaṃ": ['ap90'],
    "anuddharitvā": ['cped'],
    "anuddhata": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "anuddhaṁsenta": ['cped'],
    "anuddhaṁsesi": ['cped'],
    "anuddhaṁseti": ['cped'],
    "anuddhaṁsita": ['cped'],
    "anuddhaṭa": ['cped'],
    "anuddhāna": ['mw'],
    "anuddhāra": ['mw'],
    "anuddhāraḥ": ['ap90'],
    "anuddhṛta": ['ap90', 'bhs', 'cae', 'mw'],
    "anuddhṛtābhyastamaya": ['mw'],
    "anuddiṭṭha": ['cped'],
    "anudeham": ['mw'],
    "anudeya": ['mw'],
    "anudeyī": ['ap90', 'gra', 'mw'],
    "anudeśa": ['cae', 'ddsa', 'mw'],
    "anudeśana": ['bhs'],
    "anudeśaḥ": ['ap90'],
    "anudeśin": ['ap90', 'mw'],
    "anudghāta": ['cae', 'ddsa', 'mw'],
    "anudghāyya": ['cae'],
    "anudgīrṇa": ['mw'],
    "anudgṛhṇat": ['mw'],
    "anudham": ['mw'],
    "anudhamma": ['cped'],
    "anudhammacāri": ['cped'],
    "anudhammacārin": ['cped'],
    "anudhammatā": ['cped'],
    "anudhammaṁ": ['cped'],
    "anudhanv": ['mw'],
    "anudhanvana": ['bhs'],
    "anudharma": ['bhs'],
    "anudharmamati": ['bhs'],
    "anudharmya": ['bhs'],
    "anudhaṁsana": ['cped'],
    "anudhe": ['mw'],
    "anudhvaṃs": ['mw'],
    "anudhvaṃsana": ['bhs'],
    "anudhvaṃsayati": ['bhs'],
    "anudhvaṃsayitar": ['bhs'],
    "anudhyai": ['ap90', 'mw'],
    "anudhyeya": ['ap90'],
    "anudhyā": ['ap90', 'mw'],
    "anudhyāna": ['ap90', 'mw'],
    "anudhyāpita": ['bhs'],
    "anudhyāyaḥ": ['ap90'],
    "anudhyāyin": ['mw'],
    "anudhā": ['mw'],
    "anudhāra": ['bhs'],
    "anudhārayati": ['bhs'],
    "anudhārin": ['bhs'],
    "anudhāv": ['ap90', 'mw'],
    "anudhāvana": ['cae', 'ddsa', 'mw'],
    "anudhāvanaka": ['cped'],
    "anudhāvanaṃ": ['ap90'],
    "anudhāvati": ['cped'],
    "anudhāvi": ['cped'],
    "anudhāvita": ['cped', 'mw'],
    "anudhī": ['mw'],
    "anudhūpita": ['mw'],
    "anudigdha": ['mw'],
    "anudina": ['cae', 'ddsa'],
    "anudinam": ['mw'],
    "anudinaṃ": ['ap90'],
    "anudisaṁ": ['cped'],
    "anudissati": ['cped'],
    "anudisā": ['cped'],
    "anudita": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anudivasam": ['cae', 'ddsa', 'mw'],
    "anudiś": ['ap90', 'mw'],
    "anudiśam": ['mw'],
    "anudiṭṭhi": ['cped'],
    "anudra": ['gra', 'mw'],
    "anudrakṣi": ['bhs'],
    "anudravaṇa": ['mw'],
    "anudraṣṭavya": ['mw'],
    "anudru": ['ap90', 'mw'],
    "anudruta": ['ap90', 'bhs', 'mw'],
    "anuduṣ": ['mw'],
    "anudvega": ['ap90', 'cae', 'mw'],
    "anudvegakara": ['cae', 'mw'],
    "anudvejayant": ['cae'],
    "anudvejayat": ['mw'],
    "anudvigna": ['ap90', 'cae', 'mw'],
    "anudviṣ": ['mw'],
    "anudvāha": ['mw'],
    "anudvāhaḥ": ['ap90'],
    "anudvāra": ['mw'],
    "anudvāta": ['mw'],
    "anudvīpa": ['mw'],
    "anudya": ['mw'],
    "anudyama": ['ddsa'],
    "anudyamāna": ['mw'],
    "anudyata": ['ap90', 'mw'],
    "anudyoga": ['ap90', 'mw'],
    "anudyogin": ['mw'],
    "anudyūta": ['mw'],
    "anudyūtaṃ": ['ap90'],
    "anudā": ['ap90', 'mw'],
    "anudāhāra": ['bhs'],
    "anudāra": ['ap90', 'ddsa', 'mw'],
    "anudāsīna": ['cae', 'ddsa'],
    "anudātta": ['ap90', 'cae', 'ddsa', 'mw'],
    "anudāttatara": ['mw'],
    "anudāttet": ['mw'],
    "anudāttodaya": ['mw'],
    "anudāttādi": ['mw'],
    "anudūta": ['cped'],
    "anudṛbh": ['mw'],
    "anudṛś": ['ap90', 'mw'],
    "anudṛṣṭi": ['ap90', 'mw'],
    "anudṝ": ['mw'],
    "anuga": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "anugacchanta": ['cped'],
    "anugacchati": ['cped'],
    "anugai": ['ap90', 'mw'],
    "anugam": ['ap90', 'mw'],
    "anugama": ['mw'],
    "anugamana": ['mw'],
    "anugamaḥ": ['ap90'],
    "anugamya": ['mw'],
    "anugamāsi": ['cped'],
    "anugantavya": ['mw'],
    "anugantī": ['bhs', 'mw'],
    "anugara": ['cae', 'mw'],
    "anugarj": ['ap90', 'mw'],
    "anugarjita": ['ap90', 'cae', 'mw'],
    "anugata": ['ap90', 'cae', 'cped', 'mw'],
    "anugati": ['cae', 'mw'],
    "anugatika": ['mw'],
    "anugatiḥ": ['ap90'],
    "anugatārtha": ['mw'],
    "anugava": ['ap90'],
    "anugavam": ['mw'],
    "anugaveṣate": ['bhs'],
    "anugavīna": ['mw'],
    "anugavīnaḥ": ['ap90'],
    "anugaṅgam": ['mw'],
    "anugaṇ": ['mw'],
    "anugaṇhāti": ['cped'],
    "anugaṇita": ['mw'],
    "anugaṇitin": ['mw'],
    "anugaṇḍikā": ['mw'],
    "anugeya": ['mw'],
    "anuggaha": ['cped'],
    "anuggahesi": ['cped'],
    "anuggahetabba": ['cped'],
    "anuggahetvā": ['cped'],
    "anuggahi": ['cped'],
    "anuggahita": ['cped'],
    "anuggahitacitta": ['cped'],
    "anuggahāpenta": ['cped'],
    "anuggahāpesi": ['cped'],
    "anuggahāpeti": ['cped'],
    "anuggahāya": ['cped'],
    "anuggata": ['cped'],
    "anuggaṇhanta": ['cped'],
    "anuggaṇhāpeti": ['cped'],
    "anuggaṇhāti": ['cped'],
    "anuggāhaka": ['cped'],
    "anugharakaṁ": ['cped'],
    "anughaṭana": ['mw'],
    "anughaṭanaṃ": ['ap90'],
    "anughaṭṭ": ['mw'],
    "anughrā": ['mw'],
    "anughuṣ": ['mw'],
    "anugiddha": ['cped'],
    "anugijjhati": ['cped'],
    "anugiram": ['mw'],
    "anugiraṃ": ['ap90'],
    "anugodam": ['mw'],
    "anugoptṛ": ['mw'],
    "anugra": ['gra', 'mw'],
    "anugrah": ['ap90', 'mw'],
    "anugraha": ['cae', 'ddsa', 'mw'],
    "anugrahacandra": ['bhs'],
    "anugrahakātara": ['mw'],
    "anugrahamati": ['bhs'],
    "anugrahasarga": ['mw'],
    "anugrahaḥ": ['ap90'],
    "anugrahaṇa": ['mw'],
    "anugrahin": ['mw'],
    "anugrahita": ['mw'],
    "anugrahītṛ": ['mw'],
    "anugravarṇakṣemagupta": ['bhs'],
    "anugrāhaka": ['ap90', 'mw'],
    "anugrāhin": ['mw'],
    "anugrāhya": ['ap90', 'mw'],
    "anugrāmam": ['mw'],
    "anugrāsaka": ['mw'],
    "anugrāsakaḥ": ['ap90'],
    "anugu": ['mw'],
    "anugupta": ['ap90', 'cae', 'mw'],
    "anuguṇa": ['ap90', 'cae', 'mw'],
    "anuguṇam": ['mw'],
    "anuguṇatvaṃ": ['ap90'],
    "anuguṇaya": ['mw'],
    "anuguṇayati": ['ap90'],
    "anuguṇin": ['bhs'],
    "anuguṇya": ['bhs'],
    "anugā": ['mw'],
    "anugādin": ['ap90', 'mw'],
    "anugāh": ['mw'],
    "anugāmin": ['ap90', 'cae', 'mw'],
    "anugāmuka": ['ap90', 'mw'],
    "anugāna": ['mw'],
    "anugānaśas": ['mw'],
    "anugāpana": ['mw'],
    "anugāyas": ['gra', 'mw'],
    "anugāyati": ['cped'],
    "anugāḍha": ['mw'],
    "anugīta": ['bhs', 'cae', 'ddsa', 'mw'],
    "anugītaṃ": ['ap90'],
    "anugīti": ['ap90', 'cae', 'mw'],
    "anugītiḥ": ['ap90'],
    "anugītā": ['mw'],
    "anugīyati": ['cped'],
    "anugṛdh": ['mw'],
    "anugṛhīta": ['cae', 'mw'],
    "anugṝ": ['mw'],
    "anuha": ['mw'],
    "anuharamāṇa": ['mw'],
    "anuharat": ['mw'],
    "anuharaṇa": ['mw'],
    "anuharaṇaṃ": ['ap90'],
    "anuhava": ['mw'],
    "anuhavaḥ": ['ap90'],
    "anuhimavanta": ['bhs'],
    "anuhiṇḍate": ['bhs'],
    "anuhlāda": ['mw'],
    "anuhoma": ['mw'],
    "anuhoḍa": ['mw'],
    "anuhoḍaḥ": ['ap90'],
    "anuhrāda": ['mw'],
    "anuhurch": ['mw'],
    "anuhuṃkāraḥ": ['ap90'],
    "anuhuṃkṛ": ['ap90', 'mw'],
    "anuhve": ['mw'],
    "anuhā": ['mw'],
    "anuhāra": ['mw'],
    "anuhāraka": ['mw'],
    "anuhārya": ['ap90', 'mw'],
    "anuhīramāna": ['cped'],
    "anuhṛ": ['ap90', 'mw'],
    "anuja": ['ap90', 'cae', 'ddsa', 'mw'],
    "anujagghanta": ['cped'],
    "anujagghati": ['cped'],
    "anujalp": ['mw'],
    "anujan": ['ap90', 'mw'],
    "anujanam": ['mw'],
    "anujanman": ['ap90', 'mw'],
    "anujap": ['mw'],
    "anujava": ['bhs'],
    "anujavana": ['bhs'],
    "anujavati": ['bhs'],
    "anujaññā": ['cped'],
    "anuji": ['mw'],
    "anujighra": ['mw'],
    "anujighṛkṣā": ['mw'],
    "anujjhat": ['mw'],
    "anujjhita": ['mw'],
    "anujjuka": ['bhs', 'cped'],
    "anujuka": ['cped'],
    "anujuṣ": ['mw'],
    "anujyeṣṭha": ['ap90', 'mw'],
    "anujyeṣṭham": ['mw'],
    "anujñaiṣaṇā": ['mw'],
    "anujñapti": ['mw'],
    "anujñā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "anujñākṣepa": ['mw'],
    "anujñāna": ['mw'],
    "anujñāpaka": ['mw'],
    "anujñāpakaḥ": ['ap90'],
    "anujñāpana": ['mw'],
    "anujñāpanaṃ": ['ap90'],
    "anujñāprārthanā": ['mw'],
    "anujñāpya": ['mw'],
    "anujñāta": ['ap90', 'cae', 'mw'],
    "anujñātāvin": ['bhs'],
    "anujā": ['mw'],
    "anujāgṛ": ['mw'],
    "anujāneti": ['cped'],
    "anujāneyya": ['cped'],
    "anujānitabba": ['cped'],
    "anujānāti": ['cped'],
    "anujāsutā": ['mw'],
    "anujāta": ['cae', 'cped', 'mw'],
    "anujātā": ['mw'],
    "anujīrṇa": ['mw'],
    "anujīv": ['ap90', 'mw'],
    "anujīvi": ['cped'],
    "anujīvin": ['ap90', 'cae', 'cped', 'mw'],
    "anujīvisātkṛta": ['mw'],
    "anujīvita": ['cped'],
    "anujīvya": ['ap90', 'mw'],
    "anuka": ['ap90', 'mw'],
    "anukaccham": ['cae', 'ddsa', 'mw'],
    "anukalam": ['mw'],
    "anukalpa": ['cae', 'mw'],
    "anukalpaḥ": ['ap90'],
    "anukalpita": ['mw'],
    "anukam": ['mw'],
    "anukamp": ['mw'],
    "anukampa": ['bhs', 'cped'],
    "anukampaka": ['cae', 'cped', 'ddsa', 'mw'],
    "anukampamāna": ['cped'],
    "anukampana": ['cae', 'mw'],
    "anukampanta": ['cped'],
    "anukampanīya": ['cae', 'mw'],
    "anukampat": ['cped'],
    "anukampata": ['cped'],
    "anukampati": ['cped'],
    "anukampi": ['cped'],
    "anukampin": ['cae', 'cped', 'mw'],
    "anukampita": ['cped', 'mw'],
    "anukampitātman": ['mw'],
    "anukampokti": ['ddsa'],
    "anukampya": ['mw'],
    "anukampā": ['cped', 'ddsa', 'mw'],
    "anukampārtham": ['cae'],
    "anukampāyin": ['mw'],
    "anukanakhalam": ['ddsa', 'mw'],
    "anukantati": ['cped'],
    "anukanīyas": ['ap90', 'mw'],
    "anukapolam": ['mw'],
    "anukara": ['ap90', 'cae', 'ddsa', 'mw'],
    "anukaraṇa": ['cae', 'ddsa', 'mw'],
    "anukaraṇaṃ": ['ap90'],
    "anukarman": ['ap90', 'mw'],
    "anukaronti": ['cped'],
    "anukaroti": ['cped'],
    "anukartṛ": ['ap90', 'mw'],
    "anukarṣa": ['cae', 'ddsa', 'mw'],
    "anukarṣan": ['ap90', 'mw'],
    "anukarṣaḥ": ['ap90'],
    "anukarṣaṇa": ['mw'],
    "anukassāmi": ['cped'],
    "anukath": ['ap90', 'mw'],
    "anukathana": ['ddsa', 'mw'],
    "anukathanaṃ": ['ap90'],
    "anukathita": ['mw'],
    "anukaṃp": ['ap90'],
    "anukaṃpaka": ['ap90'],
    "anukaṃpana": ['ap90'],
    "anukaṃpin": ['ap90'],
    "anukaṃpita": ['ap90'],
    "anukaṃpya": ['ap90'],
    "anukaṃpā": ['ap90'],
    "anukaṇṭhī": ['mw'],
    "anukhaneti": ['bhs'],
    "anukhañja": ['mw'],
    "anukhyā": ['ap90', 'mw'],
    "anukhyāti": ['ddsa', 'mw'],
    "anukhyātiḥ": ['ap90'],
    "anukhyātṛ": ['ap90', 'mw'],
    "anukkama": ['cped'],
    "anukkamamāna": ['cped'],
    "anukkamat": ['cped'],
    "anukkamati": ['cped'],
    "anukkaṭṭhita": ['cped'],
    "anukkhepa": ['cped'],
    "anukkhipanta": ['cped'],
    "anukkhittaka": ['cped'],
    "anuklṛpti": ['ddsa'],
    "anukrakaca": ['ap90', 'mw'],
    "anukram": ['ap90', 'mw'],
    "anukrama": ['ap90', 'cae', 'ddsa', 'mw'],
    "anukramam": ['mw'],
    "anukramaṇa": ['cae', 'mw'],
    "anukramaṇaṃ": ['ap90'],
    "anukramaṇikā": ['mw'],
    "anukramaṇī": ['mw'],
    "anukrand": ['mw'],
    "anukraṃd": ['ap90'],
    "anukraṃdanaṃ": ['ap90'],
    "anukriyā": ['mw'],
    "anukrośa": ['cae', 'mw'],
    "anukrośaḥ": ['ap90'],
    "anukrośin": ['mw'],
    "anukrośākṣepa": ['mw'],
    "anukruś": ['ap90', 'mw'],
    "anukrānta": ['mw'],
    "anukrī": ['mw'],
    "anukrīḍ": ['mw'],
    "anukrīḥ": ['ap90'],
    "anukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "anuktanimitta": ['mw'],
    "anuktasiddhi": ['mw'],
    "anuktha": ['ap90', 'gra', 'mw'],
    "anukti": ['mw'],
    "anukubba": ['cped'],
    "anukubbanti": ['cped'],
    "anukubbat": ['cped'],
    "anukulayañña": ['cped'],
    "anukulaṁ": ['cped'],
    "anukulesu": ['cped'],
    "anukuñcita": ['mw'],
    "anukuṣ": ['mw'],
    "anukuṭṭaka": ['bhs'],
    "anukā": ['mw'],
    "anukāla": ['ap90', 'mw'],
    "anukālam": ['mw'],
    "anukāma": ['ap90', 'cae', 'gra', 'mw'],
    "anukāmakṛt": ['gra', 'mw'],
    "anukāmam": ['mw'],
    "anukāmin": ['mw'],
    "anukāmīna": ['ap90', 'mw'],
    "anukāra": ['cae', 'mw'],
    "anukāraḥ": ['ap90'],
    "anukārin": ['ap90', 'cae', 'mw'],
    "anukārya": ['ap90', 'mw'],
    "anukāṃkṣā": ['ap90'],
    "anukāṅkṣ": ['mw'],
    "anukāṅkṣin": ['cae', 'ddsa', 'mw'],
    "anukāṅkṣā": ['mw'],
    "anukīrt": ['mw'],
    "anukīrtana": ['cae', 'ddsa', 'mw'],
    "anukīrtanaṃ": ['ap90'],
    "anukīrṇa": ['mw'],
    "anukūj": ['mw'],
    "anukūla": ['ap90', 'cae', 'ddsa', 'mw'],
    "anukūlanāyaka": ['mw'],
    "anukūlatā": ['ap90', 'cae', 'mw'],
    "anukūlavāyu": ['mw'],
    "anukūlay": ['cae'],
    "anukūlaya": ['ddsa', 'mw'],
    "anukūlayajña": ['bhs'],
    "anukūlayati": ['ap90'],
    "anukūle": ['bhs'],
    "anukūlokta": ['ddsa'],
    "anukūlā": ['mw'],
    "anukḷp": ['ap90', 'mw'],
    "anukḷpti": ['mw'],
    "anukṛ": ['ap90', 'mw'],
    "anukṛp": ['mw'],
    "anukṛpāyate": ['ap90'],
    "anukṛt": ['mw'],
    "anukṛta": ['cae', 'mw'],
    "anukṛti": ['ddsa', 'mw'],
    "anukṛtya": ['mw'],
    "anukṛś": ['mw'],
    "anukṛṣ": ['ap90', 'mw'],
    "anukṛṣṭa": ['mw'],
    "anukṝ": ['mw'],
    "anukṣamati": ['bhs'],
    "anukṣapam": ['mw'],
    "anukṣar": ['mw'],
    "anukṣattṛ": ['ap90', 'mw'],
    "anukṣaṇam": ['cae', 'mw'],
    "anukṣaṇaṃ": ['ap90'],
    "anukṣetra": ['mw'],
    "anukṣetraṃ": ['ap90'],
    "anukṣi": ['mw'],
    "anulabh": ['mw'],
    "anulagna": ['ap90', 'cae', 'mw'],
    "anulagnati": ['bhs'],
    "anulakṣya": ['mw'],
    "anulamba": ['mw'],
    "anulbaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "anulepa": ['cae', 'ddsa', 'mw'],
    "anulepaka": ['ap90', 'mw'],
    "anulepana": ['mw'],
    "anulepaḥ": ['ap90'],
    "anulepikā": ['mw'],
    "anulepin": ['mw'],
    "anulip": ['ap90', 'mw'],
    "anulipta": ['mw'],
    "anuliptaka": ['bhs'],
    "anuliptāṅga": ['mw'],
    "anuliṅgin": ['bhs'],
    "anullapanā": ['cped'],
    "anullokita": ['bhs'],
    "anuloma": ['ap90', 'cae', 'cped', 'mw'],
    "anulomacaryā": ['bhs'],
    "anulomaja": ['mw'],
    "anulomakalpa": ['mw'],
    "anulomakṛṣṭa": ['mw'],
    "anulomalipi": ['bhs'],
    "anulomam": ['mw'],
    "anulomana": ['mw'],
    "anulomanatā": ['bhs'],
    "anulomanaṃ": ['ap90'],
    "anulomapariṇītā": ['mw'],
    "anulomapaṭilena": ['cped'],
    "anulomapaṭilomaṁ": ['cped'],
    "anulomapratiloma": ['bhs', 'mw'],
    "anulomapraṇidhāna": ['bhs'],
    "anulomaya": ['mw'],
    "anulomayati": ['ap90', 'cped'],
    "anulomaṁ": ['cped'],
    "anulometi": ['cped'],
    "anulomika": ['bhs', 'cped'],
    "anulomikī": ['mw'],
    "anulomā": ['mw'],
    "anulomārtha": ['mw'],
    "anulomāya": ['mw'],
    "anulubh": ['mw'],
    "anulvaṇa": ['ap90'],
    "anulā": ['mw'],
    "anulāpa": ['mw'],
    "anulāpaḥ": ['ap90'],
    "anulāsa": ['mw'],
    "anulāsaḥ": ['ap90'],
    "anulāsya": ['mw'],
    "anulī": ['mw'],
    "anulīna": ['ap90'],
    "anumad": ['ap90', 'mw'],
    "anumadhya": ['bhs'],
    "anumadhyama": ['mw'],
    "anumajjanta": ['cped'],
    "anumajjati": ['cped'],
    "anumajjhima": ['bhs'],
    "anumajjitvā": ['cped'],
    "anuman": ['ap90', 'mw'],
    "anumanana": ['mw'],
    "anumananaṃ": ['ap90'],
    "anumantavya": ['mw'],
    "anumantr": ['mw'],
    "anumantraṇa": ['mw'],
    "anumantraṇamantra": ['mw'],
    "anumantrita": ['mw'],
    "anumantṛ": ['cae', 'mw'],
    "anumanyamāna": ['mw'],
    "anumaraṇa": ['cae', 'mw'],
    "anumaraṇaṃ": ['ap90'],
    "anumariṣyat": ['mw'],
    "anumaru": ['mw'],
    "anumaruḥ": ['ap90'],
    "anumarśam": ['mw'],
    "anumasati": ['cped'],
    "anumasi": ['cped'],
    "anumassa": ['cped'],
    "anumata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "anumatakarmakārin": ['mw'],
    "anumatavajra": ['mw'],
    "anumate": ['mw'],
    "anumati": ['cae', 'gra', 'mw'],
    "anumatikappa": ['cped'],
    "anumatipakkha": ['cped'],
    "anumatipattra": ['mw'],
    "anumatiḥ": ['ap90'],
    "anumatta": ['ap90'],
    "anumaññati": ['cped'],
    "anumaṃtr": ['ap90'],
    "anumaṃtraṇaṃ": ['ap90'],
    "anumaṃtṛ": ['ap90'],
    "anumeya": ['ap90', 'mw'],
    "anumid": ['mw'],
    "anumimāna": ['mw'],
    "anuminitabba": ['cped'],
    "anumita": ['cae', 'mw'],
    "anumiti": ['mw'],
    "anumitiḥ": ['ap90'],
    "anumitsā": ['ap90'],
    "anumlocantī": ['mw'],
    "anumlocā": ['mw'],
    "anumluc": ['mw'],
    "anummattaka": ['cped'],
    "anumoda": ['mw'],
    "anumodaka": ['cped', 'mw'],
    "anumodamāna": ['cped'],
    "anumodana": ['cped', 'mw'],
    "anumodanaṃ": ['ap90'],
    "anumodaniya": ['cped'],
    "anumodanta": ['cped'],
    "anumodanā": ['bhs'],
    "anumodanī": ['bhs'],
    "anumodanīya": ['cped'],
    "anumodati": ['cped'],
    "anumodaḥ": ['ap90'],
    "anumodin": ['mw'],
    "anumodita": ['cped', 'mw'],
    "anumoditabba": ['cped'],
    "anumoditar": ['cped'],
    "anumoditvā": ['cped'],
    "anumodiṁsu": ['cped'],
    "anumroka": ['mw'],
    "anumud": ['ap90', 'mw'],
    "anumuh": ['mw'],
    "anumā": ['ap90', 'ddsa', 'mw'],
    "anumādia": ['gra'],
    "anumādya": ['ap90', 'cae', 'gra', 'mw'],
    "anumālinītīram": ['cae', 'mw'],
    "anumāna": ['cae', 'mw'],
    "anumānacintāmaṇi": ['mw'],
    "anumānakhaṇḍa": ['mw'],
    "anumānamaṇidīdhiti": ['mw'],
    "anumānaprakāśa": ['mw'],
    "anumānaṃ": ['ap90'],
    "anumānokti": ['mw'],
    "anumāpaka": ['ap90', 'mw'],
    "anumārg": ['mw'],
    "anumārga": ['bhs', 'mw'],
    "anumārgaṃ": ['ap90'],
    "anumārgāgata": ['mw'],
    "anumārjati": ['bhs'],
    "anumāsaḥ": ['ap90'],
    "anumāssa": ['cped'],
    "anumātṛ": ['ap90', 'mw'],
    "anumāṣam": ['mw'],
    "anumāṣaṃ": ['ap90'],
    "anumīyamāna": ['mw'],
    "anumīyati": ['cped'],
    "anumṛ": ['ap90', 'mw'],
    "anumṛgya": ['mw'],
    "anumṛgyadāśu": ['mw'],
    "anumṛj": ['mw'],
    "anumṛt": ['mw'],
    "anumṛtā": ['mw'],
    "anumṛś": ['mw'],
    "anunad": ['ap90', 'mw'],
    "anunadi": ['mw'],
    "anunadītīre": ['cped'],
    "anunam": ['mw'],
    "anunand": ['mw'],
    "anunaya": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "anunayagātra": ['bhs'],
    "anunayam": ['mw'],
    "anunayamāna": ['cped', 'mw'],
    "anunayapratighaprahāṇa": ['mw'],
    "anunayavigata": ['bhs'],
    "anunayin": ['ap90', 'mw'],
    "anunayāmantraṇa": ['mw'],
    "anunenta": ['cped'],
    "anuneta": ['cped'],
    "anunetar": ['cped'],
    "anuneya": ['ddsa', 'mw'],
    "anunidhānam": ['mw'],
    "anunikram": ['mw'],
    "anunikṣ": ['mw'],
    "anuninīṣu": ['mw'],
    "anuninīṣā": ['mw'],
    "anunipad": ['mw'],
    "anunirdah": ['mw'],
    "anunirdeśa": ['mw'],
    "anunirdeśaḥ": ['ap90'],
    "anunirjihāna": ['mw'],
    "anunirvap": ['mw'],
    "anunirvā": ['mw'],
    "anunirvāpaḥ": ['ap90'],
    "anunirvāpya": ['mw'],
    "anunirvāpyā": ['ap90', 'mw'],
    "anunitud": ['mw'],
    "anunivṛj": ['mw'],
    "anunivṛt": ['mw'],
    "anuniyuj": ['mw'],
    "anuniśam": ['ddsa', 'mw'],
    "anuniścara": ['bhs'],
    "anuniśītham": ['mw'],
    "anunmadita": ['ddsa', 'mw'],
    "anunmatta": ['ddsa', 'mw'],
    "anunmāda": ['ap90', 'mw'],
    "anunnahanatā": ['bhs'],
    "anunnala": ['cped'],
    "anunnamana": ['bhs'],
    "anunnata": ['ap90', 'bhs', 'cped', 'mw'],
    "anunnatagātra": ['mw'],
    "anunnatānata": ['mw'],
    "anunnaḍa": ['bhs'],
    "anunnaḷa": ['cped'],
    "anunnāmaninnāmi": ['cped'],
    "anunnāmininnāmi": ['cped'],
    "anunu": ['mw'],
    "anunāda": ['ddsa', 'mw'],
    "anunādaḥ": ['ap90'],
    "anunādin": ['ap90', 'mw'],
    "anunādita": ['mw'],
    "anunāma": ['bhs'],
    "anunāsika": ['ap90', 'cae', 'mw'],
    "anunāsikalopa": ['mw'],
    "anunāsikatva": ['mw'],
    "anunāsikopadha": ['mw'],
    "anunāsikādi": ['mw'],
    "anunāsikānta": ['mw'],
    "anunāthanā": ['bhs'],
    "anunāyaka": ['ap90', 'mw'],
    "anunāyika": ['ap90'],
    "anunāyikā": ['mw'],
    "anunī": ['ap90', 'mw'],
    "anunīta": ['mw'],
    "anunīti": ['ddsa', 'mw'],
    "anunītiḥ": ['ap90'],
    "anunīyate": ['bhs'],
    "anunīyatā": ['bhs'],
    "anunṛt": ['mw'],
    "anupa": ['ap90'],
    "anupabbajati": ['cped'],
    "anupabbajiṁsu": ['cped'],
    "anupabbajā": ['cped'],
    "anupabhogya": ['cae'],
    "anupabhujyamāna": ['mw'],
    "anupabhukta": ['mw'],
    "anupabādha": ['mw'],
    "anupac": ['mw'],
    "anupacarita": ['mw'],
    "anupacarya": ['ddsa'],
    "anupaccheda": ['bhs'],
    "anupacchedana": ['bhs'],
    "anupacchedanatā": ['bhs'],
    "anupacchinna": ['bhs', 'cped'],
    "anupacchinnālambha": ['bhs'],
    "anupacita": ['cped'],
    "anupad": ['ap90', 'mw'],
    "anupada": ['ap90', 'cped', 'mw'],
    "anupadajjeyya": ['cped'],
    "anupadajjeyyāsi": ['cped'],
    "anupadam": ['cae', 'ddsa', 'mw'],
    "anupadasta": ['mw'],
    "anupadasūtra": ['mw'],
    "anupadavī": ['ap90', 'mw'],
    "anupaddava": ['cped'],
    "anupadduta": ['cped'],
    "anupadeti": ['cped'],
    "anupadeṣṭavya": ['cae', 'ddsa', 'mw'],
    "anupadeṣṭṛ": ['mw'],
    "anupadha": ['mw'],
    "anupadhaḥ": ['ap90'],
    "anupadhi": ['ap90'],
    "anupadhika": ['cped'],
    "anupadhiśeṣa": ['bhs', 'mw'],
    "anupadhmāta": ['mw'],
    "anupadhīka": ['bhs'],
    "anupadika": ['ap90'],
    "anupadin": ['ap90', 'ddsa', 'mw'],
    "anupadiṣṭa": ['mw'],
    "anupadrutalipi": ['bhs'],
    "anupadīnā": ['ap90', 'mw'],
    "anupagacchati": ['cped'],
    "anupagamana": ['cped'],
    "anupagamanāman": ['bhs'],
    "anupagamma": ['cped'],
    "anupagantvā": ['cped'],
    "anupagata": ['cped'],
    "anupagatajara": ['mw'],
    "anupaghnant": ['cae'],
    "anupaghnat": ['ddsa', 'mw'],
    "anupaghāta": ['cped'],
    "anupaghātaḥ": ['ap90'],
    "anupaghātya": ['bhs'],
    "anupaghātārjita": ['mw'],
    "anupagīta": ['ap90'],
    "anupagītam": ['mw'],
    "anupagṛhīta": ['mw'],
    "anupahacca": ['cped'],
    "anupahata": ['ap90', 'cped', 'mw'],
    "anupahatakarṇendriyatā": ['mw'],
    "anupahatakruṣṭa": ['mw'],
    "anupahatamati": ['bhs'],
    "anupahita": ['cae', 'mw'],
    "anupahāra": ['cped'],
    "anupahūta": ['mw'],
    "anupahūyamāna": ['mw'],
    "anupajagghati": ['cped'],
    "anupajjhāyaka": ['cped'],
    "anupajīvanīya": ['ap90', 'mw'],
    "anupakampati": ['cped'],
    "anupakhajja": ['cped'],
    "anupakhajjana": ['cped'],
    "anupakhajjanta": ['cped'],
    "anupakiñca": ['mw'],
    "anupakkama": ['cped'],
    "anupakkhipitvā": ['cped'],
    "anupakkilesa": ['cped'],
    "anupakkuṭṭha": ['cped'],
    "anupakramya": ['cae', 'ddsa'],
    "anupakruṣṭa": ['bhs'],
    "anupakrāmya": ['cae'],
    "anupakuṭṭha": ['cped'],
    "anupakārin": ['ap90', 'cae', 'ddsa', 'mw'],
    "anupakṛta": ['mw'],
    "anupakṣita": ['ap90', 'gra', 'mw'],
    "anupalabbhamāna": ['cped'],
    "anupalabbhiyamāna": ['cped'],
    "anupalabdha": ['ap90', 'mw'],
    "anupalabdhi": ['bhs', 'cae', 'mw'],
    "anupalabdhika": ['bhs'],
    "anupalabdhisama": ['mw'],
    "anupalabdhiḥ": ['ap90'],
    "anupalabhyamāna": ['mw'],
    "anupalakkhaṇa": ['cped'],
    "anupalakṣita": ['mw'],
    "anupalakṣya": ['mw'],
    "anupalakṣyavartman": ['mw'],
    "anupalambha": ['bhs', 'mw'],
    "anupalambhana": ['mw'],
    "anupalaṃbhaḥ": ['ap90'],
    "anupalipta": ['bhs', 'mw'],
    "anupalitta": ['cped'],
    "anupalābha": ['mw'],
    "anupalāla": ['mw'],
    "anupalīḍha": ['mw'],
    "anupama": ['ap90', 'cae', 'cped', 'mw'],
    "anupamacitta": ['bhs'],
    "anupamamati": ['bhs', 'mw'],
    "anupamarakṣita": ['bhs'],
    "anupamardana": ['mw'],
    "anupamardanaṃ": ['ap90'],
    "anupameya": ['ap90', 'mw'],
    "anupamita": ['mw'],
    "anupamā": ['bhs', 'mw'],
    "anupanata": ['mw'],
    "anupanenta": ['cped'],
    "anupaneyya": ['cped'],
    "anupanisa": ['cped'],
    "anupanthake": ['bhs'],
    "anupanyasta": ['mw'],
    "anupanyāsa": ['mw'],
    "anupanyāsaḥ": ['ap90'],
    "anupanāha": ['bhs', 'cped', 'mw'],
    "anupanāhi": ['cped'],
    "anupanāhin": ['cped'],
    "anupanīta": ['cped'],
    "anupapanna": ['ap90', 'cae', 'cped', 'mw'],
    "anupaparikkha": ['cped'],
    "anupaparikkhat": ['cped'],
    "anupapatti": ['cae', 'ddsa', 'mw'],
    "anupapattiḥ": ['ap90'],
    "anupaplava": ['mw'],
    "anupapluta": ['mw'],
    "anupapādaka": ['mw'],
    "anupapīḷa": ['cped'],
    "anuparata": ['ap90', 'mw'],
    "anupare": ['mw'],
    "anuparicarati": ['bhs'],
    "anuparicāram": ['mw'],
    "anuparidhi": ['mw'],
    "anuparidhāva": ['cped'],
    "anuparidhāvat": ['cped'],
    "anuparidhāvati": ['cped'],
    "anuparigamma": ['cped'],
    "anuparigantuṁ": ['cped'],
    "anuparigantvā": ['cped'],
    "anuparigaṇikā": ['bhs'],
    "anuparigrah": ['mw'],
    "anuparigraha": ['bhs'],
    "anuparigrāhikayā": ['bhs'],
    "anuparigā": ['mw'],
    "anuparigṛhṇīte": ['bhs'],
    "anupariharati": ['cped'],
    "anuparihāram": ['mw'],
    "anuparikram": ['mw'],
    "anuparikramaṇa": ['mw'],
    "anuparikrāmam": ['mw'],
    "anuparikṝ": ['mw'],
    "anuparikṣipta": ['bhs'],
    "anuparimārjati": ['bhs'],
    "anuparimṛj": ['mw'],
    "anuparindanā": ['bhs'],
    "anuparindāmi": ['bhs'],
    "anupariplu": ['mw'],
    "anuparipālayati": ['bhs'],
    "anuparipāṭikayā": ['bhs'],
    "anuparipāṭikrama": ['mw'],
    "anuparisakkana": ['cped'],
    "anuparisakkati": ['cped'],
    "anuparisic": ['mw'],
    "anuparisru": ['mw'],
    "anuparivartana": ['bhs'],
    "anuparivartati": ['bhs'],
    "anuparivartin": ['bhs'],
    "anuparivatta": ['cped'],
    "anuparivattat": ['cped'],
    "anuparivattati": ['cped'],
    "anuparivattīyati": ['cped'],
    "anupariveṇiyam": ['cped'],
    "anuparivārayati": ['bhs'],
    "anuparivāreti": ['cped'],
    "anuparivārita": ['mw'],
    "anuparivṛt": ['mw'],
    "anuparivṛta": ['bhs'],
    "anupariyagā": ['cped'],
    "anupariyeti": ['cped'],
    "anupariyā": ['mw'],
    "anupariyāsi": ['cped'],
    "anupariyāti": ['cped'],
    "anupariyāya": ['cped'],
    "anupariyāyapatha": ['cped'],
    "anupariyāyati": ['cped'],
    "anupariśoṣita": ['bhs'],
    "anupariśrit": ['mw'],
    "anupariṇī": ['mw'],
    "anuparodha": ['cae', 'mw'],
    "anuparodhatas": ['mw'],
    "anuparvata": ['mw'],
    "anuparyavanaddha": ['bhs'],
    "anuparye": ['mw'],
    "anuparyukṣ": ['mw'],
    "anuparyādhā": ['mw'],
    "anuparyāgā": ['mw'],
    "anuparyāvṛt": ['mw'],
    "anuparābhū": ['mw'],
    "anuparāga": ['mw'],
    "anuparāgam": ['mw'],
    "anuparāmṛś": ['mw'],
    "anuparāpat": ['mw'],
    "anuparāsru": ['mw'],
    "anuparī": ['mw'],
    "anuparīndanā": ['bhs'],
    "anuparīndāmi": ['bhs'],
    "anuparītaka": ['bhs'],
    "anuparītta": ['bhs'],
    "anupasagga": ['cped'],
    "anupasampanna": ['cped'],
    "anupasanta": ['cped'],
    "anupasarga": ['cae', 'mw'],
    "anupasargaḥ": ['ap90'],
    "anupasaṃhārin": ['ap90'],
    "anupasaṃpanna": ['bhs'],
    "anupasaṅkanta": ['cped'],
    "anupasaṭṭha": ['cped'],
    "anupasecana": ['ap90', 'mw'],
    "anupaskāra": ['ap90'],
    "anupaskṛta": ['ap90', 'cae', 'mw'],
    "anupassagga": ['cped'],
    "anupassaka": ['cped'],
    "anupassati": ['cped'],
    "anupassaṭṭha": ['cped'],
    "anupassi": ['cped'],
    "anupassin": ['cped'],
    "anupasthita": ['ap90', 'bhs', 'mw'],
    "anupasthiti": ['mw'],
    "anupasthitiḥ": ['ap90'],
    "anupasthāna": ['mw'],
    "anupasthānaṃ": ['ap90'],
    "anupasthāpana": ['mw'],
    "anupasthāpanaṃ": ['ap90'],
    "anupasthāpayat": ['mw'],
    "anupasthāpita": ['ap90', 'mw'],
    "anupasthāyin": ['ap90', 'mw'],
    "anupastīrṇaśāyin": ['mw'],
    "anupat": ['ap90', 'mw'],
    "anupatana": ['mw'],
    "anupatanaṃ": ['ap90'],
    "anupatati": ['cped'],
    "anupatha": ['ap90', 'cae', 'gra', 'mw'],
    "anupatham": ['mw'],
    "anupati": ['mw'],
    "anupatita": ['cped', 'mw'],
    "anupatitvā": ['cped'],
    "anupatta": ['cped'],
    "anupatti": ['cped'],
    "anupat‍trikā": ['ddsa'],
    "anupavadita": ['cped'],
    "anupavadya": ['bhs'],
    "anupavajja": ['cped'],
    "anupavattayati": ['cped'],
    "anupavattesi": ['cped'],
    "anupavatteti": ['cped'],
    "anupavecchanta": ['cped'],
    "anupavecchati": ['cped'],
    "anupavecchi": ['cped'],
    "anupavisati": ['cped'],
    "anupavisitvā": ['cped'],
    "anupaviṭṭha": ['cped'],
    "anupavāda": ['cped'],
    "anupavādaka": ['cped'],
    "anupavādi": ['cped'],
    "anupavādin": ['cped'],
    "anupavītin": ['ap90', 'mw'],
    "anupaya": ['cped'],
    "anupayant": ['cae'],
    "anupayat": ['mw'],
    "anupayoga": ['ap90', 'mw'],
    "anupayogin": ['mw'],
    "anupayukta": ['ap90', 'cae', 'mw'],
    "anupaññatta": ['cped'],
    "anupaññatti": ['cped'],
    "anupaś": ['mw'],
    "anupaśaya": ['mw'],
    "anupaśayaḥ": ['ap90'],
    "anupaśya": ['ap90', 'mw'],
    "anupaśyanā": ['bhs'],
    "anupaśyin": ['bhs'],
    "anupaśānta": ['bhs', 'mw'],
    "anupaṭh": ['ap90', 'mw'],
    "anupaṭhita": ['ap90', 'mw'],
    "anupaṭhitin": ['ap90', 'mw'],
    "anupaṭṭhita": ['cped'],
    "anupekkhat": ['cped'],
    "anupekkhati": ['cped'],
    "anupekkhatt": ['cped'],
    "anupekkheti": ['cped'],
    "anupekkhi": ['cped'],
    "anupekkhin": ['cped'],
    "anupekkhita": ['cped'],
    "anupekṣaṇa": ['ddsa'],
    "anupeta": ['ap90', 'cae', 'ddsa', 'mw'],
    "anupetapūrva": ['cae'],
    "anupeti": ['cped'],
    "anupeya": ['cae', 'mw'],
    "anupeyamāna": ['mw'],
    "anupiś": ['mw'],
    "anupiṇḍam": ['mw'],
    "anupiṣ": ['mw'],
    "anuplava": ['bhs', 'mw'],
    "anuplavaḥ": ['ap90'],
    "anuplu": ['ap90', 'mw'],
    "anupopta": ['mw'],
    "anuposatha": ['cped'],
    "anuposathikaṁ": ['cped'],
    "anupoṣaṇa": ['mw'],
    "anuppadajjeyyāsi": ['cped'],
    "anuppadajjuṁ": ['cped'],
    "anuppadeti": ['cped'],
    "anuppadiyamāna": ['cped'],
    "anuppadāna": ['cped'],
    "anuppadāsi": ['cped'],
    "anuppadāta": ['cped'],
    "anuppadātabba": ['cped'],
    "anuppadātar": ['cped'],
    "anuppadātuṁ": ['cped'],
    "anuppajjamāna": ['cped'],
    "anuppakkhanda": ['cped'],
    "anuppakkhandati": ['cped'],
    "anuppanna": ['cped'],
    "anuppannapaññatti": ['cped'],
    "anuppatta": ['cped'],
    "anuppatta vayo": ['cped'],
    "anuppatti": ['cped'],
    "anuppavecchanta": ['cped'],
    "anuppavecchati": ['cped'],
    "anuppavisati": ['cped'],
    "anuppavisitvā": ['cped'],
    "anuppaviṭṭha": ['cped'],
    "anuppaññatta": ['cped'],
    "anuppaññatti": ['cped'],
    "anuppiya": ['cped'],
    "anuppiyabhāṇi": ['cped'],
    "anuppiyabhāṇin": ['cped'],
    "anuppiḷa": ['cped'],
    "anuppāda": ['cped'],
    "anuppādenta": ['cped'],
    "anuppādetvā": ['cped'],
    "anuprabadhnāti": ['bhs'],
    "anuprabandha": ['bhs'],
    "anuprabhā": ['mw'],
    "anuprabhūta": ['mw'],
    "anuprabhūṣ": ['mw'],
    "anuprach": ['mw'],
    "anupradadāti": ['bhs'],
    "anupradakṣiṇīkaroti": ['bhs'],
    "anupradarśita": ['bhs'],
    "anupradattaka": ['bhs'],
    "anupradhāv": ['mw'],
    "anupradhāvita": ['mw'],
    "anupradā": ['mw'],
    "anupradāna": ['bhs', 'mw'],
    "anupradānaṃ": ['ap90'],
    "anupradātṛ": ['mw'],
    "anupraharaṇa": ['mw'],
    "anuprahita": ['mw'],
    "anuprahāram": ['ddsa'],
    "anuprahṛ": ['mw'],
    "anuprahṛtabhājana": ['mw'],
    "anuprahṛtya": ['mw'],
    "anupraiṣa": ['mw'],
    "anuprajan": ['mw'],
    "anuprajñā": ['mw'],
    "anuprajñāna": ['mw'],
    "anuprajñānaṃ": ['ap90'],
    "anuprajñāpti": ['bhs'],
    "anuprakamp": ['mw'],
    "anupramuc": ['mw'],
    "anupramud": ['mw'],
    "anupramāṇa": ['cae', 'mw'],
    "anuprapad": ['mw'],
    "anuprapanna": ['mw'],
    "anuprapat": ['mw'],
    "anuprapattavya": ['ddsa', 'mw'],
    "anuprapā": ['mw'],
    "anuprapādam": ['mw'],
    "anuprapātam": ['mw'],
    "anuprapātaṃ": ['ap90'],
    "anuprapūra": ['bhs'],
    "anuprapūrayati": ['bhs'],
    "anupraroha": ['mw'],
    "anupraruh": ['mw'],
    "anuprasad": ['ap90', 'mw'],
    "anuprasakta": ['mw'],
    "anuprasakti": ['mw'],
    "anuprasaktiḥ": ['ap90'],
    "anuprasarati": ['bhs'],
    "anuprasarpaka": ['mw'],
    "anuprasarpin": ['mw'],
    "anuprasañj": ['mw'],
    "anupraskandati": ['bhs'],
    "anuprastha": ['ap90', 'mw'],
    "anuprasthā": ['mw'],
    "anuprastṛ": ['mw'],
    "anuprasādanaṃ": ['ap90'],
    "anuprasūta": ['mw'],
    "anuprasṛ": ['mw'],
    "anuprasṛp": ['mw'],
    "anuprasṛptin": ['mw'],
    "anuprath": ['mw'],
    "anupratidhā": ['mw'],
    "anupratikrāmam": ['mw'],
    "anupratipanna": ['bhs'],
    "anupratipādayate": ['bhs'],
    "anupratiṣṭha": ['bhs'],
    "anupratiṣṭhā": ['mw'],
    "anupravacana": ['cae', 'mw'],
    "anupravacanaṃ": ['ap90'],
    "anupravacanādi": ['mw'],
    "anupravacanīya": ['mw'],
    "anupravad": ['mw'],
    "anupravah": ['mw'],
    "anupravap": ['mw'],
    "anupravartaka": ['bhs'],
    "anupravartana": ['bhs', 'mw'],
    "anupravartayati": ['bhs'],
    "anupravartita": ['mw'],
    "anupraveśa": ['cae', 'mw'],
    "anupraveśaka": ['bhs'],
    "anupraveśana": ['mw'],
    "anupraveśanīya": ['mw'],
    "anupraveśaḥ": ['ap90'],
    "anupraviddhakarṇa": ['bhs'],
    "anupraviś": ['ap90', 'mw'],
    "anupraviśati": ['bhs'],
    "anupraviśya": ['mw'],
    "anupraviṣṭa": ['cae'],
    "anupravraj": ['mw'],
    "anupravrajana": ['bhs', 'mw'],
    "anupravrajati": ['bhs'],
    "anupravārita": ['bhs'],
    "anupravṛj": ['mw'],
    "anupravṛt": ['mw'],
    "anupravṛtta": ['mw'],
    "anupravṛtti": ['mw'],
    "anuprayacchati": ['bhs'],
    "anuprayam": ['mw'],
    "anuprayoga": ['mw'],
    "anuprayogaḥ": ['ap90'],
    "anuprayoktavya": ['mw'],
    "anuprayuj": ['ap90', 'mw'],
    "anuprayujyamāna": ['mw'],
    "anuprayā": ['mw'],
    "anupraśna": ['mw'],
    "anupraśnaḥ": ['ap90'],
    "anupraśuc": ['mw'],
    "anupraṇidheti": ['bhs'],
    "anupraṇidhi": ['bhs'],
    "anupraṇud": ['mw'],
    "anupraṣṭṛ": ['mw'],
    "anupre": ['mw'],
    "anuprekṣ": ['mw'],
    "anuprekṣaṇa": ['bhs'],
    "anuprekṣin": ['bhs'],
    "anupreṣ": ['mw'],
    "anupreṣaṇa": ['mw'],
    "anupriya": ['mw'],
    "anuproh": ['mw'],
    "anuprākāram": ['bhs'],
    "anuprāp": ['ap90', 'mw'],
    "anuprāpaṇa": ['bhs'],
    "anuprāpta": ['ap90', 'mw'],
    "anuprāptiḥ": ['ap90'],
    "anuprāpunati": ['bhs'],
    "anuprārthayate": ['bhs'],
    "anuprās": ['mw'],
    "anuprāsa": ['cae', 'mw'],
    "anuprāsaḥ": ['ap90'],
    "anuprāṇ": ['ap90', 'mw'],
    "anuprāṇanaṃ": ['ap90'],
    "anupta": ['ap90', 'mw'],
    "anuptasasya": ['mw'],
    "anuptrima": ['ap90', 'mw'],
    "anupubbakiriyā": ['cped'],
    "anupubbakāraṇa": ['cped'],
    "anupubbanirodha": ['cped'],
    "anupubbapaṭipadā": ['cped'],
    "anupubbasikkhā": ['cped'],
    "anupubbaso": ['cped'],
    "anupubbavihāra": ['cped'],
    "anupubbavihāri": ['cped'],
    "anupubbavihārin": ['cped'],
    "anupubbaṁ": ['cped'],
    "anupubbena": ['cped'],
    "anupucchamāna": ['cped'],
    "anupuruṣa": ['mw'],
    "anupuruṣaḥ": ['ap90'],
    "anupuṣ": ['mw'],
    "anupuṣpa": ['mw'],
    "anupuṣpaḥ": ['ap90'],
    "anupuṭṭha": ['cped'],
    "anupā": ['ap90', 'mw'],
    "anupāde": ['mw'],
    "anupādhirāmaṇīya": ['mw'],
    "anupādinna": ['cped'],
    "anupādisesa": ['cped'],
    "anupādiya": ['cped'],
    "anupādiyamāna": ['cped'],
    "anupādiyat": ['cped'],
    "anupādiṇṇa": ['cped'],
    "anupādā": ['bhs', 'cped'],
    "anupādāna": ['bhs', 'cped', 'mw'],
    "anupādāya": ['bhs', 'cped'],
    "anupāhanā": ['cped'],
    "anupāhāra": ['cped'],
    "anupākhya": ['ap90', 'mw'],
    "anupākruṣṭa": ['mw'],
    "anupākṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "anupākṛtamāṃsa": ['mw'],
    "anupāl": ['mw'],
    "anupālabhya": ['ddsa'],
    "anupālaka": ['ddsa'],
    "anupālana": ['mw'],
    "anupālanaṃ": ['ap90'],
    "anupālanā": ['bhs'],
    "anupālayat": ['mw'],
    "anupālin": ['cae', 'ddsa', 'mw'],
    "anupālu": ['mw'],
    "anupālya": ['mw'],
    "anupāna": ['mw'],
    "anupānapaṭṭaka": ['bhs'],
    "anupānatka": ['mw'],
    "anupānaṃ": ['ap90'],
    "anupānīya": ['ap90', 'mw'],
    "anupāpuṇitvā": ['cped'],
    "anupāpuṇāti": ['cped'],
    "anupārata": ['ddsa'],
    "anupārśva": ['ap90', 'bhs', 'mw'],
    "anupāsana": ['mw'],
    "anupāsikā": ['cped'],
    "anupāsita": ['cped', 'mw'],
    "anupāta": ['ap90', 'bhs', 'ddsa', 'mw'],
    "anupātaka": ['mw'],
    "anupātakaṃ": ['ap90'],
    "anupātam": ['mw'],
    "anupāti": ['cped'],
    "anupātin": ['ap90', 'cped', 'mw'],
    "anupātta": ['mw'],
    "anupāvṛtta": ['ap90', 'mw'],
    "anupāya": ['cped', 'mw'],
    "anupāyin": ['mw'],
    "anupāyāsa": ['bhs', 'cped'],
    "anupāṭa": ['bhs', 'mw'],
    "anupāṭana": ['bhs'],
    "anupīḍana": ['bhs'],
    "anupīḍin": ['bhs'],
    "anupū": ['mw'],
    "anupūraṇa": ['mw'],
    "anupūrva": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "anupūrvadaṃṣṭra": ['mw'],
    "anupūrvadaṃṣṭratā": ['mw'],
    "anupūrvagātra": ['mw'],
    "anupūrvagātratā": ['mw'],
    "anupūrvaja": ['mw'],
    "anupūrvaka": ['bhs'],
    "anupūrvakeśa": ['mw'],
    "anupūrvam": ['mw'],
    "anupūrvanābhi": ['mw'],
    "anupūrvapāṇilekha": ['mw'],
    "anupūrvasamudgataparivarta": ['bhs'],
    "anupūrvasamāpatti": ['bhs'],
    "anupūrvavatsā": ['mw'],
    "anupūrvavihārasamāpatti": ['bhs'],
    "anupūrvaśas": ['bhs', 'mw'],
    "anupūrvaśaḥ": ['ap90'],
    "anupūrvaṃ": ['bhs'],
    "anupūrveṇa": ['bhs', 'mw'],
    "anupūrvia": ['gra'],
    "anupūrvya": ['ap90', 'mw'],
    "anupūrvāṅgulitā": ['mw'],
    "anupūrvī": ['bhs'],
    "anupūrvīya": ['bhs'],
    "anupṛkta": ['cae', 'mw'],
    "anupṛṣṭhya": ['ap90', 'mw'],
    "anupṝ": ['mw'],
    "anuracita": ['bhs'],
    "anuracitagandhagarbha": ['bhs'],
    "anurahasa": ['ap90'],
    "anurahasam": ['mw'],
    "anuraho": ['cped'],
    "anurajju": ['mw'],
    "anurakkha": ['cped'],
    "anurakkhana": ['cped'],
    "anurakkhanta": ['cped'],
    "anurakkhat": ['cped'],
    "anurakkhati": ['cped'],
    "anurakkhaṇa": ['cped'],
    "anurakkhissāmi": ['cped'],
    "anurakkhitabba": ['cped'],
    "anurakkhā": ['cped'],
    "anurakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "anuraktaloka": ['mw'],
    "anuraktapraja": ['mw'],
    "anuraktarāṣṭra": ['bhs'],
    "anurakti": ['mw'],
    "anuraktiḥ": ['ap90'],
    "anurakṣ": ['mw'],
    "anurakṣaṇa": ['mw'],
    "anurakṣaṇatā": ['bhs'],
    "anurakṣaṇā": ['bhs'],
    "anurakṣā": ['bhs'],
    "anuram": ['mw'],
    "anuras": ['mw'],
    "anurasa": ['mw'],
    "anurasaḥ": ['ap90'],
    "anurasita": ['ap90', 'cae', 'mw'],
    "anurata": ['cae', 'mw'],
    "anuratha": ['mw'],
    "anuratham": ['mw'],
    "anurathyā": ['ap90', 'mw'],
    "anurati": ['mw'],
    "anuratiḥ": ['ap90'],
    "anuratta": ['cped'],
    "anuravaṇa": ['bhs'],
    "anuravita": ['bhs'],
    "anurañj": ['mw'],
    "anurañjaka": ['mw'],
    "anurañjana": ['mw'],
    "anurañjita": ['mw'],
    "anuraṃj": ['ap90'],
    "anuraṃjaka": ['ap90'],
    "anuraṃjanaṃ": ['ap90'],
    "anuraṃjita": ['ap90'],
    "anuraṇana": ['mw'],
    "anuraṇanaṃ": ['ap90'],
    "anuraṇati": ['bhs'],
    "anurevatī": ['mw'],
    "anuric": ['mw'],
    "anuriṣ": ['mw'],
    "anurodanaṃ": ['ap90'],
    "anurodha": ['cae', 'cped', 'mw'],
    "anurodhana": ['mw'],
    "anurodhavirodha": ['bhs', 'cped'],
    "anurodhaḥ": ['ap90'],
    "anurodhin": ['ap90', 'cae', 'mw'],
    "anurodhitā": ['mw'],
    "anurodhāpratirodha": ['bhs'],
    "anuroha": ['mw'],
    "anuru": ['mw'],
    "anuruc": ['mw'],
    "anurud": ['ap90', 'mw'],
    "anuruddha": ['bhs', 'cped', 'mw'],
    "anuruddhapaṭiviruddha": ['cped'],
    "anurudh": ['ap90', 'mw'],
    "anuruh": ['mw'],
    "anuruhā": ['mw'],
    "anurujjhati": ['cped'],
    "anuruta": ['mw'],
    "anurāddha": ['mw'],
    "anurādh": ['mw'],
    "anurādha": ['ap90', 'mw'],
    "anurādhagrāma": ['mw'],
    "anurādhapura": ['mw'],
    "anurādhā": ['mw'],
    "anurāga": ['ap90', 'cae', 'mw'],
    "anurāgataṃ": ['bhs'],
    "anurāgavat": ['mw'],
    "anurāgaṇa": ['bhs'],
    "anurāgeṅgita": ['mw'],
    "anurāgin": ['ap90', 'cae', 'mw'],
    "anurāgitā": ['mw'],
    "anurāgiṇī": ['mw'],
    "anurāj": ['mw'],
    "anurātra": ['ap90'],
    "anurātram": ['mw'],
    "anurāśi": ['bhs'],
    "anurī": ['mw'],
    "anurūpa": ['ap90', 'cae', 'ddsa', 'mw'],
    "anurūpaceṣṭa": ['mw'],
    "anurūpagātra": ['bhs'],
    "anurūpam": ['mw'],
    "anurūpasvara": ['bhs'],
    "anurūpatas": ['mw'],
    "anurūpataḥ": ['ap90'],
    "anurūpe": ['bhs'],
    "anurūpeṇa": ['mw'],
    "anurūpikā": ['cped'],
    "anusahita": ['bhs'],
    "anusahāya": ['bhs'],
    "anusainya": ['mw'],
    "anusainyaṃ": ['ap90'],
    "anusajjhāyati": ['cped'],
    "anusaktham": ['mw'],
    "anusakya": ['bhs'],
    "anusamas": ['mw'],
    "anusamaya": ['mw'],
    "anusamayaḥ": ['ap90'],
    "anusamaś": ['mw'],
    "anusambaddha": ['mw'],
    "anusambhid": ['mw'],
    "anusambhū": ['mw'],
    "anusami": ['ap90', 'mw'],
    "anusamman": ['mw'],
    "anusampavaṅkatā": ['cped'],
    "anusamprayā": ['mw'],
    "anusamprāp": ['mw'],
    "anusamprāpta": ['mw'],
    "anusamudram": ['mw'],
    "anusamācar": ['mw'],
    "anusamādhā": ['mw'],
    "anusamāhāraḥ": ['ap90'],
    "anusamāhṛ": ['mw'],
    "anusamāp": ['mw'],
    "anusamāpana": ['mw'],
    "anusamāpanaṃ": ['ap90'],
    "anusamārabh": ['mw'],
    "anusamāruh": ['mw'],
    "anusamīkṣ": ['mw'],
    "anusandahati": ['cped'],
    "anusandati": ['cped'],
    "anusandeti": ['cped'],
    "anusandhati": ['cped'],
    "anusandhyam": ['mw'],
    "anusantata": ['cped'],
    "anusantatavutti": ['cped'],
    "anusantati": ['ddsa'],
    "anusara": ['cae', 'ddsa', 'mw'],
    "anusarati": ['cped'],
    "anusaraḥ": ['ap90'],
    "anusaraṇa": ['cae', 'mw'],
    "anusaraṇaṃ": ['ap90'],
    "anusarga": ['mw'],
    "anusarpa": ['mw'],
    "anusarpaḥ": ['ap90'],
    "anusarpaṇa": ['mw'],
    "anusartavya": ['mw'],
    "anusartṛ": ['mw'],
    "anusati": ['cped'],
    "anusavanam": ['mw'],
    "anusavanaṃ": ['ap90'],
    "anusavati": ['cped'],
    "anusaya": ['cped'],
    "anusayi": ['cped'],
    "anusayin": ['cped'],
    "anusayita": ['cped'],
    "anusañcaranta": ['cped'],
    "anusañcarati": ['cped'],
    "anusaññāyati": ['cped'],
    "anusaññāyatuṁ": ['cped'],
    "anusaṁsāvetvā": ['cped'],
    "anusaṁvaccharaṁ": ['cped'],
    "anusaṁyāyamāna": ['cped'],
    "anusaṁyāyati": ['cped'],
    "anusaṁyāyitvā": ['cped'],
    "anusaṃbaddha": ['ap90'],
    "anusaṃbandha": ['bhs'],
    "anusaṃbuddha": ['bhs'],
    "anusaṃcar": ['ap90', 'mw'],
    "anusaṃcara": ['cae', 'mw'],
    "anusaṃcaraṇaṃ": ['ap90'],
    "anusaṃcint": ['mw'],
    "anusaṃdah": ['mw'],
    "anusaṃdheya": ['mw'],
    "anusaṃdhi": ['bhs', 'mw'],
    "anusaṃdhyam": ['cae'],
    "anusaṃdhā": ['ap90', 'mw'],
    "anusaṃdhāna": ['cae', 'mw'],
    "anusaṃdhānaṃ": ['ap90'],
    "anusaṃdhānin": ['ap90', 'mw'],
    "anusaṃdhānīya": ['mw'],
    "anusaṃdhātavya": ['mw'],
    "anusaṃdhāyin": ['mw'],
    "anusaṃdiś": ['mw'],
    "anusaṃdṛś": ['mw'],
    "anusaṃgrah": ['mw'],
    "anusaṃhita": ['ap90'],
    "anusaṃhitam": ['mw'],
    "anusaṃhṛ": ['mw'],
    "anusaṃjvar": ['mw'],
    "anusaṃjñapti": ['bhs', 'mw'],
    "anusaṃkal": ['mw'],
    "anusaṃkhyā": ['mw'],
    "anusaṃkram": ['mw'],
    "anusaṃrabh": ['mw'],
    "anusaṃrakta": ['mw'],
    "anusaṃsarpam": ['mw'],
    "anusaṃsmṛ": ['mw'],
    "anusaṃspṛś": ['mw'],
    "anusaṃsthita": ['cae', 'mw'],
    "anusaṃsthā": ['mw'],
    "anusaṃsyand": ['mw'],
    "anusaṃsārya": ['bhs'],
    "anusaṃsīdati": ['bhs'],
    "anusaṃsṛ": ['mw'],
    "anusaṃsṛp": ['mw'],
    "anusaṃsṛṣṭa": ['mw'],
    "anusaṃtan": ['ap90', 'mw'],
    "anusaṃtati": ['mw'],
    "anusaṃtatiḥ": ['ap90'],
    "anusaṃtāna": ['mw'],
    "anusaṃtṝ": ['mw'],
    "anusaṃvah": ['mw'],
    "anusaṃvaraṇaṃ": ['ap90'],
    "anusaṃvarṇ": ['mw'],
    "anusaṃvarṇayati": ['bhs'],
    "anusaṃvatsaram": ['mw'],
    "anusaṃvicar": ['mw'],
    "anusaṃvid": ['mw'],
    "anusaṃviś": ['mw'],
    "anusaṃvraj": ['mw'],
    "anusaṃvā": ['mw'],
    "anusaṃvīta": ['mw'],
    "anusaṃvṛjin": ['mw'],
    "anusaṃvṛjina": ['mw'],
    "anusaṃyā": ['mw'],
    "anusaṃśaya": ['bhs'],
    "anuseti": ['cped'],
    "anusev": ['mw'],
    "anusevin": ['ap90', 'mw'],
    "anusevā": ['cae'],
    "anusic": ['mw'],
    "anusiddha": ['mw'],
    "anusikkha": ['cped'],
    "anusikkhamāna": ['cped'],
    "anusikkhanta": ['cped'],
    "anusikkhat": ['cped'],
    "anusikkhati": ['cped'],
    "anusikkhi": ['cped'],
    "anusikkhin": ['cped'],
    "anusiṭṭha": ['cped'],
    "anusiṭṭhi": ['cped'],
    "anuskandam": ['mw'],
    "anuskaṃdaṃ": ['ap90'],
    "anusmaraṇa": ['mw'],
    "anusmaraṇaṃ": ['ap90'],
    "anusmṛ": ['ap90', 'mw'],
    "anusmṛta": ['cae', 'mw'],
    "anusmṛti": ['bhs', 'mw'],
    "anusmṛtiḥ": ['ap90'],
    "anusneham": ['mw'],
    "anusnehaṃ": ['ap90'],
    "anusocana": ['cped'],
    "anusocati": ['cped'],
    "anusomam": ['mw'],
    "anusotagāmi": ['cped'],
    "anusotagāmin": ['cped'],
    "anusotapaṭisotaṁ": ['cped'],
    "anusotaṁ": ['cped'],
    "anuspandyam": ['mw'],
    "anuspaṣṭa": ['ap90', 'cae', 'mw'],
    "anusphur": ['mw'],
    "anusphura": ['ap90', 'gra', 'mw'],
    "anuspṛś": ['mw'],
    "anusrayāman": ['gra', 'mw'],
    "anusrotasa": ['mw'],
    "anussada": ['cped'],
    "anussadaka": ['cped'],
    "anussara": ['cped'],
    "anussaramāna": ['cped'],
    "anussaranta": ['cped'],
    "anussarat": ['cped'],
    "anussarati": ['cped'],
    "anussaraṁ": ['cped'],
    "anussaraṇa": ['cped'],
    "anussaraṇaka": ['cped'],
    "anussarita": ['cped'],
    "anussaritabba": ['cped'],
    "anussaritar": ['cped'],
    "anussati": ['cped'],
    "anussatiṭṭhāna": ['cped'],
    "anussatānuttariya": ['cped'],
    "anussava": ['cped'],
    "anussavappasanna": ['cped'],
    "anussavasacca": ['cped'],
    "anussavati": ['cped'],
    "anussaṅki": ['cped'],
    "anussaṅkin": ['cped'],
    "anussita": ['cped'],
    "anussuka": ['cped'],
    "anussuta": ['cped'],
    "anussādetvā": ['cped'],
    "anussāha": ['cped'],
    "anussāvaka": ['cped'],
    "anussāvana": ['cped'],
    "anussāvayati": ['cped'],
    "anussāvesi": ['cped'],
    "anussāvesuṁ": ['cped'],
    "anussāveti": ['cped'],
    "anussāvita": ['cped'],
    "anussāviyamāna": ['cped'],
    "anustanayati": ['bhs'],
    "anustanita": ['mw'],
    "anustaraṇa": ['mw'],
    "anustaraṇaṃ": ['ap90'],
    "anustaraṇī": ['ddsa', 'mw'],
    "anustotra": ['mw'],
    "anustotraṃ": ['ap90'],
    "anusukham": ['bhs'],
    "anusuyyaka": ['cped'],
    "anusuyyāyamāna": ['cped'],
    "anusvan": ['mw'],
    "anusvāna": ['mw'],
    "anusvānaḥ": ['ap90'],
    "anusvāra": ['cae', 'mw'],
    "anusvāravat": ['mw'],
    "anusvāravyavāya": ['mw'],
    "anusvāraḥ": ['ap90'],
    "anusvārāgama": ['mw'],
    "anusyūta": ['ap90', 'cae', 'mw'],
    "anusyūti": ['bhs'],
    "anusādhaka": ['bhs'],
    "anusādhi": ['bhs'],
    "anusāma": ['ap90', 'mw'],
    "anusānu": ['mw'],
    "anusāra": ['cae', 'mw'],
    "anusāraka": ['ap90', 'mw'],
    "anusāratas": ['mw'],
    "anusārataḥ": ['ap90'],
    "anusārayati": ['bhs'],
    "anusāraḥ": ['ap90'],
    "anusāraṇā": ['ap90'],
    "anusāreṇa": ['mw'],
    "anusārin": ['cae', 'mw'],
    "anusāryaka": ['mw'],
    "anusāryakaṃ": ['ap90'],
    "anusārī": ['cped'],
    "anusāsa": ['cped'],
    "anusāsaka": ['cped'],
    "anusāsana": ['cped'],
    "anusāsanī": ['cped'],
    "anusāsanīpāṭiharīya": ['cped'],
    "anusāsanīya": ['cped'],
    "anusāsat": ['cped'],
    "anusāsati": ['cped'],
    "anusāsayiṁ": ['cped'],
    "anusāsi": ['cped'],
    "anusāsikā": ['cped'],
    "anusāsita": ['cped'],
    "anusāsitabba": ['cped'],
    "anusāsitvā": ['cped'],
    "anusāsiya": ['cped'],
    "anusāsiyamāna": ['cped'],
    "anusātam": ['mw'],
    "anusāvana": ['cped'],
    "anusāveti": ['cped'],
    "anusāyam": ['mw'],
    "anusāyaṃ": ['ap90'],
    "anusāyika": ['cped'],
    "anusīram": ['mw'],
    "anusītam": ['mw'],
    "anusīvana": ['bhs'],
    "anusū": ['mw'],
    "anusūcaka": ['ap90', 'mw'],
    "anusūcana": ['mw'],
    "anusūcanaṃ": ['ap90'],
    "anusūpam": ['mw'],
    "anusūyaka": ['cped'],
    "anusūyāyamāna": ['cped'],
    "anusṛ": ['ap90', 'mw'],
    "anusṛj": ['mw'],
    "anusṛp": ['ap90', 'mw'],
    "anusṛta": ['cae', 'mw'],
    "anusṛtavatsā": ['mw'],
    "anusṛti": ['mw'],
    "anusṛtiḥ": ['ap90'],
    "anusṛtya": ['cae'],
    "anusṛṣṭa": ['ap90', 'mw'],
    "anusṛṣṭiḥ": ['ap90'],
    "anutakṣ": ['mw'],
    "anutamām": ['mw'],
    "anutan": ['mw'],
    "anutap": ['ap90', 'mw'],
    "anutappa": ['cped'],
    "anutappati": ['cped'],
    "anutappissati": ['cped'],
    "anutapta": ['ap90', 'mw'],
    "anutaptā": ['mw'],
    "anutapyana": ['bhs'],
    "anutapyanīya": ['bhs'],
    "anutara": ['ap90', 'mw'],
    "anutaraṃ": ['ap90'],
    "anutark": ['mw'],
    "anutarṣa": ['bhs', 'mw'],
    "anutarṣaḥ": ['ap90'],
    "anutarṣaṇa": ['mw'],
    "anutarṣaṇaṃ": ['ap90'],
    "anutarṣula": ['mw'],
    "anutaṭa": ['bhs', 'cae', 'ddsa'],
    "anutaṭam": ['cae', 'mw'],
    "anutila": ['ap90'],
    "anutilam": ['mw'],
    "anutiṣṭhamāna": ['mw'],
    "anutiṣṭhāsu": ['mw'],
    "anutiṭṭha": ['cped'],
    "anutka": ['ap90', 'mw'],
    "anutkarṣa": ['mw'],
    "anutkarṣaṇatā": ['bhs'],
    "anutkhāta": ['cae'],
    "anutkīrṇa": ['ddsa'],
    "anutoda": ['mw'],
    "anutpanna": ['ap90', 'mw'],
    "anutpatti": ['cae', 'mw'],
    "anutpattikadharmakṣānti": ['bhs', 'mw'],
    "anutpattisama": ['mw'],
    "anutpattiḥ": ['ap90'],
    "anutpāda": ['bhs', 'mw'],
    "anutpādakṣānti": ['mw'],
    "anutpādana": ['mw'],
    "anutpādaḥ": ['ap90'],
    "anutpādya": ['cae', 'mw'],
    "anutpūta": ['mw'],
    "anutrasta": ['cped'],
    "anutraṣṭa": ['bhs'],
    "anutrāsa": ['cped'],
    "anutsada": ['bhs'],
    "anutsanna": ['bhs', 'mw'],
    "anutseka": ['cae', 'mw'],
    "anutsekaḥ": ['ap90'],
    "anutsekin": ['ap90', 'mw'],
    "anutsikta": ['mw'],
    "anutsuka": ['ap90', 'cae', 'mw'],
    "anutsukatā": ['mw'],
    "anutsāha": ['ap90', 'mw'],
    "anutsāhatā": ['mw'],
    "anutsūtra": ['ap90', 'mw'],
    "anutsṛjanatā": ['bhs'],
    "anutsṛṣṭa": ['mw'],
    "anutta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anuttama": ['ap90', 'cae', 'ddsa', 'mw'],
    "anuttamanya": ['mw'],
    "anuttamanyu": ['gra'],
    "anuttamāmbhas": ['mw'],
    "anuttamāmbhasika": ['mw'],
    "anuttara": ['ap90', 'bhs', 'cped', 'mw'],
    "anuttarapūjā": ['mw'],
    "anuttararāja": ['bhs'],
    "anuttarayogatantra": ['mw'],
    "anuttaraśrī": ['bhs'],
    "anuttaraṃga": ['ap90', 'mw'],
    "anuttarika": ['bhs'],
    "anuttariya": ['cped'],
    "anuttaropapātika": ['mw'],
    "anuttaropapātikadaśā": ['mw'],
    "anuttarya": ['bhs'],
    "anuttarāyo": ['bhs'],
    "anutthavati": ['cped'],
    "anutthita": ['mw'],
    "anutthuna": ['cped'],
    "anutthunanta": ['cped'],
    "anutthunat": ['cped'],
    "anutthunāti": ['cped'],
    "anutthuṇāti": ['cped'],
    "anutthāna": ['mw'],
    "anutthānaṃ": ['ap90'],
    "anuttiṇṇa": ['cped'],
    "anuttrāsa": ['bhs'],
    "anuttrāsita": ['bhs'],
    "anuttuṇḍita": ['mw'],
    "anuttāna": ['mw'],
    "anuttānīkata": ['cped'],
    "anutunna": ['ap90', 'mw'],
    "anutunī": ['cped'],
    "anutāpa": ['cae', 'mw'],
    "anutāpaka": ['mw'],
    "anutāpana": ['ap90', 'mw'],
    "anutāpaḥ": ['ap90'],
    "anutāpi": ['cped'],
    "anutāpin": ['ap90', 'cped', 'mw'],
    "anutāpya": ['bhs'],
    "anutāpāṅka": ['mw'],
    "anutīre": ['cped'],
    "anutūlanaṃ": ['ap90'],
    "anutūlaya": ['mw'],
    "anutūlayati": ['ap90'],
    "anutṛd": ['mw'],
    "anutṛp": ['mw'],
    "anutṝ": ['ap90', 'mw'],
    "anuvac": ['ap90', 'mw'],
    "anuvacana": ['cae', 'mw'],
    "anuvacanaṃ": ['ap90'],
    "anuvacanīya": ['mw'],
    "anuvad": ['ap90', 'mw'],
    "anuvadamāna": ['cped'],
    "anuvadanā": ['cped'],
    "anuvadati": ['cped'],
    "anuvah": ['mw'],
    "anuvaha": ['mw'],
    "anuvahaḥ": ['ap90'],
    "anuvaineya": ['bhs', 'mw'],
    "anuvajja": ['cped'],
    "anuvakra": ['ap90', 'mw'],
    "anuvakraga": ['mw'],
    "anuvaktavya": ['mw'],
    "anuvaktṛ": ['ap90', 'mw'],
    "anuvanam": ['mw'],
    "anuvanāntam": ['mw'],
    "anuvap": ['mw'],
    "anuvapram": ['mw'],
    "anuvarga": ['bhs'],
    "anuvartaka": ['bhs'],
    "anuvartana": ['ap90', 'cae', 'mw'],
    "anuvartanatā": ['bhs'],
    "anuvartanaṃ": ['ap90'],
    "anuvartanā": ['bhs'],
    "anuvartanīya": ['mw'],
    "anuvartin": ['ap90', 'cae', 'mw'],
    "anuvartita": ['bhs'],
    "anuvartitva": ['mw'],
    "anuvartitā": ['mw'],
    "anuvartitṛ": ['mw'],
    "anuvartman": ['ap90', 'mw'],
    "anuvartya": ['mw'],
    "anuvarṇ": ['mw'],
    "anuvarṣa": ['bhs'],
    "anuvas": ['ap90', 'mw'],
    "anuvasati": ['cped'],
    "anuvasita": ['ap90', 'mw'],
    "anuvasitvā": ['cped'],
    "anuvassaṁ": ['cped'],
    "anuvassika": ['cped'],
    "anuvatsara": ['mw'],
    "anuvatsaram": ['mw'],
    "anuvatsaraḥ": ['ap90'],
    "anuvatsarīya": ['mw'],
    "anuvatsarīṇa": ['mw'],
    "anuvattaka": ['cped'],
    "anuvattati": ['cped'],
    "anuvattayati": ['cped'],
    "anuvatteti": ['cped'],
    "anuvatti": ['cped'],
    "anuvattitabbal": ['cped'],
    "anuvattiya": ['cped'],
    "anuvattāpana": ['cped'],
    "anuvaśa": ['ap90', 'cae', 'mw'],
    "anuvaṃśa": ['cae', 'ddsa', 'mw'],
    "anuvaṃśam": ['mw'],
    "anuvaṃśaśloka": ['mw'],
    "anuvaṃśaḥ": ['ap90'],
    "anuvaṃśya": ['ap90', 'mw'],
    "anuvaṣaṭkāra": ['mw'],
    "anuvaṣaṭkṛ": ['mw'],
    "anuvaṣaṭkṛta": ['mw'],
    "anuvedha": ['cped', 'mw'],
    "anuvedhaḥ": ['ap90'],
    "anuvedi": ['mw'],
    "anuvedyantam": ['mw'],
    "anuvelam": ['cae', 'ddsa', 'mw'],
    "anuvelaṃ": ['ap90'],
    "anuvellita": ['ap90', 'mw'],
    "anuven": ['mw'],
    "anuveśa": ['ddsa', 'mw'],
    "anuveśana": ['mw'],
    "anuveśaḥ": ['ap90'],
    "anuveśya": ['ap90'],
    "anuveṣṭ": ['mw'],
    "anuvibhū": ['mw'],
    "anuvical": ['mw'],
    "anuvicar": ['mw'],
    "anuvicaramāna": ['cped'],
    "anuvicaranta": ['cped'],
    "anuvicarati": ['bhs', 'cped'],
    "anuvicaraṇa": ['bhs'],
    "anuvicarita": ['cped'],
    "anuvicarāpeti": ['cped'],
    "anuvicca": ['cped'],
    "anuviccakāra": ['cped'],
    "anuvicinanta": ['cped'],
    "anuvicint": ['mw'],
    "anuvicintayati": ['bhs', 'cped'],
    "anuvicinteti": ['cped'],
    "anuvicintetvā": ['cped'],
    "anuvicināti": ['cped'],
    "anuvicāraya": ['cped'],
    "anuvicārayat": ['cped'],
    "anuvicārayati": ['bhs', 'cped'],
    "anuvicāraṇā": ['bhs'],
    "anuvicāreti": ['cped'],
    "anuvicāretvā": ['cped'],
    "anuvid": ['ap90', 'mw'],
    "anuviddha": ['ap90', 'cae', 'mw'],
    "anuvidha": ['mw'],
    "anuvidheya": ['mw'],
    "anuvidhiyyati": ['cped'],
    "anuvidhā": ['ap90', 'mw'],
    "anuvidhāna": ['mw'],
    "anuvidhānaṃ": ['ap90'],
    "anuvidhātavya": ['mw'],
    "anuvidhāv": ['mw'],
    "anuvidhāyaka": ['cped'],
    "anuvidhāyin": ['ap90', 'cae', 'mw'],
    "anuvidhīyanta": ['cped'],
    "anuvidhīyanā": ['cped'],
    "anuvidhīyati": ['cped'],
    "anuvidita": ['bhs', 'cped'],
    "anuvidiś": ['bhs'],
    "anuvidvas": ['mw'],
    "anuvigaṇeti": ['cped'],
    "anuvihan": ['mw'],
    "anuvijjaka": ['cped'],
    "anuvijjamāna": ['cped'],
    "anuvijjiyamāna": ['cped'],
    "anuvijjā": ['cped'],
    "anuvikas": ['mw'],
    "anuvikkhitta": ['cped'],
    "anuvikram": ['mw'],
    "anuvikāś": ['mw'],
    "anuvikṛ": ['mw'],
    "anuvikṝ": ['mw'],
    "anuvikṣepa": ['bhs'],
    "anuvilok": ['mw'],
    "anuvilokana": ['bhs'],
    "anuvilokaya": ['cped'],
    "anuvilokayat": ['cped'],
    "anuvilokayati": ['bhs', 'cped'],
    "anuvilokesi": ['cped'],
    "anuviloketabba": ['cped'],
    "anuviloketi": ['cped'],
    "anuvilī": ['mw'],
    "anuvimṛś": ['mw'],
    "anuvinad": ['mw'],
    "anuvinard": ['mw'],
    "anuvinaś": ['ap90', 'mw'],
    "anuvinda": ['mw'],
    "anuviniḥsṛ": ['mw'],
    "anuvināśa": ['mw'],
    "anuvināśaḥ": ['ap90'],
    "anuvipaś": ['mw'],
    "anuvirāj": ['mw'],
    "anuvirājita": ['bhs'],
    "anuvisaṭa": ['cped'],
    "anuvismita": ['mw'],
    "anuvisraṃs": ['mw'],
    "anuvistṛta": ['mw'],
    "anuvisṛ": ['mw'],
    "anuvisṛj": ['mw'],
    "anuvitakkaya": ['cped'],
    "anuvitakkayat": ['cped'],
    "anuvitakkenta": ['cped'],
    "anuvitakketi": ['cped'],
    "anuvitakketvā": ['cped'],
    "anuvitan": ['mw'],
    "anuvitarkayati": ['bhs'],
    "anuvitarkaṇā": ['bhs'],
    "anuvitta": ['cae', 'mw'],
    "anuvitti": ['mw'],
    "anuvittiḥ": ['ap90'],
    "anuvivaṭṭa": ['cped'],
    "anuviviś": ['mw'],
    "anuvivā": ['mw'],
    "anuvivṛt": ['mw'],
    "anuviś": ['ap90', 'mw'],
    "anuviśva": ['mw'],
    "anuviśvaḥ": ['ap90'],
    "anuviṣaṇṇa": ['mw'],
    "anuviṣic": ['mw'],
    "anuviṣyand": ['mw'],
    "anuviṣṇu": ['mw'],
    "anuviṣṭambha": ['mw'],
    "anuviṣṭaṃbhaḥ": ['ap90'],
    "anuviṣṭhā": ['mw'],
    "anuvraj": ['ap90', 'mw'],
    "anuvraja": ['bhs'],
    "anuvrajana": ['mw'],
    "anuvrajanaṃ": ['ap90'],
    "anuvrajya": ['mw'],
    "anuvrajyā": ['cae', 'mw'],
    "anuvrata": ['ap90', 'cae', 'gra', 'mw'],
    "anuvrājya": ['ap90'],
    "anuvya": ['ap90'],
    "anuvyadh": ['ap90', 'mw'],
    "anuvyam": ['cae', 'mw'],
    "anuvyavagā": ['mw'],
    "anuvyavaharati": ['bhs'],
    "anuvyavahāra": ['bhs'],
    "anuvyavalokita": ['bhs'],
    "anuvyavaso": ['mw'],
    "anuvyavasāyaḥ": ['ap90'],
    "anuvyave": ['mw'],
    "anuvyañjana": ['bhs', 'mw'],
    "anuvyañjanaggāhi": ['cped'],
    "anuvyañjanaggāhin": ['cped'],
    "anuvyañjanaso": ['cped'],
    "anuvyañjanaṁ": ['cped'],
    "anuvyaś": ['mw'],
    "anuvyaṃjanaṃ": ['ap90'],
    "anuvyuccar": ['mw'],
    "anuvyādha": ['ddsa', 'mw'],
    "anuvyāharaṇa": ['mw'],
    "anuvyāharaṇaṃ": ['ap90'],
    "anuvyāhāra": ['mw'],
    "anuvyāhārin": ['ap90', 'mw'],
    "anuvyāhṛ": ['mw'],
    "anuvyāhṛta": ['mw'],
    "anuvyākhyā": ['mw'],
    "anuvyākhyāna": ['cae', 'mw'],
    "anuvyākhyānaṃ": ['ap90'],
    "anuvyākṛta": ['bhs'],
    "anuvyāpin": ['mw'],
    "anuvyāsthā": ['mw'],
    "anuvyūh": ['mw'],
    "anuvā": ['mw'],
    "anuvāc": ['ap90', 'ddsa', 'mw'],
    "anuvācana": ['mw'],
    "anuvācanapraiṣa": ['mw'],
    "anuvācanaṃ": ['ap90'],
    "anuvāceti": ['cped'],
    "anuvāda": ['cae', 'cped', 'mw'],
    "anuvādadhikaraṇa": ['cped'],
    "anuvādaka": ['ap90', 'mw'],
    "anuvādaḥ": ['ap90'],
    "anuvādin": ['cae', 'mw'],
    "anuvādinī": ['mw'],
    "anuvādita": ['mw'],
    "anuvādya": ['ap90', 'mw'],
    "anuvādyatva": ['mw'],
    "anuvāhin": ['bhs'],
    "anuvāka": ['cae', 'ddsa', 'mw'],
    "anuvākasaṅkhyā": ['mw'],
    "anuvākaḥ": ['ap90'],
    "anuvākya": ['cae', 'mw'],
    "anuvākyavat": ['mw'],
    "anuvākyā": ['ap90', 'mw'],
    "anuvākyāvat": ['mw'],
    "anuvākānukramaṇī": ['mw'],
    "anuvāram": ['mw'],
    "anuvāraṃ": ['ap90'],
    "anuvās": ['ap90', 'mw'],
    "anuvāsa": ['mw'],
    "anuvāsana": ['mw'],
    "anuvāsanīya": ['mw'],
    "anuvāsaram": ['mw'],
    "anuvāsaḥ": ['ap90'],
    "anuvāsin": ['ap90', 'mw'],
    "anuvāsita": ['ap90', 'mw'],
    "anuvāsya": ['mw'],
    "anuvāta": ['cae', 'cped'],
    "anuvātaḥ": ['ap90'],
    "anuvātaṁ": ['cped'],
    "anuvāte": ['mw'],
    "anuvāś": ['mw'],
    "anuvī": ['mw'],
    "anuvīj": ['mw'],
    "anuvīkṣ": ['mw'],
    "anuvṛ": ['mw'],
    "anuvṛddhi": ['ap90'],
    "anuvṛdh": ['mw'],
    "anuvṛt": ['ap90', 'mw'],
    "anuvṛtta": ['ap90', 'cae', 'mw'],
    "anuvṛtti": ['cae', 'mw'],
    "anuvṛttiḥ": ['ap90'],
    "anuvṛṣ": ['mw'],
    "anuyajus": ['mw'],
    "anuyam": ['mw'],
    "anuyanta": ['cped'],
    "anuyat": ['mw'],
    "anuyata": ['mw'],
    "anuyavam": ['mw'],
    "anuyiyāsu": ['mw'],
    "anuyoga": ['bhs', 'cae', 'cped', 'mw'],
    "anuyogabhaya": ['cped'],
    "anuyogadvāra": ['mw'],
    "anuyogakkhama": ['cped'],
    "anuyogakṛt": ['mw'],
    "anuyogavatta": ['cped'],
    "anuyogaḥ": ['ap90'],
    "anuyogaṁ dadāti": ['cped'],
    "anuyogi": ['cped'],
    "anuyogin": ['ap90', 'bhs', 'cped', 'mw'],
    "anuyojana": ['mw'],
    "anuyojanaṃ": ['ap90'],
    "anuyojya": ['ap90', 'bhs', 'cae', 'mw'],
    "anuyoktavya": ['mw'],
    "anuyoktṛ": ['ap90', 'mw'],
    "anuyugam": ['cae', 'mw'],
    "anuyuj": ['ap90', 'mw'],
    "anuyukta": ['ap90', 'bhs', 'mw'],
    "anuyuktin": ['ap90', 'mw'],
    "anuyutta": ['cped'],
    "anuyuñja": ['cped'],
    "anuyuñjat": ['cped'],
    "anuyuñjati": ['cped'],
    "anuyuñjisaṁ": ['cped'],
    "anuyuñjiyamāna": ['cped'],
    "anuyuñjiyati": ['cped'],
    "anuyuñjiṁsu": ['cped'],
    "anuyyutta": ['cped'],
    "anuyā": ['ap90', 'mw'],
    "anuyāga": ['mw'],
    "anuyāgi": ['cped'],
    "anuyāgin": ['cped'],
    "anuyāja": ['cae', 'ddsa', 'gra', 'mw'],
    "anuyājapraiṣa": ['mw'],
    "anuyājaprasava": ['mw'],
    "anuyājavat": ['mw'],
    "anuyājaḥ": ['ap90'],
    "anuyājānumantraṇa": ['mw'],
    "anuyājārtha": ['mw'],
    "anuyāna": ['mw'],
    "anuyānaṃ": ['ap90'],
    "anuyāta": ['cped', 'mw'],
    "anuyātavya": ['mw'],
    "anuyāti": ['cped'],
    "anuyātra": ['cae', 'mw'],
    "anuyātraṃ": ['ap90'],
    "anuyātrika": ['mw'],
    "anuyātrikaḥ": ['ap90'],
    "anuyātṛ": ['ap90', 'mw'],
    "anuyāyati": ['cped'],
    "anuyāyin": ['ap90', 'cae', 'mw'],
    "anuyāyitva": ['mw'],
    "anuyāyitvā": ['cped'],
    "anuyāyitā": ['mw'],
    "anuyū": ['mw'],
    "anuyūpam": ['mw'],
    "anuññeyya": ['cped'],
    "anuññāsi": ['cped'],
    "anuññāta": ['cped'],
    "anuññātapatīññāta": ['cped'],
    "anuāviṭṭha": ['cped'],
    "anuśabdita": ['mw'],
    "anuśabdya": ['mw'],
    "anuśak": ['mw'],
    "anuśakti": ['ddsa'],
    "anuśakya": ['bhs'],
    "anuśalyasamābṛṃhaṇatā": ['bhs'],
    "anuśam": ['mw'],
    "anuśap": ['mw'],
    "anuśara": ['mw'],
    "anuśaraḥ": ['ap90'],
    "anuśastra": ['mw'],
    "anuśastraṃ": ['ap90'],
    "anuśatika": ['ap90', 'mw'],
    "anuśatikādi": ['mw'],
    "anuśaya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "anuśayavat": ['mw'],
    "anuśayaḥ": ['ap90'],
    "anuśayin": ['ap90', 'mw'],
    "anuśayitavya": ['mw'],
    "anuśayākṣepa": ['mw'],
    "anuśayāna": ['ap90', 'mw'],
    "anuśayānā": ['mw'],
    "anuśayī": ['mw'],
    "anuśaṃs": ['mw'],
    "anuśaṃsa": ['bhs', 'mw'],
    "anuśaṃsaka": ['bhs'],
    "anuśaṃsaśaṃsana": ['mw'],
    "anuśete": ['bhs'],
    "anuśikha": ['mw'],
    "anuśikṣ": ['mw'],
    "anuśikṣati": ['bhs'],
    "anuśikṣaṇa": ['bhs'],
    "anuśikṣin": ['ap90', 'mw'],
    "anuśikṣā": ['bhs', 'mw'],
    "anuśivam": ['mw'],
    "anuśiśu": ['mw'],
    "anuśiśuḥ": ['ap90'],
    "anuśiṣya": ['mw'],
    "anuśiṣṭa": ['cae', 'mw'],
    "anuśiṣṭi": ['mw'],
    "anuśiṣṭiḥ": ['ap90'],
    "anuśliṣṭa": ['bhs'],
    "anuśloka": ['mw'],
    "anuślokaṃ": ['ap90'],
    "anuśobhin": ['mw'],
    "anuśocaka": ['ap90', 'mw'],
    "anuśocana": ['mw'],
    "anuśocin": ['mw'],
    "anuśocita": ['mw'],
    "anuśoka": ['mw'],
    "anuśokaḥ": ['ap90'],
    "anuśrath": ['mw'],
    "anuśrava": ['bhs', 'mw'],
    "anuśravaḥ": ['ap90'],
    "anuśraya": ['bhs'],
    "anuśrotavya": ['mw'],
    "anuśrotaṃ": ['bhs'],
    "anuśru": ['ap90', 'mw'],
    "anuśruta": ['bhs', 'mw'],
    "anuśrāvayati": ['bhs'],
    "anuśrāvaṇa": ['bhs'],
    "anuśuc": ['ap90', 'mw'],
    "anuśucikā": ['ap90'],
    "anuśuśrūṣā": ['mw'],
    "anuśuṣ": ['mw'],
    "anuśvas": ['mw'],
    "anuśākṣyate": ['bhs'],
    "anuśās": ['ap90', 'mw'],
    "anuśāsaka": ['ap90', 'mw'],
    "anuśāsana": ['cae', 'gra', 'mw'],
    "anuśāsanapara": ['mw'],
    "anuśāsanaṃ": ['ap90'],
    "anuśāsanā": ['bhs'],
    "anuśāsanī": ['bhs'],
    "anuśāsanīya": ['cae', 'mw'],
    "anuśāsat": ['mw'],
    "anuśāsin": ['cae', 'mw'],
    "anuśāsita": ['mw'],
    "anuśāsitṛ": ['cae', 'mw'],
    "anuśāsti": ['bhs', 'cae', 'mw'],
    "anuśāsya": ['mw'],
    "anuśāyin": ['mw'],
    "anuśī": ['ap90', 'mw'],
    "anuśīlana": ['mw'],
    "anuśīlanaṃ": ['ap90'],
    "anuśīlaya": ['mw'],
    "anuśīlita": ['ap90', 'mw'],
    "anuśṛṇoti": ['bhs'],
    "anuḍahati": ['cped'],
    "anuḥ": ['ap90'],
    "anuṇṇata": ['cped'],
    "anuṣa": ['mw'],
    "anuṣac": ['mw'],
    "anuṣak": ['ap90', 'mw'],
    "anuṣakta": ['ap90', 'cae', 'mw'],
    "anuṣakti": ['mw'],
    "anuṣatya": ['gra', 'mw'],
    "anuṣañj": ['mw'],
    "anuṣañjana": ['mw'],
    "anuṣañjanīya": ['mw'],
    "anuṣaṃgaḥ": ['ap90'],
    "anuṣaṃgika": ['ap90'],
    "anuṣaṃgin": ['ap90'],
    "anuṣaṃj": ['ap90'],
    "anuṣaṃjanaṃ": ['ap90'],
    "anuṣaṅga": ['cae', 'ddsa', 'mw'],
    "anuṣaṅgika": ['mw'],
    "anuṣaṅgin": ['cae', 'mw'],
    "anuṣaṇḍa": ['mw'],
    "anuṣaṭ": ['mw'],
    "anuṣecana": ['mw'],
    "anuṣeka": ['mw'],
    "anuṣekaḥ": ['ap90'],
    "anuṣic": ['mw'],
    "anuṣidh": ['mw'],
    "anuṣikta": ['mw'],
    "anuṣkṛta": ['bhs'],
    "anuṣvadha": ['ap90'],
    "anuṣvadham": ['cae', 'ddsa', 'gra', 'mw'],
    "anuṣvāpam": ['gra', 'mw'],
    "anuṣyand": ['mw'],
    "anuṣyanda": ['mw'],
    "anuṣyaṃdaḥ": ['ap90'],
    "anuṣṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "anuṣṇagu": ['mw'],
    "anuṣṇaka": ['mw'],
    "anuṣṇavallikā": ['mw'],
    "anuṣṇā": ['mw'],
    "anuṣṇāśīta": ['mw'],
    "anuṣṭabdha": ['mw'],
    "anuṣṭha": ['ap90'],
    "anuṣṭheya": ['ap90', 'cae', 'mw'],
    "anuṣṭhi": ['mw'],
    "anuṣṭhita": ['ap90', 'cae', 'mw'],
    "anuṣṭhiḥ": ['ap90'],
    "anuṣṭhu": ['cae', 'gra', 'mw'],
    "anuṣṭhuyā": ['cae', 'mw'],
    "anuṣṭhyā": ['cae', 'ddsa', 'mw'],
    "anuṣṭhā": ['ap90', 'gra', 'mw'],
    "anuṣṭhāna": ['cae', 'mw'],
    "anuṣṭhānakrama": ['mw'],
    "anuṣṭhānasmāraka": ['mw'],
    "anuṣṭhānaśarīra": ['mw'],
    "anuṣṭhānaṃ": ['ap90'],
    "anuṣṭhānika": ['mw'],
    "anuṣṭhānī": ['mw'],
    "anuṣṭhāpaka": ['ap90', 'mw'],
    "anuṣṭhāpana": ['mw'],
    "anuṣṭhāpanaṃ": ['ap90'],
    "anuṣṭhātavya": ['ddsa', 'mw'],
    "anuṣṭhātṛ": ['ap90', 'mw'],
    "anuṣṭhāyin": ['ap90', 'mw'],
    "anuṣṭobhana": ['mw'],
    "anuṣṭra": ['cae', 'mw'],
    "anuṣṭu": ['mw'],
    "anuṣṭubgarbhā": ['mw'],
    "anuṣṭubh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anuṣṭupchandas": ['mw'],
    "anuṣṭupkarmīṇa": ['mw'],
    "anuṣṭupsampad": ['mw'],
    "anuṣṭupśiras": ['mw'],
    "anuṣṭupśīrṣan": ['mw'],
    "anuṣṭuti": ['cae', 'ddsa', 'gra', 'mw'],
    "anuṣṭutiḥ": ['ap90'],
    "anuṭṭhaha": ['cped'],
    "anuṭṭhahat": ['cped'],
    "anuṭṭhahāna": ['cped'],
    "anuṭṭhāna": ['cped'],
    "anuṭṭhāta": ['cped'],
    "anuṭṭhātar": ['cped'],
    "anva-d-eva": ['cped'],
    "anvabhiṣic": ['mw'],
    "anvabhyavacar": ['mw'],
    "anvabhyavacāram": ['mw'],
    "anvac": ['gra'],
    "anvaddhamāsaṁ": ['cped'],
    "anvadhiruh": ['mw'],
    "anvadhyas": ['mw'],
    "anvadhyāyam": ['mw'],
    "anvagbhāvam": ['mw'],
    "anvagbhūya": ['mw'],
    "anvagjyeṣṭha": ['mw'],
    "anvagram": ['mw'],
    "anvagū": ['cped'],
    "anvah": ['mw'],
    "anvaham": ['cae', 'ddsa', 'mw'],
    "anvahaṃ": ['ap90'],
    "anvak": ['ap90', 'mw'],
    "anvakkharaṁ": ['cped'],
    "anvaksthānin": ['mw'],
    "anvaksthānīya": ['mw'],
    "anvakārī": ['cped'],
    "anvakāsi": ['cped'],
    "anvakṣa": ['ap90', 'mw'],
    "anvakṣam": ['ddsa', 'mw'],
    "anvakṣaram": ['mw'],
    "anvakṣarasandhi": ['mw'],
    "anvakṣarasaṃdhiḥ": ['ap90'],
    "anvan": ['ap90'],
    "anvapakram": ['mw'],
    "anvarc": ['mw'],
    "anvardhamāsam": ['bhs'],
    "anvarj": ['mw'],
    "anvart": ['mw'],
    "anvartha": ['ap90', 'cae', 'ddsa', 'mw'],
    "anvarthagrahaṇa": ['mw'],
    "anvarthasaṃjñā": ['mw'],
    "anvartitṛ": ['ap90', 'gra', 'mw'],
    "anvas": ['mw'],
    "anvasta": ['ap90', 'mw'],
    "anvat": ['mw'],
    "anvatisic": ['mw'],
    "anvatī": ['mw'],
    "anvav": ['mw'],
    "anvavacar": ['mw'],
    "anvavacāra": ['mw'],
    "anvavacāraḥ": ['ap90'],
    "anvavadhā": ['mw'],
    "anvavagā": ['mw'],
    "anvavahan": ['mw'],
    "anvavahṛ": ['mw'],
    "anvavakiraṇa": ['mw'],
    "anvavakiraṇaṃ": ['ap90'],
    "anvavakram": ['mw'],
    "anvavakṛ": ['mw'],
    "anvavakṝ": ['mw'],
    "anvavalamba": ['mw'],
    "anvavalup": ['mw'],
    "anvavamṛś": ['mw'],
    "anvavaplu": ['mw'],
    "anvavapā": ['mw'],
    "anvavaruh": ['mw'],
    "anvavasarga": ['mw'],
    "anvavasargaḥ": ['ap90'],
    "anvavasita": ['ap90', 'mw'],
    "anvavaso": ['mw'],
    "anvavasru": ['mw'],
    "anvavasthā": ['mw'],
    "anvavasāyin": ['mw'],
    "anvavasṛj": ['mw'],
    "anvave": ['mw'],
    "anvavekṣ": ['mw'],
    "anvavekṣaṇa": ['mw'],
    "anvavekṣin": ['mw'],
    "anvavekṣā": ['ap90', 'ddsa', 'mw'],
    "anvavārj": ['mw'],
    "anvavās": ['mw'],
    "anvavāya": ['mw'],
    "anvavāyana": ['mw'],
    "anvavāyaḥ": ['ap90'],
    "anvaya": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "anvayajña": ['mw'],
    "anvayavat": ['ap90', 'mw'],
    "anvayavyatireka": ['mw'],
    "anvayavyatirekin": ['mw'],
    "anvayavyāpti": ['mw'],
    "anvayaḥ": ['ap90'],
    "anvayin": ['ap90', 'cae', 'ddsa', 'mw'],
    "anvayitva": ['mw'],
    "anvayāgata": ['mw'],
    "anvañc": ['cae', 'ddsa', 'mw'],
    "anvañj": ['mw'],
    "anvaś": ['mw'],
    "anvaḍḍhamāsaṁ": ['cped'],
    "anvaṃc": ['ap90'],
    "anvaṅgam": ['mw'],
    "anvaṣṭakya": ['mw'],
    "anvaṣṭakyaṃ": ['ap90'],
    "anvaṣṭakā": ['ap90', 'cae', 'ddsa', 'mw'],
    "anvaṣṭamadiśaṃ": ['ap90'],
    "anve": ['mw'],
    "anventa": ['cped'],
    "anvesa": ['cped'],
    "anvesanta": ['cped'],
    "anvesat": ['cped'],
    "anvesati": ['cped'],
    "anvesaṁ": ['cped'],
    "anvetave": ['mw'],
    "anveti": ['cped'],
    "anveṣa": ['cae', 'ddsa', 'mw'],
    "anveṣaka": ['ap90', 'mw'],
    "anveṣati": ['bhs'],
    "anveṣaḥ": ['ap90'],
    "anveṣaṇa": ['mw'],
    "anveṣaṇīya": ['cae'],
    "anveṣin": ['cae', 'ddsa', 'mw'],
    "anveṣya": ['cae', 'mw'],
    "anveṣṭavya": ['mw'],
    "anveṣṭṛ": ['cae', 'mw'],
    "anvi": ['ap90', 'mw'],
    "anvicchā": ['mw'],
    "anvidh": ['mw'],
    "anvindh": ['mw'],
    "anvita": ['ap90', 'cae', 'ddsa', 'mw'],
    "anviti": ['ap90', 'mw'],
    "anvitārtha": ['mw'],
    "anviṣ": ['ap90', 'mw'],
    "anviṣyamāṇa": ['mw'],
    "anviṣṭa": ['ap90', 'mw'],
    "anvodahana": ['bhs'],
    "anvā": ['mw'],
    "anvābhaj": ['mw'],
    "anvābhakta": ['mw'],
    "anvābhū": ['mw'],
    "anvācakṣ": ['mw'],
    "anvācam": ['mw'],
    "anvācar": ['mw'],
    "anvācaya": ['mw'],
    "anvācayaśiṣṭa": ['mw'],
    "anvācayaḥ": ['ap90'],
    "anvācita": ['ap90', 'mw'],
    "anvādeśa": ['mw'],
    "anvādeśaka": ['mw'],
    "anvādeśaḥ": ['ap90'],
    "anvādheya": ['cae', 'mw'],
    "anvādheyaka": ['mw'],
    "anvādheyaṃ": ['ap90'],
    "anvādhi": ['ddsa', 'mw'],
    "anvādhika": ['cped'],
    "anvādhiḥ": ['ap90'],
    "anvādhya": ['mw'],
    "anvādhyaḥ": ['ap90'],
    "anvādhā": ['mw'],
    "anvādhāna": ['mw'],
    "anvādhānaṃ": ['ap90'],
    "anvādhāv": ['mw'],
    "anvādhī": ['mw'],
    "anvādiś": ['ap90', 'mw'],
    "anvādiśati": ['bhs'],
    "anvādiṣṭa": ['ap90', 'mw'],
    "anvādā": ['mw'],
    "anvāgam": ['mw'],
    "anvāgameti": ['cped'],
    "anvāgata": ['cped'],
    "anvāgā": ['mw'],
    "anvāharaṇa": ['mw'],
    "anvāhata": ['cped'],
    "anvāhika": ['ap90'],
    "anvāhita": ['ap90', 'mw'],
    "anvāhiṇḍ": ['mw'],
    "anvāhiṇḍati": ['bhs', 'cped'],
    "anvāhve": ['mw'],
    "anvāhāra": ['mw'],
    "anvāhārya": ['cae', 'mw'],
    "anvāhāryaka": ['mw'],
    "anvāhāryapacana": ['cae', 'mw'],
    "anvāhāryaḥ": ['ap90'],
    "anvāhṛ": ['mw'],
    "anvāje": ['ap90', 'mw'],
    "anvākarṣaka": ['mw'],
    "anvākhyā": ['ap90', 'mw'],
    "anvākhyāna": ['mw'],
    "anvākhyānaṃ": ['ap90'],
    "anvākhyāyaka": ['mw'],
    "anvākram": ['mw'],
    "anvākśāyam": ['mw'],
    "anvākṛ": ['mw'],
    "anvākṛti": ['mw'],
    "anvālabh": ['mw'],
    "anvālabhana": ['cae', 'mw'],
    "anvālambhana": ['mw'],
    "anvāloc": ['mw'],
    "anvānayati": ['cped'],
    "anvāntrya": ['mw'],
    "anvānu": ['mw'],
    "anvānī": ['mw'],
    "anvāp": ['mw'],
    "anvāpadīna": ['mw'],
    "anvārabdha": ['ap90'],
    "anvārabh": ['ap90', 'mw'],
    "anvārabhya": ['ap90', 'mw'],
    "anvārambha": ['mw'],
    "anvārambhaṇa": ['mw'],
    "anvārambhaṇīyā": ['mw'],
    "anvāraṃbhaḥ": ['ap90'],
    "anvāraṃbhaṇīyā": ['ap90'],
    "anvāroha": ['mw'],
    "anvārohaṇa": ['mw'],
    "anvārohaṇaṃ": ['ap90'],
    "anvārohaṇīya": ['mw'],
    "anvāruh": ['ap90', 'mw'],
    "anvās": ['ap90', 'mw'],
    "anvāsana": ['mw'],
    "anvāsanaṃ": ['ap90'],
    "anvāsatta": ['cped'],
    "anvāsavati": ['cped'],
    "anvāsecana": ['mw'],
    "anvāssavati": ['cped'],
    "anvāsthā": ['mw'],
    "anvāsthāna": ['mw'],
    "anvāsthāya": ['mw'],
    "anvāsyamāna": ['mw'],
    "anvāsīna": ['ap90', 'mw'],
    "anvātan": ['mw'],
    "anvāvah": ['mw'],
    "anvāvap": ['mw'],
    "anvāvartayati": ['bhs'],
    "anvāvaṭṭa": ['cped'],
    "anvāvaṭṭati": ['cped'],
    "anvāvisati": ['cped'],
    "anvāvisitvā": ['cped'],
    "anvāviś": ['mw'],
    "anvāviṭṭha": ['cped'],
    "anvāvṛt": ['mw'],
    "anvāvṛtam": ['mw'],
    "anvāya": ['cped'],
    "anvāyanta": ['cae'],
    "anvāyat": ['mw'],
    "anvāyatana": ['ap90', 'mw'],
    "anvāyatta": ['ap90', 'mw'],
    "anvāyika": ['cped'],
    "anvāyātya": ['mw'],
    "anvāyātyā": ['ap90'],
    "anvāśrita": ['mw'],
    "anvāśī": ['mw'],
    "anvāṃtrya": ['ap90'],
    "anvīkṣ": ['ap90', 'mw'],
    "anvīkṣaka": ['mw'],
    "anvīkṣaṇa": ['mw'],
    "anvīkṣaṇaṃ": ['ap90'],
    "anvīkṣitavya": ['mw'],
    "anvīkṣā": ['mw'],
    "anvīpa": ['ap90'],
    "anvīpam": ['mw'],
    "anvīta": ['ap90', 'mw'],
    "anvīyamāna": ['mw'],
    "anvṛ": ['mw'],
    "anvṛcam": ['mw'],
    "anvṛcaṃ": ['ap90'],
    "anvṛdh": ['mw'],
    "anvṛju": ['mw'],
    "anya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anyabandhu": ['mw'],
    "anyabhāva": ['mw'],
    "anyabhṛt": ['mw'],
    "anyabhṛta": ['cae', 'mw'],
    "anyabījaja": ['cae', 'mw'],
    "anyabījasamudbhava": ['mw'],
    "anyabījotpanna": ['mw'],
    "anyacchāyāyoni": ['mw'],
    "anyacetas": ['cae'],
    "anyacintā": ['cae'],
    "anyacitta": ['cae', 'ddsa', 'mw'],
    "anyacodita": ['mw'],
    "anyadaivata": ['mw'],
    "anyadevata": ['mw'],
    "anyadevatya": ['mw'],
    "anyadharma": ['mw'],
    "anyadhī": ['mw'],
    "anyadurvaha": ['mw'],
    "anyadā": ['ap90', 'cae', 'ddsa', 'mw'],
    "anyadāśis": ['mw'],
    "anyadāśā": ['mw'],
    "anyadīya": ['ap90', 'ddsa', 'mw'],
    "anyaga": ['mw'],
    "anyagata": ['cae'],
    "anyagotra": ['mw'],
    "anyagāmin": ['mw'],
    "anyaja": ['mw'],
    "anyajanatā": ['mw'],
    "anyajanman": ['cae', 'mw'],
    "anyajānmika": ['bhs'],
    "anyajāta": ['gra', 'mw'],
    "anyaka": ['ap90', 'gra', 'mw'],
    "anyakartṛka": ['cae', 'ddsa'],
    "anyakriya": ['mw'],
    "anyakāma": ['mw'],
    "anyakāra": ['mw'],
    "anyakārukā": ['mw'],
    "anyakṛta": ['cae', 'gra', 'mw'],
    "anyakṣetra": ['mw'],
    "anyaliṅga": ['mw'],
    "anyaliṅgaka": ['mw'],
    "anyaloha": ['mw'],
    "anyalohaka": ['mw'],
    "anyalokya": ['cae', 'mw'],
    "anyamanas": ['cae', 'mw'],
    "anyamanaska": ['mw'],
    "anyamanya": ['bhs'],
    "anyamānasa": ['cae', 'mw'],
    "anyamātṛja": ['mw'],
    "anyamātṛka": ['mw'],
    "anyanimitta": ['cae', 'ddsa'],
    "anyanābhi": ['mw'],
    "anyapadārthapradhāna": ['mw'],
    "anyapakṣikāṃ": ['bhs'],
    "anyapara": ['cae', 'mw'],
    "anyaparigraha": ['mw'],
    "anyapuṣṭa": ['cae', 'mw'],
    "anyapūrvā": ['mw'],
    "anyarhi": ['ap90', 'mw'],
    "anyarājan": ['mw'],
    "anyarāṣṭriya": ['mw'],
    "anyarāṣṭrīya": ['mw'],
    "anyarūpa": ['cae', 'ddsa', 'gra', 'mw'],
    "anyarūpin": ['cae', 'mw'],
    "anyasaṃgama": ['mw'],
    "anyasaṃkrānta": ['cae'],
    "anyastrīga": ['cae', 'mw'],
    "anyasādhāraṇa": ['mw'],
    "anyat": ['ap90'],
    "anyataeta": ['mw'],
    "anyatama": ['ap90', 'bhs', 'cae', 'mw'],
    "anyatamaka": ['bhs'],
    "anyatamānyatama": ['bhs'],
    "anyatara": ['ap90', 'bhs', 'cae', 'mw'],
    "anyataratas": ['mw'],
    "anyatarataḥ": ['ap90'],
    "anyataratodanta": ['mw'],
    "anyataratoyukta": ['mw'],
    "anyataredyus": ['mw'],
    "anyataredyuḥ": ['ap90'],
    "anyatarāgra": ['bhs'],
    "anyatarānyatara": ['bhs', 'mw'],
    "anyatas": ['cae', 'ddsa', 'gra', 'mw'],
    "anyatastya": ['mw'],
    "anyatastyajāyin": ['mw'],
    "anyatastyaḥ": ['ap90'],
    "anyataḥ": ['ap90'],
    "anyataḥkṣṇut": ['mw'],
    "anyataḥplakṣā": ['cae', 'mw'],
    "anyataḥsitibāhu": ['mw'],
    "anyataḥsitirandhra": ['mw'],
    "anyathaya": ['mw'],
    "anyathayati": ['ap90'],
    "anyathā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anyathābhidhāna": ['cae', 'mw'],
    "anyathābhāva": ['cae', 'mw'],
    "anyathābhūta": ['mw'],
    "anyathādarśana": ['cae', 'ddsa', 'mw'],
    "anyathājātīyaka": ['mw'],
    "anyathākaraṇa": ['mw'],
    "anyathākhyāti": ['mw'],
    "anyathākāra": ['mw'],
    "anyathākāram": ['mw'],
    "anyathākṛ": ['mw'],
    "anyathākṛta": ['mw'],
    "anyathākṛti": ['mw'],
    "anyathāprathā": ['cae'],
    "anyathāsambhāvin": ['mw'],
    "anyathāsaṃbhāvanā": ['cae'],
    "anyathāsaṃbhāvin": ['cae'],
    "anyathāsiddha": ['mw'],
    "anyathāsiddhatva": ['mw'],
    "anyathāsiddhi": ['mw'],
    "anyathāstotra": ['mw'],
    "anyathātva": ['bhs', 'mw'],
    "anyathāvādin": ['cae', 'mw'],
    "anyathāvṛtti": ['cae', 'mw'],
    "anyathāśīlika": ['mw'],
    "anyathībhāva": ['bhs'],
    "anyatkāma": ['mw'],
    "anyatkāraka": ['mw'],
    "anyatkṛ": ['mw'],
    "anyatodat": ['mw'],
    "anyatodvāra": ['mw'],
    "anyatoghātin": ['mw'],
    "anyatojyotis": ['mw'],
    "anyatomukha": ['mw'],
    "anyatoraṇya": ['mw'],
    "anyatovāta": ['mw'],
    "anyatpārśva": ['mw'],
    "anyatra": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "anyatrakaraṇa": ['mw'],
    "anyatramanas": ['mw'],
    "anyatsthānagata": ['mw'],
    "anyatva": ['cae'],
    "anyatā": ['cae', 'ddsa', 'mw'],
    "anyatīrthika": ['bhs', 'mw'],
    "anyavarṇa": ['mw'],
    "anyaviṣaya": ['cae'],
    "anyavrata": ['gra', 'mw'],
    "anyavāda": ['bhs'],
    "anyavādin": ['cae'],
    "anyavāpa": ['mw'],
    "anyayajña": ['mw'],
    "anyaśaṅkita": ['cae', 'mw'],
    "anyaśākhaka": ['mw'],
    "anyaśākhāstha": ['mw'],
    "anyaśṛṅga": ['mw'],
    "anyaṃga": ['ap90'],
    "anyaṅga": ['mw'],
    "anyaṅgaśveta": ['ddsa', 'mw'],
    "anyedyuka": ['mw'],
    "anyedyus": ['cae', 'ddsa', 'mw'],
    "anyedyuska": ['mw'],
    "anyedyuḥ": ['ap90'],
    "anyedyuṣka": ['ap90', 'mw'],
    "anyena": ['bhs'],
    "anyodarya": ['ddsa', 'gra', 'mw'],
    "anyokas": ['ap90', 'mw'],
    "anyokti": ['mw'],
    "anyoktikaṇṭhābharaṇa": ['mw'],
    "anyoktipariccheda": ['mw'],
    "anyoktiśataka": ['mw'],
    "anyonya": ['ap90', 'bhs', 'cae', 'mw'],
    "anyonyabheda": ['cae', 'mw'],
    "anyonyabhāva": ['mw'],
    "anyonyadarśana": ['cae', 'mw'],
    "anyonyadharmin": ['mw'],
    "anyonyagata": ['cae', 'mw'],
    "anyonyaghāta": ['mw'],
    "anyonyahārābhihata": ['mw'],
    "anyonyakalaha": ['mw'],
    "anyonyakṛtya": ['cae', 'mw'],
    "anyonyam": ['mw'],
    "anyonyamithuna": ['mw'],
    "anyonyapakṣanayana": ['mw'],
    "anyonyasaṃśraya": ['mw'],
    "anyonyaspardhin": ['mw'],
    "anyonyaspardhā": ['cae', 'mw'],
    "anyonyasāpekṣa": ['mw'],
    "anyonyatas": ['mw'],
    "anyonyavibhāga": ['mw'],
    "anyonyavyatikara": ['mw'],
    "anyonyavṛtti": ['mw'],
    "anyonyokti": ['mw'],
    "anyonyopamā": ['cae', 'mw'],
    "anyonyābhāva": ['mw'],
    "anyonyānurāga": ['cae', 'mw'],
    "anyonyāpahṛta": ['mw'],
    "anyonyāpatitatyāgin": ['mw'],
    "anyonyāśraya": ['mw'],
    "anyonyāśrita": ['mw'],
    "anyopatāpin": ['cae', 'ddsa', 'mw'],
    "anyotpanna": ['cae', 'mw'],
    "anyoḍhā": ['mw'],
    "anyo’nya": ['ddsa'],
    "anyā": ['ap90', 'mw'],
    "anyādhīna": ['mw'],
    "anyādṛkṣ": ['ap90'],
    "anyādṛkṣa": ['cae', 'ddsa', 'mw'],
    "anyādṛś": ['cae', 'mw'],
    "anyādṛśa": ['cae', 'mw'],
    "anyāpadeśa": ['mw'],
    "anyārtha": ['cae', 'ddsa', 'mw'],
    "anyārthatva": ['mw'],
    "anyāsakta": ['mw'],
    "anyāsi": ['bhs'],
    "anyāsādhāraṇa": ['mw'],
    "anyātaka": ['bhs'],
    "anyāvāda": ['bhs'],
    "anyāya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "anyāyamati": ['mw'],
    "anyāyasamāsa": ['mw'],
    "anyāyatas": ['mw'],
    "anyāyavartin": ['cae', 'mw'],
    "anyāyavṛtta": ['mw'],
    "anyāyavṛtti": ['mw'],
    "anyāyin": ['ap90', 'ddsa', 'mw'],
    "anyāyya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anyāśrayaṇa": ['mw'],
    "anyāśrita": ['mw'],
    "anyāṅkasupta": ['ddsa'],
    "anyūna": ['ap90', 'cae', 'ddsa', 'mw'],
    "anyūnādhika": ['mw'],
    "anyūnārthavādin": ['cae', 'mw'],
    "anyūnātirikta": ['mw'],
    "anyūnātiriktāṅga": ['mw'],
    "anyūnāṅga": ['mw'],
    "anā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anābayu": ['mw'],
    "anābhayin": ['ap90', 'gra', 'mw'],
    "anābhibhū": ['bhs'],
    "anābhibhūta": ['bhs'],
    "anābhoga": ['bhs', 'cped', 'mw'],
    "anābhyudayika": ['cae', 'mw'],
    "anābhāsa": ['bhs'],
    "anābhū": ['ap90', 'gra', 'mw'],
    "anābādha": ['mw'],
    "anācakṣat": ['cae', 'ddsa'],
    "anācarant": ['cae'],
    "anācaraṇa": ['ddsa', 'mw'],
    "anācariyaka": ['cped'],
    "anācchṛṇṇa": ['mw'],
    "anāchedya": ['bhs'],
    "anāchindana": ['bhs'],
    "anāciṇṇa": ['cped'],
    "anācāra": ['ap90', 'cped', 'ddsa', 'mw'],
    "anācārin": ['mw'],
    "anācāryabhogīna": ['mw'],
    "anācāryaka": ['bhs'],
    "anācīrṇa": ['mw'],
    "anāda": ['mw'],
    "anādadāna": ['mw'],
    "anādara": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "anādaraṇa": ['ddsa', 'mw'],
    "anādaraṇaṃ": ['ap90'],
    "anādari": ['cped'],
    "anādarin": ['ap90', 'mw'],
    "anādariya": ['cped'],
    "anādarākṣepa": ['mw'],
    "anādarśaka": ['bhs'],
    "anādarśanā": ['bhs'],
    "anādeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anādeyavākya": ['bhs'],
    "anādeśa": ['ddsa'],
    "anādeśakara": ['mw'],
    "anādeśaḥ": ['ap90'],
    "anādhi": ['ap90', 'ddsa'],
    "anādhānagāhin": ['cped'],
    "anādhāra": ['ap90', 'cped'],
    "anādhṛṣ": ['ap90', 'mw'],
    "anādhṛṣya": ['cae', 'ddsa', 'gra', 'mw'],
    "anādhṛṣṭa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anādhṛṣṭi": ['mw'],
    "anādi": ['ap90', 'cae', 'ddsa', 'mw'],
    "anādikarmika": ['bhs'],
    "anādikālika": ['bhs'],
    "anādimadhyānta": ['mw'],
    "anādimant": ['cae'],
    "anādimat": ['ap90', 'mw'],
    "anādin": ['mw'],
    "anādinidhana": ['mw'],
    "anādinna": ['cped'],
    "anāditva": ['mw'],
    "anāditā": ['ap90'],
    "anādiyana": ['cped'],
    "anādiyanta": ['cped'],
    "anādiyitvā": ['cped'],
    "anādiṣṭa": ['ddsa', 'mw'],
    "anādya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anādyabhakṣaṇa": ['cae'],
    "anādyananta": ['ddsa', 'mw'],
    "anādyanta": ['ddsa', 'mw'],
    "anādyādana": ['cae'],
    "anādā": ['cped'],
    "anādāna": ['bhs', 'cped'],
    "anādātṛ": ['cae'],
    "anādāya": ['cped'],
    "anādīnava": ['ap90', 'ddsa', 'mw'],
    "anādīnavadassāvi": ['cped'],
    "anādīnavadassāvin": ['cped'],
    "anādṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "anādṛtya": ['cae', 'ddsa', 'mw'],
    "anāga": ['ap90', 'ddsa', 'gra', 'mw'],
    "anāgacchant": ['cae'],
    "anāgacchat": ['ddsa'],
    "anāgama": ['ap90', 'mw'],
    "anāgamana": ['cped', 'ddsa'],
    "anāgamanadiṭṭhika": ['cped'],
    "anāgamanīya": ['cped'],
    "anāgamiṣyat": ['mw'],
    "anāgamopabhoga": ['mw'],
    "anāgamya": ['ap90', 'mw'],
    "anāganta": ['cped'],
    "anāgantar": ['cped'],
    "anāgarta": ['mw'],
    "anāgas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anāgata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "anāgata-m-addhāne": ['cped'],
    "anāgatam addhānaṁ": ['cped'],
    "anāgatattha": ['cped'],
    "anāgatavat": ['mw'],
    "anāgatavidhātṛ": ['cae', 'mw'],
    "anāgataṁsa": ['cped'],
    "anāgati": ['mw'],
    "anāgatika": ['bhs'],
    "anāgatiḥ": ['ap90'],
    "anāgatābādha": ['mw'],
    "anāgatārtavā": ['mw'],
    "anāgatāvekṣaṇa": ['mw'],
    "anāgaṃdhita": ['ap90'],
    "anāghrāta": ['cae', 'ddsa'],
    "anāghāta": ['cped'],
    "anāgohatyā": ['mw'],
    "anāgu": ['cped'],
    "anāgā": ['gra', 'mw'],
    "anāgāmi": ['cped'],
    "anāgāmin": ['ap90', 'bhs', 'cped', 'mw'],
    "anāgāmitā": ['cped'],
    "anāgāmphala": ['cped'],
    "anāgāmuka": ['ap90', 'mw'],
    "anāgāra": ['bhs'],
    "anāgārikā": ['bhs'],
    "anāgāriya": ['cped'],
    "anāgāstva": ['cae', 'ddsa', 'gra', 'mw'],
    "anāgūrtin": ['mw'],
    "anāgṛha": ['bhs'],
    "anāgṛhīta": ['bhs'],
    "anāhanasya": ['mw'],
    "anāharaṇā": ['bhs'],
    "anāhata": ['ap90', 'cae', 'ddsa', 'mw'],
    "anāhatanāda": ['mw'],
    "anāhavanīya": ['mw'],
    "anāhaṭa": ['cped'],
    "anāhita": ['mw'],
    "anāhitāgni": ['cae', 'ddsa', 'mw'],
    "anāhitāgnitā": ['cae'],
    "anāhlāda": ['mw'],
    "anāhlādita": ['mw'],
    "anāhuti": ['gra', 'mw'],
    "anāhutiḥ": ['ap90'],
    "anāhvāna": ['cae', 'ddsa'],
    "anāhāra": ['ap90', 'cped', 'ddsa', 'mw'],
    "anāhārin": ['ap90', 'mw'],
    "anāhārya": ['ap90', 'cae', 'mw'],
    "anāhūta": ['ap90', 'ddsa', 'mw'],
    "anāhūtopajalpin": ['mw'],
    "anāhūtopaviṣṭa": ['mw'],
    "anājñapta": ['mw'],
    "anājñaptakārin": ['mw'],
    "anājñayā": ['mw'],
    "anājñā": ['cae', 'ddsa'],
    "anājñāta": ['ap90', 'cae', 'ddsa', 'mw'],
    "anājñātam": ['mw'],
    "anājñātamājñāsyāmī": ['bhs'],
    "anājānat": ['mw'],
    "anājānīya": ['cped'],
    "anākampa": ['cae', 'ddsa'],
    "anākappasampanna": ['cped'],
    "anākarṇita": ['cae', 'ddsa'],
    "anākarṇitaka": ['cae'],
    "anākasmika": ['ddsa'],
    "anākhyeya": ['cae', 'ddsa'],
    "anākhyāta": ['cae', 'ddsa'],
    "anākhyāya": ['cae', 'ddsa', 'mw'],
    "anākiṇṇa": ['cped'],
    "anākramya": ['ddsa'],
    "anākranda": ['mw'],
    "anākrānta": ['mw'],
    "anākrāntā": ['mw'],
    "anākrāṃta": ['ap90'],
    "anāktākṣa": ['mw'],
    "anākula": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "anākāla": ['mw'],
    "anākālabhṛta": ['mw'],
    "anākālaḥ": ['ap90'],
    "anākāra": ['ap90', 'mw'],
    "anākārita": ['mw'],
    "anākāśa": ['ap90', 'mw'],
    "anākṛta": ['ap90', 'gra', 'mw'],
    "anākṛtsnagatā": ['bhs'],
    "anākṛṣṭa": ['ddsa'],
    "anākṣepam": ['mw'],
    "anākṣit": ['ap90', 'mw'],
    "anākṣārita": ['cae', 'ddsa', 'mw'],
    "anāla": ['bhs', 'ddsa', 'mw'],
    "anālabdha": ['bhs', 'mw'],
    "anālakṣya": ['ddsa'],
    "anālamba": ['cped', 'mw'],
    "anālambana": ['mw'],
    "anālambha": ['bhs'],
    "anālambhukā": ['mw'],
    "anālambukā": ['mw'],
    "anālambī": ['mw'],
    "anālapana": ['ddsa'],
    "anālapanatā": ['cped'],
    "anālapanta": ['cped'],
    "anālasa": ['bhs'],
    "anālassa": ['cped'],
    "anālasya": ['cped', 'ddsa'],
    "anālaya": ['bhs', 'cped'],
    "anālayamaṇḍala": ['bhs'],
    "anālayana": ['mw'],
    "anālayavyūha": ['bhs'],
    "anālaṃba": ['ap90'],
    "anālaṃbhukā": ['ap90'],
    "anālaṃbukā": ['ap90'],
    "anālindaka": ['cped'],
    "anālocita": ['ap90', 'ddsa', 'mw'],
    "anālocya": ['ddsa', 'mw'],
    "anāloka": ['cped'],
    "anālokiya": ['bhs'],
    "anālāpa": ['ap90', 'cped', 'mw'],
    "anālīḍha": ['bhs', 'ddsa'],
    "anāmaka": ['ap90', 'mw'],
    "anāman": ['ap90', 'cae', 'mw'],
    "anāmana": ['mw'],
    "anāmanatā": ['bhs'],
    "anāmanta": ['cped'],
    "anāmantacara": ['cped'],
    "anāmantetvā": ['cped'],
    "anāmantraṇaka": ['bhs'],
    "anāmantā": ['cped'],
    "anāmatva": ['mw'],
    "anāmaya": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "anāmayapraśna": ['cae'],
    "anāmayat": ['ap90', 'mw'],
    "anāmayatā": ['mw'],
    "anāmayitnu": ['ap90', 'gra', 'mw'],
    "anāmikā": ['ddsa', 'mw'],
    "anāmin": ['gra', 'mw'],
    "anāmiṣa": ['ap90', 'mw'],
    "anāmnāta": ['mw'],
    "anāmnāya": ['ddsa'],
    "anāmukta": ['cae', 'ddsa'],
    "anāmya": ['ddsa', 'mw'],
    "anāmā": ['ap90'],
    "anāmṛta": ['ap90', 'mw'],
    "anāmṛṇa": ['ap90', 'gra', 'mw'],
    "anāmṛṣṭa": ['ddsa'],
    "anānata": ['cae', 'ddsa', 'gra', 'mw'],
    "anāntarīyaka": ['mw'],
    "anānubhūti": ['gra', 'mw'],
    "anānubhūtiḥ": ['ap90'],
    "anānuda": ['ap90', 'gra', 'mw'],
    "anānudiṣṭa": ['gra', 'mw'],
    "anānugiddha": ['cped'],
    "anānujana": ['cped'],
    "anānujanat": ['cped'],
    "anānujā": ['mw'],
    "anānukṛtya": ['ap90', 'gra', 'mw'],
    "anānuloma": ['cped'],
    "anānupassi": ['cped'],
    "anānupassin": ['cped'],
    "anānupuṭṭha": ['cped'],
    "anānupūrvya": ['mw'],
    "anānupūrvyasaṃhitā": ['mw'],
    "anānupūrvyaṃ": ['ap90'],
    "anānuruddha": ['cped'],
    "anānuvajja": ['cped'],
    "anānuyāyin": ['cped'],
    "anāpad": ['ap90', 'cae', 'ddsa', 'mw'],
    "anāpanna": ['bhs', 'mw'],
    "anāpannasattā": ['cped'],
    "anāpara": ['cped'],
    "anāpatti": ['bhs', 'cped', 'mw'],
    "anāpattibahula": ['cped'],
    "anāpattika": ['bhs', 'cped'],
    "anāpi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anāpia": ['gra'],
    "anāpluta": ['mw'],
    "anāplutāṅga": ['mw'],
    "anāpnuvat": ['ddsa'],
    "anāprīta": ['mw'],
    "anāpta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anāpti": ['cae', 'ddsa', 'mw'],
    "anāptiḥ": ['ap90'],
    "anāptṛ": ['ap90', 'ddsa'],
    "anāpuccha": ['cped'],
    "anāpucchat": ['cped'],
    "anāpucchita": ['cped'],
    "anāpucchā": ['cped'],
    "anāpya": ['ddsa', 'gra', 'mw'],
    "anāpāna": ['mw'],
    "anāpāthagata": ['cped'],
    "anāpūyita": ['cae', 'mw'],
    "anārabdha": ['bhs'],
    "anārabhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anārabhyatva": ['mw'],
    "anārabhyavāda": ['mw'],
    "anārabhyādhīta": ['mw'],
    "anārakkha": ['cped'],
    "anārambaṇa": ['mw'],
    "anārambha": ['cae', 'cped', 'mw'],
    "anārambhaṇa": ['gra', 'mw'],
    "anārammaṇa": ['cped'],
    "anārata": ['ap90', 'mw'],
    "anāratam": ['mw'],
    "anāraṃbhaḥ": ['ap90'],
    "anāraṃbhaṇa": ['ap90'],
    "anārja": ['bhs'],
    "anārjava": ['ap90', 'cae', 'ddsa', 'mw'],
    "anārocana": ['cped'],
    "anārogya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anārogyakara": ['mw'],
    "anāroka": ['mw'],
    "anāropetvā": ['cped'],
    "anāropita": ['cped'],
    "anārta": ['mw'],
    "anārtava": ['ap90', 'mw'],
    "anārthikā": ['bhs'],
    "anārti": ['mw'],
    "anārtvijīna": ['mw'],
    "anāruddha": ['ddsa'],
    "anāruhya": ['cae', 'ddsa', 'mw'],
    "anārya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anāryaja": ['mw'],
    "anāryajuṣṭa": ['mw'],
    "anāryaka": ['mw'],
    "anāryakarmin": ['cae', 'mw'],
    "anāryakaṃ": ['ap90'],
    "anāryatikta": ['mw'],
    "anāryatva": ['mw'],
    "anāryatā": ['mw'],
    "anārādhaka": ['cped'],
    "anārādhanīya": ['cped'],
    "anārūḍha": ['ddsa', 'mw'],
    "anārṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "anārṣeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anās": ['ap90', 'gra', 'mw'],
    "anāsa": ['cped', 'mw'],
    "anāsaka": ['cped'],
    "anāsakā": ['cped'],
    "anāsana": ['cped'],
    "anāsanna": ['cped', 'ddsa'],
    "anāsannavara": ['cped'],
    "anāsasāna": ['cped'],
    "anāsava": ['cped'],
    "anāsavākhya": ['ddsa'],
    "anāsaṅga": ['cae', 'mw'],
    "anāsevita": ['cped'],
    "anāsika": ['mw'],
    "anāsmāka": ['mw'],
    "anāsrava": ['bhs', 'mw'],
    "anāsravaprakāra": ['mw'],
    "anāsrāva": ['ap90', 'mw'],
    "anāstha": ['mw'],
    "anāsthā": ['ap90', 'cae', 'ddsa', 'mw'],
    "anāsthāna": ['ap90', 'gra', 'mw'],
    "anāstika": ['cae', 'ddsa', 'mw'],
    "anāstikya": ['mw'],
    "anāstīrṇa": ['ddsa'],
    "anāsvāda": ['ap90', 'mw'],
    "anāsvādita": ['ap90', 'cae', 'ddsa', 'mw'],
    "anāsādayant": ['cae'],
    "anāsādayat": ['ddsa'],
    "anāsādita": ['ap90', 'mw'],
    "anāsāditavigraha": ['mw'],
    "anāsādya": ['cae', 'mw'],
    "anātapa": ['ap90', 'cae', 'ddsa', 'mw'],
    "anātata": ['mw'],
    "anātha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anāthapiṇḍada": ['bhs', 'mw'],
    "anāthapiṇḍika": ['bhs', 'mw'],
    "anāthasabhā": ['mw'],
    "anātiṣṭhant": ['cae'],
    "anātma": ['mw'],
    "anātmajña": ['cae', 'ddsa', 'mw'],
    "anātmaka": ['ap90', 'mw'],
    "anātman": ['ap90', 'cae', 'ddsa', 'mw'],
    "anātmanīna": ['ap90', 'mw'],
    "anātmanīya": ['bhs'],
    "anātmapratyavekṣā": ['mw'],
    "anātmatva": ['cae', 'ddsa'],
    "anātmatā": ['mw'],
    "anātmavant": ['cae'],
    "anātmavat": ['ap90', 'ddsa', 'mw'],
    "anātmya": ['ap90', 'mw'],
    "anātmīya": ['bhs'],
    "anātreyī": ['ddsa'],
    "anātura": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "anātyantika": ['mw'],
    "anātyaṃtika": ['ap90'],
    "anātāpi": ['cped'],
    "anātāpin": ['cped'],
    "anāvara": ['cped'],
    "anāvaraṇa": ['bhs'],
    "anāvaraṇadarśin": ['bhs'],
    "anāvaraṇadassāvi": ['cped'],
    "anāvaraṇadassāvin": ['cped'],
    "anāvaraṇadharmagaganaprabha": ['bhs'],
    "anāvaraṇajñānaviśuddhigarbha": ['bhs'],
    "anāvaraṇamati": ['bhs'],
    "anāvaraṇasvaramaṇḍalamadhuranirghoṣagarbha": ['bhs'],
    "anāvaraṇin": ['mw'],
    "anāvartikadharma": ['bhs'],
    "anāvartin": ['ap90', 'ddsa'],
    "anāvartiḥ": ['ap90'],
    "anāvasa": ['cped'],
    "anāvatapta": ['bhs'],
    "anāvatti": ['cped'],
    "anāvattidhamma": ['cped'],
    "anāvayas": ['mw'],
    "anāvayha": ['cped'],
    "anāvayā": ['ap90'],
    "anāvaṭa": ['cped'],
    "anāvaṭṭi": ['cped'],
    "anāvaṭṭin": ['cped'],
    "anāvedita": ['mw'],
    "anāviddha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anāviddhavarṇa": ['bhs'],
    "anāvikatvā": ['cped'],
    "anāvila": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "anāvilasaṃkalpa": ['bhs'],
    "anāviṣkṛta": ['cae', 'ddsa'],
    "anāviṣkṛtapāpa": ['cae'],
    "anāvraska": ['mw'],
    "anāvraskaḥ": ['ap90'],
    "anāvuta": ['cped'],
    "anāvyādha": ['mw'],
    "anāvyūha": ['bhs'],
    "anāvādi": ['ddsa'],
    "anāvṛt": ['cae', 'ddsa', 'gra', 'mw'],
    "anāvṛta": ['bhs', 'cae', 'ddsa', 'mw'],
    "anāvṛtta": ['ap90', 'mw'],
    "anāvṛtti": ['cae', 'mw'],
    "anāvṛttibhaya": ['mw'],
    "anāvṛttidharman": ['bhs'],
    "anāvṛttikadharmin": ['bhs'],
    "anāvṛttiḥ": ['ap90'],
    "anāvṛṣṭi": ['cae', 'ddsa', 'mw'],
    "anāvṛṣṭiḥ": ['ap90'],
    "anāya": ['ddsa'],
    "anāyaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "anāyana": ['ap90'],
    "anāyasita": ['ddsa'],
    "anāyasāgra": ['mw'],
    "anāyata": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anāyatana": ['bhs', 'mw'],
    "anāyatanaso": ['cped'],
    "anāyatanavat": ['mw'],
    "anāyatikṣama": ['ddsa'],
    "anāyatta": ['ap90', 'ddsa', 'mw'],
    "anāyattavṛtti": ['mw'],
    "anāyattavṛttitā": ['mw'],
    "anāyatārgala": ['cae'],
    "anāyikā": ['bhs'],
    "anāyudha": ['cae', 'ddsa', 'gra', 'mw'],
    "anāyus": ['mw'],
    "anāyussa": ['cped'],
    "anāyuvāna": ['mw'],
    "anāyuṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "anāyuṣā": ['mw'],
    "anāyānt": ['cae'],
    "anāyāsa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "anāyāsakṛta": ['mw'],
    "anāyāsena": ['mw'],
    "anāyāta": ['ddsa'],
    "anāyūha": ['bhs', 'cped'],
    "anāyūhat": ['cped'],
    "anāññāta": ['cped'],
    "anāśa": ['ap90', 'ddsa', 'mw'],
    "anāśaka": ['ap90', 'ddsa', 'mw'],
    "anāśakanivṛtta": ['mw'],
    "anāśakin": ['mw'],
    "anāśakāyana": ['mw'],
    "anāśakāyanaṃ": ['ap90'],
    "anāśasta": ['ap90', 'gra', 'mw'],
    "anāścarya": ['bhs', 'mw'],
    "anāśin": ['ap90', 'cae', 'ddsa', 'mw'],
    "anāśis": ['ddsa', 'mw'],
    "anāśita": ['ddsa', 'mw'],
    "anāśiṣṭa": ['mw'],
    "anāśiṣṭha": ['ddsa'],
    "anāśrama": ['ddsa'],
    "anāśramavāsa": ['mw'],
    "anāśramevāsa": ['mw'],
    "anāśramin": ['ap90', 'mw'],
    "anāśrava": ['ap90', 'bhs', 'ddsa'],
    "anāśraya": ['ap90', 'ddsa', 'mw'],
    "anāśrita": ['ap90', 'cae', 'ddsa', 'mw'],
    "anāśu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anāśvas": ['ap90', 'cae', 'ddsa', 'mw'],
    "anāśvāsa": ['bhs'],
    "anāśvāsika": ['bhs', 'mw'],
    "anāśya": ['mw'],
    "anāśāsya": ['ddsa'],
    "anāśīrdā": ['gra', 'mw'],
    "anāśīrka": ['mw'],
    "anāḍhya": ['mw'],
    "anāḍhyambhaviṣṇu": ['mw'],
    "anāḷhika": ['cped'],
    "anāḷhiya": ['cped'],
    "anāṣṭra": ['cae', 'ddsa', 'mw'],
    "anāṭa": ['mw'],
    "anī": ['mw'],
    "anīca": ['ap90', 'ddsa', 'mw'],
    "anīcadarśin": ['mw'],
    "anīcais": ['mw'],
    "anīcaistana": ['mw'],
    "anīcānuvartin": ['mw'],
    "anīdṛgātman": ['ddsa'],
    "anīdṛśa": ['mw'],
    "anīgha": ['cped'],
    "anīha": ['ap90', 'mw'],
    "anīhamāna": ['cae', 'ddsa', 'mw'],
    "anīhita": ['ap90', 'cae', 'ddsa', 'mw'],
    "anīhā": ['mw'],
    "anījāna": ['ddsa'],
    "anīka": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "anīkadassana": ['cped'],
    "anīkagga": ['cped'],
    "anīkastha": ['mw'],
    "anīkavat": ['ap90', 'mw'],
    "anīkavidāraṇa": ['mw'],
    "anīkaśas": ['mw'],
    "anīkaśaḥ": ['ap90'],
    "anīkaḥ": ['ap90'],
    "anīkaṭṭha": ['cped'],
    "anīkinī": ['ap90', 'mw'],
    "anīkṣaka": ['mw'],
    "anīkṣaṇa": ['mw'],
    "anīla": ['ap90', 'mw'],
    "anīlavājin": ['mw'],
    "anīl̤a": ['mw'],
    "anīpsita": ['cae', 'ddsa', 'mw'],
    "anīraśana": ['ddsa', 'mw'],
    "anīrita": ['mw'],
    "anīrṣu": ['bhs'],
    "anīrṣuka": ['bhs'],
    "anīrṣya": ['cae', 'ddsa'],
    "anīrṣyu": ['cae'],
    "anīti": ['cae', 'cped', 'ddsa', 'mw'],
    "anītiha": ['cped'],
    "anītijña": ['cae', 'mw'],
    "anītika": ['bhs', 'cped'],
    "anītivid": ['mw'],
    "anītiśāstrajña": ['ddsa'],
    "anītiḥ": ['ap90'],
    "anīśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "anīśatva": ['mw'],
    "anīśvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "anīśvaratva": ['mw'],
    "anīśvaratā": ['mw'],
    "anīśvaravādin": ['mw'],
    "anīśā": ['mw'],
    "anīḍa": ['ap90', 'gra', 'mw'],
    "anīḷaka": ['cped'],
    "anūbandhya": ['mw'],
    "anūbaṃdhya": ['ap90'],
    "anūccalita": ['bhs'],
    "anūci": ['mw'],
    "anūcya": ['mw'],
    "anūcyate": ['mw'],
    "anūcyaṃ": ['ap90'],
    "anūcāna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anūcī": ['ddsa'],
    "anūcīna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anūcīnagarbha": ['mw'],
    "anūcīnāham": ['mw'],
    "anūd": ['mw'],
    "anūdaka": ['cped', 'ddsa', 'mw'],
    "anūdakaṃ": ['ap90'],
    "anūdara": ['mw'],
    "anūdas": ['mw'],
    "anūdbhāsin": ['mw'],
    "anūddeśa": ['mw'],
    "anūddeśaḥ": ['ap90'],
    "anūddhā": ['mw'],
    "anūddhṛ": ['mw'],
    "anūddru": ['mw'],
    "anūddṛṃh": ['mw'],
    "anūde": ['mw'],
    "anūdhas": ['gra', 'mw'],
    "anūdi": ['mw'],
    "anūdita": ['mw'],
    "anūdvā": ['mw'],
    "anūdya": ['ap90', 'mw'],
    "anūdyamāna": ['mw'],
    "anūha": ['ap90', 'mw'],
    "anūhata": ['bhs', 'cped'],
    "anūhya": ['mw'],
    "anūjji": ['mw'],
    "anūka": ['cae', 'ddsa', 'gra', 'mw'],
    "anūkaḥ": ['ap90'],
    "anūkia": ['gra'],
    "anūkta": ['ap90', 'cae', 'mw'],
    "anūkti": ['ap90', 'cae', 'mw'],
    "anūktitva": ['mw'],
    "anūkya": ['gra', 'mw'],
    "anūkā": ['mw'],
    "anūkāśa": ['ddsa', 'mw'],
    "anūkāśaḥ": ['ap90'],
    "anūkāśin": ['mw'],
    "anūkṣ": ['mw'],
    "anūlā": ['ddsa', 'mw'],
    "anūna": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "anūnaguru": ['mw'],
    "anūnaka": ['bhs', 'cped', 'mw'],
    "anūnavarcas": ['gra', 'mw'],
    "anūnavastuka": ['cae', 'mw'],
    "anūnnī": ['mw'],
    "anūnā": ['mw'],
    "anūpa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anūpabṛṃhayati": ['bhs'],
    "anūpadas": ['mw'],
    "anūpadeśa": ['mw'],
    "anūpadhā": ['mw'],
    "anūpadhīka": ['cped'],
    "anūpadhṛ": ['mw'],
    "anūpahata": ['cped'],
    "anūpaja": ['mw'],
    "anūpakhajja": ['cped'],
    "anūpalipta": ['bhs'],
    "anūpalitta": ['cped'],
    "anūpama": ['cped'],
    "anūpanāhi": ['cped'],
    "anūpanāhin": ['cped'],
    "anūpanīta": ['cped'],
    "anūpaprāya": ['mw'],
    "anūpasadam": ['mw'],
    "anūpasthā": ['mw'],
    "anūpavajja": ['cped'],
    "anūpavilāsa": ['mw'],
    "anūpaviś": ['mw'],
    "anūpavāda": ['cped'],
    "anūpaya": ['cped'],
    "anūpya": ['ap90', 'mw'],
    "anūpālu": ['mw'],
    "anūrdhva": ['ap90', 'mw'],
    "anūrdhvabhās": ['gra', 'mw'],
    "anūrdhvajñu": ['mw'],
    "anūrdhvaṃbhāvuka": ['mw'],
    "anūrjita": ['ap90', 'mw'],
    "anūrmi": ['ap90', 'gra', 'mw'],
    "anūru": ['ap90', 'ddsa', 'mw'],
    "anūrudh": ['gra', 'mw'],
    "anūrusārathi": ['mw'],
    "anūrādha": ['mw'],
    "anūsara": ['cped'],
    "anūti": ['gra', 'mw'],
    "anūtiḥ": ['ap90'],
    "anūtkram": ['mw'],
    "anūtpat": ['mw'],
    "anūtpā": ['mw'],
    "anūtsarga": ['mw'],
    "anūtsāram": ['mw'],
    "anūtsṛj": ['mw'],
    "anūtthita": ['ddsa'],
    "anūtthā": ['mw'],
    "anūtthāna": ['mw'],
    "anūtthātṛ": ['mw'],
    "anūvṛj": ['ap90', 'mw'],
    "anūyāja": ['ap90', 'mw'],
    "anūḍha": ['ap90', 'mw'],
    "anūḍhamāna": ['mw'],
    "anūḍhā": ['cae', 'ddsa', 'mw'],
    "anūḍhābhrātṛ": ['mw'],
    "anūḍhāgamana": ['mw'],
    "anūṣara": ['ap90', 'mw'],
    "anūṣarih": ['mw'],
    "anūṣita": ['mw'],
    "anūṣivas": ['ddsa'],
    "anūṣman": ['mw'],
    "anūṣmapara": ['mw'],
    "anṛc": ['ap90', 'cae', 'gra', 'mw'],
    "anṛca": ['cae', 'mw'],
    "anṛcam": ['mw'],
    "anṛcka": ['mw'],
    "anṛgvedavinīta": ['mw'],
    "anṛju": ['ap90', 'cae', 'gra', 'mw'],
    "anṛkka": ['mw'],
    "anṛkṣara": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anṛta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "anṛtabhāṣaṇa": ['cae'],
    "anṛtadeva": ['gra', 'mw'],
    "anṛtadviṣ": ['gra', 'mw'],
    "anṛtaka": ['ap90', 'bhs'],
    "anṛtakatha": ['mw'],
    "anṛtamaya": ['mw'],
    "anṛtapaśu": ['mw'],
    "anṛtapūrvam": ['cae'],
    "anṛtasarvasva": ['mw'],
    "anṛtasaṃgara": ['mw'],
    "anṛtasaṃhita": ['mw'],
    "anṛtavadana": ['mw'],
    "anṛtavrata": ['mw'],
    "anṛtavāc": ['mw'],
    "anṛtavādin": ['cae', 'mw'],
    "anṛtaṃvada": ['bhs'],
    "anṛtika": ['ddsa', 'mw'],
    "anṛtin": ['cae', 'mw'],
    "anṛtu": ['cae', 'mw'],
    "anṛtukanyā": ['mw'],
    "anṛtupā": ['gra', 'mw'],
    "anṛtuḥ": ['ap90'],
    "anṛtābhisandha": ['mw'],
    "anṛtākhyāna": ['mw'],
    "anṛtātmaka": ['cae', 'mw'],
    "anṛśaṃsa": ['mw'],
    "anṛśaṃsatā": ['mw'],
    "anṛṅga": ['mw'],
    "anṛṇa": ['ap90', 'cae', 'mw'],
    "anṛṇatva": ['mw'],
    "anṛṇatā": ['ap90', 'mw'],
    "anṛṇin": ['ap90', 'mw'],
    "anṛṇyatā": ['mw'],
    "anṛṇīkaraṇa": ['mw'],
    "anṛṣabha": ['mw'],
    "ap": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apa-iti": ['cped'],
    "apabarhis": ['ap90', 'mw'],
    "apabbhāra": ['bhs'],
    "apabbūhati": ['cped'],
    "apabbūhitvā": ['cped'],
    "apabhaj": ['mw'],
    "apabharaṇī": ['ap90', 'mw'],
    "apabhartavai": ['mw'],
    "apabhartṛ": ['ap90', 'cae', 'gra', 'mw'],
    "apabhaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "apabhid": ['mw'],
    "apabhraṃsa": ['mw'],
    "apabhraṃś": ['ap90'],
    "apabhraṃśa": ['cae', 'mw'],
    "apabhraṃśaḥ": ['ap90'],
    "apabhraṣṭa": ['ap90', 'cae', 'mw'],
    "apabhāṣ": ['ap90', 'mw'],
    "apabhāṣaṇa": ['mw'],
    "apabhāṣaṇaṃ": ['ap90'],
    "apabhāṣitavai": ['mw'],
    "apabhī": ['mw'],
    "apabhū": ['ap90', 'mw'],
    "apabhūti": ['mw'],
    "apabhūtiḥ": ['ap90'],
    "apabodhati": ['cped'],
    "apabrū": ['mw'],
    "apabyāma": ['cped'],
    "apabyūhati": ['cped'],
    "apabyūheti": ['cped'],
    "apabādh": ['mw'],
    "apabādha": ['bhs'],
    "apabāhuka": ['mw'],
    "apabāhukaḥ": ['ap90'],
    "apaca": ['cped', 'mw'],
    "apacamāna": ['cae', 'mw'],
    "apacamānaka": ['mw'],
    "apacana": ['mw'],
    "apacar": ['ap90', 'mw'],
    "apacaraka": ['bhs'],
    "apacarita": ['ap90', 'cae', 'mw'],
    "apacaya": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "apacayagāmin": ['cped'],
    "apacayati": ['bhs'],
    "apacayaḥ": ['ap90'],
    "apacayārāma": ['cped'],
    "apacaḥ": ['ap90'],
    "apacca": ['cped'],
    "apacchad": ['mw'],
    "apacchatra": ['ap90'],
    "apacchattra": ['mw'],
    "apacchat‍tra": ['ddsa'],
    "apaccheda": ['cae', 'mw'],
    "apacchedana": ['mw'],
    "apacchedaḥ": ['ap90'],
    "apacchid": ['mw'],
    "apacchāya": ['ap90', 'mw'],
    "apacchāyā": ['mw'],
    "apaccupekkhana": ['cped'],
    "apacetabba": ['cped'],
    "apacetas": ['mw'],
    "apacetṛ": ['mw'],
    "apaceyya": ['cped'],
    "apaci": ['ap90', 'mw'],
    "apacikīrṣu": ['mw'],
    "apacikīrṣā": ['mw'],
    "apacina": ['cped'],
    "apacinat": ['cped'],
    "apacinati": ['cped'],
    "apacineyya": ['cped'],
    "apacinitva": ['cped'],
    "apaciniyya": ['cped'],
    "apacināti": ['cped'],
    "apacit": ['ap90', 'mw'],
    "apacita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "apaciti": ['cae', 'cped', 'gra', 'mw'],
    "apacitimat": ['mw'],
    "apacitiḥ": ['ap90'],
    "apacitā": ['bhs'],
    "apacyava": ['gra', 'mw'],
    "apacyavaḥ": ['ap90'],
    "apacyu": ['ap90', 'mw'],
    "apacyuta": ['ap90'],
    "apacāra": ['cae', 'mw'],
    "apacāraḥ": ['ap90'],
    "apacārin": ['ap90', 'cae', 'mw'],
    "apacāy": ['ap90', 'mw'],
    "apacāyaka": ['bhs', 'mw'],
    "apacāyamāna": ['cped'],
    "apacāyanā": ['bhs'],
    "apacāyati": ['bhs', 'cped'],
    "apacāyika": ['cped'],
    "apacāyin": ['mw'],
    "apacāyita": ['ap90', 'bhs', 'mw'],
    "apacī": ['ap90', 'mw'],
    "apad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apada": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "apadah": ['mw'],
    "apadakṣiṇam": ['mw'],
    "apadakṣiṇaṃ": ['ap90'],
    "apadama": ['ap90', 'mw'],
    "apadarohiṇi": ['mw'],
    "apadarpa": ['mw'],
    "apadaruhā": ['mw'],
    "apadarśayati": ['bhs'],
    "apadas": ['mw'],
    "apadastha": ['mw'],
    "apadava": ['ap90', 'mw'],
    "apadavāpad": ['mw'],
    "apadaśa": ['ap90', 'mw'],
    "apadevatā": ['ap90', 'mw'],
    "apadeśa": ['bhs', 'cae', 'mw'],
    "apadeśaḥ": ['ap90'],
    "apadeśin": ['ap90', 'mw'],
    "apadeśya": ['ap90', 'mw'],
    "apadham": ['mw'],
    "apadhuram": ['mw'],
    "apadhvasta": ['ap90', 'cae', 'mw'],
    "apadhvaṃs": ['ap90', 'mw'],
    "apadhvaṃsa": ['cae', 'mw'],
    "apadhvaṃsaja": ['cae', 'mw'],
    "apadhvaṃsaḥ": ['ap90'],
    "apadhvaṃsin": ['ap90', 'mw'],
    "apadhvānta": ['cae', 'mw'],
    "apadhvāṃta": ['ap90'],
    "apadhyai": ['ap90', 'mw'],
    "apadhyāna": ['cae', 'mw'],
    "apadhyānaṃ": ['ap90'],
    "apadhā": ['ap90', 'cae', 'gra', 'mw'],
    "apadhāv": ['ap90', 'mw'],
    "apadhāvanaṃ": ['ap90'],
    "apadhū": ['mw'],
    "apadhūma": ['ap90', 'mw'],
    "apadhṛṣ": ['mw'],
    "apadibaddha": ['mw'],
    "apadisati": ['cped'],
    "apadisitabba": ['cped'],
    "apadissati": ['cped'],
    "apadiś": ['ap90', 'mw'],
    "apadiśam": ['mw'],
    "apadiśaṃ": ['ap90'],
    "apadiṣṭa": ['mw'],
    "apadma": ['cae', 'ddsa', 'mw'],
    "apadoṣa": ['mw'],
    "apadravya": ['ddsa', 'mw'],
    "apadravyaṃ": ['ap90'],
    "apadru": ['mw'],
    "apadruta": ['bhs'],
    "apadrā": ['mw'],
    "apaduṣpad": ['gra', 'mw'],
    "apadvāra": ['mw'],
    "apadvāraṃ": ['ap90'],
    "apadālaka": ['mw'],
    "apadāna": ['cae', 'cped', 'ddsa', 'mw'],
    "apadānasobhana": ['cped'],
    "apadānaṃ": ['ap90'],
    "apadānta": ['mw'],
    "apadāntara": ['mw'],
    "apadāntaram": ['mw'],
    "apadāntastha": ['mw'],
    "apadārtha": ['mw'],
    "apadārthaḥ": ['ap90'],
    "apadūṣaṇa": ['mw'],
    "apadṛṣṭi": ['mw'],
    "apadṝ": ['mw'],
    "apaga": ['ap90', 'ddsa', 'mw'],
    "apagabbha": ['cped'],
    "apagai": ['mw'],
    "apagalbha": ['ap90', 'mw'],
    "apagam": ['ap90', 'mw'],
    "apagama": ['cae', 'ddsa', 'mw'],
    "apagamana": ['mw'],
    "apagamaḥ": ['ap90'],
    "apagara": ['mw'],
    "apagaraḥ": ['ap90'],
    "apagarjita": ['ap90', 'ddsa', 'mw'],
    "apagata": ['ap90', 'cped', 'mw'],
    "apagata-kāḷaka": ['cped'],
    "apagatagabbha": ['cped'],
    "apagatajimha": ['cped'],
    "apagatakālaka": ['bhs', 'mw'],
    "apagataphegguka": ['cped'],
    "apagatatejaska": ['ddsa'],
    "apagatavaṅka": ['cped'],
    "apagatavyādhi": ['mw'],
    "apagatiḥ": ['ap90'],
    "apagaṃḍaḥ": ['ap90'],
    "apaghana": ['cae', 'ddsa', 'mw'],
    "apaghanaḥ": ['ap90'],
    "apaghaṭ": ['mw'],
    "apaghāta": ['cae', 'ddsa', 'mw'],
    "apaghātaka": ['cae', 'mw'],
    "apaghātaḥ": ['ap90'],
    "apaghātin": ['ap90', 'mw'],
    "apaghāṭayati": ['bhs'],
    "apaghāṭilā": ['mw'],
    "apaghṛṇa": ['ddsa', 'mw'],
    "apagoha": ['gra', 'mw'],
    "apagohaḥ": ['ap90'],
    "apagopura": ['ap90', 'mw'],
    "apagoram": ['mw'],
    "apagoraṇa": ['mw'],
    "apagrah": ['mw'],
    "apagrāma": ['mw'],
    "apaguh": ['ap90', 'mw'],
    "apagur": ['ap90', 'mw'],
    "apaguṇa": ['ddsa'],
    "apaguṇaḥ": ['ap90'],
    "apagā": ['mw'],
    "apagāram": ['mw'],
    "apagāraṃ": ['ap90'],
    "apagūhamāna": ['mw'],
    "apagūḍha": ['mw'],
    "apagṛhya": ['mw'],
    "apagṝ": ['mw'],
    "apaha": ['ap90', 'cae', 'ddsa', 'mw'],
    "apahala": ['ap90', 'mw'],
    "apahan": ['ap90', 'mw'],
    "apahanana": ['mw'],
    "apahananaṃ": ['ap90'],
    "apahantṛ": ['cae', 'mw'],
    "apahara": ['mw'],
    "apaharas": ['mw'],
    "apaharati": ['bhs'],
    "apaharaṇa": ['bhs', 'cae', 'mw'],
    "apaharaṇaṃ": ['ap90'],
    "apaharaṇīya": ['mw'],
    "apahari": ['cped'],
    "apaharin": ['cped'],
    "apahartṛ": ['ap90', 'cae', 'mw'],
    "apaharṣa": ['mw'],
    "apahas": ['ap90', 'mw'],
    "apahasita": ['mw'],
    "apahasitaṃ": ['ap90'],
    "apahasta": ['mw'],
    "apahastaka": ['mw'],
    "apahastay": ['cae'],
    "apahastaya": ['ddsa', 'mw'],
    "apahastayati": ['ap90'],
    "apahastaḥ": ['ap90'],
    "apahastita": ['ap90', 'mw'],
    "apahata": ['cped', 'mw'],
    "apahatapāpman": ['mw'],
    "apahati": ['cae', 'mw'],
    "apahatiḥ": ['ap90'],
    "apahatta": ['cped'],
    "apahattar": ['cped'],
    "apahelana": ['mw'],
    "apahelā": ['mw'],
    "apahi": ['mw'],
    "apahita": ['mw'],
    "apahiṃkāra": ['mw'],
    "apahnava": ['cae', 'mw'],
    "apahnavana": ['mw'],
    "apahnavaḥ": ['ap90'],
    "apahnotṛ": ['mw'],
    "apahnu": ['ap90', 'mw'],
    "apahnuta": ['mw'],
    "apahnuti": ['mw'],
    "apahnutiḥ": ['ap90'],
    "apahnuvāna": ['mw'],
    "apahrepaṇa": ['mw'],
    "apahrāsa": ['mw'],
    "apahrāsaḥ": ['ap90'],
    "apahvara": ['mw'],
    "apahā": ['ap90', 'mw'],
    "apahānaṃ": ['ap90'],
    "apahāni": ['mw'],
    "apahāniḥ": ['ap90'],
    "apahāra": ['cae', 'ddsa', 'mw'],
    "apahāraka": ['ap90', 'mw'],
    "apahārakam": ['bhs'],
    "apahāravarman": ['mw'],
    "apahāraḥ": ['ap90'],
    "apahāraṇa": ['mw'],
    "apahārika": ['bhs'],
    "apahārin": ['mw'],
    "apahārita": ['mw'],
    "apahārya": ['mw'],
    "apahāsa": ['mw'],
    "apahāsya": ['mw'],
    "apahāya": ['ap90', 'cae', 'mw'],
    "apahṛ": ['ap90', 'mw'],
    "apahṛt": ['mw'],
    "apahṛta": ['ap90', 'mw'],
    "apahṛtabhāra": ['bhs'],
    "apahṛtavijñāna": ['mw'],
    "apahṛti": ['mw'],
    "apaiśuna": ['cae', 'ddsa', 'mw'],
    "apajaha": ['cped'],
    "apajargurāṇa": ['ap90'],
    "apajaya": ['mw'],
    "apajayaḥ": ['ap90'],
    "apajayya": ['mw'],
    "apaji": ['ap90', 'mw'],
    "apajighāṃsu": ['mw'],
    "apajihīrṣu": ['mw'],
    "apajihīrṣā": ['mw'],
    "apajita": ['cped'],
    "apajjhāyati": ['cped'],
    "apajvara": ['cae', 'mw'],
    "apajya": ['mw'],
    "apajñā": ['ap90', 'mw'],
    "apajñāna": ['mw'],
    "apajñānaṃ": ['ap90'],
    "apajāta": ['ddsa', 'mw'],
    "apajātaḥ": ['ap90'],
    "apakalaṃkaḥ": ['ap90'],
    "apakalaṅka": ['mw'],
    "apakalmaṣa": ['mw'],
    "apakantati": ['cped'],
    "apakara": ['bhs'],
    "apakaraṇa": ['mw'],
    "apakaraṇaṃ": ['ap90'],
    "apakarman": ['ap90', 'mw'],
    "apakartana": ['ddsa', 'mw'],
    "apakartṛ": ['ap90', 'mw'],
    "apakaruṇa": ['mw'],
    "apakarṣa": ['bhs', 'cae', 'mw'],
    "apakarṣaka": ['ap90', 'cae', 'mw'],
    "apakarṣasama": ['mw'],
    "apakarṣaḥ": ['ap90'],
    "apakarṣaṇa": ['ap90', 'cae', 'mw'],
    "apakarṣaṇatā": ['bhs'],
    "apakarṣaṇā": ['bhs'],
    "apakarṣikā": ['bhs'],
    "apakarṣin": ['bhs', 'mw'],
    "apakarṣitaka": ['bhs'],
    "apakassa": ['cped'],
    "apakassati": ['cped'],
    "apakauśalī": ['ap90'],
    "apakaḍḍhanta": ['cped'],
    "apakaḍḍhati": ['cped'],
    "apakaḍḍhi": ['cped'],
    "apakaṇṭaka": ['mw'],
    "apakaṣ": ['mw'],
    "apakaṣāya": ['mw'],
    "apakaṣāyatva": ['mw'],
    "apakaṭṭha": ['cped'],
    "apakhyāti": ['mw'],
    "apakiraṇaṃ": ['ap90'],
    "apakiritūna": ['cped'],
    "apakkamati": ['cped'],
    "apakkami": ['cped'],
    "apakkamiṁsu": ['cped'],
    "apakkamma": ['cped'],
    "apakkanta": ['cped'],
    "apakkaṭṭha": ['cped'],
    "apakkā": ['bhs'],
    "apakośa": ['mw'],
    "apakoṭana": ['bhs'],
    "apakram": ['ap90', 'mw'],
    "apakrama": ['cae', 'ddsa', 'mw'],
    "apakramamaṇḍala": ['mw'],
    "apakramaḥ": ['ap90'],
    "apakramaṇa": ['mw'],
    "apakramaṇaṃ": ['ap90'],
    "apakramin": ['ap90', 'mw'],
    "apakriyā": ['ap90', 'mw'],
    "apakrośa": ['mw'],
    "apakrośaḥ": ['ap90'],
    "apakruś": ['mw'],
    "apakruṣṭa": ['cae'],
    "apakrāma": ['mw'],
    "apakrāmam": ['mw'],
    "apakrāmuka": ['mw'],
    "apakrānta": ['bhs', 'mw'],
    "apakrāntaka": ['bhs'],
    "apakrāntamedha": ['mw'],
    "apakrānti": ['mw'],
    "apakrī": ['mw'],
    "apakti": ['mw'],
    "apaktiḥ": ['ap90'],
    "apakubjaka": ['bhs'],
    "apakukṣi": ['mw'],
    "apakuñja": ['mw'],
    "apakva": ['ap90', 'ddsa', 'mw'],
    "apakvabuddhi": ['mw'],
    "apakvatā": ['mw'],
    "apakvāśin": ['mw'],
    "apakāma": ['gra', 'mw'],
    "apakāmam": ['mw'],
    "apakāmaḥ": ['ap90'],
    "apakāra": ['cae', 'mw'],
    "apakāragir": ['mw'],
    "apakāraka": ['ap90', 'mw'],
    "apakāratā": ['mw'],
    "apakāraśabda": ['mw'],
    "apakāraḥ": ['ap90'],
    "apakārin": ['cae', 'mw'],
    "apakārārthin": ['mw'],
    "apakāsati": ['cped'],
    "apakīrti": ['mw'],
    "apakṛ": ['ap90', 'mw'],
    "apakṛt": ['ddsa', 'mw'],
    "apakṛta": ['ap90', 'cae', 'mw'],
    "apakṛti": ['mw'],
    "apakṛtiḥ": ['ap90'],
    "apakṛtya": ['mw'],
    "apakṛṣ": ['ap90', 'mw'],
    "apakṛṣṭa": ['ap90', 'cae', 'mw'],
    "apakṛṣṭacetana": ['mw'],
    "apakṛṣṭajāti": ['mw'],
    "apakṛṣṭatva": ['mw'],
    "apakṛṣṭatā": ['mw'],
    "apakṝ": ['ap90', 'mw'],
    "apakṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "apakṣalopa": ['cae', 'ddsa'],
    "apakṣapuccha": ['mw'],
    "apakṣapāta": ['mw'],
    "apakṣapātin": ['mw'],
    "apakṣasāda": ['cae'],
    "apakṣatā": ['mw'],
    "apakṣaya": ['cae', 'ddsa', 'mw'],
    "apakṣayaḥ": ['ap90'],
    "apakṣaṇa": ['bhs'],
    "apakṣepaḥ": ['ap90'],
    "apakṣepaṇa": ['mw'],
    "apakṣi": ['ap90', 'mw'],
    "apakṣip": ['ap90', 'mw'],
    "apakṣipta": ['mw'],
    "apakṣita": ['mw'],
    "apakṣya": ['bhs'],
    "apakṣāla": ['bhs'],
    "apakṣīṇa": ['ap90', 'mw'],
    "apala": ['ap90', 'mw'],
    "apalakṣaṇa": ['bhs'],
    "apalakṣmaṇa": ['mw'],
    "apalap": ['ap90', 'mw'],
    "apalapana": ['mw'],
    "apalapanaṃ": ['ap90'],
    "apalapita": ['mw'],
    "apalatābhavana": ['ddsa'],
    "apalekhana": ['cped'],
    "apalepa": ['cped'],
    "apalepapatita": ['cped'],
    "apalikh": ['mw'],
    "apalita": ['mw'],
    "apalokana": ['cped'],
    "apalokana-kamma": ['cped'],
    "apalokayati": ['cped'],
    "apalokenta": ['cped'],
    "apalokesi": ['cped'],
    "apaloketabba": ['cped'],
    "apaloketi": ['cped'],
    "apaloketvā": ['cped'],
    "apalokita": ['cped'],
    "apalpūlanakṛta": ['mw'],
    "apalupam": ['mw'],
    "apalyūlanaṃ": ['ap90'],
    "apalāla": ['bhs', 'mw'],
    "apalāletabba": ['cped'],
    "apalāpa": ['mw'],
    "apalāpadaṇḍa": ['mw'],
    "apalāpin": ['ap90', 'cae', 'mw'],
    "apalāsikā": ['mw'],
    "apalāyana": ['cae'],
    "apalāśa": ['gra', 'mw'],
    "apalāḷana": ['cped'],
    "apalāḷeti": ['cped'],
    "apalāṣikā": ['ap90', 'mw'],
    "apalāṣin": ['ap90', 'mw'],
    "apalāṣuka": ['mw'],
    "apama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apamada": ['mw'],
    "apamajyā": ['mw'],
    "apamakṣetra": ['mw'],
    "apamala": ['mw'],
    "apamamaṇḍala": ['mw'],
    "apaman": ['ap90'],
    "apamanyu": ['mw'],
    "apamarda": ['mw'],
    "apamardana": ['bhs'],
    "apamardaḥ": ['ap90'],
    "apamarśa": ['cae', 'mw'],
    "apamarśaḥ": ['ap90'],
    "apamatsara": ['bhs'],
    "apamavṛtta": ['mw'],
    "apamaśiñjinī": ['mw'],
    "apamaṅgala": ['mw'],
    "apamaṇḍala": ['mw'],
    "apame": ['mw'],
    "apamitya": ['ap90', 'mw'],
    "apamlukta": ['cae', 'mw'],
    "apamud": ['mw'],
    "apamukha": ['ap90', 'mw'],
    "apamukham": ['mw'],
    "apamyakṣ": ['mw'],
    "apamā": ['mw'],
    "apamāna": ['cae', 'mw'],
    "apamānaḥ": ['ap90'],
    "apamānin": ['ap90', 'mw'],
    "apamānita": ['mw'],
    "apamānya": ['mw'],
    "apamāra": ['cped'],
    "apamārga": ['cae', 'mw'],
    "apamārgaka": ['bhs'],
    "apamārgaḥ": ['ap90'],
    "apamārika": ['cped'],
    "apamārin": ['mw'],
    "apamāriya": ['cped'],
    "apamārjana": ['cae', 'mw'],
    "apamārjanaṃ": ['ap90'],
    "apamūrdhan": ['ap90', 'mw'],
    "apamṛga": ['cae', 'mw'],
    "apamṛj": ['ap90', 'mw'],
    "apamṛtyu": ['mw'],
    "apamṛtyuḥ": ['ap90'],
    "apamṛṣita": ['ap90', 'mw'],
    "apamṛṣṭa": ['mw'],
    "apamṛṣṭi": ['mw'],
    "apanaddha": ['cped'],
    "apanaddhakalāpa": ['cped'],
    "apanah": ['mw'],
    "apanam": ['mw'],
    "apanamati": ['cped'],
    "apanasa": ['ap90', 'mw'],
    "apanata": ['cae', 'cped', 'mw'],
    "apanaya": ['cae', 'ddsa', 'mw'],
    "apanayana": ['cae', 'mw'],
    "apanayanaṃ": ['ap90'],
    "apanayaḥ": ['ap90'],
    "apanayin": ['mw'],
    "apanaś": ['mw'],
    "apaneti": ['cped'],
    "apanetvā": ['cped'],
    "apanetṛ": ['mw'],
    "apaneya": ['cae', 'mw'],
    "apaneyya": ['cped'],
    "apanidha": ['cped'],
    "apanidhenta": ['cped'],
    "apanidhesuṁ": ['cped'],
    "apanidheti": ['cped'],
    "apanidhi": ['mw'],
    "apanidhita": ['cped'],
    "apanidhā": ['mw'],
    "apanidhāpeti": ['cped'],
    "apanidra": ['mw'],
    "apanidrat": ['mw'],
    "apanihnu": ['mw'],
    "apanilī": ['mw'],
    "apaninīṣu": ['mw'],
    "apaninīṣā": ['mw'],
    "apanirvāṇa": ['mw'],
    "apaniṣāduka": ['mw'],
    "apanna": ['ap90'],
    "apannada": ['ddsa', 'mw'],
    "apannadat": ['mw'],
    "apannagṛha": ['mw'],
    "apanoda": ['cae', 'mw'],
    "apanodaka": ['mw'],
    "apanodana": ['cae', 'mw'],
    "apanodya": ['mw'],
    "apanthadāyin": ['bhs', 'ddsa', 'mw'],
    "apanu": ['mw'],
    "apanud": ['ap90', 'mw'],
    "apanuda": ['mw'],
    "apanudita": ['cped'],
    "apanuditar": ['cped'],
    "apanujja": ['cped'],
    "apanunutsu": ['cae', 'mw'],
    "apanutti": ['cae', 'mw'],
    "apanuttiḥ": ['ap90'],
    "apanyāyya": ['mw'],
    "apanyāyyatva": ['mw'],
    "apanābhi": ['mw'],
    "apanāma": ['mw'],
    "apanāman": ['ap90', 'mw'],
    "apanāmayati": ['bhs'],
    "apanāmesi": ['cped'],
    "apanāmeti": ['cped'],
    "apanāmetvā": ['cped'],
    "apanāya": ['bhs'],
    "apanī": ['ap90', 'mw'],
    "apanīta": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "apanīti": ['mw'],
    "apanīyati": ['cped'],
    "apanīyyati": ['cped'],
    "apapa": ['bhs', 'mw'],
    "apapad": ['mw'],
    "apapare": ['mw'],
    "apaparyāvṛt": ['mw'],
    "apapayas": ['ap90', 'ddsa', 'mw'],
    "apapitva": ['gra', 'mw'],
    "apapitvaṃ": ['ap90'],
    "apapivas": ['mw'],
    "apaplu": ['mw'],
    "apapradāna": ['mw'],
    "apapradānaṃ": ['ap90'],
    "apapragā": ['mw'],
    "apaprajātā": ['ap90', 'mw'],
    "apaprasara": ['mw'],
    "apapravrājana": ['bhs'],
    "apapre": ['mw'],
    "apaproṣita": ['mw'],
    "apaproṣitaṃ": ['ap90'],
    "apapru": ['mw'],
    "apapruth": ['mw'],
    "apapāda": ['ap90'],
    "apapādatra": ['mw'],
    "apapāna": ['mw'],
    "apapānaṃ": ['ap90'],
    "apapātra": ['ap90', 'cae', 'mw'],
    "apapātrika": ['cae'],
    "apapātrita": ['mw'],
    "apapātritaḥ": ['ap90'],
    "apapāṭha": ['mw'],
    "apapāṭhaḥ": ['ap90'],
    "apapīḍā": ['mw'],
    "apapūta": ['ap90', 'mw'],
    "apapṛ": ['mw'],
    "apara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "aparabhāva": ['mw'],
    "aparacāmara": ['bhs'],
    "aparadakṣiṇam": ['mw'],
    "aparaddha": ['cped'],
    "aparaddhuṁ": ['cped'],
    "aparadiś": ['ddsa'],
    "aparadīkṣin": ['mw'],
    "aparagandhikā": ['mw'],
    "aparagayā": ['bhs'],
    "aparagodāna": ['mw'],
    "aparagodāni": ['mw'],
    "aparagodānīya": ['bhs'],
    "aparahaimana": ['mw'],
    "aparahemanta": ['mw'],
    "aparaja": ['mw'],
    "aparajaladhi": ['ddsa'],
    "aparajana": ['mw'],
    "aparajjhati": ['cped'],
    "aparajjhaṁ": ['cped'],
    "aparajju": ['cped'],
    "aparajjugata": ['cped'],
    "aparajjukāto": ['bhs'],
    "aparakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "aparakāla": ['mw'],
    "aparakānyakubja": ['mw'],
    "aparakāya": ['mw'],
    "aparakīya": ['bhs'],
    "aparakṣa": ['bhs'],
    "aparaloka": ['mw'],
    "aparam": ['mw'],
    "aparamātar": ['bhs'],
    "aparanidāgha": ['mw'],
    "aparanta": ['cped'],
    "aparantakappika": ['cped'],
    "aparantanudiṭṭhi": ['cped'],
    "aparantanudiṭṭhin": ['cped'],
    "aparapajā": ['cped'],
    "aparapakṣa": ['cae', 'ddsa', 'mw'],
    "aparapakṣīya": ['mw'],
    "aparapara": ['cped', 'mw'],
    "aparaparaṁ": ['cped'],
    "aparapañcāla": ['mw'],
    "aparapratyaya": ['bhs'],
    "aparapraṇeya": ['mw'],
    "aparapuraṃjaya": ['bhs'],
    "aparapuruṣa": ['mw'],
    "apararājāvavādakasūtra": ['bhs'],
    "apararātra": ['cae', 'mw'],
    "apararātri": ['mw'],
    "aparasad": ['mw'],
    "aparasaktha": ['mw'],
    "aparaspara": ['ap90', 'mw'],
    "aparasparasambhūta": ['ddsa', 'mw'],
    "aparasparasaṃbhūta": ['cae'],
    "aparasvara": ['bhs'],
    "aparasvastika": ['mw'],
    "aparata": ['mw'],
    "aparatas": ['cae', 'ddsa', 'mw'],
    "aparathā": ['ap90', 'ddsa'],
    "aparatiḥ": ['ap90'],
    "aparatra": ['ap90', 'cae', 'mw'],
    "aparatva": ['ddsa', 'mw'],
    "aparatā": ['ap90', 'mw'],
    "aparava": ['mw'],
    "aparavaktra": ['cae'],
    "aparavaktrā": ['mw'],
    "aparavallabha": ['mw'],
    "aparavarṣā": ['mw'],
    "aparavat": ['ap90', 'mw'],
    "aparavaḥ": ['ap90'],
    "aparavedanīya": ['mw'],
    "aparavojjhita": ['mw'],
    "aparayoga": ['mw'],
    "aparañj": ['mw'],
    "aparaśaila": ['bhs'],
    "aparaśarad": ['mw'],
    "aparaśuvṛkṇa": ['cae', 'ddsa', 'mw'],
    "aparaśvas": ['mw'],
    "aparaṁ": ['cped'],
    "aparaṃj": ['ap90'],
    "aparaṇṇa": ['cped'],
    "aparedyus": ['cae', 'ddsa', 'mw'],
    "aparedyuḥ": ['ap90'],
    "aparejjukāto": ['bhs'],
    "aparena": ['cped'],
    "aparetarā": ['mw'],
    "apareṇa": ['ddsa', 'mw'],
    "aparhāṇa": ['mw'],
    "aparibhakṣa": ['mw'],
    "aparibhinna": ['bhs', 'mw'],
    "aparibhogam": ['mw'],
    "aparibhraśyamāna": ['mw'],
    "aparibhāṣita": ['mw'],
    "aparibādha": ['cae', 'mw'],
    "aparicalita": ['mw'],
    "aparicaya": ['cae', 'ddsa'],
    "aparicayin": ['ap90', 'mw'],
    "aparicchada": ['ap90', 'cae', 'mw'],
    "aparicchanna": ['mw'],
    "apariccheda": ['cae', 'mw'],
    "aparicchedaḥ": ['ap90'],
    "aparicchinna": ['ap90', 'cae', 'mw'],
    "aparicchādita": ['mw'],
    "apariceya": ['mw'],
    "aparicita": ['cae', 'mw'],
    "aparigata": ['mw'],
    "aparigaṇya": ['mw'],
    "aparighaṁsanta": ['cped'],
    "aparigraha": ['ap90', 'cae', 'mw'],
    "aparigrāhya": ['mw'],
    "apariharaṇīya": ['ap90', 'mw'],
    "aparihata": ['cae', 'ddsa'],
    "aparihita": ['mw'],
    "aparihvṛta": ['ap90', 'gra', 'mw'],
    "aparihāra": ['cae'],
    "aparihārya": ['cae', 'mw'],
    "aparihāṇa": ['mw'],
    "aparihāṇīya": ['bhs'],
    "aparihīyamāna": ['cae'],
    "aparihīyamāṇa": ['mw'],
    "aparihīṇakālam": ['mw'],
    "aparihṛta": ['cae'],
    "aparijyāni": ['mw'],
    "aparijyāniḥ": ['ap90'],
    "aparijñāta": ['cae'],
    "aparijāta": ['mw'],
    "aparijīrṇa": ['mw'],
    "aparikalita": ['mw'],
    "aparikheda": ['bhs'],
    "aparikhedana": ['bhs'],
    "aparikhedanatā": ['bhs'],
    "aparikhinna": ['bhs'],
    "apariklinna": ['mw'],
    "aparikliṣṭa": ['cae'],
    "aparikrama": ['ap90', 'cae', 'ddsa', 'mw'],
    "aparikrāmam": ['mw'],
    "aparikāṅkṣin": ['bhs'],
    "aparikṣata": ['cae'],
    "aparilopa": ['mw'],
    "aparilupta": ['mw'],
    "aparimeya": ['cae', 'mw'],
    "aparimita": ['bhs', 'cae', 'mw'],
    "aparimitadhā": ['mw'],
    "aparimitaguṇadharma": ['bhs'],
    "aparimitaguṇagaṇa": ['mw'],
    "aparimitakṛtvas": ['mw'],
    "aparimitavidha": ['mw'],
    "aparimitālikhita": ['mw'],
    "aparimlāna": ['ap90', 'mw'],
    "aparimlānalalāṭatā": ['mw'],
    "aparimoṣa": ['mw'],
    "aparimāṇa": ['ap90', 'bhs', 'mw'],
    "aparimāṇaparivarta": ['bhs'],
    "aparimāṇavant": ['bhs'],
    "aparinirvāṇa": ['cae'],
    "apariniṣṭhita": ['ap90', 'cae'],
    "aparipakva": ['ddsa', 'mw'],
    "aparipanthadāyin": ['bhs'],
    "aparipanthin": ['cae'],
    "aparipara": ['ap90', 'mw'],
    "aparipūta": ['cae'],
    "aparisamāptika": ['mw'],
    "aparisara": ['ap90', 'mw'],
    "aparisaṃkhyeya": ['mw'],
    "aparisaṃkhyāna": ['mw'],
    "aparisaṃkhyānaṃ": ['ap90'],
    "apariskandam": ['mw'],
    "apariskaṃda": ['ap90'],
    "aparisrāva": ['bhs'],
    "aparissāvanaka": ['cped'],
    "aparisthāna": ['cae', 'mw'],
    "aparitamana": ['bhs'],
    "aparitarṣaṇā": ['bhs'],
    "aparitasana": ['bhs'],
    "aparitassa": ['cped'],
    "aparitassi": ['cped'],
    "aparitassin": ['cped'],
    "aparitasyana": ['bhs'],
    "aparitoṣa": ['cae', 'mw'],
    "aparitta": ['mw'],
    "aparituṣṭa": ['cae', 'ddsa'],
    "aparityajya": ['mw'],
    "aparityakta": ['cae'],
    "aparityāga": ['cae'],
    "aparitṛṣita": ['bhs'],
    "aparivargam": ['mw'],
    "aparivartanīya": ['mw'],
    "apariviṣṭa": ['ap90', 'gra', 'mw'],
    "aparivādya": ['cae', 'ddsa', 'mw'],
    "aparivīta": ['mw'],
    "aparivṛta": ['ap90', 'cae', 'mw'],
    "apariyāṇi": ['ap90', 'mw'],
    "apariśaṅkita": ['ddsa'],
    "apariśeṣa": ['ap90', 'mw'],
    "apariślatham": ['mw'],
    "apariśrita": ['mw'],
    "apariśrotavāhana": ['bhs'],
    "apariśrānta": ['cae'],
    "apariṇayana": ['mw'],
    "apariṇayaḥ": ['ap90'],
    "apariṇāma": ['mw'],
    "apariṇāmadarśin": ['mw'],
    "apariṇāmaḥ": ['ap90'],
    "apariṇāmin": ['mw'],
    "apariṇītā": ['ap90', 'mw'],
    "apariṣkaraḥ": ['ap90'],
    "apariṣkāra": ['mw'],
    "apariṣkṛta": ['ap90', 'mw'],
    "apariṣṭiḥ": ['ap90'],
    "aparkyapṛṣṭha": ['mw'],
    "aparoddhṛ": ['mw'],
    "aparodha": ['bhs', 'mw'],
    "aparodhaḥ": ['ap90'],
    "aparodhuka": ['mw'],
    "aparodhya": ['mw'],
    "aparokṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "aparokṣam": ['mw'],
    "aparokṣay": ['cae'],
    "aparokṣaya": ['ddsa', 'mw'],
    "aparokṣayati": ['ap90'],
    "aparokṣāt": ['mw'],
    "aparopaḥ": ['ap90'],
    "apartu": ['ap90', 'cae', 'ddsa', 'mw'],
    "aparudh": ['mw'],
    "aparujā": ['mw'],
    "aparuṣ": ['ap90', 'ddsa', 'mw'],
    "aparuṣa": ['ddsa', 'mw'],
    "aparuṣakeśatā": ['mw'],
    "aparvabhaṅganipuṇa": ['mw'],
    "aparvadaṇḍa": ['mw'],
    "aparvaka": ['mw'],
    "aparvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aparvata": ['mw'],
    "aparvatīya": ['mw'],
    "aparvaṇi": ['mw'],
    "aparyanta": ['bhs', 'cae', 'ddsa', 'mw'],
    "aparyantabhadra": ['bhs'],
    "aparyantaparivarta": ['bhs'],
    "aparyaṃta": ['ap90'],
    "aparyeṣita": ['mw'],
    "aparyeṣṭa": ['mw'],
    "aparyupya": ['mw'],
    "aparyuṣita": ['ap90', 'ddsa', 'mw'],
    "aparyāgata": ['mw'],
    "aparyāpta": ['ap90', 'cae', 'ddsa', 'mw'],
    "aparyāptavat": ['mw'],
    "aparyāpti": ['cae'],
    "aparyāptiḥ": ['ap90'],
    "aparyāsita": ['ddsa', 'mw'],
    "aparyātta": ['bhs'],
    "aparyāya": ['ap90', 'mw'],
    "aparyāṇa": ['ddsa', 'mw'],
    "aparā": ['mw'],
    "aparābhava": ['mw'],
    "aparābhāva": ['mw'],
    "aparābhūta": ['mw'],
    "aparāddha": ['ap90', 'cae', 'ddsa', 'mw'],
    "aparāddhapṛṣatka": ['mw'],
    "aparāddheṣu": ['mw'],
    "aparāddhi": ['cae', 'mw'],
    "aparāddhiḥ": ['ap90'],
    "aparāddhṛ": ['mw'],
    "aparādh": ['ap90', 'mw'],
    "aparādha": ['cae', 'ddsa', 'mw'],
    "aparādhabhañjana": ['mw'],
    "aparādhabhañjanastotra": ['mw'],
    "aparādhavat": ['mw'],
    "aparādhaḥ": ['ap90'],
    "aparādhenta": ['cped'],
    "aparādheti": ['cped'],
    "aparādhi": ['cped'],
    "aparādhika": ['bhs'],
    "aparādhin": ['ap90', 'cae', 'cped', 'mw'],
    "aparādhita": ['cped'],
    "aparādhitva": ['mw'],
    "aparādhitā": ['mw'],
    "aparādhyati": ['bhs'],
    "aparādhīna": ['mw'],
    "aparādika": ['cped'],
    "aparāga": ['cae', 'ddsa', 'mw'],
    "aparāgaḥ": ['ap90'],
    "aparāgni": ['mw'],
    "aparāhata": ['mw'],
    "aparāhla": ['ddsa'],
    "aparāhṇa": ['cae', 'mw'],
    "aparāhṇaka": ['mw'],
    "aparāhṇatana": ['mw'],
    "aparāhṇetana": ['mw'],
    "aparājaya": ['cae'],
    "aparājayin": ['mw'],
    "aparājita": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "aparājitadhvaja": ['bhs'],
    "aparājitadhvajabala": ['bhs'],
    "aparājitagaṇa": ['mw'],
    "aparājitajñānasthāma": ['bhs'],
    "aparājitameru": ['bhs'],
    "aparājitatejas": ['bhs'],
    "aparājitavratadhvaja": ['bhs'],
    "aparājitā": ['bhs', 'mw'],
    "aparājiṣṇu": ['ap90', 'mw'],
    "aparājīta": ['bhs'],
    "aparāktva": ['mw'],
    "aparāmṛṣṭa": ['bhs', 'mw'],
    "aparānta": ['bhs', 'cae', 'ddsa', 'mw'],
    "aparāntajñāna": ['mw'],
    "aparāntaka": ['bhs', 'mw'],
    "aparāntakoṭi": ['bhs'],
    "aparāntikā": ['mw'],
    "aparāpara": ['bhs', 'mw'],
    "aparāparaṇa": ['ap90', 'mw'],
    "aparāpāta": ['mw'],
    "aparārdha": ['mw'],
    "aparārdhya": ['mw'],
    "aparārka": ['ddsa', 'mw'],
    "aparārkacandrikā": ['mw'],
    "aparāsikta": ['mw'],
    "aparāvapiṣṭha": ['mw'],
    "aparāvāpa": ['mw'],
    "aparāvṛtta": ['cae', 'mw'],
    "aparāvṛttabhāgadheya": ['ddsa', 'mw'],
    "aparāvṛtti": ['mw'],
    "aparāvṛttivartin": ['mw'],
    "aparāyaṇa": ['mw'],
    "aparāśā": ['mw'],
    "aparāṃc": ['ap90'],
    "aparāṅmukha": ['cae', 'ddsa', 'mw'],
    "aparāṅmukham": ['mw'],
    "aparī": ['ddsa', 'gra', 'mw'],
    "aparīkṣita": ['ap90', 'cae', 'ddsa', 'mw'],
    "aparīkṣya": ['cae'],
    "aparīkṣyakārin": ['cae', 'mw'],
    "aparīta": ['ap90', 'cae', 'gra', 'mw'],
    "aparītta": ['mw'],
    "aparītya": ['mw'],
    "aparīvṛta": ['cae', 'gra', 'mw'],
    "aparūpa": ['ap90', 'mw'],
    "aparṇa": ['ap90', 'ddsa', 'mw'],
    "aparṇā": ['mw'],
    "apas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apasabya": ['cped'],
    "apasac": ['mw'],
    "apasada": ['cae', 'ddsa', 'mw'],
    "apasadaḥ": ['ap90'],
    "apasakkati": ['cped'],
    "apasala": ['ap90'],
    "apasalais": ['cae'],
    "apasalaiḥ": ['mw'],
    "apasalavi": ['ap90', 'cae', 'mw'],
    "apasamam": ['mw'],
    "apasamaṃ": ['ap90'],
    "apasammajjati": ['cped'],
    "apasara": ['ap90', 'cae', 'mw'],
    "apasaraḥ": ['ap90'],
    "apasaraṇa": ['mw'],
    "apasaraṇaṃ": ['ap90'],
    "apasarjana": ['mw'],
    "apasarjanaṃ": ['ap90'],
    "apasarpa": ['mw'],
    "apasarpaḥ": ['ap90'],
    "apasarpaṇa": ['mw'],
    "apasarpaṇaṃ": ['ap90'],
    "apasarpya": ['mw'],
    "apasavya": ['ap90', 'cae', 'cped', 'mw'],
    "apasavyakam": ['bhs'],
    "apasavyam": ['mw'],
    "apasavyato karoti": ['cped'],
    "apasavyavat": ['ap90', 'mw'],
    "apasavyaṁ karoti": ['cped'],
    "apasavyaṃkṛ": ['mw'],
    "apasavyena": ['mw'],
    "apasavyīkaroti": ['bhs'],
    "apasaṃharati": ['bhs'],
    "apasia": ['gra'],
    "apasiddhānta": ['mw'],
    "apasiddhāṃtaḥ": ['ap90'],
    "apasidh": ['mw'],
    "apaskambha": ['mw'],
    "apaskara": ['mw'],
    "apaskaraḥ": ['ap90'],
    "apaskaṃbhaḥ": ['ap90'],
    "apaskhala": ['mw'],
    "apaskhalaḥ": ['ap90'],
    "apaskāra": ['mw'],
    "apaskāraḥ": ['ap90'],
    "apaskṝ": ['mw'],
    "apasmaya": ['mw'],
    "apasmāra": ['bhs', 'cae', 'cped', 'mw'],
    "apasmāraka": ['bhs'],
    "apasmāraḥ": ['ap90'],
    "apasmārin": ['ap90', 'cae', 'mw'],
    "apasmṛti": ['ap90', 'mw'],
    "apasnāna": ['cae', 'ddsa', 'mw'],
    "apasnānaṃ": ['ap90'],
    "apasnāta": ['ap90', 'mw'],
    "apasparśa": ['ap90'],
    "apaspati": ['mw'],
    "apaspaśa": ['ap90', 'mw'],
    "apasphiga": ['ap90', 'mw'],
    "apasphigam": ['mw'],
    "apasphoṭana": ['bhs'],
    "apasphur": ['ap90', 'gra', 'mw'],
    "apasphura": ['gra'],
    "apaspṛ": ['mw'],
    "apaspṛś": ['ap90', 'mw'],
    "apaspṛṣṭa": ['bhs'],
    "apassayati": ['cped'],
    "apassena": ['cped'],
    "apassenaka": ['cped'],
    "apassenaphalaka": ['cped'],
    "apasseta": ['cped'],
    "apassetabba": ['cped'],
    "apassetar": ['cped'],
    "apassāya": ['cped'],
    "apastama": ['ap90', 'mw'],
    "apastamba": ['mw'],
    "apastambha": ['mw'],
    "apastambhinī": ['mw'],
    "apastana": ['mw'],
    "apastaṃbhaḥ": ['ap90'],
    "apasvara": ['mw'],
    "apasvaraḥ": ['ap90'],
    "apasvāna": ['mw'],
    "apasvāpana": ['bhs'],
    "apasy": ['cae', 'gra'],
    "apasya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apasyati": ['ap90'],
    "apasyu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apasyā": ['gra', 'mw'],
    "apasādana": ['cped'],
    "apasādayati": ['cped'],
    "apasādesi": ['cped'],
    "apasādeta": ['cped'],
    "apasādetabba": ['cped'],
    "apasādetar": ['cped'],
    "apasādeti": ['cped'],
    "apasādetvā": ['cped'],
    "apasādita": ['cped'],
    "apasādiyamāna": ['cped'],
    "apasāra": ['cae', 'mw'],
    "apasāraḥ": ['ap90'],
    "apasāraṇa": ['cae', 'cped', 'mw'],
    "apasāraṇaṃ": ['ap90'],
    "apasārin": ['cae'],
    "apasārita": ['mw'],
    "apasāritā": ['mw'],
    "apasū": ['mw'],
    "apasṛ": ['ap90', 'mw'],
    "apasṛjati": ['bhs'],
    "apasṛp": ['ap90', 'mw'],
    "apasṛpti": ['mw'],
    "apasṛptiḥ": ['ap90'],
    "apasṛta": ['ap90'],
    "apasṛti": ['mw'],
    "apatakṣ": ['mw'],
    "apatanadharmin": ['mw'],
    "apatanadharmitva": ['mw'],
    "apatanta": ['mw'],
    "apatantra": ['mw'],
    "apatantraka": ['mw'],
    "apatanīya": ['mw'],
    "apataram": ['cae', 'mw'],
    "apatarpaṇa": ['mw'],
    "apatarpaṇaṃ": ['ap90'],
    "apataṃsana": ['mw'],
    "apataṃtrakaḥ": ['ap90'],
    "apatha": ['ap90', 'cae', 'ddsa', 'mw'],
    "apathadāyin": ['mw'],
    "apathagāmin": ['mw'],
    "apathahara": ['mw'],
    "apathaprapanna": ['mw'],
    "apathin": ['mw'],
    "apathya": ['ap90', 'cae', 'ddsa', 'mw'],
    "apathyabhuj": ['mw'],
    "apathyanimitta": ['mw'],
    "apathā": ['mw'],
    "apati": ['ap90', 'ddsa', 'mw'],
    "apatighnī": ['gra', 'mw'],
    "apatikā": ['mw'],
    "apatiputrā": ['mw'],
    "apatita": ['cae', 'ddsa', 'mw'],
    "apatitā": ['mw'],
    "apatitānyonyatyāgin": ['mw'],
    "apativratā": ['cae', 'ddsa', 'mw'],
    "apatnī": ['ap90'],
    "apatnīka": ['ap90', 'ddsa', 'mw'],
    "apatra": ['ap90'],
    "apatrap": ['ap90', 'mw'],
    "apatrapa": ['ap90'],
    "apatrapaṇa": ['ddsa', 'mw'],
    "apatrapitavya": ['bhs'],
    "apatrapiṣṇu": ['ap90', 'mw'],
    "apatrapā": ['mw'],
    "apatras": ['mw'],
    "apatrasta": ['ap90', 'mw'],
    "apatrāpya": ['bhs'],
    "apattacīvaraka": ['cped'],
    "apattana": ['bhs'],
    "apattha": ['cped'],
    "apatthaddha": ['cped'],
    "apatthadāyin": ['bhs'],
    "apatthaṭa": ['cped'],
    "apattra": ['mw'],
    "apattrā": ['mw'],
    "apaturīya": ['mw'],
    "apatuṣāra": ['ddsa', 'mw'],
    "apatuṣāratā": ['mw'],
    "apatya": ['cae', 'ddsa', 'gra', 'mw'],
    "apatyada": ['mw'],
    "apatyadā": ['mw'],
    "apatyajīva": ['mw'],
    "apatyakāma": ['mw'],
    "apatyanātha": ['mw'],
    "apatyapatha": ['mw'],
    "apatyapratyaya": ['mw'],
    "apatyasac": ['mw'],
    "apatyasneha": ['cae', 'mw'],
    "apatyasāc": ['gra'],
    "apatyatā": ['mw'],
    "apatyavat": ['mw'],
    "apatyavikrayin": ['cae', 'mw'],
    "apatyaśatru": ['mw'],
    "apatyaṃ": ['ap90'],
    "apatyārthaśabda": ['mw'],
    "apatāna": ['bhs', 'mw'],
    "apatānaka": ['mw'],
    "apatānakaḥ": ['ap90'],
    "apatānakin": ['ap90', 'mw'],
    "apatīrtha": ['ap90', 'mw'],
    "apatūla": ['mw'],
    "apatṛp": ['ap90', 'mw'],
    "apaulkasa": ['mw'],
    "apauruṣa": ['ap90', 'mw'],
    "apauruṣeya": ['cae', 'mw'],
    "apaurādara": ['ddsa'],
    "apauṣkalya": ['mw'],
    "apava": ['bhs'],
    "apavacanaṃ": ['ap90'],
    "apavad": ['ap90', 'mw'],
    "apavadamāna": ['mw'],
    "apavadati": ['cped'],
    "apavadh": ['mw'],
    "apavah": ['ap90', 'mw'],
    "apavahati": ['cped'],
    "apavaktra": ['mw'],
    "apavaktraka": ['mw'],
    "apavaktṛ": ['ap90', 'ddsa', 'gra', 'mw'],
    "apavana": ['ap90', 'mw'],
    "apavap": ['mw'],
    "apavaraka": ['ap90', 'mw'],
    "apavarakaḥ": ['ap90'],
    "apavaraṇa": ['mw'],
    "apavaraṇaṃ": ['ap90'],
    "apavarga": ['ap90', 'cae', 'mw'],
    "apavargada": ['mw'],
    "apavargamārga": ['mw'],
    "apavargaḥ": ['ap90'],
    "apavarjana": ['mw'],
    "apavarjanavarjitatailapūra": ['mw'],
    "apavarjanaṃ": ['ap90'],
    "apavarjanīya": ['mw'],
    "apavarjita": ['ap90', 'mw'],
    "apavarjitatailapūra": ['mw'],
    "apavarjya": ['mw'],
    "apavarta": ['ap90', 'mw'],
    "apavartaka": ['mw'],
    "apavartakaḥ": ['ap90'],
    "apavartana": ['mw'],
    "apavartanaṃ": ['ap90'],
    "apavartaḥ": ['ap90'],
    "apavartikā": ['mw'],
    "apavartita": ['mw'],
    "apavartya": ['mw'],
    "apavartṛ": ['mw'],
    "apavarṇa": ['mw'],
    "apavas": ['mw'],
    "apavat": ['mw'],
    "apavatsa": ['mw'],
    "apavaṃśa": ['mw'],
    "apave": ['mw'],
    "apavedha": ['cae', 'mw'],
    "apavedhaḥ": ['ap90'],
    "apaven": ['mw'],
    "apaveṣṭ": ['mw'],
    "apavic": ['mw'],
    "apaviddha": ['ap90', 'cae', 'cped', 'mw'],
    "apaviddhaloka": ['mw'],
    "apaviddhaputra": ['mw'],
    "apavidyā": ['ap90', 'mw'],
    "apavighna": ['ap90', 'cae', 'mw'],
    "apavij": ['mw'],
    "apavijjhati": ['bhs'],
    "apavikṣata": ['ap90', 'ddsa', 'mw'],
    "apavipad": ['mw'],
    "apavitra": ['mw'],
    "apavitraḍākinī": ['cae', 'mw'],
    "apavivāra": ['bhs'],
    "apaviyūhati": ['cped'],
    "apaviyūhitvā": ['cped'],
    "apaviś": ['mw'],
    "apaviṣa": ['ap90'],
    "apaviṣā": ['mw'],
    "apaviṣṇu": ['mw'],
    "apavoḍhṛ": ['ap90'],
    "apavraj": ['mw'],
    "apavrata": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apavyadh": ['ap90', 'mw'],
    "apavyavastha": ['mw'],
    "apavyaya": ['mw'],
    "apavyayamāna": ['mw'],
    "apavyayaḥ": ['ap90'],
    "apavyayin": ['ap90'],
    "apavye": ['mw'],
    "apavyādā": ['mw'],
    "apavyāhāra": ['mw'],
    "apavyāhṛ": ['mw'],
    "apavyākhyā": ['mw'],
    "apavyāma": ['cped'],
    "apavyāmato karoti": ['cped'],
    "apavyāmaṁ karoti": ['cped'],
    "apavyāpāra": ['mw'],
    "apavā": ['mw'],
    "apavācana": ['mw'],
    "apavācanaṃ": ['ap90'],
    "apavāda": ['cae', 'mw'],
    "apavādaka": ['ap90', 'mw'],
    "apavādapratyaya": ['mw'],
    "apavādasthala": ['mw'],
    "apavādaḥ": ['ap90'],
    "apavādin": ['cae', 'mw'],
    "apavādita": ['mw'],
    "apavādya": ['mw'],
    "apavāha": ['mw'],
    "apavāhaka": ['mw'],
    "apavāhana": ['mw'],
    "apavāhaḥ": ['ap90'],
    "apavāhya": ['mw'],
    "apavāraka": ['cae'],
    "apavārakaḥ": ['ap90'],
    "apavāraṇa": ['mw'],
    "apavāraṇaṃ": ['ap90'],
    "apavārita": ['ap90', 'cae', 'mw'],
    "apavāritakena": ['mw'],
    "apavāritam": ['mw'],
    "apavārya": ['mw'],
    "apavāsa": ['mw'],
    "apavāsaḥ": ['ap90'],
    "apavātā": ['mw'],
    "apavī": ['mw'],
    "apavīravat": ['gra', 'mw'],
    "apavīṇa": ['ap90', 'mw'],
    "apavīṇam": ['mw'],
    "apavīṇati": ['cped'],
    "apavīṇā": ['mw'],
    "apavṛ": ['ap90', 'mw'],
    "apavṛj": ['ap90', 'mw'],
    "apavṛkta": ['ap90', 'mw'],
    "apavṛktatva": ['mw'],
    "apavṛkti": ['mw'],
    "apavṛktiḥ": ['ap90'],
    "apavṛt": ['ap90', 'mw'],
    "apavṛtiḥ": ['ap90'],
    "apavṛtta": ['ap90', 'cae', 'mw'],
    "apavṛttabhāva": ['mw'],
    "apavṛtti": ['mw'],
    "apavṛttiḥ": ['ap90'],
    "apayaj": ['mw'],
    "apayanta": ['cped'],
    "apayasya": ['mw'],
    "apayaśas": ['ap90', 'cae', 'mw'],
    "apayaśaskara": ['mw'],
    "apayiṁsu": ['cped'],
    "apayodharavāraṇa": ['ddsa'],
    "apayu": ['mw'],
    "apayuj": ['mw'],
    "apayā": ['ap90', 'mw'],
    "apayāna": ['cae', 'cped', 'mw'],
    "apayānaṃ": ['ap90'],
    "apayāpetabba": ['cped'],
    "apayāpeti": ['cped'],
    "apayāta": ['mw'],
    "apayātavya": ['mw'],
    "apayātavyanaya": ['mw'],
    "apayāṇya": ['mw'],
    "apañcama": ['mw'],
    "apañcayajña": ['mw'],
    "apañcībhūta": ['cae'],
    "apañcīkṛta": ['cae', 'ddsa', 'mw'],
    "apañjasa": ['cped'],
    "apaśabda": ['cae', 'mw'],
    "apaśabdaḥ": ['ap90'],
    "apaśabdita": ['mw'],
    "apaśadaḥ": ['ap90'],
    "apaśakuna": ['mw'],
    "apaśakunaṃ": ['ap90'],
    "apaśama": ['mw'],
    "apaśamaḥ": ['ap90'],
    "apaśastra": ['mw'],
    "apaśavya": ['ap90', 'mw'],
    "apaśaṃka": ['ap90'],
    "apaśaṅka": ['mw'],
    "apaśaṅkam": ['ddsa', 'mw'],
    "apaścima": ['ap90', 'cae', 'ddsa', 'mw'],
    "apaścimaka": ['bhs'],
    "apaścādaghvan": ['mw'],
    "apaścāddaghvan": ['gra'],
    "apaśiras": ['ap90', 'mw'],
    "apaśiṣ": ['mw'],
    "apaśnath": ['mw'],
    "apaśoka": ['ap90', 'mw'],
    "apaśrama": ['mw'],
    "apaśraya": ['bhs', 'mw'],
    "apaśrayaḥ": ['ap90'],
    "apaśri": ['mw'],
    "apaśrita": ['mw'],
    "apaśruti": ['mw'],
    "apaśrī": ['ap90', 'ddsa', 'mw'],
    "apaśu": ['ap90', 'mw'],
    "apaśubandhayājin": ['mw'],
    "apaśuc": ['ap90', 'mw'],
    "apaśuhan": ['mw'],
    "apaśutā": ['mw'],
    "apaśuṣka": ['mw'],
    "apaśvas": ['mw'],
    "apaśvāsa": ['mw'],
    "apaśvāsaḥ": ['ap90'],
    "apaśya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apaśyamāna": ['cae'],
    "apaśyant": ['cae'],
    "apaśyanā": ['bhs', 'mw'],
    "apaśyanīya": ['bhs'],
    "apaśyat": ['ddsa', 'gra', 'mw'],
    "apaśālīna": ['mw'],
    "apaśālīnatā": ['mw'],
    "apaśātaya": ['mw'],
    "apaśīla": ['mw'],
    "apaśūla": ['mw'],
    "apaḥsaṃvarta": ['mw'],
    "apaṃcīkṛtaṃ": ['ap90'],
    "apaṃḍita": ['ap90'],
    "apaṅga": ['cped'],
    "apaṅka": ['ddsa', 'mw'],
    "apaṅkatā": ['mw'],
    "apaṇata": ['cped'],
    "apaṇya": ['ap90', 'cae', 'ddsa', 'mw'],
    "apaṇyījāta": ['bhs'],
    "apaṇḍita": ['cae', 'ddsa', 'mw'],
    "apaṇṇaka": ['cped'],
    "apaṇṇakata": ['cped'],
    "apaṇṇakaṁ": ['cped'],
    "apaṣṭha": ['mw'],
    "apaṣṭhaṃ": ['ap90'],
    "apaṣṭhu": ['ap90', 'ddsa', 'mw'],
    "apaṣṭhula": ['mw'],
    "apaṣṭhura": ['ap90', 'mw'],
    "apaṭha": ['ap90', 'mw'],
    "apaṭu": ['ap90', 'cae', 'ddsa', 'mw'],
    "apaṭutva": ['mw'],
    "apaṭutā": ['mw'],
    "apaṭāntara": ['mw'],
    "apaṭāṃtara": ['ap90'],
    "apaṭī": ['ap90', 'mw'],
    "apaṭīkā": ['mw'],
    "apaṭīkṣepa": ['cae', 'ddsa', 'mw'],
    "apaṭīkṣepeṇa": ['mw'],
    "apcara": ['cae', 'ddsa', 'mw'],
    "ape": ['ap90', 'mw'],
    "apehi": ['ap90', 'mw'],
    "apehipraghasā": ['mw'],
    "apehivātā": ['mw'],
    "apehivāṇijā": ['mw'],
    "apej": ['mw'],
    "apekhamāna": ['cped'],
    "apekhati": ['cped'],
    "apekhi": ['cped'],
    "apekhin": ['cped'],
    "apekhā": ['cped'],
    "apekkhamāna": ['cped'],
    "apekkhati": ['cped'],
    "apekkhava": ['cped'],
    "apekkhavat": ['cped'],
    "apekkhi": ['cped'],
    "apekkhin": ['cped'],
    "apekkhā": ['cped'],
    "apekṣ": ['ap90', 'mw'],
    "apekṣayā": ['mw'],
    "apekṣaṇa": ['mw'],
    "apekṣaṇīya": ['mw'],
    "apekṣin": ['ap90', 'cae', 'ddsa', 'mw'],
    "apekṣita": ['ap90', 'ddsa', 'mw'],
    "apekṣitatva": ['cae'],
    "apekṣitavya": ['mw'],
    "apekṣitā": ['cae', 'mw'],
    "apekṣya": ['ap90', 'ddsa', 'mw'],
    "apekṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "apekṣābuddhi": ['mw'],
    "apelava": ['ddsa'],
    "apendra": ['mw'],
    "apesi": ['cped'],
    "apeta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "apetabhī": ['mw'],
    "apetalomahaṁsa": ['cped'],
    "apetaprajanana": ['mw'],
    "apetaprāṇa": ['cae', 'mw'],
    "apetarākṣasī": ['mw'],
    "apetaviññāṇa": ['cped'],
    "apeti": ['cped'],
    "apeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "apeśala": ['mw'],
    "apeśas": ['cae', 'gra', 'mw'],
    "apeṣ": ['mw'],
    "aphala": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aphalakāṅkṣin": ['mw'],
    "aphalaprepsu": ['cae', 'mw'],
    "aphalatva": ['mw'],
    "aphalatā": ['mw'],
    "aphalgu": ['ddsa', 'mw'],
    "aphalā": ['mw'],
    "aphalākāṅkṣin": ['cae', 'mw'],
    "aphena": ['ap90', 'cae', 'ddsa', 'mw'],
    "aphenila": ['cae', 'mw'],
    "aphulla": ['mw'],
    "aphālakṛṣṭa": ['ddsa'],
    "aphāṣa": ['bhs'],
    "aphūtkārya": ['ddsa'],
    "api": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "api ca": ['cped'],
    "api ce": ['cped'],
    "api hi": ['cped'],
    "api nu": ['cped'],
    "api nu kho": ['cped'],
    "api nūna": ['cped'],
    "api ssu": ['cped'],
    "api ssudaṁ": ['cped'],
    "apia": ['gra'],
    "apibaddha": ['mw'],
    "apibandh": ['mw'],
    "apibhāga": ['ap90', 'mw'],
    "apibhū": ['mw'],
    "apicchila": ['ap90', 'mw'],
    "apidah": ['mw'],
    "apidham": ['mw'],
    "apidheti": ['bhs'],
    "apidhi": ['gra', 'mw'],
    "apidhiḥ": ['ap90'],
    "apidhā": ['ap90', 'mw'],
    "apidhāna": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "apidhānavat": ['gra', 'mw'],
    "apidhānaṃ": ['ap90'],
    "apidhānī": ['mw'],
    "apidhāv": ['mw'],
    "apido": ['mw'],
    "apidraṣṭṛ": ['mw'],
    "apigam": ['mw'],
    "apighas": ['mw'],
    "apigrah": ['mw'],
    "apigrāhya": ['mw'],
    "apiguṇa": ['mw'],
    "apigā": ['mw'],
    "apigīrṇa": ['ap90', 'mw'],
    "apigṛhya": ['mw'],
    "apihan": ['mw'],
    "apihita": ['ap90', 'cae', 'ddsa', 'mw'],
    "apihiti": ['mw'],
    "apihnu": ['mw'],
    "apihve": ['mw'],
    "apihālu": ['cped'],
    "apija": ['ap90', 'mw'],
    "apikakṣa": ['gra', 'mw'],
    "apikakṣaḥ": ['ap90'],
    "apikakṣia": ['gra'],
    "apikakṣya": ['ap90', 'gra', 'mw'],
    "apikarṇa": ['gra', 'mw'],
    "apikarṇaṃ": ['ap90'],
    "apikṛ": ['mw'],
    "apikṛt": ['mw'],
    "apikṣai": ['mw'],
    "apilāpati": ['cped'],
    "apimantra": ['mw'],
    "apimanya": ['bhs'],
    "apimṛṣ": ['mw'],
    "apinaddha": ['cae', 'ddsa', 'mw'],
    "apinaddhākṣa": ['mw'],
    "apinah": ['mw'],
    "apinetṛ": ['mw'],
    "apināma": ['mw'],
    "apinī": ['mw'],
    "apipad": ['mw'],
    "apipakṣa": ['mw'],
    "apipath": ['mw'],
    "apiprāṇa": ['ap90', 'gra', 'mw'],
    "apipāsa": ['mw'],
    "apipṛc": ['mw'],
    "apiripta": ['mw'],
    "apiruh": ['mw'],
    "apisaṃgṛbhāya": ['mw'],
    "apisic": ['mw'],
    "apisomopītha": ['mw'],
    "apisṛ": ['mw'],
    "apisṛj": ['mw'],
    "apit": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apitrya": ['ap90', 'cae', 'ddsa', 'mw'],
    "apitva": ['cae', 'ddsa', 'mw'],
    "apitvaṃ": ['ap90'],
    "apitvin": ['ap90', 'mw'],
    "apitṛ": ['mw'],
    "apitṛdevatya": ['cae', 'ddsa', 'mw'],
    "apitṛjña": ['bhs'],
    "apitṛka": ['ap90', 'mw'],
    "apivap": ['mw'],
    "apivat": ['mw'],
    "apivatī": ['mw'],
    "apivrata": ['ap90', 'mw'],
    "apivraśc": ['mw'],
    "apivye": ['mw'],
    "apivānyavatsā": ['mw'],
    "apivāpa": ['mw'],
    "apivātayat": ['ddsa'],
    "apivṛ": ['mw'],
    "apivṛj": ['mw'],
    "apivṛt": ['mw'],
    "apiyat": ['mw'],
    "apiyāc": ['mw'],
    "apiśala": ['mw'],
    "apiśalaḥ": ['ap90'],
    "apiśarvara": ['ap90', 'gra', 'mw'],
    "apiśas": ['ap90', 'mw'],
    "apiśasas": ['ddsa'],
    "apiśliṣṭa": ['bhs'],
    "apiśuna": ['mw'],
    "apiśācadhīta": ['mw'],
    "apiśīrṇa": ['mw'],
    "apiśṝ": ['mw'],
    "apiḍita": ['bhs'],
    "apiṇḍa": ['mw'],
    "apiṣṭhita": ['mw'],
    "apiṣṭhā": ['mw'],
    "apiṣṭuta": ['mw'],
    "apkṛtsna": ['bhs', 'mw'],
    "aplava": ['ap90', 'mw'],
    "aplavavat": ['mw'],
    "aplaveśa": ['mw'],
    "apliṅga": ['mw'],
    "apluta": ['ap90'],
    "apnarāj": ['gra', 'mw'],
    "apnas": ['cae', 'ddsa', 'gra', 'mw'],
    "apnasvat": ['ap90', 'gra', 'mw'],
    "apnavāna": ['ap90', 'gra', 'mw'],
    "apnavānavat": ['mw'],
    "apnaḥ": ['ap90'],
    "apnaḥstha": ['gra', 'mw'],
    "apobdha": ['mw'],
    "apobh": ['mw'],
    "apocchad": ['mw'],
    "apodaka": ['ap90', 'gra', 'mw'],
    "apoddhārya": ['mw'],
    "apodi": ['mw'],
    "apodikā": ['ap90', 'mw'],
    "apoditya": ['mw'],
    "apodūh": ['mw'],
    "apogaṃḍaḥ": ['ap90'],
    "apogaṇḍa": ['cae', 'ddsa', 'mw'],
    "apoh": ['ap90', 'mw'],
    "apoha": ['cae', 'ddsa', 'mw'],
    "apohana": ['mw'],
    "apohanaṃ": ['ap90'],
    "apohanīya": ['mw'],
    "apohaḥ": ['ap90'],
    "apohita": ['mw'],
    "apohya": ['ap90', 'mw'],
    "apombhana": ['mw'],
    "aponaptriya": ['mw'],
    "aponaptrīya": ['mw'],
    "aponaptṛ": ['mw'],
    "aporṇavana": ['mw'],
    "aporṇu": ['mw'],
    "apotkṛṣ": ['mw'],
    "apotsṛj": ['mw'],
    "apotsṛjati": ['bhs'],
    "apoḍha": ['ap90', 'cae', 'ddsa', 'mw'],
    "apoṣ": ['mw'],
    "apoṣadhika": ['bhs'],
    "appa": ['cped'],
    "appabhassa": ['cped'],
    "appabhikkhuka": ['cped'],
    "appadassa": ['cped'],
    "appadhaṁsika": ['cped'],
    "appadhaṁsiya": ['cped'],
    "appadīkṣita": ['mw'],
    "appaggha": ['cped'],
    "appaharita": ['cped'],
    "appaka": ['cped'],
    "appakasirena": ['cped'],
    "appakicca": ['cped'],
    "appakiṇṇa": ['cped'],
    "appalābha": ['cped'],
    "appamatta": ['cped'],
    "appamattaka": ['cped'],
    "appamattika": ['cped'],
    "appamattā": ['cped'],
    "appamaññati": ['cped'],
    "appamaññā": ['cped'],
    "appameyya": ['cped'],
    "appanā": ['cped'],
    "appapurisa": ['cped'],
    "appapurisaka": ['cped'],
    "apparajakkha": ['cped'],
    "apparajakkhajātika": ['cped'],
    "appasacca": ['cped'],
    "appasadda": ['cped'],
    "appasattha": ['cped'],
    "appassaka": ['cped'],
    "appassuta": ['cped'],
    "appassāda": ['cped'],
    "appasuta": ['cped'],
    "appatara": ['cped'],
    "appathāmaka": ['cped'],
    "appati": ['ap90', 'cae', 'ddsa', 'mw'],
    "appatikkha": ['cped'],
    "appatissa": ['cped'],
    "appatitthīna": ['cped'],
    "appativattiya": ['cped'],
    "appatiṭṭhīna": ['cped'],
    "appayati": ['cped'],
    "appaññātaka": ['cped'],
    "appaṇā": ['cped'],
    "appaṭikkha": ['cped'],
    "appaṭimaṁsa": ['cped'],
    "appaṭisandhika": ['cped'],
    "appaṭisaṁvedana": ['cped'],
    "appaṭisaṁviditvā": ['cped'],
    "appaṭissa": ['cped'],
    "appaṭivattiya": ['cped'],
    "appaṭivānitā": ['cped'],
    "appaṭivānī": ['cped'],
    "appaṭivānīya": ['cped'],
    "appaṭivāṇī": ['cped'],
    "appaṭṭha": ['cped'],
    "appaṭṭhatara": ['cped'],
    "appe kacca": ['cped'],
    "appekacca": ['cped'],
    "appekadā": ['cped'],
    "appesakkha": ['cped'],
    "appeti": ['bhs', 'cped'],
    "appeva nāma": ['cped'],
    "apphoṭayati": ['cped'],
    "apphoṭeti": ['cped'],
    "appiccha": ['cped'],
    "appita": ['cped'],
    "appitta": ['mw'],
    "appitthika": ['cped'],
    "appodaka": ['cped'],
    "appossuka": ['cped'],
    "appossukka": ['cped'],
    "appuyya": ['cped'],
    "appābādha": ['cped'],
    "appāhāra": ['cped'],
    "appākiṇṇa": ['cped'],
    "appātaṅka": ['cped'],
    "appātuma": ['cped'],
    "appāyuka": ['cped'],
    "appāṇaka": ['cped'],
    "appūrvam": ['mw'],
    "aprabala": ['mw'],
    "aprabha": ['ap90', 'mw'],
    "aprabhraṃśa": ['mw'],
    "aprabhu": ['ap90', 'gra', 'mw'],
    "aprabhutva": ['mw'],
    "aprabhūta": ['mw'],
    "aprabhūti": ['gra', 'mw'],
    "aprabhūtiḥ": ['ap90'],
    "aprabuddha": ['cae', 'ddsa'],
    "apracaṃkaśa": ['ap90'],
    "apracaṅkaśa": ['mw'],
    "apracchanna": ['mw'],
    "apracchedya": ['ap90', 'mw'],
    "apracchinna": ['mw'],
    "apracchāya": ['mw'],
    "apracetas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apracetita": ['mw'],
    "apracodita": ['mw'],
    "apracura": ['mw'],
    "apracyuta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apracyuti": ['mw'],
    "apracyāva": ['mw'],
    "apracyāvuka": ['mw'],
    "apradadi": ['mw'],
    "apradagdha": ['mw'],
    "apradakṣiṇam": ['ddsa'],
    "apradakṣiṇaṃ": ['ap90'],
    "apradatta": ['ap90'],
    "apradharṣya": ['bhs'],
    "apradhāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "apradhānatva": ['mw'],
    "apradhānatā": ['mw'],
    "apradhṛṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "apradugdha": ['ap90', 'gra', 'mw'],
    "apradāha": ['mw'],
    "apradāna": ['ddsa'],
    "apradānavat": ['mw'],
    "apradīptāgni": ['mw'],
    "apradṛpita": ['gra', 'mw'],
    "apragalbha": ['ap90', 'cae', 'mw'],
    "apragalbhāyate": ['bhs'],
    "apragama": ['ap90', 'mw'],
    "apraghnatī": ['mw'],
    "apragraha": ['mw'],
    "apragrāha": ['ap90', 'mw'],
    "apraguṇa": ['ap90', 'mw'],
    "apragādha": ['mw'],
    "aprahan": ['ap90', 'gra', 'mw'],
    "aprahata": ['ap90', 'ddsa', 'mw'],
    "aprahita": ['ap90', 'gra', 'mw'],
    "aprahāvan": ['mw'],
    "aprahṛta": ['mw'],
    "aprahṛṣṭaka": ['mw'],
    "apraiṣa": ['mw'],
    "apraja": ['ap90', 'cae', 'ddsa', 'mw'],
    "aprajajñi": ['ap90', 'cae', 'gra', 'mw'],
    "aprajana": ['mw'],
    "aprajanatva": ['mw'],
    "aprajaniṣṇu": ['mw'],
    "aprajas": ['ap90', 'cae', 'mw'],
    "aprajastā": ['cae', 'mw'],
    "aprajasya": ['mw'],
    "aprajña": ['cae', 'ddsa', 'mw'],
    "aprajñāta": ['ddsa', 'mw'],
    "aprajñātra": ['mw'],
    "aprajā": ['gra', 'mw'],
    "aprajāstva": ['mw'],
    "aprajātā": ['mw'],
    "aprakalpaka": ['ap90', 'mw'],
    "aprakampa": ['mw'],
    "aprakampatā": ['mw'],
    "aprakampin": ['mw'],
    "aprakara": ['ap90', 'mw'],
    "aprakaraṇa": ['mw'],
    "aprakaraṇaṃ": ['ap90'],
    "aprakarṣita": ['mw'],
    "aprakaṃpa": ['ap90'],
    "aprakaṭa": ['mw'],
    "aprakaṭam": ['mw'],
    "aprakaṭīkṛta": ['ddsa'],
    "apraketa": ['cae', 'gra', 'mw'],
    "aprakhara": ['mw'],
    "aprakhyatā": ['mw'],
    "aprakāra": ['bhs'],
    "aprakāśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aprakāśaka": ['ap90', 'mw'],
    "aprakāśam": ['mw'],
    "aprakāśamāna": ['mw'],
    "aprakāśant": ['cae'],
    "aprakāśat": ['ddsa', 'mw'],
    "aprakāśin": ['mw'],
    "aprakāśita": ['mw'],
    "aprakāśya": ['ap90', 'cae', 'mw'],
    "aprakāṃḍa": ['ap90'],
    "aprakāṇḍa": ['mw'],
    "aprakḷpta": ['mw'],
    "aprakḷptatā": ['mw'],
    "aprakṛta": ['ap90', 'mw'],
    "aprakṛti": ['mw'],
    "aprakṛtiḥ": ['ap90'],
    "aprakṛṣṭa": ['ap90', 'bhs', 'mw'],
    "aprakṣita": ['ap90', 'gra', 'mw'],
    "apralambam": ['mw'],
    "apralaya": ['ddsa'],
    "apralaṃba": ['ap90'],
    "apramada": ['ap90', 'mw'],
    "apramatta": ['ap90', 'cae', 'ddsa', 'mw'],
    "apramattavat": ['mw'],
    "apramaya": ['ap90', 'mw'],
    "aprameya": ['ap90', 'bhs', 'cae', 'mw'],
    "aprameyānubhāva": ['mw'],
    "aprameyātman": ['mw'],
    "apramita": ['ap90', 'mw'],
    "apramoda": ['cae', 'mw'],
    "apramodamānā": ['mw'],
    "apramodaḥ": ['ap90'],
    "apramuditā": ['mw'],
    "apramā": ['ap90', 'ddsa', 'mw'],
    "apramāda": ['ap90', 'cae', 'mw'],
    "apramādam": ['mw'],
    "apramādatā": ['mw'],
    "apramādin": ['cae', 'mw'],
    "apramādya": ['bhs'],
    "apramādyant": ['cae'],
    "apramāyuka": ['ap90', 'mw'],
    "apramāṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "apramāṇaguṇasāgaraprabha": ['bhs'],
    "apramāṇaparivarta": ['bhs'],
    "apramāṇavid": ['mw'],
    "apramāṇaśubha": ['bhs', 'mw'],
    "apramāṇābha": ['bhs', 'mw'],
    "apramāṇābhāsvara": ['bhs'],
    "apramīya": ['mw'],
    "apramūra": ['ap90', 'gra', 'mw'],
    "apramṛṣya": ['ap90', 'gra', 'mw'],
    "apranihita": ['bhs'],
    "aprapadana": ['mw'],
    "aprapadanaṃ": ['ap90'],
    "aprapata": ['bhs'],
    "aprapañca": ['bhs'],
    "aprapaśya": ['mw'],
    "aprapāda": ['mw'],
    "aprapāduka": ['mw'],
    "aprapāṇa": ['mw'],
    "aprasahiṣṇu": ['mw'],
    "aprasahya": ['mw'],
    "aprasakta": ['ap90', 'mw'],
    "aprasakti": ['cae', 'mw'],
    "aprasaktiḥ": ['ap90'],
    "aprasanna": ['ap90', 'cae', 'ddsa', 'mw'],
    "aprasava": ['ap90', 'mw'],
    "aprasavadharmin": ['mw'],
    "aprasaṃgaḥ": ['ap90'],
    "aprasaṅga": ['mw'],
    "aprasiddha": ['ap90', 'cae', 'mw'],
    "aprasiddhapada": ['mw'],
    "aprasiddhiḥ": ['ap90'],
    "aprasraṃsa": ['mw'],
    "aprastuta": ['ap90', 'cae', 'mw'],
    "aprastutapraśaṃsā": ['mw'],
    "aprastutastuti": ['mw'],
    "aprastāvika": ['ap90', 'mw'],
    "aprasāda": ['bhs', 'mw'],
    "aprasādaḥ": ['ap90'],
    "aprasādya": ['mw'],
    "aprasāha": ['ap90', 'mw'],
    "aprasūta": ['ap90', 'mw'],
    "aprasūti": ['bhs'],
    "aprasūtā": ['mw'],
    "apratarkya": ['ap90', 'cae', 'ddsa', 'mw'],
    "aprathita": ['mw'],
    "aprati": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apratibaddha": ['ddsa'],
    "apratibala": ['ap90', 'mw'],
    "apratibandha": ['cae', 'mw'],
    "apratibaṃdha": ['ap90'],
    "apratibha": ['ap90', 'mw'],
    "apratibhaṭa": ['ap90', 'mw'],
    "apratibhā": ['mw'],
    "apratibodha": ['mw'],
    "apratibodhavat": ['mw'],
    "apratibruvat": ['mw'],
    "apratibuddha": ['cae'],
    "apratibuddhaka": ['cae'],
    "apraticodya": ['bhs'],
    "apratidhura": ['ap90', 'mw'],
    "apratidhṛṣya": ['mw'],
    "apratidhṛṣṭa": ['gra', 'mw'],
    "apratidhṛṣṭaśavas": ['gra', 'mw'],
    "apratidvandva": ['mw'],
    "apratidvandvatā": ['mw'],
    "apratidvaṃdva": ['ap90'],
    "apratigha": ['ap90', 'cae', 'ddsa', 'mw'],
    "apratighāta": ['bhs'],
    "apratigrahaṇa": ['mw'],
    "apratigrāhaka": ['ap90', 'cae', 'mw'],
    "apratigrāhita": ['bhs'],
    "apratigrāhya": ['ap90', 'cae', 'mw'],
    "apratigṛhya": ['ap90', 'mw'],
    "apratigṛhṇant": ['cae'],
    "apratihata": ['ap90', 'cae', 'ddsa', 'mw'],
    "apratihataguṇakīrtivimokṣaprabharāja": ['bhs'],
    "apratihatanetra": ['bhs', 'mw'],
    "apratihataprabha": ['bhs'],
    "apratihataraśmirāgaprabha": ['mw'],
    "apratihatavega": ['bhs'],
    "apratihāra": ['mw'],
    "apratihārya": ['cae', 'mw'],
    "apratijñā": ['ddsa'],
    "apratikara": ['ap90', 'mw'],
    "apratikareṇa": ['mw'],
    "apratikarman": ['ap90', 'mw'],
    "apratikhyāta": ['mw'],
    "apratikāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "apratikārin": ['mw'],
    "apratikāṅkṣatā": ['bhs'],
    "apratikāṅkṣaṇa": ['bhs'],
    "apratikāṅkṣin": ['bhs'],
    "apratikūla": ['cae', 'mw'],
    "apratikṛṣṭa": ['mw'],
    "apratilabdhakāma": ['mw'],
    "apratilomayat": ['mw'],
    "apratima": ['ap90', 'cae', 'ddsa', 'mw'],
    "apratimalla": ['mw'],
    "apratimanyūyamāna": ['mw'],
    "apratimaprabhāva": ['cae'],
    "apratimaujas": ['cae'],
    "apratimeya": ['cae', 'mw'],
    "apratimukta": ['ddsa'],
    "apratimā": ['bhs'],
    "apratimāna": ['cae', 'gra', 'mw'],
    "apratinoda": ['mw'],
    "apratipad": ['ap90', 'mw'],
    "apratipadyamāna": ['cae', 'mw'],
    "apratipakṣa": ['ap90', 'mw'],
    "apratipanna": ['mw'],
    "apratipatti": ['cae', 'ddsa', 'mw'],
    "apratipattiḥ": ['ap90'],
    "apratipaṇya": ['mw'],
    "apratipraśrabdha": ['bhs'],
    "apratipraśrabdhi": ['bhs'],
    "apratipraśrambhaṇa": ['bhs'],
    "apratipudgala": ['bhs'],
    "apratipādana": ['cae'],
    "apratipūjita": ['cae'],
    "apratiratha": ['ap90', 'cae', 'ddsa', 'mw'],
    "apratirava": ['ap90', 'mw'],
    "apratirūpa": ['ap90', 'cae', 'mw'],
    "apratirūpakathā": ['mw'],
    "apratisama": ['bhs'],
    "apratisaṃhārya": ['bhs'],
    "apratisaṃkhya": ['ap90'],
    "apratisaṃkhyā": ['bhs', 'mw'],
    "apratisaṃkhyānirodha": ['mw'],
    "apratisaṃkhyāya": ['bhs'],
    "apratisaṃkrama": ['ap90', 'mw'],
    "apratisaṃveda": ['bhs'],
    "apratisaṃvedanā": ['bhs'],
    "apratisaṃvidita": ['bhs'],
    "apratistabdha": ['mw'],
    "apratisādhya": ['mw'],
    "aprativacana": ['bhs'],
    "aprativartiya": ['bhs'],
    "aprativarṇanīya": ['bhs'],
    "apratividhāna": ['ddsa'],
    "aprativinīta": ['bhs'],
    "aprativirata": ['bhs'],
    "aprativādin": ['mw'],
    "aprativārita": ['cae'],
    "aprativāṇi": ['bhs', 'mw'],
    "aprativāṇīya": ['bhs'],
    "aprativīrya": ['ap90', 'mw'],
    "aprativīryārambha": ['bhs', 'mw'],
    "apratiyatnapūrva": ['mw'],
    "apratiyatnaḥ": ['ap90'],
    "apratiyodhin": ['mw'],
    "apratiyogin": ['ap90', 'ddsa', 'mw'],
    "apratiśaraṇa": ['bhs'],
    "apratiśasta": ['mw'],
    "apratiśaṃsat": ['mw'],
    "apratiśāsana": ['ap90', 'ddsa', 'mw'],
    "apratiṣedha": ['cae', 'ddsa', 'mw'],
    "apratiṣekya": ['mw'],
    "apratiṣiddha": ['mw'],
    "apratiṣikta": ['mw'],
    "apratiṣkuta": ['gra', 'mw'],
    "apratiṣkṛta": ['mw'],
    "apratiṣṭabdha": ['mw'],
    "apratiṣṭha": ['ap90', 'cae', 'ddsa', 'mw'],
    "apratiṣṭhita": ['ap90', 'bhs', 'cae', 'mw'],
    "apratiṣṭhā": ['mw'],
    "apratiṣṭhādhyānavartanin": ['bhs'],
    "apratiṣṭhāna": ['ap90', 'mw'],
    "apratiṣṭhāyuka": ['mw'],
    "apratta": ['ap90', 'mw'],
    "aprattadaivata": ['mw'],
    "aprattadevata": ['mw'],
    "aprattā": ['ddsa', 'mw'],
    "apratula": ['mw'],
    "apratulaḥ": ['ap90'],
    "apratyakṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "apratyakṣatā": ['mw'],
    "apratyakṣaśiṣṭa": ['mw'],
    "apratyanīya": ['bhs'],
    "apratyaya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "apratyayastha": ['mw'],
    "apratyuddhārya": ['bhs'],
    "apratyudāvarta": ['bhs'],
    "apratyudāvartana": ['bhs'],
    "apratyudāvartanīya": ['bhs'],
    "apratyudāvartya": ['bhs'],
    "apratyutthāyuka": ['mw'],
    "apratyākhyeya": ['mw'],
    "apratyākhyāna": ['mw'],
    "apratyākhyāta": ['mw'],
    "apratyākhyāyin": ['cae', 'ddsa'],
    "apratyālabhamāna": ['mw'],
    "apratyāmnāya": ['mw'],
    "apratyṛta": ['ap90', 'mw'],
    "apratā": ['ap90', 'mw'],
    "apratāpa": ['mw'],
    "apratāpaḥ": ['ap90'],
    "apratībhā": ['mw'],
    "apratīghātitā": ['mw'],
    "apratīka": ['ap90'],
    "apratīkāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "apratīkṣa": ['mw'],
    "apratīkṣam": ['mw'],
    "apratīpa": ['mw'],
    "apratīta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apratīti": ['cae', 'ddsa', 'mw'],
    "apratītiḥ": ['ap90'],
    "apratītta": ['mw'],
    "apratīśa": ['bhs'],
    "aprauḍha": ['ap90', 'ddsa', 'mw'],
    "aprauḍhā": ['mw'],
    "apravadat": ['mw'],
    "apravaktṛ": ['ddsa'],
    "apravargya": ['mw'],
    "apravartaka": ['ap90', 'mw'],
    "apravartana": ['mw'],
    "apravartanaṃ": ['ap90'],
    "apravartin": ['mw'],
    "apraveda": ['ap90', 'mw'],
    "apravlaya": ['mw'],
    "apravyāhāra": ['bhs'],
    "apravāsagamana": ['ddsa'],
    "apravīta": ['ap90', 'gra'],
    "apravītā": ['mw'],
    "apravīṇa": ['mw'],
    "apravṛddha": ['mw'],
    "apravṛtta": ['mw'],
    "apravṛtti": ['cae', 'mw'],
    "apravṛttiḥ": ['ap90'],
    "aprayacchant": ['cae'],
    "aprayacchat": ['ddsa'],
    "aprayata": ['cae', 'mw'],
    "aprayatna": ['ap90', 'cae', 'ddsa', 'mw'],
    "aprayoga": ['mw'],
    "aprayogaḥ": ['ap90'],
    "aprayojaka": ['mw'],
    "aprayuccat": ['ap90'],
    "aprayucchant": ['cae'],
    "aprayucchat": ['mw'],
    "aprayuchat": ['gra'],
    "aprayujyamāna": ['cae', 'mw'],
    "aprayukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "aprayuktatva": ['mw'],
    "aprayuktatā": ['mw'],
    "aprayuta": ['gra', 'mw'],
    "aprayutvan": ['gra', 'mw'],
    "aprayāja": ['mw'],
    "aprayāpaṇi": ['ap90', 'mw'],
    "aprayāsa": ['mw'],
    "aprayāsena": ['mw'],
    "aprayāvam": ['mw'],
    "aprayāvaṃ": ['ap90'],
    "aprayāṇaka": ['mw'],
    "aprayāṇi": ['mw'],
    "aprayāṇiḥ": ['ap90'],
    "apraśama": ['mw'],
    "apraśasta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apraśasya": ['mw'],
    "apraṇaya": ['ddsa'],
    "apraṇidhi": ['bhs'],
    "apraṇihita": ['bhs', 'mw'],
    "apraṇodya": ['mw'],
    "apraṇāśa": ['mw'],
    "apraṇīta": ['ap90', 'cae', 'mw'],
    "aprekṣaṇīya": ['cae', 'ddsa'],
    "aprekṣya": ['cae', 'ddsa'],
    "aprekṣāpūrvakārin": ['ddsa'],
    "apreman": ['ap90', 'mw'],
    "apreta": ['mw'],
    "apretarākṣasī": ['ap90', 'mw'],
    "apriya": ['ap90', 'cae', 'ddsa', 'mw'],
    "apriyabhāgin": ['mw'],
    "apriyakara": ['cae', 'ddsa', 'mw'],
    "apriyamvada": ['mw'],
    "apriyavādin": ['mw'],
    "apriyaṃvada": ['cae', 'ddsa', 'mw'],
    "apriyaṃvādin": ['cae'],
    "apriyā": ['mw'],
    "apriyākhya": ['bhs'],
    "apriyākhyāyin": ['bhs', 'mw'],
    "aprodita": ['mw'],
    "aprokṣita": ['mw'],
    "aproṣita": ['ddsa', 'mw'],
    "aproṣivas": ['gra', 'mw'],
    "aprācīna": ['ap90', 'mw'],
    "aprādeśika": ['mw'],
    "aprādhānya": ['cae', 'ddsa', 'mw'],
    "aprāgbhāra": ['bhs'],
    "aprāgrya": ['ap90', 'mw'],
    "aprājña": ['cae', 'ddsa', 'mw'],
    "aprājñatā": ['mw'],
    "aprākaraṇika": ['ap90', 'mw'],
    "aprākṛta": ['ap90', 'ddsa', 'mw'],
    "aprākṛṣu": ['bhs'],
    "aprāmi": ['ap90', 'gra'],
    "aprāmisatya": ['gra', 'mw'],
    "aprāmāṇika": ['ap90', 'mw'],
    "aprāmāṇya": ['cae', 'ddsa', 'mw'],
    "aprāpta": ['ap90', 'cae', 'ddsa', 'mw'],
    "aprāptakāla": ['mw'],
    "aprāptakāya": ['bhs'],
    "aprāptavibhāṣā": ['mw'],
    "aprāptavikalpa": ['mw'],
    "aprāptavyavahāra": ['mw'],
    "aprāptayauvana": ['mw'],
    "aprāpti": ['mw'],
    "aprāptika": ['bhs'],
    "aprāptiḥ": ['ap90'],
    "aprāptiṣu": ['bhs'],
    "aprāptāvasara": ['mw'],
    "aprāpya": ['bhs', 'ddsa', 'mw'],
    "aprāpyagrahaṇa": ['mw'],
    "aprāpyakārin": ['mw'],
    "aprāpyatama": ['mw'],
    "aprārthaka": ['mw'],
    "aprārthita": ['ddsa'],
    "aprāstāvika": ['cae', 'ddsa', 'mw'],
    "aprāsādika": ['bhs'],
    "aprātilomya": ['mw'],
    "aprātirūpya": ['mw'],
    "aprāvṛta": ['mw'],
    "aprāyatya": ['mw'],
    "aprāyatyaṃ": ['ap90'],
    "aprāyu": ['ap90', 'gra', 'mw'],
    "aprāyus": ['ap90', 'gra', 'mw'],
    "aprāśana": ['mw'],
    "aprāśitriya": ['mw'],
    "aprāśitṛ": ['mw'],
    "aprāṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aprāṇant": ['cae'],
    "aprāṇat": ['mw'],
    "aprāṇin": ['cae'],
    "aprīti": ['cae', 'ddsa', 'mw'],
    "aprītikara": ['cae', 'mw'],
    "aprītiḥ": ['ap90'],
    "aprītyātmaka": ['mw'],
    "apsaras": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apsarastīrtha": ['ddsa', 'mw'],
    "apsaraḥ": ['ap90'],
    "apsaraḥpati": ['mw'],
    "apsarā": ['cae'],
    "apsarāpati": ['mw'],
    "apsarāya": ['mw'],
    "apsarāyita": ['mw'],
    "apsas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apsava": ['ap90', 'gra', 'mw'],
    "apsavya": ['ap90', 'mw'],
    "apsaḥ": ['ap90'],
    "apsu": ['ap90', 'gra', 'mw'],
    "apsucara": ['mw'],
    "apsudīkṣā": ['mw'],
    "apsuhomya": ['mw'],
    "apsuja": ['mw'],
    "apsujit": ['gra', 'mw'],
    "apsujā": ['gra', 'mw'],
    "apsukṣit": ['gra', 'mw'],
    "apsumat": ['mw'],
    "apsusaṃśita": ['mw'],
    "apsuvah": ['mw'],
    "apsuyoga": ['mw'],
    "apsuyoni": ['mw'],
    "apsuṣad": ['gra', 'mw'],
    "apsuṣadas": ['mw'],
    "apsuṣoma": ['mw'],
    "apsā": ['gra', 'mw'],
    "apta": ['ap90', 'gra', 'mw'],
    "aptas": ['ap90', 'mw'],
    "aptaya": ['ddsa'],
    "aptia": ['gra'],
    "aptoryāma": ['ddsa', 'mw'],
    "aptoryāman": ['mw'],
    "aptoryāmaḥ": ['ap90'],
    "aptu": ['ap90', 'cae', 'mw'],
    "aptumat": ['mw'],
    "aptur": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aptya": ['ap90', 'cae', 'gra', 'mw'],
    "aptūria": ['gra'],
    "aptūrya": ['gra', 'mw'],
    "apuccaṇḍatā": ['cped'],
    "apuccha": ['ap90', 'mw'],
    "apucchā": ['mw'],
    "apumaṃs": ['cae'],
    "apunar": ['ap90', 'gra', 'mw'],
    "apunaranvaya": ['mw'],
    "apunarbhava": ['mw'],
    "apunarbhāva": ['mw'],
    "apunarbhāvin": ['ddsa', 'mw'],
    "apunarbhū": ['mw'],
    "apunardīyamāna": ['mw'],
    "apunarnivartin": ['ddsa'],
    "apunarukta": ['ddsa', 'mw'],
    "apunarukti": ['mw'],
    "apunarvṛtti": ['ddsa'],
    "apunarābhāva": ['mw'],
    "apunarāvartana": ['cae', 'mw'],
    "apunarāvṛtti": ['mw'],
    "apunaḥpratyudāvartya": ['bhs'],
    "apunaḥprāpya": ['mw'],
    "apunāgamana": ['bhs'],
    "apunāvarta": ['bhs'],
    "apurogava": ['mw'],
    "apurohita": ['ddsa', 'mw'],
    "apuronuvākyaka": ['mw'],
    "apurorukka": ['mw'],
    "apuruṣa": ['ap90', 'mw'],
    "apuruṣābhivīta": ['mw'],
    "apuruṣāparādha": ['ddsa', 'mw'],
    "apuruṣārtha": ['mw'],
    "apurātana": ['mw'],
    "apurāṇa": ['mw'],
    "apus": ['ap90', 'mw'],
    "aputra": ['cae', 'ddsa', 'mw'],
    "aputraka": ['cae', 'mw'],
    "aputratā": ['mw'],
    "aputraḥ": ['ap90'],
    "aputrika": ['mw'],
    "aputrikā": ['ap90'],
    "aputrin": ['cae', 'ddsa'],
    "aputriya": ['cae', 'mw'],
    "aputrya": ['cae', 'mw'],
    "aputtaka": ['cped'],
    "apuvāya": ['mw'],
    "apuñja": ['mw'],
    "apuā": ['gra'],
    "apuṃs": ['ap90', 'ddsa', 'mw'],
    "apuṃskā": ['ap90', 'mw'],
    "apuṃstva": ['mw'],
    "apuṃstvaṃ": ['ap90'],
    "apuṃścalīya": ['ddsa'],
    "apuṇya": ['ap90', 'mw'],
    "apuṇyakṛt": ['cae', 'ddsa', 'mw'],
    "apuṣa": ['mw'],
    "apuṣkala": ['ap90', 'ddsa', 'mw'],
    "apuṣpa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apuṣpaphala": ['mw'],
    "apuṣpaphalada": ['mw'],
    "apuṣṭa": ['ap90', 'mw'],
    "apuṣṭārtha": ['mw'],
    "apuṣṭārthatva": ['mw'],
    "apva": ['ap90', 'mw'],
    "apvā": ['cae', 'gra', 'mw'],
    "apya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apyac": ['gra'],
    "apyad": ['mw'],
    "apyadīkṣita": ['mw'],
    "apyadīkṣitaḥ": ['ap90'],
    "apyardham": ['mw'],
    "apyardhaṃ": ['ap90'],
    "apyas": ['mw'],
    "apyatyarj": ['mw'],
    "apyaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "apyayadīkṣita": ['mw'],
    "apyayana": ['mw'],
    "apyayanaṃ": ['ap90'],
    "apyayaḥ": ['ap90'],
    "apyaṃc": ['ap90'],
    "apyekatya": ['bhs'],
    "apyuta": ['mw'],
    "apyāhṛ": ['mw'],
    "apāc": ['ap90', 'gra', 'mw'],
    "apācia": ['gra'],
    "apācya": ['ap90', 'gra', 'mw'],
    "apācī": ['ap90', 'mw'],
    "apācīna": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "apācīnaṁ": ['cped'],
    "apācītarā": ['mw'],
    "apād": ['ap90', 'mw'],
    "apāda": ['mw'],
    "apādaka": ['mw'],
    "apādhvan": ['ap90', 'mw'],
    "apādhā": ['mw'],
    "apādya": ['mw'],
    "apādā": ['ap90', 'mw'],
    "apādādi": ['mw'],
    "apādādibhāj": ['mw'],
    "apādāna": ['cae', 'ddsa', 'mw'],
    "apādānaṃ": ['ap90'],
    "apādāntīya": ['mw'],
    "apādātṛ": ['mw'],
    "apāhan": ['mw'],
    "apāhatuṁ": ['cped'],
    "apāhā": ['ap90'],
    "apāhāya": ['mw'],
    "apāhṛ": ['mw'],
    "apāj": ['mw'],
    "apāk": ['ap90', 'mw'],
    "apāka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apākacakṣas": ['gra', 'mw'],
    "apākaja": ['mw'],
    "apākaraṇa": ['mw'],
    "apākaraṇaṃ": ['ap90'],
    "apākariṣṇu": ['ap90', 'ddsa', 'mw'],
    "apākarman": ['ap90', 'mw'],
    "apākaśāka": ['mw'],
    "apākin": ['mw'],
    "apāktas": ['mw'],
    "apāktāt": ['gra', 'mw'],
    "apākā": ['cae', 'ddsa', 'gra', 'mw'],
    "apākāt": ['ddsa', 'gra', 'mw'],
    "apākṛ": ['ap90', 'mw'],
    "apākṛta": ['ap90', 'mw'],
    "apākṛti": ['ddsa', 'gra', 'mw'],
    "apākṛtiḥ": ['ap90'],
    "apākṛṣ": ['mw'],
    "apākṝ": ['mw'],
    "apākṣa": ['ap90', 'mw'],
    "apāla": ['mw'],
    "apālamba": ['cped', 'mw'],
    "apālayat": ['ddsa'],
    "apālaṃbaḥ": ['ap90'],
    "apālaṃkaḥ": ['ap90'],
    "apālaṅka": ['mw'],
    "apāli": ['mw'],
    "apālu": ['mw'],
    "apālā": ['gra', 'mw'],
    "apāmaṃbhaviṣṇu": ['mw'],
    "apāmitya": ['mw'],
    "apāmpati": ['ddsa', 'mw'],
    "apāmpitta": ['mw'],
    "apāmārga": ['mw'],
    "apāmārgaḥ": ['ap90'],
    "apāmārjana": ['mw'],
    "apāmārjanastotra": ['mw'],
    "apāmārjanaṃ": ['ap90'],
    "apāmṛtyu": ['mw'],
    "apān": ['ap90', 'mw'],
    "apāna": ['cae', 'ddsa', 'mw'],
    "apānabhṛt": ['mw'],
    "apānadvāra": ['mw'],
    "apānadā": ['mw'],
    "apānadṛh": ['mw'],
    "apānanaṃ": ['ap90'],
    "apānapavana": ['mw'],
    "apānapā": ['mw'],
    "apānavāyu": ['mw'],
    "apānaḥ": ['ap90'],
    "apānika": ['mw'],
    "apāniya": ['bhs'],
    "apānodgāra": ['mw'],
    "apāntaratamas": ['mw'],
    "apānud": ['mw'],
    "apānunutsu": ['mw'],
    "apānīya": ['mw'],
    "apānṛta": ['ap90', 'mw'],
    "apāpa": ['ap90', 'cae', 'ddsa', 'mw'],
    "apāpad": ['mw'],
    "apāpada": ['mw'],
    "apāpakāśin": ['mw'],
    "apāpakṛt": ['mw'],
    "apāpapurī": ['mw'],
    "apāpavasyasa": ['mw'],
    "apāpaviddha": ['mw'],
    "apāpurati": ['cped'],
    "apāpuraṇa": ['cped'],
    "apāpurituṁ": ['cped'],
    "apāpuritvā": ['cped'],
    "apāpurīyati": ['cped'],
    "apāpāya": ['mw'],
    "apār": ['mw'],
    "apāra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apāraka": ['ap90'],
    "apāramārthika": ['mw'],
    "apārapāra": ['mw'],
    "apārayant": ['cae'],
    "apārayat": ['ddsa', 'mw'],
    "apāraṇīya": ['mw'],
    "apārch": ['mw'],
    "apārijāta": ['mw'],
    "apārima": ['bhs'],
    "apārjita": ['mw'],
    "apārtha": ['ap90', 'cae', 'ddsa', 'mw'],
    "apārthaka": ['cae', 'mw'],
    "apārthakaraṇa": ['mw'],
    "apārthaya": ['mw'],
    "apārthiva": ['ddsa', 'mw'],
    "apāruta": ['cped'],
    "apārutaghara": ['cped'],
    "apārājikīya": ['bhs'],
    "apārṇa": ['ap90', 'mw'],
    "apās": ['ap90', 'mw'],
    "apāsana": ['mw'],
    "apāsanaṃ": ['ap90'],
    "apāsaraṇa": ['mw'],
    "apāsaraṇaṃ": ['ap90'],
    "apāsaṃgaḥ": ['ap90'],
    "apāsaṅga": ['mw'],
    "apāsi": ['mw'],
    "apāsita": ['ap90', 'mw'],
    "apāsta": ['mw'],
    "apāsthā": ['mw'],
    "apāsu": ['ap90', 'mw'],
    "apāsya": ['cae', 'mw'],
    "apāsyat": ['mw'],
    "apāsṛ": ['mw'],
    "apāsṛta": ['mw'],
    "apātaka": ['cae', 'ddsa'],
    "apātra": ['cae', 'ddsa', 'mw'],
    "apātrabhṛt": ['mw'],
    "apātradāyin": ['mw'],
    "apātrakṛtyā": ['cae', 'mw'],
    "apātravarṣaṇa": ['mw'],
    "apātravarṣin": ['cae', 'mw'],
    "apātraṃ": ['ap90'],
    "apātrībhū": ['mw'],
    "apātrīkarana": ['mw'],
    "apātrīkaraṇa": ['cae', 'ddsa'],
    "apātta": ['ddsa', 'mw'],
    "apātubha": ['cped'],
    "apātī": ['mw'],
    "apāvaraṇī": ['bhs'],
    "apāvartana": ['mw'],
    "apāvartanaṃ": ['ap90'],
    "apāvurīyati": ['bhs'],
    "apāvya": ['mw'],
    "apāvṛ": ['ap90', 'mw'],
    "apāvṛkta": ['gra', 'mw'],
    "apāvṛt": ['ap90', 'mw'],
    "apāvṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "apāvṛti": ['gra', 'mw'],
    "apāvṛtiḥ": ['ap90'],
    "apāvṛtta": ['ap90', 'cae', 'mw'],
    "apāvṛtti": ['mw'],
    "apāvṛtya": ['mw'],
    "apāya": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "apāyagāmanīya": ['cped'],
    "apāyajaha": ['bhs'],
    "apāyakosalla": ['cped'],
    "apāyakusala": ['cped'],
    "apāyamukha": ['cped'],
    "apāyapramathana": ['bhs'],
    "apāyasaṃvartanīya": ['mw'],
    "apāyasthāna": ['bhs'],
    "apāyati": ['cped'],
    "apāyaḥ": ['ap90'],
    "apāyaṁsu": ['cped'],
    "apāyi": ['cped'],
    "apāyin": ['ap90', 'cped', 'ddsa', 'mw'],
    "apāñc": ['cae', 'ddsa', 'mw'],
    "apāñcālya": ['mw'],
    "apāñjas": ['mw'],
    "apāśraga": ['mw'],
    "apāśraya": ['ap90', 'cae', 'ddsa', 'mw'],
    "apāśrayavat": ['mw'],
    "apāśrayaṇa": ['bhs', 'mw'],
    "apāśrayin": ['mw'],
    "apāśri": ['ap90', 'mw'],
    "apāśrita": ['ap90', 'mw'],
    "apāśyā": ['ap90', 'mw'],
    "apāṃ": ['ap90'],
    "apāṃga": ['ap90'],
    "apāṃgarbha": ['mw'],
    "apāṃkta": ['ap90'],
    "apāṃnaptriya": ['mw'],
    "apāṃnaptrīya": ['mw'],
    "apāṃnaptṛ": ['mw'],
    "apāṃnapāt": ['mw'],
    "apāṃnidhi": ['mw'],
    "apāṃnātha": ['mw'],
    "apāṃpati": ['cae'],
    "apāṃpitta": ['ap90'],
    "apāṃvatsa": ['mw'],
    "apāṅga": ['cae', 'cped', 'ddsa', 'mw'],
    "apāṅgadarśana": ['mw'],
    "apāṅgadeśa": ['mw'],
    "apāṅgadṛṣṭi": ['mw'],
    "apāṅgaka": ['mw'],
    "apāṅganetra": ['mw'],
    "apāṅganetrā": ['cae'],
    "apāṅgaviśālanetra": ['cae', 'mw'],
    "apāṅkteya": ['cae', 'ddsa', 'mw'],
    "apāṅktya": ['cae', 'ddsa', 'mw'],
    "apāṅktyopahata": ['mw'],
    "apāṇi": ['cae', 'ddsa', 'mw'],
    "apāṇigrahaṇa": ['mw'],
    "apāṇinīya": ['ap90'],
    "apāṇipāda": ['mw'],
    "apāṇitva": ['mw'],
    "apāṇḍava": ['ddsa'],
    "apāṣṭha": ['gra', 'mw'],
    "apāṣṭhavat": ['gra', 'mw'],
    "apāṣṭhaḥ": ['ap90'],
    "apāṣṭhi": ['mw'],
    "apāṣṭhiha": ['mw'],
    "apāṣṭhihan": ['mw'],
    "apāṣṭi": ['mw'],
    "apāṣṭiḥ": ['ap90'],
    "apāṭava": ['ap90', 'mw'],
    "apāṭha": ['mw'],
    "apāṭhya": ['mw'],
    "apāṭubha": ['cped'],
    "apāṭuka": ['cped'],
    "apī": ['ap90', 'mw'],
    "apīcia": ['gra'],
    "apīcya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apīju": ['ap90'],
    "apījū": ['gra', 'mw'],
    "apīnasa": ['mw'],
    "apīnasaḥ": ['ap90'],
    "apīta": ['cae', 'ddsa', 'mw'],
    "apīti": ['gra', 'mw'],
    "apītiḥ": ['ap90'],
    "apītvā": ['mw'],
    "apīvya": ['ap90', 'mw'],
    "apīvṛta": ['cae', 'gra', 'mw'],
    "apīḍana": ['mw'],
    "apīḍayant": ['cae'],
    "apīḍayat": ['ddsa', 'mw'],
    "apīḍayā": ['mw'],
    "apīḍita": ['ddsa'],
    "apīḍā": ['mw'],
    "apūjaka": ['ap90', 'mw'],
    "apūjita": ['cae', 'ddsa', 'mw'],
    "apūjya": ['mw'],
    "apūjā": ['ap90', 'mw'],
    "apūpa": ['cae', 'ddsa', 'gra', 'mw'],
    "apūpaka": ['mw'],
    "apūpamaya": ['mw'],
    "apūpanābhi": ['mw'],
    "apūpavat": ['gra', 'mw'],
    "apūpaśālā": ['cae', 'mw'],
    "apūpaḥ": ['ap90'],
    "apūpikā": ['mw'],
    "apūpya": ['mw'],
    "apūpādi": ['mw'],
    "apūpāpihita": ['mw'],
    "apūpīya": ['ap90', 'mw'],
    "apūra": ['mw'],
    "apūraṇa": ['ddsa', 'mw'],
    "apūraṇī": ['ap90', 'mw'],
    "apūrti": ['mw'],
    "apūruṣa": ['ap90', 'gra', 'mw'],
    "apūruṣaghna": ['gra', 'mw'],
    "apūrva": ['ap90', 'cae', 'ddsa', 'mw'],
    "apūrvadarśana": ['mw'],
    "apūrvakaraṇa": ['mw'],
    "apūrvakarman": ['mw'],
    "apūrvapada": ['mw'],
    "apūrvapati": ['mw'],
    "apūrvatva": ['mw'],
    "apūrvatā": ['ap90', 'mw'],
    "apūrvavat": ['ap90', 'mw'],
    "apūrvavāda": ['mw'],
    "apūrveṇa": ['ap90', 'bhs', 'mw'],
    "apūrvia": ['gra'],
    "apūrvin": ['ddsa', 'mw'],
    "apūrvya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "apūrvīya": ['ap90', 'mw'],
    "apūryamāṇa": ['mw'],
    "apūrṇa": ['ap90', 'cae', 'mw'],
    "apūrṇakāla": ['mw'],
    "apūrṇakālaja": ['mw'],
    "apūrṇatā": ['mw'],
    "apūta": ['cae', 'mw'],
    "apṛkta": ['ap90', 'mw'],
    "apṛthagbhūta": ['ddsa'],
    "apṛthagdharmaśīla": ['mw'],
    "apṛthagdharmin": ['mw'],
    "apṛthagjita": ['cae', 'mw'],
    "apṛthagvivekya": ['mw'],
    "apṛthak": ['ap90', 'mw'],
    "apṛthaktvin": ['mw'],
    "apṛthakśruti": ['mw'],
    "apṛthātmaja": ['ddsa'],
    "apṛṇant": ['cae'],
    "apṛṇat": ['ap90', 'ddsa', 'gra', 'mw'],
    "apṛṣṭa": ['cae', 'ddsa', 'mw'],
    "ar": ['gra'],
    "ara": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "arada": ['ap90'],
    "aradhra": ['ap90', 'cae', 'gra', 'mw'],
    "aragarāṭa": ['mw'],
    "araghaṭṭa": ['cae', 'ddsa', 'mw'],
    "araghaṭṭaka": ['cae', 'mw'],
    "araha": ['bhs', 'cped'],
    "arahaddhaja": ['cped'],
    "arahaggata": ['cped'],
    "arahant": ['bhs'],
    "arahantaghātaka": ['cped'],
    "arahantavāda": ['cped'],
    "arahas": ['ap90', 'mw'],
    "arahat": ['cped'],
    "arahati": ['cped'],
    "arahatta": ['cped'],
    "arahattamagga": ['cped'],
    "arahattaphala": ['cped'],
    "arahita": ['ddsa', 'mw'],
    "arahāya": ['mw'],
    "arahāyate": ['ap90'],
    "araja": ['mw'],
    "arajanīkṛta": ['mw'],
    "arajas": ['ap90', 'cae', 'ddsa', 'mw'],
    "arajaska": ['mw'],
    "arajju": ['ap90', 'gra', 'mw'],
    "arajottarīya": ['bhs'],
    "arajovirajonayayukta": ['bhs'],
    "arajovittā": ['mw'],
    "arajyat": ['ddsa'],
    "arajā": ['mw'],
    "arajāya": ['mw'],
    "arajāyate": ['ap90'],
    "araka": ['mw'],
    "arakta": ['cae', 'mw'],
    "araktapravāḍa": ['bhs'],
    "araktatāmra": ['mw'],
    "arakṣant": ['cae'],
    "arakṣas": ['ap90', 'cae', 'gra', 'mw'],
    "arakṣasya": ['mw'],
    "arakṣat": ['ddsa', 'mw'],
    "arakṣita": ['mw'],
    "arakṣitṛ": ['cae', 'mw'],
    "arakṣya": ['bhs'],
    "aralu": ['mw'],
    "araluka": ['mw'],
    "aram": ['cae', 'ddsa', 'gra', 'mw'],
    "arama": ['ap90'],
    "aramamāṇa": ['gra', 'mw'],
    "aramati": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aramaṇa": ['ap90'],
    "aramaṇas": ['ap90', 'gra', 'mw'],
    "aramaṇīya": ['ddsa'],
    "aramaṇīyatva": ['cae'],
    "aramaṇīyatā": ['mw'],
    "aramiṣ": ['ap90', 'gra', 'mw'],
    "aramuḍi": ['ddsa', 'mw'],
    "aramya": ['cae', 'ddsa'],
    "aranemi": ['bhs', 'mw'],
    "arantos": ['ddsa', 'mw'],
    "arantuka": ['mw'],
    "arapa": ['cae', 'ddsa', 'mw'],
    "arapacana": ['bhs', 'mw'],
    "arapacanaḥ": ['ap90'],
    "arapas": ['ap90', 'cae', 'gra', 'mw'],
    "arara": ['mw'],
    "araraka": ['mw'],
    "ararakā": ['mw'],
    "araraṃ": ['ap90'],
    "arare": ['ap90', 'mw'],
    "arari": ['ddsa', 'gra', 'mw'],
    "ararinda": ['gra', 'mw'],
    "ararivas": ['ap90', 'gra', 'mw'],
    "ararivaṃs": ['cae'],
    "arariḥ": ['ap90'],
    "arariṃdaṃ": ['ap90'],
    "araru": ['ap90', 'cae', 'gra', 'mw'],
    "ararya": ['mw'],
    "araryati": ['ap90'],
    "ararāka": ['mw'],
    "ararākā": ['mw'],
    "arasa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "arasajña": ['mw'],
    "arasayitṛ": ['mw'],
    "arasika": ['ap90', 'cae', 'ddsa', 'mw'],
    "arasāśa": ['mw'],
    "arasāśin": ['mw'],
    "arasīṭhakkura": ['mw'],
    "arata": ['ap90', 'mw'],
    "aratatrapa": ['mw'],
    "aratha": ['cae', 'gra', 'mw'],
    "arathin": ['ap90', 'ddsa', 'mw'],
    "arathī": ['cae', 'gra', 'mw'],
    "arathīḥ": ['ap90'],
    "arati": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "aratijña": ['mw'],
    "aratika": ['ddsa', 'mw'],
    "aratni": ['cae', 'ddsa', 'gra', 'mw'],
    "aratnika": ['mw'],
    "aratnikaḥ": ['ap90'],
    "aratnimātra": ['mw'],
    "aratnin": ['mw'],
    "aratniḥ": ['ap90'],
    "aratnālokasaṃhārya": ['ddsa'],
    "araudra": ['ap90', 'mw'],
    "arava": ['mw'],
    "aravinda": ['cae', 'ddsa', 'mw'],
    "aravindadalaprabha": ['mw'],
    "aravindanābha": ['mw'],
    "aravindasad": ['mw'],
    "aravindinī": ['mw'],
    "araviṃdaṃ": ['ap90'],
    "araviṃdinī": ['ap90'],
    "aravāla": ['bhs'],
    "aravāḍa": ['bhs'],
    "arañjita": ['ddsa'],
    "arañña": ['cped'],
    "araññavihāra": ['cped'],
    "araññāyatana": ['cped'],
    "araśana": ['mw'],
    "araśman": ['gra', 'mw'],
    "araśmika": ['mw'],
    "araḍa": ['mw'],
    "araḍu": ['mw'],
    "araḍuka": ['mw'],
    "araḍā": ['mw'],
    "araṃ": ['ap90', 'mw'],
    "araṃdhanaṃ": ['ap90'],
    "araṃgam": ['ap90', 'mw'],
    "araṃgama": ['gra', 'mw'],
    "araṃgamaḥ": ['ap90'],
    "araṃgara": ['mw'],
    "araṃgaraḥ": ['ap90'],
    "araṃghuṣa": ['ap90', 'mw'],
    "araṃgin": ['ap90'],
    "araṃkṛ": ['ap90', 'mw'],
    "araṃkṛt": ['gra', 'mw'],
    "araṃkṛta": ['cae', 'mw'],
    "araṃkṛti": ['gra', 'mw'],
    "araṃkṛtyā": ['mw'],
    "araṅgaṇa": ['bhs'],
    "araṅgin": ['mw'],
    "araṅgisattva": ['mw'],
    "araṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "araṇasamavasaraṇa": ['bhs'],
    "araṇasaraṇasarvasamavasaraṇa": ['bhs'],
    "araṇemi": ['bhs'],
    "araṇemika": ['bhs'],
    "araṇi": ['cae', 'gra', 'mw'],
    "araṇika": ['cped'],
    "araṇikā": ['mw'],
    "araṇimat": ['ap90', 'mw'],
    "araṇisahita": ['cped'],
    "araṇiḥ": ['ap90'],
    "araṇm, araṇī": ['ddsa'],
    "araṇya": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "araṇyabhava": ['mw'],
    "araṇyabhāga": ['mw'],
    "araṇyacara": ['mw'],
    "araṇyacaṭaka": ['mw'],
    "araṇyadharma": ['mw'],
    "araṇyadhānya": ['mw'],
    "araṇyadvādaśī": ['mw'],
    "araṇyagaja": ['mw'],
    "araṇyagata": ['mw'],
    "araṇyagholī": ['mw'],
    "araṇyahaladī": ['mw'],
    "araṇyaja": ['mw'],
    "araṇyajārdrakā": ['mw'],
    "araṇyajīra": ['mw'],
    "araṇyajīva": ['mw'],
    "araṇyaka": ['bhs', 'mw'],
    "araṇyakadalī": ['mw'],
    "araṇyakarpāsī": ['mw'],
    "araṇyakaṃ": ['ap90'],
    "araṇyakaṇā": ['mw'],
    "araṇyaketu": ['mw'],
    "araṇyakulathikā": ['mw'],
    "araṇyakusumbha": ['mw'],
    "araṇyakāka": ['mw'],
    "araṇyakārpāsī": ['mw'],
    "araṇyakāṇḍa": ['mw'],
    "araṇyamakṣikā": ['mw'],
    "araṇyamudga": ['mw'],
    "araṇyamārjāra": ['mw'],
    "araṇyanitya": ['mw'],
    "araṇyanṛpati": ['mw'],
    "araṇyaparvan": ['mw'],
    "araṇyarajanī": ['mw'],
    "araṇyarakṣaka": ['mw'],
    "araṇyarudita": ['cae', 'mw'],
    "araṇyarāj": ['mw'],
    "araṇyarājya": ['mw'],
    "araṇyatulasī": ['mw'],
    "araṇyaukas": ['cae', 'ddsa', 'mw'],
    "araṇyavat": ['mw'],
    "araṇyavāsa": ['cae', 'mw'],
    "araṇyavāsin": ['cae', 'mw'],
    "araṇyavāsinī": ['mw'],
    "araṇyavāstuka": ['mw'],
    "araṇyavāstūka": ['mw'],
    "araṇyavāyasa": ['mw'],
    "araṇyayāna": ['mw'],
    "araṇyaśvan": ['mw'],
    "araṇyaśāli": ['mw'],
    "araṇyaśūraṇa": ['mw'],
    "araṇyaṃ": ['ap90'],
    "araṇyaṣaṣṭhikā": ['mw'],
    "araṇyaṣaṣṭhī": ['mw'],
    "araṇye": ['mw'],
    "araṇyegeya": ['mw'],
    "araṇyenuvākya": ['mw'],
    "araṇyenūcya": ['mw'],
    "araṇyenūcyaḥ": ['ap90'],
    "araṇyetilaka": ['mw'],
    "araṇyetilakaḥ": ['ap90'],
    "araṇyopaniṣad": ['mw'],
    "araṇyādhyayana": ['mw'],
    "araṇyādhīti": ['mw'],
    "araṇyāni": ['cae', 'ddsa', 'gra', 'mw'],
    "araṇyāniḥ": ['ap90'],
    "araṇyānī": ['cae', 'gra', 'mw'],
    "araṇyāyana": ['mw'],
    "araṇyīya": ['ap90', 'mw'],
    "araṇā": ['bhs'],
    "araṇāvihārin": ['mw'],
    "araṇī": ['cae', 'gra', 'mw'],
    "araṇīketu": ['mw'],
    "araṭu": ['gra', 'mw'],
    "araṭva": ['gra', 'mw'],
    "arb": ['ap90', 'mw'],
    "arbha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "arbhaga": ['ap90', 'gra', 'mw'],
    "arbhaka": ['ap90', 'cae', 'gra', 'mw'],
    "arbuda": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "arbudadhā": ['mw'],
    "arbudamāhātmya": ['mw'],
    "arbudaparvata": ['mw'],
    "arbudaśikhara": ['cae', 'mw'],
    "arbudaḥ": ['ap90'],
    "arbudha": ['mw'],
    "arbudi": ['mw'],
    "arbudin": ['ap90', 'mw'],
    "arbudiḥ": ['ap90'],
    "arbudodāsarpiṇī": ['cae', 'mw'],
    "arbudākāra": ['mw'],
    "arbudāraṇya": ['mw'],
    "arbuka": ['mw'],
    "arc": ['ap90', 'ddsa', 'gra', 'mw'],
    "arca": ['ap90'],
    "arcaddhūma": ['gra', 'mw'],
    "arcaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "arcana": ['ap90', 'cae', 'gra', 'mw'],
    "arcanas": ['mw'],
    "arcanānas": ['gra', 'mw'],
    "arcanīya": ['ap90', 'cae', 'mw'],
    "arcas": ['mw'],
    "arcat": ['ddsa', 'mw'],
    "arcatri": ['ap90', 'cae', 'gra', 'mw'],
    "arcatria": ['gra'],
    "arcatrya": ['ap90', 'gra', 'mw'],
    "arch": ['ddsa', 'gra'],
    "arci": ['cae', 'ddsa', 'gra', 'mw'],
    "arcicayiṣu": ['mw'],
    "arciketu": ['bhs'],
    "arcimahendra": ['bhs'],
    "arcimant": ['bhs'],
    "arcimat": ['ap90', 'gra', 'mw'],
    "arcin": ['ap90', 'gra', 'mw'],
    "arcinetrādhipati": ['bhs', 'mw'],
    "arcirmaṇḍalagātra": ['bhs'],
    "arcis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "arcita": ['ap90', 'bhs', 'cae', 'mw'],
    "arcitanama": ['bhs'],
    "arcitin": ['ap90', 'mw'],
    "arcitṛ": ['mw'],
    "arcivat": ['gra', 'mw'],
    "arciścandra": ['bhs'],
    "arciśiri": ['bhs'],
    "arciḥ": ['ap90'],
    "arciḥsamudramukhavegapradīpa": ['bhs'],
    "arciṣmant": ['bhs', 'cae'],
    "arciṣmat": ['ap90', 'ddsa', 'mw'],
    "arciṣmatī": ['bhs', 'mw'],
    "arcya": ['cae', 'ddsa', 'mw'],
    "arcā": ['ap90', 'ddsa', 'mw'],
    "arcārha": ['cae', 'mw'],
    "arcārhaka": ['mw'],
    "arcāvat": ['mw'],
    "arcāvidhi": ['mw'],
    "arcāviḍambanā": ['mw'],
    "ard": ['ap90', 'ddsa', 'gra', 'mw'],
    "ardana": ['ap90', 'cae', 'ddsa', 'mw'],
    "ardani": ['mw'],
    "ardaniḥ": ['ap90'],
    "ardanā": ['mw'],
    "ardh": ['ddsa', 'gra'],
    "ardha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ardhabhakṣita": ['cae'],
    "ardhabheda": ['mw'],
    "ardhabhāga": ['mw'],
    "ardhabhāgika": ['mw'],
    "ardhabhāgin": ['mw'],
    "ardhabhāj": ['cae', 'mw'],
    "ardhabhāskara": ['mw'],
    "ardhabhūmi": ['mw'],
    "ardhabṛgala": ['cae', 'mw'],
    "ardhabṛhatī": ['mw'],
    "ardhacakravartin": ['mw'],
    "ardhacakrin": ['mw'],
    "ardhacandanalipta": ['mw'],
    "ardhacandra": ['bhs', 'cae', 'ddsa', 'mw'],
    "ardhacandrabhāgin": ['mw'],
    "ardhacandraka": ['bhs', 'mw'],
    "ardhacandrakuṇḍa": ['mw'],
    "ardhacandramukha": ['mw'],
    "ardhacandrikā": ['mw'],
    "ardhacandropama": ['mw'],
    "ardhacandrā": ['mw'],
    "ardhacandrākāra": ['mw'],
    "ardhacandrākṛta": ['mw'],
    "ardhacaturtha": ['mw'],
    "ardhacola": ['bhs'],
    "ardhacolaka": ['mw'],
    "ardhadagdha": ['mw'],
    "ardhadaṇḍa": ['cae', 'mw'],
    "ardhadeva": ['cae', 'gra', 'mw'],
    "ardhadevatā": ['mw'],
    "ardhadhāra": ['mw'],
    "ardhadivasa": ['mw'],
    "ardhadrauṇika": ['mw'],
    "ardhadvicaturaska": ['mw'],
    "ardhagallī": ['bhs'],
    "ardhagarbha": ['gra', 'mw'],
    "ardhagaṅgā": ['mw'],
    "ardhagola": ['mw'],
    "ardhaguccha": ['mw'],
    "ardhahara": ['mw'],
    "ardhahastaka": ['mw'],
    "ardhahrasva": ['mw'],
    "ardhahāra": ['cae', 'mw'],
    "ardhajaratīya": ['mw'],
    "ardhajvalita": ['ddsa'],
    "ardhajyā": ['mw'],
    "ardhajāhnavī": ['mw'],
    "ardhajīvakā": ['mw'],
    "ardhaka": ['ap90', 'mw'],
    "ardhakaghātin": ['mw'],
    "ardhakaiśika": ['mw'],
    "ardhakapiśa": ['mw'],
    "ardhakarṇa": ['mw'],
    "ardhakathana": ['ddsa', 'mw'],
    "ardhakauḍavika": ['mw'],
    "ardhakaṃsika": ['mw'],
    "ardhaketu": ['mw'],
    "ardhakhāra": ['mw'],
    "ardhakhārī": ['mw'],
    "ardhakoṣa": ['mw'],
    "ardhakoṭī": ['cae', 'mw'],
    "ardhakrośa": ['mw'],
    "ardhakāla": ['mw'],
    "ardhakārṣika": ['mw'],
    "ardhakāya": ['bhs'],
    "ardhakāyika": ['bhs'],
    "ardhakīla": ['mw'],
    "ardhakūṭa": ['mw'],
    "ardhakṛta": ['mw'],
    "ardhakṛṣṭa": ['cae', 'mw'],
    "ardhakṣetra": ['mw'],
    "ardhalakṣmīhari": ['mw'],
    "ardhalakṣya": ['ddsa'],
    "ardhalikhita": ['cae', 'mw'],
    "ardhamakuṭa": ['mw'],
    "ardhamuṇḍa": ['mw'],
    "ardhamuṣṭi": ['mw'],
    "ardhamāgadhaka": ['mw'],
    "ardhamāgadhī": ['cae', 'mw'],
    "ardhamānava": ['mw'],
    "ardhamānuṣa": ['mw'],
    "ardhamārga": ['cae'],
    "ardhamārge": ['mw'],
    "ardhamāsa": ['cae', 'mw'],
    "ardhamāsasahasra": ['mw'],
    "ardhamāsatama": ['mw'],
    "ardhamāsaśas": ['mw'],
    "ardhamāsika": ['mw'],
    "ardhamātra": ['mw'],
    "ardhamātrika": ['mw'],
    "ardhamātrikā": ['mw'],
    "ardhamātrā": ['mw'],
    "ardhamāyūrī": ['mw'],
    "ardhamāṇava": ['mw'],
    "ardhamāṇavaka": ['mw'],
    "ardhaniśā": ['mw'],
    "ardhaniṣpanna": ['mw'],
    "ardhanākula": ['mw'],
    "ardhanārāca": ['mw'],
    "ardhanārāyaṇa": ['bhs'],
    "ardhanārīnaravapus": ['mw'],
    "ardhanārīnāṭeśvara": ['mw'],
    "ardhanārīśa": ['mw'],
    "ardhanārīśvara": ['mw'],
    "ardhanāva": ['mw'],
    "ardhapada": ['mw'],
    "ardhapadyā": ['mw'],
    "ardhapakva": ['mw'],
    "ardhaparyaṅka": ['bhs', 'mw'],
    "ardhaparyaṅkin": ['bhs'],
    "ardhapatha": ['cae', 'mw'],
    "ardhapathe": ['mw'],
    "ardhapatita": ['cae'],
    "ardhapañcadaśa": ['mw'],
    "ardhapañcama": ['cae', 'mw'],
    "ardhapañcamaka": ['mw'],
    "ardhapañcan": ['cae', 'ddsa', 'mw'],
    "ardhapañcāśat": ['cae', 'mw'],
    "ardhapaṇa": ['cae', 'ddsa', 'mw'],
    "ardhaphālaka": ['mw'],
    "ardhaphālakamata": ['mw'],
    "ardhaprahara": ['mw'],
    "ardhapraharikā": ['mw'],
    "ardhaprasthika": ['mw'],
    "ardhapulāyita": ['mw'],
    "ardhapuruṣa": ['mw'],
    "ardhapuruṣīya": ['mw'],
    "ardhapuṣpā": ['mw'],
    "ardhapāda": ['mw'],
    "ardhapādika": ['cae', 'mw'],
    "ardhapādā": ['mw'],
    "ardhapārāvata": ['mw'],
    "ardhapāñcālaka": ['mw'],
    "ardhapīta": ['cae', 'mw'],
    "ardhapūrṇa": ['mw'],
    "ardharatha": ['mw'],
    "ardharca": ['cae', 'ddsa', 'mw'],
    "ardharcasya": ['mw'],
    "ardharcaśas": ['cae', 'ddsa', 'mw'],
    "ardharcaśasya": ['mw'],
    "ardharcaḥ": ['ap90'],
    "ardharcya": ['mw'],
    "ardharcādi": ['mw'],
    "ardharcāntara": ['mw'],
    "ardharāja": ['mw'],
    "ardharātra": ['ddsa', 'mw'],
    "ardharātri": ['bhs'],
    "ardharātrārdhadivasa": ['mw'],
    "ardharūpa": ['mw'],
    "ardharūpatā": ['mw'],
    "ardharūḍha": ['mw'],
    "ardhasama": ['mw'],
    "ardhasamamuktāvalī": ['mw'],
    "ardhasamasyā": ['mw'],
    "ardhasamavṛtta": ['cae'],
    "ardhasaptadaśa": ['mw'],
    "ardhasaptama": ['mw'],
    "ardhasaptaśata": ['mw'],
    "ardhasaṃjātasasya": ['mw'],
    "ardhasoma": ['mw'],
    "ardhaspṛṣṭa": ['mw'],
    "ardhasuptaka": ['mw'],
    "ardhasīrin": ['cae', 'mw'],
    "ardhatanu": ['mw'],
    "ardhatikta": ['mw'],
    "ardhatrayodaśa": ['ddsa', 'mw'],
    "ardhatūra": ['mw'],
    "ardhatṛtīya": ['mw'],
    "ardhavaināśika": ['mw'],
    "ardhavaiśasa": ['mw'],
    "ardhavartman": ['mw'],
    "ardhavastrasaṃvīta": ['mw'],
    "ardhavaśā": ['mw'],
    "ardhavidhu": ['mw'],
    "ardhavisarga": ['mw'],
    "ardhavrata": ['mw'],
    "ardhavyāma": ['mw'],
    "ardhavyāsa": ['mw'],
    "ardhavācita": ['cae'],
    "ardhavīkṣaṇa": ['mw'],
    "ardhavṛddha": ['mw'],
    "ardhavṛddhi": ['mw'],
    "ardhaya": ['mw'],
    "ardhayāma": ['ddsa', 'mw'],
    "ardhaśabda": ['mw'],
    "ardhaśaphara": ['mw'],
    "ardhaśas": ['mw'],
    "ardhaśata": ['cae', 'ddsa', 'mw'],
    "ardhaśeṣa": ['mw'],
    "ardhaśiras": ['mw'],
    "ardhaśloka": ['mw'],
    "ardhaśruta": ['mw'],
    "ardhaśyāma": ['mw'],
    "ardhaṛca": ['mw'],
    "ardhaṣaṣṭha": ['mw'],
    "ardhe": ['mw'],
    "ardhendra": ['mw'],
    "ardhendu": ['cae', 'mw'],
    "ardhendumauli": ['ddsa', 'mw'],
    "ardheḍā": ['mw'],
    "ardheṣṭakā": ['mw'],
    "ardhi": ['gra'],
    "ardhia": ['gra'],
    "ardhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "ardhin": ['ap90', 'cae', 'mw'],
    "ardhocchiṣṭa": ['mw'],
    "ardhodaya": ['mw'],
    "ardhodita": ['cae', 'mw'],
    "ardhokta": ['cae', 'ddsa', 'mw'],
    "ardhokti": ['mw'],
    "ardhona": ['mw'],
    "ardhopā": ['mw'],
    "ardhoruka": ['cae', 'mw'],
    "ardhuka": ['ap90', 'mw'],
    "ardhuṣṭa": ['bhs'],
    "ardhya": ['ap90', 'gra', 'mw'],
    "ardhācita": ['mw'],
    "ardhādhve": ['mw'],
    "ardhākāra": ['mw'],
    "ardhākṣi": ['cae', 'ddsa', 'mw'],
    "ardhāmbu": ['mw'],
    "ardhāntaraikapadatā": ['mw'],
    "ardhāntaraikavācaka": ['mw'],
    "ardhāpayati": ['bhs'],
    "ardhārdha": ['mw'],
    "ardhārdhabhāga": ['mw'],
    "ardhārdhahāni": ['mw'],
    "ardhāsana": ['mw'],
    "ardhāsi": ['mw'],
    "ardhāstamaya": ['mw'],
    "ardhāvabheda": ['mw'],
    "ardhāvabhedaka": ['mw'],
    "ardhāvalīḍha": ['cae', 'mw'],
    "ardhāvaśeṣa": ['mw'],
    "ardhāviṣṭa": ['mw'],
    "ardhāśana": ['mw'],
    "ardhāṃśa": ['mw'],
    "ardhāṃśin": ['mw'],
    "ardhāṅga": ['mw'],
    "ardhāṇumātrā": ['mw'],
    "ardhīkṛta": ['mw'],
    "ardidhiṣu": ['mw'],
    "ardita": ['ap90', 'ddsa', 'mw'],
    "arditin": ['ap90', 'mw'],
    "ardravalika": ['bhs'],
    "ardyamāna": ['mw'],
    "ardīyate": ['bhs'],
    "are": ['ap90', 'cae', 'ddsa', 'mw'],
    "arepa": ['mw'],
    "arepas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "arepha": ['mw'],
    "arephajāta": ['mw'],
    "arephavat": ['mw'],
    "arephin": ['mw'],
    "arere": ['ap90', 'mw'],
    "aretas": ['mw'],
    "aretaska": ['mw'],
    "areṇu": ['ap90', 'cae', 'gra', 'mw'],
    "arga": ['mw'],
    "argala": ['cae', 'ddsa', 'mw'],
    "argalaka": ['bhs'],
    "argalapāśa": ['bhs'],
    "argalaḥ": ['ap90'],
    "argalikā": ['ap90', 'mw'],
    "argalita": ['ap90', 'mw'],
    "argalya": ['mw'],
    "argalānirgama": ['mw'],
    "argalāstotra": ['mw'],
    "argalāstuti": ['mw'],
    "argalīya": ['ap90', 'mw'],
    "argaḍa": ['bhs', 'mw'],
    "argaḍaḥ": ['ap90'],
    "argaṭa": ['mw'],
    "argh": ['ap90', 'cae', 'ddsa', 'mw'],
    "argha": ['cae', 'ddsa', 'gra', 'mw'],
    "arghabalābala": ['mw'],
    "arghadāna": ['mw'],
    "arghapātra": ['mw'],
    "arghasaṃsthāpana": ['mw'],
    "arghaḥ": ['ap90'],
    "arghaṭa": ['mw'],
    "arghaṭaṃ": ['ap90'],
    "argheśvara": ['mw'],
    "arghodaka": ['cae'],
    "arghya": ['ap90', 'cae', 'ddsa', 'mw'],
    "arghyadāna": ['mw'],
    "arghyapātra": ['mw'],
    "arghyaśīla": ['mw'],
    "arghyeya": ['bhs'],
    "arghyodaka": ['cae'],
    "arghyārha": ['mw'],
    "arghāpacaya": ['mw'],
    "arghāpacayena": ['mw'],
    "arghārha": ['mw'],
    "arghīśa": ['mw'],
    "arghīśaḥ": ['ap90'],
    "arh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "arha": ['ap90', 'cae', 'ddsa', 'mw'],
    "arhaka": ['mw'],
    "arhant": ['bhs', 'cae'],
    "arhanta": ['mw'],
    "arhantikā": ['ddsa', 'mw'],
    "arhariṣvaṇi": ['ap90', 'gra', 'mw'],
    "arhase": ['cae'],
    "arhasāna": ['mw'],
    "arhat": ['ap90', 'ddsa', 'mw'],
    "arhati": ['bhs'],
    "arhattama": ['mw'],
    "arhattva": ['mw'],
    "arhavant": ['bhs'],
    "arhaṃta": ['ap90'],
    "arhaṃtī": ['ap90'],
    "arhaṇa": ['cae', 'mw'],
    "arhaṇaṃ": ['ap90'],
    "arhaṇā": ['ap90', 'gra', 'mw'],
    "arhaṇīya": ['ap90', 'cae', 'mw'],
    "arhaṭaghaṭīcakra": ['bhs'],
    "arhita": ['mw'],
    "arhya": ['ap90', 'mw'],
    "ari": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aria": ['gra'],
    "aricintana": ['mw'],
    "aricintā": ['mw'],
    "aridhāyas": ['gra', 'mw'],
    "aridānta": ['mw'],
    "arighna": ['mw'],
    "arigupta": ['bhs'],
    "arigūrta": ['gra', 'mw'],
    "ariha": ['mw'],
    "arihan": ['cae', 'ddsa', 'mw'],
    "arijana": ['ddsa', 'mw'],
    "arijit": ['mw'],
    "arikarṣaṇa": ['mw'],
    "arikta": ['cae', 'ddsa', 'mw'],
    "arikthabhāj": ['ap90', 'mw'],
    "arikthīya": ['cae', 'ddsa', 'mw'],
    "ariloka": ['mw'],
    "arimarda": ['mw'],
    "arimardana": ['bhs', 'ddsa', 'mw'],
    "arimeda": ['mw'],
    "arimedaka": ['mw'],
    "arimejaya": ['mw'],
    "arimitra": ['mw'],
    "arin": ['ap90', 'ddsa', 'mw'],
    "arinandana": ['ddsa', 'mw'],
    "arindama": ['bhs', 'ddsa'],
    "arinihantar": ['bhs'],
    "arinipāta": ['mw'],
    "arinuta": ['mw'],
    "ariphita": ['ap90', 'mw'],
    "aripra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aripura": ['mw'],
    "arirāṣṭra": ['mw'],
    "arisevin": ['cae'],
    "arisiṃha": ['mw'],
    "arisoma": ['mw'],
    "arisūdana": ['bhs', 'cae', 'ddsa', 'mw'],
    "aritra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aritragādha": ['mw'],
    "aritraparaṇa": ['gra', 'mw'],
    "aritta": ['cped'],
    "aritva": ['mw'],
    "aritā": ['mw'],
    "aritīyate": ['bhs'],
    "aritṛ": ['ap90', 'gra', 'mw'],
    "ariya": ['bhs', 'cped'],
    "ariyaddasa": ['cped'],
    "ariyagarahi": ['cped'],
    "ariyagarahin": ['cped'],
    "ariyaka": ['cped'],
    "ariyamagga": ['cped'],
    "ariyasacca": ['cped'],
    "ariyasīli": ['cped'],
    "ariyasīlin": ['cped'],
    "ariyavaṁiksa": ['cped'],
    "ariyavaṁsa": ['cped'],
    "ariyavihāra": ['cped'],
    "ariyavohāra": ['cped'],
    "ariyavutti": ['cped'],
    "ariyavāsa": ['cped'],
    "ariyāyatana": ['cped'],
    "ariyūpavādi": ['cped'],
    "ariyūpavādin": ['cped'],
    "ariñcana": ['bhs'],
    "ariśāsin": ['mw'],
    "ariṃdama": ['ap90', 'cae', 'mw'],
    "ariṇin": ['ap90'],
    "ariṣaṃ": ['ap90'],
    "ariṣaṇya": ['ap90', 'gra', 'mw'],
    "ariṣaṇyat": ['ap90', 'gra', 'mw'],
    "ariṣyat": ['ap90', 'gra', 'mw'],
    "ariṣṭa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ariṣṭabharman": ['gra', 'mw'],
    "ariṣṭaduṣṭadhī": ['mw'],
    "ariṣṭagrāma": ['cae', 'gra', 'mw'],
    "ariṣṭagu": ['mw'],
    "ariṣṭagātu": ['gra', 'mw'],
    "ariṣṭagṛha": ['mw'],
    "ariṣṭahan": ['mw'],
    "ariṣṭaka": ['cae', 'mw'],
    "ariṣṭakarman": ['mw'],
    "ariṣṭakaḥ": ['ap90'],
    "ariṣṭakā": ['mw'],
    "ariṣṭamathana": ['mw'],
    "ariṣṭanemi": ['bhs', 'gra', 'mw'],
    "ariṣṭanemin": ['mw'],
    "ariṣṭapura": ['mw'],
    "ariṣṭaratha": ['gra', 'mw'],
    "ariṣṭaroga": ['mw'],
    "ariṣṭasūdana": ['mw'],
    "ariṣṭatāti": ['cae', 'gra', 'mw'],
    "ariṣṭavīra": ['gra', 'mw'],
    "ariṣṭaśayyā": ['cae', 'mw'],
    "ariṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "ariṣṭikā": ['bhs', 'mw'],
    "ariṣṭiḥ": ['ap90'],
    "ariṣṭuta": ['gra', 'mw'],
    "ariṣṭā": ['bhs', 'mw'],
    "ariṣṭāsu": ['mw'],
    "ariṣṭāśritapura": ['mw'],
    "ariṭṭha": ['cped'],
    "ariṭṭhaka": ['cped'],
    "arj": ['ap90', 'ddsa', 'gra', 'mw'],
    "arjaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "arjana": ['cae', 'mw'],
    "arjanaṃ": ['ap90'],
    "arjanīya": ['mw'],
    "arjin": ['mw'],
    "arjita": ['mw'],
    "arjuna": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "arjunacchavi": ['mw'],
    "arjunadhvaja": ['mw'],
    "arjunaka": ['ap90', 'mw'],
    "arjunakāṇḍa": ['mw'],
    "arjunamiśra": ['mw'],
    "arjunapura": ['mw'],
    "arjunapuruṣa": ['mw'],
    "arjunapākī": ['mw'],
    "arjunapāla": ['mw'],
    "arjunasa": ['ap90', 'mw'],
    "arjunasakhi": ['mw'],
    "arjunasiṃha": ['mw'],
    "arjunatas": ['mw'],
    "arjunaśirīṣa": ['mw'],
    "arjuneśvaratīrtha": ['mw'],
    "arjunopama": ['mw'],
    "arjunābhra": ['mw'],
    "arjunāhva": ['mw'],
    "arjunārcanakalpalatā": ['mw'],
    "arjunārcāpārijāta": ['mw'],
    "arjunāriṣṭasaṃchanna": ['mw'],
    "arjunāva": ['mw'],
    "arjunāvana": ['bhs'],
    "arjunī": ['mw'],
    "arjunīyādamana": ['mw'],
    "ark": ['ap90', 'mw'],
    "arka": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "arkabandhu": ['mw'],
    "arkabhaktā": ['mw'],
    "arkabāndhava": ['mw'],
    "arkacandana": ['mw'],
    "arkacikitsā": ['mw'],
    "arkadhānā": ['mw'],
    "arkadina": ['mw'],
    "arkadugdha": ['mw'],
    "arkagraha": ['mw'],
    "arkagrīva": ['mw'],
    "arkahitā": ['mw'],
    "arkaja": ['mw'],
    "arkajau": ['mw'],
    "arkakara": ['mw'],
    "arkakośī": ['mw'],
    "arkakuṇḍatīrtha": ['mw'],
    "arkakāntā": ['mw'],
    "arkakāṣṭha": ['mw'],
    "arkakṣetra": ['mw'],
    "arkakṣīra": ['mw'],
    "arkalavaṇa": ['mw'],
    "arkalūṣa": ['mw'],
    "arkamaya": ['mw'],
    "arkamaṇḍala": ['mw'],
    "arkamūla": ['mw'],
    "arkamūlā": ['mw'],
    "arkanandana": ['mw'],
    "arkanayana": ['mw'],
    "arkanetra": ['mw'],
    "arkaparṇa": ['mw'],
    "arkapattra": ['mw'],
    "arkapattrā": ['mw'],
    "arkaprabhājāla": ['mw'],
    "arkaprakāśa": ['mw'],
    "arkapriyā": ['mw'],
    "arkaputra": ['mw'],
    "arkapuṣpikā": ['mw'],
    "arkapuṣpottara": ['mw'],
    "arkapuṣpādya": ['mw'],
    "arkapuṣpī": ['mw'],
    "arkapādapa": ['mw'],
    "arkaretoja": ['mw'],
    "arkaripu": ['mw'],
    "arkasamudga": ['mw'],
    "arkasodara": ['mw'],
    "arkastubh": ['mw'],
    "arkasuta": ['mw'],
    "arkasutā": ['mw'],
    "arkasāti": ['gra', 'mw'],
    "arkasūnu": ['mw'],
    "arkatanaya": ['mw'],
    "arkatanayā": ['mw'],
    "arkatva": ['mw'],
    "arkatviṣ": ['mw'],
    "arkavallabha": ['mw'],
    "arkavarṣa": ['mw'],
    "arkavat": ['ap90', 'mw'],
    "arkavedha": ['mw'],
    "arkavidha": ['mw'],
    "arkavrata": ['mw'],
    "arkaya": ['mw'],
    "arkaśaśiśatru": ['mw'],
    "arkaśiras": ['mw'],
    "arkaśoka": ['gra', 'mw'],
    "arkendusaṃgama": ['mw'],
    "arkeṣṭa": ['mw'],
    "arkin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "arkopala": ['mw'],
    "arkya": ['mw'],
    "arkāgrā": ['mw'],
    "arkāhuti": ['mw'],
    "arkāhva": ['mw'],
    "arkātmajā": ['mw'],
    "arkāśman": ['mw'],
    "arkāśvamedha": ['mw'],
    "arkāśvamedhavat": ['mw'],
    "arkāśvamedhin": ['mw'],
    "arkāṃśa": ['mw'],
    "arkāṣṭhīlā": ['mw'],
    "arkīya": ['ap90', 'mw'],
    "arma": ['cae', 'ddsa', 'mw'],
    "armaka": ['ap90', 'gra', 'mw'],
    "armakapāla": ['mw'],
    "arman": ['ap90', 'mw'],
    "armaḥ": ['ap90'],
    "armaṇa": ['mw'],
    "armaṇaṃ": ['ap90'],
    "arocaka": ['ap90', 'mw'],
    "arocakin": ['ap90', 'cae', 'ddsa', 'mw'],
    "arocamāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "arociṣṇu": ['ap90', 'mw'],
    "arocuka": ['mw'],
    "arodana": ['mw'],
    "arodhya": ['mw'],
    "aroga": ['ap90', 'cae', 'ddsa', 'mw'],
    "arogatva": ['mw'],
    "arogatā": ['cae', 'mw'],
    "arogaṇa": ['ap90', 'mw'],
    "arogin": ['ap90', 'ddsa', 'mw'],
    "arogitā": ['mw'],
    "arogya": ['mw'],
    "arogyatā": ['mw'],
    "arogā": ['mw'],
    "arogāpeti": ['cped'],
    "arohiṇīka": ['ddsa', 'mw'],
    "aroka": ['ap90', 'mw'],
    "arokadanta": ['mw'],
    "arokadat": ['mw'],
    "aroma": ['mw'],
    "aromaśa": ['mw'],
    "aropaṇa": ['mw'],
    "arosaneyya": ['cped'],
    "aroṣa": ['mw'],
    "aroṣaḥ": ['ap90'],
    "aroṣaṇa": ['cae', 'mw'],
    "arpaya": ['ddsa', 'mw'],
    "arpaṇa": ['cae', 'ddsa', 'mw'],
    "arpaṇamīmāṃsā": ['mw'],
    "arpaṇaṃ": ['ap90'],
    "arpaṇā": ['bhs'],
    "arpaṇīya": ['mw'],
    "arpima": ['mw'],
    "arpisa": ['mw'],
    "arpisaḥ": ['ap90'],
    "arpita": ['mw'],
    "arpitakara": ['mw'],
    "arpitopta": ['mw'],
    "arpiśa": ['mw'],
    "arpiṣa": ['mw'],
    "arpya": ['mw'],
    "art": ['gra'],
    "artagala": ['mw'],
    "artagalaḥ": ['ap90'],
    "artana": ['ap90', 'mw'],
    "arth": ['ap90', 'mw'],
    "artha": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "arthabandha": ['cae', 'mw'],
    "arthabheda": ['mw'],
    "arthabhraṃśa": ['mw'],
    "arthabhāj": ['mw'],
    "arthabhṛta": ['mw'],
    "arthacara": ['bhs'],
    "arthacaryā": ['bhs', 'mw'],
    "arthacintaka": ['mw'],
    "arthacintana": ['mw'],
    "arthacintā": ['mw'],
    "arthacitra": ['mw'],
    "arthacitta": ['mw'],
    "arthada": ['cae', 'mw'],
    "arthadarpaṇa": ['mw'],
    "arthadarśaka": ['mw'],
    "arthadarśana": ['mw'],
    "arthadarśi": ['bhs'],
    "arthadarśimant": ['bhs'],
    "arthadarśin": ['mw'],
    "arthadatta": ['cae', 'mw'],
    "arthadhāraṇī": ['bhs'],
    "arthadoṣa": ['mw'],
    "arthadravyavirodha": ['mw'],
    "arthadyotanikā": ['mw'],
    "arthadāna": ['cae', 'mw'],
    "arthadāyāda": ['mw'],
    "arthadūṣaṇa": ['cae', 'mw'],
    "arthadṛś": ['mw'],
    "arthadṛṣṭi": ['mw'],
    "arthagarīyas": ['mw'],
    "arthagata": ['mw'],
    "arthagati": ['mw'],
    "arthaghna": ['cae', 'mw'],
    "arthagrahaṇa": ['mw'],
    "arthagrāhin": ['mw'],
    "arthaguṇa": ['mw'],
    "arthagṛha": ['mw'],
    "arthahara": ['mw'],
    "arthahāni": ['mw'],
    "arthahāraka": ['mw'],
    "arthahārikā": ['mw'],
    "arthahārin": ['mw'],
    "arthahīna": ['mw'],
    "arthaikatva": ['mw'],
    "arthaikya": ['mw'],
    "arthajña": ['mw'],
    "arthajāta": ['cae', 'mw'],
    "arthakalyavarta": ['cae'],
    "arthakara": ['ddsa', 'mw'],
    "arthakarman": ['mw'],
    "arthakartṛ": ['mw'],
    "arthakathā": ['mw'],
    "arthakilbiṣin": ['cae', 'mw'],
    "arthakovida": ['mw'],
    "arthakriyā": ['bhs', 'mw'],
    "arthakāma": ['cae', 'mw'],
    "arthakāmya": ['mw'],
    "arthakāraka": ['mw'],
    "arthakāraṇāt": ['mw'],
    "arthakārin": ['mw'],
    "arthakārśya": ['mw'],
    "arthakāśin": ['mw'],
    "arthakṛcchra": ['cae', 'mw'],
    "arthakṛt": ['mw'],
    "arthakṛta": ['mw'],
    "arthakṛtya": ['mw'],
    "arthakṛtyā": ['mw'],
    "arthaleśa": ['mw'],
    "arthalobha": ['mw'],
    "arthalola": ['mw'],
    "arthalopa": ['mw'],
    "arthalubdha": ['mw'],
    "arthalābha": ['mw'],
    "arthalāghava": ['mw'],
    "artham": ['mw'],
    "arthamanas": ['mw'],
    "arthamatta": ['mw'],
    "arthamaya": ['mw'],
    "arthamātra": ['mw'],
    "arthanatā": ['bhs'],
    "arthanibandhana": ['mw'],
    "arthanirvṛtti": ['mw'],
    "arthaniścaya": ['mw'],
    "arthanyūna": ['mw'],
    "arthanā": ['ap90', 'cae', 'ddsa', 'mw'],
    "arthanāśa": ['ddsa', 'mw'],
    "arthanāśaka": ['mw'],
    "arthanīya": ['ddsa', 'mw'],
    "arthapada": ['mw'],
    "arthapadavī": ['mw'],
    "arthapara": ['mw'],
    "arthaparigraha": ['mw'],
    "arthapati": ['ddsa', 'mw'],
    "arthapañcaka": ['mw'],
    "arthaprakṛti": ['mw'],
    "arthaprasaṃkhyā": ['mw'],
    "arthaprayoga": ['mw'],
    "arthaprāpti": ['mw'],
    "arthapunarukta": ['mw'],
    "arthapāla": ['mw'],
    "arthapāṭha": ['mw'],
    "arthapūrvaka": ['mw'],
    "arthapūrvakatva": ['mw'],
    "artharacana": ['mw'],
    "artharuci": ['cae', 'mw'],
    "artharāśi": ['mw'],
    "artharūpa": ['mw'],
    "arthasama": ['mw'],
    "arthasambandha": ['mw'],
    "arthasambandhin": ['mw'],
    "arthasambhava": ['mw'],
    "arthasampādana": ['ddsa', 'mw'],
    "arthasamāhartṛ": ['cae', 'mw'],
    "arthasaṃbandhin": ['cae'],
    "arthasaṃcaya": ['mw'],
    "arthasaṃdeha": ['mw'],
    "arthasaṃgraha": ['mw'],
    "arthasaṃgrahin": ['mw'],
    "arthasaṃnyāsin": ['mw'],
    "arthasaṃpādana": ['cae'],
    "arthasaṃsthāna": ['mw'],
    "arthasaṃśaya": ['mw'],
    "arthasiddha": ['cae', 'mw'],
    "arthasiddhaka": ['mw'],
    "arthasiddhi": ['bhs', 'cae', 'mw'],
    "arthasādhaka": ['mw'],
    "arthasādhana": ['mw'],
    "arthasāra": ['mw'],
    "arthatantra": ['mw'],
    "arthatas": ['cae', 'mw'],
    "arthatattva": ['mw'],
    "arthataḥ": ['ap90'],
    "arthatṛṣ": ['mw'],
    "arthatṛṣṇā": ['cae', 'mw'],
    "arthaugha": ['mw'],
    "arthavacanaśrī": ['bhs'],
    "arthavaikalya": ['cae', 'mw'],
    "arthavant": ['cae'],
    "arthavargīya": ['bhs', 'mw'],
    "arthavarjita": ['mw'],
    "arthavarman": ['mw'],
    "arthavat": ['ap90', 'mw'],
    "arthavattva": ['mw'],
    "arthavattā": ['ap90', 'cae', 'mw'],
    "arthavaśa": ['bhs', 'mw'],
    "arthavid": ['cae', 'mw'],
    "arthavidyā": ['mw'],
    "arthavijñāna": ['mw'],
    "arthaviniścaya": ['bhs', 'mw'],
    "arthavināśa": ['mw'],
    "arthavināśana": ['mw'],
    "arthavipatti": ['mw'],
    "arthaviśeṣaṇa": ['mw'],
    "arthavyakti": ['mw'],
    "arthavyavahāra": ['mw'],
    "arthavyaya": ['mw'],
    "arthavyayasaha": ['mw'],
    "arthavāda": ['cae', 'mw'],
    "arthavādin": ['mw'],
    "arthavṛddhi": ['mw'],
    "arthay": ['cae', 'gra'],
    "arthaya": ['ddsa'],
    "arthayogya": ['mw'],
    "arthayukta": ['ddsa', 'mw'],
    "arthayukti": ['mw'],
    "arthaśabdau": ['mw'],
    "arthaśauca": ['cae', 'mw'],
    "arthaśleṣa": ['mw'],
    "arthaśrī": ['mw'],
    "arthaśālin": ['mw'],
    "arthaśāstra": ['cae', 'ddsa', 'mw'],
    "arthaśāstraka": ['mw'],
    "arthaḥ": ['ap90'],
    "arthe": ['mw'],
    "arthega": ['mw'],
    "arthehā": ['mw'],
    "arthepsutā": ['mw'],
    "arthet": ['mw'],
    "arthi": ['mw'],
    "arthibhāva": ['cae', 'mw'],
    "arthika": ['bhs', 'ddsa', 'mw'],
    "arthikaḥ": ['ap90'],
    "arthin": ['ap90', 'cae', 'gra', 'mw'],
    "arthisāt": ['mw'],
    "arthisātkṛ": ['ddsa'],
    "arthita": ['ap90', 'mw'],
    "arthitavya": ['cae', 'mw'],
    "arthitva": ['mw'],
    "arthitā": ['ap90', 'cae', 'mw'],
    "arthoddyotanikā": ['mw'],
    "arthopakṣepaka": ['mw'],
    "arthopakṣepaṇa": ['mw'],
    "arthopama": ['mw'],
    "arthopārjana": ['mw'],
    "arthotpāda": ['mw'],
    "arthotsarga": ['ddsa', 'mw'],
    "arthoṣman": ['mw'],
    "arthuṣya": ['mw'],
    "arthya": ['ap90', 'cae', 'ddsa', 'mw'],
    "arthyukta": ['cae'],
    "arthābhinirvṛtti": ['mw'],
    "arthābhipatti": ['mw'],
    "arthābhiprāpaṇa": ['mw'],
    "arthābhāva": ['mw'],
    "arthādhikāra": ['mw'],
    "arthādhikārin": ['mw'],
    "arthādhinātha": ['mw'],
    "arthāgama": ['ddsa', 'mw'],
    "arthākṣipta": ['mw'],
    "arthālaṃkāra": ['mw'],
    "arthānartha": ['cae', 'mw'],
    "arthāntara": ['cae', 'mw'],
    "arthāntaranyāsa": ['mw'],
    "arthāntarya": ['mw'],
    "arthāntarākṣepa": ['mw'],
    "arthānvita": ['mw'],
    "arthāpatti": ['mw'],
    "arthāpattisama": ['mw'],
    "arthāpaya": ['ap90', 'mw'],
    "arthāpekṣa": ['mw'],
    "arthārjana": ['cae', 'mw'],
    "arthārtha": ['mw'],
    "arthārtham": ['mw'],
    "arthārthatattvajña": ['mw'],
    "arthārthin": ['cae', 'mw'],
    "arthārthitā": ['mw'],
    "arthāt": ['ap90', 'mw'],
    "arthāvamarda": ['mw'],
    "arthāvṛtti": ['mw'],
    "arthīya": ['ap90', 'ddsa', 'mw'],
    "arti": ['ddsa', 'mw'],
    "artikā": ['ap90', 'mw'],
    "artita": ['bhs'],
    "artiyati": ['bhs'],
    "artiḥ": ['ap90'],
    "artuka": ['ap90', 'mw'],
    "artīyanā": ['bhs'],
    "aru": ['cae', 'mw'],
    "aruc": ['ap90', 'cae', 'gra', 'mw'],
    "aruci": ['ddsa', 'mw'],
    "arucira": ['ap90', 'mw'],
    "arucita": ['mw'],
    "aruciḥ": ['ap90'],
    "arucya": ['mw'],
    "aruddha": ['mw'],
    "arugatta": ['cped'],
    "arugṇa": ['ap90', 'cae', 'gra', 'mw'],
    "aruhā": ['ap90', 'mw'],
    "aruj": ['ap90', 'cae', 'ddsa', 'mw'],
    "aruja": ['ap90', 'cae', 'mw'],
    "aruka": ['cped'],
    "arukāya": ['cped'],
    "arula": ['mw'],
    "arundhatī": ['cae', 'ddsa', 'mw'],
    "arundhatīdarśananyāya": ['mw'],
    "arundhatījāni": ['mw'],
    "arundhatīnātha": ['mw'],
    "arundhatīsahacara": ['mw'],
    "arundhatīvaṭa": ['mw'],
    "arunmukha": ['mw'],
    "aruntuda": ['ddsa'],
    "arurmagha": ['mw'],
    "arus": ['ap90', 'cae', 'ddsa', 'mw'],
    "arusikā": ['ap90'],
    "arussrāṇa": ['mw'],
    "aruta": ['ap90', 'gra'],
    "arutahanu": ['gra', 'mw'],
    "aruśa": ['mw'],
    "aruśahan": ['gra', 'mw'],
    "aruḥ": ['ap90'],
    "aruḥsrāṇa": ['mw'],
    "aruṃdhatī": ['ap90'],
    "aruṃtuda": ['ap90', 'cae', 'mw'],
    "aruṃṣikā": ['ap90', 'mw'],
    "aruṇa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "aruṇababhru": ['mw'],
    "aruṇacūḍa": ['mw'],
    "aruṇadatta": ['mw'],
    "aruṇadatī": ['mw'],
    "aruṇadūrvā": ['mw'],
    "aruṇagga": ['cped'],
    "aruṇaita": ['mw'],
    "aruṇajyotis": ['mw'],
    "aruṇakamala": ['mw'],
    "aruṇakara": ['mw'],
    "aruṇaketubrāhmaṇa": ['mw'],
    "aruṇakiraṇa": ['mw'],
    "aruṇalocana": ['mw'],
    "aruṇanetra": ['mw'],
    "aruṇapiśaṅga": ['mw'],
    "aruṇapriyā": ['mw'],
    "aruṇapsu": ['cae', 'gra', 'mw'],
    "aruṇapuṣpa": ['mw'],
    "aruṇapuṣpī": ['mw'],
    "aruṇasmṛti": ['mw'],
    "aruṇasārathi": ['mw'],
    "aruṇatva": ['mw'],
    "aruṇatā": ['mw'],
    "aruṇavati": ['bhs'],
    "aruṇaya": ['ddsa', 'mw'],
    "aruṇayuj": ['gra', 'mw'],
    "aruṇaṁ uṭṭhāpeti": ['cped'],
    "aruṇi": ['mw'],
    "aruṇiman": ['ap90', 'cae', 'mw'],
    "aruṇita": ['ap90'],
    "aruṇoda": ['ddsa', 'mw'],
    "aruṇodaya": ['cae', 'mw'],
    "aruṇodayasaptamī": ['mw'],
    "aruṇodghāṭa": ['bhs'],
    "aruṇopala": ['mw'],
    "aruṇugga": ['cped'],
    "aruṇuggamana": ['cped'],
    "aruṇā": ['bhs', 'mw'],
    "aruṇāditya": ['mw'],
    "aruṇāgraja": ['mw'],
    "aruṇāmnāyavidhi": ['mw'],
    "aruṇānuja": ['ddsa', 'mw'],
    "aruṇārcis": ['mw'],
    "aruṇātmaja": ['mw'],
    "aruṇāvaraja": ['mw'],
    "aruṇāśva": ['cae', 'gra', 'mw'],
    "aruṇī": ['ddsa', 'mw'],
    "aruṇīkṛ": ['ddsa'],
    "aruṇīkṛta": ['mw'],
    "aruṇīyavidhi": ['mw'],
    "aruṇīyaḥ": ['ap90'],
    "aruṣ": ['ap90', 'ddsa', 'mw'],
    "aruṣa": ['ap90', 'ddsa', 'gra', 'mw'],
    "aruṣastūpa": ['gra', 'mw'],
    "aruṣati": ['ap90'],
    "aruṣaṃ": ['cae'],
    "aruṣka": ['mw'],
    "aruṣkara": ['mw'],
    "aruṣkaḥ": ['ap90'],
    "aruṣkṛta": ['mw'],
    "aruṣya": ['bhs', 'mw'],
    "aruṣyat": ['ddsa'],
    "aruṣyati": ['ap90'],
    "aruṣī": ['mw'],
    "arv": ['ap90', 'mw'],
    "arva": ['gra', 'mw'],
    "arvam, arvan": ['ddsa'],
    "arvan": ['ap90', 'cae', 'gra', 'mw'],
    "arvant": ['cae'],
    "arvat": ['gra', 'mw'],
    "arvatī": ['ddsa', 'gra', 'mw'],
    "arvaśa": ['ap90', 'cae', 'gra', 'mw'],
    "arvaṇa": ['gra', 'mw'],
    "arvaṭaṃ": ['ap90'],
    "arvuka": ['ap90', 'mw'],
    "arvāc": ['gra', 'mw'],
    "arvācin": ['mw'],
    "arvācīna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "arvācīnam": ['mw'],
    "arvāg": ['mw'],
    "arvāgaśīta": ['mw'],
    "arvāgbila": ['mw'],
    "arvāgvasu": ['mw'],
    "arvāgviṃśa": ['mw'],
    "arvāk": ['ddsa', 'mw'],
    "arvāka": ['gra'],
    "arvākcatvāriṃśa": ['mw'],
    "arvāke": ['ap90', 'cae', 'mw'],
    "arvākkālikatā": ['cae', 'ddsa', 'mw'],
    "arvākkūla": ['mw'],
    "arvākpañcāśa": ['mw'],
    "arvāksrotas": ['mw'],
    "arvāksāman": ['mw'],
    "arvāktana": ['mw'],
    "arvākśata": ['mw'],
    "arvākṣaṣṭha": ['mw'],
    "arvāvasu": ['ap90', 'mw'],
    "arvāvat": ['ap90', 'gra', 'mw'],
    "arvāñc": ['cae', 'ddsa'],
    "arvāṃc": ['ap90'],
    "arya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aryajārā": ['mw'],
    "aryaka": ['bhs', 'mw'],
    "aryama": ['mw'],
    "aryamabhūti": ['mw'],
    "aryamadaivata": ['mw'],
    "aryamadatta": ['mw'],
    "aryamadevā": ['mw'],
    "aryamagṛhapati": ['mw'],
    "aryaman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aryamanandana": ['mw'],
    "aryamarādha": ['mw'],
    "aryamia": ['gra'],
    "aryamika": ['ap90', 'mw'],
    "aryamila": ['mw'],
    "aryamiya": ['mw'],
    "aryamya": ['cae', 'ddsa', 'gra', 'mw'],
    "aryamyaḥ": ['ap90'],
    "aryamākhya": ['mw'],
    "aryapati": ['mw'],
    "aryapatnī": ['gra', 'mw'],
    "aryavarya": ['mw'],
    "aryayā": ['gra'],
    "aryaśveta": ['mw'],
    "aryā": ['mw'],
    "aryāṇī": ['ap90', 'mw'],
    "aryī": ['mw'],
    "arā": ['mw'],
    "arāddhi": ['mw'],
    "arāddhiḥ": ['ap90'],
    "arādhas": ['ap90', 'cae', 'gra', 'mw'],
    "arāga": ['ap90', 'ddsa', 'mw'],
    "arāgadveṣa": ['mw'],
    "arāgadveṣatas": ['cae', 'mw'],
    "arāgadveṣin": ['mw'],
    "arāgin": ['mw'],
    "arāgitā": ['mw'],
    "arājaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "arājan": ['ap90', 'cae', 'mw'],
    "arājanya": ['cae', 'mw'],
    "arājanyaprasūti": ['cae'],
    "arājatā": ['mw'],
    "arājika": ['cped'],
    "arājin": ['ap90', 'cae', 'gra', 'mw'],
    "arājyabhāj": ['cae'],
    "arājānvayin": ['mw'],
    "arākṣasa": ['cae', 'mw'],
    "arāla": ['ap90', 'cae', 'ddsa', 'mw'],
    "arālahasta": ['mw'],
    "arālakeśī": ['mw'],
    "arālapakṣmanayana": ['mw'],
    "arāli": ['mw'],
    "arālā": ['mw'],
    "arālī": ['mw'],
    "arāma": ['ddsa'],
    "arāntara": ['mw'],
    "arāntaragatā": ['mw'],
    "arāti": ['cae', 'ddsa', 'gra', 'mw'],
    "arātibhaṅga": ['mw'],
    "arātidūṣaṇa": ['mw'],
    "arātidūṣi": ['mw'],
    "arātiha": ['mw'],
    "arātinud": ['mw'],
    "arātiya": ['mw'],
    "arātiyati": ['ap90'],
    "arātiḥ": ['ap90'],
    "arātīvan": ['ap90', 'cae', 'gra', 'mw'],
    "arātīy": ['cae', 'gra'],
    "arātīya": ['mw'],
    "arātīyat": ['ap90'],
    "arātīyati": ['ap90'],
    "arātīyu": ['ap90', 'mw'],
    "arāva": ['bhs'],
    "arāvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "arāya": ['ap90', 'cae', 'gra', 'mw'],
    "arāyacātana": ['mw'],
    "arāyakṣayaṇa": ['mw'],
    "arāyī": ['gra', 'mw'],
    "arāḍa": ['bhs', 'cae', 'mw'],
    "arāḍya": ['cae', 'mw'],
    "arāṇa": ['ddsa', 'mw'],
    "arāṇi": ['mw'],
    "arāṣṭra": ['mw'],
    "arāṣṭraṃ": ['ap90'],
    "arāṭakī": ['ap90', 'mw'],
    "arīhaṇa": ['mw'],
    "arīhaṇādi": ['mw'],
    "arīl̤ha": ['ap90', 'cae', 'mw'],
    "arīti": ['mw'],
    "arītika": ['mw'],
    "arīḍha": ['cae', 'gra'],
    "arīṇa": ['mw'],
    "arś": ['gra'],
    "arśa": ['ap90', 'gra', 'mw'],
    "arśas": ['ap90', 'cae', 'ddsa', 'mw'],
    "arśasa": ['ap90', 'cae', 'mw'],
    "arśasin": ['mw'],
    "arśasāna": ['ap90', 'mw'],
    "arśaādi": ['mw'],
    "arśin": ['ap90', 'mw'],
    "arśo": ['mw'],
    "arśoghora": ['mw'],
    "arśoghorī": ['mw'],
    "arśohita": ['mw'],
    "arśoroga": ['mw'],
    "arśorogayuta": ['mw'],
    "arśorogin": ['mw'],
    "arśovartman": ['mw'],
    "arśoyuj": ['mw'],
    "arśāṅgi": ['bhs'],
    "arūha": ['bhs'],
    "arūkṛ": ['mw'],
    "arūkṣa": ['ap90', 'mw'],
    "arūkṣatā": ['mw'],
    "arūkṣita": ['ap90', 'gra', 'mw'],
    "arūkṣṇa": ['mw'],
    "arūpa": ['ap90', 'cae', 'ddsa', 'mw'],
    "arūpajña": ['mw'],
    "arūpaka": ['ap90', 'mw'],
    "arūpaloka": ['mw'],
    "arūpamacitta": ['cped'],
    "arūparāga": ['mw'],
    "arūpatva": ['mw'],
    "arūpatā": ['ap90', 'mw'],
    "arūpavat": ['mw'],
    "arūpaṇa": ['cae', 'mw'],
    "arūpin": ['bhs', 'mw'],
    "arūpāvacara": ['bhs', 'mw'],
    "arūḍhamūlatva": ['cae', 'ddsa', 'mw'],
    "arūṣa": ['mw'],
    "arūṣaḥ": ['ap90'],
    "arṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "arṇas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "arṇasa": ['gra', 'mw'],
    "arṇasvat": ['ap90', 'mw'],
    "arṇasāti": ['cae', 'ddsa', 'gra', 'mw'],
    "arṇava": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "arṇavabhava": ['mw'],
    "arṇavaja": ['mw'],
    "arṇavamala": ['mw'],
    "arṇavamandira": ['mw'],
    "arṇavanemi": ['mw'],
    "arṇavapati": ['mw'],
    "arṇavapota": ['mw'],
    "arṇavasaridāśrita": ['mw'],
    "arṇavavarṇana": ['mw'],
    "arṇavayāna": ['mw'],
    "arṇavaśakkarī": ['mw'],
    "arṇavodbhava": ['mw'],
    "arṇavānta": ['mw'],
    "arṇikā": ['mw'],
    "arṇo": ['mw'],
    "arṇobhava": ['mw'],
    "arṇoda": ['mw'],
    "arṇodara": ['mw'],
    "arṇonidhi": ['mw'],
    "arṇovṛt": ['gra', 'mw'],
    "arṇā": ['mw'],
    "arṇācitrarathā": ['mw'],
    "arṣ": ['ddsa', 'gra'],
    "arṣaṇa": ['ap90', 'mw'],
    "arṣaṇin": ['mw'],
    "arṣaṇī": ['mw'],
    "arṣu": ['gra'],
    "arṣṭṛ": ['mw'],
    "as": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asa": ['cped', 'mw'],
    "asabandhu": ['mw'],
    "asabbha": ['cped'],
    "asabha": ['mw'],
    "asabhya": ['ap90', 'mw'],
    "asac": ['mw'],
    "asaca": ['gra'],
    "asacadviṣ": ['ap90', 'cae', 'gra', 'mw'],
    "asacchākhā": ['mw'],
    "asacchāstra": ['mw'],
    "asad": ['mw'],
    "asadadhyetṛ": ['mw'],
    "asadbhāva": ['cae', 'mw'],
    "asadbuddhi": ['mw'],
    "asaddadhāna": ['bhs'],
    "asaddharma": ['mw'],
    "asaddhiya": ['cped'],
    "asaddṛś": ['mw'],
    "asadgraha": ['cae', 'ddsa', 'mw'],
    "asadgrāha": ['mw'],
    "asadgrāhin": ['mw'],
    "asadvyavahāra": ['mw'],
    "asadvyavahārin": ['mw'],
    "asadvāc": ['mw'],
    "asadvāda": ['mw'],
    "asadvṛtti": ['mw'],
    "asadyas": ['ap90', 'mw'],
    "asadācāra": ['mw'],
    "asadācārin": ['mw'],
    "asadāgraha": ['mw'],
    "asadṛśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "asadṛśaguṇakīrtidhvaja": ['bhs'],
    "asadṛśatva": ['mw'],
    "asadṛśavyavahārin": ['mw'],
    "asadṛśopama": ['mw'],
    "asagotra": ['ap90', 'cae', 'mw'],
    "asaha": ['ap90', 'cae', 'ddsa', 'mw'],
    "asahamāna": ['ap90', 'cae', 'mw'],
    "asahana": ['ap90', 'cae', 'mw'],
    "asahanatā": ['mw'],
    "asahant": ['cae'],
    "asahanīya": ['ap90'],
    "asahat": ['mw'],
    "asahatva": ['mw'],
    "asahita": ['ap90', 'bhs'],
    "asahitavya": ['ap90'],
    "asahiṣṇu": ['ap90', 'cae', 'ddsa', 'mw'],
    "asahiṣṇutva": ['mw'],
    "asahiṣṇutā": ['mw'],
    "asahya": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "asahyapīḍa": ['mw'],
    "asahyasāhin": ['bhs'],
    "asahānadhammatā": ['cped'],
    "asahāya": ['ap90', 'cae', 'ddsa', 'mw'],
    "asahāyatā": ['mw'],
    "asahāyavant": ['cae'],
    "asahāyavat": ['mw'],
    "asahāyin": ['cae'],
    "asahṛdaya": ['mw'],
    "asaj": ['mw'],
    "asajjamāna": ['ddsa', 'mw'],
    "asajjana": ['cae', 'ddsa', 'mw'],
    "asajjitātman": ['mw'],
    "asajjātimiśra": ['mw'],
    "asajāta": ['ap90', 'mw'],
    "asajāti": ['cae', 'ddsa', 'mw'],
    "asajātya": ['ap90', 'cae', 'gra', 'mw'],
    "asakala": ['cae', 'mw'],
    "asakau": ['ap90', 'mw'],
    "asakhi": ['mw'],
    "asakhiḥ": ['ap90'],
    "asakra": ['ap90', 'gra', 'mw'],
    "asakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "asaktabuddhi": ['cae'],
    "asaktam": ['mw'],
    "asaktha": ['ap90', 'mw'],
    "asakthi": ['mw'],
    "asakti": ['cae', 'mw'],
    "asaktātman": ['cae'],
    "asakāma": ['cped'],
    "asakṛdbhava": ['mw'],
    "asakṛdgarbhavāsa": ['mw'],
    "asakṛt": ['ap90', 'cae', 'ddsa', 'mw'],
    "asakṛtsamādhi": ['mw'],
    "asalaṃ": ['ap90'],
    "asama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asamabāṇa": ['mw'],
    "asamad": ['ap90', 'cae', 'ddsa', 'mw'],
    "asamada": ['ap90'],
    "asamagra": ['ap90', 'cae', 'ddsa', 'mw'],
    "asamagram": ['mw'],
    "asamakṣam": ['mw'],
    "asamana": ['ap90', 'ddsa', 'gra', 'mw'],
    "asamanta": ['bhs'],
    "asamantaparivarta": ['bhs'],
    "asamanvāharitvā": ['bhs'],
    "asamanvāhāra": ['bhs', 'mw'],
    "asamanvāhṛtya": ['bhs'],
    "asamaratha": ['mw'],
    "asamarpaṇa": ['mw'],
    "asamarpita": ['mw'],
    "asamartha": ['ap90', 'cae', 'ddsa', 'mw'],
    "asamarthatva": ['mw'],
    "asamasama": ['bhs', 'mw'],
    "asamasta": ['ap90', 'cae', 'ddsa', 'mw'],
    "asamasāyaka": ['ddsa', 'mw'],
    "asamatva": ['mw'],
    "asamatā": ['mw'],
    "asamaujas": ['mw'],
    "asamavahitam": ['mw'],
    "asamaveta": ['ap90', 'ddsa', 'mw'],
    "asamavāyin": ['ap90', 'mw'],
    "asamavāṇa": ['ddsa'],
    "asamaya": ['cae', 'ddsa', 'mw'],
    "asamayavimukta": ['bhs'],
    "asamayavyukta": ['mw'],
    "asamayaḥ": ['ap90'],
    "asamañja": ['cae', 'ddsa', 'mw'],
    "asamañjas": ['cae', 'mw'],
    "asamañjasa": ['cae', 'mw'],
    "asamañjasam": ['mw'],
    "asamaśara": ['mw'],
    "asamaṃjasa": ['ap90'],
    "asamaṣṭa": ['gra'],
    "asamaṣṭakāvia": ['gra'],
    "asamaṣṭakāvya": ['gra', 'mw'],
    "asambaddha": ['ddsa'],
    "asambhava": ['ddsa'],
    "asambhūta": ['mw'],
    "asameta": ['mw'],
    "asametya": ['cae'],
    "asameṣu": ['mw'],
    "asamidhya": ['cae', 'mw'],
    "asammata": ['ddsa'],
    "asammoṣadharman": ['mw'],
    "asammṛṣṭa": ['gra'],
    "asampakampi": ['cped'],
    "asampakampin": ['cped'],
    "asamparigraha": ['mw'],
    "asampatti": ['ddsa'],
    "asampavedhi": ['cped'],
    "asampavedhin": ['cped'],
    "asamprajñāna": ['mw'],
    "asamprajñāta": ['mw'],
    "asampramāṇa": ['mw'],
    "asampuṣa": ['mw'],
    "asampṛkta": ['mw'],
    "asamudrotthita": ['cae'],
    "asamudyama": ['cae'],
    "asamyak": ['cae', 'ddsa', 'mw'],
    "asamyakkārin": ['cae', 'mw'],
    "asamyakkṛtakārin": ['mw'],
    "asamyakprayoga": ['mw'],
    "asamyaṃc": ['ap90'],
    "asamāhita": ['cae'],
    "asamāhāra": ['ap90'],
    "asamāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "asamānagrāma": ['mw'],
    "asamānakāraṇa": ['mw'],
    "asamāpta": ['ap90', 'cae', 'ddsa', 'mw'],
    "asamāptaprabha": ['mw'],
    "asamāpti": ['mw'],
    "asamāti": ['ap90', 'gra', 'mw'],
    "asamātiojas": ['gra'],
    "asamātyojas": ['gra', 'mw'],
    "asamāvartaka": ['mw'],
    "asamāvartakaḥ": ['ap90'],
    "asamāvṛttaka": ['cae', 'ddsa', 'mw'],
    "asamāvṛttaḥ": ['ap90'],
    "asamāvṛttika": ['cae', 'mw'],
    "asamāvṛttikaḥ": ['ap90'],
    "asamāyuta": ['mw'],
    "asamāśuga": ['mw'],
    "asamīcīna": ['mw'],
    "asamīkṣita": ['mw'],
    "asamīkṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "asamīkṣyakārin": ['mw'],
    "asamīrita": ['ddsa'],
    "asamṛddha": ['cae', 'mw'],
    "asamṛddhi": ['cae', 'mw'],
    "asan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "asanaparṇī": ['mw'],
    "asanaṃ": ['ap90'],
    "asandadhāna": ['ddsa'],
    "asani": ['mw'],
    "asanidarśana": ['mw'],
    "asanika": ['mw'],
    "asanivicakka": ['cped'],
    "asaniḥ": ['ap90'],
    "asanmantra": ['mw'],
    "asanmati": ['mw'],
    "asanmāna": ['mw'],
    "asanna": ['ap90', 'mw'],
    "asannaddha": ['ddsa'],
    "asant": ['cae'],
    "asantaka": ['bhs'],
    "asantāpa": ['ddsa'],
    "asanā": ['gra', 'mw'],
    "asanābhi": ['mw'],
    "asanāma": ['cae', 'ddsa', 'mw'],
    "asanī": ['bhs', 'cped'],
    "asapatna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asapatnā": ['mw'],
    "asapiṃḍa": ['ap90'],
    "asapiṇḍa": ['cae', 'mw'],
    "asaptaśapha": ['mw'],
    "asaraṇa": ['mw'],
    "asarpabhūta": ['ddsa'],
    "asaru": ['mw'],
    "asaruḥ": ['ap90'],
    "asarva": ['ap90', 'cae', 'ddsa', 'mw'],
    "asarvahoma": ['mw'],
    "asarvajña": ['mw'],
    "asarvakratu": ['mw'],
    "asarvavibhakti": ['mw'],
    "asarvavīra": ['mw'],
    "asarvaśas": ['mw'],
    "asarūpa": ['mw'],
    "asasant": ['cae'],
    "asasat": ['ap90', 'ddsa', 'gra', 'mw'],
    "asasya": ['mw'],
    "asat": ['ap90', 'ddsa', 'gra', 'mw'],
    "asate": ['bhs'],
    "asati": ['cped'],
    "asatkalpanā": ['cae', 'mw'],
    "asatkaratva": ['mw'],
    "asatkarman": ['ap90'],
    "asatkriyā": ['mw'],
    "asatkāra": ['mw'],
    "asatkāraḥ": ['ap90'],
    "asatkārya": ['cae', 'mw'],
    "asatkāryaparigraha": ['cae'],
    "asatkāryavādin": ['mw'],
    "asatkṛ": ['ap90'],
    "asatkṛta": ['ap90', 'cae', 'mw'],
    "asatkṛtya": ['mw'],
    "asatparigraha": ['mw'],
    "asatpatha": ['mw'],
    "asatpramudita": ['mw'],
    "asatpratigraha": ['mw'],
    "asatputra": ['cae', 'mw'],
    "asatsamparka": ['ddsa'],
    "asatsaṃsarga": ['mw'],
    "asatsaṅga": ['mw'],
    "asatthika": ['cped'],
    "asattva": ['ap90', 'cae', 'mw'],
    "asattvavacana": ['cae'],
    "asattā": ['ap90', 'mw'],
    "asatya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asatyasandha": ['mw'],
    "asatyasannibha": ['mw'],
    "asatyasaṃdha": ['cae'],
    "asatyatā": ['mw'],
    "asatyavacana": ['cae'],
    "asatyavāda": ['mw'],
    "asatyavādin": ['mw'],
    "asatyaśīla": ['mw'],
    "asatāyī": ['ap90'],
    "asatī": ['mw'],
    "asatīsuta": ['mw'],
    "asau": ['cae', 'ddsa', 'mw'],
    "asaubhāgya": ['ddsa'],
    "asauhṛda": ['cae', 'mw'],
    "asaukṛ": ['mw'],
    "asaumya": ['ap90', 'mw'],
    "asaundarya": ['mw'],
    "asaunāman": ['ap90', 'mw'],
    "asauvarṇa": ['cae', 'ddsa', 'mw'],
    "asauyaja": ['mw'],
    "asauṣṭhava": ['ap90', 'cae', 'mw'],
    "asavarṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "asavya": ['ddsa', 'mw'],
    "asavye": ['mw'],
    "asañcetayamāna": ['ddsa'],
    "asañjña": ['ddsa'],
    "asañjñā": ['ddsa'],
    "asañjāta": ['ddsa'],
    "asaścant": ['cae'],
    "asaścat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asaścatā": ['mw'],
    "asaścivas": ['gra', 'mw'],
    "asaṁ": ['cped'],
    "asaṃbaddha": ['ap90', 'cae', 'mw'],
    "asaṃbaddhamanoratha": ['cae'],
    "asaṃbaddhapralāpa": ['cae'],
    "asaṃbaddhapralāpin": ['cae'],
    "asaṃbandha": ['cae', 'mw'],
    "asaṃbaṃdha": ['ap90'],
    "asaṃbhava": ['ap90', 'cae', 'mw'],
    "asaṃbhavya": ['ap90'],
    "asaṃbhavyam": ['mw'],
    "asaṃbheda": ['mw'],
    "asaṃbhedya": ['mw'],
    "asaṃbhindat": ['mw'],
    "asaṃbhinna": ['bhs', 'mw'],
    "asaṃbhoga": ['mw'],
    "asaṃbhojya": ['cae', 'mw'],
    "asaṃbhrama": ['ap90', 'cae', 'mw'],
    "asaṃbhramam": ['mw'],
    "asaṃbhrānta": ['cae'],
    "asaṃbhrāntam": ['mw'],
    "asaṃbhrāntavacana": ['bhs'],
    "asaṃbhāvanā": ['ap90', 'mw'],
    "asaṃbhāvanīya": ['ap90', 'mw'],
    "asaṃbhāvita": ['cae', 'mw'],
    "asaṃbhāvitopamā": ['cae', 'mw'],
    "asaṃbhāvya": ['mw'],
    "asaṃbhāvyam": ['mw'],
    "asaṃbhāṣya": ['cae', 'mw'],
    "asaṃbhāṣā": ['mw'],
    "asaṃbhūti": ['mw'],
    "asaṃbhūtiḥ": ['ap90'],
    "asaṃbhṛta": ['ap90'],
    "asaṃbodha": ['mw'],
    "asaṃbādha": ['ap90', 'cae', 'mw'],
    "asaṃbādhā": ['mw'],
    "asaṃcara": ['mw'],
    "asaṃcarat": ['mw'],
    "asaṃcaya": ['mw'],
    "asaṃcayavat": ['mw'],
    "asaṃcayika": ['mw'],
    "asaṃchanna": ['mw'],
    "asaṃcita": ['mw'],
    "asaṃcāra": ['mw'],
    "asaṃcārya": ['mw'],
    "asaṃdadhāna": ['mw'],
    "asaṃdarśana": ['mw'],
    "asaṃdheya": ['cae', 'mw'],
    "asaṃdheyatā": ['mw'],
    "asaṃdhi": ['ap90', 'bhs', 'mw'],
    "asaṃdhita": ['mw'],
    "asaṃdhāna": ['mw'],
    "asaṃdhūkṣaṇatā": ['bhs'],
    "asaṃdigdha": ['ap90', 'mw'],
    "asaṃdigdham": ['mw'],
    "asaṃdina": ['cae', 'gra', 'mw'],
    "asaṃdita": ['ap90', 'cae', 'gra', 'mw'],
    "asaṃdṛśya": ['mw'],
    "asaṃga": ['ap90'],
    "asaṃgama": ['ap90', 'mw'],
    "asaṃgata": ['ap90', 'mw'],
    "asaṃgataprabha": ['mw'],
    "asaṃgati": ['mw'],
    "asaṃgatiḥ": ['ap90'],
    "asaṃghaṭṭa": ['mw'],
    "asaṃgin": ['ap90'],
    "asaṃgraha": ['mw'],
    "asaṃgrāha": ['bhs', 'mw'],
    "asaṃgītakam": ['cae', 'mw'],
    "asaṃhata": ['ap90', 'mw'],
    "asaṃhatavihārin": ['mw'],
    "asaṃhita": ['mw'],
    "asaṃhārya": ['mw'],
    "asaṃjvara": ['cae', 'mw'],
    "asaṃjña": ['ap90', 'cae', 'mw'],
    "asaṃjñapta": ['mw'],
    "asaṃjñatva": ['mw'],
    "asaṃjñika": ['bhs', 'mw'],
    "asaṃjñikasattva": ['mw'],
    "asaṃjñin": ['bhs'],
    "asaṃjñisamāpatti": ['bhs'],
    "asaṃjñisattva": ['bhs', 'mw'],
    "asaṃjñā": ['cae', 'mw'],
    "asaṃjñāna": ['mw'],
    "asaṃjñāsamāpatti": ['bhs'],
    "asaṃkalpa": ['mw'],
    "asaṃkalpanīya": ['mw'],
    "asaṃkalpayat": ['mw'],
    "asaṃkalpita": ['mw'],
    "asaṃkara": ['mw'],
    "asaṃkasuka": ['ap90', 'cae', 'mw'],
    "asaṃkathya": ['bhs'],
    "asaṃketita": ['mw'],
    "asaṃketitatva": ['mw'],
    "asaṃkhya": ['ap90', 'bhs', 'cae', 'mw'],
    "asaṃkhyaka": ['mw'],
    "asaṃkhyaya": ['bhs'],
    "asaṃkhyaśas": ['mw'],
    "asaṃkhyeya": ['ap90', 'bhs', 'cae', 'mw'],
    "asaṃkhyeyaguṇa": ['mw'],
    "asaṃkhyeyaparivarta": ['bhs'],
    "asaṃkhyeyatā": ['mw'],
    "asaṃkhyāta": ['ap90', 'cae', 'mw'],
    "asaṃkliṣṭa": ['bhs'],
    "asaṃkrānta": ['mw'],
    "asaṃkrāntimāsa": ['mw'],
    "asaṃkrāntitā": ['bhs'],
    "asaṃkrāṃta": ['ap90'],
    "asaṃkula": ['ap90', 'mw'],
    "asaṃkīrṇa": ['bhs', 'mw'],
    "asaṃkḷpta": ['mw'],
    "asaṃkṣipta": ['cae'],
    "asaṃlakṣya": ['mw'],
    "asaṃlulitakeśatā": ['mw'],
    "asaṃmata": ['ap90', 'cae', 'mw'],
    "asaṃmati": ['mw'],
    "asaṃmatiḥ": ['ap90'],
    "asaṃmatādāyin": ['mw'],
    "asaṃmita": ['ap90', 'mw'],
    "asaṃmoha": ['cae', 'mw'],
    "asaṃmohaḥ": ['ap90'],
    "asaṃmoṣa": ['bhs', 'mw'],
    "asaṃmoṣaṇatā": ['bhs'],
    "asaṃmugdha": ['mw'],
    "asaṃmukha": ['mw'],
    "asaṃmāna": ['mw'],
    "asaṃmānaḥ": ['ap90'],
    "asaṃmūḍha": ['ap90', 'cae', 'mw'],
    "asaṃmṛṣṭa": ['ap90', 'mw'],
    "asaṃnaddha": ['ap90', 'mw'],
    "asaṃnidhi": ['mw'],
    "asaṃnidhiḥ": ['ap90'],
    "asaṃnidhāna": ['cae', 'mw'],
    "asaṃnihita": ['ap90', 'cae'],
    "asaṃnikarṣa": ['mw'],
    "asaṃnikarṣaḥ": ['ap90'],
    "asaṃnikṛṣṭa": ['ap90', 'mw'],
    "asaṃnipātin": ['mw'],
    "asaṃnivṛtti": ['cae'],
    "asaṃnivṛttiḥ": ['ap90'],
    "asaṃnyasta": ['cae'],
    "asaṃnyupta": ['mw'],
    "asaṃpanna": ['mw'],
    "asaṃparka": ['mw'],
    "asaṃpatti": ['ap90', 'cae', 'mw'],
    "asaṃprabhīta": ['bhs'],
    "asaṃpradatta": ['mw'],
    "asaṃprajanya": ['bhs'],
    "asaṃprajñāna": ['bhs'],
    "asaṃprajñāta": ['ap90'],
    "asaṃprakampin": ['bhs'],
    "asaṃprakhyāna": ['bhs'],
    "asaṃpramoṣa": ['bhs', 'mw'],
    "asaṃpramoṣaṇa": ['bhs'],
    "asaṃpramuṣita": ['bhs'],
    "asaṃpramāda": ['mw'],
    "asaṃprati": ['mw'],
    "asaṃpratta": ['mw'],
    "asaṃpravaṇatā": ['bhs'],
    "asaṃpravedhana": ['bhs'],
    "asaṃpravedhin": ['bhs'],
    "asaṃprāpta": ['cae', 'mw'],
    "asaṃprāpya": ['mw'],
    "asaṃpāta": ['mw'],
    "asaṃpāṭhya": ['cae', 'mw'],
    "asaṃpūrṇa": ['ap90', 'cae', 'mw'],
    "asaṃpūrṇamanoratha": ['cae'],
    "asaṃpṛñcāna": ['mw'],
    "asaṃrodha": ['mw'],
    "asaṃrodhena": ['mw'],
    "asaṃroha": ['mw'],
    "asaṃsakta": ['mw'],
    "asaṃsaktam": ['mw'],
    "asaṃsarga": ['ddsa'],
    "asaṃskāra": ['cae', 'ddsa', 'mw'],
    "asaṃskārya": ['cae', 'mw'],
    "asaṃskṛta": ['ap90', 'bhs', 'cae', 'mw'],
    "asaṃskṛtālakin": ['mw'],
    "asaṃstava": ['mw'],
    "asaṃsthita": ['ap90', 'cae', 'mw'],
    "asaṃsthitiḥ": ['ap90'],
    "asaṃsthāna": ['mw'],
    "asaṃsthānaṃ": ['ap90'],
    "asaṃstuta": ['ap90', 'cae', 'mw'],
    "asaṃsvādam": ['mw'],
    "asaṃsārin": ['cae'],
    "asaṃsūktagila": ['mw'],
    "asaṃsṛti": ['mw'],
    "asaṃsṛtiḥ": ['ap90'],
    "asaṃsṛṣṭa": ['ap90', 'cae', 'mw'],
    "asaṃsṛṣṭi": ['mw'],
    "asaṃtata": ['mw'],
    "asaṃtati": ['ap90'],
    "asaṃtoṣa": ['cae', 'mw'],
    "asaṃtoṣavat": ['mw'],
    "asaṃtuṣṭa": ['cae', 'mw'],
    "asaṃtyāga": ['mw'],
    "asaṃtyāgin": ['mw'],
    "asaṃtyājya": ['mw'],
    "asaṃtāna": ['ap90'],
    "asaṃtāpa": ['mw'],
    "asaṃvara": ['bhs', 'mw'],
    "asaṃvaraṇa": ['bhs'],
    "asaṃvasant": ['cae'],
    "asaṃvatsara": ['mw'],
    "asaṃvatsarabhṛta": ['mw'],
    "asaṃvatsarabhṛtin": ['mw'],
    "asaṃvatsaravāsin": ['mw'],
    "asaṃvida": ['mw'],
    "asaṃvidita": ['bhs'],
    "asaṃvidāna": ['ap90', 'mw'],
    "asaṃvijñāna": ['mw'],
    "asaṃvijñāta": ['mw'],
    "asaṃvivāda": ['bhs'],
    "asaṃvlaya": ['mw'],
    "asaṃvyavahita": ['ap90'],
    "asaṃvyavahitam": ['mw'],
    "asaṃvyavahārya": ['mw'],
    "asaṃvyāhārin": ['mw'],
    "asaṃvyātha": ['mw'],
    "asaṃvārya": ['mw'],
    "asaṃvāsika": ['bhs'],
    "asaṃvāsya": ['bhs'],
    "asaṃvīta": ['cae'],
    "asaṃvṛta": ['ap90', 'bhs', 'cae', 'mw'],
    "asaṃvṛttavidheya": ['mw'],
    "asaṃvṛtti": ['mw'],
    "asaṃyama": ['ddsa', 'mw'],
    "asaṃyamaḥ": ['ap90'],
    "asaṃyat": ['mw'],
    "asaṃyata": ['ap90', 'cae', 'mw'],
    "asaṃyatta": ['gra', 'mw'],
    "asaṃyatātman": ['cae', 'mw'],
    "asaṃyoga": ['mw'],
    "asaṃyogopadha": ['mw'],
    "asaṃyukta": ['ap90', 'mw'],
    "asaṃyuta": ['ap90', 'mw'],
    "asaṃyājya": ['cae', 'mw'],
    "asaṃśabdya": ['mw'],
    "asaṃśaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "asaṃśayam": ['mw'],
    "asaṃśleṣa": ['mw'],
    "asaṃśliṣṭa": ['ap90', 'mw'],
    "asaṃśrava": ['ap90', 'mw'],
    "asaṃśravaṇe": ['cae', 'mw'],
    "asaṃśrave": ['cae'],
    "asaṃśrāvam": ['mw'],
    "asaṅga": ['bhs', 'cae', 'ddsa', 'mw'],
    "asaṅgabaladhārin": ['bhs'],
    "asaṅgabalavīryamati": ['bhs'],
    "asaṅgabuddhi": ['bhs'],
    "asaṅgacitta": ['bhs'],
    "asaṅgacārin": ['mw'],
    "asaṅgadhvaja": ['bhs'],
    "asaṅgadhāraṇī": ['bhs'],
    "asaṅgahaka": ['cped'],
    "asaṅgajñānaketudhvaja": ['bhs'],
    "asaṅgakāyaraśmitejomati": ['bhs'],
    "asaṅgamati": ['bhs'],
    "asaṅgamaticandra": ['bhs'],
    "asaṅgamukha": ['bhs'],
    "asaṅgamukhapraveśā": ['bhs'],
    "asaṅganetra": ['bhs'],
    "asaṅgapratibhāna": ['bhs'],
    "asaṅgasvara": ['bhs'],
    "asaṅgata": ['ddsa'],
    "asaṅgavat": ['mw'],
    "asaṅgavyūha": ['bhs'],
    "asaṅgaśrīgarbharāja": ['bhs'],
    "asaṅgena": ['mw'],
    "asaṅgin": ['mw'],
    "asaṅgisattva": ['mw'],
    "asaṅgitva": ['mw'],
    "asaṅgottarajñānin": ['bhs'],
    "asaṅgāt": ['mw'],
    "asaṅkara": ['ddsa'],
    "asaṅkhya": ['ddsa'],
    "asaṅkṣipta": ['ddsa'],
    "asecana": ['ap90', 'bhs', 'mw'],
    "asecanaka": ['bhs', 'cped', 'mw'],
    "asecanakadarśana": ['mw'],
    "asecanīya": ['bhs', 'mw'],
    "asenia": ['gra'],
    "asenya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asenāsanaka": ['cped'],
    "asenāsanika": ['cped'],
    "asevaka": ['ddsa'],
    "asevana": ['ap90', 'cae'],
    "asevita": ['ap90', 'mw'],
    "aseviteśvaradvāra": ['mw'],
    "asevya": ['mw'],
    "asevā": ['cae', 'ddsa', 'mw'],
    "asi": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "asibaddha": ['mw'],
    "asicamma": ['cped'],
    "asicaryā": ['mw'],
    "asiccheda": ['bhs'],
    "asidaṃṣṭra": ['mw'],
    "asidaṃṣṭraka": ['mw'],
    "asiddha": ['ap90', 'ddsa', 'mw'],
    "asiddhi": ['ddsa', 'mw'],
    "asiddhida": ['mw'],
    "asiddhiḥ": ['ap90'],
    "asiddhānta": ['mw'],
    "asiddhārtha": ['mw'],
    "asidhara": ['ddsa', 'mw'],
    "asidharā": ['bhs'],
    "asidhenu": ['mw'],
    "asidhenukā": ['mw'],
    "asidhārā": ['cae', 'ddsa', 'mw'],
    "asidhārāpatha": ['mw'],
    "asidhārāvrata": ['cae', 'mw'],
    "asidhāva": ['mw'],
    "asidhāvaka": ['mw'],
    "asigaṇḍa": ['mw'],
    "asihatya": ['mw'],
    "asiheti": ['mw'],
    "asijala": ['mw'],
    "asijihva": ['mw'],
    "asika": ['mw'],
    "asikaṃ": ['ap90'],
    "asiknikā": ['ap90', 'mw'],
    "asiknī": ['ap90', 'ddsa', 'mw'],
    "asikta": ['ddsa'],
    "asilatā": ['cae', 'mw'],
    "asiloma": ['cped'],
    "asiloman": ['mw'],
    "asimat": ['mw'],
    "asimeda": ['mw'],
    "asimuśaladharā": ['bhs'],
    "asimārga": ['mw'],
    "asinva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asinvant": ['cae'],
    "asinvat": ['gra', 'mw'],
    "asipatha": ['mw'],
    "asipattavana": ['cped'],
    "asipattra": ['bhs', 'cae', 'mw'],
    "asipattraka": ['mw'],
    "asipattravana": ['cae', 'mw'],
    "asipattravrata": ['cae', 'mw'],
    "asipattravṛkṣa": ['mw'],
    "asipat‍tra": ['ddsa'],
    "asiplava": ['mw'],
    "asipucchaka": ['mw'],
    "asiputrikā": ['mw'],
    "asiputrī": ['mw'],
    "asipāṇi": ['mw'],
    "asira": ['gra', 'mw'],
    "asiraḥ": ['ap90'],
    "asissaṁ": ['cped'],
    "asissāmi": ['cped'],
    "asisūnā": ['cped', 'mw'],
    "asita": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "asitabhrū": ['mw'],
    "asitabhānu": ['bhs'],
    "asitadruma": ['mw'],
    "asitagati": ['mw'],
    "asitagrīva": ['mw'],
    "asitajñu": ['mw'],
    "asitajānu": ['mw'],
    "asitakeśānta": ['mw'],
    "asitamuṣkaka": ['mw'],
    "asitamṛga": ['mw'],
    "asitanayana": ['mw'],
    "asitapucchaka": ['mw'],
    "asitapītaka": ['cae'],
    "asitaratna": ['mw'],
    "asitaskandha": ['mw'],
    "asitatiga": ['cped'],
    "asitavartman": ['mw'],
    "asitavarṇa": ['mw'],
    "asitavyābhaṅgī": ['cped'],
    "asitekṣaṇa": ['cae', 'mw'],
    "asitoda": ['mw'],
    "asitopala": ['mw'],
    "asitotpala": ['cae', 'mw'],
    "asitā": ['mw'],
    "asitābhraśekhara": ['mw'],
    "asitākṣa": ['mw'],
    "asitāla": ['mw'],
    "asitālu": ['mw'],
    "asitāmburuha": ['mw'],
    "asitānana": ['mw'],
    "asitārcis": ['mw'],
    "asitāśman": ['mw'],
    "asitāṅga": ['mw'],
    "asiyaṣṭi": ['mw'],
    "asiśimbī": ['mw'],
    "asiḥ": ['ap90'],
    "asiṃhāsana": ['cae', 'ddsa'],
    "asiṣṭha": ['mw'],
    "askambhana": ['gra', 'mw'],
    "askanda": ['cae', 'mw'],
    "askandatva": ['mw'],
    "askandayant": ['cae'],
    "askandayat": ['mw'],
    "askandin": ['mw'],
    "askandita": ['mw'],
    "askanna": ['ap90', 'cae', 'ddsa', 'mw'],
    "askannatva": ['mw'],
    "askaṃdita": ['ap90'],
    "askhala": ['mw'],
    "askhalana": ['cae'],
    "askhalita": ['ap90', 'cae', 'ddsa', 'mw'],
    "askhalitacakra": ['cae'],
    "askhalitapada": ['cae'],
    "askhalitapravarāgra": ['bhs'],
    "askhalitaprayāṇa": ['mw'],
    "askṛdhoyu": ['ap90', 'cae', 'gra', 'mw'],
    "asma": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "asmad": ['ap90', 'cae', 'mw'],
    "asmadarthe": ['ddsa'],
    "asmaddevatya": ['mw'],
    "asmadriac": ['gra'],
    "asmadruh": ['gra', 'mw'],
    "asmadryac": ['ddsa', 'gra'],
    "asmadryak": ['mw'],
    "asmadryañc": ['cae', 'mw'],
    "asmadryaṃc": ['ap90'],
    "asmadrāta": ['mw'],
    "asmadvat": ['ddsa', 'mw'],
    "asmadvidha": ['cae', 'mw'],
    "asmadīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "asman": ['cped'],
    "asmarat": ['mw'],
    "asmaraṇa": ['mw'],
    "asmaraṇaṃ": ['ap90'],
    "asmartavya": ['mw'],
    "asmat": ['mw'],
    "asmatkūlīna": ['ddsa'],
    "asmatpreṣita": ['mw'],
    "asmatrā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asmatrāc": ['gra'],
    "asmatrāñc": ['mw'],
    "asmatsakhi": ['gra', 'mw'],
    "asmattas": ['cae', 'ddsa'],
    "asmaya": ['mw'],
    "asmayu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asmaṃtaṃ": ['ap90'],
    "asme": ['ddsa'],
    "asmehiti": ['cae', 'ddsa', 'gra', 'mw'],
    "asmera": ['ap90', 'gra', 'mw'],
    "asmi": ['ap90', 'mw'],
    "asmimāna": ['bhs', 'cped', 'mw'],
    "asmisaṃjñā": ['bhs'],
    "asmitā": ['ap90', 'mw'],
    "asmādṛśa": ['cae', 'ddsa', 'mw'],
    "asmāka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asmākīna": ['bhs'],
    "asmārta": ['ap90', 'mw'],
    "asmṛta": ['mw'],
    "asmṛtadhru": ['gra', 'mw'],
    "asmṛti": ['cae', 'ddsa', 'mw'],
    "asmṛtiḥ": ['ap90'],
    "asneha": ['ap90', 'mw'],
    "asnehana": ['mw'],
    "asnehavat": ['mw'],
    "asnehya": ['mw'],
    "asnigdha": ['ap90', 'mw'],
    "asnigdhadāruka": ['mw'],
    "asnāna": ['mw'],
    "asnāta": ['mw'],
    "asnāti": ['cped'],
    "asnātṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "asnāvaka": ['mw'],
    "asnāvira": ['ap90', 'mw'],
    "asnāyin": ['mw'],
    "asoma": ['cae', 'ddsa', 'mw'],
    "asomapa": ['cae', 'mw'],
    "asomapītha": ['mw'],
    "asomapīthin": ['mw'],
    "asomayājin": ['mw'],
    "asoḍha": ['cae', 'ddsa', 'mw'],
    "aspanda": ['mw'],
    "aspandamāna": ['mw'],
    "aspandana": ['mw'],
    "aspandanasthiti": ['mw'],
    "aspandayat": ['mw'],
    "aspandāsu": ['mw'],
    "asparśa": ['ap90', 'cae', 'mw'],
    "asparśana": ['ddsa', 'mw'],
    "asparśanaṃ": ['ap90'],
    "asparśapara": ['mw'],
    "asparśavihāra": ['bhs'],
    "aspaṃda": ['ap90'],
    "aspaṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aspaṣṭakīrti": ['mw'],
    "aspharaṇīya": ['bhs'],
    "asphuṭa": ['ap90', 'cae', 'mw'],
    "asphuṭabhāṣaṇa": ['mw'],
    "asphuṭaphala": ['mw'],
    "asphuṭālaṃkāra": ['mw'],
    "aspraṣṭṛ": ['mw'],
    "aspṛha": ['cae', 'mw'],
    "aspṛhatva": ['mw'],
    "aspṛhaṇīya": ['mw'],
    "aspṛhā": ['cae', 'ddsa', 'mw'],
    "aspṛta": ['ap90', 'gra', 'mw'],
    "aspṛśant": ['cae'],
    "aspṛśat": ['ddsa', 'mw'],
    "aspṛśya": ['ap90', 'ddsa', 'mw'],
    "aspṛśyatva": ['mw'],
    "aspṛṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aspṛṣṭamaithunā": ['mw'],
    "aspṛṣṭapuruṣāntara": ['mw'],
    "aspṛṣṭarajastamaska": ['mw'],
    "aspṛṣṭi": ['mw'],
    "aspṛṣṭiḥ": ['ap90'],
    "asra": ['cae', 'ddsa', 'mw'],
    "asrabinducchadā": ['mw'],
    "asraja": ['mw'],
    "asrajanman": ['mw'],
    "asrakhadira": ['mw'],
    "asramukha": ['cae'],
    "asramātṛ": ['mw'],
    "asramātṛkā": ['mw'],
    "asrapa": ['mw'],
    "asrapattraka": ['mw'],
    "asraphalā": ['mw'],
    "asrapitta": ['mw'],
    "asrapā": ['mw'],
    "asrarodhinī": ['mw'],
    "asravat": ['gra', 'mw'],
    "asraḥ": ['ap90'],
    "asredhant": ['cae'],
    "asredhat": ['gra', 'mw'],
    "asreman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asridh": ['ap90', 'cae', 'gra', 'mw'],
    "asridhāna": ['cae', 'gra', 'mw'],
    "asridm, asridhāna": ['ddsa'],
    "asrin": ['mw'],
    "asriḥ": ['ap90'],
    "asrottaram": ['ddsa'],
    "asru": ['ap90'],
    "asruta": ['mw'],
    "asruva": ['mw'],
    "asrāma": ['mw'],
    "asrārjaka": ['mw'],
    "asrāya": ['mw'],
    "asrāyamāṇaka": ['mw'],
    "asrāyate": ['ap90'],
    "asrīvayas": ['mw'],
    "asrīvi": ['mw'],
    "asrīvī": ['mw'],
    "assa": ['cped'],
    "assadamaka": ['cped'],
    "assaddhiya": ['cped'],
    "assadūta": ['cped'],
    "assaka": ['cped'],
    "assakhaluṅka": ['cped'],
    "assakāya": ['cped'],
    "assama": ['cped'],
    "assamaṇḍalikā": ['cped'],
    "assamedha": ['cped'],
    "assamiya": ['cped'],
    "assapaṇīya": ['cped'],
    "assapiṭṭha": ['cped'],
    "assapiṭṭhi": ['cped'],
    "assapuṭa": ['cped'],
    "assaratana": ['cped'],
    "assasadassa": ['cped'],
    "assasammadda": ['cped'],
    "assasanta": ['cped'],
    "assasati": ['cped'],
    "assasi": ['cped'],
    "assasitvā": ['cped'],
    "assatara": ['cped'],
    "assatarī": ['cped'],
    "assatha": ['cped'],
    "assattha": ['cped'],
    "assatthara": ['cped'],
    "assava": ['cped'],
    "assavati": ['cped'],
    "assaṁ": ['cped'],
    "assita": ['cped'],
    "assu": ['cped'],
    "assudaṁ": ['cped'],
    "assuka": ['cped'],
    "assumukha": ['cped'],
    "assāda": ['cped'],
    "assādana": ['cped'],
    "assādayati": ['cped'],
    "assādeti": ['cped'],
    "assādiyati": ['cped'],
    "assājāneyya": ['cped'],
    "assājānīya": ['cped'],
    "assāma": ['cped'],
    "assāroha": ['cped'],
    "assārūha": ['cped'],
    "assāsa": ['cped'],
    "assāsaka": ['cped'],
    "assāsaniya": ['cped'],
    "assāsapassāsa": ['cped'],
    "assāsapatta": ['cped'],
    "assāsappatta": ['cped'],
    "assāsati": ['cped'],
    "assāsenta": ['cped'],
    "assāsetabba": ['cped'],
    "assāsetvā": ['cped'],
    "assāva": ['cped'],
    "assāvi": ['cped'],
    "assāvin": ['cped'],
    "asta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "astabdha": ['ap90', 'ddsa', 'mw'],
    "astabdhatva": ['mw'],
    "astabdhatā": ['mw'],
    "astabhavana": ['mw'],
    "astadhī": ['mw'],
    "astagamana": ['mw'],
    "astagiri": ['ddsa', 'mw'],
    "astagāmin": ['mw'],
    "astaka": ['mw'],
    "astakaruṇa": ['cae', 'mw'],
    "astakaḥ": ['ap90'],
    "astakopa": ['mw'],
    "astakṣitibhṛt": ['mw'],
    "astalagna": ['mw'],
    "astam": ['mw'],
    "astamana": ['mw'],
    "astamanaṃ": ['ap90'],
    "astamastaka": ['mw'],
    "astamaya": ['cae', 'ddsa', 'mw'],
    "astamayana": ['mw'],
    "astamayaḥ": ['ap90'],
    "astamayācala": ['mw'],
    "astambha": ['ddsa', 'mw'],
    "astambhin": ['bhs'],
    "astameṣyat": ['mw'],
    "astamike": ['ap90'],
    "astamita": ['cae', 'mw'],
    "astamite": ['mw'],
    "astamitoditā": ['mw'],
    "astamīke": ['gra', 'mw'],
    "astamūrdhan": ['mw'],
    "astanimagna": ['mw'],
    "astanā": ['mw'],
    "astarkṣaṇaṃ": ['ap90'],
    "astarya": ['mw'],
    "astarāśi": ['mw'],
    "astasamaya": ['ddsa', 'mw'],
    "astasaṃkhya": ['mw'],
    "astatandri": ['mw'],
    "astatāti": ['gra', 'mw'],
    "astatātiḥ": ['ap90'],
    "astavyasta": ['mw'],
    "astaśikhara": ['mw'],
    "astaḥ": ['ap90'],
    "astaṃgacchat": ['mw'],
    "astaṃgama": ['bhs'],
    "astaṃgamita": ['mw'],
    "astaṃyant": ['cae'],
    "astaṃyat": ['ddsa', 'mw'],
    "astaṃyāt": ['mw'],
    "astaṅgata": ['ddsa'],
    "astena": ['cae', 'mw'],
    "astenamānin": ['cae', 'mw'],
    "asteya": ['cae', 'ddsa', 'mw'],
    "asteyaṃ": ['ap90'],
    "astha": ['gra', 'mw'],
    "asthairya": ['ap90', 'mw'],
    "asthan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asthanvat": ['ap90', 'gra', 'mw'],
    "astheyas": ['gra', 'mw'],
    "asthi": ['ap90', 'cae', 'ddsa', 'mw'],
    "asthibandhana": ['mw'],
    "asthibhakṣa": ['mw'],
    "asthibhaṅga": ['mw'],
    "asthibheda": ['bhs', 'mw'],
    "asthibhedaka": ['cae'],
    "asthibhuj": ['mw'],
    "asthibhūyas": ['mw'],
    "asthicchallita": ['mw'],
    "asthicit": ['mw'],
    "asthicūrṇa": ['cae'],
    "asthidantamaya": ['ddsa', 'mw'],
    "asthidhanvan": ['mw'],
    "asthija": ['cae', 'mw'],
    "asthika": ['mw'],
    "asthikara": ['mw'],
    "asthiketu": ['mw'],
    "asthikhāda": ['mw'],
    "asthikumbha": ['mw'],
    "asthikuṇḍa": ['mw'],
    "asthikṛt": ['mw'],
    "asthimat": ['mw'],
    "asthimaya": ['mw'],
    "asthimālin": ['mw'],
    "asthimālā": ['mw'],
    "asthipañjara": ['cae', 'mw'],
    "asthira": ['ap90', 'cae', 'ddsa', 'mw'],
    "asthiratva": ['mw'],
    "asthirībhū": ['mw'],
    "asthisamarpaṇa": ['mw'],
    "asthisambhava": ['mw'],
    "asthisandhi": ['mw'],
    "asthisaṃcaya": ['mw'],
    "asthisaṃcayana": ['mw'],
    "asthisaṃghāta": ['bhs', 'mw'],
    "asthisaṃhāra": ['mw'],
    "asthisaṃhāraka": ['mw'],
    "asthisaṃhārī": ['mw'],
    "asthisaṃjñā": ['bhs'],
    "asthisaṃnahana": ['mw'],
    "asthisaṃstha": ['cae'],
    "asthisaṃyoga": ['mw'],
    "asthisena": ['bhs'],
    "asthisenasyajātakaṃ": ['bhs'],
    "asthisneha": ['cae', 'mw'],
    "asthisnehaka": ['mw'],
    "asthisraṃsa": ['mw'],
    "asthisthūṇa": ['cae', 'mw'],
    "asthisāra": ['mw'],
    "asthita": ['ap90', 'ddsa', 'mw'],
    "asthitejas": ['mw'],
    "asthiti": ['ap90', 'ddsa', 'mw'],
    "asthitoda": ['mw'],
    "asthituṇḍa": ['mw'],
    "asthitvac": ['mw'],
    "asthivilaya": ['mw'],
    "asthivilayatīrtha": ['mw'],
    "asthiyajña": ['mw'],
    "asthiyantra": ['bhs'],
    "asthiyantravat": ['mw'],
    "asthiyuj": ['mw'],
    "asthiśakalā": ['bhs'],
    "asthiśeṣa": ['ddsa', 'mw'],
    "asthiśeṣatā": ['mw'],
    "asthiśuddhi": ['mw'],
    "asthiśṛṅkhalā": ['mw'],
    "asthyuddharaṇa": ['mw'],
    "asthā": ['ap90', 'cae', 'gra', 'mw'],
    "asthāga": ['ap90'],
    "asthāgha": ['mw'],
    "asthāna": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "asthānasthapada": ['mw'],
    "asthānasthasamāsa": ['mw'],
    "asthānatā": ['bhs'],
    "asthānayukta": ['mw'],
    "asthāne": ['ap90', 'mw'],
    "asthānin": ['mw'],
    "asthāsnu": ['ddsa', 'mw'],
    "asthāvara": ['ap90', 'mw'],
    "asthāyin": ['ap90', 'mw'],
    "asthāyitva": ['mw'],
    "asthīkṛtya": ['bhs'],
    "asthūla": ['cae', 'ddsa', 'mw'],
    "asthūri": ['gra', 'mw'],
    "asthūriḥ": ['ap90'],
    "asti": ['ap90', 'bhs', 'gra', 'mw'],
    "astikaḥ": ['ap90'],
    "astikāya": ['mw'],
    "astikṣīrā": ['mw'],
    "astimat": ['ap90', 'mw'],
    "astināsti": ['mw'],
    "astināstitva": ['mw'],
    "astipravāda": ['mw'],
    "astitva": ['mw'],
    "astitvaṃ": ['ap90'],
    "astitā": ['mw'],
    "astobha": ['mw'],
    "astoka": ['cae', 'mw'],
    "astopaka": ['bhs'],
    "astotṛ": ['cae', 'mw'],
    "astra": ['cae', 'ddsa', 'gra', 'mw'],
    "astrabandha": ['mw'],
    "astrabhṛt": ['mw'],
    "astracikitsaka": ['mw'],
    "astracikitsā": ['mw'],
    "astradhāraṇa": ['mw'],
    "astradhārin": ['mw'],
    "astragrāma": ['cae', 'mw'],
    "astrahīna": ['mw'],
    "astraiṇa": ['ap90', 'mw'],
    "astrajit": ['mw'],
    "astrajīva": ['mw'],
    "astrajīvana": ['mw'],
    "astrakaṇṭaka": ['mw'],
    "astrakāra": ['mw'],
    "astrakāraka": ['mw'],
    "astrakārin": ['mw'],
    "astrakṣatimat": ['mw'],
    "astrakṣepaka": ['mw'],
    "astramantra": ['mw'],
    "astramārja": ['mw'],
    "astranivāraṇa": ['mw'],
    "astrasāyaka": ['mw'],
    "astraveda": ['mw'],
    "astravid": ['mw'],
    "astravidyā": ['mw'],
    "astravṛṣṭi": ['mw'],
    "astraśastra": ['mw'],
    "astraśikṣā": ['mw'],
    "astraṃ": ['ap90'],
    "astrin": ['ap90', 'ddsa', 'mw'],
    "astropaniṣad": ['ddsa', 'mw'],
    "astryupāyin": ['mw'],
    "astrāghāta": ['mw'],
    "astrāgāra": ['mw'],
    "astrāhata": ['mw'],
    "astrāya": ['mw'],
    "astrī": ['ap90', 'cae', 'ddsa', 'mw'],
    "astrījita": ['mw'],
    "astrīka": ['ap90', 'mw'],
    "astrīsambhogin": ['mw'],
    "astu": ['ap90', 'mw'],
    "astuta": ['ddsa', 'gra', 'mw'],
    "astuti": ['mw'],
    "astutya": ['ddsa', 'mw'],
    "astuvid": ['ddsa', 'mw'],
    "astuṃkāra": ['ap90', 'mw'],
    "astya": ['mw'],
    "astyāna": ['mw'],
    "astyānaṃ": ['ap90'],
    "astā": ['cae', 'ddsa', 'mw'],
    "astābhilāṣin": ['ddsa', 'mw'],
    "astācala": ['ddsa', 'mw'],
    "astādri": ['mw'],
    "astāgha": ['ap90', 'mw'],
    "astāvalambin": ['mw'],
    "astīka": ['mw'],
    "astṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "astṛta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "astṛtayajvan": ['gra', 'mw'],
    "astṛti": ['mw'],
    "asu": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "asubhaṅga": ['mw'],
    "asubhṛt": ['mw'],
    "asubodha": ['ddsa'],
    "asucīka": ['cped'],
    "asucīkamissita": ['cped'],
    "asudhāraṇa": ['mw'],
    "asugama": ['mw'],
    "asugandha": ['mw'],
    "asuhṛd": ['ap90', 'cae', 'mw'],
    "asuhṛda": ['ddsa'],
    "asuhṛdgaṇa": ['ddsa'],
    "asuka": ['cped'],
    "asukara": ['mw'],
    "asukas": ['mw'],
    "asukha": ['ap90', 'cae', 'ddsa', 'mw'],
    "asukhapīḍita": ['mw'],
    "asukhasaṃcāra": ['mw'],
    "asukhin": ['ap90', 'ddsa', 'mw'],
    "asukhodarka": ['cae', 'mw'],
    "asukhodaya": ['cae', 'mw'],
    "asukhāvaha": ['mw'],
    "asukhāviṣṭa": ['mw'],
    "asukhāya": ['mw'],
    "asulabha": ['ap90', 'cae', 'ddsa', 'mw'],
    "asumat": ['ap90', 'mw'],
    "asumna": ['ap90', 'mw'],
    "asundara": ['ddsa', 'mw'],
    "asunva": ['ap90', 'gra', 'mw'],
    "asunvat": ['gra', 'mw'],
    "asunīta": ['mw'],
    "asunīti": ['ddsa', 'gra', 'mw'],
    "asupratāra": ['mw'],
    "asupta": ['ap90', 'mw'],
    "asuptadṛś": ['mw'],
    "asura": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "asurabhi": ['ddsa'],
    "asurabrahma": ['cae', 'mw'],
    "asuradeva": ['bhs'],
    "asuradharma": ['cae'],
    "asuradruh": ['ddsa', 'mw'],
    "asuradviṣ": ['mw'],
    "asuraguru": ['mw'],
    "asurahan": ['cae', 'gra', 'mw'],
    "asurakumāra": ['mw'],
    "asurakā": ['bhs'],
    "asurakāya": ['cped'],
    "asurakṣa": ['ddsa', 'mw'],
    "asurakṣayaṇa": ['mw'],
    "asurakṣiti": ['mw'],
    "asuralipi": ['bhs'],
    "asuraloka": ['mw'],
    "asuramāyā": ['mw'],
    "asuranemin": ['bhs'],
    "asuraprāmbhāra": ['bhs'],
    "asurarakṣasa": ['cae', 'ddsa', 'mw'],
    "asuraripu": ['mw'],
    "asurarāj": ['mw'],
    "asurasā": ['ap90', 'mw'],
    "asurasūdana": ['mw'],
    "asuratamasa": ['mw'],
    "asuratva": ['gra', 'mw'],
    "asuratvaṃ": ['ap90'],
    "asuraviśa": ['mw'],
    "asurayoni": ['mw'],
    "asurejya": ['mw'],
    "asurendra": ['mw'],
    "asurendrā": ['bhs'],
    "asuri": ['mw'],
    "asurinda": ['cped'],
    "asurya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asurā": ['mw'],
    "asurācārya": ['mw'],
    "asurādhipa": ['mw'],
    "asurāhva": ['mw'],
    "asurārdana": ['mw'],
    "asurāri": ['mw'],
    "asurī": ['mw'],
    "asurīa": ['gra'],
    "asusama": ['mw'],
    "asusamāpta": ['mw'],
    "asustha": ['ap90', 'cae', 'ddsa', 'mw'],
    "asusthatā": ['mw'],
    "asusthirādara": ['ddsa', 'mw'],
    "asusthita": ['cae'],
    "asusū": ['ddsa', 'mw'],
    "asusūḥ": ['ap90'],
    "asuta": ['ap90', 'gra', 'mw'],
    "asutara": ['ddsa', 'mw'],
    "asutyāga": ['mw'],
    "asutṛp": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asutṛpa": ['mw'],
    "asuvargya": ['mw'],
    "asuvarṇa": ['cae'],
    "asuvilāsa": ['mw'],
    "asuvyaya": ['mw'],
    "asuḥ": ['ap90'],
    "asuṃbhara": ['mw'],
    "asuṣira": ['mw'],
    "asuṣiratva": ['mw'],
    "asuṣupta": ['mw'],
    "asuṣvi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asva": ['ap90', 'ddsa', 'mw'],
    "asvabhāva": ['ap90', 'mw'],
    "asvacchanda": ['mw'],
    "asvacchaṃda": ['ap90'],
    "asvadharma": ['ddsa', 'mw'],
    "asvadita": ['cae', 'ddsa', 'mw'],
    "asvadṛś": ['mw'],
    "asvaga": ['mw'],
    "asvagatā": ['ddsa', 'mw'],
    "asvajāti": ['mw'],
    "asvaka": ['ap90', 'mw'],
    "asvana": ['mw'],
    "asvanta": ['mw'],
    "asvapat": ['mw'],
    "asvapna": ['ap90', 'mw'],
    "asvapnaj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asvara": ['ap90', 'mw'],
    "asvaraka": ['mw'],
    "asvaram": ['mw'],
    "asvargayogya": ['cae', 'ddsa'],
    "asvargya": ['ap90', 'cae', 'ddsa', 'mw'],
    "asvarita": ['cae', 'ddsa', 'mw'],
    "asvarya": ['mw'],
    "asvaryogya": ['mw'],
    "asvarādi": ['mw'],
    "asvarūpa": ['ap90', 'mw'],
    "asvastha": ['ap90', 'cae', 'ddsa', 'mw'],
    "asvasthacetasa": ['cae'],
    "asvasthatā": ['mw'],
    "asvasthaśarīra": ['cae', 'mw'],
    "asvasthāna": ['mw'],
    "asvatantra": ['cae', 'ddsa', 'mw'],
    "asvatantratā": ['mw'],
    "asvataṃtra": ['ap90'],
    "asvatva": ['mw'],
    "asvatvaṃ": ['ap90'],
    "asvatā": ['mw'],
    "asvaveśa": ['ap90', 'gra', 'mw'],
    "asvayaṅkṛta": ['ddsa'],
    "asvaṃta": ['ap90'],
    "asveda": ['ddsa', 'mw'],
    "asvedana": ['mw'],
    "asvedya": ['mw'],
    "asvinna": ['mw'],
    "asvādhyāya": ['mw'],
    "asvādhyāyapara": ['mw'],
    "asvādhyāyaḥ": ['ap90'],
    "asvādhīna": ['cae', 'ddsa', 'mw'],
    "asvādu": ['mw'],
    "asvāhākṛta": ['mw'],
    "asvāmika": ['ap90', 'ddsa', 'mw'],
    "asvāmin": ['ap90', 'cae', 'mw'],
    "asvāmivikraya": ['cae', 'mw'],
    "asvāmya": ['ap90'],
    "asvārtha": ['mw'],
    "asvāsthya": ['mw'],
    "asvāsthyaṃ": ['ap90'],
    "asvātantrya": ['cae', 'ddsa', 'mw'],
    "asvāṅgapūrvapada": ['mw'],
    "asvīkāra": ['mw'],
    "asvīkṛta": ['mw'],
    "asya": ['bhs'],
    "asyagra": ['mw'],
    "asyahatya": ['mw'],
    "asyaheti": ['mw'],
    "asyandamāna": ['gra', 'mw'],
    "asyasi": ['mw'],
    "asyavāmīya": ['ddsa', 'mw'],
    "asyavāmīyaṃ": ['ap90'],
    "asyudyata": ['ap90', 'mw'],
    "asyākṛti": ['mw'],
    "asyūtanāsika": ['mw'],
    "asāda": ['ap90', 'ddsa', 'mw'],
    "asādhaka": ['cae', 'ddsa'],
    "asādhana": ['ap90', 'cae', 'mw'],
    "asādhanīya": ['ap90'],
    "asādhu": ['ap90', 'cae', 'ddsa', 'mw'],
    "asādhudarśin": ['cae'],
    "asādhunā": ['mw'],
    "asādhutva": ['mw'],
    "asādhuvāda": ['mw'],
    "asādhuvṛtta": ['cae', 'mw'],
    "asādhya": ['cae', 'ddsa', 'mw'],
    "asādhyatva": ['mw'],
    "asādhyatā": ['mw'],
    "asādhāraṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "asādhāraṇopamā": ['cae', 'mw'],
    "asādiśa": ['bhs'],
    "asādṛśya": ['cae', 'ddsa'],
    "asāhacarya": ['mw'],
    "asāhasa": ['ddsa', 'mw'],
    "asāhasaṃ": ['ap90'],
    "asāhasika": ['mw'],
    "asāhāyya": ['mw'],
    "asākṣika": ['ap90', 'cae', 'ddsa', 'mw'],
    "asākṣikahata": ['mw'],
    "asākṣin": ['ap90', 'mw'],
    "asākṣitva": ['mw'],
    "asākṣya": ['mw'],
    "asākṣyaṃ": ['ap90'],
    "asākṣāt": ['ap90', 'mw'],
    "asālatiprakāśa": ['mw'],
    "asāman": ['mw'],
    "asāmanya": ['ddsa', 'mw'],
    "asāmarthya": ['mw'],
    "asāmayika": ['ap90', 'mw'],
    "asāmañjasya": ['mw'],
    "asāmi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asāmiśavas": ['cae', 'gra', 'mw'],
    "asāmnā": ['mw'],
    "asāmprata": ['ddsa'],
    "asāmya": ['mw'],
    "asāmyaṃ": ['ap90'],
    "asāmānya": ['ap90', 'cae', 'ddsa', 'mw'],
    "asānnidhya": ['ddsa'],
    "asānāthya": ['mw'],
    "asāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "asāraka": ['bhs'],
    "asāratā": ['ap90', 'mw'],
    "asārā": ['mw'],
    "asāta": ['bhs'],
    "asātmya": ['mw'],
    "asāvadhāna": ['cae', 'mw'],
    "asāvadhānatā": ['mw'],
    "asāyaka": ['ddsa'],
    "asāṃnidhya": ['cae', 'mw'],
    "asāṃpradāyika": ['mw'],
    "asāṃprata": ['ap90', 'cae', 'mw'],
    "asāṃpratam": ['mw'],
    "asāṃpratikatā": ['mw'],
    "asāṃpreya": ['bhs'],
    "asāṃtāpika": ['mw'],
    "asī": ['ap90', 'mw'],
    "asīma": ['mw'],
    "asīmakṛṣṇa": ['mw'],
    "asīman": ['mw'],
    "asīsaka": ['cped'],
    "asīti": ['cped'],
    "asītika": ['cped'],
    "asū": ['ap90', 'cae', 'gra', 'mw'],
    "asūcīsañcāra": ['ddsa'],
    "asūcīsaṃcāra": ['mw'],
    "asūkṣaṇaṃ": ['ap90'],
    "asūkṣma": ['mw'],
    "asūra": ['ap90', 'gra', 'mw'],
    "asūre": ['mw'],
    "asūria": ['gra'],
    "asūrkṣaṇa": ['mw'],
    "asūrta": ['ap90', 'gra', 'mw'],
    "asūrtarajasa": ['mw'],
    "asūrya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asūryaga": ['cae'],
    "asūryam": ['mw'],
    "asūryampaśyā": ['mw'],
    "asūryaṃpaśya": ['ap90'],
    "asūsū": ['mw'],
    "asūta": ['ap90', 'cae', 'mw'],
    "asūtajaratī": ['mw'],
    "asūti": ['ddsa', 'mw'],
    "asūtikā": ['mw'],
    "asūtiḥ": ['ap90'],
    "asūy": ['cae', 'gra'],
    "asūya": ['cae', 'ddsa', 'mw'],
    "asūyaka": ['ap90', 'cae', 'mw'],
    "asūyanaṃ": ['ap90'],
    "asūyati": ['ap90'],
    "asūyitṛ": ['ap90', 'cae', 'mw'],
    "asūyu": ['cae', 'mw'],
    "asūyuḥ": ['ap90'],
    "asūyā": ['ap90', 'mw'],
    "asṛg": ['mw'],
    "asṛgbhājana": ['mw'],
    "asṛgdara": ['mw'],
    "asṛgdharā": ['mw'],
    "asṛgdhārā": ['ddsa', 'mw'],
    "asṛgdoha": ['mw'],
    "asṛggraha": ['mw'],
    "asṛgvahā": ['mw'],
    "asṛgvimokṣaṇa": ['mw'],
    "asṛj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "asṛk": ['mw'],
    "asṛkkara": ['mw'],
    "asṛkpa": ['mw'],
    "asṛkpaṅkapeṣam": ['ddsa'],
    "asṛkpāta": ['cae', 'mw'],
    "asṛkpāvan": ['mw'],
    "asṛksrāva": ['mw'],
    "asṛksrāvin": ['mw'],
    "asṛktva": ['mw'],
    "asṛpāṭa": ['mw'],
    "asṛpāṭaḥ": ['ap90'],
    "asṛpāṭī": ['mw'],
    "asṛṅ": ['mw'],
    "asṛṅmaya": ['ddsa', 'mw'],
    "asṛṅmiśra": ['mw'],
    "asṛṅmukha": ['mw'],
    "asṛṇi": ['ap90', 'mw'],
    "asṛṇya": ['mw'],
    "asṛṣṭa": ['ap90', 'mw'],
    "asṛṣṭānna": ['cae', 'mw'],
    "at": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "atad": ['mw'],
    "atadarha": ['mw'],
    "atadarham": ['mw'],
    "atadarhaṃ": ['ap90'],
    "ataddhita": ['mw'],
    "atadguṇa": ['mw'],
    "atadguṇaḥ": ['ap90'],
    "atadvid": ['cae'],
    "ataeva": ['mw'],
    "ataijasa": ['cae', 'mw'],
    "atailapūra": ['ddsa', 'mw'],
    "atajjña": ['ap90', 'mw'],
    "atakaḥ": ['ap90'],
    "atala": ['ap90', 'cae', 'ddsa', 'mw'],
    "atalasparśa": ['mw'],
    "atalaspṛś": ['mw'],
    "atamas": ['mw'],
    "atameru": ['mw'],
    "atamisra": ['ddsa', 'mw'],
    "atamāviṣṭa": ['mw'],
    "atana": ['mw'],
    "atanavat": ['mw'],
    "atanaṃ": ['ap90'],
    "atandra": ['cae', 'gra', 'mw'],
    "atandrin": ['cae', 'mw'],
    "atandrita": ['cae', 'ddsa', 'mw'],
    "atandrī": ['mw'],
    "atantra": ['mw'],
    "atanu": ['cae', 'ddsa', 'mw'],
    "atanubala": ['ddsa'],
    "atapa": ['ap90', 'bhs', 'mw'],
    "atapas": ['ap90', 'cae', 'ddsa', 'mw'],
    "atapaska": ['cae', 'mw'],
    "atapasya": ['cae', 'mw'],
    "atappa": ['cped'],
    "atapta": ['ap90', 'gra', 'mw'],
    "ataptatanū": ['gra', 'mw'],
    "ataptatapas": ['mw'],
    "atapyamāna": ['gra', 'mw'],
    "atara": ['bhs', 'mw'],
    "atarapaṇyena": ['mw'],
    "ataritra": ['mw'],
    "atarka": ['ap90', 'mw'],
    "atarkika": ['bhs'],
    "atarkin": ['ddsa'],
    "atarkita": ['ap90', 'cae', 'ddsa', 'mw'],
    "atarkitam": ['mw'],
    "atarkitopapanna": ['mw'],
    "atarkya": ['ap90', 'ddsa', 'mw'],
    "atarkyasahasraśakti": ['mw'],
    "ataru": ['bhs'],
    "atarucchāya": ['ddsa'],
    "atarṣaka": ['bhs'],
    "atarṣaṇīya": ['bhs'],
    "atarṣulam": ['mw'],
    "atas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "atasa": ['cae', 'gra', 'mw'],
    "atasaḥ": ['ap90'],
    "atasi": ['cae', 'gra', 'mw'],
    "atasiḥ": ['ap90'],
    "ataskara": ['mw'],
    "atasthāna": ['mw'],
    "atasāyia": ['gra'],
    "atasāyya": ['gra', 'mw'],
    "atasī": ['ap90', 'mw'],
    "atathocita": ['cae', 'ddsa', 'mw'],
    "atathya": ['ddsa', 'mw'],
    "atathā": ['ap90', 'gra', 'mw'],
    "atathābhāva": ['cae'],
    "atatpara": ['ddsa'],
    "atattva": ['cae', 'ddsa'],
    "atattvavid": ['mw'],
    "atattvārthavant": ['cae'],
    "atattvārthavat": ['mw'],
    "atavyas": ['ap90', 'gra', 'mw'],
    "ataūrdhvam": ['mw'],
    "ataḥparam": ['mw'],
    "ataṃdra": ['ap90'],
    "ataṃtra": ['ap90'],
    "ataṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "atejas": ['ap90', 'mw'],
    "atejaska": ['mw'],
    "atejasvin": ['mw'],
    "atejomaya": ['mw'],
    "atha": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "atha ca pana": ['cped'],
    "atha kho": ['cped'],
    "atha vā": ['cped'],
    "atha vā pi": ['cped'],
    "athabbana": ['cped'],
    "athabbaṇa": ['cped'],
    "athaca": ['mw'],
    "athakim": ['mw'],
    "athakimu": ['mw'],
    "athar": ['gra'],
    "athari": ['mw'],
    "athariḥ": ['ap90'],
    "atharva": ['mw'],
    "atharvabhūta": ['mw'],
    "atharvahṛdaya": ['mw'],
    "atharvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "atharvavat": ['mw'],
    "atharvaveda": ['cae', 'ddsa', 'mw'],
    "atharvavid": ['mw'],
    "atharvaśikhā": ['mw'],
    "atharvaśiras": ['cae', 'mw'],
    "atharvaḥ": ['ap90'],
    "atharvaṇa": ['bhs', 'mw'],
    "atharvaṇaḥ": ['ap90'],
    "atharvaṇi": ['mw'],
    "atharvaṇika": ['bhs'],
    "atharvaṇiḥ": ['ap90'],
    "atharvāṃgiras": ['ap90'],
    "atharvāṃgirasa": ['ap90'],
    "atharvāṅgiras": ['cae', 'ddsa', 'mw'],
    "atharvāṅgirasa": ['mw'],
    "atharvāṇa": ['mw'],
    "atharvāṇavid": ['mw'],
    "atharvāṇaṃ": ['ap90'],
    "atharvī": ['ap90', 'gra', 'mw'],
    "atharya": ['ap90', 'mw'],
    "atharyati": ['ap90'],
    "atharyu": ['gra'],
    "atharyū": ['mw'],
    "atharī": ['cae', 'gra', 'mw'],
    "athatu": ['mw'],
    "athavā": ['ap90', 'mw'],
    "athavāpi": ['mw'],
    "atho": ['ap90', 'cped', 'ddsa', 'mw'],
    "athovā": ['mw'],
    "athā": ['cae', 'mw'],
    "athānantaram": ['mw'],
    "athāparaṁ": ['cped'],
    "athāpi": ['mw'],
    "athātas": ['mw'],
    "ati": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ati-r-iva": ['cped'],
    "ati-uṇha": ['cped'],
    "atia": ['gra'],
    "atibaddha": ['cped'],
    "atibahu": ['mw'],
    "atibala": ['ap90', 'cae', 'ddsa', 'mw'],
    "atibalavant": ['cae'],
    "atibalavīryaparākrama": ['bhs'],
    "atibalin": ['cae'],
    "atibalā": ['mw'],
    "atibandhitvā": ['cped'],
    "atibhairava": ['cae', 'ddsa'],
    "atibhakti": ['cae'],
    "atibharaḥ": ['ap90'],
    "atibhavaḥ": ['ap90'],
    "atibhaya": ['ddsa'],
    "atibhojana": ['cae', 'mw'],
    "atibhojanaṃ": ['ap90'],
    "atibhrū": ['mw'],
    "atibhukta": ['cae'],
    "atibhā": ['mw'],
    "atibhāra": ['cae', 'ddsa', 'mw'],
    "atibhārabhūta": ['mw'],
    "atibhāraga": ['mw'],
    "atibhāraḥ": ['ap90'],
    "atibhāva": ['mw'],
    "atibhī": ['mw'],
    "atibhīḥ": ['ap90'],
    "atibhīṣaṇa": ['cae', 'ddsa', 'mw'],
    "atibhū": ['ap90', 'ddsa', 'mw'],
    "atibhūmi": ['cae', 'ddsa', 'mw'],
    "atibhūmiḥ": ['ap90'],
    "atibhūri": ['cae', 'ddsa'],
    "atibhūṣ": ['mw'],
    "atibhṛ": ['mw'],
    "atibhṛt": ['ddsa'],
    "atibhṛta": ['mw'],
    "atibodhisattva": ['cae', 'mw'],
    "atibrahmacarya": ['mw'],
    "atibrahmacaryaṃ": ['ap90'],
    "atibrahman": ['mw'],
    "atibrū": ['mw'],
    "atibādh": ['mw'],
    "atibāhu": ['mw'],
    "atibāla": ['cae'],
    "atibālaka": ['ap90', 'mw'],
    "atibālā": ['ap90'],
    "atibībhatsa": ['cae', 'mw'],
    "atibṛh": ['mw'],
    "aticamū": ['ap90', 'mw'],
    "aticar": ['ap90', 'mw'],
    "aticara": ['ap90', 'mw'],
    "aticarati": ['cped'],
    "aticaraṇa": ['mw'],
    "aticaraṇaṃ": ['ap90'],
    "aticarita": ['cped'],
    "aticaritar": ['cped'],
    "aticariyā": ['cped'],
    "aticarā": ['mw'],
    "aticatura": ['cae', 'ddsa'],
    "aticaṇḍa": ['mw'],
    "aticca": ['cped'],
    "aticchanda": ['mw'],
    "aticchandas": ['cae', 'ddsa', 'mw'],
    "aticchatraḥ": ['ap90'],
    "aticchaṃdaḥ": ['ap90'],
    "aticeṣṭ": ['mw'],
    "atichattra": ['mw'],
    "atichattraka": ['mw'],
    "atichattrakā": ['mw'],
    "atichattrā": ['mw'],
    "aticira": ['mw'],
    "aticiram": ['cae', 'ddsa', 'mw'],
    "aticirasya": ['ddsa', 'mw'],
    "aticiraya": ['mw'],
    "aticirayati": ['bhs'],
    "aticiraṃ": ['ap90'],
    "aticirāt": ['mw'],
    "aticitram": ['ddsa'],
    "aticitrīya": ['mw'],
    "aticāpalya": ['ddsa', 'mw'],
    "aticāra": ['cae', 'ddsa', 'mw'],
    "aticāraḥ": ['ap90'],
    "aticāri": ['cped'],
    "aticārin": ['ap90', 'cped', 'mw'],
    "aticārini": ['cped'],
    "aticārī": ['cped'],
    "aticārītta": ['cped'],
    "aticṛt": ['mw'],
    "atidagdha": ['ap90', 'mw'],
    "atidagh": ['mw'],
    "atidah": ['mw'],
    "atidahanātmaka": ['ddsa'],
    "atidakṣiṇatā": ['cae'],
    "atidantura": ['mw'],
    "atidarpa": ['ddsa', 'mw'],
    "atidarpita": ['ddsa'],
    "atidarśin": ['mw'],
    "atidatta": ['mw'],
    "atidaṃh": ['mw'],
    "atideva": ['mw'],
    "atidevaḥ": ['ap90'],
    "atideśa": ['cae', 'ddsa', 'mw'],
    "atideśaḥ": ['ap90'],
    "atidhanvan": ['ap90', 'mw'],
    "atidhavala": ['ddsa', 'mw'],
    "atidhenu": ['mw'],
    "atidhonacāri": ['cped'],
    "atidhonacārin": ['cped'],
    "atidhvaṃs": ['mw'],
    "atidhyai": ['mw'],
    "atidhā": ['mw'],
    "atidhāv": ['mw'],
    "atidhāvati": ['cped'],
    "atidhāvitabba": ['cped'],
    "atidhīra": ['cae'],
    "atidhṛti": ['cae', 'ddsa', 'mw'],
    "atidhṛtiḥ": ['ap90'],
    "atidigdha": ['mw'],
    "atidiv": ['mw'],
    "atidiś": ['ap90', 'mw'],
    "atidiṣṭa": ['mw'],
    "atidiṭṭhayā": ['cped'],
    "atidoṣa": ['mw'],
    "atidoṣam": ['mw'],
    "atidru": ['mw'],
    "atidurbala": ['ddsa'],
    "atidurdharṣa": ['ddsa', 'mw'],
    "atidurgama": ['ddsa'],
    "atidurgata": ['mw'],
    "atidurjana": ['ddsa'],
    "atidurlambha": ['mw'],
    "atidurmanas": ['ddsa'],
    "atidurmanāyamāna": ['ddsa'],
    "atidurvaha": ['ddsa'],
    "atidurvṛtta": ['cae', 'ddsa'],
    "atidustara": ['cae', 'ddsa'],
    "atiduḥkhita": ['cae', 'ddsa', 'mw'],
    "atiduḥkhānvita": ['cae', 'ddsa'],
    "atiduḥsaha": ['mw'],
    "atiduḥśrava": ['ddsa'],
    "atiduṣkara": ['cae', 'ddsa', 'mw'],
    "atiduṣkhita": ['mw'],
    "atiduṣṭa": ['cae'],
    "atidvaya": ['ap90', 'ddsa', 'mw'],
    "atidā": ['mw'],
    "atidāha": ['cae', 'ddsa', 'mw'],
    "atidāhaḥ": ['ap90'],
    "atidāna": ['ddsa', 'mw'],
    "atidānaṃ": ['ap90'],
    "atidānta": ['mw'],
    "atidāruṇa": ['cae', 'mw'],
    "atidātṛ": ['ddsa', 'mw'],
    "atidāś": ['mw'],
    "atidīpta": ['cae'],
    "atidīpya": ['mw'],
    "atidīpyaḥ": ['ap90'],
    "atidīrgha": ['cae', 'ddsa', 'mw'],
    "atidīrghakopanatā": ['cae'],
    "atidūna": ['cae'],
    "atidūra": ['ap90', 'cae', 'ddsa', 'mw'],
    "atidṛp": ['mw'],
    "atidṛḍha": ['cae'],
    "atiga": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "atigahana": ['ap90', 'ddsa', 'mw'],
    "atigam": ['ap90', 'mw'],
    "atigambhīra": ['ddsa'],
    "atigandha": ['mw'],
    "atigandhālu": ['mw'],
    "atigardha": ['ddsa'],
    "atigarj": ['mw'],
    "atigarvita": ['mw'],
    "atigarīyas": ['ddsa', 'mw'],
    "atigata": ['mw'],
    "atigava": ['ap90', 'mw'],
    "atigaṃdha": ['ap90'],
    "atigaṃdhālu": ['ap90'],
    "atigaṃḍaḥ": ['ap90'],
    "atigaṇḍa": ['mw'],
    "atigha": ['ap90', 'mw'],
    "atighana": ['ddsa'],
    "atighna": ['ap90'],
    "atighnya": ['mw'],
    "atighnī": ['mw'],
    "atighora": ['ddsa'],
    "atigo": ['mw'],
    "atigrah": ['ap90', 'mw'],
    "atigraha": ['ap90', 'mw'],
    "atigrāha": ['mw'],
    "atigrāhya": ['ap90', 'mw'],
    "atiguhā": ['ap90', 'mw'],
    "atigupta": ['ddsa', 'mw'],
    "atigur": ['mw'],
    "atiguru": ['ap90', 'ddsa', 'mw'],
    "atiguṇa": ['ap90', 'ddsa', 'mw'],
    "atigā": ['mw'],
    "atigāh": ['mw'],
    "atigārgya": ['mw'],
    "atigāḍha": ['mw'],
    "atigāḍham": ['mw'],
    "atihan": ['mw'],
    "atiharanta": ['cped'],
    "atiharati": ['cped'],
    "atiharitabba": ['cped'],
    "atiharitvā": ['cped'],
    "atiharāpesuṁ": ['cped'],
    "atiharāpetabba": ['cped'],
    "atiharāpeti": ['cped'],
    "atiharāpetvā": ['cped'],
    "atiharṣula": ['ddsa'],
    "atihasita": ['ddsa', 'mw'],
    "atihastaya": ['mw'],
    "atihastayati": ['ap90'],
    "atihata": ['mw'],
    "atihimam": ['mw'],
    "atihita": ['cped', 'mw'],
    "atihrasva": ['mw'],
    "atihrepaṇa": ['ddsa'],
    "atihve": ['mw'],
    "atihā": ['mw'],
    "atihāra": ['mw'],
    "atihārin": ['ddsa'],
    "atihāsa": ['mw'],
    "atihṛ": ['mw'],
    "atihṛṣṭa": ['ddsa'],
    "atijagatī": ['ap90', 'cae', 'ddsa', 'mw'],
    "atijala": ['mw'],
    "atijalpati": ['bhs'],
    "atijana": ['ap90', 'ddsa', 'mw'],
    "atijara": ['mw'],
    "atijaras": ['mw'],
    "atijava": ['ddsa', 'mw'],
    "atijaṭhara": ['ddsa'],
    "atiji": ['mw'],
    "atijitakāśin": ['ddsa'],
    "atijāgara": ['ap90', 'mw'],
    "atijāta": ['ap90', 'ddsa', 'mw'],
    "atijīrṇa": ['mw'],
    "atijīrṇatā": ['ddsa', 'mw'],
    "atijīv": ['ap90', 'mw'],
    "atijīva": ['mw'],
    "atijīvanaṃ": ['ap90'],
    "atijīvanmṛtaka": ['cae', 'ddsa'],
    "atikala": ['ddsa'],
    "atikalyam": ['cae', 'ddsa', 'mw'],
    "atikalyāṇa": ['cae', 'ddsa', 'mw'],
    "atikamma": ['cped'],
    "atikandaka": ['mw'],
    "atikaruṇa": ['cae'],
    "atikarṣaṇa": ['mw'],
    "atikarṣaṇaṃ": ['ap90'],
    "atikata": ['cped'],
    "atikatha": ['mw'],
    "atikathā": ['ap90', 'mw'],
    "atikaśa": ['mw'],
    "atikaḍḍhati": ['cped'],
    "atikaṃdakaḥ": ['ap90'],
    "atikaṇha": ['cped'],
    "atikaṣṭa": ['ddsa'],
    "atikaṭhora": ['ddsa', 'mw'],
    "atikeśara": ['mw'],
    "atikeśaraḥ": ['ap90'],
    "atikhara": ['mw'],
    "atikhaṭva": ['ap90', 'mw'],
    "atikhyā": ['mw'],
    "atikhīṇa": ['cped'],
    "atikiriṭa": ['mw'],
    "atikirīṭa": ['mw'],
    "atikisa": ['cped'],
    "atikkama": ['cped'],
    "atikkamaka": ['cped'],
    "atikkamanta": ['cped'],
    "atikkamati": ['cped'],
    "atikkami": ['cped'],
    "atikkamitabba": ['cped'],
    "atikkamitvā": ['cped'],
    "atikkamiṁsu": ['cped'],
    "atikkamma": ['cped'],
    "atikkanta": ['cped'],
    "atikkanta-mānussaka": ['cped'],
    "atikkanta-vara": ['cped'],
    "atikkāmaya": ['cped'],
    "atikkāmayat": ['cped'],
    "atikkāmayati": ['cped'],
    "atikkāmenta": ['cped'],
    "atikkāmita": ['cped'],
    "atikleśa": ['ddsa'],
    "atiklāmita": ['cae'],
    "atikopa": ['cae', 'ddsa'],
    "atikopana": ['cae', 'ddsa'],
    "atikram": ['ap90', 'mw'],
    "atikrama": ['cae', 'ddsa', 'mw'],
    "atikramaḥ": ['ap90'],
    "atikramaṇa": ['cae', 'ddsa', 'mw'],
    "atikramaṇaṃ": ['ap90'],
    "atikramaṇīya": ['ap90', 'ddsa', 'mw'],
    "atikramin": ['ddsa', 'mw'],
    "atikramya": ['mw'],
    "atikruddha": ['ap90', 'mw'],
    "atikrudh": ['ddsa', 'mw'],
    "atikruṣṭa": ['mw'],
    "atikrāmaka": ['mw'],
    "atikrānta": ['bhs', 'ddsa', 'mw'],
    "atikrāntamānuṣyaka": ['bhs'],
    "atikrāntaniṣedha": ['mw'],
    "atikrānti": ['mw'],
    "atikrāntātikrānta": ['mw'],
    "atikrāṃta": ['ap90'],
    "atikrūra": ['ap90', 'cae', 'ddsa'],
    "atikulva": ['mw'],
    "atikup": ['mw'],
    "atikupita": ['cae', 'ddsa'],
    "atikutsita": ['mw'],
    "atikutūhala": ['ddsa'],
    "atikāla": ['bhs'],
    "atikālassa": ['cped'],
    "atikāle": ['cped'],
    "atikālena": ['cped'],
    "atikānta": ['mw'],
    "atikātara": ['cae', 'ddsa'],
    "atikāya": ['ap90', 'cae', 'mw'],
    "atikāḷa": ['cped'],
    "atikāḷikā": ['cped'],
    "atikūrd": ['mw'],
    "atikṛcchra": ['ap90', 'cae', 'ddsa', 'mw'],
    "atikṛcchram": ['mw'],
    "atikṛta": ['cae', 'mw'],
    "atikṛtaṃ": ['ap90'],
    "atikṛti": ['mw'],
    "atikṛtiḥ": ['ap90'],
    "atikṛtārtha": ['mw'],
    "atikṛśa": ['mw'],
    "atikṛṣ": ['mw'],
    "atikṛṣṇa": ['mw'],
    "atikṣar": ['mw'],
    "atikṣip": ['mw'],
    "atikṣipta": ['ap90', 'mw'],
    "atikṣuṇaka": ['bhs'],
    "atilajjanīya": ['cae'],
    "atilakṣa": ['bhs'],
    "atilakṣmī": ['mw'],
    "atilalita": ['cae', 'ddsa'],
    "atilamba": ['mw'],
    "atilaulya": ['cae', 'mw'],
    "atilaṃghanaṃ": ['ap90'],
    "atilaṃghin": ['ap90'],
    "atilaṅgh": ['mw'],
    "atilaṅghana": ['mw'],
    "atilaṅghin": ['ddsa'],
    "atilihā": ['ap90', 'mw'],
    "atilobha": ['cae', 'mw'],
    "atilobhatā": ['mw'],
    "atilohita": ['cae', 'mw'],
    "atilola": ['cae'],
    "atiloma": ['cae', 'ddsa', 'mw'],
    "atilomaśa": ['mw'],
    "atilomaśā": ['mw'],
    "atilubdha": ['cae', 'ddsa', 'mw'],
    "atilulita": ['mw'],
    "atilīyate": ['bhs'],
    "atimada": ['ddsa'],
    "atimadhuram": ['cae'],
    "atimadhyandina": ['mw'],
    "atimadhyaṃdina": ['cae'],
    "atimahat": ['ddsa'],
    "atimaithuna": ['mw'],
    "atimalina": ['cae', 'ddsa'],
    "atiman": ['mw'],
    "atimandhāka": ['cped'],
    "atimanorathakrama": ['mw'],
    "atimanuṣyabuddhi": ['mw'],
    "atimanyanā": ['bhs'],
    "atimartya": ['ap90', 'mw'],
    "atimaryāda": ['ap90', 'mw'],
    "atimaryādam": ['mw'],
    "atimarśa": ['mw'],
    "atimarśam": ['mw'],
    "atimarśaḥ": ['ap90'],
    "atimati": ['gra', 'mw'],
    "atimatimat": ['ddsa'],
    "atimatiḥ": ['ap90'],
    "atimañjula": ['ddsa'],
    "atimaññamāna": ['cped'],
    "atimaññati": ['cped'],
    "atimaññe": ['cped'],
    "atimaññetha": ['cped'],
    "atimaññeyya": ['cped'],
    "atimaññitabba": ['cped'],
    "atimaṃgalya": ['ap90'],
    "atimaṅgalya": ['mw'],
    "atimaṭāhaka": ['cped'],
    "atimemiṣa": ['mw'],
    "atimirmira": ['mw'],
    "atimita": ['ap90', 'mw'],
    "atimitraṃ": ['ap90'],
    "atimodā": ['ap90', 'mw'],
    "atimokṣa": ['mw'],
    "atimokṣin": ['mw'],
    "atimuc": ['mw'],
    "atimucya": ['mw'],
    "atimugdha": ['cae'],
    "atimukhara": ['cae', 'ddsa'],
    "atimukta": ['ap90', 'bhs', 'cae', 'mw'],
    "atimuktaka": ['bhs', 'mw'],
    "atimuktakamalā": ['bhs'],
    "atimukti": ['mw'],
    "atimuktiḥ": ['ap90'],
    "atimuttakamala": ['cped'],
    "atimāla": ['mw'],
    "atimām": ['mw'],
    "atimāna": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "atimāni": ['cped'],
    "atimānin": ['cae', 'cped', 'ddsa', 'mw'],
    "atimānita": ['mw'],
    "atimānitā": ['mw'],
    "atimānuṣa": ['cae', 'ddsa', 'mw'],
    "atimāpaya": ['cped'],
    "atimāpayat": ['cped'],
    "atimāpeti": ['cped'],
    "atimāpita": ['cped'],
    "atimāra": ['mw'],
    "atimāruta": ['ap90', 'ddsa', 'mw'],
    "atimātra": ['ap90', 'cae', 'ddsa', 'mw'],
    "atimātram": ['mw'],
    "atimātraśas": ['mw'],
    "atimāya": ['ap90', 'mw'],
    "atimāyā": ['bhs'],
    "atimāṃsa": ['ap90'],
    "atimūrti": ['mw'],
    "atimūḍha": ['cae'],
    "atimṛtyu": ['ap90', 'mw'],
    "atinairantarya": ['ddsa'],
    "atinam": ['mw'],
    "atinau": ['ap90', 'mw'],
    "atined": ['mw'],
    "atinetabba": ['cped'],
    "atinetvā": ['cped'],
    "atinibhṛtam": ['ddsa'],
    "atinicṛt": ['ap90', 'ddsa', 'mw'],
    "atinidra": ['mw'],
    "atinidram": ['mw'],
    "atinidrā": ['ap90', 'mw'],
    "atinidrālu": ['cae'],
    "atinihnutya": ['mw'],
    "atinijjhāyitatta": ['cped'],
    "atinipuṇa": ['mw'],
    "atinipāta": ['cped'],
    "atinirbandha": ['cae'],
    "atinirghṛṇa": ['cae', 'ddsa'],
    "atinirhārin": ['ap90'],
    "atinirviṇṇa": ['cae'],
    "atiniryāti": ['bhs'],
    "atinivṛt": ['ap90', 'mw'],
    "atiniḥśvas": ['mw'],
    "atiniṣkaruṇa": ['cae', 'ddsa'],
    "atiniṣṇāta": ['ddsa'],
    "atiniṣṭan": ['mw'],
    "atiniṣṭhura": ['cae', 'ddsa'],
    "atinu": ['mw'],
    "atinud": ['mw'],
    "atināman": ['mw'],
    "atināmayati": ['bhs', 'cped'],
    "atināṣṭra": ['ap90', 'cae', 'ddsa', 'mw'],
    "atinī": ['mw'],
    "atinīca": ['mw'],
    "atinīcais": ['ddsa'],
    "atinṛśaṃsa": ['cae', 'ddsa'],
    "atipad": ['ap90', 'mw'],
    "atipada": ['ap90', 'mw'],
    "atipanna": ['ap90', 'mw'],
    "atipara": ['ap90', 'mw'],
    "atiparicaya": ['ddsa'],
    "atiparicayaḥ": ['ap90'],
    "atiparikṣata": ['cae', 'ddsa'],
    "atiparokṣa": ['ap90', 'mw'],
    "atiparokṣavṛtti": ['mw'],
    "atiparuṣa": ['ddsa'],
    "atiparī": ['mw'],
    "atipassitvā": ['cped'],
    "atipat": ['ap90', 'mw'],
    "atipatana": ['mw'],
    "atipatanaṃ": ['ap90'],
    "atipathin": ['ap90', 'mw'],
    "atipatita": ['mw'],
    "atipatraḥ": ['ap90'],
    "atipatti": ['ddsa', 'mw'],
    "atipattiḥ": ['ap90'],
    "atipattra": ['mw'],
    "atipauruṣa": ['ddsa'],
    "atipañcā": ['mw'],
    "atipaś": ['mw'],
    "atipaścāt": ['bhs'],
    "atipaṃcā": ['ap90'],
    "atipaṭh": ['mw'],
    "atipaṭīkṣepa": ['mw'],
    "atipeśala": ['mw'],
    "atipinaddha": ['cae', 'ddsa'],
    "atipitāmaha": ['mw'],
    "atipitṛ": ['mw'],
    "atipiśuna": ['ddsa'],
    "atiprabala": ['ddsa'],
    "atiprabandha": ['cae', 'ddsa', 'mw'],
    "atiprabaṃdhaḥ": ['ap90'],
    "atipracaṇḍa": ['ddsa'],
    "atiprach": ['mw'],
    "atipracit": ['mw'],
    "atipracyu": ['mw'],
    "atiprage": ['ap90', 'cae', 'ddsa', 'mw'],
    "atiprahā": ['mw'],
    "atiprajval": ['mw'],
    "atiprakāśa": ['cae', 'ddsa', 'mw'],
    "atipramāṇa": ['cae', 'ddsa', 'mw'],
    "atiprapad": ['mw'],
    "atiprasad": ['mw'],
    "atiprasakti": ['cae', 'ddsa', 'mw'],
    "atiprasanna": ['cae', 'mw'],
    "atiprasaṃgaḥ": ['ap90'],
    "atiprasaṅga": ['mw'],
    "atiprasiddha": ['mw'],
    "atiprasthā": ['mw'],
    "atiprasṛ": ['mw'],
    "atiprasṛta": ['mw'],
    "atiprathate": ['bhs'],
    "atiprauḍha": ['mw'],
    "atiprauḍhayauvana": ['cae', 'mw'],
    "atiprauḍhā": ['ap90'],
    "atipravah": ['mw'],
    "atipravaraṇa": ['mw'],
    "atipravaṇṇa": ['bhs'],
    "atiprave": ['mw'],
    "atipraveśa": ['ddsa'],
    "atipraviddha": ['mw'],
    "atipravā": ['mw'],
    "atipravṛddha": ['ap90', 'cae', 'mw'],
    "atipravṛt": ['mw'],
    "atipravṛtta": ['cae'],
    "atipravṛtti": ['mw'],
    "atiprayam": ['mw'],
    "atiprayuj": ['mw'],
    "atiprayukta": ['cae', 'ddsa'],
    "atipraśasta": ['ddsa'],
    "atipraśaṃs": ['mw'],
    "atipraśna": ['mw'],
    "atipraśnaḥ": ['ap90'],
    "atipraśnya": ['mw'],
    "atipraśru": ['mw'],
    "atipraśānta": ['cae'],
    "atipraśṛdh": ['mw'],
    "atipraṇaya": ['mw'],
    "atipraṇaś": ['mw'],
    "atipraṇud": ['mw'],
    "atipraṇudya": ['mw'],
    "atipraṇī": ['mw'],
    "atipreṣita": ['mw'],
    "atipreṣitaṃ": ['ap90'],
    "atipriya": ['ddsa'],
    "atipru": ['mw'],
    "atiprāgas": ['bhs'],
    "atiprāgeva": ['bhs'],
    "atiprākṛta": ['cae', 'ddsa'],
    "atiprāṇam": ['mw'],
    "atiprāṇapriya": ['mw'],
    "atipuruṣa": ['bhs', 'mw'],
    "atipuṇya": ['ddsa'],
    "atipā": ['mw'],
    "atipāda": ['mw'],
    "atipādanicṛt": ['ap90', 'ddsa', 'mw'],
    "atipādanivṛt": ['ap90'],
    "atipāraya": ['gra', 'mw'],
    "atipāta": ['cae', 'ddsa', 'mw'],
    "atipātaka": ['mw'],
    "atipātakaṃ": ['ap90'],
    "atipātaya": ['cped'],
    "atipātayat": ['cped'],
    "atipātayati": ['cped'],
    "atipātaḥ": ['ap90'],
    "atipātenta": ['cped'],
    "atipāti": ['cped'],
    "atipātin": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "atipātita": ['ap90', 'mw'],
    "atipātya": ['ap90', 'mw'],
    "atipātāpayati": ['cped'],
    "atipīḍana": ['ddsa'],
    "atipū": ['mw'],
    "atipūra": ['ddsa'],
    "atipūruṣa": ['mw'],
    "atipūrva": ['ddsa'],
    "atipūta": ['mw'],
    "atipṛ": ['mw'],
    "atipṝ": ['mw'],
    "atirabhasa": ['mw'],
    "atirabhasaḥ": ['ap90'],
    "atirai": ['ap90', 'mw'],
    "atirakta": ['ap90', 'mw'],
    "atiraktatā": ['ddsa'],
    "atiraktā": ['mw'],
    "atiramaṇīya": ['cae'],
    "atiramya": ['cae'],
    "atiraskṛta": ['cae', 'ddsa'],
    "atirasā": ['ap90', 'mw'],
    "atiratha": ['mw'],
    "atirathaḥ": ['ap90'],
    "atiraṃhas": ['ap90', 'cae', 'ddsa', 'mw'],
    "atireka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "atirekaḥ": ['ap90'],
    "atirekin": ['mw'],
    "atiri": ['mw'],
    "atiric": ['ap90', 'mw'],
    "atirikta": ['ap90', 'cae', 'mw'],
    "atiriktaka": ['bhs'],
    "atiriktatā": ['mw'],
    "atiriktāṅga": ['cae', 'mw'],
    "atiritta": ['cped'],
    "atiriva": ['bhs'],
    "atirocamāna": ['ddsa'],
    "atirocatha": ['cped'],
    "atirocati": ['cped'],
    "atiroga": ['mw'],
    "atirogaḥ": ['ap90'],
    "atirohitatva": ['ddsa'],
    "atiroka": ['mw'],
    "atiromaśa": ['ap90', 'mw'],
    "atiruc": ['ap90', 'mw'],
    "atirucira": ['ap90', 'mw'],
    "atirucirā": ['mw'],
    "atiruh": ['mw'],
    "atiruṣ": ['cae', 'ddsa', 'mw'],
    "atirāj": ['mw'],
    "atirājakumāri": ['mw'],
    "atirājan": ['ap90', 'mw'],
    "atirājaya": ['mw'],
    "atirājñī": ['mw'],
    "atirātra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "atirātrasavanīyapaśu": ['mw'],
    "atirātrayājin": ['mw'],
    "atirūkṣa": ['ap90'],
    "atirūpa": ['ap90', 'cae', 'mw'],
    "atisadaya": ['ddsa'],
    "atisadṛśa": ['bhs', 'ddsa'],
    "atisahasā": ['cae', 'ddsa'],
    "atisakhi": ['ddsa'],
    "atisakti": ['ddsa', 'mw'],
    "atisaktimat": ['mw'],
    "atisaktiḥ": ['ap90'],
    "atisamartha": ['ddsa', 'mw'],
    "atisambhoga": ['ddsa'],
    "atisambhrama": ['ddsa'],
    "atisamparka": ['mw'],
    "atisamīpa": ['ddsa', 'mw'],
    "atisamṛddha": ['bhs'],
    "atisandham": ['mw'],
    "atisandheya": ['ddsa'],
    "atisandhita": ['mw'],
    "atisannidhāna": ['ddsa'],
    "atisantata": ['ddsa'],
    "atisara": ['ap90', 'mw'],
    "atisarasa": ['cae', 'ddsa'],
    "atisarasvatī": ['mw'],
    "atisarati": ['bhs'],
    "atisarga": ['cae', 'ddsa', 'mw'],
    "atisargaḥ": ['ap90'],
    "atisarjana": ['bhs', 'mw'],
    "atisarjanaṃ": ['ap90'],
    "atisarpaṇa": ['ddsa'],
    "atisarpaṇaṃ": ['ap90'],
    "atisarva": ['ap90', 'ddsa', 'mw'],
    "atisatvaram": ['ddsa'],
    "atisauhitya": ['cae', 'mw'],
    "atisauhityaṃ": ['ap90'],
    "atisaujanya": ['ddsa'],
    "atisauparṇa": ['mw'],
    "atisaurabha": ['ap90', 'mw'],
    "atisaviśaṅkam": ['ddsa'],
    "atisaṃbhrama": ['cae'],
    "atisaṃcaya": ['cae', 'mw'],
    "atisaṃdheya": ['mw'],
    "atisaṃdhyā": ['ap90'],
    "atisaṃdhā": ['ap90', 'mw'],
    "atisaṃdhāna": ['mw'],
    "atisaṃdhānaṃ": ['ap90'],
    "atisaṃkaṭa": ['cae'],
    "atisaṃkruddha": ['cae'],
    "atisaṃnidhāna": ['cae'],
    "atisaṃskṛta": ['mw'],
    "atisaṃtapta": ['mw'],
    "atisaṅkaṭa": ['ddsa'],
    "atisena": ['mw'],
    "atisev": ['mw'],
    "atisevā": ['mw'],
    "atisiddhi": ['mw'],
    "atisitvā": ['cped'],
    "atisitāṅgavihaṃga": ['mw'],
    "atisitāṅgavihaṅga": ['ddsa'],
    "atisneha": ['ddsa'],
    "atisnehaḥ": ['ap90'],
    "atisnigdha": ['mw'],
    "atisparśa": ['ap90', 'mw'],
    "atisphira": ['mw'],
    "atisraṃs": ['mw'],
    "atisru": ['mw'],
    "atisruta": ['mw'],
    "atisrāvita": ['mw'],
    "atisthira": ['mw'],
    "atisthūla": ['mw'],
    "atistri": ['mw'],
    "atistuti": ['mw'],
    "atisuhita": ['mw'],
    "atisujana": ['mw'],
    "atisukha": ['cae', 'ddsa'],
    "atisulabha": ['mw'],
    "atisundara": ['mw'],
    "atisvalpa": ['cae'],
    "atisvapna": ['mw'],
    "atisvapnaśīla": ['cae'],
    "atisvastha": ['mw'],
    "atisvinna": ['mw'],
    "atisvāra": ['bhs'],
    "atisvārya": ['mw'],
    "atisvṛ": ['mw'],
    "atisādhvasa": ['cae', 'ddsa', 'mw'],
    "atisāhasa": ['cae', 'ddsa'],
    "atisāmyā": ['ap90', 'mw'],
    "atisāndra": ['ddsa'],
    "atisāntapana": ['mw'],
    "atisāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "atisārakin": ['mw'],
    "atisāraḥ": ['ap90'],
    "atisāri": ['cped'],
    "atisārin": ['ap90', 'bhs', 'cped', 'mw'],
    "atisāyam": ['cae', 'ddsa', 'mw'],
    "atisāṃtapanaṃ": ['ap90'],
    "atisāṃvatsara": ['ap90', 'cae', 'ddsa', 'mw'],
    "atisūkṣma": ['cae', 'ddsa'],
    "atisūrya": ['bhs'],
    "atisṛ": ['ap90', 'mw'],
    "atisṛj": ['ap90', 'mw'],
    "atisṛjya": ['mw'],
    "atisṛp": ['mw'],
    "atisṛṣṭi": ['cae', 'ddsa', 'mw'],
    "atitamām": ['mw'],
    "atitap": ['mw'],
    "atitapasvin": ['cae', 'ddsa', 'mw'],
    "atitara": ['ddsa'],
    "atitarati": ['cped'],
    "atitaraṇaṃ": ['ap90'],
    "atitarām": ['cae', 'ddsa', 'mw'],
    "atitarāṃ": ['ap90'],
    "atitata": ['mw'],
    "atitejas": ['cae', 'ddsa'],
    "atitejasvin": ['cae'],
    "atithi": ['cae', 'ddsa', 'gra', 'mw'],
    "atithibali": ['cped'],
    "atithideva": ['mw'],
    "atithidharma": ['mw'],
    "atithidharmin": ['mw'],
    "atithidveṣa": ['mw'],
    "atithigva": ['gra', 'mw'],
    "atithigvaḥ": ['ap90'],
    "atithikaraṇīya": ['cped'],
    "atithikriyā": ['mw'],
    "atithin": ['ap90', 'ddsa', 'gra', 'mw'],
    "atithipati": ['mw'],
    "atithipūjana": ['cae', 'ddsa', 'mw'],
    "atithipūjā": ['mw'],
    "atithisatkāra": ['mw'],
    "atithisevā": ['mw'],
    "atithitva": ['mw'],
    "atithivat": ['mw'],
    "atithiḥ": ['ap90'],
    "atithyartha": ['mw'],
    "atithī": ['cped'],
    "atithībhū": ['mw'],
    "atithīkṛ": ['mw'],
    "atitikṣamāṇa": ['mw'],
    "atitiriya": ['cped'],
    "atititīrṣu": ['ddsa'],
    "atitrasnu": ['mw'],
    "atitti": ['bhs'],
    "atitud": ['ddsa'],
    "atitvam": ['mw'],
    "atitvar": ['mw'],
    "atitvarita": ['ddsa'],
    "atityad": ['mw'],
    "atitānava": ['ddsa'],
    "atitārin": ['ap90', 'cae', 'ddsa', 'mw'],
    "atitārya": ['mw'],
    "atitīkṣṇa": ['mw'],
    "atitīvra": ['ap90', 'mw'],
    "atitīvrā": ['mw'],
    "atitṛd": ['mw'],
    "atitṛp": ['mw'],
    "atitṛpti": ['ddsa', 'mw'],
    "atitṛṇṇa": ['mw'],
    "atitṛṣṇa": ['cae', 'ddsa', 'mw'],
    "atitṛṣṇā": ['ap90', 'cae', 'ddsa', 'mw'],
    "atitṝ": ['ap90', 'mw'],
    "ativac": ['mw'],
    "ativad": ['mw'],
    "ativah": ['ap90', 'mw'],
    "ativaicakṣaṇya": ['ddsa', 'mw'],
    "ativaiśasa": ['mw'],
    "ativaiṣamya": ['ddsa'],
    "ativakra": ['ap90', 'mw'],
    "ativakrā": ['mw'],
    "ativaktṛ": ['ap90', 'mw'],
    "ativannati": ['cped'],
    "ativara": ['mw'],
    "ativardhanaṃ": ['ap90'],
    "ativartana": ['cae', 'mw'],
    "ativartanaṃ": ['ap90'],
    "ativartin": ['ap90', 'cae', 'mw'],
    "ativartula": ['ap90', 'mw'],
    "ativarṇāśramin": ['ap90'],
    "ativarṣa": ['cae'],
    "ativassati": ['cped'],
    "ativassi": ['cped'],
    "ativatsala": ['ddsa'],
    "ativatta": ['bhs', 'cped'],
    "ativattati": ['cped'],
    "ativayam": ['mw'],
    "ativayas": ['ap90'],
    "ativedhaḥ": ['ap90'],
    "ativega": ['ddsa'],
    "ativegita": ['ap90'],
    "ativela": ['ap90', 'mw'],
    "ativelam": ['mw'],
    "ativepathu": ['mw'],
    "ativepathumat": ['mw'],
    "ativeṭhayati": ['cped'],
    "atividdha": ['mw'],
    "atividhura": ['cae', 'ddsa'],
    "atividhā": ['mw'],
    "ativigarhya": ['ddsa'],
    "ativigrahin": ['ddsa'],
    "ativijjha": ['cped'],
    "ativikaṭa": ['ap90', 'mw'],
    "ativikāla": ['bhs'],
    "ativilamba": ['ddsa'],
    "ativilambin": ['mw'],
    "ativilaṅgh": ['mw'],
    "ativiluḍ": ['mw'],
    "ativiparyaya": ['ddsa'],
    "ativipina": ['mw'],
    "ativirāj": ['mw'],
    "ativirājin": ['ddsa'],
    "ativisa": ['cped'],
    "ativisaṃṣṭhula": ['cae'],
    "ativistara": ['cae'],
    "ativistaraḥ": ['ap90'],
    "ativistāra": ['cae'],
    "ativistṛta": ['bhs'],
    "ativitatha": ['ddsa'],
    "ativivṛt": ['mw'],
    "ativiya": ['cped'],
    "ativiśrabdha": ['mw'],
    "ativiśrabdham": ['mw'],
    "ativiśrabdhanavoḍhā": ['mw'],
    "ativiśrambh": ['mw'],
    "ativiśva": ['mw'],
    "ativiśvas": ['mw'],
    "ativiśvasta": ['bhs'],
    "ativiṣa": ['ap90', 'bhs', 'mw'],
    "ativiṣama": ['ddsa'],
    "ativiṣā": ['mw'],
    "ativoḍhṛ": ['mw'],
    "ativraj": ['mw'],
    "ativyadh": ['mw'],
    "ativyasta": ['mw'],
    "ativyathana": ['mw'],
    "ativyathanaṃ": ['ap90'],
    "ativyathā": ['mw'],
    "ativyaya": ['ddsa', 'mw'],
    "ativyādhin": ['mw'],
    "ativyādhya": ['mw'],
    "ativyāpta": ['mw'],
    "ativyāpti": ['mw'],
    "ativyāptiḥ": ['ap90'],
    "ativā": ['mw'],
    "ativāda": ['cae', 'mw'],
    "ativādaḥ": ['ap90'],
    "ativādin": ['ap90', 'mw'],
    "ativāha": ['bhs', 'cped'],
    "ativāhakaḥ": ['ap90'],
    "ativāhana": ['mw'],
    "ativāhanaṃ": ['ap90'],
    "ativāhaḥ": ['ap90'],
    "ativāhika": ['ap90', 'mw'],
    "ativāhita": ['ap90'],
    "ativāhya": ['mw'],
    "ativākya": ['bhs', 'cped'],
    "ativālaka": ['mw'],
    "ativāmoru": ['cae'],
    "ativāsa": ['mw'],
    "ativāsaḥ": ['ap90'],
    "ativāta": ['ddsa', 'mw'],
    "ativī": ['mw'],
    "ativīra": ['ddsa'],
    "ativīryaparākrama": ['ddsa'],
    "ativīryaprabha": ['mw'],
    "ativīryavant": ['cae'],
    "ativīryavat": ['ddsa'],
    "ativṛddha": ['ap90', 'cae', 'mw'],
    "ativṛddhi": ['mw'],
    "ativṛdh": ['mw'],
    "ativṛt": ['ap90', 'mw'],
    "ativṛtta": ['cae', 'ddsa'],
    "ativṛtti": ['mw'],
    "ativṛttiḥ": ['ap90'],
    "ativṛṃhita": ['mw'],
    "ativṛṣ": ['mw'],
    "ativṛṣṭi": ['cae', 'mw'],
    "ativṛṣṭihata": ['mw'],
    "ativṛṣṭiḥ": ['ap90'],
    "atiyaj": ['mw'],
    "atiyatna": ['ddsa'],
    "atiyava": ['mw'],
    "atiyavaḥ": ['ap90'],
    "atiyaśa": ['cae', 'mw'],
    "atiyaśas": ['cae', 'mw'],
    "atiyoga": ['mw'],
    "atiyogaḥ": ['ap90'],
    "atiyuvan": ['mw'],
    "atiyā": ['mw'],
    "atiyāja": ['gra', 'mw'],
    "atiyāti": ['cped'],
    "atiyātrā": ['bhs', 'mw'],
    "atiyūyam": ['mw'],
    "atiāya": ['gra'],
    "atiśakkarī": ['ap90', 'mw'],
    "atiśakra": ['ddsa', 'mw'],
    "atiśakta": ['mw'],
    "atiśakti": ['mw'],
    "atiśaktibhāj": ['mw'],
    "atiśaktitā": ['mw'],
    "atiśakvarī": ['ap90', 'cae', 'ddsa', 'mw'],
    "atiśarvara": ['mw'],
    "atiśarvaraṃ": ['ap90'],
    "atiśasta": ['mw'],
    "atiśastra": ['ap90', 'ddsa', 'mw'],
    "atiśauca": ['ddsa'],
    "atiśauṇḍīratā": ['cae'],
    "atiśaya": ['cae', 'ddsa', 'mw'],
    "atiśayam": ['mw'],
    "atiśayana": ['ap90', 'cae', 'mw'],
    "atiśayanam": ['mw'],
    "atiśayanī": ['mw'],
    "atiśayavat": ['mw'],
    "atiśayaḥ": ['ap90'],
    "atiśayena": ['mw'],
    "atiśayin": ['ap90', 'ddsa', 'mw'],
    "atiśayita": ['ap90', 'cae', 'ddsa', 'mw'],
    "atiśayokti": ['mw'],
    "atiśayopamā": ['cae', 'ddsa', 'mw'],
    "atiśayālu": ['ap90'],
    "atiśaṃs": ['mw'],
    "atiśaṃsana": ['mw'],
    "atiśaṃsanā": ['mw'],
    "atiśaṅk": ['mw'],
    "atiśaṅkita": ['cae', 'ddsa'],
    "atiśaṅkā": ['mw'],
    "atiśaṭha": ['ddsa'],
    "atiśeṣa": ['mw'],
    "atiśeṣaḥ": ['ap90'],
    "atiśi": ['mw'],
    "atiśithila": ['cae', 'ddsa'],
    "atiśiśira": ['ddsa'],
    "atiśiṣ": ['mw'],
    "atiśiṣṭa": ['cae', 'mw'],
    "atiślakṣṇa": ['mw'],
    "atiśliṣ": ['mw'],
    "atiśobhana": ['mw'],
    "atiśrama": ['cae', 'ddsa', 'mw'],
    "atiśreyasi": ['mw'],
    "atiśreyasiḥ": ['ap90'],
    "atiśreṣṭha": ['mw'],
    "atiśreṣṭhatva": ['mw'],
    "atiśrī": ['mw'],
    "atiśubh": ['mw'],
    "atiśuddha": ['cae', 'ddsa'],
    "atiśukla": ['mw'],
    "atiśukra": ['mw'],
    "atiśva": ['ap90', 'mw'],
    "atiśvan": ['ap90'],
    "atiśvā": ['mw'],
    "atiśākvara": ['mw'],
    "atiśāta": ['ddsa', 'mw'],
    "atiśāyana": ['mw'],
    "atiśāyanaṃ": ['ap90'],
    "atiśāyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "atiśī": ['ap90', 'mw'],
    "atiśīghra": ['ddsa'],
    "atiśīlaya": ['mw'],
    "atiśīta": ['ddsa'],
    "atiśītam": ['mw'],
    "atiśūra": ['ddsa'],
    "atiḍīna": ['mw'],
    "atiḍīnaṃ": ['ap90'],
    "atiṅ": ['ddsa'],
    "atiṣakta": ['cae', 'mw'],
    "atiṣita": ['cae', 'mw'],
    "atiṣkad": ['cae', 'gra'],
    "atiṣkadvan": ['mw'],
    "atiṣkadvarī": ['ap90'],
    "atiṣkand": ['ddsa', 'mw'],
    "atiṣṭhant": ['cae'],
    "atiṣṭhat": ['ddsa', 'gra', 'mw'],
    "atiṣṭhā": ['ap90', 'cae', 'mw'],
    "atiṣṭhāvan": ['mw'],
    "atiṣṭhāvat": ['mw'],
    "atiṣṭigham": ['mw'],
    "atiṣṭu": ['mw'],
    "atka": ['cae', 'ddsa', 'gra', 'mw'],
    "atkaḥ": ['ap90'],
    "atkīla": ['mw'],
    "atkīlaḥ": ['ap90'],
    "atma": ['bhs'],
    "atna": ['mw'],
    "atnaḥ": ['ap90'],
    "atnaṃ": ['ap90'],
    "atnu": ['mw'],
    "ato": ['cped'],
    "atonimittam": ['ddsa', 'mw'],
    "atonya": ['mw'],
    "atortham": ['mw'],
    "atoṣaṇīya": ['mw'],
    "ato’rtham": ['ddsa'],
    "atra": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "atrabhavant": ['cae'],
    "atrabhavat": ['ddsa', 'mw'],
    "atradaghna": ['mw'],
    "atraiva": ['mw'],
    "atraja": ['cped'],
    "atramantrā": ['bhs'],
    "atran": ['ddsa'],
    "atrapa": ['ap90', 'cae', 'ddsa', 'mw'],
    "atrapu": ['mw'],
    "atrapus": ['mw'],
    "atrasad": ['mw'],
    "atrasnu": ['mw'],
    "atrasta": ['ap90', 'ddsa'],
    "atrastha": ['ddsa'],
    "atrasyat": ['mw'],
    "atratya": ['ap90', 'ddsa', 'mw'],
    "atravas": ['ap90'],
    "atri": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "atribhāradvājikā": ['mw'],
    "atricaturaha": ['mw'],
    "atridṛgja": ['mw'],
    "atrija": ['cae'],
    "atrijāta": ['mw'],
    "atrin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "atrinetrabhū": ['mw'],
    "atrinetraja": ['mw'],
    "atrinetraprabhava": ['mw'],
    "atrinetraprasūta": ['mw'],
    "atrinetrasūta": ['mw'],
    "atrirātrayājin": ['mw'],
    "atrisaṃhitā": ['mw'],
    "atrismṛti": ['mw'],
    "atrivarṣa": ['cae', 'ddsa'],
    "atrivat": ['ddsa', 'gra', 'mw'],
    "atrā": ['cae', 'mw'],
    "atrāntare": ['cae'],
    "atrāsita": ['ddsa', 'mw'],
    "atrāṇa": ['bhs'],
    "atrāṇya": ['bhs'],
    "atsaruka": ['mw'],
    "atsarukaḥ": ['ap90'],
    "atta": ['bhs', 'cped'],
    "atta-d-attha": ['cped'],
    "atta-n-tapa": ['cped'],
    "attabhara": ['cped'],
    "attabhāva": ['cped'],
    "attabhāvapaṭilābha": ['cped'],
    "attabhāvi": ['cped'],
    "attabhāvin": ['cped'],
    "attacatuttha": ['cped'],
    "attadhipaka": ['cped'],
    "attadhīna": ['cped'],
    "attadutiya": ['cped'],
    "attadīpa": ['cped'],
    "attagarahi": ['cped'],
    "attagarahin": ['cped'],
    "attaghañña": ['cped'],
    "attahetu": ['cped'],
    "attaja": ['cped'],
    "attakilamatha": ['cped'],
    "attakāma": ['cped'],
    "attakāra": ['cped'],
    "attali": ['mw'],
    "attamana": ['cped'],
    "attamanas": ['bhs'],
    "attamāraṇiya": ['cped'],
    "attan": ['cped'],
    "attanudiṭṭhi": ['cped'],
    "attanupkkhi": ['cped'],
    "attanupkkhin": ['cped'],
    "attanuvādabhaya": ['cped'],
    "attanuyogi": ['cped'],
    "attanuyogin": ['cped'],
    "attanīya": ['cped'],
    "attapaṭilābha": ['cped'],
    "attarūpa": ['cped'],
    "attatta": ['cped'],
    "attatthiya": ['cped'],
    "attavetanabhata": ['cped'],
    "attavya": ['cae', 'ddsa', 'mw'],
    "attavyābādha": ['cped'],
    "attavādupādāna": ['cped'],
    "attaññu": ['cped'],
    "attaṭhapañña": ['cped'],
    "attaṭṭapañña": ['cped'],
    "attha": ['cped'],
    "atthabaddha": ['cped'],
    "atthacara": ['cped'],
    "atthacaraka": ['cped'],
    "atthacariyā": ['cped'],
    "atthadassi": ['cped'],
    "atthadassin": ['cped'],
    "atthagama": ['cped'],
    "atthagata": ['cped'],
    "atthajāta": ['cped'],
    "atthakaraṇa": ['cped'],
    "atthakathā": ['cped'],
    "atthakavi": ['cped'],
    "atthakkhāyi": ['cped'],
    "atthakkhāyin": ['cped'],
    "atthakāma": ['cped'],
    "atthakāmi": ['cped'],
    "atthakāmin": ['cped'],
    "atthantara": ['cped'],
    "atthanusiṭṭhi": ['cped'],
    "atthapada": ['cped'],
    "atthapaṭisambhidā": ['cped'],
    "atthapucchana": ['cped'],
    "atthapurekkhāra": ['cped'],
    "attharati": ['cped'],
    "attharaṇa": ['cped'],
    "attharitabba": ['cped'],
    "attharitvā": ['cped'],
    "atthasaṁhita": ['cped'],
    "atthata": ['cped'],
    "atthava": ['cped'],
    "atthavasa": ['cped'],
    "atthavasi": ['cped'],
    "atthavasika": ['cped'],
    "atthavasin": ['cped'],
    "atthavat": ['cped'],
    "atthaveda": ['cped'],
    "atthavādi": ['cped'],
    "atthavādin": ['cped'],
    "atthaññū": ['cped'],
    "atthaṁ": ['cped'],
    "atthaṭakaṭhina": ['cped'],
    "atthi": ['cped'],
    "atthika": ['cped'],
    "atthikava": ['cped'],
    "atthikavat": ['cped'],
    "atthikavāda": ['cped'],
    "atthin": ['cped'],
    "atthisukha": ['cped'],
    "atthitā": ['cped'],
    "atthiya": ['cped'],
    "atthopasaṁhita": ['cped'],
    "atthu": ['cped'],
    "atthāra": ['cped'],
    "atthāraka": ['cped'],
    "atthāya": ['cped'],
    "atthūpaparikkhi": ['cped'],
    "atthūpaparikkhin": ['cped'],
    "atthūpeta": ['cped'],
    "atti": ['cae', 'mw'],
    "attikā": ['cae', 'mw'],
    "attiḥ": ['ap90'],
    "attra": ['mw'],
    "attri": ['mw'],
    "attrīṇi": ['mw'],
    "attuddesa": ['cped'],
    "attuddesika": ['cped'],
    "attukkaṁsaka": ['cped'],
    "attukkaṁsana": ['cped'],
    "attā": ['ap90', 'cae', 'mw'],
    "attādhipateyya": ['cped'],
    "attādāna": ['cped'],
    "attānam": ['cped'],
    "attāttamīya": ['bhs'],
    "attīyanā": ['bhs'],
    "attīyati": ['bhs'],
    "attūpanāyika": ['cped'],
    "attṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "atudant": ['cae'],
    "atuhina": ['mw'],
    "atuhinadhāman": ['mw'],
    "atuhinaraśmi": ['mw'],
    "atuhinaruci": ['mw'],
    "atula": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "atulaprabha": ['bhs'],
    "atuliya": ['bhs'],
    "atulya": ['ap90', 'bhs', 'mw'],
    "atulyaparivarta": ['bhs'],
    "atulyaprabha": ['mw'],
    "atunda": ['mw'],
    "atura": ['ap90', 'mw'],
    "atuṃda": ['ap90'],
    "atuṅga": ['mw'],
    "atuṣa": ['mw'],
    "atuṣāra": ['ap90'],
    "atuṣārakara": ['ddsa', 'mw'],
    "atuṣṭa": ['cae', 'ddsa'],
    "atuṣṭi": ['cae', 'ddsa', 'mw'],
    "atuṣṭikara": ['cae'],
    "atvac": ['mw'],
    "atvakka": ['mw'],
    "atvara": ['cae', 'ddsa', 'mw'],
    "atvarant": ['cae'],
    "atvarā": ['cae', 'ddsa', 'mw'],
    "atya": ['cae', 'ddsa', 'gra', 'mw'],
    "atyabhisṛta": ['mw'],
    "atyaccha": ['ddsa'],
    "atyadbhuta": ['cae', 'mw'],
    "atyadhvan": ['ap90', 'mw'],
    "atyagni": ['ap90', 'mw'],
    "atyagnisomārka": ['mw'],
    "atyagniṣṭoma": ['mw'],
    "atyagniṣṭomaḥ": ['ap90'],
    "atyagra": ['mw'],
    "atyaham": ['mw'],
    "atyahata": ['bhs'],
    "atyahna": ['ap90', 'mw'],
    "atyakṣara": ['mw'],
    "atyalpa": ['cae', 'ddsa', 'mw'],
    "atyalpabuddhi": ['cae'],
    "atyamarṣaṇa": ['mw'],
    "atyamarṣin": ['mw'],
    "atyambupāna": ['ddsa'],
    "atyamla": ['ap90', 'mw'],
    "atyamlaparṇī": ['mw'],
    "atyamlā": ['mw'],
    "atyanila": ['mw'],
    "atyanta": ['cae', 'ddsa', 'mw'],
    "atyantacandramas": ['bhs'],
    "atyantaga": ['mw'],
    "atyantagata": ['mw'],
    "atyantagati": ['mw'],
    "atyantaguṇin": ['mw'],
    "atyantagāmin": ['mw'],
    "atyantakopana": ['mw'],
    "atyantakāle": ['bhs'],
    "atyantam": ['mw'],
    "atyantapīḍana": ['mw'],
    "atyantarībhūta": ['bhs'],
    "atyantasamparka": ['mw'],
    "atyantasaṃyoga": ['mw'],
    "atyantasukumāra": ['mw'],
    "atyantatiraskṛtavācyadhvani": ['mw'],
    "atyantatā": ['bhs'],
    "atyantavāsin": ['mw'],
    "atyantaśas": ['mw'],
    "atyantika": ['mw'],
    "atyantābhāva": ['mw'],
    "atyantāya": ['mw'],
    "atyantīna": ['mw'],
    "atyanusṛ": ['mw'],
    "atyard": ['mw'],
    "atyarh": ['mw'],
    "atyartha": ['ap90', 'cae', 'ddsa', 'mw'],
    "atyartham": ['mw'],
    "atyarāti": ['mw'],
    "atyas": ['mw'],
    "atyasama": ['mw'],
    "atyasita": ['ddsa'],
    "atyasta": ['mw'],
    "atyastam": ['bhs'],
    "atyastikā": ['bhs'],
    "atyatikram": ['mw'],
    "atyatiric": ['mw'],
    "atyatīta": ['bhs'],
    "atyautsukya": ['ddsa'],
    "atyavahāra": ['bhs'],
    "atyavasṛj": ['mw'],
    "atyavaśyaṃ": ['bhs'],
    "atyavi": ['ap90', 'gra', 'mw'],
    "atyaya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "atyayadeśana": ['bhs'],
    "atyayaḥ": ['ap90'],
    "atyayika": ['ap90', 'bhs', 'mw'],
    "atyayikapiṇḍapāta": ['mw'],
    "atyayin": ['ap90', 'mw'],
    "atyayita": ['ap90'],
    "atyaś": ['mw'],
    "atyaśana": ['cae', 'mw'],
    "atyaśnant": ['cae'],
    "atyaśnat": ['ddsa', 'mw'],
    "atyaḥ": ['ap90'],
    "atyaṃha": ['mw'],
    "atyaṃhas": ['ap90', 'mw'],
    "atyaṃkuśa": ['ap90'],
    "atyaṃta": ['ap90'],
    "atyaṃtika": ['ap90'],
    "atyaṃtīna": ['ap90'],
    "atyaṅgula": ['mw'],
    "atyaṅkuśa": ['mw'],
    "atyaṇu": ['mw'],
    "atyaṣṭi": ['cae', 'ddsa', 'mw'],
    "atyaṣṭisāmagrī": ['mw'],
    "atyaṣṭiḥ": ['ap90'],
    "atyetavai": ['mw'],
    "atyeṣ": ['mw'],
    "atyucca": ['ddsa'],
    "atyuccadeva": ['bhs'],
    "atyuccagāmin": ['bhs'],
    "atyuccairdhvani": ['mw'],
    "atyuccais": ['mw'],
    "atyucchrita": ['cae', 'ddsa'],
    "atyuddhā": ['mw'],
    "atyudgacchati": ['bhs'],
    "atyudgata": ['bhs'],
    "atyudāra": ['cae', 'mw'],
    "atyudātta": ['cae'],
    "atyugra": ['ap90', 'cae', 'ddsa', 'mw'],
    "atyuh": ['mw'],
    "atyukthā": ['mw'],
    "atyukti": ['ddsa', 'mw'],
    "atyuktiḥ": ['ap90'],
    "atyuktā": ['ap90', 'mw'],
    "atyukṣ": ['mw'],
    "atyulbaṇa": ['mw'],
    "atyulvaṇa": ['mw'],
    "atyunnamayya": ['bhs'],
    "atyunnati": ['cae'],
    "atyupacāra": ['ddsa'],
    "atyupadha": ['ap90', 'mw'],
    "atyupayaj": ['mw'],
    "atyurvīśa": ['mw'],
    "atyutka": ['ddsa'],
    "atyutkaṭa": ['mw'],
    "atyutkram": ['mw'],
    "atyutsāha": ['mw'],
    "atyutsāhatā": ['bhs'],
    "atyuttama": ['bhs'],
    "atyuṣṇa": ['cae', 'ddsa', 'mw'],
    "atyācāra": ['ap90', 'ddsa', 'mw'],
    "atyādara": ['cae', 'ddsa', 'mw'],
    "atyādham": ['mw'],
    "atyādhā": ['mw'],
    "atyādhāna": ['mw'],
    "atyādhānaṃ": ['ap90'],
    "atyāditya": ['ap90', 'cae', 'ddsa', 'mw'],
    "atyādāna": ['mw'],
    "atyādṛ": ['mw'],
    "atyāga": ['ddsa'],
    "atyāgin": ['cae', 'ddsa'],
    "atyāhita": ['cae', 'ddsa', 'mw'],
    "atyāhitaṃ": ['ap90'],
    "atyāhāra": ['mw'],
    "atyāhārin": ['mw'],
    "atyājya": ['ddsa'],
    "atyākhaṇḍalavikrama": ['mw'],
    "atyākhyāya": ['bhs'],
    "atyākram": ['ap90', 'mw'],
    "atyākula": ['cae', 'ddsa'],
    "atyākāra": ['mw'],
    "atyākāraḥ": ['ap90'],
    "atyāla": ['mw'],
    "atyālaḥ": ['ap90'],
    "atyānanda": ['mw'],
    "atyānaṃdā": ['ap90'],
    "atyāpti": ['mw'],
    "atyārabdha": ['bhs'],
    "atyāroha": ['mw'],
    "atyārūḍha": ['ap90', 'cae'],
    "atyārūḍhi": ['mw'],
    "atyāsad": ['mw'],
    "atyāsam": ['mw'],
    "atyāsanna": ['ddsa', 'mw'],
    "atyāsaḥ": ['ap90'],
    "atyāsaṅga": ['ddsa'],
    "atyāsārin": ['mw'],
    "atyāsṛ": ['mw'],
    "atyāya": ['ap90', 'gra', 'mw'],
    "atyāyam": ['mw'],
    "atyāyat": ['mw'],
    "atyāyata": ['cae'],
    "atyāyu": ['ap90', 'mw'],
    "atyāyus": ['mw'],
    "atyāyā": ['mw'],
    "atyāścarya": ['cae', 'ddsa'],
    "atyāśita": ['mw'],
    "atyāśramin": ['mw'],
    "atyāśā": ['mw'],
    "atyūdhnī": ['mw'],
    "atyūh": ['mw'],
    "atyūha": ['mw'],
    "atyūhaḥ": ['ap90'],
    "atyūhā": ['mw'],
    "atyūmaśā": ['ap90', 'mw'],
    "atyūrdhvākṣa": ['mw'],
    "atyūrjasvala": ['ddsa'],
    "atyūrjitam": ['ddsa', 'mw'],
    "atyūrmi": ['ap90', 'gra', 'mw'],
    "atyṛj": ['mw'],
    "atyṛju": ['ddsa'],
    "atyṛṣabha": ['mw'],
    "atāpasa": ['mw'],
    "atātparyavid": ['ddsa'],
    "atī": ['ap90', 'mw'],
    "atīcchā": ['bhs'],
    "atīcāra": ['mw'],
    "atīkāśa": ['ddsa', 'mw'],
    "atīkṣṇa": ['ddsa', 'mw'],
    "atīndriya": ['cae', 'ddsa', 'mw'],
    "atīndriyagrāhya": ['cae'],
    "atīraka": ['cped'],
    "atīreka": ['mw'],
    "atīrekaḥ": ['ap90'],
    "atīrtha": ['cae', 'ddsa', 'mw'],
    "atīrṇa": ['gra', 'mw'],
    "atīsaraṁdiṭṭhi": ['cped'],
    "atīsāra": ['cped', 'mw'],
    "atīsārakin": ['mw'],
    "atīsāraḥ": ['ap90'],
    "atīsārin": ['ap90', 'mw'],
    "atīta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "atītaka": ['bhs'],
    "atītakāla": ['mw'],
    "atītam addhanaṁ": ['cped'],
    "atītanauka": ['mw'],
    "atītasatthuka": ['cped'],
    "atītasmim": ['cped'],
    "atītayobbana": ['cped'],
    "atītaśaiśava": ['cae'],
    "atītaṁ": ['cped'],
    "atītaṁsa": ['cped'],
    "atītaṭṭha": ['cped'],
    "atīte": ['cped'],
    "atītvarī": ['mw'],
    "atītārtha": ['bhs'],
    "atīva": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "atīvra": ['ddsa', 'mw'],
    "atīvāda": ['mw'],
    "atīśa": ['mw'],
    "atīśaya": ['bhs'],
    "atīṃdriya": ['ap90'],
    "atīṣ": ['mw'],
    "atūrta": ['ap90', 'gra', 'mw'],
    "atūrtadakṣa": ['gra', 'mw'],
    "atūrtapanthā": ['gra'],
    "atūrtapathin": ['mw'],
    "atūtuji": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "atṛdila": ['ap90', 'gra', 'mw'],
    "atṛpa": ['gra', 'mw'],
    "atṛpta": ['cae', 'ddsa', 'mw'],
    "atṛptadṛś": ['mw'],
    "atṛpti": ['mw'],
    "atṛpyat": ['ddsa'],
    "atṛpṇuvant": ['cae'],
    "atṛpṇuvat": ['ddsa', 'gra', 'mw'],
    "atṛtīya": ['bhs'],
    "atṛṇa": ['ddsa'],
    "atṛṇyā": ['ap90', 'mw'],
    "atṛṇāda": ['mw'],
    "atṛṇādaḥ": ['ap90'],
    "atṛṣita": ['gra', 'mw'],
    "atṛṣya": ['mw'],
    "atṛṣyat": ['gra', 'mw'],
    "atṛṣṇa": ['ddsa'],
    "atṛṣṇaj": ['gra', 'mw'],
    "au": ['ap90', 'mw'],
    "aucathia": ['gra'],
    "aucathya": ['gra', 'mw'],
    "auccaiḥśravasa": ['cae', 'ddsa', 'mw'],
    "auccaiḥśravasaḥ": ['ap90'],
    "auccya": ['mw'],
    "auccāmanyava": ['mw'],
    "aucitya": ['cae', 'mw'],
    "aucityaṃ": ['ap90'],
    "aucityālaṃkāra": ['mw'],
    "aucitī": ['ddsa', 'mw'],
    "audabhṛjji": ['mw'],
    "audabuddhi": ['mw'],
    "audajñāyani": ['mw'],
    "audaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "audakaja": ['mw'],
    "audaki": ['mw'],
    "audakā": ['mw'],
    "audakīya": ['mw'],
    "audala": ['mw'],
    "audamajji": ['mw'],
    "audambarī": ['mw'],
    "audamegha": ['mw'],
    "audameghi": ['mw'],
    "audameghyā": ['mw'],
    "audameghīya": ['mw'],
    "audanika": ['mw'],
    "audanikaḥ": ['ap90'],
    "audanvata": ['cae', 'mw'],
    "audanya": ['cae', 'mw'],
    "audanyava": ['cae', 'mw'],
    "audanyi": ['mw'],
    "audanyāyani": ['mw'],
    "audapāna": ['ap90', 'mw'],
    "audara": ['cae', 'mw'],
    "audarciṣa": ['ddsa', 'mw'],
    "audarika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "audarya": ['ap90', 'cae', 'mw'],
    "audaryaka": ['bhs'],
    "audarīyaka": ['bhs'],
    "audasthāna": ['ap90', 'mw'],
    "audatya": ['bhs'],
    "audavraja": ['mw'],
    "audavraji": ['mw'],
    "audavāhi": ['mw'],
    "audavāpi": ['mw'],
    "audavāpīya": ['mw'],
    "audayaka": ['mw'],
    "audayakāḥ": ['ap90'],
    "audayana": ['mw'],
    "audayika": ['ap90', 'mw'],
    "audañcana": ['mw'],
    "audañcanaka": ['mw'],
    "audañcavi": ['mw'],
    "audaśuddhi": ['mw'],
    "audaśvita": ['ap90', 'mw'],
    "audaśvitka": ['mw'],
    "audaṃcana": ['ap90'],
    "audaṅki": ['mw'],
    "audaṅkīya": ['mw'],
    "audbhaṭa": ['mw'],
    "audbhettra": ['cae', 'mw'],
    "audbhettriya": ['cae', 'mw'],
    "audbhida": ['ap90', 'cae', 'mw'],
    "audbhidya": ['cae', 'mw'],
    "audbhidyaṃ": ['ap90'],
    "audbhijja": ['mw'],
    "audbhijjaṃ": ['ap90'],
    "audbhāri": ['mw'],
    "audbilya": ['bhs', 'mw'],
    "auddaṇḍaka": ['mw'],
    "auddeśika": ['ap90', 'mw'],
    "auddhatya": ['bhs', 'cae', 'ddsa', 'mw'],
    "auddhatyaṃ": ['ap90'],
    "auddhava": ['mw'],
    "auddhavamaya": ['mw'],
    "auddhavya": ['ddsa'],
    "auddhārika": ['ap90', 'cae', 'ddsa', 'mw'],
    "auddālaka": ['mw'],
    "auddālakaṃ": ['ap90'],
    "auddālaki": ['cae', 'mw'],
    "auddālakāyana": ['mw'],
    "audgrabhaṇa": ['mw'],
    "audgrabhaṇatva": ['mw'],
    "audgrahaṇa": ['mw'],
    "audgāhamāni": ['mw'],
    "audgātra": ['cae', 'mw'],
    "audgātrasārasaṃgraha": ['mw'],
    "audgātraṃ": ['ap90'],
    "audhasa": ['ap90', 'mw'],
    "audhasyaṃ": ['ap90'],
    "audheya": ['mw'],
    "audrāyaṇa": ['mw'],
    "audumbara": ['cae', 'ddsa', 'mw'],
    "audumbaracchada": ['mw'],
    "audumbaraka": ['mw'],
    "audumbaratva": ['mw'],
    "audumbaratā": ['mw'],
    "audumbari": ['mw'],
    "audumbarā": ['bhs'],
    "audumbarāyaṇa": ['mw'],
    "audumbarāyaṇi": ['mw'],
    "audumbarī": ['mw'],
    "auduṃbara": ['ap90'],
    "auduṃbarakaḥ": ['ap90'],
    "audvepa": ['mw'],
    "audvāhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "audyāva": ['mw'],
    "audāra": ['bhs'],
    "audārika": ['bhs', 'mw'],
    "audārikatā": ['bhs'],
    "audārikaśarīra": ['mw'],
    "audārikaṃ": ['ap90'],
    "audārya": ['cae', 'ddsa', 'mw'],
    "audāryacintāmaṇi": ['mw'],
    "audāryatā": ['mw'],
    "audāryaṃ": ['ap90'],
    "audāsya": ['cae', 'mw'],
    "audāsīnya": ['cae', 'ddsa', 'mw'],
    "audāsīnyaṃ": ['ap90'],
    "audāttya": ['cae', 'ddsa', 'mw'],
    "audīcya": ['mw'],
    "audīcyaprakāśa": ['mw'],
    "augha": ['cae', 'ddsa', 'mw'],
    "aughaḥ": ['ap90'],
    "augrasainya": ['mw'],
    "augraseni": ['mw'],
    "augrasenya": ['mw'],
    "augreya": ['mw'],
    "augrya": ['cae', 'ddsa', 'mw'],
    "augryaṃ": ['ap90'],
    "aujasa": ['mw'],
    "aujasaṃ": ['ap90'],
    "aujasika": ['ap90', 'mw'],
    "aujasya": ['ap90', 'mw'],
    "aujjayanaka": ['mw'],
    "aujjayanika": ['mw'],
    "aujjihāni": ['mw'],
    "aujjvalya": ['cae', 'ddsa', 'mw'],
    "aujjvalyaṃ": ['ap90'],
    "aujjāgari": ['mw'],
    "aukarika": ['bhs'],
    "aukheya": ['mw'],
    "aukhya": ['ap90', 'mw'],
    "aukhyeyaka": ['mw'],
    "aukhīya": ['mw'],
    "auktha": ['mw'],
    "aukthaṃ": ['ap90'],
    "aukthika": ['mw'],
    "aukthikaḥ": ['ap90'],
    "aukthikya": ['mw'],
    "aukthikyaṃ": ['ap90'],
    "aukthya": ['mw'],
    "aukāra": ['cae', 'ddsa', 'mw'],
    "aukṣa": ['cae', 'ddsa', 'mw'],
    "aukṣagandhi": ['mw'],
    "aukṣaka": ['cae', 'ddsa', 'mw'],
    "aukṣakaṃ": ['ap90'],
    "aukṣaṇa": ['mw'],
    "aukṣṇa": ['cae', 'ddsa', 'mw'],
    "aula": ['mw'],
    "aulabhīya": ['mw'],
    "aulapi": ['mw'],
    "aulapin": ['mw'],
    "aulapīya": ['mw'],
    "aulbaṇyaṃ": ['ap90'],
    "auluṇḍya": ['mw'],
    "aulvaṇya": ['mw'],
    "aulāna": ['gra', 'mw'],
    "aulānaṃ": ['ap90'],
    "aulūka": ['mw'],
    "aulūkaṃ": ['ap90'],
    "aulūkhala": ['ap90', 'cae', 'mw'],
    "aulūkhalau": ['mw'],
    "aulūkya": ['mw'],
    "aulūkyadarśana": ['mw'],
    "aulūkyaḥ": ['ap90'],
    "aulūkīya": ['mw'],
    "aum": ['ap90', 'mw'],
    "auma": ['ap90', 'cae', 'ddsa', 'mw'],
    "aumaka": ['mw'],
    "aumbheyaka": ['mw'],
    "aumika": ['mw'],
    "aumāpata": ['mw'],
    "aumīna": ['mw'],
    "aumīnaṃ": ['ap90'],
    "aunmukhya": ['cae', 'mw'],
    "aunnatya": ['cae', 'mw'],
    "aunnatyaṃ": ['ap90'],
    "aunnetra": ['mw'],
    "aunnetraṃ": ['ap90'],
    "aunnidrya": ['mw'],
    "aupabhogika": ['bhs'],
    "aupabhṛta": ['ap90', 'mw'],
    "aupabindavi": ['mw'],
    "aupabāhavi": ['mw'],
    "aupacandhani": ['mw'],
    "aupacayika": ['bhs'],
    "aupacchandasaka": ['cae'],
    "aupacchandasika": ['cae', 'ddsa', 'mw'],
    "aupacchaṃdasikaṃ": ['ap90'],
    "aupacārika": ['ap90', 'mw'],
    "aupacāyika": ['mw'],
    "aupadeśika": ['ap90', 'mw'],
    "aupadeśikatva": ['mw'],
    "aupadharmya": ['ddsa', 'mw'],
    "aupadharmyaṃ": ['ap90'],
    "aupadhenava": ['mw'],
    "aupadheya": ['ap90', 'mw'],
    "aupadhika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "aupadravika": ['ap90', 'mw'],
    "aupadraṣṭrya": ['mw'],
    "aupadraṣṭryaṃ": ['ap90'],
    "aupagama": ['bhs'],
    "aupagava": ['mw'],
    "aupagavaka": ['mw'],
    "aupagavi": ['mw'],
    "aupagavīya": ['mw'],
    "aupagrahika": ['mw'],
    "aupagrastika": ['mw'],
    "aupagrastikaḥ": ['ap90'],
    "aupagātra": ['mw'],
    "aupahastika": ['mw'],
    "aupahārika": ['ap90', 'ddsa', 'mw'],
    "aupajandhani": ['mw'],
    "aupajaṅghani": ['mw'],
    "aupajānuka": ['ap90', 'mw'],
    "aupakalāpya": ['mw'],
    "aupakarṇika": ['ap90', 'mw'],
    "aupakramika": ['bhs'],
    "aupakurvāṇaka": ['mw'],
    "aupakārika": ['mw'],
    "aupakārya": ['cae', 'mw'],
    "aupakāryaṃ": ['ap90'],
    "aupakāryā": ['mw'],
    "aupakāyana": ['mw'],
    "aupala": ['ap90', 'cae', 'ddsa', 'mw'],
    "aupalambhika": ['bhs'],
    "aupalā": ['mw'],
    "aupamanyava": ['cae', 'mw'],
    "aupamika": ['ap90', 'mw'],
    "aupamita": ['ddsa'],
    "aupamya": ['bhs', 'cae', 'ddsa', 'mw'],
    "aupamyaṃ": ['ap90'],
    "aupamānika": ['mw'],
    "aupanayika": ['bhs'],
    "aupanidhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "aupaniṣada": ['ap90', 'ddsa', 'mw'],
    "aupaniṣadha": ['cae'],
    "aupaniṣadika": ['mw'],
    "aupaniṣatka": ['ap90', 'mw'],
    "aupanāsika": ['ap90', 'mw'],
    "aupanāyanika": ['ap90', 'cae', 'ddsa', 'mw'],
    "aupanāyika": ['bhs', 'mw'],
    "aupanīvika": ['ap90', 'ddsa', 'mw'],
    "aupapakṣya": ['ap90', 'mw'],
    "aupapatti": ['bhs'],
    "aupapattika": ['ap90', 'mw'],
    "aupapattyaṃśika": ['bhs'],
    "aupapattyaṅgika": ['bhs'],
    "aupapatya": ['mw'],
    "aupapādika": ['mw'],
    "aupapāduka": ['bhs', 'mw'],
    "aupapātika": ['ap90', 'mw'],
    "aupara": ['mw'],
    "auparaidhikaḥ": ['ap90'],
    "auparaudhika": ['ap90'],
    "auparava": ['mw'],
    "aupariṣṭa": ['ap90', 'mw'],
    "aupariṣṭaka": ['mw'],
    "auparodhika": ['ap90', 'mw'],
    "auparādhayya": ['mw'],
    "auparājika": ['ap90', 'mw'],
    "aupasada": ['mw'],
    "aupasadaḥ": ['ap90'],
    "aupasargika": ['ap90', 'mw'],
    "aupasaṃdhya": ['mw'],
    "aupasaṃkhyānika": ['ap90', 'mw'],
    "aupasaṃkramaṇa": ['ap90', 'mw'],
    "aupasthika": ['ap90', 'mw'],
    "aupasthya": ['mw'],
    "aupasthyaṃ": ['ap90'],
    "aupasthāna": ['ap90', 'mw'],
    "aupasthānika": ['ap90', 'mw'],
    "aupasthūṇya": ['mw'],
    "aupasvastī": ['mw'],
    "aupasvastīputra": ['mw'],
    "aupasīrya": ['mw'],
    "aupatasvini": ['mw'],
    "aupavana": ['bhs'],
    "aupavasathika": ['cae', 'mw'],
    "aupavasathya": ['cae', 'mw'],
    "aupavasta": ['ddsa', 'mw'],
    "aupavastaṃ": ['ap90'],
    "aupavastha": ['mw'],
    "aupavastra": ['mw'],
    "aupavastraka": ['mw'],
    "aupavastraṃ": ['ap90'],
    "aupaveśi": ['mw'],
    "aupaveśika": ['ap90'],
    "aupaveṣika": ['mw'],
    "aupavāhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "aupavāsa": ['ap90', 'mw'],
    "aupavāsika": ['ap90', 'mw'],
    "aupavāsya": ['mw'],
    "aupavāsyaṃ": ['ap90'],
    "aupavīlī": ['mw'],
    "aupavītika": ['ddsa', 'mw'],
    "aupayaja": ['ap90', 'mw'],
    "aupayaugika": ['ap90', 'mw'],
    "aupayika": ['ap90', 'cae', 'ddsa', 'mw'],
    "aupayikatva": ['mw'],
    "aupayikatā": ['mw'],
    "aupaśa": ['mw'],
    "aupaśada": ['mw'],
    "aupaśamika": ['bhs', 'mw'],
    "aupaśivi": ['mw'],
    "aupaśleṣika": ['ap90', 'mw'],
    "aupaśāla": ['mw'],
    "aupendra": ['ddsa', 'mw'],
    "aupeṃdra": ['ap90'],
    "aupodghātika": ['mw'],
    "aupoditeya": ['mw'],
    "aupoditi": ['mw'],
    "aupādhika": ['ap90', 'mw'],
    "aupādhyāyaka": ['ap90', 'mw'],
    "aupādānika": ['mw'],
    "aupākaraṇa": ['ddsa', 'mw'],
    "aupānahya": ['ap90', 'mw'],
    "aupānuvākya": ['mw'],
    "aupānuvākyakāṇḍa": ['mw'],
    "aupāsana": ['ap90', 'cae', 'ddsa', 'mw'],
    "aupāsanaprayoga": ['mw'],
    "aupāsanika": ['mw'],
    "aupāvi": ['mw'],
    "aupāyika": ['ap90', 'mw'],
    "aurabhra": ['ap90', 'cae', 'ddsa', 'mw'],
    "aurabhraka": ['bhs', 'mw'],
    "aurabhrakaṃ": ['ap90'],
    "aurabhrika": ['ap90', 'bhs', 'cae', 'mw'],
    "auraga": ['ap90', 'cae', 'mw'],
    "aurasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aurasi": ['mw'],
    "aurasika": ['mw'],
    "auraska": ['ap90'],
    "aurasya": ['ap90', 'cae', 'mw'],
    "aurasāyani": ['mw'],
    "aurasī": ['mw'],
    "aurava": ['mw'],
    "auraśa": ['ddsa', 'mw'],
    "aurdhva": ['mw'],
    "aurdhvabhaktika": ['mw'],
    "aurdhvadaihika": ['ap90', 'mw'],
    "aurdhvadeha": ['cae', 'ddsa', 'mw'],
    "aurdhvadehaṃ": ['ap90'],
    "aurdhvadehika": ['ap90', 'cae', 'mw'],
    "aurdhvadehikakalpavalli": ['mw'],
    "aurdhvadehikanirṇaya": ['mw'],
    "aurdhvadehikapaddhati": ['mw'],
    "aurdhvadehikaprayoga": ['mw'],
    "aurdhvakālika": ['ap90', 'mw'],
    "aurdhvasadmana": ['mw'],
    "aurdhvasrotasika": ['mw'],
    "aurdhvasrotasikaḥ": ['ap90'],
    "aurdhvaśrotasikaḥ": ['ap90'],
    "aurdhvaṃdamika": ['mw'],
    "aurdāyanī": ['mw'],
    "auriṇa": ['mw'],
    "aurjasya": ['mw'],
    "aurjitya": ['mw'],
    "aurjityaṃ": ['ap90'],
    "aurmileya": ['mw'],
    "aurmya": ['mw'],
    "aurua": ['gra'],
    "auruabhṛguvat": ['gra'],
    "aurukṣaya": ['mw'],
    "aurukṣayasa": ['mw'],
    "aurva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aurvabhṛguvat": ['gra'],
    "aurvadahana": ['mw'],
    "aurvakalpagrantha": ['mw'],
    "aurvaprakāra": ['mw'],
    "aurvaprayoga": ['mw'],
    "aurvara": ['ap90', 'mw'],
    "aurvaśa": ['mw'],
    "aurvaśeya": ['cae', 'ddsa', 'mw'],
    "aurvaśeyaḥ": ['ap90'],
    "aurvāgni": ['cae', 'ddsa', 'mw'],
    "aurvānala": ['cae', 'mw'],
    "aurvāy": ['cae'],
    "aurvāya": ['ddsa', 'mw'],
    "aurvī": ['mw'],
    "aurā": ['mw'],
    "aurṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aurṇaka": ['bhs', 'mw'],
    "aurṇanābha": ['mw'],
    "aurṇanābhaka": ['mw'],
    "aurṇavābha": ['gra', 'mw'],
    "aurṇika": ['cae', 'mw'],
    "aurṇāsūtra": ['cae'],
    "aurṇāvatya": ['mw'],
    "aurṇāyava": ['mw'],
    "autathya": ['mw'],
    "autathyeśvara": ['mw'],
    "autaṅka": ['mw'],
    "autkara": ['bhs'],
    "autkarṣa": ['mw'],
    "autkarṣya": ['mw'],
    "autkarṣyaṃ": ['ap90'],
    "autkaṃṭhyaṃ": ['ap90'],
    "autkaṇṭhya": ['cae', 'ddsa', 'mw'],
    "autkaṇṭhyavat": ['mw'],
    "autkaṭya": ['mw'],
    "autkya": ['cae', 'mw'],
    "autkṣepa": ['mw'],
    "autpattika": ['ap90', 'cae', 'ddsa', 'mw'],
    "autpuṭa": ['mw'],
    "autpuṭika": ['ap90', 'mw'],
    "autpāda": ['ap90', 'mw'],
    "autpāta": ['ap90', 'mw'],
    "autpātika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "autra": ['ap90', 'mw'],
    "autsa": ['ap90', 'mw'],
    "autsargika": ['ap90', 'mw'],
    "autsargikatva": ['mw'],
    "autsaṃgika": ['ap90'],
    "autsaṅgika": ['mw'],
    "autsuka": ['bhs'],
    "autsukya": ['cae', 'ddsa', 'mw'],
    "autsukyavat": ['mw'],
    "autsukyaṃ": ['ap90'],
    "autsāyana": ['mw'],
    "auttama": ['cae'],
    "auttameya": ['mw'],
    "auttami": ['cae', 'ddsa', 'mw'],
    "auttamika": ['ap90', 'mw'],
    "auttamiḥ": ['ap90'],
    "auttara": ['ap90', 'mw'],
    "auttarabhaktika": ['mw'],
    "auttarapadika": ['mw'],
    "auttarapathika": ['mw'],
    "auttaravedika": ['mw'],
    "auttareya": ['mw'],
    "auttareyaḥ": ['ap90'],
    "auttarādharya": ['cae', 'ddsa', 'mw'],
    "auttarāha": ['mw'],
    "auttarāpathika": ['bhs'],
    "auttarārdhika": ['mw'],
    "auttaṅka": ['mw'],
    "autthānika": ['mw'],
    "auttānapāda": ['mw'],
    "auttānapādaḥ": ['ap90'],
    "auttānapādi": ['mw'],
    "auvelī": ['mw'],
    "auveṇaka": ['ddsa', 'mw'],
    "auvīlī": ['mw'],
    "auśana": ['ap90', 'mw'],
    "auśanasa": ['cae', 'ddsa', 'mw'],
    "auśanasya": ['mw'],
    "auśata": ['mw'],
    "auśija": ['ap90', 'cae', 'gra', 'mw'],
    "auśāna": ['gra', 'mw'],
    "auśīnara": ['cae', 'ddsa', 'mw'],
    "auśīnaraḥ": ['ap90'],
    "auśīnari": ['mw'],
    "auśīnarī": ['mw'],
    "auśīra": ['cae', 'ddsa', 'mw'],
    "auśīraṃ": ['ap90'],
    "auśīrika": ['bhs'],
    "auśīrikā": ['ap90', 'mw'],
    "auḍa": ['ap90'],
    "auḍava": ['ap90', 'cae', 'ddsa', 'mw'],
    "auḍavi": ['mw'],
    "auḍavā": ['mw'],
    "auḍavīya": ['mw'],
    "auḍra": ['mw'],
    "auḍraḥ": ['ap90'],
    "auḍulomi": ['mw'],
    "auḍumbara": ['mw'],
    "auḍupa": ['ap90', 'mw'],
    "auḍupika": ['ap90', 'mw'],
    "auḍuṃbara": ['ap90'],
    "auḍāyana": ['mw'],
    "auḍāyanabhakta": ['mw'],
    "auṇādika": ['ddsa'],
    "auṣadaśvi": ['mw'],
    "auṣadha": ['ap90', 'cae', 'ddsa', 'mw'],
    "auṣadhakalpagrantha": ['mw'],
    "auṣadhapeṣaka": ['mw'],
    "auṣadhaprakāra": ['mw'],
    "auṣadhaprayoga": ['mw'],
    "auṣadhavikrayin": ['cae'],
    "auṣadhi": ['mw'],
    "auṣadhiḥ": ['ap90'],
    "auṣadhāvali": ['mw'],
    "auṣadhī": ['mw'],
    "auṣadhīkṛ": ['ap90', 'mw'],
    "auṣadhīya": ['ap90', 'mw'],
    "auṣara": ['mw'],
    "auṣaraka": ['mw'],
    "auṣaraṃ": ['ap90'],
    "auṣarya": ['bhs'],
    "auṣasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "auṣasika": ['ap90', 'mw'],
    "auṣastya": ['mw'],
    "auṣasya": ['ap90'],
    "auṣasī": ['mw'],
    "auṣata": ['mw'],
    "auṣaḍhi": ['bhs'],
    "auṣaṇa": ['mw'],
    "auṣaṇaśauṇḍī": ['mw'],
    "auṣaṇaṃ": ['ap90'],
    "auṣija": ['mw'],
    "auṣika": ['mw'],
    "auṣmya": ['mw'],
    "auṣṇa": ['mw'],
    "auṣṇaṃ": ['ap90'],
    "auṣṇiha": ['mw'],
    "auṣṇya": ['cae', 'ddsa', 'mw'],
    "auṣṇyaṃ": ['ap90'],
    "auṣṇīka": ['mw'],
    "auṣṭha": ['cae', 'ddsa', 'mw'],
    "auṣṭhya": ['ap90'],
    "auṣṭhīna": ['mw'],
    "auṣṭra": ['ap90', 'cae', 'ddsa', 'mw'],
    "auṣṭraka": ['ap90', 'cae', 'mw'],
    "auṣṭraratha": ['ap90', 'mw'],
    "auṣṭrika": ['mw'],
    "auṣṭrākṣi": ['mw'],
    "auṣṭrāyaṇa": ['mw'],
    "auṣṭrāyaṇaka": ['mw'],
    "av": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ava": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "avabaddha": ['cae', 'mw'],
    "avabadhā": ['ap90', 'mw'],
    "avabandh": ['mw'],
    "avabandha": ['mw'],
    "avabaṃdh": ['ap90'],
    "avabaṃdhaḥ": ['ap90'],
    "avabhagna": ['mw'],
    "avabharjana": ['mw'],
    "avabharjita": ['mw'],
    "avabharts": ['mw'],
    "avabhartsana": ['mw'],
    "avabhañj": ['mw'],
    "avabhañjana": ['mw'],
    "avabhaṃgaḥ": ['ap90'],
    "avabhaṃj": ['ap90'],
    "avabhaṃjanaṃ": ['ap90'],
    "avabhaṅga": ['cae', 'ddsa', 'mw'],
    "avabhedaka": ['mw'],
    "avabhedaḥ": ['ap90'],
    "avabhedin": ['ap90', 'mw'],
    "avabhid": ['ap90', 'mw'],
    "avabhinna": ['mw'],
    "avabhra": ['gra', 'mw'],
    "avabhraḥ": ['ap90'],
    "avabhraṭa": ['ap90', 'mw'],
    "avabhugna": ['ap90', 'mw'],
    "avabhuj": ['ap90', 'mw'],
    "avabhā": ['bhs', 'mw'],
    "avabhāna": ['bhs'],
    "avabhās": ['ap90', 'mw'],
    "avabhāsa": ['bhs', 'cae', 'mw'],
    "avabhāsaka": ['ap90', 'mw'],
    "avabhāsakara": ['bhs', 'mw'],
    "avabhāsamakuṭa": ['bhs'],
    "avabhāsana": ['cae', 'mw'],
    "avabhāsanaśikhin": ['bhs', 'mw'],
    "avabhāsaprabha": ['bhs', 'mw'],
    "avabhāsaprāpta": ['mw'],
    "avabhāsaprāptā": ['bhs'],
    "avabhāsarājaprabhaketuśrī": ['bhs'],
    "avabhāsatā": ['bhs'],
    "avabhāsayitar": ['bhs'],
    "avabhāsaḥ": ['ap90'],
    "avabhāsin": ['ap90', 'cae', 'mw'],
    "avabhāsita": ['ap90', 'mw'],
    "avabhāsya": ['bhs', 'mw'],
    "avabhāṣaṇa": ['mw'],
    "avabhāṣaṇaṃ": ['ap90'],
    "avabhāṣita": ['mw'],
    "avabhūta": ['cped'],
    "avabhūṣita": ['bhs'],
    "avabhṛ": ['mw'],
    "avabhṛtha": ['cae', 'mw'],
    "avabhṛthasnapana": ['mw'],
    "avabhṛthasnāna": ['mw'],
    "avabhṛthasāman": ['mw'],
    "avabhṛthayajūṃṣi": ['mw'],
    "avabhṛthaḥ": ['ap90'],
    "avabhṛtheṣṭi": ['mw'],
    "avabhṛti": ['mw'],
    "avabhṛṭha": ['gra'],
    "avaboddhavya": ['mw'],
    "avabodha": ['cae', 'ddsa', 'mw'],
    "avabodhaka": ['ap90', 'cae', 'mw'],
    "avabodhana": ['mw'],
    "avabodhanaṃ": ['ap90'],
    "avabodhanīya": ['mw'],
    "avabodhaḥ": ['ap90'],
    "avabodhi": ['bhs'],
    "avabodhita": ['mw'],
    "avabrava": ['gra', 'mw'],
    "avabravaḥ": ['ap90'],
    "avabuddha": ['ap90', 'mw'],
    "avabudh": ['ap90', 'mw'],
    "avabujjhati": ['cped'],
    "avabādh": ['mw'],
    "avabādhā": ['ap90'],
    "avabāhuka": ['mw'],
    "avabāhukaḥ": ['ap90'],
    "avabāḍha": ['cae', 'mw'],
    "avaca": ['ap90', 'cae', 'mw'],
    "avacakṣ": ['ap90', 'mw'],
    "avacakṣaṇa": ['ap90'],
    "avacakṣaṇam": ['mw'],
    "avacana": ['ap90', 'cae', 'ddsa', 'mw'],
    "avacanakara": ['mw'],
    "avacandramasa": ['mw'],
    "avacanīkaroti": ['bhs'],
    "avacanīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "avacanīyatva": ['mw'],
    "avacanīyatā": ['mw'],
    "avacar": ['ap90', 'mw'],
    "avacara": ['bhs', 'mw'],
    "avacaraka": ['bhs', 'mw'],
    "avacarantikā": ['mw'],
    "avacarati": ['bhs'],
    "avacaskara": ['ap90', 'mw'],
    "avacatnuka": ['mw'],
    "avacaya": ['cae', 'ddsa', 'mw'],
    "avacayaḥ": ['ap90'],
    "avacaṃdramasaṃ": ['ap90'],
    "avacchad": ['ap90', 'mw'],
    "avacchada": ['mw'],
    "avacchadaḥ": ['ap90'],
    "avacchanna": ['cae', 'mw'],
    "avaccheda": ['cae', 'ddsa', 'mw'],
    "avacchedaka": ['ap90', 'mw'],
    "avacchedana": ['mw'],
    "avacchedanaṃ": ['ap90'],
    "avacchedaḥ": ['ap90'],
    "avacchedya": ['mw'],
    "avacchedāvaccheda": ['mw'],
    "avacchid": ['ap90', 'mw'],
    "avacchidda": ['cped'],
    "avacchinna": ['ap90', 'cae', 'mw'],
    "avacchita": ['mw'],
    "avaccho": ['mw'],
    "avacchurita": ['ap90', 'mw'],
    "avacchuritaka": ['mw'],
    "avacchādana": ['mw'],
    "avacchādaḥ": ['ap90'],
    "avacchāta": ['cae', 'mw'],
    "avaci": ['ap90', 'mw'],
    "avacicīṣā": ['mw'],
    "avacita": ['ap90', 'mw'],
    "avacodayati": ['bhs'],
    "avacāra": ['ap90'],
    "avacāraka": ['bhs'],
    "avacāraṇa": ['ap90', 'cae', 'mw'],
    "avacārita": ['mw'],
    "avacārya": ['ap90'],
    "avacāya": ['cae'],
    "avacāyaḥ": ['ap90'],
    "avacāyin": ['ap90', 'mw'],
    "avacīravicīraka": ['bhs', 'mw'],
    "avacūla": ['ap90', 'mw'],
    "avacūlaka": ['mw'],
    "avacūlakaḥ": ['ap90'],
    "avacūri": ['mw'],
    "avacūrikā": ['mw'],
    "avacūrṇ": ['ap90', 'mw'],
    "avacūrṇana": ['mw'],
    "avacūrṇanaṃ": ['ap90'],
    "avacūrṇita": ['ap90', 'mw'],
    "avacūḍa": ['mw'],
    "avacūḍaḥ": ['ap90'],
    "avacūḍā": ['mw'],
    "avacṛt": ['mw'],
    "avada": ['bhs'],
    "avadadhati": ['bhs'],
    "avadagdha": ['mw'],
    "avadah": ['ap90', 'mw'],
    "avadal": ['mw'],
    "avadalita": ['mw'],
    "avadanta": ['mw'],
    "avadaraṇa": ['mw'],
    "avadaraṇaṃ": ['ap90'],
    "avadarpita": ['bhs'],
    "avadat": ['gra', 'mw'],
    "avadatta": ['ap90', 'mw'],
    "avaday": ['mw'],
    "avadaṃśa": ['mw'],
    "avadaṃśaḥ": ['ap90'],
    "avadeya": ['mw'],
    "avadha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avadham": ['mw'],
    "avadharṣya": ['ap90', 'mw'],
    "avadhes": ['mw'],
    "avadheya": ['ap90', 'mw'],
    "avadhi": ['cae', 'mw'],
    "avadhijñāna": ['mw'],
    "avadhijñānin": ['mw'],
    "avadhika": ['bhs', 'mw'],
    "avadhimat": ['ap90', 'mw'],
    "avadhiḥ": ['ap90'],
    "avadhra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avadhvasta": ['ap90', 'mw'],
    "avadhvaṃs": ['ap90', 'mw'],
    "avadhvaṃsa": ['ddsa', 'mw'],
    "avadhvaṃsaḥ": ['ap90'],
    "avadhya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "avadhyabhāva": ['cae'],
    "avadhyai": ['mw'],
    "avadhyaparamabuddhi": ['bhs'],
    "avadhyati": ['bhs'],
    "avadhyatva": ['cae', 'mw'],
    "avadhyatā": ['cae', 'mw'],
    "avadhyeya": ['mw'],
    "avadhyāna": ['bhs', 'mw'],
    "avadhyāta": ['mw'],
    "avadhyāyin": ['mw'],
    "avadhā": ['ap90', 'mw'],
    "avadhāna": ['cae', 'ddsa', 'mw'],
    "avadhānatva": ['mw'],
    "avadhānatā": ['mw'],
    "avadhānavat": ['mw'],
    "avadhānavattā": ['mw'],
    "avadhānaṃ": ['ap90'],
    "avadhānin": ['ap90', 'mw'],
    "avadhānīya": ['ap90'],
    "avadhāra": ['mw'],
    "avadhāraka": ['ap90', 'mw'],
    "avadhāraḥ": ['ap90'],
    "avadhāraṇa": ['ap90', 'cae', 'mw'],
    "avadhāraṇīya": ['ap90', 'mw'],
    "avadhārha": ['mw'],
    "avadhārin": ['bhs'],
    "avadhārita": ['ap90', 'mw'],
    "avadhāritin": ['mw'],
    "avadhārya": ['mw'],
    "avadhātavya": ['ap90', 'mw'],
    "avadhāv": ['ap90', 'mw'],
    "avadhāvanaṃ": ['ap90'],
    "avadhāvita": ['ap90'],
    "avadhī": ['mw'],
    "avadhīkṛ": ['ddsa'],
    "avadhīr": ['ap90', 'mw'],
    "avadhīray": ['cae'],
    "avadhīraya": ['ddsa'],
    "avadhīraṇa": ['cae', 'ddsa', 'mw'],
    "avadhīraṇaṃ": ['ap90'],
    "avadhīraṇā": ['ap90', 'mw'],
    "avadhīrin": ['ap90', 'ddsa', 'mw'],
    "avadhīrita": ['ap90', 'mw'],
    "avadhīyamāna": ['mw'],
    "avadhū": ['ap90', 'mw'],
    "avadhūka": ['mw'],
    "avadhūkaḥ": ['ap90'],
    "avadhūlana": ['mw'],
    "avadhūlanaṃ": ['ap90'],
    "avadhūlita": ['mw'],
    "avadhūnakam": ['bhs'],
    "avadhūnana": ['cae', 'mw'],
    "avadhūnanaṃ": ['ap90'],
    "avadhūpita": ['ap90', 'mw'],
    "avadhūta": ['ap90', 'bhs', 'cae', 'mw'],
    "avadhūtapraṇipāta": ['mw'],
    "avadhūtaveṣa": ['mw'],
    "avadhūti": ['bhs'],
    "avadhūya": ['mw'],
    "avadhṛ": ['ap90', 'mw'],
    "avadhṛta": ['ap90', 'mw'],
    "avadhṛṣya": ['mw'],
    "avadih": ['mw'],
    "avadiś": ['mw'],
    "avado": ['ap90', 'mw'],
    "avadoha": ['mw'],
    "avadohaḥ": ['ap90'],
    "avadola": ['ddsa', 'mw'],
    "avadraga": ['bhs'],
    "avadrai": ['mw'],
    "avadraṃgaḥ": ['ap90'],
    "avadraṅga": ['bhs', 'mw'],
    "avaduh": ['mw'],
    "avadvārāpayati": ['bhs'],
    "avadya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avadyabhī": ['gra', 'mw'],
    "avadyabhīru": ['bhs'],
    "avadyagohana": ['gra', 'mw'],
    "avadyapa": ['gra', 'mw'],
    "avadyat": ['mw'],
    "avadyavat": ['ap90', 'mw'],
    "avadyotaka": ['mw'],
    "avadyotana": ['mw'],
    "avadyotanaṃ": ['ap90'],
    "avadyotin": ['ap90', 'mw'],
    "avadyut": ['mw'],
    "avadāgha": ['mw'],
    "avadāghaḥ": ['ap90'],
    "avadāha": ['mw'],
    "avadāhaḥ": ['ap90'],
    "avadāheṣṭa": ['mw'],
    "avadāna": ['bhs', 'cae', 'mw'],
    "avadānakalpalatā": ['mw'],
    "avadānaṃ": ['ap90'],
    "avadāniya": ['cped'],
    "avadānya": ['ap90', 'mw'],
    "avadānīya": ['mw'],
    "avadāra": ['cae', 'mw'],
    "avadāraka": ['mw'],
    "avadāraṇa": ['mw'],
    "avadāraṇaṃ": ['ap90'],
    "avadārita": ['mw'],
    "avadāta": ['ap90', 'cae', 'ddsa', 'mw'],
    "avadātaka": ['cped'],
    "avadātakeśā": ['bhs'],
    "avadātavasana": ['mw'],
    "avadāvada": ['ap90', 'cae', 'ddsa', 'mw'],
    "avadīp": ['mw'],
    "avadīrṇa": ['ap90', 'cae', 'mw'],
    "avadṛś": ['mw'],
    "avadṝ": ['ap90', 'mw'],
    "avaga": ['bhs'],
    "avagadha": ['mw'],
    "avagadita": ['mw'],
    "avagaditaḥ": ['ap90'],
    "avagai": ['ap90', 'mw'],
    "avagal": ['mw'],
    "avagalbh": ['mw'],
    "avagalita": ['mw'],
    "avagam": ['ap90', 'mw'],
    "avagama": ['cae', 'mw'],
    "avagamaka": ['cped', 'mw'],
    "avagamana": ['mw'],
    "avagamayitṛ": ['mw'],
    "avagamaḥ": ['ap90'],
    "avagamin": ['mw'],
    "avagamya": ['mw'],
    "avagantavya": ['ddsa', 'mw'],
    "avagantos": ['mw'],
    "avagarhita": ['mw'],
    "avagata": ['ap90', 'mw'],
    "avagatha": ['ap90', 'mw'],
    "avagati": ['ddsa', 'mw'],
    "avagatiḥ": ['ap90'],
    "avagaṃḍaḥ": ['ap90'],
    "avagaṇ": ['ap90', 'mw'],
    "avagaṇa": ['ap90', 'mw'],
    "avagaṇana": ['mw'],
    "avagaṇanaṃ": ['ap90'],
    "avagaṇita": ['mw'],
    "avagaṇḍa": ['mw'],
    "avagaṇḍakāraṁ": ['cped'],
    "avagharṣaṇa": ['mw'],
    "avagharṣaṇaṃ": ['ap90'],
    "avaghaṭarikā": ['mw'],
    "avaghaṭṭ": ['ap90', 'mw'],
    "avaghaṭṭa": ['mw'],
    "avaghaṭṭana": ['cped', 'mw'],
    "avaghaṭṭanaṃ": ['ap90'],
    "avaghaṭṭaḥ": ['ap90'],
    "avaghaṭṭita": ['mw'],
    "avaghoṣa": ['mw'],
    "avaghoṣaḥ": ['ap90'],
    "avaghoṣaṇa": ['bhs', 'mw'],
    "avaghoṣaṇā": ['mw'],
    "avaghoṭita": ['ap90', 'mw'],
    "avaghra": ['mw'],
    "avaghreya": ['mw'],
    "avaghrā": ['ap90', 'mw'],
    "avaghrāpaṇa": ['mw'],
    "avaghrāta": ['mw'],
    "avaghrāyam": ['mw'],
    "avaghrāṇa": ['mw'],
    "avaghrāṇaṃ": ['ap90'],
    "avaghuṣ": ['ap90', 'mw'],
    "avaghuṣita": ['mw'],
    "avaghuṣṭa": ['mw'],
    "avaghāta": ['mw'],
    "avaghātaḥ": ['ap90'],
    "avaghātin": ['ap90', 'mw'],
    "avaghūrṇ": ['ap90', 'mw'],
    "avaghūrṇa": ['mw'],
    "avaghūrṇanaṃ": ['ap90'],
    "avaghūrṇaḥ": ['ap90'],
    "avaghūrṇita": ['mw'],
    "avaghṛṣ": ['ap90', 'mw'],
    "avagoraṇa": ['mw'],
    "avagorya": ['mw'],
    "avagrah": ['ap90', 'mw'],
    "avagraha": ['cae', 'mw'],
    "avagrahaśaka": ['mw'],
    "avagrahaḥ": ['ap90'],
    "avagrahaṇa": ['bhs', 'mw'],
    "avagrahaṇaṃ": ['ap90'],
    "avagrahaṇī": ['mw'],
    "avagrahāntara": ['mw'],
    "avagrāha": ['mw'],
    "avagrāham": ['mw'],
    "avagrāhaḥ": ['ap90'],
    "avaguh": ['ap90', 'mw'],
    "avagur": ['ap90', 'mw'],
    "avaguraṇaṃ": ['ap90'],
    "avaguṃphita": ['ap90'],
    "avaguṃḍita": ['ap90'],
    "avaguṃṭh": ['ap90'],
    "avaguṃṭhanavat": ['ap90'],
    "avaguṃṭhanaṃ": ['ap90'],
    "avaguṃṭhikā": ['ap90'],
    "avaguṃṭhita": ['ap90'],
    "avaguṇa": ['mw'],
    "avaguṇaḥ": ['ap90'],
    "avaguṇḍita": ['mw'],
    "avaguṇṭh": ['mw'],
    "avaguṇṭhana": ['cae', 'mw'],
    "avaguṇṭhanavat": ['mw'],
    "avaguṇṭhikā": ['bhs', 'mw'],
    "avaguṇṭhita": ['mw'],
    "avaguṇṭhitamukha": ['mw'],
    "avagā": ['mw'],
    "avagādaḥ": ['ap90'],
    "avagāh": ['ap90', 'mw'],
    "avagāha": ['cae', 'cped', 'mw'],
    "avagāhana": ['mw'],
    "avagāhaḥ": ['ap90'],
    "avagāhita": ['mw'],
    "avagāhya": ['ap90'],
    "avagāḍha": ['ap90', 'cae', 'mw'],
    "avagāḍhavat": ['mw'],
    "avagāṇa": ['mw'],
    "avagīrṇa": ['mw'],
    "avagīta": ['ap90', 'bhs', 'mw'],
    "avagītha": ['mw'],
    "avagūhana": ['mw'],
    "avagūhanaṃ": ['ap90'],
    "avagūhayati": ['bhs'],
    "avagūraṇa": ['mw'],
    "avagūrṇa": ['mw'],
    "avagṛhya": ['ap90', 'mw'],
    "avagṛhīta": ['ap90'],
    "avagṝ": ['mw'],
    "avaha": ['ap90'],
    "avahan": ['ap90', 'mw'],
    "avahanana": ['cae', 'ddsa', 'mw'],
    "avahananaṃ": ['ap90'],
    "avahantṛ": ['mw'],
    "avaharamāna": ['cped'],
    "avaharati": ['cped'],
    "avaharaṇa": ['mw'],
    "avaharaṇacitta": ['cped'],
    "avaharaṇaṃ": ['ap90'],
    "avahari": ['cped'],
    "avaharituṁ": ['cped'],
    "avaharitvā": ['cped'],
    "avahariṁsu": ['cped'],
    "avaharuṁ": ['cped'],
    "avaharṣita": ['mw'],
    "avahas": ['ap90', 'mw'],
    "avahasana": ['mw'],
    "avahasta": ['mw'],
    "avahastaḥ": ['ap90'],
    "avahat": ['mw'],
    "avahata": ['mw'],
    "avahatiḥ": ['ap90'],
    "avahaṭa": ['cped'],
    "avahela": ['mw'],
    "avahelana": ['mw'],
    "avahelanaṃ": ['ap90'],
    "avahelayā": ['mw'],
    "avahelaḥ": ['ap90'],
    "avahelita": ['ap90', 'mw'],
    "avahita": ['ap90', 'cae', 'mw'],
    "avahitapāṇi": ['mw'],
    "avahitatā": ['mw'],
    "avahittha": ['mw'],
    "avahitthā": ['ap90', 'mw'],
    "avahitāñjali": ['mw'],
    "avahiyyati": ['cped'],
    "avahni": ['mw'],
    "avahoṭimaka": ['bhs'],
    "avahu": ['mw'],
    "avahvara": ['ap90', 'gra', 'mw'],
    "avahve": ['mw'],
    "avahā": ['ap90', 'mw'],
    "avahālikā": ['ap90', 'mw'],
    "avahāniḥ": ['ap90'],
    "avahāra": ['cped', 'mw'],
    "avahāraka": ['ap90', 'cped', 'mw'],
    "avahāraḥ": ['ap90'],
    "avahāri": ['cped'],
    "avahārika": ['mw'],
    "avahārya": ['ap90', 'cae', 'mw'],
    "avahāsa": ['cae', 'mw'],
    "avahāsaḥ": ['ap90'],
    "avahāsi": ['cped'],
    "avahāsya": ['ap90', 'mw'],
    "avahāsyatā": ['mw'],
    "avahīna": ['ap90'],
    "avahīyati": ['cped'],
    "avahṛ": ['ap90', 'mw'],
    "avahṛta": ['ap90', 'mw'],
    "avaibhīdaka": ['mw'],
    "avaidagdhya": ['ddsa'],
    "avaidha": ['ap90', 'mw'],
    "avaidhavya": ['mw'],
    "avaidika": ['mw'],
    "avaidya": ['ddsa', 'mw'],
    "avaikṛta": ['ddsa'],
    "avaimatyaṃ": ['ap90'],
    "avaira": ['bhs'],
    "avairahatya": ['mw'],
    "avairahatyaṃ": ['ap90'],
    "avairijuṣṭa": ['cae', 'ddsa'],
    "avaivarta": ['bhs'],
    "avaivartacaryā": ['bhs'],
    "avaivartavarṇa": ['bhs'],
    "avaivartika": ['bhs', 'mw'],
    "avaivartikacakra": ['bhs'],
    "avaivartikatva": ['mw'],
    "avaivartikatā": ['bhs'],
    "avaivartiya": ['bhs'],
    "avaivartya": ['bhs'],
    "avaiśāradya": ['mw'],
    "avaiṣamya": ['mw'],
    "avajaghnat": ['mw'],
    "avajaya": ['mw'],
    "avajayana": ['mw'],
    "avajayaḥ": ['ap90'],
    "avajhāyati": ['cped'],
    "avaji": ['ap90', 'mw'],
    "avajihva": ['mw'],
    "avajita": ['ap90', 'mw'],
    "avajiti": ['mw'],
    "avajitiḥ": ['ap90'],
    "avajja": ['cped'],
    "avajjhāyati": ['cped'],
    "avajuṣṭa": ['ap90'],
    "avajval": ['mw'],
    "avajvalana": ['mw'],
    "avajvāla": ['mw'],
    "avajyotana": ['mw'],
    "avajyotya": ['mw'],
    "avajyut": ['mw'],
    "avajñayā": ['mw'],
    "avajñeya": ['ap90', 'mw'],
    "avajñopahata": ['mw'],
    "avajñā": ['ap90', 'cae', 'mw'],
    "avajñāna": ['mw'],
    "avajñānaṃ": ['ap90'],
    "avajñāta": ['ap90', 'mw'],
    "avajānanta": ['cped'],
    "avajāneyya": ['cped'],
    "avajāni": ['cped'],
    "avajānitabba": ['cped'],
    "avajānitvā": ['cped'],
    "avajāniya": ['cped'],
    "avajānāti": ['cped'],
    "avajāta": ['bhs', 'cped', 'mw'],
    "avajīryati": ['bhs'],
    "avajīyati": ['cped'],
    "avajṛmbh": ['mw'],
    "avaka": ['mw'],
    "avakalana": ['mw'],
    "avakalita": ['ap90', 'mw'],
    "avakalkana": ['mw'],
    "avakalpanatā": ['bhs'],
    "avakalpanā": ['bhs'],
    "avakalpayati": ['bhs'],
    "avakalpita": ['ap90', 'mw'],
    "avakara": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "avakarakūṭa": ['mw'],
    "avakaraḥ": ['ap90'],
    "avakarta": ['cae', 'ddsa', 'mw'],
    "avakartana": ['cae', 'mw'],
    "avakartanaṃ": ['ap90'],
    "avakartaḥ": ['ap90'],
    "avakartin": ['ap90', 'mw'],
    "avakarttṛ": ['mw'],
    "avakarṇ": ['ap90'],
    "avakarṇanaṃ": ['ap90'],
    "avakarṇaya": ['ddsa', 'mw'],
    "avakarṣati": ['bhs'],
    "avakarṣaṇa": ['mw'],
    "avakarṣaṇaṃ": ['ap90'],
    "avakas": ['bhs'],
    "avakassati": ['cped'],
    "avakaḍḍhana": ['cped'],
    "avakaṅkhati": ['cped'],
    "avakaṭa": ['ap90', 'mw'],
    "avakaṭikā": ['ap90', 'mw'],
    "avakaṭṭati": ['bhs'],
    "avakeśa": ['ap90', 'mw'],
    "avakeśin": ['ap90', 'mw'],
    "avakhaṃḍ": ['ap90'],
    "avakhaṃḍanaṃ": ['ap90'],
    "avakhaṇḍ": ['mw'],
    "avakhaṇḍana": ['ddsa', 'mw'],
    "avakhyā": ['mw'],
    "avakhāda": ['cae', 'gra', 'mw'],
    "avakhādaḥ": ['ap90'],
    "avakhātaṃ": ['ap90'],
    "avakin": ['mw'],
    "avakiraṇa": ['mw'],
    "avakkanti": ['cped'],
    "avakkhitta": ['cped'],
    "avakkāra": ['cped'],
    "avakkārapāti": ['cped'],
    "avakleda": ['mw'],
    "avakledana": ['mw'],
    "avakledanaṃ": ['ap90'],
    "avakledaḥ": ['ap90'],
    "avaklinna": ['ap90'],
    "avaklinnapakva": ['mw'],
    "avakokila": ['ap90', 'mw'],
    "avakolba": ['mw'],
    "avakoṭa": ['bhs'],
    "avakoṭimaka": ['bhs'],
    "avakra": ['ap90', 'mw'],
    "avakracetas": ['cae'],
    "avakraga": ['ddsa'],
    "avakragamitā": ['mw'],
    "avakrakṣin": ['ap90', 'gra', 'mw'],
    "avakram": ['ap90', 'mw'],
    "avakramati": ['bhs'],
    "avakramaḥ": ['ap90'],
    "avakramaṇa": ['bhs', 'mw'],
    "avakrand": ['mw'],
    "avakranda": ['mw'],
    "avakrandana": ['mw'],
    "avakraya": ['cae', 'ddsa', 'mw'],
    "avakrayaḥ": ['ap90'],
    "avakraṃd": ['ap90'],
    "avakraṃda": ['ap90'],
    "avakraṃdanaṃ": ['ap90'],
    "avakriyā": ['ap90', 'mw'],
    "avakrośa": ['mw'],
    "avakrośaḥ": ['ap90'],
    "avakruś": ['ap90'],
    "avakruṣṭa": ['ap90', 'mw'],
    "avakrāma": ['bhs'],
    "avakrāmati": ['bhs'],
    "avakrāmin": ['ap90', 'mw'],
    "avakrāntaka": ['bhs'],
    "avakrānti": ['bhs', 'mw'],
    "avakrāntika": ['bhs'],
    "avakrāṃtiḥ": ['ap90'],
    "avakrī": ['ap90', 'mw'],
    "avakrīḍ": ['mw'],
    "avaktavya": ['ap90', 'mw'],
    "avaktra": ['ap90', 'mw'],
    "avaktṛ": ['mw'],
    "avakubja": ['bhs'],
    "avakujja": ['cped'],
    "avakujjapañña": ['cped'],
    "avakuts": ['ap90', 'mw'],
    "avakutsita": ['ap90', 'mw'],
    "avakuñcana": ['mw'],
    "avakuṃcanaṃ": ['ap90'],
    "avakuṃṭhanaṃ": ['ap90'],
    "avakuṃṭhita": ['ap90'],
    "avakuṇṭhana": ['mw'],
    "avakuṇṭhita": ['bhs', 'mw'],
    "avakuṣ": ['mw'],
    "avakuṭ": ['mw'],
    "avakuṭāra": ['ap90', 'mw'],
    "avakuṭārikā": ['mw'],
    "avakuṭṭita": ['ap90'],
    "avakvaṇa": ['mw'],
    "avakvaṇaḥ": ['ap90'],
    "avakvātha": ['mw'],
    "avakvāthaḥ": ['ap90'],
    "avakā": ['ap90', 'mw'],
    "avakāda": ['mw'],
    "avakāmasevā": ['bhs'],
    "avakāra": ['bhs'],
    "avakāsayati": ['bhs'],
    "avakāś": ['ap90', 'mw'],
    "avakāśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "avakāśada": ['cae', 'mw'],
    "avakāśati": ['bhs'],
    "avakāśavat": ['ap90', 'mw'],
    "avakāśaḥ": ['ap90'],
    "avakāśe": ['mw'],
    "avakāśena": ['mw'],
    "avakāśya": ['ap90', 'mw'],
    "avakāṅkṣ": ['mw'],
    "avakīlaka": ['mw'],
    "avakīrṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "avakīrṇajaṭābhāra": ['mw'],
    "avakīrṇakusuma": ['bhs'],
    "avakīrṇin": ['ap90', 'cae', 'ddsa', 'mw'],
    "avakīrṇivrata": ['cae'],
    "avakūj": ['mw'],
    "avakūl": ['mw'],
    "avakḷp": ['ap90', 'mw'],
    "avakḷpta": ['mw'],
    "avakḷpti": ['mw'],
    "avakḷptiḥ": ['ap90'],
    "avakṛ": ['mw'],
    "avakṛt": ['ap90', 'mw'],
    "avakṛta": ['mw'],
    "avakṛtta": ['mw'],
    "avakṛś": ['mw'],
    "avakṛṣ": ['ap90', 'mw'],
    "avakṛṣṭa": ['ap90', 'cae', 'mw'],
    "avakṛṣṭajāti": ['cae'],
    "avakṛṣṭatara": ['mw'],
    "avakṝ": ['ap90', 'mw'],
    "avakṣai": ['mw'],
    "avakṣapayati": ['bhs'],
    "avakṣar": ['mw'],
    "avakṣaya": ['mw'],
    "avakṣayaḥ": ['ap90'],
    "avakṣayaṇa": ['mw'],
    "avakṣayaṇaṃ": ['ap90'],
    "avakṣepa": ['cae', 'ddsa', 'mw'],
    "avakṣepaḥ": ['ap90'],
    "avakṣepaṇa": ['cae', 'mw'],
    "avakṣepaṇaṃ": ['ap90'],
    "avakṣepaṇī": ['mw'],
    "avakṣi": ['ap90', 'mw'],
    "avakṣip": ['ap90', 'mw'],
    "avakṣipta": ['ap90', 'bhs', 'mw'],
    "avakṣu": ['ap90'],
    "avakṣud": ['mw'],
    "avakṣuta": ['ap90', 'cae', 'mw'],
    "avakṣālana": ['mw'],
    "avakṣāma": ['mw'],
    "avakṣāmaḥ": ['ap90'],
    "avakṣāyam": ['mw'],
    "avakṣāṇa": ['cae', 'mw'],
    "avakṣīṇa": ['ap90', 'mw'],
    "avakṣṇu": ['mw'],
    "avalag": ['mw'],
    "avalagita": ['mw'],
    "avalagna": ['ap90', 'cae', 'ddsa', 'mw'],
    "avalakṣa": ['ap90', 'mw'],
    "avalakṣaṇa": ['bhs'],
    "avalamb": ['mw'],
    "avalamba": ['cae', 'ddsa', 'mw'],
    "avalambaka": ['bhs', 'mw'],
    "avalambana": ['cae', 'mw'],
    "avalambanā": ['bhs'],
    "avalambin": ['cae', 'mw'],
    "avalambita": ['cae', 'mw'],
    "avalambitavya": ['mw'],
    "avalambā": ['bhs'],
    "avalava": ['bhs'],
    "avalaṃb": ['ap90'],
    "avalaṃbakaḥ": ['ap90'],
    "avalaṃbanaṃ": ['ap90'],
    "avalaṃbaḥ": ['ap90'],
    "avalaṃbin": ['ap90'],
    "avalaṃbita": ['ap90'],
    "avalaṃbitavya": ['ap90'],
    "avalaṅgh": ['mw'],
    "avalaṅghita": ['mw'],
    "avaleha": ['mw'],
    "avalehaka": ['mw'],
    "avalehakam": ['bhs'],
    "avalehana": ['mw'],
    "avalehanaṃ": ['ap90'],
    "avalehaḥ": ['ap90'],
    "avalehikā": ['ap90', 'mw'],
    "avalehin": ['mw'],
    "avalekha": ['mw'],
    "avalekhana": ['mw'],
    "avalekhanakaṭṭha": ['cped'],
    "avalekhanapiṭhara": ['cped'],
    "avalekhanaṃ": ['ap90'],
    "avalekhanī": ['mw'],
    "avalekhati": ['cped'],
    "avalekhaḥ": ['ap90'],
    "avalekhitabba": ['cped'],
    "avalekhā": ['ap90', 'mw'],
    "avalepa": ['cae', 'mw'],
    "avalepana": ['mw'],
    "avalepanaṃ": ['ap90'],
    "avalepaḥ": ['ap90'],
    "avalguja": ['ap90', 'mw'],
    "avalgukārin": ['mw'],
    "avalgulī": ['ap90', 'mw'],
    "avalih": ['ap90', 'mw'],
    "avalikh": ['mw'],
    "avalikhati": ['cped'],
    "avalip": ['ap90', 'mw'],
    "avalipsa": ['mw'],
    "avalipta": ['ap90', 'cae', 'ddsa', 'mw'],
    "avaliptatva": ['mw'],
    "avaliptatā": ['mw'],
    "avalita": ['mw'],
    "avalitta": ['cped'],
    "avalka": ['mw'],
    "avalobhana": ['mw'],
    "avalobhanaṃ": ['ap90'],
    "avalok": ['ap90', 'mw'],
    "avaloka": ['cae', 'ddsa', 'mw'],
    "avalokaka": ['ap90', 'mw'],
    "avalokana": ['mw'],
    "avalokanaka": ['bhs', 'mw'],
    "avalokanasūtra": ['bhs'],
    "avalokanaṃ": ['ap90'],
    "avalokanīya": ['bhs', 'mw'],
    "avalokayamāna": ['cped'],
    "avalokayati": ['bhs', 'cped'],
    "avalokayitavya": ['mw'],
    "avalokayitṛ": ['ap90', 'cae', 'mw'],
    "avalokaḥ": ['ap90'],
    "avalokenta": ['cped'],
    "avaloketi": ['cped'],
    "avalokeṣu": ['mw'],
    "avalokin": ['ap90', 'cae', 'mw'],
    "avalokita": ['ap90', 'bhs', 'mw'],
    "avalokitalakṣmī": ['bhs'],
    "avalokitamūrdhitā": ['bhs'],
    "avalokitanetra": ['bhs'],
    "avalokitavrata": ['mw'],
    "avalokiteśvara": ['bhs', 'mw'],
    "avalokiteśvaravimokṣa": ['bhs'],
    "avalokitā": ['cae', 'mw'],
    "avalokya": ['mw'],
    "avaloma": ['ap90', 'mw'],
    "avalopa": ['mw'],
    "avalopana": ['mw'],
    "avalopaḥ": ['ap90'],
    "avalopya": ['ap90', 'mw'],
    "avalumpana": ['mw'],
    "avalup": ['ap90', 'mw'],
    "avalupta": ['bhs'],
    "avalupti": ['mw'],
    "avaluñc": ['mw'],
    "avaluñcana": ['mw'],
    "avaluṃc": ['ap90'],
    "avaluṃcanaṃ": ['ap90'],
    "avaluṃpanaṃ": ['ap90'],
    "avaluṃṭhanaṃ": ['ap90'],
    "avaluṇṭhana": ['mw'],
    "avaluṇṭhita": ['mw'],
    "avalī": ['ap90', 'mw'],
    "avalīlayā": ['mw'],
    "avalīlā": ['ap90', 'mw'],
    "avalīna": ['ap90', 'bhs', 'cae', 'mw'],
    "avalīyana": ['bhs'],
    "avalīyate": ['bhs'],
    "avalīyati": ['bhs'],
    "avalīḍha": ['ap90', 'mw'],
    "avalīḍhā": ['mw'],
    "avalūna": ['mw'],
    "avama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avamajj": ['mw'],
    "avaman": ['ap90', 'mw'],
    "avamantavya": ['mw'],
    "avamantha": ['mw'],
    "avamanthaka": ['mw'],
    "avamantṛ": ['cae', 'mw'],
    "avamanya": ['mw'],
    "avamanyaka": ['cae', 'mw'],
    "avamanyanatā": ['bhs'],
    "avamanyanā": ['bhs'],
    "avamarda": ['mw'],
    "avamardana": ['ap90', 'mw'],
    "avamardaḥ": ['ap90'],
    "avamardita": ['mw'],
    "avamarditacittam": ['bhs'],
    "avamarśa": ['cae', 'mw'],
    "avamarśam": ['mw'],
    "avamarśaḥ": ['ap90'],
    "avamarśita": ['mw'],
    "avamarṣaḥ": ['ap90'],
    "avamarṣaṇaṃ": ['ap90'],
    "avamata": ['ap90', 'cped', 'mw'],
    "avamath": ['mw'],
    "avamati": ['mw'],
    "avamatiḥ": ['ap90'],
    "avamatya": ['mw'],
    "avamatāṅkuśa": ['mw'],
    "avamaññatha": ['cped'],
    "avamaṃtavya": ['ap90'],
    "avamaṃtha": ['ap90'],
    "avamaṃtṛ": ['ap90'],
    "avamehana": ['mw'],
    "avamehanīya": ['mw'],
    "avamih": ['mw'],
    "avamocana": ['mw'],
    "avamocanaṃ": ['ap90'],
    "avamohana": ['mw'],
    "avamuc": ['ap90', 'mw'],
    "avamuṣ": ['mw'],
    "avamā": ['mw'],
    "avamāna": ['cae', 'mw'],
    "avamānana": ['mw'],
    "avamānanaṃ": ['ap90'],
    "avamānanīya": ['mw'],
    "avamānatā": ['mw'],
    "avamānaḥ": ['ap90'],
    "avamānin": ['ap90', 'cae', 'mw'],
    "avamānita": ['mw'],
    "avamānitva": ['mw'],
    "avamānitā": ['mw'],
    "avamānya": ['mw'],
    "avamārjana": ['gra', 'mw'],
    "avamārjanaṃ": ['ap90'],
    "avamūrch": ['mw'],
    "avamūrdha": ['bhs'],
    "avamūrdhaka": ['bhs', 'mw'],
    "avamūrdhan": ['ap90'],
    "avamūrdhaśaya": ['mw'],
    "avamūtr": ['mw'],
    "avamūtraṇa": ['mw'],
    "avamūtrita": ['mw'],
    "avamṛd": ['ap90', 'mw'],
    "avamṛj": ['ap90', 'mw'],
    "avamṛś": ['ap90', 'mw'],
    "avamṛśya": ['mw'],
    "avana": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "avanaddha": ['ap90', 'mw'],
    "avanah": ['ap90', 'mw'],
    "avanakṣ": ['mw'],
    "avanakṣatra": ['mw'],
    "avanakṣatraṃ": ['ap90'],
    "avanam": ['ap90', 'mw'],
    "avanamana": ['bhs'],
    "avanamra": ['ap90', 'mw'],
    "avanard": ['mw'],
    "avanata": ['ap90', 'cae', 'mw'],
    "avanatakaya": ['mw'],
    "avanatakāya": ['ddsa'],
    "avanatamukha": ['mw'],
    "avanataśīrṣan": ['mw'],
    "avanati": ['cae', 'ddsa', 'mw'],
    "avanatiḥ": ['ap90'],
    "avanatottarakāya": ['mw'],
    "avanatā": ['bhs'],
    "avanatānana": ['mw'],
    "avanaya": ['mw'],
    "avanayana": ['mw'],
    "avanayanaṃ": ['ap90'],
    "avanayaḥ": ['ap90'],
    "avanaś": ['mw'],
    "avanaṃ": ['ap90'],
    "avandhya": ['cae', 'ddsa', 'mw'],
    "avanega": ['mw'],
    "avanegya": ['cae', 'ddsa', 'mw'],
    "avaneja": ['mw'],
    "avanejana": ['cae', 'ddsa', 'mw'],
    "avanejanaṃ": ['ap90'],
    "avanejya": ['ap90', 'mw'],
    "avanektṛ": ['mw'],
    "avaneya": ['mw'],
    "avani": ['cae', 'ddsa', 'gra', 'mw'],
    "avanibhṛt": ['mw'],
    "avanicara": ['mw'],
    "avanij": ['ap90', 'mw'],
    "avanija": ['mw'],
    "avanikta": ['ap90', 'mw'],
    "avanimaṇḍala": ['mw'],
    "avaninī": ['mw'],
    "avanipa": ['cae', 'mw'],
    "avanipati": ['cae', 'mw'],
    "avanipāla": ['cae', 'mw'],
    "avanipālaka": ['mw'],
    "avanipātam": ['ddsa'],
    "avaniruh": ['mw'],
    "avaniruha": ['ddsa', 'mw'],
    "avanisuta": ['mw'],
    "avaniścaya": ['mw'],
    "avaniścayaḥ": ['ap90'],
    "avaniḥ": ['ap90'],
    "avaniḥsaraṇa": ['mw'],
    "avaniṃgata": ['mw'],
    "avaniṣṭhiv": ['mw'],
    "avaniṣṭhīvana": ['mw'],
    "avaniṣṭhīvanaṃ": ['ap90'],
    "avant": ['cae'],
    "avantaka": ['bhs', 'mw'],
    "avanti": ['cae', 'ddsa', 'mw'],
    "avantibhūpāla": ['mw'],
    "avantibrahma": ['mw'],
    "avantideva": ['mw'],
    "avantikhaṇḍa": ['mw'],
    "avantikā": ['mw'],
    "avantimihira": ['mw'],
    "avantinagarī": ['mw'],
    "avantipura": ['mw'],
    "avantipurī": ['mw'],
    "avantisena": ['mw'],
    "avantisoma": ['mw'],
    "avantisvāmin": ['mw'],
    "avantivardhana": ['mw'],
    "avantivarman": ['mw'],
    "avantivatī": ['mw'],
    "avantyaśmaka": ['mw'],
    "avantī": ['cae', 'ddsa', 'mw'],
    "avantīdeśa": ['mw'],
    "avantīnagara": ['mw'],
    "avantīsaras": ['mw'],
    "avantīsundarī": ['mw'],
    "avantīśvara": ['mw'],
    "avanu": ['mw'],
    "avanādayati": ['bhs'],
    "avanāha": ['bhs', 'mw'],
    "avanāhaḥ": ['ap90'],
    "avanāma": ['bhs', 'mw'],
    "avanāmaka": ['ap90', 'mw'],
    "avanāmana": ['bhs'],
    "avanāmaḥ": ['ap90'],
    "avanāmin": ['ap90', 'mw'],
    "avanāmita": ['mw'],
    "avanāya": ['mw'],
    "avanāyaka": ['ap90'],
    "avanāyaḥ": ['ap90'],
    "avanāṭa": ['ap90', 'mw'],
    "avanāṭanāsika": ['mw'],
    "avanī": ['ap90', 'ddsa', 'mw'],
    "avanībhṛt": ['mw'],
    "avanīdhara": ['mw'],
    "avanīdhra": ['mw'],
    "avanīmukha": ['mw'],
    "avanīpati": ['mw'],
    "avanīpāla": ['mw'],
    "avanīta": ['mw'],
    "avanīya": ['mw'],
    "avanīyamāna": ['mw'],
    "avanīśa": ['mw'],
    "avanīśvara": ['mw'],
    "avapad": ['ap90', 'mw'],
    "avapakassati": ['cped'],
    "avapakāsati": ['cped'],
    "avapana": ['mw'],
    "avapanna": ['ap90', 'cae', 'mw'],
    "avapat": ['ap90', 'mw'],
    "avapatana": ['mw'],
    "avapatanaṃ": ['ap90'],
    "avapatita": ['cae', 'cped', 'mw'],
    "avapaś": ['mw'],
    "avapaṭ": ['ap90', 'mw'],
    "avaphaḥ": ['ap90'],
    "avapiṇḍita": ['mw'],
    "avapiṣ": ['mw'],
    "avaplu": ['mw'],
    "avapluta": ['mw'],
    "avaplutya": ['mw'],
    "avapothikā": ['mw'],
    "avapothita": ['mw'],
    "avaprajjana": ['mw'],
    "avaprajjanaḥ": ['ap90'],
    "avaprasnuta": ['mw'],
    "avaprasruta": ['mw'],
    "avapravrajati": ['bhs'],
    "avapunati": ['bhs'],
    "avapura": ['bhs'],
    "avapus": ['mw'],
    "avaputh": ['mw'],
    "avapuñjita": ['mw'],
    "avapāda": ['mw'],
    "avapādaḥ": ['ap90'],
    "avapāka": ['ap90', 'mw'],
    "avapālita": ['ap90'],
    "avapāna": ['cae', 'gra', 'mw'],
    "avapāta": ['cae', 'ddsa', 'mw'],
    "avapātam": ['mw'],
    "avapātana": ['cae', 'mw'],
    "avapātanaṃ": ['ap90'],
    "avapātaḥ": ['ap90'],
    "avapātra": ['ap90'],
    "avapātrita": ['ap90', 'mw'],
    "avapāśita": ['ap90', 'mw'],
    "avapāṭana": ['bhs'],
    "avapāṭikā": ['ap90', 'mw'],
    "avapīḍ": ['ap90', 'mw'],
    "avapīḍa": ['ap90', 'mw'],
    "avapīḍaka": ['mw'],
    "avapīḍana": ['mw'],
    "avapīḍanaṃ": ['ap90'],
    "avapīḍanā": ['mw'],
    "avapīḍita": ['mw'],
    "avapūraṇa": ['mw'],
    "avapūrṇa": ['ap90', 'mw'],
    "avapṛcchati": ['bhs'],
    "avapṛgna": ['gra'],
    "avapṛṣṭhībhūta": ['mw'],
    "avapṛṣṭhīkṛta": ['bhs', 'mw'],
    "avara": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "avarabhāgīya": ['bhs'],
    "avaragodānīya": ['bhs'],
    "avarahasa": ['ap90'],
    "avaraja": ['cae', 'mw'],
    "avarajjhati": ['cped'],
    "avarajā": ['mw'],
    "avaraka": ['bhs'],
    "avarakaṅkā": ['mw'],
    "avaram": ['ap90'],
    "avaramb": ['mw'],
    "avarapara": ['mw'],
    "avaraparam": ['mw'],
    "avarapure": ['cped'],
    "avarapuruṣa": ['mw'],
    "avaraspara": ['mw'],
    "avarastāt": ['ap90', 'mw'],
    "avarata": ['ap90', 'mw'],
    "avaratara": ['mw'],
    "avaratas": ['mw'],
    "avarataḥ": ['ap90'],
    "avarati": ['mw'],
    "avaratiḥ": ['ap90'],
    "avaravarṇa": ['cae', 'mw'],
    "avaravarṇaja": ['mw'],
    "avaravayas": ['mw'],
    "avaravrata": ['mw'],
    "avaraśaila": ['mw'],
    "avaraṅgasāha": ['mw'],
    "avarcas": ['ap90', 'ddsa', 'mw'],
    "avardhamāna": ['ddsa', 'mw'],
    "avareṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "avarga": ['ap90'],
    "avariph": ['mw'],
    "avarjanīya": ['mw'],
    "avarjanīyatva": ['mw'],
    "avarjanīyatā": ['mw'],
    "avarjivas": ['ap90'],
    "avarjuṣī": ['mw'],
    "avarman": ['mw'],
    "avarocaka": ['mw'],
    "avarocakaḥ": ['ap90'],
    "avarodha": ['cae', 'ddsa', 'mw'],
    "avarodhaka": ['ap90', 'mw'],
    "avarodhana": ['cae', 'gra', 'mw'],
    "avarodhanaṃ": ['ap90'],
    "avarodhaḥ": ['ap90'],
    "avarodhika": ['ap90', 'mw'],
    "avarodhikā": ['mw'],
    "avarodhin": ['ap90', 'mw'],
    "avarodhāyana": ['mw'],
    "avaroha": ['cae', 'mw'],
    "avarohaka": ['mw'],
    "avarohavat": ['mw'],
    "avarohaśākhin": ['mw'],
    "avarohaḥ": ['ap90'],
    "avarohaṇa": ['cae', 'mw'],
    "avarohaṇaṃ": ['ap90'],
    "avarohikā": ['ap90', 'mw'],
    "avarohin": ['ap90', 'cae', 'mw'],
    "avarohita": ['ap90', 'mw'],
    "avarohitīya": ['mw'],
    "avarokin": ['ap90', 'mw'],
    "avarokta": ['mw'],
    "avaropanarāja": ['bhs'],
    "avaropayati": ['bhs'],
    "avaropaṇa": ['bhs', 'mw'],
    "avaropaṇaṃ": ['ap90'],
    "avaropita": ['ap90', 'mw'],
    "avaropya": ['mw'],
    "avartamāna": ['cae', 'ddsa', 'mw'],
    "avartana": ['ap90'],
    "avarti": ['cae', 'ddsa', 'gra', 'mw'],
    "avartin": ['mw'],
    "avartiḥ": ['ap90'],
    "avartra": ['ap90', 'cae', 'gra', 'mw'],
    "avaruc": ['mw'],
    "avaruddha": ['ap90', 'cae', 'cped', 'mw'],
    "avaruddhadeha": ['mw'],
    "avaruddhi": ['mw'],
    "avaruddhikā": ['mw'],
    "avaruddhiḥ": ['ap90'],
    "avarudh": ['ap90', 'mw'],
    "avarudham": ['mw'],
    "avarudhyamāna": ['mw'],
    "avarudita": ['mw'],
    "avarugṇa": ['ap90', 'mw'],
    "avaruh": ['ap90', 'mw'],
    "avaruj": ['mw'],
    "avarundham": ['mw'],
    "avarupta": ['bhs'],
    "avaruṇam": ['mw'],
    "avaruṇya": ['mw'],
    "avaruṇḍa": ['bhs'],
    "avarya": ['mw'],
    "avaryati": ['ap90'],
    "avarā": ['mw'],
    "avarādh": ['mw'],
    "avarārdha": ['mw'],
    "avarārdham": ['mw'],
    "avarārdhatas": ['mw'],
    "avarārdhya": ['mw'],
    "avarāvapatana": ['mw'],
    "avarāvara": ['mw'],
    "avarīyas": ['mw'],
    "avarīṇa": ['ap90', 'mw'],
    "avarūpa": ['ap90', 'mw'],
    "avarūḍha": ['ap90', 'cae', 'mw'],
    "avarṇa": ['ap90', 'bhs', 'ddsa', 'mw'],
    "avarṇakāraka": ['mw'],
    "avarṇasaṃyoga": ['mw'],
    "avarṇavāda": ['mw'],
    "avarṇya": ['mw'],
    "avarṇyasama": ['mw'],
    "avarṣa": ['cae', 'ddsa', 'mw'],
    "avarṣatarkye": ['mw'],
    "avarṣaḥ": ['ap90'],
    "avarṣaṇa": ['cae', 'mw'],
    "avarṣin": ['mw'],
    "avarṣuka": ['ap90', 'mw'],
    "avarṣya": ['ap90', 'mw'],
    "avarṣā": ['mw'],
    "avarṣṭos": ['ddsa', 'mw'],
    "avas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avasa": ['cae', 'gra', 'mw'],
    "avasabha": ['ap90', 'mw'],
    "avasad": ['ap90', 'mw'],
    "avasai": ['mw'],
    "avasajjanaṃ": ['ap90'],
    "avasajjetvā": ['cped'],
    "avasakkati": ['bhs'],
    "avasakta": ['ap90', 'ddsa', 'mw'],
    "avasakthikā": ['ap90', 'cae', 'mw'],
    "avasalavi": ['mw'],
    "avasanna": ['ap90', 'bhs', 'cae', 'mw'],
    "avasannatā": ['ap90'],
    "avasara": ['cae', 'mw'],
    "avasarakāle": ['mw'],
    "avasarapāṭhaka": ['mw'],
    "avasarati": ['bhs', 'cped'],
    "avasaravelāyām": ['mw'],
    "avasaraḥ": ['ap90'],
    "avasaraṇaṃ": ['ap90'],
    "avasare": ['mw'],
    "avasarga": ['mw'],
    "avasargaḥ": ['ap90'],
    "avasari": ['cped'],
    "avasariṁ": ['cped'],
    "avasarjana": ['mw'],
    "avasarjanaṃ": ['ap90'],
    "avasarjita": ['mw'],
    "avasarpa": ['mw'],
    "avasarpaḥ": ['ap90'],
    "avasarpaṇa": ['cae', 'mw'],
    "avasarpaṇaṃ": ['ap90'],
    "avasarpin": ['ap90'],
    "avasarpita": ['mw'],
    "avasarpiṇī": ['mw'],
    "avasatha": ['mw'],
    "avasathaḥ": ['ap90'],
    "avasathin": ['mw'],
    "avasathya": ['mw'],
    "avasathyaḥ": ['ap90'],
    "avasavi": ['mw'],
    "avasavya": ['ap90', 'bhs', 'mw'],
    "avasañj": ['mw'],
    "avasañjana": ['mw'],
    "avasaḥ": ['ap90'],
    "avasaṃcakṣya": ['mw'],
    "avasaṃj": ['ap90'],
    "avasaṃjanaṃ": ['ap90'],
    "avasaṃḍīna": ['mw'],
    "avasaṃḍīnaṃ": ['ap90'],
    "avasaṭa": ['cped'],
    "avasecana": ['cae', 'mw'],
    "avasecanaṃ": ['ap90'],
    "avasecita": ['mw'],
    "avaseka": ['cae', 'mw'],
    "avasekaḥ": ['ap90'],
    "avasekima": ['mw'],
    "avasekimaḥ": ['ap90'],
    "avasesa": ['cped'],
    "avasevitavant": ['bhs'],
    "avaseya": ['ap90', 'mw'],
    "avasic": ['ap90', 'mw'],
    "avasidh": ['mw'],
    "avasikta": ['ap90', 'mw'],
    "avasirati": ['bhs'],
    "avasissati": ['cped'],
    "avasissi": ['cped'],
    "avasissiṁsu": ['cped'],
    "avasita": ['ap90', 'cae', 'gra', 'mw'],
    "avasitakārya": ['cae', 'mw'],
    "avasitamaṇḍana": ['cae', 'mw'],
    "avasiti": ['mw'],
    "avasitārtha": ['mw'],
    "avasiñcita": ['mw'],
    "avasiṭṭha": ['cped'],
    "avaskand": ['mw'],
    "avaskanda": ['cae', 'ddsa', 'mw'],
    "avaskandana": ['mw'],
    "avaskandanā": ['bhs'],
    "avaskandin": ['mw'],
    "avaskandita": ['mw'],
    "avaskanna": ['mw'],
    "avaskara": ['mw'],
    "avaskaraka": ['ap90', 'mw'],
    "avaskaramandira": ['mw'],
    "avaskaraḥ": ['ap90'],
    "avaskava": ['ap90', 'mw'],
    "avaskaṃd": ['ap90'],
    "avaskaṃdaḥ": ['ap90'],
    "avaskaṃdin": ['ap90'],
    "avaskaṃdita": ['ap90'],
    "avaskhalita": ['bhs'],
    "avaskṝ": ['ap90', 'mw'],
    "avasmi": ['mw'],
    "avasnā": ['mw'],
    "avasnāta": ['mw'],
    "avaso": ['ap90', 'mw'],
    "avaspartṛ": ['ap90', 'cae', 'gra', 'mw'],
    "avasphaṇḍaka": ['bhs'],
    "avasphaṇḍana": ['bhs'],
    "avasphaṇḍayati": ['bhs'],
    "avasphoṭana": ['bhs', 'ddsa', 'mw'],
    "avasphoṭaḥ": ['ap90'],
    "avasphur": ['mw'],
    "avasphūrj": ['mw'],
    "avasphūrja": ['mw'],
    "avasphūrjathu": ['mw'],
    "avasphūrjitaṃ": ['ap90'],
    "avaspṛ": ['mw'],
    "avasras": ['ap90', 'gra'],
    "avasrasas": ['mw'],
    "avasrasta": ['mw'],
    "avasraṃs": ['mw'],
    "avasraṃsana": ['mw'],
    "avasraṃsanaṃ": ['ap90'],
    "avasraṃsita": ['ap90'],
    "avasru": ['mw'],
    "avasruta": ['bhs', 'cae', 'mw'],
    "avassajiṁ": ['cped'],
    "avassajjetvā": ['cped'],
    "avassajī": ['cped'],
    "avassuta": ['cped'],
    "avastabdha": ['bhs', 'mw'],
    "avastaraṇa": ['mw'],
    "avastaraṇaṃ": ['ap90'],
    "avastha": ['cae', 'ddsa', 'mw'],
    "avasthaḥ": ['ap90'],
    "avasthita": ['ap90', 'cae', 'mw'],
    "avasthiti": ['cae', 'mw'],
    "avasthitiḥ": ['ap90'],
    "avasthā": ['ap90', 'ddsa', 'gra', 'mw'],
    "avasthācatuṣṭaya": ['mw'],
    "avasthādvaya": ['mw'],
    "avasthāna": ['cae', 'mw'],
    "avasthānaṃ": ['ap90'],
    "avasthāntara": ['cae'],
    "avasthāpana": ['mw'],
    "avasthāpanaṃ": ['ap90'],
    "avasthātavya": ['mw'],
    "avasthātraya": ['mw'],
    "avasthāvan": ['mw'],
    "avasthāyin": ['ap90', 'mw'],
    "avastra": ['ap90', 'cae', 'ddsa', 'mw'],
    "avastratā": ['mw'],
    "avastu": ['ap90', 'cae', 'ddsa', 'mw'],
    "avastutva": ['mw'],
    "avastutā": ['mw'],
    "avastāra": ['mw'],
    "avastāraḥ": ['ap90'],
    "avastāt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avastātprapadana": ['mw'],
    "avastīrṇa": ['mw'],
    "avastṝ": ['ap90', 'mw'],
    "avasupta": ['ap90', 'cae', 'mw'],
    "avasuṣirā": ['mw'],
    "avasvadvat": ['mw'],
    "avasvan": ['ap90', 'mw'],
    "avasvant": ['cae'],
    "avasvanya": ['ap90', 'mw'],
    "avasvapati": ['bhs'],
    "avasvat": ['ap90', 'mw'],
    "avasvāpana": ['bhs'],
    "avasvāpanikā": ['mw'],
    "avasvāpanī": ['mw'],
    "avasvāpayati": ['bhs'],
    "avasvṛ": ['mw'],
    "avasy": ['gra'],
    "avasya": ['mw'],
    "avasyand": ['mw'],
    "avasyandana": ['bhs', 'mw'],
    "avasyandita": ['mw'],
    "avasyant": ['cae'],
    "avasyati": ['ap90'],
    "avasyaṃdanaṃ": ['ap90'],
    "avasyu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avasā": ['ap90', 'cae', 'gra', 'mw'],
    "avasāda": ['bhs', 'cae', 'mw'],
    "avasādaka": ['ap90', 'mw'],
    "avasādana": ['bhs', 'mw'],
    "avasādanaṃ": ['ap90'],
    "avasādanikā": ['bhs'],
    "avasādanā": ['mw'],
    "avasādanāvineya": ['mw'],
    "avasādayati": ['bhs', 'cped'],
    "avasādaḥ": ['ap90'],
    "avasādeti": ['cped'],
    "avasādin": ['ap90'],
    "avasādita": ['mw'],
    "avasāma": ['mw'],
    "avasāmaṃ": ['ap90'],
    "avasāna": ['cae', 'gra', 'mw'],
    "avasānabhūmi": ['mw'],
    "avasānadarśa": ['mw'],
    "avasānaka": ['ap90', 'mw'],
    "avasānaṃ": ['ap90'],
    "avasānika": ['mw'],
    "avasānya": ['ap90', 'mw'],
    "avasāraṇa": ['bhs', 'mw'],
    "avasāraṇā": ['mw'],
    "avasātṛ": ['ap90', 'cae', 'gra', 'mw'],
    "avasāya": ['cae', 'mw'],
    "avasāyaka": ['mw'],
    "avasāyaḥ": ['ap90'],
    "avasāyi": ['cped'],
    "avasāyin": ['ap90', 'cped', 'mw'],
    "avasāyya": ['mw'],
    "avasṛ": ['ap90', 'mw'],
    "avasṛj": ['ap90', 'mw'],
    "avasṛjana": ['bhs'],
    "avasṛp": ['mw'],
    "avasṛṣṭa": ['ap90', 'mw'],
    "avat": ['ddsa', 'mw'],
    "avata": ['cae', 'ddsa', 'gra', 'mw'],
    "avatakṣaṇa": ['mw'],
    "avatakṣaṇaṃ": ['ap90'],
    "avatamasa": ['ddsa', 'mw'],
    "avatamasaṃ": ['ap90'],
    "avatan": ['ap90', 'mw'],
    "avatap": ['ap90', 'mw'],
    "avatapta": ['ap90', 'mw'],
    "avataptenakulasthita": ['mw'],
    "avatara": ['mw'],
    "avataram": ['cae', 'gra', 'mw'],
    "avatarati": ['bhs'],
    "avataraḥ": ['ap90'],
    "avataraṃ": ['ap90'],
    "avataraṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "avataraṇamaṅgala": ['mw'],
    "avataraṇaṃ": ['ap90'],
    "avataraṇikā": ['ap90', 'mw'],
    "avataraṇī": ['ap90'],
    "avatarda": ['mw'],
    "avataritavya": ['mw'],
    "avatarpaṇa": ['mw'],
    "avatarpaṇaṃ": ['ap90'],
    "avatas": ['ap90'],
    "avatata": ['ap90', 'mw'],
    "avatatadhanvan": ['mw'],
    "avatati": ['mw'],
    "avatatiḥ": ['ap90'],
    "avataḍ": ['ap90', 'mw'],
    "avataḥ": ['ap90'],
    "avataṃsa": ['cae', 'ddsa', 'mw'],
    "avataṃsaka": ['bhs', 'cae', 'mw'],
    "avataṃsakaḥ": ['ap90'],
    "avataṃsana": ['mw'],
    "avataṃsanīya": ['cae'],
    "avataṃsay": ['cae'],
    "avataṃsaya": ['ddsa'],
    "avataṃsayati": ['ap90'],
    "avataṃsaḥ": ['ap90'],
    "avataṃsinī": ['cae', 'ddsa'],
    "avataṃsita": ['ap90', 'mw'],
    "avataṃsīkṛ": ['ddsa', 'mw'],
    "avatitīrṣu": ['mw'],
    "avatiṭṭhati": ['cped'],
    "avatka": ['mw'],
    "avatokā": ['ap90', 'mw'],
    "avatrasta": ['ap90', 'mw'],
    "avatrāpin": ['bhs'],
    "avatsala": ['cae', 'mw'],
    "avatsar": ['mw'],
    "avatsā": ['ddsa', 'mw'],
    "avatsāra": ['gra', 'mw'],
    "avatsīya": ['ap90', 'mw'],
    "avatta": ['ap90', 'cae', 'ddsa', 'mw'],
    "avattaram": ['mw'],
    "avatthasi": ['cped'],
    "avatthita": ['cped'],
    "avattin": ['ap90', 'ddsa', 'mw'],
    "avatunna": ['mw'],
    "avatviṣ": ['mw'],
    "avatāna": ['mw'],
    "avatānaḥ": ['ap90'],
    "avatānta": ['cae', 'mw'],
    "avatāpin": ['ap90', 'mw'],
    "avatāra": ['bhs', 'cae', 'mw'],
    "avatāradvādaśakīrtana": ['mw'],
    "avatāraka": ['ap90', 'bhs', 'mw'],
    "avatārakathā": ['mw'],
    "avatāramantra": ['mw'],
    "avatāraprekṣin": ['bhs', 'mw'],
    "avatāravādāvalī": ['mw'],
    "avatārayati": ['bhs'],
    "avatāraḥ": ['ap90'],
    "avatāraṇa": ['bhs', 'mw'],
    "avatāraṇaṃ": ['ap90'],
    "avatārin": ['ap90', 'mw'],
    "avatārita": ['mw'],
    "avatāḍana": ['cae', 'mw'],
    "avatāḍanaṃ": ['ap90'],
    "avatīrṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "avatīrṇarṇa": ['mw'],
    "avatūlaya": ['mw'],
    "avatūlayati": ['ap90'],
    "avatṛd": ['mw'],
    "avatṛṇṇa": ['mw'],
    "avatṝ": ['ap90', 'mw'],
    "avavad": ['mw'],
    "avavadana": ['mw'],
    "avavadati": ['bhs'],
    "avavadaḥ": ['ap90'],
    "avavadita": ['mw'],
    "avavaditṛ": ['ap90', 'mw'],
    "avavahati": ['bhs'],
    "avavaraka": ['bhs'],
    "avavarakaḥ": ['ap90'],
    "avavarti": ['mw'],
    "avavarṣaṇa": ['mw'],
    "avavarṣaṇaṃ": ['ap90'],
    "avavicārād": ['bhs'],
    "avaviddha": ['ap90', 'mw'],
    "avavidhyana": ['bhs'],
    "avavisraṃsita": ['mw'],
    "avavraśc": ['ap90', 'mw'],
    "avavraśca": ['mw'],
    "avavraścaḥ": ['ap90'],
    "avavyadh": ['mw'],
    "avavye": ['mw'],
    "avavā": ['mw'],
    "avavāda": ['bhs', 'ddsa', 'mw'],
    "avavādaka": ['bhs', 'mw'],
    "avavādati": ['bhs'],
    "avavādaḥ": ['ap90'],
    "avavāditar": ['bhs'],
    "avavāyati": ['bhs'],
    "avavī": ['mw'],
    "avavṛj": ['mw'],
    "avavṛṣ": ['mw'],
    "avavṛṣṭa": ['mw'],
    "avaya": ['gra', 'mw'],
    "avayaj": ['ap90', 'mw'],
    "avayajana": ['mw'],
    "avayajanaṃ": ['ap90'],
    "avayava": ['cae', 'ddsa', 'mw'],
    "avayavadharma": ['cae', 'mw'],
    "avayavarūpaka": ['cae', 'mw'],
    "avayavavirūpaka": ['cae'],
    "avayavaśas": ['mw'],
    "avayavaśaḥ": ['ap90'],
    "avayavaḥ": ['ap90'],
    "avayavin": ['ap90', 'mw'],
    "avayavirūpaka": ['mw'],
    "avayavārtha": ['mw'],
    "avayu": ['mw'],
    "avayuna": ['ap90', 'gra', 'mw'],
    "avayuti": ['mw'],
    "avayutyā": ['mw'],
    "avayā": ['ap90', 'mw'],
    "avayāj": ['ap90', 'gra', 'mw'],
    "avayāna": ['bhs', 'gra', 'mw'],
    "avayānaṃ": ['ap90'],
    "avayāsa": ['mw'],
    "avayāta": ['mw'],
    "avayātahel̤as": ['cae', 'mw'],
    "avayātaheḍas": ['gra'],
    "avayātṛ": ['ap90', 'gra', 'mw'],
    "avañcaka": ['cae'],
    "avañcanatā": ['ddsa', 'mw'],
    "avaññāta": ['cped'],
    "avañāta": ['cped'],
    "avaśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "avaśaga": ['cae', 'mw'],
    "avaśaka": ['cae'],
    "avaśakthikā": ['ap90'],
    "avaśapta": ['mw'],
    "avaśardhayitṛ": ['mw'],
    "avaśas": ['ap90', 'mw'],
    "avaśayati": ['bhs'],
    "avaśaṃgama": ['mw'],
    "avaśaṃgamaḥ": ['ap90'],
    "avaśaṃsyati": ['bhs'],
    "avaścut": ['mw'],
    "avaśendriyacitta": ['ddsa', 'mw'],
    "avaśeṣa": ['bhs', 'cae', 'mw'],
    "avaśeṣam": ['mw'],
    "avaśeṣatā": ['mw'],
    "avaśeṣaḥ": ['ap90'],
    "avaśeṣita": ['ap90', 'mw'],
    "avaśeṣya": ['mw'],
    "avaśi": ['mw'],
    "avaśikā": ['ap90'],
    "avaśin": ['cae', 'mw'],
    "avaśiras": ['ap90', 'mw'],
    "avaśirati": ['bhs'],
    "avaśitva": ['mw'],
    "avaśiṣ": ['ap90', 'mw'],
    "avaśiṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "avaśiṣṭaka": ['mw'],
    "avaśrath": ['mw'],
    "avaśrayaṇa": ['mw'],
    "avaśrayaṇaṃ": ['ap90'],
    "avaśruta": ['bhs'],
    "avaśuṣ": ['mw'],
    "avaśvasam": ['mw'],
    "avaśvit": ['mw'],
    "avaśya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "avaśyabhāgīyaka": ['mw'],
    "avaśyabhāvin": ['cae'],
    "avaśyaka": ['ap90'],
    "avaśyakarman": ['mw'],
    "avaśyakatā": ['ap90', 'cae'],
    "avaśyakārya": ['mw'],
    "avaśyam": ['mw'],
    "avaśyambhāvin": ['mw'],
    "avaśyambhāvitva": ['mw'],
    "avaśyambhāvitā": ['mw'],
    "avaśyapācya": ['mw'],
    "avaśyayātavyatā": ['mw'],
    "avaśyaṃ": ['ap90'],
    "avaśyaṃbhāvin": ['ap90'],
    "avaśyendriya": ['mw'],
    "avaśyā": ['ap90', 'ddsa', 'mw'],
    "avaśyāna": ['mw'],
    "avaśyāta": ['mw'],
    "avaśyāya": ['cae', 'mw'],
    "avaśyāyakiraṇa": ['mw'],
    "avaśyāyapaṭa": ['mw'],
    "avaśyāyapaṭṭa": ['bhs'],
    "avaśyāyati": ['bhs'],
    "avaśyāyaḥ": ['ap90'],
    "avaśā": ['ap90', 'mw'],
    "avaśākha": ['bhs'],
    "avaśānta": ['cae', 'mw'],
    "avaśātana": ['mw'],
    "avaśātanaṃ": ['ap90'],
    "avaśāvaśam": ['bhs'],
    "avaśāyita": ['bhs'],
    "avaśī": ['mw'],
    "avaśībhūta": ['ap90', 'mw'],
    "avaśīna": ['mw'],
    "avaśīnaḥ": ['ap90'],
    "avaśīrṇa": ['cae', 'mw'],
    "avaśīrṣa": ['ap90'],
    "avaśīrṣaka": ['mw'],
    "avaśīta": ['mw'],
    "avaśṛdh": ['mw'],
    "avaśṝ": ['mw'],
    "avaḍa": ['mw'],
    "avaḍaṃgaḥ": ['ap90'],
    "avaḍaṅga": ['mw'],
    "avaḍīna": ['mw'],
    "avaḍīnaṃ": ['ap90'],
    "avaḍīyati": ['bhs'],
    "avaṁ": ['cped'],
    "avaṁsira": ['cped'],
    "avaṃdhya": ['ap90'],
    "avaṃti": ['ap90'],
    "avaṃtiḥ": ['ap90'],
    "avaṃśa": ['cae', 'ddsa', 'gra', 'mw'],
    "avaṃśaḥ": ['ap90'],
    "avaṃśya": ['mw'],
    "avaṃḍa": ['ap90'],
    "avaṅga": ['cped'],
    "avaṅka": ['bhs'],
    "avaṅkatā": ['bhs'],
    "avaṛti": ['mw'],
    "avaṣaṅga": ['bhs'],
    "avaṣaṭkāra": ['mw'],
    "avaṣaṭkṛta": ['mw'],
    "avaṣkayaṇī": ['ap90'],
    "avaṣvan": ['ap90', 'mw'],
    "avaṣvāṇa": ['mw'],
    "avaṣvāṇaḥ": ['ap90'],
    "avaṣṭabdha": ['ap90', 'cae', 'mw'],
    "avaṣṭabdhatā": ['mw'],
    "avaṣṭabhya": ['bhs', 'ddsa', 'mw'],
    "avaṣṭambh": ['mw'],
    "avaṣṭambha": ['cae', 'mw'],
    "avaṣṭambhamaya": ['cae', 'mw'],
    "avaṣṭambhana": ['mw'],
    "avaṣṭaṃbh": ['ap90'],
    "avaṣṭaṃbhamaya": ['ap90'],
    "avaṣṭaṃbhanaṃ": ['ap90'],
    "avaṣṭaṃbhaḥ": ['ap90'],
    "avaṣṭhyūta": ['mw'],
    "avaṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "avaṭakacchapa": ['mw'],
    "avaṭavirodhana": ['mw'],
    "avaṭaṅka": ['mw'],
    "avaṭhiti": ['cped'],
    "avaṭi": ['mw'],
    "avaṭiḥ": ['ap90'],
    "avaṭodā": ['mw'],
    "avaṭu": ['cae', 'mw'],
    "avaṭuja": ['ddsa', 'mw'],
    "avaṭuḥ": ['ap90'],
    "avaṭya": ['ap90', 'mw'],
    "avaṭyāyanī": ['mw'],
    "avaṭīṭa": ['ap90', 'mw'],
    "avaṭṭhasi": ['cped'],
    "avaṭṭhita": ['cped'],
    "avaṭṭhiti": ['cped'],
    "ave": ['ap90', 'mw'],
    "avecca": ['cped'],
    "aveccapasanna": ['cped'],
    "aveccapasāda": ['cped'],
    "aveccappasanna": ['cped'],
    "aveccappasāda": ['cped'],
    "aveda": ['mw'],
    "avedana": ['cae', 'ddsa', 'mw'],
    "avedavid": ['cae', 'mw'],
    "avedavidvas": ['mw'],
    "avedavihita": ['cae', 'ddsa', 'mw'],
    "avedayāna": ['ap90', 'cae', 'mw'],
    "avedhadamma": ['cped'],
    "avedhi": ['cped'],
    "avedhin": ['cped'],
    "avedhya": ['mw'],
    "avedi": ['mw'],
    "avedin": ['mw'],
    "avediḥ": ['ap90'],
    "avedokta": ['mw'],
    "avedya": ['ap90', 'cae', 'ddsa', 'mw'],
    "avedyā": ['mw'],
    "avekkhanta": ['cped'],
    "avekkhati": ['cped'],
    "avekkhi": ['cped'],
    "avekkhita": ['cped'],
    "avekkhitācāra": ['cped'],
    "avekkhiṁ": ['cped'],
    "avekṣ": ['ap90', 'mw'],
    "avekṣaka": ['ap90'],
    "avekṣatā": ['mw'],
    "avekṣavant": ['bhs'],
    "avekṣaṇa": ['cae', 'ddsa', 'mw'],
    "avekṣaṇaṃ": ['ap90'],
    "avekṣaṇīya": ['ap90', 'mw'],
    "avekṣin": ['ap90', 'mw'],
    "avekṣita": ['bhs'],
    "avekṣitavya": ['mw'],
    "avekṣitṛ": ['ap90'],
    "avekṣya": ['mw'],
    "avekṣā": ['ap90', 'cae', 'mw'],
    "avela": ['ap90', 'mw'],
    "avelam": ['ddsa', 'mw'],
    "avelā": ['mw'],
    "avenat": ['ap90', 'gra', 'mw'],
    "avenv": ['mw'],
    "aveta": ['ap90', 'mw'],
    "aveti": ['cped'],
    "avetyaprasāda": ['bhs'],
    "aveśasadṛśa": ['cae', 'ddsa', 'mw'],
    "aveṇi": ['ap90', 'mw'],
    "aveṣṭi": ['mw'],
    "aveṣṭiḥ": ['ap90'],
    "avhayati": ['cped'],
    "avheti": ['cped'],
    "avheyya": ['cped'],
    "avhāna": ['cped'],
    "avhāyana": ['cped'],
    "avi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avianat": ['gra'],
    "aviat": ['gra'],
    "avibarha": ['mw'],
    "avibhajya": ['mw'],
    "avibhakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "avibhaktatva": ['mw'],
    "avibhaktin": ['mw'],
    "avibhavat": ['mw'],
    "avibhinna": ['ddsa', 'mw'],
    "avibhrama": ['cae', 'ddsa', 'mw'],
    "avibhraṃśa": ['mw'],
    "avibhraṃśin": ['mw'],
    "avibhraṣṭa": ['mw'],
    "avibhrānta": ['ddsa', 'mw'],
    "avibhuj": ['mw'],
    "avibhāga": ['ap90', 'mw'],
    "avibhāgavid": ['mw'],
    "avibhāgena": ['mw'],
    "avibhāgin": ['mw'],
    "avibhāgya": ['mw'],
    "avibhājya": ['ap90', 'mw'],
    "avibhājyatva": ['mw'],
    "avibhājyatā": ['mw'],
    "avibhāvana": ['mw'],
    "avibhāvanā": ['ap90'],
    "avibhāvanīya": ['ap90', 'mw'],
    "avibhāvita": ['cae', 'ddsa', 'mw'],
    "avibhāvya": ['mw'],
    "avibhāvyamāna": ['mw'],
    "avibhūṣaṇaparicchada": ['ddsa'],
    "avibruvant": ['cae'],
    "avibruvat": ['mw'],
    "avibudha": ['mw'],
    "avicakṣaṇa": ['cae', 'ddsa', 'mw'],
    "avicala": ['cae', 'ddsa', 'mw'],
    "avicalat": ['mw'],
    "avicalendriya": ['mw'],
    "avicalita": ['cae', 'mw'],
    "avicartya": ['mw'],
    "aviccheda": ['ap90', 'mw'],
    "avicchedena": ['mw'],
    "avicchedāt": ['mw'],
    "avicchindat": ['mw'],
    "avicchinna": ['ap90', 'ddsa', 'mw'],
    "avicchinnapāta": ['mw'],
    "avicetana": ['gra', 'mw'],
    "avicetas": ['gra', 'mw'],
    "avicikitsat": ['mw'],
    "avicikitsā": ['mw'],
    "avicintana": ['mw'],
    "avicintitṛ": ['mw'],
    "avicintya": ['mw'],
    "avicita": ['mw'],
    "avicyuta": ['ap90', 'mw'],
    "avicācala": ['ap90', 'mw'],
    "avicācalat": ['mw'],
    "avicācali": ['gra', 'mw'],
    "avicālin": ['mw'],
    "avicālita": ['ap90', 'mw'],
    "avicālya": ['mw'],
    "avicāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "avicārajña": ['cae', 'mw'],
    "avicāram": ['mw'],
    "avicārayant": ['cae'],
    "avicārayat": ['mw'],
    "avicāraṇa": ['mw'],
    "avicāraṇāt": ['mw'],
    "avicāraṇīya": ['ap90', 'mw'],
    "avicārin": ['ap90'],
    "avicārita": ['ap90', 'cae', 'mw'],
    "avicāritam": ['mw'],
    "avicārya": ['cae', 'mw'],
    "avicṛtya": ['ap90', 'mw'],
    "avida": ['cae', 'mw'],
    "avidagdha": ['ap90', 'ddsa', 'mw'],
    "avidasya": ['ap90', 'gra', 'mw'],
    "aviddasu": ['bhs'],
    "aviddha": ['ap90', 'cae', 'ddsa', 'mw'],
    "aviddhadṛś": ['mw'],
    "aviddhakarṇā": ['mw'],
    "aviddhakarṇī": ['mw'],
    "aviddhanas": ['mw'],
    "aviddhavarcas": ['mw'],
    "avidhavā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avidhaṃ": ['bhs'],
    "avidheya": ['ap90', 'ddsa'],
    "avidhi": ['ap90', 'cae', 'mw'],
    "avidhinā": ['mw'],
    "avidhipūrvakam": ['cae', 'ddsa', 'mw'],
    "avidhura": ['ddsa', 'mw'],
    "avidhya": ['mw'],
    "avidhā": ['ap90', 'mw'],
    "avidhāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "avidhānatas": ['mw'],
    "avidhāya": ['cae'],
    "avidhāyin": ['mw'],
    "avidita": ['ap90', 'cae', 'ddsa', 'mw'],
    "aviditam": ['mw'],
    "avidite": ['mw'],
    "avidoha": ['mw'],
    "avidoṣa": ['mw'],
    "avidriya": ['ap90', 'gra', 'mw'],
    "avidu": ['bhs'],
    "avidugdha": ['mw'],
    "aviduṣṭara": ['ddsa', 'mw'],
    "avidvala": ['bhs'],
    "avidvas": ['ddsa', 'gra', 'mw'],
    "avidvasu": ['bhs'],
    "avidvaṃs": ['cae'],
    "avidveṣa": ['ddsa', 'mw'],
    "avidviṣ": ['mw'],
    "avidviṣe": ['ddsa', 'mw'],
    "avidviṣāvat": ['mw'],
    "avidviṣāṇa": ['mw'],
    "avidya": ['ap90', 'cae', 'ddsa', 'mw'],
    "avidyamāna": ['cae', 'ddsa', 'mw'],
    "avidyamānatva": ['mw'],
    "avidyamānatā": ['mw'],
    "avidyamānavat": ['mw'],
    "avidyatā": ['bhs'],
    "avidyā": ['bhs', 'cae', 'mw'],
    "avidyāmaya": ['ap90', 'mw'],
    "avidyāndhakāravidhvamsanakara": ['bhs'],
    "avidāhin": ['ap90', 'mw'],
    "avidānta": ['mw'],
    "avidāsin": ['ap90', 'cae', 'ddsa', 'mw'],
    "avidīdhayu": ['ap90', 'gra', 'mw'],
    "avidūra": ['ap90', 'cae', 'mw'],
    "avidūram": ['mw'],
    "avidūratas": ['mw'],
    "avidūre": ['mw'],
    "avidūrāt": ['mw'],
    "avidūsa": ['mw'],
    "avigalita": ['mw'],
    "avigama": ['ap90'],
    "avigandhikā": ['mw'],
    "avigarhita": ['mw'],
    "avigata": ['ap90'],
    "avigaṇayya": ['cae', 'mw'],
    "avighna": ['ap90', 'cae', 'ddsa', 'mw'],
    "avighnakaraṇavrata": ['mw'],
    "avighnamaṅgala": ['cae', 'mw'],
    "avighnatas": ['mw'],
    "avighnavrata": ['mw'],
    "avighnena": ['mw'],
    "avighnita": ['mw'],
    "avighnā": ['mw'],
    "avighāta": ['ap90', 'mw'],
    "avigna": ['mw'],
    "avignaḥ": ['ap90'],
    "avigopita": ['bhs'],
    "avigraha": ['ap90', 'bhs', 'ddsa', 'mw'],
    "aviguṇa": ['mw'],
    "avigāna": ['ddsa', 'mw'],
    "avigīta": ['mw'],
    "aviha": ['cped'],
    "aviharyata": ['ap90', 'gra'],
    "aviharyatakratu": ['gra', 'mw'],
    "avihasta": ['mw'],
    "avihata": ['mw'],
    "avihatagati": ['ddsa'],
    "aviheṭhita": ['mw'],
    "avihita": ['mw'],
    "avihiṃsaka": ['mw'],
    "avihiṃsana": ['mw'],
    "avihiṃsra": ['mw'],
    "avihiṃsā": ['mw'],
    "avihruta": ['ap90', 'gra', 'mw'],
    "avihvala": ['cae', 'ddsa', 'mw'],
    "avihvarat": ['ap90', 'gra', 'mw'],
    "avijahanatā": ['bhs'],
    "avijitin": ['mw'],
    "avijitya": ['mw'],
    "avijugupsanatā": ['bhs'],
    "avijña": ['ap90', 'mw'],
    "avijñaptika": ['bhs'],
    "avijñatā": ['mw'],
    "avijñeya": ['ap90', 'cae', 'mw'],
    "avijñāna": ['cae', 'mw'],
    "avijñānatva": ['mw'],
    "avijñānavant": ['cae'],
    "avijñānavat": ['mw'],
    "avijñānāt": ['mw'],
    "avijñāta": ['ap90', 'cae', 'mw'],
    "avijñātagada": ['mw'],
    "avijñātagati": ['mw'],
    "avijñātṛ": ['ap90', 'mw'],
    "avijñāya": ['cae'],
    "avijānaka": ['mw'],
    "avijānant": ['cae'],
    "avijānat": ['ddsa', 'gra', 'mw'],
    "avijāta": ['ap90'],
    "avijātā": ['mw'],
    "avijātīya": ['ap90', 'mw'],
    "avika": ['gra', 'mw'],
    "avikaca": ['mw'],
    "avikacita": ['mw'],
    "avikala": ['ap90', 'cae', 'ddsa', 'mw'],
    "avikalpa": ['ap90', 'ddsa', 'mw'],
    "avikalpaka": ['mw'],
    "avikalpam": ['mw'],
    "avikalpita": ['mw'],
    "avikampa": ['cae'],
    "avikampanatā": ['bhs'],
    "avikampi": ['cped'],
    "avikampin": ['cped'],
    "avikampita": ['ddsa'],
    "avikarṣa": ['mw'],
    "avikathayat": ['mw'],
    "avikattha": ['ap90'],
    "avikatthana": ['ap90', 'cae', 'ddsa', 'mw'],
    "avikaḥ": ['ap90'],
    "avikaṭa": ['mw'],
    "avikaṭoraṇa": ['mw'],
    "avikhaṇḍana": ['mw'],
    "avikhaṇḍita": ['mw'],
    "avikhinna": ['bhs'],
    "avikhyātadoṣa": ['ddsa', 'mw'],
    "aviklamaḥ": ['ap90'],
    "aviklava": ['mw'],
    "aviklinnākṣa": ['mw'],
    "avikliṣṭa": ['mw'],
    "avikopana": ['bhs'],
    "avikopita": ['bhs', 'mw'],
    "avikrama": ['ap90', 'ddsa', 'mw'],
    "avikramaṇa": ['mw'],
    "avikraya": ['mw'],
    "avikrayya": ['mw'],
    "avikreya": ['cae', 'mw'],
    "avikriya": ['ap90', 'cae', 'mw'],
    "avikriyatva": ['ddsa', 'mw'],
    "avikriyā": ['mw'],
    "avikriyātmaka": ['mw'],
    "avikrānta": ['mw'],
    "avikrāṃta": ['ap90'],
    "avikrīta": ['cae', 'ddsa', 'gra', 'mw'],
    "avikuṇṭha": ['mw'],
    "avikā": ['mw'],
    "avikāra": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "avikārasadṛśa": ['mw'],
    "avikāravat": ['mw'],
    "avikārin": ['cae', 'mw'],
    "avikārya": ['cae', 'mw'],
    "avikīrṇavāca": ['bhs'],
    "avikūṇita": ['mw'],
    "avikṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "avikṛti": ['mw'],
    "avikṛtiḥ": ['ap90'],
    "avikṛtya": ['cae'],
    "avikṛtāṅga": ['mw'],
    "avikṛṣita": ['mw'],
    "avikṛṣṭa": ['mw'],
    "avikṣata": ['ap90', 'cae', 'mw'],
    "avikṣaṇa": ['bhs'],
    "avikṣipa": ['ap90', 'mw'],
    "avikṣipta": ['ap90', 'mw'],
    "avikṣiptāṃśa": ['bhs'],
    "avikṣit": ['mw'],
    "avikṣita": ['ap90', 'gra', 'mw'],
    "avikṣobha": ['mw'],
    "avikṣubdha": ['cae', 'mw'],
    "avikṣīṇa": ['mw'],
    "avilagnam": ['mw'],
    "avilakṣita": ['mw'],
    "avilakṣya": ['ap90'],
    "avilamba": ['cae', 'ddsa', 'mw'],
    "avilambam": ['mw'],
    "avilambana": ['cae', 'mw'],
    "avilambasarasvatī": ['mw'],
    "avilambena": ['mw'],
    "avilambin": ['cae'],
    "avilambita": ['cae', 'mw'],
    "avilambitam": ['mw'],
    "avilambya": ['cae', 'mw'],
    "avilaṃba": ['ap90'],
    "avilaṃbita": ['ap90'],
    "avilaṃghanaṃ": ['ap90'],
    "avilaṃghanīya": ['ap90'],
    "avilaṅghana": ['mw'],
    "avilaṅghanīya": ['mw'],
    "avilaṅghya": ['mw'],
    "avilikha": ['ap90', 'mw'],
    "aviloman": ['mw'],
    "avilomana": ['bhs'],
    "avilopa": ['mw'],
    "avilupta": ['mw'],
    "avilupya": ['ddsa'],
    "avilā": ['ap90', 'mw'],
    "avilāsa": ['ap90'],
    "avilīna": ['ddsa'],
    "avimanas": ['mw'],
    "avimardanatā": ['bhs'],
    "avimarīsa": ['mw'],
    "avimarśa": ['mw'],
    "avimarśitavya": ['cae', 'ddsa', 'mw'],
    "avimat": ['gra', 'mw'],
    "avimatta": ['mw'],
    "avimita": ['mw'],
    "avimocana": ['ddsa', 'mw'],
    "avimokya": ['ap90', 'mw'],
    "avimokṣa": ['mw'],
    "avimucyamāna": ['mw'],
    "avimukham": ['mw'],
    "avimukta": ['ap90', 'mw'],
    "avimuktaśaiva": ['ddsa'],
    "avimukteśa": ['mw'],
    "avimukteśamāhātmya": ['mw'],
    "avimukteśvara": ['mw'],
    "avimukteśvaraliṅga": ['mw'],
    "avimuktopaniṣad": ['mw'],
    "avimuktāpīḍa": ['mw'],
    "avimāna": ['mw'],
    "avimūḍha": ['mw'],
    "avimṛśya": ['cae'],
    "avimṛṣya": ['ap90'],
    "avina": ['mw'],
    "avinaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "avinaśvara": ['ap90', 'ddsa'],
    "avinaśyant": ['cae'],
    "avinaḥ": ['ap90'],
    "avindant": ['cae'],
    "avindat": ['ddsa'],
    "avindhya": ['cae', 'mw'],
    "avindhyā": ['mw'],
    "avinigama": ['mw'],
    "avinigamaḥ": ['ap90'],
    "avinipāta": ['mw'],
    "avinipātadharman": ['bhs'],
    "avinipātadharmin": ['bhs'],
    "avinipātin": ['mw'],
    "avinipātita": ['mw'],
    "avinirbhāga": ['bhs'],
    "avinirbhāva": ['bhs'],
    "avinirṇaya": ['mw'],
    "avinivarta": ['bhs'],
    "avinivartanīya": ['bhs'],
    "avinivartin": ['bhs', 'ddsa', 'mw'],
    "avinivartya": ['bhs'],
    "avinoda": ['cae', 'ddsa', 'mw'],
    "avinyasta": ['mw'],
    "avinābhāva": ['mw'],
    "avinābhāvaḥ": ['ap90'],
    "avinābhāvin": ['mw'],
    "avinābhāvitva": ['mw'],
    "avināyin": ['mw'],
    "avināśa": ['ddsa', 'mw'],
    "avināśin": ['cae', 'mw'],
    "avināśitva": ['mw'],
    "avināśya": ['mw'],
    "avinīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "avinītā": ['mw'],
    "avipad": ['ap90', 'mw'],
    "avipadyat": ['mw'],
    "avipakkanta": ['cped'],
    "avipakva": ['ap90', 'mw'],
    "avipakvabuddhi": ['mw'],
    "avipakvakaraṇa": ['ddsa', 'mw'],
    "avipakvakaṣāya": ['mw'],
    "avipakṣa": ['mw'],
    "avipanna": ['ap90'],
    "aviparihṛta": ['mw'],
    "aviparokṣa": ['bhs'],
    "aviparyaya": ['ddsa', 'mw'],
    "aviparyayāt": ['mw'],
    "aviparyāsam": ['mw'],
    "avipañcita": ['bhs'],
    "avipaścit": ['cae', 'mw'],
    "avipaṭa": ['mw'],
    "aviphala": ['mw'],
    "aviplava": ['mw'],
    "avipluta": ['ap90', 'cae', 'mw'],
    "aviplutamanobuddhi": ['mw'],
    "aviplutamati": ['mw'],
    "avippakkanta": ['cped'],
    "avipra": ['ap90', 'gra', 'mw'],
    "aviprahata": ['mw'],
    "aviprakramaṇa": ['mw'],
    "aviprakṛṣṭa": ['mw'],
    "avipralabdha": ['mw'],
    "avipralambhaka": ['mw'],
    "avipranaṣṭarāṣṭra": ['bhs'],
    "aviprapañca": ['bhs', 'mw'],
    "avipratisāra": ['bhs'],
    "avipratisārin": ['bhs'],
    "avipratisāritā": ['bhs'],
    "avipravāsa": ['bhs', 'mw'],
    "aviprayukta": ['ddsa', 'mw'],
    "avipraṇāśa": ['mw'],
    "avipriya": ['mw'],
    "avipriyā": ['mw'],
    "avipula": ['mw'],
    "avipāka": ['ap90', 'mw'],
    "avipākatā": ['mw'],
    "avipāla": ['cae', 'ddsa', 'mw'],
    "aviraha": ['cae', 'ddsa'],
    "avirahita": ['cae', 'mw'],
    "avirajas": ['bhs'],
    "avirakta": ['mw'],
    "aviraktarāṣṭra": ['bhs'],
    "avirala": ['ap90', 'cae', 'ddsa', 'mw'],
    "aviraladantatā": ['mw'],
    "aviraladhārāsāra": ['mw'],
    "aviralam": ['mw'],
    "aviralita": ['ap90', 'mw'],
    "aviramat": ['mw'],
    "avirasa": ['bhs'],
    "avirata": ['ap90', 'cae', 'mw'],
    "aviratam": ['mw'],
    "avirati": ['ap90', 'mw'],
    "aviravikanyāya": ['mw'],
    "aviraṇa": ['gra', 'mw'],
    "avirecana": ['mw'],
    "avirecanaṃ": ['ap90'],
    "avirecanīya": ['mw'],
    "avirecya": ['ap90', 'mw'],
    "aviroddhṛ": ['mw'],
    "avirodha": ['cae', 'mw'],
    "avirodhaḥ": ['ap90'],
    "avirodhin": ['cae', 'mw'],
    "avirodhita": ['mw'],
    "aviruddha": ['ap90', 'cae', 'ddsa', 'mw'],
    "avirādhayat": ['ap90', 'mw'],
    "avirāga": ['mw'],
    "avirāgayati": ['bhs'],
    "avirāgaṇa": ['bhs'],
    "avirāma": ['ap90'],
    "avirāmam": ['ddsa', 'mw'],
    "avirūḍha": ['mw'],
    "avis": ['ap90'],
    "avisabhāga": ['bhs'],
    "avisaraṇā": ['bhs'],
    "avisargin": ['ap90', 'mw'],
    "avisarpin": ['mw'],
    "avisaṃvāda": ['mw'],
    "avisaṃvādanatā": ['bhs'],
    "avisaṃvādin": ['ap90', 'mw'],
    "avisaṃvādita": ['mw'],
    "avisaṃvāditā": ['mw'],
    "aviskanttṛ": ['mw'],
    "avismaraṇa": ['bhs'],
    "avismita": ['mw'],
    "avismṛta": ['mw'],
    "avismṛti": ['mw'],
    "avisoḍha": ['mw'],
    "avispandita": ['mw'],
    "avispaṣṭa": ['ap90', 'cae', 'mw'],
    "avisraṃsa": ['mw'],
    "avisrāvya": ['mw'],
    "avistara": ['ap90', 'bhs'],
    "avisthala": ['mw'],
    "avistāraḥ": ['ap90'],
    "avistīrṇa": ['ap90', 'ddsa', 'mw'],
    "avistṛta": ['ap90', 'mw'],
    "avisvara": ['bhs'],
    "avisvaram": ['mw'],
    "avisyandita": ['mw'],
    "avisāri": ['cped'],
    "avisārin": ['cped'],
    "avisṛta": ['bhs'],
    "avisṛṣṭa": ['mw'],
    "avita": ['mw'],
    "avitadbhāṣaṇa": ['mw'],
    "avitaraṇa": ['mw'],
    "avitarka": ['bhs', 'mw'],
    "avitarkita": ['mw'],
    "avitatha": ['ap90', 'cae', 'ddsa', 'mw'],
    "avitathakriya": ['mw'],
    "avitatham": ['mw'],
    "avitathehita": ['mw'],
    "avitathena": ['mw'],
    "avitathābhisandhi": ['mw'],
    "avitathīkṛ": ['mw'],
    "avitatkaraṇa": ['mw'],
    "avitave": ['mw'],
    "avithura": ['ap90', 'cae', 'gra', 'mw'],
    "avithya": ['mw'],
    "avithyā": ['ap90', 'mw'],
    "avitrī": ['gra'],
    "avitta": ['ap90'],
    "avitti": ['ap90', 'mw'],
    "avityaja": ['mw'],
    "avityajaḥ": ['ap90'],
    "avitā": ['ap90'],
    "avitāna": ['mw'],
    "avitārin": ['ap90', 'gra', 'mw'],
    "avitṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "avitṛpta": ['ddsa', 'mw'],
    "avitṛptadṛś": ['mw'],
    "avitṛptakāma": ['mw'],
    "avitṛptatā": ['mw'],
    "avitṛpti": ['bhs'],
    "avivadiṣṇu": ['mw'],
    "avivakṣat": ['mw'],
    "avivakṣita": ['ap90', 'mw'],
    "avivakṣitatva": ['mw'],
    "avivakṣā": ['mw'],
    "avivarta": ['bhs', 'mw'],
    "avivartacaryā": ['bhs'],
    "avivartika": ['bhs'],
    "avivartiya": ['bhs'],
    "avivartya": ['bhs'],
    "avivartyadharmadhātunirghoṣa": ['bhs'],
    "avivayha": ['cped'],
    "avivecaka": ['mw'],
    "avivecam": ['mw'],
    "avivecanā": ['mw'],
    "aviveka": ['ap90', 'cae', 'ddsa', 'mw'],
    "avivekam": ['mw'],
    "avivekatā": ['mw'],
    "avivekin": ['ap90', 'cae', 'mw'],
    "avivena": ['ap90'],
    "avivenam": ['gra', 'mw'],
    "avivenant": ['cae'],
    "avivenat": ['ddsa', 'gra', 'mw'],
    "avivikta": ['ap90', 'cae', 'ddsa', 'mw'],
    "avivāda": ['cae', 'mw'],
    "avivādaḥ": ['ap90'],
    "avivādin": ['ap90', 'mw'],
    "avivāha": ['cae', 'ddsa', 'mw'],
    "avivāhin": ['ap90', 'cae', 'mw'],
    "avivāhya": ['cae', 'mw'],
    "avivākya": ['mw'],
    "avivārya": ['bhs'],
    "aviyoga": ['ap90', 'mw'],
    "aviyogatṛtīyā": ['mw'],
    "aviyogatṛtīyāvrata": ['mw'],
    "aviyogin": ['mw'],
    "aviyukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "aviśada": ['cae', 'ddsa'],
    "aviśastṛ": ['ap90', 'ddsa', 'gra', 'mw'],
    "aviśaṃka": ['ap90'],
    "aviśaṃkita": ['ap90'],
    "aviśaṅka": ['cae', 'ddsa', 'mw'],
    "aviśaṅkita": ['cae', 'mw'],
    "aviśaṅkitam": ['mw'],
    "aviśaṅkā": ['cae', 'mw'],
    "aviśeṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aviśeṣajñatā": ['mw'],
    "aviśeṣasama": ['mw'],
    "aviśeṣatas": ['mw'],
    "aviśeṣavat": ['mw'],
    "aviśeṣeṇa": ['mw'],
    "aviśeṣita": ['cae'],
    "aviśeṣāt": ['mw'],
    "aviśiṣṭa": ['cae', 'ddsa'],
    "aviśrabdha": ['mw'],
    "aviśrama": ['cae', 'ddsa', 'mw'],
    "aviśrambha": ['mw'],
    "aviśrambhatā": ['mw'],
    "aviśrambhin": ['mw'],
    "aviśrāma": ['cae'],
    "aviśrāmam": ['mw'],
    "aviśrānta": ['cae', 'mw'],
    "aviśrāntavidhyādharavyākaraṇa": ['mw'],
    "aviśrāṃta": ['ap90'],
    "aviśuddha": ['mw'],
    "aviśuddhiḥ": ['ap90'],
    "aviśuṣkamūla": ['bhs'],
    "aviśva": ['mw'],
    "aviśvaminva": ['gra', 'mw'],
    "aviśvasanīya": ['cae', 'mw'],
    "aviśvasanīyatva": ['mw'],
    "aviśvasat": ['ddsa', 'mw'],
    "aviśvasta": ['ap90', 'mw'],
    "aviśvavinna": ['mw'],
    "aviśvāsa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aviśvāsajanaka": ['cae'],
    "aviśvāsin": ['ap90', 'cae', 'mw'],
    "aviśvāsā": ['mw'],
    "aviśālabhāva": ['mw'],
    "aviḍīna": ['mw'],
    "aviḍīnaṃ": ['ap90'],
    "aviṃdhyaḥ": ['ap90'],
    "aviṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aviṣahya": ['bhs', 'cae', 'ddsa', 'mw'],
    "aviṣakta": ['ddsa', 'mw'],
    "aviṣama": ['cae', 'ddsa', 'mw'],
    "aviṣamam": ['mw'],
    "aviṣamapadatā": ['mw'],
    "aviṣaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "aviṣayamanas": ['cae', 'mw'],
    "aviṣayīkaraṇa": ['cae', 'mw'],
    "aviṣayīkaraṇaṃ": ['ap90'],
    "aviṣy": ['gra'],
    "aviṣyant": ['cae'],
    "aviṣyat": ['mw'],
    "aviṣyu": ['ap90', 'cae', 'gra', 'mw'],
    "aviṣyā": ['ap90', 'ddsa', 'gra', 'mw'],
    "aviṣā": ['mw'],
    "aviṣāda": ['cae', 'ddsa', 'mw'],
    "aviṣādin": ['mw'],
    "aviṣāṇa": ['mw'],
    "aviṣī": ['mw'],
    "aviṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aviṣṭhu": ['mw'],
    "aviṣṭāva": ['mw'],
    "avocat": ['ddsa'],
    "avoda": ['ap90', 'mw'],
    "avodeva": ['ap90', 'gra', 'mw'],
    "avoditāḥ": ['bhs'],
    "avoh": ['mw'],
    "avokṣ": ['mw'],
    "avokṣaṇa": ['ddsa', 'mw'],
    "avokṣaṇaṃ": ['ap90'],
    "avokṣaṇīya": ['mw'],
    "avoḍhṛ": ['mw'],
    "avoṣa": ['mw'],
    "avoṣaḥ": ['ap90'],
    "avoṣya": ['mw'],
    "avoṣīya": ['mw'],
    "avrata": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avratavat": ['mw'],
    "avratika": ['mw'],
    "avratin": ['mw'],
    "avratya": ['mw'],
    "avratyaṃ": ['ap90'],
    "avratyopacāra": ['mw'],
    "avraṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "avrājin": ['mw'],
    "avrātya": ['mw'],
    "avustaṃ": ['bhs'],
    "avya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avyabhicāra": ['cae', 'mw'],
    "avyabhicāravat": ['mw'],
    "avyabhicāraḥ": ['ap90'],
    "avyabhicāreṇa": ['mw'],
    "avyabhicārin": ['ap90', 'cae', 'ddsa', 'mw'],
    "avyabhicārāt": ['mw'],
    "avyabhīcāra": ['cae'],
    "avyabhīcāraḥ": ['ap90'],
    "avyacas": ['ap90', 'mw'],
    "avyadha": ['ap90'],
    "avyagra": ['ap90', 'cae', 'ddsa', 'mw'],
    "avyagram": ['mw'],
    "avyakta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "avyaktabhāṣin": ['cae', 'mw'],
    "avyaktagati": ['mw'],
    "avyaktagaṇita": ['mw'],
    "avyaktakriyā": ['mw'],
    "avyaktalakṣaṇa": ['mw'],
    "avyaktam": ['mw'],
    "avyaktamūrti": ['cae', 'mw'],
    "avyaktanirmāṇa": ['mw'],
    "avyaktapada": ['mw'],
    "avyaktarāga": ['mw'],
    "avyaktarāśi": ['mw'],
    "avyaktasāmya": ['mw'],
    "avyaktavyakta": ['mw'],
    "avyaktānukaraṇa": ['mw'],
    "avyalīka": ['ap90', 'mw'],
    "avyalīkam": ['mw'],
    "avyanat": ['ap90', 'gra', 'mw'],
    "avyanta": ['mw'],
    "avyapadeśa": ['mw'],
    "avyapadeśarūpin": ['mw'],
    "avyapadeśya": ['mw'],
    "avyapekṣā": ['ap90'],
    "avyapeta": ['mw'],
    "avyapohya": ['mw'],
    "avyardhuka": ['mw'],
    "avyartha": ['ap90', 'mw'],
    "avyarṇa": ['mw'],
    "avyasana": ['ap90', 'cae', 'mw'],
    "avyasanin": ['cae', 'ddsa', 'mw'],
    "avyasta": ['ap90', 'mw'],
    "avyat": ['gra', 'mw'],
    "avyatha": ['ap90', 'ddsa', 'mw'],
    "avyathamāna": ['mw'],
    "avyathatva": ['mw'],
    "avyathayaḥ": ['ap90'],
    "avyathi": ['ap90', 'cae', 'gra', 'mw'],
    "avyathin": ['ap90', 'mw'],
    "avyathiṣa": ['mw'],
    "avyathiṣaḥ": ['ap90'],
    "avyathiṣyai": ['mw'],
    "avyathiṣī": ['mw'],
    "avyathya": ['ap90', 'gra', 'mw'],
    "avyathā": ['mw'],
    "avyaticāra": ['mw'],
    "avyatikrama": ['mw'],
    "avyatikīrṇa": ['ap90', 'mw'],
    "avyatimoha": ['mw'],
    "avyatireka": ['mw'],
    "avyatirekin": ['mw'],
    "avyatirikta": ['ddsa'],
    "avyatiḥ": ['ap90'],
    "avyatiṣakta": ['mw'],
    "avyatiṣaṅgam": ['mw'],
    "avyatī": ['mw'],
    "avyavaccheda": ['mw'],
    "avyavacchinna": ['mw'],
    "avyavacchinnam": ['mw'],
    "avyavacāra": ['bhs'],
    "avyavadhāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "avyavahita": ['ap90', 'mw'],
    "avyavahāra": ['bhs', 'mw'],
    "avyavahārya": ['ap90', 'mw'],
    "avyavahṛta": ['mw'],
    "avyavakīrṇa": ['bhs'],
    "avyavalambin": ['mw'],
    "avyavasita": ['mw'],
    "avyavasraṃsa": ['mw'],
    "avyavasta": ['mw'],
    "avyavastha": ['ap90', 'ddsa', 'mw'],
    "avyavasthita": ['ap90', 'mw'],
    "avyavasthā": ['mw'],
    "avyavasāyavant": ['cae'],
    "avyavasāyin": ['cae', 'ddsa', 'mw'],
    "avyaveta": ['mw'],
    "avyavikanyāya": ['mw'],
    "avyavānam": ['mw'],
    "avyavāya": ['mw'],
    "avyaya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avyayaggamanasa": ['cped'],
    "avyayaggamānasa": ['cped'],
    "avyayatva": ['mw'],
    "avyayatvaṃ": ['ap90'],
    "avyayavat": ['mw'],
    "avyayaṃ": ['bhs'],
    "avyayātman": ['cae', 'mw'],
    "avyayībhāva": ['cae', 'mw'],
    "avyayībhāvasamāsa": ['mw'],
    "avyayībhāvaḥ": ['ap90'],
    "avyañjana": ['ddsa', 'mw'],
    "avyaṃga": ['ap90'],
    "avyaṃjana": ['ap90'],
    "avyaṃḍā": ['ap90'],
    "avyaṅga": ['ddsa', 'mw'],
    "avyaṅgatā": ['mw'],
    "avyaṅgā": ['mw'],
    "avyaṅgāṅga": ['cae', 'mw'],
    "avyaṇḍā": ['mw'],
    "avyaṣṭa": ['bhs'],
    "avyeṣyat": ['mw'],
    "avyoṣita": ['bhs'],
    "avyucchettṛ": ['mw'],
    "avyucchinna": ['cae', 'ddsa', 'mw'],
    "avyuptakeśa": ['mw'],
    "avyuptavaha": ['mw'],
    "avyutpanna": ['ap90', 'ddsa', 'mw'],
    "avyuṣṭa": ['cae', 'ddsa', 'gra', 'mw'],
    "avyuṣṭi": ['mw'],
    "avyābadhya": ['bhs'],
    "avyābādha": ['bhs', 'mw'],
    "avyābādhya": ['bhs'],
    "avyāghāta": ['mw'],
    "avyāhata": ['ap90', 'mw'],
    "avyāhārin": ['mw'],
    "avyāhṛta": ['cae', 'ddsa', 'mw'],
    "avyāja": ['ap90', 'cae', 'ddsa', 'mw'],
    "avyākhyeya": ['ap90', 'mw'],
    "avyākhyā": ['ap90'],
    "avyākhyāta": ['ap90'],
    "avyākṛta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "avyākṣepa": ['ddsa', 'mw'],
    "avyālaceṣṭita": ['mw'],
    "avyāpaka": ['ap90', 'mw'],
    "avyāpakatva": ['mw'],
    "avyāpakatā": ['mw'],
    "avyāpanna": ['bhs', 'ddsa', 'mw'],
    "avyāpin": ['ap90', 'mw'],
    "avyāpta": ['ap90', 'cae', 'ddsa', 'mw'],
    "avyāpti": ['mw'],
    "avyāptiḥ": ['ap90'],
    "avyāpya": ['ap90', 'mw'],
    "avyāpyavṛtti": ['mw'],
    "avyāpāda": ['bhs'],
    "avyāpāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "avyāvadhya": ['bhs'],
    "avyāvartanīya": ['ddsa', 'mw'],
    "avyāvṛtta": ['mw'],
    "avyāvṛtti": ['mw'],
    "avyāyata": ['ap90'],
    "avyāyika": ['cped'],
    "avyāyāma": ['ap90', 'mw'],
    "avyūha": ['mw'],
    "avyūḍha": ['mw'],
    "avyṛddha": ['mw'],
    "avyṛddhi": ['mw'],
    "avāc": ['ap90', 'gra', 'mw'],
    "avācaka": ['mw'],
    "avācanīya": ['mw'],
    "avācaṃyama": ['mw'],
    "avāchid": ['mw'],
    "avāci": ['mw'],
    "avācina": ['mw'],
    "avācya": ['ap90', 'cae', 'ddsa', 'mw'],
    "avācyadeśa": ['mw'],
    "avācyatva": ['mw'],
    "avācyatā": ['mw'],
    "avācyavāda": ['cae'],
    "avācāla": ['ddsa', 'mw'],
    "avācī": ['mw'],
    "avācīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "avācīnahasta": ['mw'],
    "avācīnaśīrṣan": ['mw'],
    "avācīnāgra": ['mw'],
    "avād": ['mw'],
    "avādin": ['ap90', 'mw'],
    "avāg": ['mw'],
    "avāgagra": ['mw'],
    "avāgam": ['mw'],
    "avāgbhāga": ['mw'],
    "avāgduṣṭa": ['mw'],
    "avāggamanavant": ['cae'],
    "avāggamanavat": ['ddsa', 'mw'],
    "avāggati": ['mw'],
    "avāgja": ['mw'],
    "avāgra": ['ap90', 'mw'],
    "avāgvadana": ['mw'],
    "avāhana": ['ap90', 'mw'],
    "avāj": ['mw'],
    "avājin": ['ap90', 'gra', 'mw'],
    "avāk": ['ap90', 'mw'],
    "avākaraḥ": ['ap90'],
    "avākchruti": ['mw'],
    "avākin": ['ap90', 'mw'],
    "avākka": ['ap90', 'mw'],
    "avākphala": ['mw'],
    "avākpuṣpī": ['mw'],
    "avāksrotas": ['mw'],
    "avākśiras": ['cae', 'mw'],
    "avākśruti": ['mw'],
    "avākśākha": ['cae', 'mw'],
    "avākśīrṣa": ['mw'],
    "avākśṛṅga": ['mw'],
    "avākṛ": ['mw'],
    "avākṝ": ['ap90'],
    "avākṣa": ['ap90'],
    "avālamba": ['mw'],
    "avāloc": ['mw'],
    "avāma": ['ap90'],
    "avān": ['ap90', 'mw'],
    "avāna": ['ap90', 'ddsa', 'mw'],
    "avānaḥ": ['ap90'],
    "avānta": ['bhs'],
    "avāntara": ['cae', 'ddsa', 'mw'],
    "avāntarabheda": ['mw'],
    "avāntaradeśa": ['cae', 'mw'],
    "avāntaradiksrakti": ['mw'],
    "avāntaradiś": ['mw'],
    "avāntaradiśā": ['mw'],
    "avāntaradīkṣa": ['mw'],
    "avāntaradīkṣin": ['mw'],
    "avāntaradīkṣā": ['mw'],
    "avāntaradīkṣādi": ['mw'],
    "avāntaram": ['mw'],
    "avāntareḍā": ['mw'],
    "avāntarām": ['mw'],
    "avāp": ['ap90', 'mw'],
    "avāpa": ['mw'],
    "avāpita": ['ap90', 'mw'],
    "avāpoh": ['mw'],
    "avāpta": ['ap90', 'cae', 'mw'],
    "avāptavat": ['mw'],
    "avāptavya": ['ap90', 'ddsa', 'mw'],
    "avāpti": ['cae', 'mw'],
    "avāptiḥ": ['ap90'],
    "avāptukāma": ['mw'],
    "avāpurati": ['cped'],
    "avāpuraṇa": ['cped'],
    "avāpurīyati": ['cped'],
    "avāpya": ['ap90', 'cae', 'mw'],
    "avāra": ['gra', 'mw'],
    "avārapāra": ['mw'],
    "avārapārīṇa": ['mw'],
    "avāratas": ['gra', 'mw'],
    "avāraḥ": ['ap90'],
    "avāraṇa": ['ap90'],
    "avāraṇīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "avārch": ['mw'],
    "avāriakratu": ['gra'],
    "avārikā": ['ap90', 'mw'],
    "avārita": ['mw'],
    "avāritadvāra": ['mw'],
    "avāritam": ['mw'],
    "avāritavya": ['mw'],
    "avārj": ['mw'],
    "avārtta": ['mw'],
    "avāruh": ['mw'],
    "avāruṇa": ['mw'],
    "avārya": ['ap90', 'gra', 'mw'],
    "avāryakratu": ['gra', 'mw'],
    "avāryatā": ['mw'],
    "avārīṇa": ['ap90', 'mw'],
    "avārṣika": ['bhs'],
    "avās": ['mw'],
    "avāsas": ['ap90', 'mw'],
    "avāsic": ['mw'],
    "avāsin": ['mw'],
    "avāstava": ['ap90', 'mw'],
    "avāstu": ['ap90', 'mw'],
    "avāta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avātala": ['mw'],
    "avātita": ['mw'],
    "avāvan": ['ap90', 'mw'],
    "avāvaṭa": ['ddsa', 'mw'],
    "avāvaṭaḥ": ['ap90'],
    "avāya": ['gra', 'mw'],
    "avāyat": ['gra'],
    "avāyaḥ": ['ap90'],
    "avāyima": ['cped'],
    "avāyu": ['mw'],
    "avāñc": ['cae', 'ddsa', 'mw'],
    "avāñcam": ['mw'],
    "avāñcita": ['mw'],
    "avāśiro": ['bhs'],
    "avāśruta": ['bhs'],
    "avāśṛṅga": ['mw'],
    "avāṃc": ['ap90'],
    "avāṃcita": ['ap90'],
    "avāṃtara": ['ap90'],
    "avāṃtarām": ['ap90'],
    "avāṃśa": ['mw'],
    "avāṅ": ['mw'],
    "avāṅagra": ['mw'],
    "avāṅmanasagocara": ['cae', 'ddsa'],
    "avāṅmukha": ['cae', 'ddsa', 'mw'],
    "avāṅniraya": ['mw'],
    "avāṅnābhi": ['mw'],
    "avāṭ": ['ddsa'],
    "avī": ['ap90', 'mw'],
    "avīci": ['ap90', 'bhs', 'ddsa', 'mw'],
    "avīcika": ['bhs'],
    "avīcimat": ['mw'],
    "avīcisaṃśoṣaṇa": ['mw'],
    "avīja": ['ap90', 'mw'],
    "avīkṣaṇa": ['mw'],
    "avīkṣin": ['mw'],
    "avīkṣita": ['ddsa', 'mw'],
    "avīra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avīraghna": ['mw'],
    "avīraghnastha": ['mw'],
    "avīrahan": ['gra', 'mw'],
    "avīrajuṣṭa": ['cae', 'mw'],
    "avīrapuruṣa": ['mw'],
    "avīratā": ['gra', 'mw'],
    "avīrya": ['ap90', 'cae', 'ddsa', 'mw'],
    "avīryavat": ['mw'],
    "avīrā": ['mw'],
    "avīta": ['gra', 'mw'],
    "avītaka": ['ddsa', 'mw'],
    "avītarāga": ['cae'],
    "avītaṃ": ['ap90'],
    "avīṅgita": ['mw'],
    "avṛddha": ['ddsa'],
    "avṛddhika": ['ap90', 'ddsa', 'mw'],
    "avṛdha": ['ap90', 'ddsa', 'gra', 'mw'],
    "avṛha": ['bhs', 'mw'],
    "avṛjina": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avṛka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avṛkṣa": ['mw'],
    "avṛkṣaka": ['mw'],
    "avṛntaka": ['mw'],
    "avṛta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "avṛthā": ['ap90', 'mw'],
    "avṛthārtha": ['ddsa'],
    "avṛthārthatā": ['mw'],
    "avṛtta": ['ddsa', 'mw'],
    "avṛtti": ['ap90', 'cae', 'ddsa', 'mw'],
    "avṛttika": ['mw'],
    "avṛṣaṇa": ['cae', 'ddsa', 'mw'],
    "avṛṣṭa": ['ddsa', 'mw'],
    "avṛṣṭi": ['ap90', 'cae', 'ddsa', 'mw'],
    "avṛṣṭikāma": ['mw'],
    "ay": ['ap90', 'mw'],
    "aya": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ayabhyā": ['mw'],
    "ayadi": ['ddsa'],
    "ayadīkṣita": ['mw'],
    "ayaguḷa": ['cped'],
    "ayajamāna": ['mw'],
    "ayajus": ['mw'],
    "ayajuṣka": ['ap90', 'mw'],
    "ayajuṣkam": ['mw'],
    "ayajuṣkṛta": ['mw'],
    "ayajvan": ['ap90', 'cae', 'gra', 'mw'],
    "ayajyu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ayajña": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ayajñadatta": ['mw'],
    "ayajñaka": ['ap90'],
    "ayajñasac": ['mw'],
    "ayajñasāc": ['gra'],
    "ayajñiya": ['ap90', 'gra', 'mw'],
    "ayajñīya": ['mw'],
    "ayakapāla": ['cped'],
    "ayakaṭāha": ['cped'],
    "ayakva": ['bhs'],
    "ayakūṭa": ['cped'],
    "ayakṣma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ayakṣmatva": ['mw'],
    "ayakṣmatāti": ['mw'],
    "ayakṣmaṃkaraṇa": ['mw'],
    "ayakṣyamāṇa": ['mw'],
    "ayam": ['ddsa', 'mw'],
    "ayamaka": ['bhs'],
    "ayamita": ['ap90', 'ddsa', 'mw'],
    "ayamitanakha": ['cae', 'mw'],
    "ayamāsya": ['mw'],
    "ayana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ayanabhāga": ['mw'],
    "ayanadṛkkarman": ['mw'],
    "ayanagraha": ['mw'],
    "ayanakalā": ['mw'],
    "ayanavṛtta": ['mw'],
    "ayantra": ['gra', 'mw'],
    "ayantraṇa": ['ddsa'],
    "ayantraṇā": ['mw'],
    "ayantrita": ['ddsa', 'mw'],
    "ayanānta": ['mw'],
    "ayanāṃśa": ['mw'],
    "ayapatta": ['cped'],
    "ayapaṭṭa": ['cped'],
    "ayas": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ayasa": ['ap90', 'cped', 'mw'],
    "ayasagra": ['gra'],
    "ayasapāṣṭi": ['gra'],
    "ayase": ['mw'],
    "ayasiṅghātaka": ['cped'],
    "ayaskarṇī": ['mw'],
    "ayaskaṃsa": ['mw'],
    "ayaskumbha": ['mw'],
    "ayaskumbhī": ['mw'],
    "ayaskuśā": ['mw'],
    "ayaskuṇḍa": ['mw'],
    "ayaskāma": ['mw'],
    "ayaskānta": ['cae', 'mw'],
    "ayaskāntamaṇi": ['cae', 'mw'],
    "ayaskāra": ['mw'],
    "ayaskāṇḍa": ['mw'],
    "ayaskīla": ['bhs', 'mw'],
    "ayaskīlā": ['mw'],
    "ayaskṛti": ['mw'],
    "ayasmaya": ['ap90', 'cae', 'gra', 'mw'],
    "ayasmayādi": ['mw'],
    "ayasmayī": ['cae', 'mw'],
    "ayasprapāṭikā": ['bhs'],
    "ayaspātra": ['mw'],
    "ayastuṇḍa": ['mw'],
    "ayastāpa": ['mw'],
    "ayat": ['ap90', 'mw'],
    "ayata": ['ap90', 'ddsa', 'mw'],
    "ayatat": ['gra', 'mw'],
    "ayatha": ['cae', 'gra', 'mw'],
    "ayathaṃ": ['ap90'],
    "ayatheṣṭa": ['mw'],
    "ayathocita": ['ddsa', 'mw'],
    "ayathoktam": ['mw'],
    "ayathā": ['ap90', 'mw'],
    "ayathābalam": ['mw'],
    "ayathābhipreta": ['mw'],
    "ayathādevatam": ['mw'],
    "ayathādyotana": ['mw'],
    "ayathājātīyaka": ['mw'],
    "ayathākṛta": ['mw'],
    "ayathāmukhīna": ['mw'],
    "ayathāmātram": ['mw'],
    "ayathāpuram": ['mw'],
    "ayathāpūrva": ['mw'],
    "ayathāpūrvam": ['mw'],
    "ayathārtha": ['cae', 'mw'],
    "ayathārtham": ['mw'],
    "ayathāsthita": ['mw'],
    "ayathātatham": ['cae', 'ddsa', 'mw'],
    "ayathātathā": ['mw'],
    "ayathāvat": ['ap90', 'cae', 'mw'],
    "ayathāvata": ['bhs'],
    "ayathāvṛtta": ['mw'],
    "ayathāyatham": ['cae', 'mw'],
    "ayathāśāstrakārin": ['mw'],
    "ayati": ['cae', 'cped', 'ddsa', 'mw'],
    "ayatin": ['ap90'],
    "ayatna": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayatnabālavyajanībhū": ['mw'],
    "ayatnaja": ['mw'],
    "ayatnakārin": ['mw'],
    "ayatnakṛta": ['mw'],
    "ayatnalabhya": ['cae'],
    "ayatnatas": ['mw'],
    "ayatnavat": ['mw'],
    "ayatnena": ['mw'],
    "ayatnāt": ['mw'],
    "ayaudhika": ['mw'],
    "ayaugapadya": ['mw'],
    "ayaugapadyaṃ": ['ap90'],
    "ayaugika": ['ap90', 'ddsa', 'mw'],
    "ayauktika": ['ap90', 'mw'],
    "ayava": ['ap90', 'bhs', 'cae', 'mw'],
    "ayavaka": ['mw'],
    "ayavan": ['cae', 'mw'],
    "ayavas": ['mw'],
    "ayavat": ['ddsa', 'mw'],
    "ayavya": ['ap90'],
    "ayaś": ['mw'],
    "ayaśas": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayaśaskara": ['cae', 'mw'],
    "ayaśasya": ['ap90', 'mw'],
    "ayaścūrṇa": ['mw'],
    "ayaśobhin": ['mw'],
    "ayaḥ": ['mw'],
    "ayaḥkaṇapa": ['mw'],
    "ayaḥkiṭṭa": ['mw'],
    "ayaḥkāya": ['ddsa', 'mw'],
    "ayaḥpiṇḍa": ['cae', 'ddsa', 'mw'],
    "ayaḥpratimā": ['mw'],
    "ayaḥpāna": ['mw'],
    "ayaḥsthūṇa": ['gra', 'mw'],
    "ayaḥsthūṇī": ['mw'],
    "ayaḥśalākā": ['mw'],
    "ayaḥśapha": ['mw'],
    "ayaḥśaya": ['mw'],
    "ayaḥśaṅku": ['mw'],
    "ayaḥśipra": ['gra', 'mw'],
    "ayaḥśiras": ['mw'],
    "ayaḥśīrṣan": ['gra', 'mw'],
    "ayaḥśūla": ['mw'],
    "ayaḥśṛṅga": ['mw'],
    "ayaṃtraṃ": ['ap90'],
    "ayaṃtrita": ['ap90'],
    "aye": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayi": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayin": ['mw'],
    "ayiraka": ['cped'],
    "ayman": ['mw'],
    "ayo": ['mw'],
    "ayoagra": ['gra', 'mw'],
    "ayobāhu": ['mw'],
    "ayocchiṣṭaṃ": ['ap90'],
    "ayodarvi": ['mw'],
    "ayodatī": ['mw'],
    "ayodaṃṣṭra": ['cae', 'gra', 'mw'],
    "ayoddhṛ": ['ap90', 'ddsa', 'gra', 'mw'],
    "ayodhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayodhyā": ['mw'],
    "ayodhyādhipati": ['mw'],
    "ayodhyākaṇḍa": ['mw'],
    "ayodhyāvāsin": ['mw'],
    "ayodāha": ['mw'],
    "ayoga": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayogakṣema": ['mw'],
    "ayogapeśala": ['mw'],
    "ayogava": ['cae', 'mw'],
    "ayogavaḥ": ['ap90'],
    "ayogavāha": ['mw'],
    "ayoghana": ['ddsa', 'mw'],
    "ayogin": ['mw'],
    "ayogra": ['mw'],
    "ayograka": ['mw'],
    "ayoguḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayoguḷa": ['cped'],
    "ayogya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayogyatva": ['mw'],
    "ayogyatā": ['mw'],
    "ayogū": ['ddsa', 'mw'],
    "ayogūḥ": ['ap90'],
    "ayohanu": ['gra', 'mw'],
    "ayohata": ['cae', 'gra', 'mw'],
    "ayohṛdaya": ['mw'],
    "ayojāla": ['mw'],
    "ayokapāla": ['cped'],
    "ayokaṭāha": ['cped'],
    "ayokhīla": ['cped'],
    "ayokūṭa": ['cped'],
    "ayomala": ['mw'],
    "ayomaya": ['cae', 'ddsa', 'mw'],
    "ayomaṇi": ['mw'],
    "ayomiśra": ['mw'],
    "ayomukha": ['cae', 'mw'],
    "ayoni": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayonija": ['mw'],
    "ayonijatva": ['mw'],
    "ayonijatīrtha": ['mw'],
    "ayonijeśa": ['mw'],
    "ayonijeśvaratīrtha": ['mw'],
    "ayonika": ['ap90', 'mw'],
    "ayonisambhava": ['mw'],
    "ayoniśa": ['bhs'],
    "ayoniśas": ['bhs'],
    "ayopatta": ['cped'],
    "ayopaṭṭa": ['cped'],
    "ayopāṣṭi": ['gra', 'mw'],
    "ayorajas": ['mw'],
    "ayorasa": ['mw'],
    "ayosiṅghātaka": ['cped'],
    "ayovikāra": ['mw'],
    "ayośana": ['mw'],
    "ayuddha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ayuddhasena": ['gra', 'mw'],
    "ayuddhvī": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayudha": ['mw'],
    "ayudhaḥ": ['ap90'],
    "ayudhvin": ['ap90', 'gra'],
    "ayudhya": ['ap90', 'gra', 'mw'],
    "ayudhyamāna": ['cae'],
    "ayuga": ['ap90', 'mw'],
    "ayugacchada": ['mw'],
    "ayugakṣa": ['mw'],
    "ayugapad": ['ap90', 'mw'],
    "ayugapadbhāva": ['mw'],
    "ayugapadgrahaṇa": ['mw'],
    "ayugasapti": ['ddsa', 'mw'],
    "ayugbāṇa": ['mw'],
    "ayugdhātu": ['mw'],
    "ayugiṣu": ['mw'],
    "ayugma": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayugmacchada": ['ddsa', 'mw'],
    "ayugmalocana": ['mw'],
    "ayugmanetra": ['mw'],
    "ayugmaparṇa": ['mw'],
    "ayugmapattra": ['mw'],
    "ayugmapādayamaka": ['mw'],
    "ayugmaśara": ['mw'],
    "ayugārcis": ['ddsa', 'mw'],
    "ayugū": ['cae', 'mw'],
    "ayugūḥ": ['ap90'],
    "ayuj": ['ap90', 'cae', 'mw'],
    "ayuja": ['ap90', 'cae', 'gra', 'mw'],
    "ayujakāram": ['mw'],
    "ayujin": ['mw'],
    "ayujākṣara": ['mw'],
    "ayukchada": ['ddsa', 'mw'],
    "ayukpalāśa": ['mw'],
    "ayukpādayamaka": ['mw'],
    "ayuksaṅkhya": ['ddsa'],
    "ayukta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ayuktacāra": ['mw'],
    "ayuktakṛt": ['mw'],
    "ayuktam": ['mw'],
    "ayuktapadārtha": ['mw'],
    "ayuktarūpa": ['mw'],
    "ayuktatva": ['mw'],
    "ayuktatā": ['mw'],
    "ayuktayogin": ['bhs'],
    "ayukti": ['mw'],
    "ayuktiyukta": ['mw'],
    "ayuktiḥ": ['ap90'],
    "ayukśakti": ['mw'],
    "ayupita": ['mw'],
    "ayuta": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ayutadhā": ['mw'],
    "ayutadhāra": ['mw'],
    "ayutahoma": ['mw'],
    "ayutajit": ['mw'],
    "ayutanāyin": ['mw'],
    "ayutasiddha": ['mw'],
    "ayutasiddhi": ['mw'],
    "ayutaśas": ['mw'],
    "ayutādhyāpaka": ['mw'],
    "ayutājit": ['mw'],
    "ayutāyu": ['mw'],
    "ayutāśva": ['mw'],
    "ayuva": ['ap90'],
    "ayuvamārin": ['ddsa', 'mw'],
    "ayuṃga": ['ap90'],
    "ayuṅga": ['cae', 'ddsa', 'mw'],
    "ayuṅnetra": ['mw'],
    "ayya": ['cped'],
    "ayyaka": ['bhs', 'cped'],
    "ayyakā": ['cped'],
    "ayyaputta": ['cped'],
    "ayyaputtaka": ['cped'],
    "ayyavosāṭitaka": ['cped'],
    "ayyika": ['cped'],
    "ayyikā": ['cped'],
    "ayā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ayācaka": ['ap90', 'mw'],
    "ayācamāna": ['mw'],
    "ayācant": ['cae'],
    "ayācat": ['mw'],
    "ayācin": ['mw'],
    "ayācita": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayācitavrata": ['mw'],
    "ayācitopanīta": ['mw'],
    "ayācitāhṛta": ['mw'],
    "ayājya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ayājyasaṃyājya": ['cae', 'mw'],
    "ayājyatva": ['mw'],
    "ayājyayājana": ['cae', 'mw'],
    "ayāma": ['mw'],
    "ayāman": ['gra', 'mw'],
    "ayāna": ['mw'],
    "ayānaya": ['mw'],
    "ayānayaṃ": ['ap90'],
    "ayānayīna": ['mw'],
    "ayānayīnaḥ": ['ap90'],
    "ayānaṃ": ['ap90'],
    "ayānvita": ['mw'],
    "ayās": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ayāsia": ['gra'],
    "ayāsomīya": ['mw'],
    "ayāsomīyaṃ": ['ap90'],
    "ayāsya": ['ap90', 'cae', 'gra', 'mw'],
    "ayāta": ['ap90', 'mw'],
    "ayātayāma": ['cae', 'ddsa', 'mw'],
    "ayātayāman": ['mw'],
    "ayātayāmatva": ['mw'],
    "ayātayāmatā": ['mw'],
    "ayāthāpurya": ['mw'],
    "ayāthārthika": ['ap90', 'mw'],
    "ayāthārthya": ['mw'],
    "ayāthārthyaṃ": ['ap90'],
    "ayāthātathya": ['mw'],
    "ayātrika": ['mw'],
    "ayātrā": ['mw'],
    "ayātrīya": ['mw'],
    "ayātu": ['ap90', 'gra', 'mw'],
    "ayātīvana": ['bhs'],
    "ayāva": ['mw'],
    "ayāvaka": ['ap90'],
    "ayāvan": ['mw'],
    "ayāvana": ['mw'],
    "ayāvanaṃ": ['ap90'],
    "ayāśaya": ['mw'],
    "ayāśu": ['ap90', 'mw'],
    "ayāṭkāra": ['mw'],
    "ayūpa": ['mw'],
    "ayūthika": ['mw'],
    "añc": ['ddsa', 'mw'],
    "añca": ['mw'],
    "añcala": ['cae', 'ddsa', 'mw'],
    "añcana": ['mw'],
    "añcati": ['mw'],
    "añcatī": ['mw'],
    "añchati": ['cped'],
    "añcita": ['cae', 'mw'],
    "añcitabhrū": ['mw'],
    "añcitalāṅgūla": ['mw'],
    "añcitapattra": ['mw'],
    "añcitapattrākṣa": ['mw'],
    "añcu": ['ddsa'],
    "añhamāna": ['cped'],
    "añj": ['cae', 'ddsa', 'gra', 'mw'],
    "añja": ['bhs'],
    "añjaka": ['mw'],
    "añjala": ['mw'],
    "añjali": ['cae', 'ddsa', 'mw'],
    "añjalibandhana": ['mw'],
    "añjalika": ['cped', 'mw'],
    "añjalikamma": ['cped'],
    "añjalikaraṇīya": ['cped'],
    "añjalikarman": ['mw'],
    "añjalikā": ['mw'],
    "añjalikārikā": ['mw'],
    "añjalimālādhārin": ['bhs'],
    "añjalipriya": ['bhs'],
    "añjalipuṭa": ['mw'],
    "añjalī": ['cped'],
    "añjalīkṛ": ['ddsa'],
    "añjalīkṛta": ['mw'],
    "añjana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "añjanaka": ['ddsa', 'mw'],
    "añjanakeśa": ['mw'],
    "añjanakeśī": ['mw'],
    "añjanakkhika": ['cped'],
    "añjanakī": ['mw'],
    "añjananāmikā": ['mw'],
    "añjanavat": ['ddsa', 'mw'],
    "añjanikā": ['mw'],
    "añjanisalākā": ['cped'],
    "añjanithavikā": ['cped'],
    "añjanā": ['mw'],
    "añjanādhikā": ['mw'],
    "añjanāgiri": ['mw'],
    "añjanāmbhas": ['mw'],
    "añjanāvatī": ['mw'],
    "añjanī": ['cped', 'mw'],
    "añjanīya": ['bhs'],
    "añjanūpapiṁsana": ['cped'],
    "añjas": ['cae', 'ddsa', 'gra', 'mw'],
    "añjasa": ['cped', 'gra', 'mw'],
    "añjasayana": ['cped'],
    "añjaspā": ['gra', 'mw'],
    "añjasā": ['mw'],
    "añjasāyana": ['mw'],
    "añjasī": ['mw'],
    "añjasīna": ['gra', 'mw'],
    "añjati": ['bhs', 'cped'],
    "añjaḥsava": ['cae', 'ddsa', 'mw'],
    "añji": ['cae', 'ddsa', 'gra', 'mw'],
    "añjihiṣā": ['mw'],
    "añjika": ['mw'],
    "añjimant": ['cae'],
    "añjimat": ['gra', 'mw'],
    "añjisaktha": ['mw'],
    "añjiva": ['mw'],
    "añjiṣṇu": ['mw'],
    "añjiṣṭha": ['bhs', 'mw'],
    "añjiṣṭhu": ['mw'],
    "añjyeta": ['mw'],
    "añjī": ['mw'],
    "añjīra": ['mw'],
    "añña": ['cped'],
    "añña-d-attha": ['cped'],
    "añña-d-atthika": ['cped'],
    "añña-m-añña": ['cped'],
    "añña-m-aññakhādikā": ['cped'],
    "añña-m-aññaṁ": ['cped'],
    "aññacetāpana": ['cped'],
    "aññadatthu": ['cped'],
    "aññadatthudasa": ['cped'],
    "aññadatthuhara": ['cped'],
    "aññadatthuṁ": ['cped'],
    "aññadiṭṭhika": ['cped'],
    "aññadā": ['cped'],
    "aññakanthika": ['cped'],
    "aññamokkha": ['cped'],
    "aññapekha": ['cped'],
    "aññapekkha": ['cped'],
    "aññatama": ['cped'],
    "aññatara": ['cped'],
    "aññataraññatara": ['cped'],
    "aññathatta": ['cped'],
    "aññathā": ['cped'],
    "aññathābhava": ['cped'],
    "aññathābhāvi": ['cped'],
    "aññathābhāvin": ['cped'],
    "aññathācariyaka": ['cped'],
    "aññatitthiya": ['cped'],
    "aññato": ['cped'],
    "aññatra": ['cped'],
    "aññatrayoga": ['cped'],
    "aññatrācariyaka": ['cped'],
    "aññattha": ['cped'],
    "aññatthācariyaka": ['cped'],
    "aññavadaka": ['cped'],
    "aññavadī": ['cped'],
    "aññavadīn": ['cped'],
    "aññavihita": ['cped'],
    "aññavihitaka": ['cped'],
    "aññañña": ['cped'],
    "aññindriya": ['cped'],
    "aññoññavivaresi": ['cped'],
    "aññoññavivaresin": ['cped'],
    "aññā": ['cped'],
    "aññācitta": ['cped'],
    "aññādisa": ['cped'],
    "aññāta": ['cped'],
    "aññātaka": ['cped'],
    "aññātakavesena": ['cped'],
    "aññātar": ['cped'],
    "aññātāvi": ['cped'],
    "aññātāvin": ['cped'],
    "aññātāvindriya": ['cped'],
    "aññāvada": ['cped'],
    "aññāya": ['bhs'],
    "aññāṁ vyākaroti": ['cped'],
    "aññāṇa": ['cped'],
    "aññāṇaka": ['cped'],
    "añāna": ['bhs'],
    "añśera": ['mw'],
    "aś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aśabala": ['bhs'],
    "aśabda": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśaikṣa": ['bhs', 'mw'],
    "aśaikṣaḥ": ['ap90'],
    "aśaknuvant": ['cae'],
    "aśaknuvat": ['ddsa', 'mw'],
    "aśaknuvāna": ['mw'],
    "aśakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśaktabhartṛka": ['mw'],
    "aśakti": ['cae', 'ddsa', 'mw'],
    "aśaktiḥ": ['ap90'],
    "aśakumbhī": ['mw'],
    "aśakuna": ['ddsa', 'mw'],
    "aśakunaḥ": ['ap90'],
    "aśakunībhū": ['mw'],
    "aśakya": ['ap90', 'cae', 'mw'],
    "aśakyatva": ['mw'],
    "aśakyatā": ['mw'],
    "aśakyārtha": ['mw'],
    "aśam": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśama": ['cae', 'mw'],
    "aśamarathaṃbhāvuka": ['mw'],
    "aśan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aśana": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśanais": ['ddsa'],
    "aśanakriyā": ['mw'],
    "aśanakṛt": ['mw'],
    "aśanapati": ['mw'],
    "aśanavat": ['mw'],
    "aśani": ['cae', 'ddsa', 'gra', 'mw'],
    "aśanigrāvan": ['mw'],
    "aśanihata": ['mw'],
    "aśanika": ['mw'],
    "aśanimat": ['gra', 'mw'],
    "aśanin": ['mw'],
    "aśaniprabha": ['mw'],
    "aśaniḥ": ['ap90'],
    "aśanā": ['ap90', 'cae', 'mw'],
    "aśanānaśana": ['cae', 'mw'],
    "aśanāpipāse": ['ddsa'],
    "aśanāya": ['mw'],
    "aśanāyati": ['ap90'],
    "aśanāyita": ['ap90', 'mw'],
    "aśanāyuka": ['cae', 'mw'],
    "aśanāyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśanāyāpipāse": ['mw'],
    "aśanāyāpipāsā": ['cae'],
    "aśanāyāvant": ['cae'],
    "aśanāyāvat": ['mw'],
    "aśanī": ['bhs', 'mw'],
    "aśanīya": ['mw'],
    "aśanīśa": ['mw'],
    "aśapat": ['mw'],
    "aśaramaya": ['mw'],
    "aśaravya": ['mw'],
    "aśaraṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśaraṇya": ['mw'],
    "aśaraṇīkṛta": ['mw'],
    "aśarman": ['ap90', 'ddsa', 'mw'],
    "aśarīra": ['ap90', 'ddsa', 'mw'],
    "aśarīrin": ['ap90', 'mw'],
    "aśas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aśasta": ['ap90', 'gra', 'mw'],
    "aśastavāra": ['gra', 'mw'],
    "aśasti": ['gra', 'mw'],
    "aśastihan": ['gra', 'mw'],
    "aśastiḥ": ['ap90'],
    "aśastra": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśastrapāṇi": ['mw'],
    "aśastrapūta": ['cae'],
    "aśata": ['mw'],
    "aśatadakṣiṇa": ['mw'],
    "aśatru": ['ap90', 'gra', 'mw'],
    "aśauca": ['cae', 'ddsa', 'mw'],
    "aśaucaṃ": ['ap90'],
    "aśaurya": ['mw'],
    "aśauṇḍīrya": ['cae', 'mw'],
    "aśauṭīrya": ['mw'],
    "aśavāgni": ['mw'],
    "aśayya": ['mw'],
    "aśaṃka": ['ap90'],
    "aśaṅka": ['cae', 'ddsa', 'mw'],
    "aśaṅkam": ['mw'],
    "aśaṅkanīya": ['cae'],
    "aśaṅkayā": ['mw'],
    "aśaṅkita": ['cae', 'mw'],
    "aśaṅkitam": ['mw'],
    "aśaṅkya": ['mw'],
    "aśaṭha": ['cae', 'mw'],
    "aśeva": ['ap90', 'cae', 'gra', 'mw'],
    "aśeṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "aśeṣam": ['mw'],
    "aśeṣas": ['ap90', 'gra', 'mw'],
    "aśeṣasāmrājya": ['mw'],
    "aśeṣatas": ['mw'],
    "aśeṣatva": ['mw'],
    "aśeṣatā": ['ap90', 'mw'],
    "aśeṣaya": ['ddsa', 'mw'],
    "aśeṣayati": ['ap90'],
    "aśeṣeṇa": ['mw'],
    "aśeṣita": ['mw'],
    "aśika": ['mw'],
    "aśikha": ['mw'],
    "aśikṣita": ['cae', 'ddsa', 'mw'],
    "aśila": ['mw'],
    "aśilpin": ['ddsa'],
    "aśimida": ['gra', 'mw'],
    "aśimividviṣ": ['mw'],
    "aśin": ['ap90', 'mw'],
    "aśipada": ['gra', 'mw'],
    "aśira": ['mw'],
    "aśiras": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśiraska": ['cae', 'mw'],
    "aśiraḥ": ['ap90'],
    "aśiraḥsnāna": ['mw'],
    "aśita": ['ap90', 'ddsa', 'mw'],
    "aśitaka": ['bhs'],
    "aśitavya": ['cae', 'mw'],
    "aśitaṃgavīna": ['ap90', 'mw'],
    "aśithila": ['mw'],
    "aśithilaṃbhāva": ['mw'],
    "aśithira": ['mw'],
    "aśitra": ['cae', 'mw'],
    "aśitraḥ": ['ap90'],
    "aśitāvat": ['mw'],
    "aśitṛ": ['ap90', 'cae', 'mw'],
    "aśiva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aśivaśaṃsin": ['cae'],
    "aśiśira": ['cae', 'ddsa', 'mw'],
    "aśiśirakara": ['mw'],
    "aśiśirakiraṇa": ['mw'],
    "aśiśiraraśmi": ['mw'],
    "aśiśiratā": ['mw'],
    "aśiśiṣu": ['mw'],
    "aśiślikṣu": ['mw'],
    "aśiśu": ['ap90', 'gra', 'mw'],
    "aśiśvikā": ['mw'],
    "aśiṣya": ['ap90', 'mw'],
    "aśiṣyavṛtti": ['cae', 'mw'],
    "aśiṣṭa": ['ap90', 'mw'],
    "aśiṣṭatva": ['mw'],
    "aśiṣṭatā": ['mw'],
    "aśiṣṭha": ['ap90', 'mw'],
    "aśleṣa": ['bhs'],
    "aśleṣaka": ['bhs'],
    "aśleṣā": ['ap90', 'mw'],
    "aśleṣābhava": ['mw'],
    "aśleṣābhū": ['mw'],
    "aśleṣāvidhi": ['mw'],
    "aśliṣṭa": ['mw'],
    "aśliṣṭārtha": ['mw'],
    "aśloka": ['bhs'],
    "aślona": ['ap90'],
    "aśloṇa": ['mw'],
    "aślāghya": ['ap90', 'cae', 'ddsa', 'mw'],
    "aślāghā": ['ap90', 'mw'],
    "aślīka": ['ap90', 'cae', 'ddsa', 'mw'],
    "aślīla": ['ap90', 'ddsa', 'mw'],
    "aślīladṛḍharūpā": ['mw'],
    "aślīlaparivāda": ['mw'],
    "aślīlatva": ['mw'],
    "aślīlatā": ['mw'],
    "aśma": ['mw'],
    "aśmabheda": ['mw'],
    "aśmabhedaka": ['mw'],
    "aśmabhid": ['mw'],
    "aśmabhāla": ['mw'],
    "aśmacakra": ['gra', 'mw'],
    "aśmacita": ['mw'],
    "aśmacūrṇa": ['mw'],
    "aśmadidyu": ['cae', 'gra', 'mw'],
    "aśmadāraṇa": ['mw'],
    "aśmagandhā": ['mw'],
    "aśmagarbha": ['bhs', 'mw'],
    "aśmagarbhaja": ['mw'],
    "aśmagarbhamaya": ['mw'],
    "aśmaghna": ['mw'],
    "aśmahanman": ['gra', 'mw'],
    "aśmaja": ['mw'],
    "aśmajatu": ['mw'],
    "aśmaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśmakadalī": ['mw'],
    "aśmakasumantu": ['mw'],
    "aśmakaḥ": ['ap90'],
    "aśmaketu": ['mw'],
    "aśmakuṭṭa": ['cae', 'mw'],
    "aśmakuṭṭaka": ['cae', 'mw'],
    "aśmakī": ['mw'],
    "aśmaloṣṭranyāya": ['mw'],
    "aśmamaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśmamūrdhan": ['cae', 'mw'],
    "aśman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aśmanagara": ['mw'],
    "aśmanmaya": ['cae', 'gra', 'mw'],
    "aśmanta": ['mw'],
    "aśmantaka": ['bhs', 'cae', 'mw'],
    "aśmanvant": ['cae'],
    "aśmanvat": ['gra', 'mw'],
    "aśmaplava": ['cae', 'mw'],
    "aśmapurā": ['mw'],
    "aśmapuṣpa": ['mw'],
    "aśmara": ['ap90'],
    "aśmarī": ['ap90', 'mw'],
    "aśmarībhedana": ['mw'],
    "aśmarīghna": ['mw'],
    "aśmarīhara": ['mw'],
    "aśmasāra": ['mw'],
    "aśmasāramaya": ['mw'],
    "aśmasārin": ['mw'],
    "aśmatā": ['mw'],
    "aśmavarman": ['mw'],
    "aśmavarṣa": ['mw'],
    "aśmavarṣavat": ['mw'],
    "aśmavat": ['mw'],
    "aśmavraja": ['gra', 'mw'],
    "aśmavṛṣṭi": ['mw'],
    "aśmayokta": ['mw'],
    "aśmayoni": ['mw'],
    "aśmayu": ['mw'],
    "aśmaśru": ['mw'],
    "aśmaśānacit": ['mw'],
    "aśmaḥ": ['ap90'],
    "aśmaṃta": ['ap90'],
    "aśmaṃtakaḥ": ['ap90'],
    "aśmottha": ['mw'],
    "aśmādi": ['mw'],
    "aśmāntaka": ['mw'],
    "aśmāparāntaka": ['bhs'],
    "aśmāpidhāna": ['mw'],
    "aśmārma": ['mw'],
    "aśmāsia": ['gra'],
    "aśmāsya": ['gra', 'mw'],
    "aśmīraḥ": ['ap90'],
    "aśna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aśnat": ['mw'],
    "aśnavat": ['ddsa'],
    "aśnayā": ['ap90'],
    "aśni": ['mw'],
    "aśnyuṣṇi": ['mw'],
    "aśnītapibatā": ['ap90', 'mw'],
    "aśnītapibatīya": ['mw'],
    "aśobhamāna": ['mw'],
    "aśobhana": ['mw'],
    "aśoca": ['mw'],
    "aśocanīya": ['cae', 'ddsa', 'mw'],
    "aśocaḥ": ['ap90'],
    "aśocya": ['ap90', 'cae', 'mw'],
    "aśocyatva": ['mw'],
    "aśocyatā": ['mw'],
    "aśodhana": ['ap90'],
    "aśodhayitvā": ['cae', 'ddsa'],
    "aśodhita": ['mw'],
    "aśoka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "aśokabhāṇḍa": ['bhs', 'mw'],
    "aśokabhāṇḍaka": ['mw'],
    "aśokadatta": ['mw'],
    "aśokadvādaśī": ['mw'],
    "aśokakara": ['mw'],
    "aśokakarī": ['mw'],
    "aśokamalla": ['mw'],
    "aśokamañjarī": ['mw'],
    "aśokamālā": ['mw'],
    "aśokapūrṇimā": ['mw'],
    "aśokarohiṇī": ['mw'],
    "aśokasattva": ['bhs'],
    "aśokataru": ['mw'],
    "aśokatrirātra": ['mw'],
    "aśokatīrtha": ['mw'],
    "aśokavanika": ['mw'],
    "aśokavanikā": ['cae', 'mw'],
    "aśokavanikānyāya": ['mw'],
    "aśokavardhana": ['mw'],
    "aśokavarṇa": ['bhs'],
    "aśokavega": ['mw'],
    "aśokaviraja": ['bhs'],
    "aśokavrata": ['mw'],
    "aśokaśrī": ['bhs', 'mw'],
    "aśokaṣaṣṭhī": ['mw'],
    "aśokeśvara": ['mw'],
    "aśokeśvaratīrtha": ['mw'],
    "aśokā": ['bhs', 'mw'],
    "aśokāhvaya": ['bhs'],
    "aśokāntara": ['mw'],
    "aśokāri": ['mw'],
    "aśokāṣṭamī": ['mw'],
    "aśokīkṛ": ['mw'],
    "aśoṣya": ['ddsa', 'mw'],
    "aśra": ['ddsa', 'mw'],
    "aśraddadhāna": ['ap90', 'ddsa', 'mw'],
    "aśraddadhānatā": ['bhs'],
    "aśraddadhānīya": ['bhs'],
    "aśraddha": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "aśraddhadhāna": ['cae'],
    "aśraddheya": ['ap90', 'cae', 'mw'],
    "aśraddhita": ['mw'],
    "aśraddhya": ['bhs', 'mw'],
    "aśraddhā": ['ddsa', 'mw'],
    "aśrama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aśramaṇa": ['ap90', 'gra', 'mw'],
    "aśrameṇa": ['mw'],
    "aśramiṣṭha": ['gra', 'mw'],
    "aśrauta": ['ap90'],
    "aśravaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśravaṇāt": ['mw'],
    "aśravaṇīya": ['mw'],
    "aśraḥ": ['ap90'],
    "aśreyas": ['ap90', 'ddsa', 'mw'],
    "aśreyaska": ['mw'],
    "aśreyaṃs": ['cae'],
    "aśreṇika": ['bhs'],
    "aśreṣman": ['mw'],
    "aśreṣṭha": ['ap90', 'mw'],
    "aśri": ['cae', 'ddsa', 'gra', 'mw'],
    "aśrimat": ['ap90', 'mw'],
    "aśrin": ['ap90'],
    "aśrita": ['ap90', 'gra', 'mw'],
    "aśriḥ": ['ap90'],
    "aśrotra": ['cae', 'ddsa', 'mw'],
    "aśrotriya": ['cae', 'ddsa', 'mw'],
    "aśrotṛ": ['mw'],
    "aśru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aśrudhārā": ['cae', 'mw'],
    "aśruka": ['bhs'],
    "aśrukarman": ['mw'],
    "aśrukaṇṭha": ['cae'],
    "aśruleśa": ['mw'],
    "aśrulocana": ['mw'],
    "aśrumaya": ['mw'],
    "aśrumukha": ['mw'],
    "aśrunetra": ['mw'],
    "aśrunipāta": ['mw'],
    "aśrunālī": ['mw'],
    "aśruparipluta": ['ddsa', 'mw'],
    "aśrupariplutākṣa": ['mw'],
    "aśruplāvita": ['mw'],
    "aśrupramārjana": ['mw'],
    "aśrupravāha": ['mw'],
    "aśrupāta": ['mw'],
    "aśrupūrṇa": ['mw'],
    "aśruta": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśrutavat": ['mw'],
    "aśrutavraṇa": ['mw'],
    "aśruti": ['ap90', 'ddsa', 'mw'],
    "aśrutidhara": ['mw'],
    "aśrutitva": ['mw'],
    "aśrutā": ['mw'],
    "aśruvadana": ['mw'],
    "aśruvaha": ['mw'],
    "aśruvilocana": ['mw'],
    "aśrāddha": ['ap90', 'bhs', 'mw'],
    "aśrāddhabhojin": ['mw'],
    "aśrāddheya": ['mw'],
    "aśrāddhin": ['cae', 'mw'],
    "aśrāddhya": ['bhs'],
    "aśrāmaṇaka": ['bhs'],
    "aśrāmaṇya": ['bhs'],
    "aśrānta": ['cae', 'ddsa', 'gra', 'mw'],
    "aśrāta": ['gra', 'mw'],
    "aśrātas": ['ap90'],
    "aśrāvya": ['ap90', 'mw'],
    "aśrāṃta": ['ap90'],
    "aśrī": ['ddsa', 'mw'],
    "aśrīka": ['ap90', 'mw'],
    "aśrīla": ['ap90'],
    "aśrīmat": ['ap90', 'mw'],
    "aśrīra": ['ap90', 'gra', 'mw'],
    "aśrīvī": ['mw'],
    "aśrūpahata": ['mw'],
    "aśubha": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśubhabhāvanā": ['bhs'],
    "aśubhacintaka": ['mw'],
    "aśubhadarśana": ['mw'],
    "aśubhamati": ['cae'],
    "aśubhatasaṃjñi": ['bhs'],
    "aśubhātmaka": ['mw'],
    "aśuci": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśucibhakṣaṇa": ['cae'],
    "aśucibhāva": ['cae', 'mw'],
    "aśucikara": ['mw'],
    "aśucikuṇapa": ['bhs'],
    "aśucilipta": ['mw'],
    "aśucitva": ['mw'],
    "aśucitā": ['mw'],
    "aśucivrata": ['cae', 'mw'],
    "aśuddha": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśuddhaprakṛti": ['mw'],
    "aśuddhavāsaka": ['mw'],
    "aśuddhi": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśukla": ['mw'],
    "aśuklavat": ['mw'],
    "aśuna": ['mw'],
    "aśuśrūṣu": ['mw'],
    "aśuśrūṣā": ['mw'],
    "aśuśūṣu": ['cae'],
    "aśuśūṣā": ['cae'],
    "aśuṣa": ['ap90', 'cae', 'gra', 'mw'],
    "aśuṣka": ['cae', 'mw'],
    "aśuṣkāgra": ['mw'],
    "aśva": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "aśvaballava": ['mw'],
    "aśvabalā": ['mw'],
    "aśvabandha": ['mw'],
    "aśvabandhaka": ['mw'],
    "aśvabandhana": ['mw'],
    "aśvabhāra": ['mw'],
    "aśvabudhna": ['gra', 'mw'],
    "aśvabudhya": ['gra', 'mw'],
    "aśvabāhu": ['mw'],
    "aśvacakra": ['mw'],
    "aśvacalanaśālā": ['mw'],
    "aśvacaryā": ['mw'],
    "aśvacikitsā": ['mw'],
    "aśvada": ['cae', 'mw'],
    "aśvadaṃṣṭrā": ['mw'],
    "aśvadeva": ['mw'],
    "aśvadhāṭī": ['mw'],
    "aśvadvādaśa": ['mw'],
    "aśvadā": ['gra', 'mw'],
    "aśvadāvan": ['cae', 'gra', 'mw'],
    "aśvadāya": ['mw'],
    "aśvadūta": ['mw'],
    "aśvagandhā": ['mw'],
    "aśvagati": ['mw'],
    "aśvaghna": ['gra', 'mw'],
    "aśvaghoṣa": ['bhs', 'mw'],
    "aśvaghāma": ['mw'],
    "aśvaghāsa": ['mw'],
    "aśvagopa": ['mw'],
    "aśvagoyuga": ['mw'],
    "aśvagoṣṭha": ['mw'],
    "aśvagrīva": ['mw'],
    "aśvagupta": ['bhs', 'mw'],
    "aśvahana": ['mw'],
    "aśvahantṛ": ['mw'],
    "aśvahanu": ['mw'],
    "aśvahavis": ['mw'],
    "aśvahaya": ['gra', 'mw'],
    "aśvahāraka": ['cae', 'mw'],
    "aśvahṛdaya": ['cae', 'mw'],
    "aśvahṛdayā": ['mw'],
    "aśvaikaviṃśa": ['mw'],
    "aśvait": ['ddsa'],
    "aśvajaghana": ['mw'],
    "aśvajit": ['bhs', 'gra', 'mw'],
    "aśvaka": ['ap90', 'bhs', 'mw'],
    "aśvakanda": ['mw'],
    "aśvakandikā": ['mw'],
    "aśvakarṇa": ['bhs', 'cae', 'mw'],
    "aśvakarṇaka": ['mw'],
    "aśvakaśā": ['mw'],
    "aśvakeśa": ['mw'],
    "aśvakhura": ['cae', 'mw'],
    "aśvakhurī": ['mw'],
    "aśvaki": ['bhs'],
    "aśvakinī": ['ap90', 'mw'],
    "aśvakovida": ['mw'],
    "aśvakranda": ['mw'],
    "aśvakrānta": ['mw'],
    "aśvakrīta": ['mw'],
    "aśvakuñjara": ['mw'],
    "aśvakuṇapa": ['mw'],
    "aśvakuṭī": ['mw'],
    "aśvakṣabha": ['mw'],
    "aśvala": ['mw'],
    "aśvalalita": ['mw'],
    "aśvalavaṇa": ['mw'],
    "aśvalaḥ": ['ap90'],
    "aśvaloman": ['mw'],
    "aśvalālā": ['mw'],
    "aśvamacarcikā": ['mw'],
    "aśvamahiṣa": ['mw'],
    "aśvamahiṣikā": ['mw'],
    "aśvamandurā": ['mw'],
    "aśvamatallikā": ['mw'],
    "aśvamaṇiṃda": ['mw'],
    "aśvamedha": ['cae', 'gra', 'mw'],
    "aśvamedhadatta": ['mw'],
    "aśvamedhaja": ['mw'],
    "aśvamedhaka": ['mw'],
    "aśvamedhakāṇḍa": ['mw'],
    "aśvamedhatva": ['mw'],
    "aśvamedhavat": ['mw'],
    "aśvamedhayājin": ['mw'],
    "aśvamedheśvara": ['mw'],
    "aśvamedhika": ['mw'],
    "aśvamedhin": ['mw'],
    "aśvamedhīya": ['mw'],
    "aśvamitra": ['mw'],
    "aśvamiṣṭi": ['gra', 'mw'],
    "aśvamohaka": ['mw'],
    "aśvamukha": ['cae', 'mw'],
    "aśvamukhī": ['mw'],
    "aśvamāla": ['mw'],
    "aśvamāra": ['mw'],
    "aśvamāraka": ['mw'],
    "aśvanadī": ['cae', 'mw'],
    "aśvanibandhika": ['mw'],
    "aśvanirṇij": ['gra', 'mw'],
    "aśvanta": ['mw'],
    "aśvanāga": ['mw'],
    "aśvanāman": ['mw'],
    "aśvanāya": ['mw'],
    "aśvanāśaka": ['mw'],
    "aśvapa": ['cae', 'mw'],
    "aśvapad": ['mw'],
    "aśvapada": ['mw'],
    "aśvaparaśu": ['mw'],
    "aśvaparṇa": ['cae', 'gra', 'mw'],
    "aśvaparṇī": ['mw'],
    "aśvapastia": ['gra'],
    "aśvapastya": ['gra', 'mw'],
    "aśvapati": ['gra', 'mw'],
    "aśvapatyādi": ['mw'],
    "aśvapaṇya": ['mw'],
    "aśvapeja": ['mw'],
    "aśvapeya": ['mw'],
    "aśvapeśas": ['gra', 'mw'],
    "aśvapluta": ['mw'],
    "aśvapota": ['mw'],
    "aśvapoṣaka": ['mw'],
    "aśvaprakāṇḍa": ['mw'],
    "aśvaprapatana": ['mw'],
    "aśvaprapatanīya": ['mw'],
    "aśvapraṇīta": ['mw'],
    "aśvapriya": ['mw'],
    "aśvapucchaka": ['mw'],
    "aśvapucchikā": ['mw'],
    "aśvapād": ['mw'],
    "aśvapāda": ['mw'],
    "aśvapāla": ['cae', 'mw'],
    "aśvapūrṇa": ['mw'],
    "aśvapṛṣṭha": ['bhs', 'gra', 'mw'],
    "aśvara": ['bhs'],
    "aśvarakṣa": ['mw'],
    "aśvaratha": ['mw'],
    "aśvarathadāna": ['mw'],
    "aśvarathā": ['mw'],
    "aśvaratna": ['mw'],
    "aśvaripu": ['mw'],
    "aśvarodhaka": ['mw'],
    "aśvarādhas": ['gra', 'mw'],
    "aśvarāja": ['cae', 'mw'],
    "aśvasani": ['mw'],
    "aśvasaṃkhya": ['mw'],
    "aśvasena": ['cae', 'mw'],
    "aśvasravaṇa": ['mw'],
    "aśvastana": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśvastanavid": ['mw'],
    "aśvastanavidhāna": ['cae', 'mw'],
    "aśvastanavidhātṛ": ['mw'],
    "aśvastanika": ['cae', 'mw'],
    "aśvastha": ['bhs'],
    "aśvasthāna": ['ddsa', 'mw'],
    "aśvastomīya": ['mw'],
    "aśvasya": ['mw'],
    "aśvasyati": ['ap90'],
    "aśvasā": ['gra', 'mw'],
    "aśvasāda": ['mw'],
    "aśvasādhana": ['mw'],
    "aśvasādin": ['mw'],
    "aśvasārathya": ['cae', 'mw'],
    "aśvasūkta": ['mw'],
    "aśvasūktin": ['mw'],
    "aśvasūnṛta": ['gra', 'mw'],
    "aśvasūta": ['mw'],
    "aśvasūtra": ['mw'],
    "aśvasṛgālikā": ['mw'],
    "aśvatara": ['ap90', 'cae', 'mw'],
    "aśvatarā": ['mw'],
    "aśvatarāśva": ['mw'],
    "aśvatarī": ['mw'],
    "aśvatarīratha": ['mw'],
    "aśvatha": ['gra', 'mw'],
    "aśvati": ['ap90'],
    "aśvatrirātra": ['mw'],
    "aśvattha": ['cae', 'ddsa', 'gra', 'mw'],
    "aśvatthabheda": ['mw'],
    "aśvatthaka": ['ap90', 'mw'],
    "aśvatthakalpa": ['mw'],
    "aśvatthakuṇa": ['mw'],
    "aśvatthapūjā": ['mw'],
    "aśvatthavivāha": ['mw'],
    "aśvatthaśākhā": ['mw'],
    "aśvatthaḥ": ['ap90'],
    "aśvatthika": ['ap90', 'mw'],
    "aśvatthikā": ['mw'],
    "aśvatthila": ['ap90', 'mw'],
    "aśvatthodyāpana": ['mw'],
    "aśvatthā": ['mw'],
    "aśvatthāma": ['mw'],
    "aśvatthāman": ['ap90', 'cae', 'mw'],
    "aśvatthī": ['mw'],
    "aśvatthīya": ['mw'],
    "aśvatva": ['mw'],
    "aśvatīrtha": ['mw'],
    "aśvatīrthika": ['bhs'],
    "aśvavadana": ['mw'],
    "aśvavaha": ['mw'],
    "aśvavaidya": ['mw'],
    "aśvavaktra": ['mw'],
    "aśvavant": ['cae'],
    "aśvavat": ['gra', 'mw'],
    "aśvavatī": ['mw'],
    "aśvavaḍava": ['mw'],
    "aśvavid": ['gra', 'mw'],
    "aśvavikrayin": ['mw'],
    "aśvavrata": ['mw'],
    "aśvavāha": ['mw'],
    "aśvavāhyālī": ['mw'],
    "aśvavāla": ['mw'],
    "aśvavāra": ['mw'],
    "aśvavāraka": ['mw'],
    "aśvavāraṇa": ['mw'],
    "aśvavāṇija": ['mw'],
    "aśvavṛndin": ['mw'],
    "aśvavṛndāraka": ['mw'],
    "aśvavṛṣa": ['cae', 'mw'],
    "aśvay": ['gra'],
    "aśvaya": ['mw'],
    "aśvayajña": ['mw'],
    "aśvayati": ['ap90'],
    "aśvayoga": ['gra', 'mw'],
    "aśvayu": ['ap90', 'gra', 'mw'],
    "aśvayuj": ['cae', 'gra', 'mw'],
    "aśvayuja": ['mw'],
    "aśvayukta": ['mw'],
    "aśvayā": ['ap90', 'gra', 'mw'],
    "aśvayūpa": ['gra', 'mw'],
    "aśvaśaka": ['mw'],
    "aśvaśakṛt": ['mw'],
    "aśvaśapha": ['mw'],
    "aśvaśaphabudhna": ['mw'],
    "aśvaśaphamātra": ['mw'],
    "aśvaśatru": ['mw'],
    "aśvaśaṅku": ['mw'],
    "aśvaścandra": ['gra', 'mw'],
    "aśvaśiras": ['mw'],
    "aśvaśiśna": ['mw'],
    "aśvaśākhoṭa": ['mw'],
    "aśvaśālā": ['cae', 'mw'],
    "aśvaśāstra": ['mw'],
    "aśvaśāva": ['mw'],
    "aśvaśīrṣa": ['bhs', 'mw'],
    "aśvaḥ": ['ap90'],
    "aśvaṃta": ['ap90'],
    "aśvaṣaḍgava": ['mw'],
    "aśvaṣā": ['mw'],
    "aśveṣita": ['gra', 'mw'],
    "aśvia": ['gra'],
    "aśvidevatāka": ['mw'],
    "aśvika": ['ap90', 'mw'],
    "aśvikā": ['mw'],
    "aśvimat": ['ap90', 'mw'],
    "aśvin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aśvinakṛta": ['mw'],
    "aśvinī": ['ap90', 'mw'],
    "aśvinīkumāra": ['mw'],
    "aśvinīputrau": ['mw'],
    "aśvinīsutau": ['mw'],
    "aśvisuta": ['mw'],
    "aśvisālokya": ['mw'],
    "aśviya": ['ap90', 'cae', 'gra', 'mw'],
    "aśvorasa": ['mw'],
    "aśvya": ['ap90', 'cae', 'gra', 'mw'],
    "aśvā": ['ap90', 'mw'],
    "aśvābhidhānī": ['mw'],
    "aśvābhidhānīkṛta": ['mw'],
    "aśvādhika": ['ddsa', 'mw'],
    "aśvādhyakṣa": ['cae', 'mw'],
    "aśvādi": ['mw'],
    "aśvājanī": ['gra', 'mw'],
    "aśvājāneya": ['mw'],
    "aśvākṣa": ['mw'],
    "aśvāmagha": ['gra', 'mw'],
    "aśvāmukha": ['mw'],
    "aśvānana": ['mw'],
    "aśvāntaka": ['mw'],
    "aśvānusaraṇa": ['mw'],
    "aśvānīka": ['cae', 'mw'],
    "aśvānṛta": ['cae', 'mw'],
    "aśvāpad": ['mw'],
    "aśvāri": ['mw'],
    "aśvāroha": ['mw'],
    "aśvārohā": ['mw'],
    "aśvārūḍha": ['cae', 'mw'],
    "aśvāvant": ['cae'],
    "aśvāvarohaka": ['mw'],
    "aśvāvarohikā": ['mw'],
    "aśvāvat": ['ddsa', 'gra', 'mw'],
    "aśvāvatāna": ['mw'],
    "aśvāvatāra": ['mw'],
    "aśvāvatī": ['mw'],
    "aśvāy": ['gra'],
    "aśvāya": ['mw'],
    "aśvāyati": ['ap90'],
    "aśvāyurveda": ['mw'],
    "aśvāyus": ['mw'],
    "aśvīna": ['ap90'],
    "aśvīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśyartha": ['ddsa'],
    "aśābda": ['mw'],
    "aśākhā": ['mw'],
    "aśāmya": ['ap90', 'mw'],
    "aśānta": ['cae', 'mw'],
    "aśāntatanu": ['ddsa'],
    "aśāntatā": ['ddsa', 'mw'],
    "aśānti": ['mw'],
    "aśāntikara": ['mw'],
    "aśārīrika": ['ap90'],
    "aśāsana": ['ap90', 'mw'],
    "aśāsant": ['cae'],
    "aśāsanīya": ['ap90'],
    "aśāsat": ['ddsa', 'mw'],
    "aśāsia": ['gra'],
    "aśāstra": ['ap90', 'mw'],
    "aśāstracakṣus": ['ddsa'],
    "aśāstrasiddha": ['mw'],
    "aśāstravihita": ['cae', 'mw'],
    "aśāstrīya": ['ap90', 'mw'],
    "aśāsya": ['gra', 'mw'],
    "aśāta": ['bhs'],
    "aśāy": ['cae', 'gra'],
    "aśāya": ['mw'],
    "aśāśvata": ['ap90', 'cae', 'mw'],
    "aśāśvatam": ['bhs'],
    "aśāṃta": ['ap90'],
    "aśīla": ['ap90', 'mw'],
    "aśīrtatanu": ['mw'],
    "aśīrya": ['cae', 'mw'],
    "aśīrṇa": ['mw'],
    "aśīrṣaka": ['ap90', 'cae', 'mw'],
    "aśīrṣan": ['cae', 'gra', 'mw'],
    "aśīrṣika": ['mw'],
    "aśīrṣin": ['mw'],
    "aśīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśītakara": ['mw'],
    "aśītala": ['mw'],
    "aśītama": ['mw'],
    "aśītaruc": ['mw'],
    "aśītatanu": ['mw'],
    "aśīti": ['cae', 'ddsa', 'gra', 'mw'],
    "aśītibhāga": ['cae', 'mw'],
    "aśītika": ['ap90', 'ddsa', 'mw'],
    "aśītikāvara": ['mw'],
    "aśītitama": ['cae', 'mw'],
    "aśītiḥ": ['ap90'],
    "aśītyakṣara": ['mw'],
    "aśītyakṣaratva": ['mw'],
    "aśītīṣṭaka": ['mw'],
    "aśūdra": ['mw'],
    "aśūdrocchiṣṭin": ['mw'],
    "aśūlā": ['ap90', 'mw'],
    "aśūnya": ['ap90', 'cae', 'ddsa', 'mw'],
    "aśūnyatā": ['mw'],
    "aśūnyaśayana": ['mw'],
    "aśūnyaśayanadvitīyā": ['mw'],
    "aśūnyaśayanavrata": ['mw'],
    "aśūnyopasthā": ['mw'],
    "aśṛta": ['ap90', 'mw'],
    "aśṛthita": ['ap90', 'gra', 'mw'],
    "aśṛṅga": ['ddsa', 'mw'],
    "aśṛṇvat": ['mw'],
    "a˚": ['ddsa'],
    "aḍ": ['ap90', 'mw'],
    "aḍakavatī": ['bhs', 'mw'],
    "aḍara": ['mw'],
    "aḍuva": ['mw'],
    "aḍḍ": ['ap90', 'mw'],
    "aḍḍacalaḥ": ['ap90'],
    "aḍḍana": ['mw'],
    "aḍḍanaṃ": ['ap90'],
    "aḍḍha": ['cped'],
    "aḍḍhaduka": ['cped'],
    "aḍḍhakumbhūpama": ['cped'],
    "aḍḍhakusi": ['cped'],
    "aḍḍhakuḍḍaka": ['cped'],
    "aḍḍhakāsika": ['cped'],
    "aḍḍhakāsiya": ['cped'],
    "aḍḍhakāyika": ['cped'],
    "aḍḍhamaṇḍala": ['cped'],
    "aḍḍhamāsa": ['cped'],
    "aḍḍhamāsika": ['cped'],
    "aḍḍhapallaṅka": ['cped'],
    "aḍḍharatta": ['cped'],
    "aḍḍharatti": ['cped'],
    "aḍḍharattā": ['cped'],
    "aḍḍhateyya": ['cped'],
    "aḍḍhateḷasa": ['cped'],
    "aḍḍhatiya": ['bhs'],
    "aḍḍhavāda": ['cped'],
    "aḍḍhayoga": ['cped'],
    "aḍḍhaṭṭhama": ['cped'],
    "aḷa": ['cped'],
    "aṁsa": ['cped'],
    "aṁsabaddha": ['cped'],
    "aṁsabandhaka": ['cped'],
    "aṁsakūṭa": ['cped'],
    "aṁsā": ['cped'],
    "aṃb": ['ap90'],
    "aṃbakaṃ": ['ap90'],
    "aṃbaraṃ": ['ap90'],
    "aṃbaryati": ['ap90'],
    "aṃbarīṣaṃ": ['ap90'],
    "aṃbayā": ['ap90'],
    "aṃbaḥ": ['ap90'],
    "aṃbaṣṭhakī": ['ap90'],
    "aṃbaṣṭhaḥ": ['ap90'],
    "aṃbaṣṭhikā": ['ap90'],
    "aṃbh": ['ap90'],
    "aṃbhas": ['ap90'],
    "aṃbhojinī": ['ap90'],
    "aṃbhṛṇa": ['ap90'],
    "aṃbikeyaḥ": ['ap90'],
    "aṃbikā": ['ap90'],
    "aṃbiḥ": ['ap90'],
    "aṃbu": ['ap90'],
    "aṃbumat": ['ap90'],
    "aṃbyaḥ": ['ap90'],
    "aṃbā": ['ap90'],
    "aṃbālikā": ['ap90'],
    "aṃbāyuḥ": ['ap90'],
    "aṃbāḍā": ['ap90'],
    "aṃbūkṛta": ['ap90'],
    "aṃc": ['ap90'],
    "aṃcalaḥ": ['ap90'],
    "aṃcatiḥ": ['ap90'],
    "aṃcita": ['ap90'],
    "aṃd": ['ap90'],
    "aṃdaḥ": ['ap90'],
    "aṃdh": ['ap90'],
    "aṃdha": ['ap90'],
    "aṃdhaka": ['ap90'],
    "aṃdhas": ['ap90'],
    "aṃdhaṃbhaviṣṇu": ['ap90'],
    "aṃdhaṃkaraṇa": ['ap90'],
    "aṃdhikā": ['ap90'],
    "aṃdhra": ['ap90'],
    "aṃdhraḥ": ['ap90'],
    "aṃdhulaḥ": ['ap90'],
    "aṃdhuḥ": ['ap90'],
    "aṃdhībhū": ['ap90'],
    "aṃdhīkṛ": ['ap90'],
    "aṃdikā": ['ap90'],
    "aṃdolanaṃ": ['ap90'],
    "aṃdolayati": ['ap90'],
    "aṃduḥ": ['ap90'],
    "aṃg": ['ap90'],
    "aṃga": ['ap90'],
    "aṃgadaṃ": ['ap90'],
    "aṃgakaṃ": ['ap90'],
    "aṃganaṃ": ['ap90'],
    "aṃganā": ['ap90'],
    "aṃgas": ['ap90'],
    "aṃgatiḥ": ['ap90'],
    "aṃgavaṃ": ['ap90'],
    "aṃgaṃ": ['ap90'],
    "aṃgaṇaṃ": ['ap90'],
    "aṃgh": ['ap90'],
    "aṃghas": ['ap90'],
    "aṃghri": ['ap90'],
    "aṃghāri": ['ap90'],
    "aṃgikā": ['ap90'],
    "aṃgin": ['ap90'],
    "aṃgir": ['ap90'],
    "aṃgirasaḥ": ['ap90'],
    "aṃgirastama": ['ap90'],
    "aṃgirasvat": ['ap90'],
    "aṃgirasāmayanaṃ": ['ap90'],
    "aṃgiraḥ": ['ap90'],
    "aṃgulaḥ": ['ap90'],
    "aṃgulikā": ['ap90'],
    "aṃguliḥ": ['ap90'],
    "aṃgulīyaṃ": ['ap90'],
    "aṃguriḥ": ['ap90'],
    "aṃguḥ": ['ap90'],
    "aṃguṣṭhaḥ": ['ap90'],
    "aṃguṣṭhyaḥ": ['ap90'],
    "aṃgya": ['ap90'],
    "aṃgārakaḥ": ['ap90'],
    "aṃgārakita": ['ap90'],
    "aṃgāraḥ": ['ap90'],
    "aṃgārikā": ['ap90'],
    "aṃgārita": ['ap90'],
    "aṃgāriḥ": ['ap90'],
    "aṃgāriṇī": ['ap90'],
    "aṃgāryā": ['ap90'],
    "aṃgārīya": ['ap90'],
    "aṃgīkāraḥ": ['ap90'],
    "aṃgīkṛ": ['ap90'],
    "aṃgīya": ['ap90'],
    "aṃgūṣaḥ": ['ap90'],
    "aṃh": ['ap90', 'cae', 'gra', 'mw'],
    "aṃhana": ['mw'],
    "aṃhas": ['ap90', 'ddsa', 'gra', 'mw'],
    "aṃhasaspati": ['mw'],
    "aṃhasaspatiḥ": ['ap90'],
    "aṃhaspati": ['mw'],
    "aṃhaspatya": ['mw'],
    "aṃhasvat": ['ap90'],
    "aṃhati": ['cae', 'ddsa', 'gra', 'mw'],
    "aṃhatiḥ": ['ap90'],
    "aṃhatī": ['mw'],
    "aṃhiti": ['mw'],
    "aṃhitiḥ": ['ap90'],
    "aṃholiṅga": ['mw'],
    "aṃhomuc": ['gra', 'mw'],
    "aṃhoyu": ['ap90', 'gra', 'mw'],
    "aṃhri": ['cae', 'ddsa', 'mw'],
    "aṃhripa": ['mw'],
    "aṃhriskandha": ['mw'],
    "aṃhriśiras": ['mw'],
    "aṃhriḥ": ['ap90'],
    "aṃhu": ['ap90', 'gra', 'mw'],
    "aṃhubhedī": ['mw'],
    "aṃhura": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aṃhīyaṃs": ['cae'],
    "aṃhūraṇa": ['ap90', 'cae', 'gra', 'mw'],
    "aṃj": ['ap90'],
    "aṃjalikā": ['ap90'],
    "aṃjaliḥ": ['ap90'],
    "aṃjanakaḥ": ['ap90'],
    "aṃjanaḥ": ['ap90'],
    "aṃjanikā": ['ap90'],
    "aṃjanā": ['ap90'],
    "aṃjanāvatī": ['ap90'],
    "aṃjanī": ['ap90'],
    "aṃjas": ['ap90'],
    "aṃjasa": ['ap90'],
    "aṃjasā": ['ap90'],
    "aṃjasīna": ['ap90'],
    "aṃji": ['ap90'],
    "aṃjiva": ['ap90'],
    "aṃjiṣṭhaḥ": ['ap90'],
    "aṃjī": ['ap90'],
    "aṃjīraḥ": ['ap90'],
    "aṃk": ['ap90'],
    "aṃkanaṃ": ['ap90'],
    "aṃkas": ['ap90'],
    "aṃkasaṃ": ['ap90'],
    "aṃkatiḥ": ['ap90'],
    "aṃkaḥ": ['ap90'],
    "aṃkh": ['ap90'],
    "aṃkin": ['ap90'],
    "aṃkolikā": ['ap90'],
    "aṃkoṭaḥ": ['ap90'],
    "aṃkupaṃ": ['ap90'],
    "aṃkurakaḥ": ['ap90'],
    "aṃkuraḥ": ['ap90'],
    "aṃkurita": ['ap90'],
    "aṃkuśaḥ": ['ap90'],
    "aṃkuśin": ['ap90'],
    "aṃkuśita": ['ap90'],
    "aṃkuṭaḥ": ['ap90'],
    "aṃkya": ['ap90'],
    "aṃkūraḥ": ['ap90'],
    "aṃkūyat": ['ap90'],
    "aṃkūṣaḥ": ['ap90'],
    "aṃs": ['ap90', 'mw'],
    "aṃsa": ['cae', 'ddsa', 'gra', 'mw'],
    "aṃsabhāra": ['mw'],
    "aṃsabhārika": ['mw'],
    "aṃsadaghna": ['mw'],
    "aṃsadhrī": ['mw'],
    "aṃsadhātrī": ['bhs'],
    "aṃsakūṭa": ['cae', 'ddsa', 'mw'],
    "aṃsala": ['ap90', 'cae', 'ddsa', 'mw'],
    "aṃsamūla": ['mw'],
    "aṃsaphalaka": ['ddsa', 'mw'],
    "aṃsapīṭha": ['mw'],
    "aṃsapṛṣṭha": ['mw'],
    "aṃsatra": ['cae', 'ddsa', 'gra', 'mw'],
    "aṃsatrakośa": ['gra', 'mw'],
    "aṃsavartin": ['cae', 'ddsa'],
    "aṃsavyāpin": ['cae'],
    "aṃsaḥ": ['ap90'],
    "aṃsebhāra": ['mw'],
    "aṃsebhārika": ['mw'],
    "aṃsia": ['gra'],
    "aṃsoccaya": ['mw'],
    "aṃsya": ['ap90', 'gra', 'mw'],
    "aṃt": ['ap90'],
    "aṃta": ['ap90'],
    "aṃtaka": ['ap90'],
    "aṃtama": ['ap90'],
    "aṃtar": ['ap90'],
    "aṃtara": ['ap90'],
    "aṃtaratama": ['ap90'],
    "aṃtarataḥ": ['ap90'],
    "aṃtarayati": ['ap90'],
    "aṃtarayaḥ": ['ap90'],
    "aṃtarbhava": ['ap90'],
    "aṃtarbhāvanā": ['ap90'],
    "aṃtarbhāvaḥ": ['ap90'],
    "aṃtarbhū": ['ap90'],
    "aṃtarbhūta": ['ap90'],
    "aṃtardhiḥ": ['ap90'],
    "aṃtardhā": ['ap90'],
    "aṃtardhānaṃ": ['ap90'],
    "aṃtardhāyaka": ['ap90'],
    "aṃtare": ['ap90'],
    "aṃtareṇa": ['ap90'],
    "aṃtargam": ['ap90'],
    "aṃtargata": ['ap90'],
    "aṃtarhita": ['ap90'],
    "aṃtari": ['ap90'],
    "aṃtarita": ['ap90'],
    "aṃtarya": ['ap90'],
    "aṃtarā": ['ap90'],
    "aṃtarālaṃ": ['ap90'],
    "aṃtarīpaḥ": ['ap90'],
    "aṃtarīyaṃ": ['ap90'],
    "aṃtataḥ": ['ap90'],
    "aṃtavat": ['ap90'],
    "aṃte": ['ap90'],
    "aṃti": ['ap90'],
    "aṃtika": ['ap90'],
    "aṃtikā": ['ap90'],
    "aṃtima": ['ap90'],
    "aṃtitaḥ": ['ap90'],
    "aṃtraṃ": ['ap90'],
    "aṃtraṃdhamiḥ": ['ap90'],
    "aṃtya": ['ap90'],
    "aṃtyakaḥ": ['ap90'],
    "aṃtī": ['ap90'],
    "aṃś": ['ap90', 'gra', 'mw'],
    "aṃśa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "aṃśabhāgin": ['cae', 'ddsa', 'mw'],
    "aṃśabhāj": ['cae', 'ddsa', 'mw'],
    "aṃśabhū": ['mw'],
    "aṃśabhūta": ['cae', 'ddsa', 'mw'],
    "aṃśadhātrī": ['bhs'],
    "aṃśahara": ['ddsa', 'mw'],
    "aṃśahārin": ['mw'],
    "aṃśaka": ['mw'],
    "aṃśakalpanā": ['cae', 'ddsa', 'mw'],
    "aṃśakaraṇa": ['mw'],
    "aṃśakaḥ": ['ap90'],
    "aṃśala": ['ap90', 'mw'],
    "aṃśanaṃ": ['ap90'],
    "aṃśapradāna": ['cae', 'ddsa', 'mw'],
    "aṃśaprakalpanā": ['cae', 'ddsa', 'mw'],
    "aṃśarūpiṇī": ['mw'],
    "aṃśasavarṇana": ['mw'],
    "aṃśasvara": ['mw'],
    "aṃśavat": ['mw'],
    "aṃśayitṛ": ['ap90'],
    "aṃśaḥ": ['ap90'],
    "aṃśika": ['bhs'],
    "aṃśin": ['ap90', 'ddsa', 'mw'],
    "aṃśitā": ['mw'],
    "aṃśu": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "aṃśubhartṛ": ['mw'],
    "aṃśudhara": ['mw'],
    "aṃśudhāna": ['mw'],
    "aṃśudhāraya": ['mw'],
    "aṃśuhasta": ['mw'],
    "aṃśujāla": ['mw'],
    "aṃśuka": ['cae', 'ddsa', 'mw'],
    "aṃśukaṃ": ['ap90'],
    "aṃśukānta": ['cae', 'ddsa'],
    "aṃśula": ['ap90', 'mw'],
    "aṃśumant": ['cae'],
    "aṃśumat": ['ap90', 'ddsa', 'gra', 'mw'],
    "aṃśumatphalā": ['mw'],
    "aṃśumatī": ['mw'],
    "aṃśumālin": ['ddsa', 'mw'],
    "aṃśumālā": ['mw'],
    "aṃśunadī": ['mw'],
    "aṃśupati": ['mw'],
    "aṃśupaṭṭa": ['cae', 'ddsa', 'mw'],
    "aṃśuvimarda": ['mw'],
    "aṃśuvāṇa": ['mw'],
    "aṃśuḥ": ['ap90'],
    "aṃśvādi": ['mw'],
    "aṃśya": ['ap90'],
    "aṃśāvataraṇa": ['mw'],
    "aṃśāṃsi": ['mw'],
    "aṃśāṃśa": ['mw'],
    "aṃśīkṛ": ['mw'],
    "aṃśūdaka": ['mw'],
    "aṃḍakaḥ": ['ap90'],
    "aṃḍaḥ": ['ap90'],
    "aṃḍāluḥ": ['ap90'],
    "aṃḍīraḥ": ['ap90'],
    "aṃṭh": ['ap90'],
    "aṃṭhita": ['ap90'],
    "aṅ": ['ddsa'],
    "aṅagula": ['ddsa'],
    "aṅg": ['cae', 'ddsa', 'gra', 'mw'],
    "aṅga": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "aṅga-m-aṅgāni": ['cped'],
    "aṅgabandhana": ['ddsa'],
    "aṅgabha": ['mw'],
    "aṅgabhañjana": ['mw'],
    "aṅgabhaṅga": ['cae'],
    "aṅgabheda": ['bhs', 'mw'],
    "aṅgabhū": ['mw'],
    "aṅgada": ['cae', 'ddsa', 'mw'],
    "aṅgadikā": ['bhs'],
    "aṅgadin": ['mw'],
    "aṅgadinna": ['bhs'],
    "aṅgadvīpa": ['mw'],
    "aṅgadā": ['mw'],
    "aṅgadāha": ['bhs'],
    "aṅgadīya": ['mw'],
    "aṅgaglāni": ['ddsa'],
    "aṅgagraha": ['mw'],
    "aṅgahāra": ['mw'],
    "aṅgahāri": ['mw'],
    "aṅgahīna": ['cae', 'mw'],
    "aṅgaja": ['ddsa', 'mw'],
    "aṅgajanus": ['mw'],
    "aṅgajvara": ['mw'],
    "aṅgajā": ['mw'],
    "aṅgajāta": ['cped', 'mw'],
    "aṅgaka": ['mw'],
    "aṅgakarman": ['mw'],
    "aṅgakartana": ['mw'],
    "aṅgakaṣāya": ['mw'],
    "aṅgakriyā": ['ddsa', 'mw'],
    "aṅgalipi": ['bhs', 'mw'],
    "aṅgaloka": ['mw'],
    "aṅgaloḍya": ['mw'],
    "aṅgamantra": ['mw'],
    "aṅgamarda": ['mw'],
    "aṅgamardaka": ['mw'],
    "aṅgamardin": ['mw'],
    "aṅgamarṣa": ['mw'],
    "aṅgamarṣapraśamana": ['mw'],
    "aṅgamaṇi": ['bhs'],
    "aṅgamejayatva": ['ddsa', 'mw'],
    "aṅgana": ['cae', 'ddsa', 'mw'],
    "aṅganyāsa": ['mw'],
    "aṅganā": ['cae', 'ddsa', 'mw'],
    "aṅganāgaṇa": ['mw'],
    "aṅganājana": ['mw'],
    "aṅganāpriya": ['mw'],
    "aṅganāḍikā": ['bhs'],
    "aṅgapaccaṅga": ['cped'],
    "aṅgaprāyaścitta": ['mw'],
    "aṅgapāli": ['mw'],
    "aṅgarakta": ['mw'],
    "aṅgarakṣaka": ['ddsa'],
    "aṅgarakṣaṇī": ['mw'],
    "aṅgarakṣiṇī": ['mw'],
    "aṅgareja": ['mw'],
    "aṅgaruha": ['mw'],
    "aṅgarāga": ['cae', 'cped', 'mw'],
    "aṅgarāj": ['mw'],
    "aṅgarāja": ['cae', 'mw'],
    "aṅgarājya": ['mw'],
    "aṅgas": ['mw'],
    "aṅgasamākhyāyam": ['mw'],
    "aṅgasaṃhati": ['mw'],
    "aṅgasaṃhitā": ['mw'],
    "aṅgasaṃskriyā": ['mw'],
    "aṅgasaṃskāra": ['cae', 'mw'],
    "aṅgasaṃtāpa": ['cae'],
    "aṅgasaṅga": ['mw'],
    "aṅgaskandha": ['mw'],
    "aṅgasparśa": ['cae', 'mw'],
    "aṅgasphuraṇavicāra": ['mw'],
    "aṅgati": ['mw'],
    "aṅgatva": ['ddsa', 'mw'],
    "aṅgatā": ['mw'],
    "aṅgava": ['mw'],
    "aṅgavaikṛta": ['mw'],
    "aṅgavata": ['cped'],
    "aṅgavidyā": ['cae', 'mw'],
    "aṅgavijjā": ['cped'],
    "aṅgavikāra": ['cae', 'ddsa'],
    "aṅgavikṛti": ['mw'],
    "aṅgavikṣepa": ['mw'],
    "aṅgavāhaka": ['mw'],
    "aṅgavākpāṇimat": ['ddsa', 'mw'],
    "aṅgayaṣṭi": ['ddsa', 'mw'],
    "aṅgayāga": ['mw'],
    "aṅgaśas": ['mw'],
    "aṅgaṇa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "aṅgeśvara": ['mw'],
    "aṅgeṣṭhā": ['mw'],
    "aṅgh": ['mw'],
    "aṅgha": ['mw'],
    "aṅghas": ['mw'],
    "aṅghri": ['cae', 'ddsa', 'mw'],
    "aṅghrināmaka": ['mw'],
    "aṅghrināman": ['mw'],
    "aṅghripa": ['mw'],
    "aṅghriparṇī": ['mw'],
    "aṅghripāna": ['mw'],
    "aṅghripāta": ['mw'],
    "aṅghrisaṃdhi": ['mw'],
    "aṅghriskandha": ['mw'],
    "aṅghrivalli": ['mw'],
    "aṅghrivallikā": ['mw'],
    "aṅghryavanejana": ['mw'],
    "aṅghryavanejanatva": ['mw'],
    "aṅghāri": ['mw'],
    "aṅgi": ['cped'],
    "aṅgia": ['gra'],
    "aṅgika": ['bhs'],
    "aṅgikā": ['mw'],
    "aṅgin": ['cae', 'cped', 'ddsa', 'mw'],
    "aṅgir": ['mw'],
    "aṅgira": ['ddsa', 'gra', 'mw'],
    "aṅgiras": ['bhs', 'cae', 'gra', 'mw'],
    "aṅgirasa": ['mw'],
    "aṅgirastama": ['gra', 'mw'],
    "aṅgirasvat": ['gra', 'mw'],
    "aṅgirasāmayana": ['mw'],
    "aṅgiraḥsmṛti": ['mw'],
    "aṅgirodhāman": ['mw'],
    "aṅgottama": ['bhs'],
    "aṅgoñcha": ['mw'],
    "aṅgoñchana": ['mw'],
    "aṅgoṣin": ['mw'],
    "aṅgu": ['mw'],
    "aṅgula": ['cae', 'cped', 'gra', 'mw'],
    "aṅgulaka": ['mw'],
    "aṅgulamāna": ['mw'],
    "aṅgulapramāṇa": ['mw'],
    "aṅgularāji": ['mw'],
    "aṅguli": ['cae', 'ddsa', 'mw'],
    "aṅgulija": ['mw'],
    "aṅgulikā": ['bhs', 'ddsa', 'mw'],
    "aṅgulimoṭana": ['mw'],
    "aṅgulimuddikā": ['cped'],
    "aṅgulimudrikā": ['mw'],
    "aṅgulimudrā": ['cae', 'mw'],
    "aṅgulimukha": ['mw'],
    "aṅgulimāla": ['bhs'],
    "aṅgulimālika": ['bhs'],
    "aṅgulimālīya": ['bhs'],
    "aṅgulimātra": ['mw'],
    "aṅgulimūla": ['cae'],
    "aṅguliparvan": ['ddsa'],
    "aṅgulipraṇejana": ['mw'],
    "aṅguliprāśana": ['mw'],
    "aṅgulisaṃdaṃsa": ['mw'],
    "aṅgulisphoṭana": ['mw'],
    "aṅgulitoraṇa": ['mw'],
    "aṅgulitra": ['cae', 'ddsa', 'mw'],
    "aṅgulitravant": ['cae'],
    "aṅgulitravat": ['mw'],
    "aṅgulitrāṇa": ['cae', 'mw'],
    "aṅguliveṣṭaka": ['mw'],
    "aṅguliveṣṭana": ['mw'],
    "aṅguliṣaṅga": ['mw'],
    "aṅgulyagra": ['ddsa', 'mw'],
    "aṅgulyādi": ['mw'],
    "aṅgulī": ['cae', 'cped', 'ddsa', 'mw'],
    "aṅgulībhaṅga": ['mw'],
    "aṅgulīchinna": ['cped'],
    "aṅgulīgranthi": ['mw'],
    "aṅgulīkā": ['bhs'],
    "aṅgulīmukha": ['mw'],
    "aṅgulīpada": ['cped'],
    "aṅgulīparvan": ['mw'],
    "aṅgulīpatodaka": ['cped'],
    "aṅgulīpañcaka": ['mw'],
    "aṅgulīphaṇahastaka": ['bhs'],
    "aṅgulīsambhūta": ['mw'],
    "aṅgulīveṣṭa": ['mw'],
    "aṅgulīya": ['cae', 'ddsa', 'mw'],
    "aṅgulīyaka": ['cae', 'mw'],
    "aṅgulīyakā": ['bhs'],
    "aṅgulīyalipi": ['bhs'],
    "aṅguri": ['cae', 'ddsa', 'gra', 'mw'],
    "aṅgurī": ['mw'],
    "aṅgurīya": ['mw'],
    "aṅgurīyaka": ['cae', 'ddsa', 'mw'],
    "aṅguṣṭha": ['cae', 'ddsa', 'mw'],
    "aṅguṣṭhamātra": ['mw'],
    "aṅguṣṭhamātraka": ['mw'],
    "aṅguṣṭhamūla": ['cae'],
    "aṅguṣṭhaparvan": ['ddsa'],
    "aṅguṣṭhavibhedaka": ['mw'],
    "aṅguṣṭhavibhedika": ['bhs'],
    "aṅguṣṭhikā": ['mw'],
    "aṅguṣṭhya": ['ddsa', 'mw'],
    "aṅguṭṭha": ['cped'],
    "aṅguṭṭhapada": ['cped'],
    "aṅgya": ['gra', 'mw'],
    "aṅgādhipa": ['mw'],
    "aṅgānukūla": ['ddsa', 'mw'],
    "aṅgānulepana": ['mw'],
    "aṅgānusārin": ['bhs'],
    "aṅgāpūrva": ['mw'],
    "aṅgāra": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "aṅgāradhānikā": ['mw'],
    "aṅgāradhānī": ['mw'],
    "aṅgārajīvikā": ['mw'],
    "aṅgāraka": ['ddsa', 'mw'],
    "aṅgārakadina": ['mw'],
    "aṅgārakamaṇi": ['mw'],
    "aṅgārakarmānta": ['mw'],
    "aṅgārakavāra": ['mw'],
    "aṅgārakayantra": ['mw'],
    "aṅgārakaṭāha": ['cped'],
    "aṅgārakita": ['mw'],
    "aṅgārakuṣṭhaka": ['mw'],
    "aṅgārakāraka": ['ddsa'],
    "aṅgārakārin": ['mw'],
    "aṅgārakāsu": ['cped'],
    "aṅgārakṛt": ['mw'],
    "aṅgāramañjarī": ['mw'],
    "aṅgāramañjī": ['mw'],
    "aṅgāraparipācita": ['mw'],
    "aṅgāraparṇa": ['mw'],
    "aṅgāraparṇī": ['mw'],
    "aṅgārapuṣpa": ['mw'],
    "aṅgārapātrī": ['mw'],
    "aṅgārasetu": ['mw'],
    "aṅgārasātkṛ": ['mw'],
    "aṅgāravallarī": ['mw'],
    "aṅgāravallī": ['mw'],
    "aṅgāravarṣa": ['mw'],
    "aṅgāravāra": ['mw'],
    "aṅgāraśakaṭi": ['mw'],
    "aṅgāraśakaṭī": ['mw'],
    "aṅgāri": ['cped', 'mw'],
    "aṅgārikā": ['mw'],
    "aṅgārin": ['bhs', 'cped', 'ddsa', 'mw'],
    "aṅgārita": ['mw'],
    "aṅgāritā": ['mw'],
    "aṅgāryā": ['mw'],
    "aṅgārāvakṣayaṇa": ['mw'],
    "aṅgārāvakṣepaṇa": ['mw'],
    "aṅgārīya": ['mw'],
    "aṅgāvapīḍana": ['cae'],
    "aṅgāṅgi": ['ddsa', 'mw'],
    "aṅgāṅgibhāva": ['mw'],
    "aṅgāṅgibhāvasaṃkara": ['mw'],
    "aṅgāṅgitā": ['mw'],
    "aṅgī": ['mw'],
    "aṅgīkaraṇa": ['ddsa', 'mw'],
    "aṅgīkāra": ['ddsa', 'mw'],
    "aṅgīkṛ": ['cae', 'ddsa', 'mw'],
    "aṅgīkṛta": ['mw'],
    "aṅgīkṛti": ['mw'],
    "aṅgīrajva": ['bhs'],
    "aṅgīrasa": ['bhs'],
    "aṅgīya": ['mw'],
    "aṅgūṣa": ['mw'],
    "aṅk": ['mw'],
    "aṅka": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "aṅkabandha": ['mw'],
    "aṅkabhāj": ['mw'],
    "aṅkaccheda": ['mw'],
    "aṅkadhāraṇā": ['mw'],
    "aṅkadhātrī": ['bhs'],
    "aṅkagata": ['mw'],
    "aṅkakaraṇa": ['mw'],
    "aṅkakāra": ['mw'],
    "aṅkalakṣaṇa": ['ddsa', 'mw'],
    "aṅkaloḍya": ['mw'],
    "aṅkamukha": ['mw'],
    "aṅkana": ['ddsa', 'mw'],
    "aṅkaparivartana": ['mw'],
    "aṅkapādavrata": ['mw'],
    "aṅkapāla": ['mw'],
    "aṅkapāli": ['mw'],
    "aṅkapālikā": ['mw'],
    "aṅkapālī": ['cae', 'mw'],
    "aṅkapāta": ['ddsa'],
    "aṅkapāśa": ['mw'],
    "aṅkapāśavyavahāra": ['mw'],
    "aṅkapāśādhyāya": ['mw'],
    "aṅkas": ['cae', 'ddsa', 'gra', 'mw'],
    "aṅkasa": ['cae', 'gra', 'mw'],
    "aṅkasaṃjñā": ['mw'],
    "aṅkastha": ['cae'],
    "aṅkatantra": ['mw'],
    "aṅkati": ['mw'],
    "aṅkavidyā": ['mw'],
    "aṅkay": ['cae'],
    "aṅkaya": ['ddsa'],
    "aṅkayaṣṭi": ['cae'],
    "aṅkaśāyin": ['cae'],
    "aṅkeśaya": ['ddsa'],
    "aṅkh": ['gra', 'mw'],
    "aṅkhay": ['cae'],
    "aṅkhaya": ['ddsa'],
    "aṅkin": ['gra', 'mw'],
    "aṅkinī": ['mw'],
    "aṅkita": ['mw'],
    "aṅkola": ['ddsa', 'mw'],
    "aṅkolaka": ['mw'],
    "aṅkolikā": ['mw'],
    "aṅkolla": ['mw'],
    "aṅkollasāra": ['mw'],
    "aṅkoṭa": ['mw'],
    "aṅkoṭha": ['mw'],
    "aṅkri": ['mw'],
    "aṅkte": ['ddsa'],
    "aṅktvā": ['mw'],
    "aṅku": ['mw'],
    "aṅkula": ['bhs'],
    "aṅkulī": ['mw'],
    "aṅkupa": ['mw'],
    "aṅkura": ['cae', 'ddsa', 'mw'],
    "aṅkuraka": ['mw'],
    "aṅkuravat": ['ddsa', 'mw'],
    "aṅkuraya": ['cae', 'ddsa', 'mw'],
    "aṅkuraṇa": ['ddsa', 'mw'],
    "aṅkurita": ['ddsa', 'mw'],
    "aṅkurāropaṇa": ['mw'],
    "aṅkurārpaṇa": ['mw'],
    "aṅkurāya": ['mw'],
    "aṅkusa": ['cped'],
    "aṅkusagayha": ['cped'],
    "aṅkusaggaha": ['cped'],
    "aṅkuśa": ['cae', 'ddsa', 'gra', 'mw'],
    "aṅkuśadurdhara": ['mw'],
    "aṅkuśagraha": ['bhs', 'mw'],
    "aṅkuśin": ['cae', 'ddsa', 'gra', 'mw'],
    "aṅkuśita": ['mw'],
    "aṅkuśā": ['mw'],
    "aṅkuśī": ['mw'],
    "aṅkuḍaka": ['mw'],
    "aṅkuṭa": ['mw'],
    "aṅkya": ['cae', 'ddsa', 'mw'],
    "aṅkāra": ['mw'],
    "aṅkāsya": ['ddsa', 'mw'],
    "aṅkāvatāra": ['ddsa', 'mw'],
    "aṅkāvaṅka": ['mw'],
    "aṅkāya": ['mw'],
    "aṅkāṅka": ['mw'],
    "aṅkī": ['mw'],
    "aṅkūra": ['mw'],
    "aṅkūraya": ['mw'],
    "aṅkūy": ['gra'],
    "aṅkūyat": ['mw'],
    "aṅkūṣa": ['mw'],
    "aṇ": ['ap90', 'ddsa', 'mw'],
    "aṇaka": ['ap90', 'mw'],
    "aṇakīya": ['mw'],
    "aṇasa": ['mw'],
    "aṇavya": ['mw'],
    "aṇavyaṃ": ['ap90'],
    "aṇi": ['mw'],
    "aṇikartṛ": ['ddsa'],
    "aṇikāṣam": ['mw'],
    "aṇiman": ['ap90', 'cae', 'ddsa', 'mw'],
    "aṇimatas": ['mw'],
    "aṇiḥ": ['ap90'],
    "aṇiṣṭha": ['cae', 'ddsa', 'mw'],
    "aṇu": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "aṇu-m-thūla": ['cped'],
    "aṇubhā": ['mw'],
    "aṇudhamma": ['cped'],
    "aṇuha": ['mw'],
    "aṇuka": ['ap90', 'mw'],
    "aṇukathūla": ['cped'],
    "aṇumadhyabīja": ['mw'],
    "aṇumatta": ['cped'],
    "aṇumukha": ['cae'],
    "aṇumātra": ['mw'],
    "aṇumātrika": ['cae', 'mw'],
    "aṇuphala": ['bhs'],
    "aṇupriyaṅgu": ['mw'],
    "aṇurevatī": ['mw'],
    "aṇureṇu": ['mw'],
    "aṇureṇujāla": ['mw'],
    "aṇusahagata": ['cped'],
    "aṇutaila": ['mw'],
    "aṇutara": ['mw'],
    "aṇutva": ['mw'],
    "aṇutā": ['mw'],
    "aṇuvedānta": ['mw'],
    "aṇuvrata": ['mw'],
    "aṇuvrīhi": ['mw'],
    "aṇuvādin": ['mw'],
    "aṇuśas": ['mw'],
    "aṇva": ['cae', 'gra', 'mw'],
    "aṇvanta": ['mw'],
    "aṇvati": ['bhs'],
    "aṇvaṃ": ['ap90'],
    "aṇvī": ['ap90', 'ddsa', 'mw'],
    "aṇyanta": ['ddsa'],
    "aṇāla": ['bhs'],
    "aṇī": ['mw'],
    "aṇīci": ['mw'],
    "aṇīcin": ['mw'],
    "aṇīka": ['cped'],
    "aṇīmāṇḍavya": ['mw'],
    "aṇīyas": ['ap90', 'ddsa', 'mw'],
    "aṇīyaska": ['mw'],
    "aṇīyaṃs": ['cae'],
    "aṇū": ['mw'],
    "aṇūbhāva": ['mw'],
    "aṇūbhū": ['ap90', 'mw'],
    "aṇḍa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "aṇḍabha": ['bhs'],
    "aṇḍabhāri": ['cped'],
    "aṇḍabhārin": ['cped'],
    "aṇḍabhūta": ['cped'],
    "aṇḍadala": ['mw'],
    "aṇḍadhara": ['mw'],
    "aṇḍahāraka": ['cped'],
    "aṇḍaja": ['cae', 'cped', 'mw'],
    "aṇḍajeśvara": ['mw'],
    "aṇḍajā": ['mw'],
    "aṇḍaka": ['cped', 'mw'],
    "aṇḍakaṭāha": ['mw'],
    "aṇḍakosa": ['cped'],
    "aṇḍakośa": ['mw'],
    "aṇḍakoṣa": ['mw'],
    "aṇḍakoṣaka": ['mw'],
    "aṇḍakoṭarapuṣpī": ['mw'],
    "aṇḍakāṣṭha": ['bhs'],
    "aṇḍara": ['mw'],
    "aṇḍarāya": ['mw'],
    "aṇḍasambhava": ['cped'],
    "aṇḍasū": ['mw'],
    "aṇḍavardhana": ['mw'],
    "aṇḍavṛddhi": ['mw'],
    "aṇḍika": ['mw'],
    "aṇḍikā": ['mw'],
    "aṇḍuka": ['mw'],
    "aṇḍākarṣaṇa": ['mw'],
    "aṇḍākāra": ['mw'],
    "aṇḍākṛti": ['mw'],
    "aṇḍālu": ['mw'],
    "aṇḍāyana": ['bhs'],
    "aṇḍīra": ['mw'],
    "aṇṇava": ['cped'],
    "aṇṭh": ['mw'],
    "aṇṭhita": ['mw'],
    "aṛṇin": ['ap90', 'mw'],
    "aṣ": ['ap90', 'mw'],
    "aṣa": ['gra'],
    "aṣadha": ['bhs'],
    "aṣatara": ['ap90', 'cae', 'mw'],
    "aṣaḍakṣīṇa": ['ap90', 'mw'],
    "aṣāl̤ha": ['cae'],
    "aṣāḍha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aṣāḍhaka": ['mw'],
    "aṣāḍhakaḥ": ['ap90'],
    "aṣāḍhin": ['ddsa', 'mw'],
    "aṣāḍhā": ['mw'],
    "aṣṭa": ['bhs', 'ddsa', 'gra', 'mw'],
    "aṣṭabhaginī": ['bhs'],
    "aṣṭabhoga": ['mw'],
    "aṣṭabhāga": ['cae'],
    "aṣṭacatvāriṃśa": ['mw'],
    "aṣṭacatvāriṃśat": ['mw'],
    "aṣṭadala": ['mw'],
    "aṣṭadaṃṣṭra": ['mw'],
    "aṣṭadhā": ['ap90', 'cae', 'mw'],
    "aṣṭadhātu": ['mw'],
    "aṣṭadhāvihita": ['mw'],
    "aṣṭadikpāla": ['mw'],
    "aṣṭadiś": ['mw'],
    "aṣṭagava": ['mw'],
    "aṣṭaguṇa": ['cae', 'mw'],
    "aṣṭaguṇāśraya": ['mw'],
    "aṣṭagṛhīta": ['mw'],
    "aṣṭaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "aṣṭakapāla": ['mw'],
    "aṣṭakarmaparibhraṣṭa": ['mw'],
    "aṣṭakarātri": ['bhs'],
    "aṣṭakarṇa": ['gra', 'mw'],
    "aṣṭakarṇī": ['mw'],
    "aṣṭakhaṇḍa": ['mw'],
    "aṣṭakika": ['ap90'],
    "aṣṭakin": ['mw'],
    "aṣṭakoṇa": ['mw'],
    "aṣṭakya": ['ap90', 'mw'],
    "aṣṭakyā": ['mw'],
    "aṣṭakā": ['mw'],
    "aṣṭakāśrāddha": ['mw'],
    "aṣṭakāṅga": ['mw'],
    "aṣṭakṛtvas": ['mw'],
    "aṣṭaloha": ['mw'],
    "aṣṭama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aṣṭamadeśa": ['mw'],
    "aṣṭamahābhayatārā": ['bhs'],
    "aṣṭamaka": ['ap90', 'bhs', 'mw'],
    "aṣṭamakālika": ['cae', 'mw'],
    "aṣṭamaṅgala": ['mw'],
    "aṣṭamika": ['bhs'],
    "aṣṭamikā": ['ap90', 'mw'],
    "aṣṭamāna": ['mw'],
    "aṣṭamī": ['mw'],
    "aṣṭamūlī": ['mw'],
    "aṣṭamūrti": ['ddsa', 'mw'],
    "aṣṭamūrtidhara": ['mw'],
    "aṣṭan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aṣṭanavata": ['mw'],
    "aṣṭanavati": ['mw'],
    "aṣṭanavatitama": ['mw'],
    "aṣṭapad": ['mw'],
    "aṣṭapada": ['ddsa', 'mw'],
    "aṣṭapadikā": ['mw'],
    "aṣṭapati": ['mw'],
    "aṣṭapattra": ['mw'],
    "aṣṭapañcāśa": ['mw'],
    "aṣṭapañcāśat": ['mw'],
    "aṣṭapañcāśattama": ['mw'],
    "aṣṭapuruṣa": ['mw'],
    "aṣṭaputra": ['mw'],
    "aṣṭapuṣpikā": ['mw'],
    "aṣṭapāda": ['cae', 'mw'],
    "aṣṭapādikā": ['mw'],
    "aṣṭarasāśraya": ['cae', 'mw'],
    "aṣṭaratna": ['mw'],
    "aṣṭaratni": ['mw'],
    "aṣṭarca": ['mw'],
    "aṣṭasaptati": ['mw'],
    "aṣṭasaptatitama": ['mw'],
    "aṣṭastanā": ['mw'],
    "aṣṭasāhasraka": ['mw'],
    "aṣṭasāhasrikāprajñāpāramitā": ['bhs'],
    "aṣṭataya": ['ap90', 'mw'],
    "aṣṭatriṃśa": ['mw'],
    "aṣṭatriṃśat": ['mw'],
    "aṣṭatva": ['mw'],
    "aṣṭavarga": ['mw'],
    "aṣṭavarṣa": ['cae', 'mw'],
    "aṣṭavat": ['bhs'],
    "aṣṭavidha": ['cae', 'mw'],
    "aṣṭavikalpa": ['mw'],
    "aṣṭavārṣika": ['mw'],
    "aṣṭavṛṣa": ['mw'],
    "aṣṭayoni": ['mw'],
    "aṣṭaśata": ['mw'],
    "aṣṭaśataka": ['mw'],
    "aṣṭaśatasāhasra": ['mw'],
    "aṣṭaśatī": ['mw'],
    "aṣṭaśravas": ['mw'],
    "aṣṭaśravaṇa": ['mw'],
    "aṣṭaṃga": ['bhs'],
    "aṣṭaṣaṣṭa": ['mw'],
    "aṣṭaṣaṣṭi": ['mw'],
    "aṣṭaṣaṣṭitama": ['mw'],
    "aṣṭhi": ['gra', 'mw'],
    "aṣṭhiḥ": ['ap90'],
    "aṣṭhī": ['gra'],
    "aṣṭhīla": ['mw'],
    "aṣṭhīlikā": ['ap90', 'mw'],
    "aṣṭhīlā": ['ap90', 'cae', 'ddsa', 'mw'],
    "aṣṭhīva": ['cae'],
    "aṣṭhīvaddaghna": ['mw'],
    "aṣṭhīvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "aṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "aṣṭika": ['mw'],
    "aṣṭin": ['ap90', 'mw'],
    "aṣṭiḥ": ['ap90'],
    "aṣṭottara": ['cae', 'ddsa', 'mw'],
    "aṣṭrā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "aṣṭrāvin": ['gra', 'mw'],
    "aṣṭuñcaka": ['bhs'],
    "aṣṭā": ['mw'],
    "aṣṭābhujā": ['mw'],
    "aṣṭācakra": ['mw'],
    "aṣṭācatvāriṃśa": ['mw'],
    "aṣṭācatvāriṃśadakṣara": ['mw'],
    "aṣṭācatvāriṃśadiṣṭaka": ['mw'],
    "aṣṭācatvāriṃśaka": ['mw'],
    "aṣṭācatvāriṃśat": ['mw'],
    "aṣṭācatvāriṃśin": ['mw'],
    "aṣṭādaśa": ['cae', 'ddsa', 'mw'],
    "aṣṭādaśadhā": ['cae', 'mw'],
    "aṣṭādaśama": ['cae', 'mw'],
    "aṣṭādaśan": ['ap90', 'cae', 'mw'],
    "aṣṭādaśaprakṛti": ['mw'],
    "aṣṭādaśarca": ['mw'],
    "aṣṭādaśavakra": ['bhs', 'mw'],
    "aṣṭādaśavakrikā": ['bhs', 'mw'],
    "aṣṭādaṃṣṭra": ['mw'],
    "aṣṭādhyāyī": ['ddsa', 'mw'],
    "aṣṭādiś": ['mw'],
    "aṣṭāgava": ['mw'],
    "aṣṭāgṛhīta": ['mw'],
    "aṣṭāha": ['mw'],
    "aṣṭākapāla": ['mw'],
    "aṣṭākṣara": ['ddsa', 'mw'],
    "aṣṭānavati": ['ddsa', 'mw'],
    "aṣṭāpad": ['cae', 'ddsa', 'gra', 'mw'],
    "aṣṭāpada": ['ddsa', 'mw'],
    "aṣṭāpadā": ['mw'],
    "aṣṭāpakṣa": ['mw'],
    "aṣṭāparṇa": ['mw'],
    "aṣṭāpañcāśat": ['mw'],
    "aṣṭāpruṣ": ['mw'],
    "aṣṭāpādya": ['cae', 'mw'],
    "aṣṭāra": ['mw'],
    "aṣṭāracakravat": ['mw'],
    "aṣṭāratha": ['mw'],
    "aṣṭāratni": ['mw'],
    "aṣṭārca": ['mw'],
    "aṣṭārdha": ['mw'],
    "aṣṭāsaptati": ['mw'],
    "aṣṭāsri": ['mw'],
    "aṣṭāstanā": ['mw'],
    "aṣṭāsītisahasra": ['ddsa'],
    "aṣṭātaya": ['ap90', 'mw'],
    "aṣṭātriṃśa": ['mw'],
    "aṣṭātriṃśat": ['mw'],
    "aṣṭāvakra": ['ddsa', 'mw'],
    "aṣṭāvakraḥ": ['ap90'],
    "aṣṭāvandhura": ['gra', 'mw'],
    "aṣṭāviṃśa": ['mw'],
    "aṣṭāviṃśati": ['mw'],
    "aṣṭāviṃśatidhā": ['mw'],
    "aṣṭāviṃśatiśata": ['mw'],
    "aṣṭāyoga": ['mw'],
    "aṣṭāyudha": ['ddsa'],
    "aṣṭāśapha": ['mw'],
    "aṣṭāśata": ['mw'],
    "aṣṭāśri": ['mw'],
    "aṣṭāśvasamādhi": ['mw'],
    "aṣṭāśīti": ['mw'],
    "aṣṭāśītiśata": ['mw'],
    "aṣṭāṃśa": ['bhs'],
    "aṣṭāṅga": ['bhs', 'cae', 'mw'],
    "aṣṭāṅgahṛdaya": ['mw'],
    "aṣṭāṅgamārgadeśika": ['mw'],
    "aṣṭāṅganaya": ['mw'],
    "aṣṭāṅgapraṇipāta": ['mw'],
    "aṣṭāṅgapraṇāma": ['mw'],
    "aṣṭāṅgapāta": ['mw'],
    "aṣṭāṅgasamanvāgata": ['mw'],
    "aṣṭāṅgayoga": ['mw'],
    "aṣṭāṅgika": ['bhs'],
    "aṣṭāṅgopeta": ['mw'],
    "aṣṭāṅgārghya": ['mw'],
    "aṣṭāṣaṣṭi": ['mw'],
    "aṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "aṭa": ['ap90'],
    "aṭaka": ['mw'],
    "aṭakkara": ['bhs'],
    "aṭakāvatī": ['bhs'],
    "aṭala": ['ap90', 'mw'],
    "aṭalī": ['cped'],
    "aṭamāna": ['mw'],
    "aṭana": ['cae', 'ddsa', 'mw'],
    "aṭanaṃ": ['ap90'],
    "aṭani": ['cae', 'cped', 'ddsa', 'mw'],
    "aṭanin": ['bhs'],
    "aṭaniḥ": ['ap90'],
    "aṭanī": ['cae', 'mw'],
    "aṭaru": ['ap90'],
    "aṭaruṣa": ['mw'],
    "aṭarūṣa": ['mw'],
    "aṭata": ['mw'],
    "aṭavaka": ['bhs'],
    "aṭavi": ['mw'],
    "aṭavika": ['mw'],
    "aṭavikaḥ": ['ap90'],
    "aṭavisaṅkopa": ['cped'],
    "aṭaviḥ": ['ap90'],
    "aṭavī": ['bhs', 'cae', 'ddsa', 'mw'],
    "aṭavīsaṃbhavā": ['bhs'],
    "aṭavīśikhara": ['mw'],
    "aṭaṭa": ['bhs', 'cped', 'mw'],
    "aṭaṭyā": ['mw'],
    "aṭh": ['ap90', 'mw'],
    "aṭhida": ['mw'],
    "aṭhillā": ['ap90', 'mw'],
    "aṭyā": ['cae', 'ddsa', 'mw'],
    "aṭā": ['ap90', 'mw'],
    "aṭāya": ['mw'],
    "aṭāṭyamāna": ['mw'],
    "aṭāṭyā": ['mw'],
    "aṭāṭā": ['mw'],
    "aṭṇāra": ['mw'],
    "aṭṭ": ['ap90', 'mw'],
    "aṭṭa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "aṭṭahasita": ['mw'],
    "aṭṭahā": ['bhs'],
    "aṭṭahāsa": ['cae', 'ddsa', 'mw'],
    "aṭṭahāsaka": ['mw'],
    "aṭṭahāsin": ['mw'],
    "aṭṭahāsya": ['mw'],
    "aṭṭaka": ['cped', 'mw'],
    "aṭṭakaraṇa": ['cped'],
    "aṭṭakaḥ": ['ap90'],
    "aṭṭakāraka": ['cped'],
    "aṭṭakārikā": ['cped'],
    "aṭṭana": ['mw'],
    "aṭṭanaṃ": ['ap90'],
    "aṭṭapatibhāgākhyagṛhakṛtya": ['mw'],
    "aṭṭapālaka": ['mw'],
    "aṭṭassara": ['cped'],
    "aṭṭasthalī": ['mw'],
    "aṭṭaṭṭa": ['ap90', 'mw'],
    "aṭṭeśvara": ['bhs'],
    "aṭṭha": ['cped'],
    "aṭṭhacattārīsa": ['cped'],
    "aṭṭhacattārīsaṁ": ['cped'],
    "aṭṭhadhā": ['cped'],
    "aṭṭhadoṇa": ['cped'],
    "aṭṭhaguṇaṁ": ['cped'],
    "aṭṭhaha": ['cped'],
    "aṭṭhaka": ['cped'],
    "aṭṭhakavaggiya": ['cped'],
    "aṭṭhakā": ['cped'],
    "aṭṭhama": ['cped'],
    "aṭṭhapada": ['cped'],
    "aṭṭhapadaka": ['cped'],
    "aṭṭhapadakatā": ['cped'],
    "aṭṭhaparivatta": ['cped'],
    "aṭṭharasa": ['cped'],
    "aṭṭhasataṁ": ['cped'],
    "aṭṭhasaṭṭhi": ['cped'],
    "aṭṭhasaṭṭhiṁ": ['cped'],
    "aṭṭhatālīsa": ['cped'],
    "aṭṭhatālīsaṁ": ['cped'],
    "aṭṭhatāḷīsa": ['cped'],
    "aṭṭhatāḷīsaṁ": ['cped'],
    "aṭṭhavatthuka": ['cped'],
    "aṭṭhavācika": ['cped'],
    "aṭṭhavīsaṁ": ['cped'],
    "aṭṭhaṁsa": ['cped'],
    "aṭṭhaṅgamagga": ['cped'],
    "aṭṭhaṅgasamannāgata": ['cped'],
    "aṭṭhaṅgasumāgata": ['cped'],
    "aṭṭhaṅgasumāhita": ['cped'],
    "aṭṭhaṅgika": ['cped'],
    "aṭṭhaṅgula": ['cped'],
    "aṭṭhaṅguli": ['cped'],
    "aṭṭhaṅgupeta": ['cped'],
    "aṭṭhi": ['cped'],
    "aṭṭhicchida": ['cped'],
    "aṭṭhicchinna": ['cped'],
    "aṭṭhika": ['cped'],
    "aṭṭhikasañña": ['cped'],
    "aṭṭhikasaṅkhalikā": ['cped'],
    "aṭṭhikaṅkāla": ['cped'],
    "aṭṭhila": ['cped'],
    "aṭṭhimiñjā": ['cped'],
    "aṭṭhisañcaya": ['cped'],
    "aṭṭhisañña": ['cped'],
    "aṭṭhisaṅkalikā": ['cped'],
    "aṭṭhitaca": ['cped'],
    "aṭṭhittaca": ['cped'],
    "aṭṭhādasa": ['cped'],
    "aṭṭhānavuti": ['cped'],
    "aṭṭhārasaka": ['cped'],
    "aṭṭhārasama": ['cped'],
    "aṭṭhīkatvā": ['cped'],
    "aṭṭilikā": ['mw'],
    "aṭṭita": ['cped'],
    "aṭṭiyamāna": ['cped'],
    "aṭṭiyanta": ['cped'],
    "aṭṭiyitvā": ['cped'],
    "aṭṭiyānika": ['bhs'],
    "aṭṭā": ['mw'],
    "aṭṭāla": ['mw'],
    "aṭṭālaka": ['ddsa', 'mw'],
    "aṭṭālaḥ": ['ap90'],
    "aṭṭālikā": ['ap90', 'mw'],
    "aṭṭālikābandham": ['mw'],
    "aṭṭālikākāra": ['mw'],
    "aṭṭāna": ['cped'],
    "aṭṭāya": ['mw'],
    "aṭṭāṭṭahāsa": ['mw'],
    "aṭṭāṭṭaḥ": ['ap90'],
    "aṭṭīyati": ['cped'],
    "ba": ['mw'],
    "bababā": ['ddsa', 'mw'],
    "babakāra": ['mw'],
    "babara": ['cae', 'mw'],
    "babbaja": ['cped'],
    "babbaḍa": ['bhs'],
    "babbu": ['cped'],
    "babbuka": ['cped'],
    "babbula": ['mw'],
    "babhasa": ['cae', 'ddsa', 'mw'],
    "babhluśa": ['mw'],
    "babhr": ['mw'],
    "babhra": ['mw'],
    "babhravī": ['ap90', 'mw'],
    "babhri": ['cae', 'ddsa', 'gra', 'mw'],
    "babhru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "babhrudeśa": ['mw'],
    "babhrudhātu": ['mw'],
    "babhrudhūta": ['gra', 'mw'],
    "babhruka": ['cae', 'mw'],
    "babhrukarṇa": ['mw'],
    "babhrukeśa": ['mw'],
    "babhruloman": ['cae', 'mw'],
    "babhrumālin": ['mw'],
    "babhrunīkāśa": ['mw'],
    "babhrupiṅgala": ['mw'],
    "babhrusmṛti": ['mw'],
    "babhruvaktra": ['mw'],
    "babhruvāha": ['cae', 'mw'],
    "babhruvāhana": ['cae', 'mw'],
    "babhruśa": ['mw'],
    "babhrūmūtra": ['mw'],
    "babhūka": ['mw'],
    "babiru": ['mw'],
    "babāḍa": ['mw'],
    "babūāṇa": ['mw'],
    "babṛhāṇa": ['mw'],
    "bad": ['ap90', 'mw'],
    "badaksāna": ['mw'],
    "badara": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "badaradvīpa": ['bhs', 'mw'],
    "badarakuṇa": ['mw'],
    "badaramissa": ['cped'],
    "badaraphallī": ['mw'],
    "badarapācana": ['mw'],
    "badarasaktu": ['mw'],
    "badaravallī": ['mw'],
    "badarayūṣa": ['mw'],
    "badaraḥ": ['ap90'],
    "badarikā": ['ap90', 'cae', 'mw'],
    "badarikākhaṇḍa": ['mw'],
    "badarikāmāhātmyasaṃgraha": ['mw'],
    "badarikātīrtha": ['mw'],
    "badarikāvanamāhātmya": ['mw'],
    "badarikāśrama": ['mw'],
    "badarikāśramamāhātmya": ['mw'],
    "badarikāśramayātrāvidhi": ['mw'],
    "badariḥ": ['ap90'],
    "badarā": ['mw'],
    "badarāmalaka": ['mw'],
    "badarī": ['ap90', 'cped', 'mw'],
    "badarīcchada": ['mw'],
    "badarīcchadā": ['mw'],
    "badarīkedāramāhātmya": ['mw'],
    "badarīmāhātmya": ['mw'],
    "badarīnārāyaṇa": ['mw'],
    "badarīnātha": ['mw'],
    "badarīpattra": ['mw'],
    "badarīpattraka": ['mw'],
    "badarīphalā": ['mw'],
    "badarīprastha": ['mw'],
    "badarīpācana": ['mw'],
    "badarītapovana": ['mw'],
    "badarīvana": ['mw'],
    "badarīvanamahātmya": ['mw'],
    "badarīvaṇa": ['mw'],
    "badarīvāsā": ['mw'],
    "badarīśaila": ['mw'],
    "badbadhāna": ['cae', 'mw'],
    "baddha": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "baddhabhāva": ['mw'],
    "baddhabhīmāndhakāra": ['mw'],
    "baddhabhū": ['mw'],
    "baddhabhūmi": ['mw'],
    "baddhabhūmika": ['mw'],
    "baddhacitta": ['cae', 'mw'],
    "baddhadarbha": ['mw'],
    "baddhadveṣa": ['mw'],
    "baddhadṛṣṭi": ['cae', 'mw'],
    "baddhagodhāṅgulitravat": ['mw'],
    "baddhagraha": ['mw'],
    "baddhaguda": ['mw'],
    "baddhagudin": ['mw'],
    "baddhajihva": ['mw'],
    "baddhaka": ['bhs', 'cae', 'mw'],
    "baddhakadambaka": ['cae', 'mw'],
    "baddhakakṣya": ['mw'],
    "baddhakalāpin": ['mw'],
    "baddhakamocana": ['mw'],
    "baddhakesara": ['mw'],
    "baddhalakṣa": ['cae', 'mw'],
    "baddhamauna": ['mw'],
    "baddhamaṇḍala": ['cae', 'mw'],
    "baddhamuṣṭi": ['mw'],
    "baddhamuṣṭitva": ['mw'],
    "baddhamālā": ['bhs'],
    "baddhamūla": ['cae', 'mw'],
    "baddhamūlatā": ['mw'],
    "baddhamūtra": ['mw'],
    "baddhanepathya": ['mw'],
    "baddhanetra": ['cae', 'mw'],
    "baddhanisyanda": ['mw'],
    "baddhaniścaya": ['mw'],
    "baddhaniṣyanda": ['mw'],
    "baddhapallava": ['cae'],
    "baddhaparikara": ['cae', 'mw'],
    "baddhapaṅkavat": ['mw'],
    "baddhaphala": ['mw'],
    "baddhappi": ['mw'],
    "baddhapratijña": ['mw'],
    "baddhapratiśrut": ['mw'],
    "baddhapurīṣa": ['mw'],
    "baddhapurīṣatva": ['mw'],
    "baddhapṛṣṭa": ['mw'],
    "baddhapṛṣṭha": ['mw'],
    "baddharabhasa": ['mw'],
    "baddharasāla": ['mw'],
    "baddharāga": ['mw'],
    "baddharājya": ['mw'],
    "baddharāva": ['cped'],
    "baddhasneha": ['mw'],
    "baddhaspṛha": ['mw'],
    "baddhasūta": ['mw'],
    "baddhati": ['bhs'],
    "baddhatūṇīra": ['mw'],
    "baddhatṛṣṇa": ['mw'],
    "baddhavaira": ['mw'],
    "baddhavarcas": ['mw'],
    "baddhavasati": ['mw'],
    "baddhavat": ['cae'],
    "baddhavatsa": ['mw'],
    "baddhavepathu": ['mw'],
    "baddhavera": ['cped'],
    "baddhaviṇmūtra": ['mw'],
    "baddhaviṭka": ['mw'],
    "baddhaviṭkatā": ['mw'],
    "baddhavāc": ['mw'],
    "baddhavīra": ['mw'],
    "baddhañjalika": ['cped'],
    "baddhaśas": ['mw'],
    "baddhaśikha": ['mw'],
    "baddhaśikhā": ['mw'],
    "baddhaśrotramanaścakṣus": ['mw'],
    "baddhodyama": ['mw'],
    "baddhotsava": ['mw'],
    "baddhādara": ['mw'],
    "baddhāmbu": ['mw'],
    "baddhānanda": ['mw'],
    "baddhāndhakāra": ['mw'],
    "baddhānurāga": ['mw'],
    "baddhānuśaya": ['mw'],
    "baddhāpayati": ['bhs'],
    "baddhāvasthiti": ['mw'],
    "baddhāyudha": ['mw'],
    "baddhāñjali": ['cae', 'mw'],
    "baddhāñjalipuṭa": ['mw'],
    "baddhāśa": ['cae', 'mw'],
    "baddhāśaṅka": ['mw'],
    "baddhāṅgulitra": ['mw'],
    "baddhāṅgulitrāṇa": ['mw'],
    "baddhṛ": ['mw'],
    "badh": ['ap90', 'ddsa', 'gra', 'mw'],
    "badha": ['bhs'],
    "badhira": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "badhiraka": ['mw'],
    "badhiratama": ['mw'],
    "badhiratva": ['mw'],
    "badhiratā": ['mw'],
    "badhiray": ['cae'],
    "badhiraya": ['ddsa', 'mw'],
    "badhirayati": ['ap90'],
    "badhirikā": ['mw'],
    "badhiriman": ['ap90', 'mw'],
    "badhirita": ['ap90', 'mw'],
    "badhirāndha": ['mw'],
    "badhirīkṛ": ['ddsa', 'mw'],
    "badhirīkṛta": ['mw'],
    "badhva": ['mw'],
    "badhya": ['mw'],
    "badhyatas": ['mw'],
    "badhyoga": ['mw'],
    "badhū": ['mw'],
    "badva": ['cae', 'ddsa', 'mw'],
    "badvan": ['mw'],
    "badvaśas": ['mw'],
    "badālatā": ['cped'],
    "bagadāda": ['mw'],
    "bagadāha": ['mw'],
    "bagadāru": ['mw'],
    "bah": ['ddsa', 'mw'],
    "bahala": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bahalacakṣus": ['mw'],
    "bahalagandha": ['mw'],
    "bahalagandhā": ['mw'],
    "bahalatta": ['cped'],
    "bahalatvaca": ['mw'],
    "bahalatā": ['mw'],
    "bahalavartman": ['mw'],
    "bahalita": ['mw'],
    "bahalā": ['mw'],
    "bahalānurāga": ['mw'],
    "bahalāṅga": ['mw'],
    "bahalībhū": ['mw'],
    "bahanaka": ['mw'],
    "bahaya": ['mw'],
    "baheṭaka": ['mw'],
    "bahi": ['cped'],
    "bahiddhā": ['cped'],
    "bahidhā": ['bhs'],
    "bahigata": ['cped'],
    "bahijana": ['cped'],
    "bahinagara": ['cped'],
    "bahinikkhamana": ['cped'],
    "bahir": ['mw'],
    "bahirante": ['mw'],
    "bahirargala": ['mw'],
    "bahirartha": ['mw'],
    "bahiraṅga": ['ddsa', 'mw'],
    "bahiraṅgatva": ['mw'],
    "bahiraṅgatā": ['mw'],
    "bahirbhava": ['mw'],
    "bahirbhavana": ['mw'],
    "bahirbhāga": ['mw'],
    "bahirbhāva": ['mw'],
    "bahirbhūta": ['mw'],
    "bahirdeśa": ['mw'],
    "bahirdhvajā": ['mw'],
    "bahirdhā": ['cae', 'mw'],
    "bahirdhābhāva": ['mw'],
    "bahirdvāra": ['cae', 'mw'],
    "bahirdvārakoṣṭhaka": ['bhs'],
    "bahirdvāraprakoṣṭhaka": ['mw'],
    "bahirdvārin": ['mw'],
    "bahirdṛś": ['mw'],
    "bahirgamana": ['mw'],
    "bahirgata": ['mw'],
    "bahirgatatva": ['mw'],
    "bahirgeham": ['cae', 'mw'],
    "bahirgira": ['mw'],
    "bahirgiri": ['mw'],
    "bahirgrāmam": ['mw'],
    "bahirgrāmapratiśraya": ['cae', 'mw'],
    "bahirgāmin": ['mw'],
    "bahirgīta": ['mw'],
    "bahirindriya": ['mw'],
    "bahirjānu": ['mw'],
    "bahirlamba": ['mw'],
    "bahirlambā": ['mw'],
    "bahirloma": ['mw'],
    "bahirloman": ['mw'],
    "bahirlāpikā": ['mw'],
    "bahirmanas": ['mw'],
    "bahirmanaska": ['mw'],
    "bahirmaṇḍalastha": ['mw'],
    "bahirmudra": ['mw'],
    "bahirmukha": ['mw'],
    "bahirmālā": ['mw'],
    "bahirmātṛkā": ['mw'],
    "bahirnagara": ['bhs'],
    "bahirnidhana": ['mw'],
    "bahirnirgamana": ['mw'],
    "bahirniḥsāraṇa": ['mw'],
    "bahirnyāsasūtra": ['mw'],
    "bahirvaiśravaṇa": ['mw'],
    "bahirvartin": ['mw'],
    "bahirvedi": ['cae', 'mw'],
    "bahirvedika": ['mw'],
    "bahirvikāra": ['mw'],
    "bahirvikāram": ['mw'],
    "bahirvyasana": ['mw'],
    "bahirvyasanin": ['mw'],
    "bahirvāsas": ['mw'],
    "bahirvṛtti": ['mw'],
    "bahiryoga": ['mw'],
    "bahiryoni": ['mw'],
    "bahiryāgapujā": ['mw'],
    "bahiryāgaratna": ['mw'],
    "bahiryāna": ['cae', 'mw'],
    "bahiryātrā": ['mw'],
    "bahiryūti": ['mw'],
    "bahirātmam": ['mw'],
    "bahirāyāma": ['bhs'],
    "bahirṇidhana": ['mw'],
    "bahirṣu": ['bhs'],
    "bahis": ['ap90', 'cae', 'ddsa', 'mw'],
    "bahistanva": ['mw'],
    "bahistapas": ['ddsa', 'mw'],
    "bahiś": ['mw'],
    "bahiścara": ['ddsa', 'mw'],
    "bahiḥ": ['mw'],
    "bahiḥprayāṇa": ['mw'],
    "bahiḥsad": ['mw'],
    "bahiḥsadas": ['mw'],
    "bahiḥsadasam": ['mw'],
    "bahiḥsaṃdhya": ['mw'],
    "bahiḥsaṃdhyatva": ['mw'],
    "bahiḥsaṃstha": ['ddsa', 'mw'],
    "bahiḥstha": ['mw'],
    "bahiḥsthita": ['mw'],
    "bahiḥsthāyin": ['mw'],
    "bahiḥstomabhāgam": ['mw'],
    "bahiḥśauca": ['mw'],
    "bahiḥśri": ['mw'],
    "bahiḥśālā": ['ddsa', 'mw'],
    "bahiḥśīta": ['mw'],
    "bahiṣ": ['mw'],
    "bahiṣka": ['ap90', 'mw'],
    "bahiṣkaraṇa": ['ddsa', 'mw'],
    "bahiṣkaraṇaṃ": ['ap90'],
    "bahiṣkarman": ['mw'],
    "bahiṣkratu": ['mw'],
    "bahiṣkriya": ['mw'],
    "bahiṣkriyā": ['mw'],
    "bahiṣkuṭīcara": ['mw'],
    "bahiṣkāra": ['mw'],
    "bahiṣkāraḥ": ['ap90'],
    "bahiṣkārya": ['mw'],
    "bahiṣkṛ": ['ap90'],
    "bahiṣkṛta": ['mw'],
    "bahiṣkṛti": ['mw'],
    "bahiṣparidhi": ['mw'],
    "bahiṣpatham": ['mw'],
    "bahiṣpatnīsaṃyāja": ['mw'],
    "bahiṣpatnīsaṃyājatva": ['mw'],
    "bahiṣpavamāna": ['cae', 'mw'],
    "bahiṣpavamānāstāva": ['mw'],
    "bahiṣpavamānī": ['mw'],
    "bahiṣpavitra": ['mw'],
    "bahiṣpaṭa": ['ddsa', 'mw'],
    "bahiṣpiṇḍa": ['mw'],
    "bahiṣprajña": ['cae', 'mw'],
    "bahiṣprākāra": ['mw'],
    "bahiṣprāṇa": ['mw'],
    "bahiṣtva": ['mw'],
    "bahiṣṭādviśasana": ['mw'],
    "bahiṣṭājjyotis": ['mw'],
    "bahiṣṭāt": ['ap90', 'cae', 'ddsa', 'mw'],
    "bahli": ['mw'],
    "bahlika": ['mw'],
    "bahlikāḥ": ['ap90'],
    "bahlīka": ['mw'],
    "bahrāmakhāna": ['mw'],
    "bahu": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bahualīkamma": ['cped'],
    "bahubala": ['mw'],
    "bahubbīhi": ['cped'],
    "bahubhadra": ['mw'],
    "bahubhakṣa": ['mw'],
    "bahubhastraka": ['mw'],
    "bahubhauma": ['mw'],
    "bahubhaṇda": ['cped'],
    "bahubhogyā": ['mw'],
    "bahubhojaka": ['cae', 'mw'],
    "bahubhojana": ['mw'],
    "bahubhojin": ['cae', 'mw'],
    "bahubhojitā": ['mw'],
    "bahubhoktṛ": ['mw'],
    "bahubhuj": ['cae', 'mw'],
    "bahubhuja": ['mw'],
    "bahubhujā": ['mw'],
    "bahubhāgya": ['mw'],
    "bahubhāva": ['cped'],
    "bahubhāṇī": ['cped'],
    "bahubhāṣin": ['cae', 'mw'],
    "bahubhāṣitā": ['mw'],
    "bahubhāṣya": ['mw'],
    "bahubhūmi": ['mw'],
    "bahubhūmika": ['mw'],
    "bahubhṛjj": ['mw'],
    "bahubollaka": ['mw'],
    "bahubuddhasūtra": ['bhs'],
    "bahubāhu": ['mw'],
    "bahubīja": ['mw'],
    "bahubījā": ['mw'],
    "bahucarmaka": ['mw'],
    "bahucchada": ['mw'],
    "bahucchala": ['mw'],
    "bahucchalatva": ['mw'],
    "bahucchinnā": ['mw'],
    "bahucitra": ['mw'],
    "bahucārin": ['mw'],
    "bahuda": ['mw'],
    "bahudaivata": ['mw'],
    "bahudaivatya": ['mw'],
    "bahudakṣiṇa": ['mw'],
    "bahudalakaniśa": ['mw'],
    "bahudantī": ['mw'],
    "bahudantīsuta": ['mw'],
    "bahudarśaka": ['mw'],
    "bahudarśin": ['mw'],
    "bahudarśitā": ['mw'],
    "bahudaṇḍika": ['mw'],
    "bahudaṇḍin": ['mw'],
    "bahudevata": ['mw'],
    "bahudevataka": ['bhs'],
    "bahudevatatva": ['mw'],
    "bahudevatya": ['mw'],
    "bahudevatā": ['mw'],
    "bahudeya": ['cae', 'mw'],
    "bahudeśadarśin": ['mw'],
    "bahudhana": ['cae', 'cped', 'mw'],
    "bahudhanatva": ['mw'],
    "bahudhaneśvara": ['mw'],
    "bahudhanvin": ['mw'],
    "bahudhanya": ['mw'],
    "bahudhenūka": ['mw'],
    "bahudheya": ['mw'],
    "bahudhmāta": ['mw'],
    "bahudhā": ['ap90', 'cae', 'cped', 'gra', 'mw'],
    "bahudhāgata": ['mw'],
    "bahudhānya": ['mw'],
    "bahudhānyaka": ['mw'],
    "bahudhāra": ['mw'],
    "bahudhātmaka": ['mw'],
    "bahudhīvan": ['mw'],
    "bahudohanā": ['mw'],
    "bahudoṣa": ['cae', 'mw'],
    "bahudugdha": ['mw'],
    "bahudugdhikā": ['mw'],
    "bahudugdhā": ['mw'],
    "bahuduḥkhavāsam": ['mw'],
    "bahudāman": ['mw'],
    "bahudāmā": ['mw'],
    "bahudāna": ['cae', 'mw'],
    "bahudāsapuruṣa": ['mw'],
    "bahudāsapūruṣa": ['mw'],
    "bahudāyin": ['cae', 'mw'],
    "bahudṛśvan": ['mw'],
    "bahudṛṣṭa": ['mw'],
    "bahugandha": ['mw'],
    "bahugandhadā": ['mw'],
    "bahugandhā": ['mw'],
    "bahugarhyavāc": ['mw'],
    "bahugava": ['mw'],
    "bahugiri": ['mw'],
    "bahugo": ['mw'],
    "bahugotraja": ['mw'],
    "bahugraha": ['mw'],
    "bahugranthi": ['mw'],
    "bahugu": ['cae', 'mw'],
    "bahuguhā": ['mw'],
    "bahuguru": ['mw'],
    "bahuguḍā": ['mw'],
    "bahuguṇa": ['cae', 'mw'],
    "bahuhastika": ['mw'],
    "bahuhiraṇya": ['mw'],
    "bahujalpa": ['cae', 'mw'],
    "bahujalpitṛ": ['mw'],
    "bahujana": ['bhs', 'cped', 'mw'],
    "bahujanahita": ['mw'],
    "bahujanaparivāra": ['mw'],
    "bahujanmabhāj": ['mw'],
    "bahujanya": ['bhs', 'mw'],
    "bahujava": ['mw'],
    "bahujña": ['mw'],
    "bahujñatā": ['mw'],
    "bahujāgara": ['cped'],
    "bahujālī": ['mw'],
    "bahujāta": ['bhs', 'mw'],
    "bahuka": ['ap90', 'bhs', 'cped', 'mw'],
    "bahukalka": ['mw'],
    "bahukalpa": ['mw'],
    "bahukalyāṇa": ['mw'],
    "bahukanda": ['mw'],
    "bahukandī": ['mw'],
    "bahukara": ['bhs', 'ddsa', 'mw'],
    "bahukaraṇīya": ['bhs', 'cped', 'mw'],
    "bahukarṇikā": ['mw'],
    "bahukaṇṭaka": ['mw'],
    "bahukaṇṭakā": ['mw'],
    "bahukaṇṭā": ['mw'],
    "bahuketu": ['mw'],
    "bahukicca": ['cped'],
    "bahukkhattuṁ": ['cped'],
    "bahukrama": ['mw'],
    "bahukulya": ['mw'],
    "bahukulīna": ['mw'],
    "bahukusumita": ['mw'],
    "bahukālam": ['mw'],
    "bahukālīna": ['mw'],
    "bahukāma": ['mw'],
    "bahukāra": ['cped', 'mw'],
    "bahukāraṇīya": ['mw'],
    "bahukīṭa": ['mw'],
    "bahukūrca": ['mw'],
    "bahukṛta": ['mw'],
    "bahukṛtvas": ['cae'],
    "bahukṛtya": ['bhs', 'mw'],
    "bahukṣama": ['mw'],
    "bahukṣāra": ['mw'],
    "bahukṣīraduh": ['mw'],
    "bahukṣīrā": ['mw'],
    "bahula": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bahulacchada": ['mw'],
    "bahulagandha": ['mw'],
    "bahulagandhā": ['mw'],
    "bahulaka": ['mw'],
    "bahulakeśa": ['bhs'],
    "bahulam": ['mw'],
    "bahulapalāśa": ['mw'],
    "bahulaparṇa": ['mw'],
    "bahulatara": ['mw'],
    "bahulatta": ['cped'],
    "bahulatva": ['mw'],
    "bahulatā": ['ap90', 'cped', 'mw'],
    "bahulatṛṇa": ['mw'],
    "bahulauṣadhika": ['cae'],
    "bahulauṣadika": ['mw'],
    "bahulavarman": ['mw'],
    "bahulavaṇa": ['mw'],
    "bahulaṁ": ['cped'],
    "bahuletarapakṣa": ['ddsa', 'mw'],
    "bahulikā": ['ap90', 'mw'],
    "bahulin": ['bhs'],
    "bahulita": ['cae', 'ddsa', 'mw'],
    "bahullya": ['cped'],
    "bahulā": ['mw'],
    "bahulābhimāna": ['gra', 'mw'],
    "bahulālāpa": ['mw'],
    "bahulānta": ['gra', 'mw'],
    "bahulāviṣṭa": ['mw'],
    "bahulāyāsa": ['cae', 'ddsa', 'mw'],
    "bahulāśva": ['mw'],
    "bahulī": ['mw'],
    "bahulībhāva": ['mw'],
    "bahulībhāvaḥ": ['ap90'],
    "bahulībhū": ['ap90', 'mw'],
    "bahulībhūta": ['mw'],
    "bahulīkamma": ['cped'],
    "bahulīkaraṇa": ['cped', 'mw'],
    "bahulīkaraṇaṃ": ['ap90'],
    "bahulīkari": ['cped'],
    "bahulīkariṣṇu": ['mw'],
    "bahulīkaroti": ['cped'],
    "bahulīkata": ['cped'],
    "bahulīkāra": ['bhs', 'cped', 'mw'],
    "bahulīkṛ": ['ap90', 'cae', 'ddsa'],
    "bahulīkṛta": ['ap90', 'bhs', 'cae', 'mw'],
    "bahumadhyaga": ['cae', 'mw'],
    "bahumala": ['mw'],
    "bahumantavya": ['cae', 'mw'],
    "bahumata": ['cped', 'mw'],
    "bahumati": ['mw'],
    "bahumatsya": ['cae', 'mw'],
    "bahumaulya": ['mw'],
    "bahumañjarī": ['mw'],
    "bahumitra": ['mw'],
    "bahumukha": ['bhs', 'cae', 'mw'],
    "bahumulyatā": ['mw'],
    "bahumāla": ['mw'],
    "bahumālaka": ['mw'],
    "bahumālyaphala": ['mw'],
    "bahumāna": ['cae', 'cped', 'mw'],
    "bahumānana": ['cped'],
    "bahumānin": ['cae', 'mw'],
    "bahumānita": ['cped'],
    "bahumānuṣasaṃkīrṇa": ['mw'],
    "bahumānya": ['cae', 'mw'],
    "bahumārgī": ['mw'],
    "bahumāya": ['mw'],
    "bahumāṣatila": ['mw'],
    "bahumūla": ['mw'],
    "bahumūlaka": ['mw'],
    "bahumūlaphalānvita": ['mw'],
    "bahumūlya": ['cae', 'mw'],
    "bahumūlā": ['mw'],
    "bahumūlī": ['mw'],
    "bahumūrdhan": ['mw'],
    "bahumūrti": ['mw'],
    "bahumūtra": ['mw'],
    "bahumūtraka": ['mw'],
    "bahumūtratā": ['mw'],
    "bahumṛga": ['mw'],
    "bahunaiṣkika": ['mw'],
    "bahuniḥśrita": ['mw'],
    "bahuniṣka": ['mw'],
    "bahunāda": ['mw'],
    "bahunāman": ['mw'],
    "bahupad": ['mw'],
    "bahupada": ['cae', 'mw'],
    "bahupakṣa": ['bhs'],
    "bahupannaga": ['mw'],
    "bahuparṇa": ['cae', 'mw'],
    "bahuparṇikā": ['mw'],
    "bahuparṇā": ['mw'],
    "bahupatnīka": ['cae', 'mw'],
    "bahupatnīkatā": ['mw'],
    "bahupatnīkṛt": ['mw'],
    "bahupatnītā": ['mw'],
    "bahupattra": ['mw'],
    "bahupattrikā": ['mw'],
    "bahupattrā": ['mw'],
    "bahupattrī": ['mw'],
    "bahupaśu": ['cae', 'mw'],
    "bahupaṭu": ['mw'],
    "bahuphala": ['mw'],
    "bahuphalikā": ['mw'],
    "bahuphalā": ['mw'],
    "bahuphalī": ['mw'],
    "bahuphenarasā": ['mw'],
    "bahuphenā": ['mw'],
    "bahuppada": ['cped'],
    "bahuprabha": ['bhs'],
    "bahuprada": ['mw'],
    "bahupraja": ['cae', 'mw'],
    "bahuprajas": ['cae'],
    "bahuprajña": ['mw'],
    "bahuprajñānaśālin": ['mw'],
    "bahuprajā": ['gra'],
    "bahuprakāra": ['cae', 'mw'],
    "bahuprakāram": ['mw'],
    "bahuprakṛti": ['mw'],
    "bahupralāpin": ['mw'],
    "bahupralāpitā": ['mw'],
    "bahuprapañca": ['mw'],
    "bahuprasū": ['mw'],
    "bahupratigrāhya": ['mw'],
    "bahupratijña": ['cae', 'mw'],
    "bahupratyarthika": ['mw'],
    "bahupratyavāya": ['cae', 'mw'],
    "bahupravāha": ['mw'],
    "bahupreyasī": ['mw'],
    "bahupriya": ['cae', 'mw'],
    "bahuprāśnika": ['mw'],
    "bahuputra": ['bhs', 'mw'],
    "bahuputraka": ['bhs'],
    "bahuputratva": ['mw'],
    "bahuputratā": ['mw'],
    "bahuputrikā": ['mw'],
    "bahuputrī": ['mw'],
    "bahupuṣpa": ['mw'],
    "bahupuṣpaphalopeta": ['mw'],
    "bahupuṣpaprabālavat": ['mw'],
    "bahupuṣṭa": ['cae', 'mw'],
    "bahupād": ['mw'],
    "bahupāda": ['cae', 'mw'],
    "bahupākya": ['cae', 'mw'],
    "bahupāyia": ['gra'],
    "bahupāyya": ['cae', 'gra', 'mw'],
    "bahupāṭhin": ['cae'],
    "bahurada": ['mw'],
    "bahurai": ['mw'],
    "bahurajas": ['cae', 'mw'],
    "bahuramadhya": ['ddsa', 'mw'],
    "bahuramya": ['mw'],
    "bahurandhrikā": ['mw'],
    "bahurasa": ['cae', 'ddsa', 'mw'],
    "bahurasā": ['mw'],
    "bahuratha": ['mw'],
    "bahuratna": ['mw'],
    "bahuratnāya": ['mw'],
    "bahurekha": ['mw'],
    "bahuretas": ['mw'],
    "bahuripu": ['mw'],
    "bahuroman": ['mw'],
    "bahuruhā": ['mw'],
    "bahurājan": ['bhs', 'mw'],
    "bahurājā": ['mw'],
    "bahurāyaspoṣa": ['mw'],
    "bahurāśi": ['bhs', 'mw'],
    "bahurāṣṭra": ['bhs'],
    "bahurūpa": ['cae', 'mw'],
    "bahurūpagarbhastotra": ['mw'],
    "bahurūpaka": ['mw'],
    "bahurūpakalpa": ['mw'],
    "bahurūpakaśobhita": ['mw'],
    "bahurūpin": ['mw'],
    "bahurūpā": ['mw'],
    "bahurūpāṣṭakatantra": ['mw'],
    "bahusadācāra": ['mw'],
    "bahusadṛśa": ['mw'],
    "bahusampuṭa": ['mw'],
    "bahusamudācāra": ['mw'],
    "bahusarpiṣka": ['mw'],
    "bahusasya": ['mw'],
    "bahusattva": ['mw'],
    "bahusatya": ['mw'],
    "bahusava": ['mw'],
    "bahusaṃkhyāka": ['mw'],
    "bahusaṃsthita": ['cae', 'mw'],
    "bahusaṃtati": ['mw'],
    "bahusaṃvatsara": ['mw'],
    "bahusaṅkhyāka": ['ddsa'],
    "bahusena": ['bhs'],
    "bahuso": ['cped'],
    "bahuspṛś": ['mw'],
    "bahussuta": ['cped'],
    "bahustavāvali": ['mw'],
    "bahusu": ['mw'],
    "bahusuta": ['mw'],
    "bahusutā": ['mw'],
    "bahusuvarṇa": ['mw'],
    "bahusuvarṇaka": ['mw'],
    "bahusuvarṇatā": ['mw'],
    "bahusvana": ['mw'],
    "bahusvara": ['mw'],
    "bahusvaratva": ['mw'],
    "bahusvarṇalakṣamūlya": ['mw'],
    "bahusvāmika": ['mw'],
    "bahusādhana": ['mw'],
    "bahusādhanatā": ['mw'],
    "bahusādhāra": ['mw'],
    "bahusādhāraṇa": ['mw'],
    "bahusāhasra": ['cae', 'mw'],
    "bahusāhasrī": ['mw'],
    "bahusāmi": ['mw'],
    "bahusāra": ['cae', 'mw'],
    "bahusū": ['mw'],
    "bahusūkta": ['mw'],
    "bahusūti": ['mw'],
    "bahusūtigo": ['mw'],
    "bahusūvan": ['gra'],
    "bahusūvarī": ['mw'],
    "bahutalavaśā": ['mw'],
    "bahutama": ['ap90', 'ddsa', 'mw'],
    "bahutanaya": ['cae', 'mw'],
    "bahutantrī": ['mw'],
    "bahutantrīka": ['mw'],
    "bahutara": ['ap90', 'cped', 'mw'],
    "bahutaraka": ['bhs', 'mw'],
    "bahutarakaṇiśa": ['mw'],
    "bahutaram": ['mw'],
    "bahutarām": ['cae', 'mw'],
    "bahutas": ['mw'],
    "bahutaya": ['cae', 'mw'],
    "bahutaḥ": ['ap90'],
    "bahuthā": ['ap90', 'mw'],
    "bahutiktā": ['mw'],
    "bahutitha": ['ap90', 'cae', 'mw'],
    "bahutitham": ['mw'],
    "bahutra": ['ap90', 'mw'],
    "bahutrivarṣa": ['cae', 'mw'],
    "bahutrā": ['cae', 'gra', 'mw'],
    "bahutta": ['cped'],
    "bahutva": ['cae', 'mw'],
    "bahutvac": ['mw'],
    "bahutvakka": ['mw'],
    "bahutā": ['ap90', 'cae', 'mw'],
    "bahutṛṇa": ['mw'],
    "bahutṛṣṇa": ['cae', 'mw'],
    "bahuvacana": ['cae', 'cped', 'mw'],
    "bahuvaistika": ['mw'],
    "bahuvaktavya": ['ddsa', 'mw'],
    "bahuvalka": ['mw'],
    "bahuvalkala": ['mw'],
    "bahuvallabha": ['cae'],
    "bahuvallī": ['mw'],
    "bahuvarta": ['mw'],
    "bahuvarṇa": ['mw'],
    "bahuvarṇatā": ['mw'],
    "bahuvarṣasahasrika": ['mw'],
    "bahuvarṣasahasrin": ['mw'],
    "bahuvat": ['mw'],
    "bahuvelam": ['mw'],
    "bahuvi": ['mw'],
    "bahuvid": ['cae', 'mw'],
    "bahuvidha": ['cae', 'cped', 'mw'],
    "bahuvidham": ['mw'],
    "bahuvidhākara": ['cae'],
    "bahuvidhākāra": ['mw'],
    "bahuvidya": ['cae', 'mw'],
    "bahuvidyatā": ['mw'],
    "bahuvighna": ['cae', 'mw'],
    "bahuvighnatā": ['mw'],
    "bahuvikrama": ['mw'],
    "bahuvista": ['mw'],
    "bahuvistara": ['mw'],
    "bahuvistaram": ['mw'],
    "bahuvistarayuktam": ['mw'],
    "bahuvistīrṇa": ['mw'],
    "bahuvistīrṇā": ['mw'],
    "bahuvrīhi": ['cae', 'mw'],
    "bahuvrīhivat": ['mw'],
    "bahuvyaya": ['mw'],
    "bahuvyayin": ['mw'],
    "bahuvyālaniṣevita": ['mw'],
    "bahuvyāpin": ['mw'],
    "bahuvādin": ['mw'],
    "bahuvādyakāra": ['bhs'],
    "bahuvāra": ['mw'],
    "bahuvāraka": ['mw'],
    "bahuvārakaphala": ['mw'],
    "bahuvāram": ['mw'],
    "bahuvārṣika": ['mw'],
    "bahuvāsara": ['cae'],
    "bahuvīja": ['mw'],
    "bahuvīrya": ['cae', 'mw'],
    "bahuvīryā": ['mw'],
    "bahuvṛttānta": ['cae'],
    "bahuyajvan": ['mw'],
    "bahuyajvā": ['mw'],
    "bahuyojanā": ['mw'],
    "bahuyājin": ['mw'],
    "bahuyājya": ['mw'],
    "bahuśabda": ['mw'],
    "bahuśakti": ['ddsa', 'mw'],
    "bahuśalya": ['mw'],
    "bahuśas": ['ap90', 'cae', 'mw'],
    "bahuśasta": ['mw'],
    "bahuśatru": ['mw'],
    "bahuśaṅku": ['bhs'],
    "bahuśikha": ['mw'],
    "bahuśikhā": ['mw'],
    "bahuśreyasī": ['mw'],
    "bahuśruta": ['bhs', 'cae', 'mw'],
    "bahuśruti": ['mw'],
    "bahuśrutya": ['bhs'],
    "bahuśrutīya": ['mw'],
    "bahuśubhāya": ['mw'],
    "bahuśākha": ['cae', 'mw'],
    "bahuśākhatva": ['mw'],
    "bahuśākhin": ['mw'],
    "bahuśāla": ['mw'],
    "bahuśāstrajña": ['mw'],
    "bahuśūnya": ['mw'],
    "bahuśṛṅga": ['mw'],
    "bahv": ['mw'],
    "bahvabaddhapralāpin": ['mw'],
    "bahvabhidhāna": ['mw'],
    "bahvac": ['mw'],
    "bahvacka": ['mw'],
    "bahvadhyayana": ['mw'],
    "bahvadhyāya": ['mw'],
    "bahvagni": ['mw'],
    "bahvajavika": ['mw'],
    "bahvakṣara": ['mw'],
    "bahvakṣaratva": ['mw'],
    "bahvakṣarāntya": ['mw'],
    "bahvamitra": ['mw'],
    "bahvanartha": ['mw'],
    "bahvanna": ['cae', 'gra', 'mw'],
    "bahvap": ['mw'],
    "bahvapa": ['mw'],
    "bahvapatya": ['cae', 'mw'],
    "bahvapatyā": ['mw'],
    "bahvapāya": ['cae', 'mw'],
    "bahvarha": ['mw'],
    "bahvartha": ['mw'],
    "bahvauṣadhika": ['mw'],
    "bahvavarodha": ['mw'],
    "bahvaśva": ['cae', 'mw'],
    "bahvenas": ['cae', 'mw'],
    "bahvoda": ['ddsa'],
    "bahvādin": ['cae', 'mw'],
    "bahvājya": ['mw'],
    "bahvāścarya": ['mw'],
    "bahvāścaryamaya": ['mw'],
    "bahvāśin": ['cae', 'mw'],
    "bahvāśitva": ['mw'],
    "bahvāśrayā": ['bhs', 'mw'],
    "bahvīyati": ['bhs'],
    "bahvīśvara": ['mw'],
    "bahvīśvaramāhātmya": ['mw'],
    "bahvṛc": ['cae', 'mw'],
    "bahvṛca": ['cae', 'mw'],
    "bahvṛcabrāhmaṇa": ['mw'],
    "bahvṛcagṛhyakārikā": ['mw'],
    "bahvṛcagṛhyapariśiṣṭa": ['mw'],
    "bahvṛcakārikā": ['mw'],
    "bahvṛcapaddhati": ['mw'],
    "bahvṛcasaṃdhyābhāṣya": ['mw'],
    "bahvṛcaśrāddhaprayoga": ['mw'],
    "bahvṛcaṣoḍaśakarmamantravivaraṇa": ['mw'],
    "bahvṛcāhnika": ['mw'],
    "bahvṛcāhnikopaniṣad": ['mw'],
    "bahādura": ['mw'],
    "bahī": ['mw'],
    "bahīnara": ['mw'],
    "bahīrajju": ['mw'],
    "bahūdaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "bahūdana": ['mw'],
    "bahūdara": ['cae'],
    "bahūdita": ['mw'],
    "bahūkṣara": ['ddsa'],
    "bahūpakāra": ['cped'],
    "bahūpamā": ['cae', 'mw'],
    "bahūrj": ['mw'],
    "baida": ['ddsa', 'mw'],
    "baidakula": ['mw'],
    "baidala": ['ap90', 'mw'],
    "baidatrirātra": ['mw'],
    "baidi": ['mw'],
    "baidāpuṭāyana": ['mw'],
    "baidāyana": ['mw'],
    "baihīnari": ['ddsa', 'mw'],
    "baijaladeva": ['mw'],
    "baijanātha": ['mw'],
    "baijavāpa": ['cae', 'mw'],
    "baijavāpagṛhya": ['mw'],
    "baijavāpasmṛti": ['mw'],
    "baijavāpi": ['mw'],
    "baijavāpāyana": ['cae', 'mw'],
    "baijavāpīya": ['mw'],
    "baijeya": ['mw'],
    "baiji": ['mw'],
    "baijika": ['ap90', 'cae', 'ddsa', 'mw'],
    "baijīya": ['mw'],
    "baiki": ['mw'],
    "baila": ['cae', 'mw'],
    "bailmavegarudra": ['mw'],
    "bailva": ['ap90', 'cae', 'ddsa', 'mw'],
    "bailvaja": ['mw'],
    "bailvajaka": ['mw'],
    "bailvaka": ['mw'],
    "bailvakīya": ['mw'],
    "bailvala": ['mw'],
    "bailvalaka": ['mw'],
    "bailvamaya": ['mw'],
    "bailvavana": ['mw'],
    "bailvavanaka": ['mw'],
    "bailvayata": ['mw'],
    "bailvāyana": ['mw'],
    "bailya": ['mw'],
    "bailyāyana": ['mw'],
    "bailāyana": ['mw'],
    "baimbaki": ['mw'],
    "baimbika": ['ddsa'],
    "bainda": ['cae', 'mw'],
    "baindava": ['mw'],
    "baindavi": ['mw'],
    "baindavīya": ['mw'],
    "baiḍāla": ['ap90', 'cae', 'ddsa', 'mw'],
    "baiḍālavrata": ['mw'],
    "baiḍālavrati": ['mw'],
    "baiḍālavratika": ['cae', 'mw'],
    "baiḍālavratin": ['mw'],
    "baiḍālikarṇakakantha": ['mw'],
    "baiḍālikarṇikantha": ['mw'],
    "baiṃbikaḥ": ['ap90'],
    "baiṣka": ['ddsa', 'mw'],
    "baiṭsaṃkhyā": ['mw'],
    "baja": ['mw'],
    "bajjhati": ['cped'],
    "baka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bakabakāya": ['ddsa', 'mw'],
    "bakacara": ['mw'],
    "bakaciñcikā": ['mw'],
    "bakadhūpa": ['mw'],
    "bakadvīpa": ['mw'],
    "bakajit": ['mw'],
    "bakakaccha": ['mw'],
    "bakakalpa": ['mw'],
    "bakanakha": ['mw'],
    "bakanakhagudapariṇaddha": ['mw'],
    "bakaniṣūdana": ['mw'],
    "bakapañcaka": ['mw'],
    "bakapuṣpa": ['bhs', 'mw'],
    "bakaripu": ['ddsa', 'mw'],
    "bakarāja": ['mw'],
    "bakasahavāsin": ['mw'],
    "bakasaktha": ['mw'],
    "bakatva": ['mw'],
    "bakavadha": ['mw'],
    "bakavairin": ['mw'],
    "bakavat": ['mw'],
    "bakavatī": ['mw'],
    "bakavrata": ['cae', 'mw'],
    "bakavratacara": ['mw'],
    "bakavratika": ['mw'],
    "bakavratin": ['mw'],
    "bakavṛkṣa": ['mw'],
    "bakavṛtti": ['cae', 'mw'],
    "bakayantra": ['mw'],
    "bakaḥ": ['ap90'],
    "bakerukā": ['ap90', 'mw'],
    "bakeśa": ['ddsa', 'mw'],
    "bakkhituṁ": ['cped'],
    "bakkula": ['bhs'],
    "bakoṭa": ['cae', 'ddsa', 'mw'],
    "bakoṭaḥ": ['ap90'],
    "bakula": ['cae', 'ddsa', 'mw'],
    "bakuladāman": ['cae', 'mw'],
    "bakulamedhī": ['mw'],
    "bakulamālinīpariṇaya": ['mw'],
    "bakulamālā": ['cae', 'mw'],
    "bakulaḥ": ['ap90'],
    "bakulita": ['mw'],
    "bakulā": ['mw'],
    "bakulābharaṇacāṭu": ['mw'],
    "bakulābharaṇamuni": ['mw'],
    "bakulāraṇyamāhātmya": ['mw'],
    "bakulāvali": ['cae', 'mw'],
    "bakulāvalikā": ['cae', 'mw'],
    "bakulī": ['mw'],
    "bakura": ['ap90', 'cae', 'gra', 'mw'],
    "bakācī": ['mw'],
    "bakālīna": ['mw'],
    "bakāra": ['mw'],
    "bakāri": ['mw'],
    "bakāya": ['mw'],
    "bakī": ['mw'],
    "bakūla": ['mw'],
    "bakūlaḥ": ['ap90'],
    "bal": ['ap90', 'ddsa', 'mw'],
    "bala": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "balabalī": ['mw'],
    "balabandhu": ['mw'],
    "balabha": ['cae', 'ddsa', 'mw'],
    "balabhadra": ['bhs', 'cae', 'ddsa', 'mw'],
    "balabhadrikā": ['mw'],
    "balabhadrā": ['mw'],
    "balabhid": ['cae', 'mw'],
    "balabhitsakhi": ['mw'],
    "balabhṛt": ['cae', 'mw'],
    "balabāhu": ['bhs'],
    "balacakra": ['cae', 'mw'],
    "balacakravartin": ['bhs', 'mw'],
    "balada": ['cae', 'cped', 'mw'],
    "baladarpa": ['mw'],
    "baladatta": ['bhs'],
    "baladeva": ['bhs', 'cae', 'mw'],
    "baladevapattana": ['mw'],
    "baladevasvasṛ": ['mw'],
    "baladevāhnika": ['mw'],
    "baladevāhnikā": ['mw'],
    "baladeya": ['cae', 'gra', 'mw'],
    "baladhara": ['mw'],
    "baladharaṇīya": ['bhs'],
    "baladviṣ": ['mw'],
    "baladā": ['cae', 'gra', 'mw'],
    "baladāna": ['cped'],
    "baladāvan": ['cae', 'mw'],
    "baladībhūta": ['mw'],
    "balagupta": ['mw'],
    "balaguptā": ['bhs', 'mw'],
    "balahan": ['mw'],
    "balahantṛ": ['mw'],
    "balahara": ['mw'],
    "balahaṣa": ['mw'],
    "balahīna": ['cae', 'mw'],
    "balahīnatā": ['mw'],
    "balaja": ['cae', 'mw'],
    "balajyeṣṭha": ['mw'],
    "balajā": ['mw'],
    "balaka": ['bhs', 'mw'],
    "balakara": ['ddsa', 'mw'],
    "balakhin": ['mw'],
    "balakkāra": ['cped'],
    "balakoṭṭhaka": ['cped'],
    "balakrama": ['mw'],
    "balakāma": ['mw'],
    "balakāya": ['bhs', 'cped', 'mw'],
    "balakṛt": ['mw'],
    "balakṛta": ['cae', 'mw'],
    "balakṛti": ['cae', 'mw'],
    "balakṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "balakṣagu": ['cae', 'mw'],
    "balakṣataṇḍulā": ['mw'],
    "balakṣobha": ['ddsa', 'mw'],
    "balala": ['mw'],
    "balalaḥ": ['ap90'],
    "balamada": ['cae', 'mw'],
    "balamattā": ['cped'],
    "balamitra": ['bhs'],
    "balamukhya": ['cae', 'mw'],
    "balana": ['mw'],
    "balanagara": ['mw'],
    "balanaṃ": ['ap90'],
    "balanigraha": ['mw'],
    "balanisūdana": ['mw'],
    "balanāśana": ['mw'],
    "balapati": ['cae', 'mw'],
    "balappatta": ['cped'],
    "balaprabhāsamati": ['bhs'],
    "balaprada": ['cae', 'mw'],
    "balapramathanī": ['mw'],
    "balaprasū": ['mw'],
    "balaprāṇa": ['mw'],
    "balapura": ['cae', 'mw'],
    "balapūrva": ['mw'],
    "balapūrṇa": ['mw'],
    "balarāma": ['cae', 'mw'],
    "balarāmapañcānana": ['mw'],
    "balasamūha": ['cae', 'mw'],
    "balasena": ['bhs', 'mw'],
    "balasenā": ['cae', 'mw'],
    "balastha": ['cae', 'mw'],
    "balasthala": ['mw'],
    "balasthiti": ['mw'],
    "balasūdana": ['mw'],
    "balattha": ['cped'],
    "balatā": ['bhs'],
    "balaugha": ['mw'],
    "balavant": ['bhs', 'cae', 'cped'],
    "balavardhana": ['mw'],
    "balavardhin": ['mw'],
    "balavardhinī": ['mw'],
    "balavarjita": ['mw'],
    "balavarmadeva": ['mw'],
    "balavarman": ['mw'],
    "balavarṇin": ['mw'],
    "balavat": ['ap90', 'ddsa', 'gra', 'mw'],
    "balavattama": ['mw'],
    "balavattara": ['mw'],
    "balavattva": ['mw'],
    "balavattā": ['ap90', 'cae', 'mw'],
    "balavatī": ['mw'],
    "balavayasana": ['mw'],
    "balavayasanasaṃkula": ['mw'],
    "balavijñāya": ['gra', 'mw'],
    "balavikarṇikā": ['mw'],
    "balavinyāsa": ['mw'],
    "balavipulahetumati": ['mw'],
    "balavirya": ['mw'],
    "balavyāpad": ['mw'],
    "balavyūha": ['bhs', 'mw'],
    "balavāhana": ['cped'],
    "balavīrya": ['mw'],
    "balavīryaparākrama": ['mw'],
    "balavṛtra": ['mw'],
    "balavṛtraghna": ['cae', 'mw'],
    "balavṛtrahan": ['cae', 'mw'],
    "balavṛtraniṣūdana": ['cae', 'mw'],
    "balaya": ['mw'],
    "balayati": ['ap90'],
    "balayukta": ['cae', 'mw'],
    "balayuta": ['cae', 'mw'],
    "balaśarman": ['mw'],
    "balaśālin": ['mw'],
    "balaśālitā": ['mw'],
    "balaṃ": ['ap90'],
    "balaṃdharā": ['mw'],
    "balaṅga": ['mw'],
    "balaṣa": ['mw'],
    "balaṭṭha": ['cped'],
    "balbaja": ['cae', 'ddsa', 'gra', 'mw'],
    "balbajamaya": ['mw'],
    "balbajastukā": ['gra', 'mw'],
    "balbajika": ['mw'],
    "balbalā": ['mw'],
    "balbalākāra": ['ddsa', 'mw'],
    "balbalākāram": ['mw'],
    "balbalākṛ": ['cae'],
    "balbūla": ['cae', 'mw'],
    "balbūtha": ['cae', 'gra', 'mw'],
    "balendraketu": ['bhs'],
    "baleśa": ['mw'],
    "balh": ['mw'],
    "balhi": ['mw'],
    "balhika": ['cae', 'ddsa', 'mw'],
    "bali": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "balibandhana": ['mw'],
    "balibhadra": ['mw'],
    "balibhoja": ['mw'],
    "balibhojana": ['cae', 'mw'],
    "balibhuj": ['cae', 'mw'],
    "balibhṛt": ['cae', 'mw'],
    "baliceṣṭitavarṇana": ['mw'],
    "balidhvaṃsin": ['mw'],
    "balidviṣ": ['mw'],
    "balidāna": ['mw'],
    "balidānapaddhati": ['mw'],
    "balidānavidhi": ['mw'],
    "baligāyatrī": ['mw'],
    "balihan": ['mw'],
    "baliharaṇa": ['cae', 'cped', 'ddsa', 'mw'],
    "baliharaṇavidhi": ['mw'],
    "balihoma": ['mw'],
    "balihāra": ['mw'],
    "balihṛt": ['cae', 'gra', 'mw'],
    "balika": ['bhs', 'mw'],
    "balikamma": ['cped'],
    "balikara": ['mw'],
    "balikarambha": ['mw'],
    "balikarman": ['cae', 'mw'],
    "balikā": ['cped', 'mw'],
    "balikṛt": ['mw'],
    "balimahānarendrākhyāna": ['mw'],
    "baliman": ['ap90', 'mw'],
    "balimandira": ['mw'],
    "balimat": ['ap90', 'mw'],
    "balimātra": ['mw'],
    "balin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "balina": ['ap90'],
    "balinandana": ['mw'],
    "baliniyamanodyata": ['ddsa'],
    "baliniyamanodyuta": ['mw'],
    "balinī": ['mw'],
    "balipaṭiggāhaka": ['cped'],
    "balipodakī": ['mw'],
    "balipratigrāhaka": ['mw'],
    "balipriya": ['mw'],
    "baliputra": ['mw'],
    "baliputramokṣaṇa": ['mw'],
    "balipuṣṭa": ['cae', 'mw'],
    "balipuṭṭha": ['cped'],
    "balipīṭhalakṣaṇa": ['mw'],
    "balisadman": ['mw'],
    "balisuta": ['cae'],
    "balisūdana": ['mw'],
    "balitantra": ['mw'],
    "balivadda": ['cped'],
    "balivarda": ['ap90', 'cae', 'ddsa', 'mw'],
    "balivardī": ['mw'],
    "baliveśman": ['mw'],
    "balividhāna": ['cae', 'mw'],
    "balivindhya": ['mw'],
    "balivyākula": ['ddsa', 'mw'],
    "balivāhana": ['mw'],
    "balivāka": ['mw'],
    "balivṛṣahan": ['mw'],
    "baliśa": ['mw'],
    "baliśaṃ": ['ap90'],
    "baliśeṣa": ['mw'],
    "baliḥ": ['ap90'],
    "baliṃdama": ['mw'],
    "baliṃdamaprakhya": ['mw'],
    "baliṃdamaḥ": ['ap90'],
    "baliṣaḍbhāga": ['mw'],
    "baliṣaḍbhāgahārin": ['mw'],
    "baliṣṇu": ['ap90', 'mw'],
    "baliṣṭha": ['ap90', 'cae', 'ddsa', 'mw'],
    "baliṣṭhatama": ['mw'],
    "balkasa": ['cae', 'mw'],
    "balla": ['mw'],
    "ballava": ['cae', 'ddsa', 'mw'],
    "ballavatva": ['mw'],
    "ballavatā": ['mw'],
    "ballavayuvati": ['mw'],
    "ballavaḥ": ['ap90'],
    "ballavī": ['mw'],
    "ballāla": ['ddsa', 'mw'],
    "ballāladeva": ['mw'],
    "ballālamiśra": ['mw'],
    "ballālasenadeva": ['mw'],
    "balonmatta": ['mw'],
    "balopapanna": ['mw'],
    "balopaviṣṭa": ['mw'],
    "balopeta": ['mw'],
    "balotkaṭā": ['mw'],
    "balotsāha": ['ddsa', 'mw'],
    "balva": ['mw'],
    "balvaja": ['mw'],
    "balvajaḥ": ['ap90'],
    "balvī": ['mw'],
    "balya": ['ap90', 'cae', 'ddsa', 'mw'],
    "balyupakhyāna": ['mw'],
    "balyā": ['mw'],
    "balā": ['ap90', 'bhs', 'mw'],
    "balābala": ['cae', 'mw'],
    "balābalabījabhaṅga": ['mw'],
    "balābalasūtrabṛhadvṛtti": ['mw'],
    "balābalākṣepaparihāra": ['mw'],
    "balābhijña": ['bhs', 'mw'],
    "balābhra": ['mw'],
    "balādhika": ['cae', 'ddsa', 'mw'],
    "balādhikaraṇa": ['mw'],
    "balādhyakṣa": ['cae', 'mw'],
    "balādhāna": ['bhs'],
    "balādyā": ['mw'],
    "balāgra": ['ddsa', 'mw'],
    "balāhaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "balāhakaḥ": ['ap90'],
    "balāhaṃ": ['ap90'],
    "balāhukka": ['bhs'],
    "balāhvakanda": ['mw'],
    "balāhvā": ['mw'],
    "balāka": ['cae', 'ddsa', 'mw'],
    "balākalpa": ['bhs'],
    "balākayoni": ['cped'],
    "balākaḥ": ['ap90'],
    "balākikā": ['ap90', 'mw'],
    "balākin": ['ap90', 'ddsa', 'mw'],
    "balākā": ['cped', 'mw'],
    "balākākauśika": ['mw'],
    "balākāpaṅktihāsin": ['mw'],
    "balākāśva": ['mw'],
    "balākṣa": ['bhs', 'mw'],
    "balālaka": ['mw'],
    "balāmoṭā": ['mw'],
    "balāntīputra": ['bhs'],
    "balānuja": ['mw'],
    "balānvita": ['mw'],
    "balānīka": ['mw'],
    "balāpakarṣam": ['mw'],
    "balāri": ['ddsa', 'mw'],
    "balārthin": ['cae', 'mw'],
    "balārāti": ['mw'],
    "balāsa": ['cae', 'ddsa', 'mw'],
    "balāsabasta": ['mw'],
    "balāsaghna": ['mw'],
    "balāsagrathita": ['mw'],
    "balāsaka": ['mw'],
    "balāsakaḥ": ['ap90'],
    "balāsakṣayakara": ['mw'],
    "balāsanāśana": ['mw'],
    "balāsavardhana": ['mw'],
    "balāsin": ['ap90', 'mw'],
    "balāsura": ['ddsa', 'mw'],
    "balāt": ['mw'],
    "balātkāra": ['cae', 'ddsa', 'mw'],
    "balātkāram": ['mw'],
    "balātkāraḥ": ['ap90'],
    "balātkāreṇa": ['mw'],
    "balātkārita": ['mw'],
    "balātkārābhilāṣin": ['mw'],
    "balātkṛta": ['ap90', 'cae', 'mw'],
    "balātmikā": ['mw'],
    "balāvalepa": ['mw'],
    "balāvastha": ['mw'],
    "balāya": ['ddsa', 'mw'],
    "balāyate": ['ap90'],
    "balāñcitā": ['mw'],
    "balāśva": ['mw'],
    "balāḍhya": ['mw'],
    "balāṅgaka": ['mw'],
    "balī": ['cped'],
    "balīha": ['mw'],
    "balīkaḥ": ['ap90'],
    "balīkṛ": ['ddsa'],
    "balīkṛta": ['mw'],
    "balīna": ['mw'],
    "balīnaḥ": ['ap90'],
    "balīndrasahasranāman": ['mw'],
    "balīvarda": ['cae', 'ddsa'],
    "balīvardaḥ": ['ap90'],
    "balīvardin": ['mw'],
    "balīvardineya": ['mw'],
    "balīvāka": ['mw'],
    "balīyas": ['ap90', 'mw'],
    "balīyasa": ['mw'],
    "balīyastara": ['mw'],
    "balīyastva": ['mw'],
    "balīyati": ['bhs'],
    "balīyaṃs": ['cae'],
    "balśa": ['mw'],
    "balūka": ['mw'],
    "balūla": ['ap90', 'mw'],
    "bal̤ā": ['cae', 'mw'],
    "bamb": ['mw'],
    "bambagairava": ['mw'],
    "bambaviśvavayas": ['mw'],
    "bambhara": ['mw'],
    "bambharāli": ['cae', 'ddsa', 'mw'],
    "bambharālī": ['mw'],
    "bambhārava": ['cae', 'mw'],
    "bambhāri": ['mw'],
    "bamburevaṇa": ['mw'],
    "bambāviśvavayas": ['mw'],
    "band": ['mw'],
    "bandh": ['cae', 'ddsa', 'gra', 'mw'],
    "bandha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bandhadeśa": ['mw'],
    "bandhaka": ['bhs', 'cae', 'mw'],
    "bandhakampa": ['mw'],
    "bandhakaraṇa": ['mw'],
    "bandhakartṛ": ['mw'],
    "bandhakatva": ['mw'],
    "bandhakaumudī": ['mw'],
    "bandhakī": ['mw'],
    "bandhamaya": ['mw'],
    "bandhamocanikā": ['mw'],
    "bandhamocinī": ['mw'],
    "bandhamudrā": ['mw'],
    "bandhana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bandhanagranthi": ['mw'],
    "bandhanakośa": ['cae'],
    "bandhanakārin": ['mw'],
    "bandhanakāritā": ['mw'],
    "bandhanapālaka": ['mw'],
    "bandhanarajju": ['mw'],
    "bandhanastha": ['cae', 'mw'],
    "bandhanasthāna": ['mw'],
    "bandhanaveśman": ['mw'],
    "bandhanika": ['ddsa', 'mw'],
    "bandhanikṣepa": ['bhs'],
    "bandhanta": ['cped'],
    "bandhanādhikāra": ['mw'],
    "bandhanāgāra": ['cae', 'cped', 'mw'],
    "bandhanāgārika": ['cped'],
    "bandhanālaya": ['mw'],
    "bandhanāntakara": ['bhs'],
    "bandhanīya": ['cae', 'cped', 'ddsa', 'mw'],
    "bandhanṛtya": ['mw'],
    "bandhapāruṣya": ['mw'],
    "bandhapāśa": ['cae', 'ddsa', 'mw'],
    "bandhastambha": ['mw'],
    "bandhatantra": ['mw'],
    "bandhati": ['cped'],
    "bandhatrayavidhāna": ['mw'],
    "bandhava": ['cped'],
    "bandhavimocanastotra": ['mw'],
    "bandhayitṛ": ['ddsa', 'mw'],
    "bandhi": ['cped', 'mw'],
    "bandhin": ['cae', 'ddsa', 'mw'],
    "bandhita": ['mw'],
    "bandhitabba": ['cped'],
    "bandhitra": ['mw'],
    "bandhituṁ": ['cped'],
    "bandhitvā": ['cped'],
    "bandhiya": ['cped'],
    "bandhu": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bandhubhāva": ['mw'],
    "bandhubhāṣita": ['mw'],
    "bandhubāndhava": ['cae'],
    "bandhudagdha": ['mw'],
    "bandhudatta": ['mw'],
    "bandhudattā": ['mw'],
    "bandhudāyāda": ['cae', 'mw'],
    "bandhueṣa": ['gra'],
    "bandhuhīna": ['mw'],
    "bandhujana": ['cae', 'mw'],
    "bandhujīva": ['mw'],
    "bandhujīvaka": ['cped', 'mw'],
    "bandhujīvin": ['mw'],
    "bandhujīvābhitāmra": ['mw'],
    "bandhuka": ['mw'],
    "bandhukin": ['mw'],
    "bandhukā": ['mw'],
    "bandhukāma": ['mw'],
    "bandhukī": ['mw'],
    "bandhukṛt": ['mw'],
    "bandhukṛtya": ['cae', 'mw'],
    "bandhukṣit": ['gra', 'mw'],
    "bandhula": ['cae', 'ddsa', 'mw'],
    "bandhulānvaya": ['mw'],
    "bandhuma": ['bhs'],
    "bandhumant": ['bhs', 'cae', 'cped'],
    "bandhumat": ['ddsa', 'gra', 'mw'],
    "bandhumatī": ['bhs', 'mw'],
    "bandhumatīya": ['bhs'],
    "bandhumatīyaka": ['mw'],
    "bandhumitra": ['mw'],
    "bandhumā": ['bhs'],
    "bandhupati": ['mw'],
    "bandhuprabha": ['mw'],
    "bandhupriya": ['cae', 'mw'],
    "bandhuprīti": ['mw'],
    "bandhupuṣpamāla": ['mw'],
    "bandhupāla": ['mw'],
    "bandhupālita": ['mw'],
    "bandhupṛch": ['gra', 'mw'],
    "bandhura": ['cae', 'ddsa', 'mw'],
    "bandhuragātrī": ['mw'],
    "bandhurakomalāṅguli": ['mw'],
    "bandhuraḥ": ['mw'],
    "bandhurita": ['ddsa', 'mw'],
    "bandhurā": ['mw'],
    "bandhurīya": ['mw'],
    "bandhutva": ['mw'],
    "bandhutā": ['cae', 'gra', 'mw'],
    "bandhuvarga": ['mw'],
    "bandhuvarman": ['mw'],
    "bandhuvat": ['cae', 'ddsa', 'mw'],
    "bandhuvañcaka": ['mw'],
    "bandhuśoka": ['mw'],
    "bandhveṣa": ['gra', 'mw'],
    "bandhya": ['cae', 'ddsa', 'mw'],
    "bandhyeṣa": ['cae'],
    "bandhyāśva": ['mw'],
    "bandhāki": ['mw'],
    "bandhāpesi": ['cped'],
    "bandhāpeti": ['cped'],
    "bandhāpita": ['cped'],
    "bandhū": ['mw'],
    "bandhūbhū": ['mw'],
    "bandhūka": ['cae', 'ddsa', 'mw'],
    "bandhūkapuṣpa": ['mw'],
    "bandhūkapuṣparajas": ['mw'],
    "bandhūkṛ": ['ddsa', 'mw'],
    "bandhūkṛta": ['mw'],
    "bandhūli": ['mw'],
    "bandhūra": ['mw'],
    "bandi": ['mw'],
    "bandicaura": ['mw'],
    "bandigraha": ['cae', 'ddsa', 'mw'],
    "bandigrāha": ['mw'],
    "bandin": ['cae', 'ddsa', 'mw'],
    "bandiputra": ['ddsa', 'mw'],
    "bandipāṭha": ['mw'],
    "bandisthita": ['mw'],
    "bandistrī": ['mw'],
    "banditva": ['mw'],
    "banditā": ['cae', 'mw'],
    "bandiārayu": ['mw'],
    "bandiśālikā": ['mw'],
    "bandiśūlā": ['mw'],
    "bandī": ['cae', 'ddsa', 'mw'],
    "bandīgraha": ['mw'],
    "bandīgṛhīta": ['mw'],
    "bandīkāra": ['mw'],
    "bandīkṛta": ['cae', 'mw'],
    "bandīpāla": ['mw'],
    "baphāra": ['mw'],
    "bappa": ['mw'],
    "bappaka": ['mw'],
    "baps": ['ddsa', 'mw'],
    "bapsat": ['gra'],
    "bapyanīla": ['ddsa', 'mw'],
    "bara": ['mw'],
    "baraṇaseyyaka": ['cped'],
    "baraṭa": ['mw'],
    "baraṭaḥ": ['ap90'],
    "barb": ['mw'],
    "barbara": ['cae', 'ddsa', 'mw'],
    "barbarasthāna": ['mw'],
    "barbaratā": ['mw'],
    "barbaraḥ": ['ap90'],
    "barbari": ['mw'],
    "barbarin": ['mw'],
    "barbarita": ['mw'],
    "barbarottha": ['mw'],
    "barbarā": ['mw'],
    "barbarī": ['mw'],
    "barbarīgandha": ['mw'],
    "barbarīka": ['mw'],
    "barbarīkopākhyāna": ['mw'],
    "barbaṇā": ['ap90'],
    "barbaṭa": ['mw'],
    "barbaṭaḥ": ['ap90'],
    "barbaṭī": ['ap90', 'mw'],
    "barbura": ['mw'],
    "barburaḥ": ['ap90'],
    "barbā": ['mw'],
    "barh": ['ap90', 'ddsa', 'gra', 'mw'],
    "barha": ['cae', 'ddsa', 'mw'],
    "barhabhāra": ['cae', 'ddsa', 'mw'],
    "barhacandraka": ['mw'],
    "barhaka": ['bhs'],
    "barhaketu": ['mw'],
    "barhanetra": ['mw'],
    "barhapuṣpa": ['mw'],
    "barhas": ['gra', 'mw'],
    "barhavat": ['mw'],
    "barhaḥ": ['ap90'],
    "barhaṇa": ['ap90', 'cae', 'mw'],
    "barhaṇacakra": ['mw'],
    "barhaṇaṃ": ['ap90'],
    "barhaṇā": ['cae', 'ddsa', 'gra', 'mw'],
    "barhaṇāvant": ['cae'],
    "barhaṇāvat": ['gra', 'mw'],
    "barhaṇāśva": ['mw'],
    "barhi": ['cae', 'mw'],
    "barhibarha": ['mw'],
    "barhicchada": ['mw'],
    "barhicitraka": ['mw'],
    "barhicūḍā": ['mw'],
    "barhidhvaja": ['ddsa', 'mw'],
    "barhidhvajā": ['mw'],
    "barhikusuma": ['mw'],
    "barhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "barhipuṣpa": ['mw'],
    "barhir": ['mw'],
    "barhirhoma": ['mw'],
    "barhirjyotis": ['mw'],
    "barhirmukha": ['mw'],
    "barhiruttha": ['ddsa', 'mw'],
    "barhis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "barhistṛṇa": ['mw'],
    "barhivāhana": ['ddsa', 'mw'],
    "barhiyāna": ['ddsa', 'mw'],
    "barhiśikha": ['mw'],
    "barhiḥ": ['ap90', 'mw'],
    "barhiḥśuṣman": ['mw'],
    "barhiḥṣad": ['ddsa', 'mw'],
    "barhiḥṣṭha": ['cae', 'mw'],
    "barhiḥṣṭhā": ['cae', 'gra', 'mw'],
    "barhiṇa": ['cae', 'ddsa', 'mw'],
    "barhiṇalakṣaṇa": ['mw'],
    "barhiṇavāhana": ['mw'],
    "barhiṇavāja": ['mw'],
    "barhiṇavāsas": ['mw'],
    "barhiṇaḥ": ['ap90'],
    "barhiṣ": ['mw'],
    "barhiṣad": ['cae', 'ddsa', 'gra', 'mw'],
    "barhiṣada": ['mw'],
    "barhiṣia": ['gra'],
    "barhiṣka": ['ap90', 'ddsa', 'mw'],
    "barhiṣkeśa": ['mw'],
    "barhiṣmant": ['cae'],
    "barhiṣmat": ['ap90', 'ddsa', 'gra', 'mw'],
    "barhiṣmatī": ['mw'],
    "barhiṣpala": ['mw'],
    "barhiṣpūla": ['mw'],
    "barhiṣya": ['cae', 'gra', 'mw'],
    "barhiṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "barhiṣṭham": ['mw'],
    "barhāpīḍa": ['cae', 'mw'],
    "barhāpīḍaka": ['mw'],
    "barhāya": ['ddsa'],
    "barhāyita": ['mw'],
    "barihisa": ['cped'],
    "bariśī": ['mw'],
    "barjaha": ['cae', 'ddsa', 'gra', 'mw'],
    "barjahya": ['cae', 'mw'],
    "barjara": ['mw'],
    "barkara": ['cae', 'mw'],
    "barkarakarkara": ['ddsa', 'mw'],
    "barku": ['cae', 'mw'],
    "barodā": ['mw'],
    "barsa": ['cae', 'ddsa', 'mw'],
    "barsanaddhi": ['mw'],
    "barsaḥ": ['ap90'],
    "barsva": ['cae', 'mw'],
    "barsvaḥ": ['ap90'],
    "baru": ['ddsa', 'mw'],
    "barv": ['ap90'],
    "barāsī": ['cae', 'ddsa', 'mw'],
    "barīvarda": ['mw'],
    "barīvardaḥ": ['ap90'],
    "basri": ['cae', 'ddsa', 'gra', 'mw'],
    "basta": ['cae', 'ddsa', 'gra', 'mw'],
    "bastagandhā": ['mw'],
    "bastagandhākṛti": ['mw'],
    "bastakarṇa": ['mw'],
    "bastamodā": ['mw'],
    "bastamukha": ['mw'],
    "bastamāram": ['mw'],
    "bastamūtra": ['mw'],
    "bastavāśin": ['mw'],
    "bastaśṛṅgī": ['mw'],
    "bastaḥ": ['ap90'],
    "basti": ['cae', 'ddsa', 'mw'],
    "bastya": ['mw'],
    "bastābhivāśin": ['mw'],
    "bastājina": ['cae', 'mw'],
    "bastāmbu": ['mw'],
    "bastāntrī": ['mw'],
    "bata": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "battiṁsati": ['cped'],
    "baubhukṣa": ['mw'],
    "bauddha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "bauddhadarśana": ['cae', 'mw'],
    "bauddhadhikkāra": ['mw'],
    "bauddhadhikkāradīdhiti": ['mw'],
    "bauddhadhikkāraguṇānandī": ['mw'],
    "bauddhadhikkāragādādharī": ['mw'],
    "bauddhadhikkārarahasya": ['mw'],
    "bauddhadūṣaṇa": ['mw'],
    "bauddhamata": ['cae', 'mw'],
    "bauddhamatadūṣaṇa": ['mw'],
    "bauddhamatanivarhaṇa": ['mw'],
    "bauddhasaṃgati": ['mw'],
    "bauddhaśāstra": ['mw'],
    "baudha": ['ddsa', 'mw'],
    "baudhaḥ": ['ap90'],
    "baudheya": ['mw'],
    "baudhi": ['mw'],
    "baudhnya": ['mw'],
    "baudhya": ['mw'],
    "baudhāyana": ['cae', 'ddsa', 'mw'],
    "baudhāyanacarakasautrāmaṇī": ['mw'],
    "baudhāyanaprayoga": ['mw'],
    "baudhāyanasaṃgraha": ['mw'],
    "baudhāyanasmṛti": ['mw'],
    "baudhāyanatati": ['mw'],
    "baudhāyanavidhi": ['mw'],
    "baudhāyanaśikṣā": ['mw'],
    "baudhāyanaśrautaprayogasāra": ['mw'],
    "baudhāyanaḥ": ['ap90'],
    "baudhāyanīpariśiṣṭa": ['mw'],
    "baudhāyanīya": ['mw'],
    "baudhāyanīyaprayogasāra": ['mw'],
    "baudhīputra": ['mw'],
    "bava": ['mw'],
    "bavaḥ": ['ap90'],
    "bavhābādha": ['cped'],
    "baḍ": ['gra'],
    "baḍabā": ['mw'],
    "baḍapilā": ['mw'],
    "baḍi": ['bhs'],
    "baḍiśa": ['cae', 'mw'],
    "baḍiśayuta": ['mw'],
    "baḍiśaṃ": ['ap90'],
    "baḍā": ['cae', 'ddsa', 'gra', 'mw'],
    "baḍāha": ['ddsa', 'mw'],
    "baḥ": ['ap90'],
    "baṃb": ['ap90'],
    "baṃbharaḥ": ['ap90'],
    "baṃbharālī": ['ap90'],
    "baṃdh": ['ap90'],
    "baṃdhakaḥ": ['ap90'],
    "baṃdhana": ['ap90'],
    "baṃdhaḥ": ['ap90'],
    "baṃdhita": ['ap90'],
    "baṃdhitraḥ": ['ap90'],
    "baṃdhraṃ": ['ap90'],
    "baṃdhudā": ['ap90'],
    "baṃdhukaḥ": ['ap90'],
    "baṃdhula": ['ap90'],
    "baṃdhumat": ['ap90'],
    "baṃdhura": ['ap90'],
    "baṃdhutvaṃ": ['ap90'],
    "baṃdhutā": ['ap90'],
    "baṃdhuḥ": ['ap90'],
    "baṃdhya": ['ap90'],
    "baṃdhyā": ['ap90'],
    "baṃdhūkaḥ": ['ap90'],
    "baṃdhūliḥ": ['ap90'],
    "baṃdhūra": ['ap90'],
    "baṃdin": ['ap90'],
    "baṃdiḥ": ['ap90'],
    "baṃh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "baṃhiman": ['ap90', 'mw'],
    "baṃhiṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "baṃhīyas": ['ap90', 'mw'],
    "baṇ": ['mw'],
    "baṇij": ['mw'],
    "baṇḍa": ['cae', 'ddsa', 'mw'],
    "baṇḍā": ['mw'],
    "baṣkaya": ['ap90', 'ddsa', 'gra', 'mw'],
    "baṣkayaṇī": ['ap90', 'mw'],
    "baṣkayinī": ['ap90'],
    "baṣkayiṇī": ['ap90', 'mw'],
    "baṣkiha": ['mw'],
    "baṣṭa": ['mw'],
    "baṭ": ['cae', 'ddsa', 'mw'],
    "baṭaraka": ['mw'],
    "baṭh": ['mw'],
    "baṭu": ['cae', 'ddsa', 'mw'],
    "baṭucaritanāṭaka": ['mw'],
    "baṭudāsa": ['mw'],
    "baṭuka": ['mw'],
    "baṭukabhairava": ['mw'],
    "baṭukabhairavadīpadāna": ['mw'],
    "baṭukabhairavakavaca": ['mw'],
    "baṭukabhairavapañcāṅga": ['mw'],
    "baṭukabhairavapūjā": ['mw'],
    "baṭukabhairavapūjāpaddhati": ['mw'],
    "baṭukabhairavasahasranāman": ['mw'],
    "baṭukabhairavasahasranāmastotra": ['mw'],
    "baṭukabhairavastavarāja": ['mw'],
    "baṭukabhairavastotra": ['mw'],
    "baṭukabhairavatantra": ['mw'],
    "baṭukabhairavāpaduddharaṇapaṭala": ['mw'],
    "baṭukakavaca": ['mw'],
    "baṭukanātha": ['mw'],
    "baṭukapañcāṅga": ['mw'],
    "baṭukapañcāṅgaprayogapaddhati": ['mw'],
    "baṭukapañjara": ['mw'],
    "baṭukapūjāpaddhati": ['mw'],
    "baṭukārcana": ['mw'],
    "baṭukārcanacandrikā": ['mw'],
    "baṭukārcanadīpikā": ['mw'],
    "baṭukārcanavidhi": ['mw'],
    "baṭukāṣṭaśatanāman": ['mw'],
    "baṭumātra": ['mw'],
    "baṭurūpin": ['mw'],
    "baṭuḥ": ['ap90'],
    "baṭūkaraṇa": ['mw'],
    "baṭūkaraṇaṃ": ['ap90'],
    "baṭṭa": ['mw'],
    "baṭṭalohaka": ['mw'],
    "baṭṭīśīvrata": ['mw'],
    "bebhiditavya": ['mw'],
    "bedarakara": ['mw'],
    "beh": ['ap90', 'mw'],
    "bekanāṭa": ['cae', 'gra', 'mw'],
    "bekanāṭaḥ": ['ap90'],
    "bekuri": ['mw'],
    "bekurā": ['cae', 'mw'],
    "beluva": ['cped'],
    "beluvalaṭṭhi": ['cped'],
    "beluvapakka": ['cped'],
    "beluvasalāṭuka": ['cped'],
    "bemba": ['mw'],
    "bembārava": ['mw'],
    "beś": ['mw'],
    "beḍā": ['ap90', 'mw'],
    "beṭī": ['mw'],
    "bha": ['cae', 'ddsa', 'mw'],
    "bhaas": ['gra'],
    "bhaasvat": ['gra'],
    "bhabba": ['cped'],
    "bhabbatā": ['cped'],
    "bhabhrama": ['mw'],
    "bhacakra": ['mw'],
    "bhacakranābhi": ['mw'],
    "bhacca": ['cped'],
    "bhadanta": ['bhs', 'cped', 'ddsa', 'mw'],
    "bhadantadharmatrāta": ['mw'],
    "bhadantaghoṣaka": ['mw'],
    "bhadantagopadatta": ['mw'],
    "bhadantajñānavarman": ['mw'],
    "bhadantarāma": ['mw'],
    "bhadantavarman": ['mw'],
    "bhadantaśrīlābha": ['mw'],
    "bhadatta": ['mw'],
    "bhadaṃtaḥ": ['ap90'],
    "bhadda": ['cped'],
    "bhaddaghaṭa": ['cped'],
    "bhaddaka": ['cped'],
    "bhaddakaccānā": ['cped'],
    "bhaddakumbha": ['cped'],
    "bhaddamukha": ['cped'],
    "bhaddanta": ['cped'],
    "bhaddapadā": ['cped'],
    "bhaddapīṭha": ['cped'],
    "bhaddayuga": ['cped'],
    "bhaddikā": ['cped'],
    "bhaddā": ['cped'],
    "bhaddālin": ['bhs', 'mw'],
    "bhaddāru": ['cped'],
    "bhadra": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhadrabalana": ['mw'],
    "bhadrabalā": ['mw'],
    "bhadrabhaṭa": ['mw'],
    "bhadrabhuja": ['cae', 'mw'],
    "bhadrabhūṣaṇā": ['mw'],
    "bhadrabāhu": ['mw'],
    "bhadrabāhucaritra": ['mw'],
    "bhadrabāhusaṃhitā": ['mw'],
    "bhadrabāhuśāstra": ['mw'],
    "bhadrabāhū": ['mw'],
    "bhadracari": ['bhs'],
    "bhadracāru": ['mw'],
    "bhadracūḍa": ['mw'],
    "bhadradanta": ['mw'],
    "bhadradantikā": ['mw'],
    "bhadradatta": ['mw'],
    "bhadradeha": ['mw'],
    "bhadradeva": ['mw'],
    "bhadrados": ['mw'],
    "bhadradvīpa": ['mw'],
    "bhadradāru": ['mw'],
    "bhadradīpa": ['mw'],
    "bhadragandhikā": ['mw'],
    "bhadragaura": ['mw'],
    "bhadragaṇita": ['mw'],
    "bhadraghaṭa": ['mw'],
    "bhadraghaṭaka": ['mw'],
    "bhadragupta": ['bhs', 'mw'],
    "bhadrahasta": ['gra', 'mw'],
    "bhadrahrada": ['mw'],
    "bhadrailā": ['mw'],
    "bhadraja": ['mw'],
    "bhadrajaya": ['mw'],
    "bhadrajit": ['bhs'],
    "bhadrajāni": ['gra', 'mw'],
    "bhadrajātika": ['mw'],
    "bhadraka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "bhadrakalpa": ['bhs', 'mw'],
    "bhadrakalpika": ['bhs', 'mw'],
    "bhadrakalpikasūtra": ['bhs'],
    "bhadrakalpīya": ['bhs'],
    "bhadrakanyā": ['bhs', 'mw'],
    "bhadrakapila": ['mw'],
    "bhadrakarṇa": ['bhs'],
    "bhadrakarṇeśvara": ['mw'],
    "bhadrakarṇikā": ['mw'],
    "bhadrakaṇṭa": ['mw'],
    "bhadrakumbha": ['mw'],
    "bhadrakā": ['mw'],
    "bhadrakālī": ['cae', 'mw'],
    "bhadrakālīcintāmaṇi": ['mw'],
    "bhadrakālīkavaca": ['mw'],
    "bhadrakālīmantra": ['mw'],
    "bhadrakālīmanu": ['mw'],
    "bhadrakālīmāhātmya": ['mw'],
    "bhadrakālīpurāṇa": ['mw'],
    "bhadrakālīpūjāvidhi": ['mw'],
    "bhadrakālīpūjāyantra": ['mw'],
    "bhadrakānta": ['bhs'],
    "bhadrakāpa": ['mw'],
    "bhadrakāpya": ['mw'],
    "bhadrakāra": ['mw'],
    "bhadrakāraka": ['cae', 'mw'],
    "bhadrakāśī": ['mw'],
    "bhadrakāṣṭha": ['mw'],
    "bhadrakṛt": ['cae', 'gra', 'mw'],
    "bhadralakṣaṇa": ['mw'],
    "bhadralatā": ['mw'],
    "bhadram": ['mw'],
    "bhadramallikā": ['mw'],
    "bhadramanas": ['mw'],
    "bhadramanda": ['mw'],
    "bhadramati": ['bhs'],
    "bhadramukha": ['cae', 'mw'],
    "bhadramusta": ['cae', 'mw'],
    "bhadramustaka": ['mw'],
    "bhadramustā": ['mw'],
    "bhadramuñja": ['mw'],
    "bhadramuṣṭika": ['bhs'],
    "bhadramātṛ": ['mw'],
    "bhadramṛga": ['mw'],
    "bhadranidhi": ['mw'],
    "bhadranāman": ['mw'],
    "bhadranāmikā": ['mw'],
    "bhadrapada": ['bhs', 'mw'],
    "bhadrapadā": ['mw'],
    "bhadrapadāyoga": ['mw'],
    "bhadraparṇā": ['mw'],
    "bhadraparṇī": ['mw'],
    "bhadrapura": ['bhs', 'mw'],
    "bhadrapāda": ['mw'],
    "bhadrapāla": ['bhs', 'mw'],
    "bhadrapāpa": ['cae', 'mw'],
    "bhadrapīṭha": ['cae', 'mw'],
    "bhadraratha": ['mw'],
    "bhadrareṇu": ['mw'],
    "bhadrarohiṇī": ['mw'],
    "bhadraruci": ['mw'],
    "bhadrarāja": ['mw'],
    "bhadrarāma": ['mw'],
    "bhadrarūpā": ['mw'],
    "bhadrasaras": ['mw'],
    "bhadrasena": ['bhs', 'cae', 'mw'],
    "bhadrasomā": ['mw'],
    "bhadrasuta": ['mw'],
    "bhadrasvapna": ['mw'],
    "bhadrasālavana": ['mw'],
    "bhadrasāman": ['mw'],
    "bhadrasāra": ['mw'],
    "bhadratara": ['ddsa', 'mw'],
    "bhadrataruṇī": ['mw'],
    "bhadratas": ['cae', 'mw'],
    "bhadrateja": ['bhs'],
    "bhadraturaga": ['mw'],
    "bhadratuṅga": ['mw'],
    "bhadratva": ['cae', 'mw'],
    "bhadratā": ['cae', 'mw'],
    "bhadraudanī": ['mw'],
    "bhadravac": ['gra'],
    "bhadravadana": ['mw'],
    "bhadravallikā": ['mw'],
    "bhadravallī": ['mw'],
    "bhadravant": ['cae'],
    "bhadravargīya": ['bhs', 'mw'],
    "bhadravarman": ['mw'],
    "bhadravasana": ['mw'],
    "bhadravat": ['ap90', 'mw'],
    "bhadravatī": ['mw'],
    "bhadravaṭa": ['mw'],
    "bhadraveṇu": ['mw'],
    "bhadravihāra": ['mw'],
    "bhadravinda": ['mw'],
    "bhadravirāj": ['mw'],
    "bhadravrāta": ['gra', 'mw'],
    "bhadravāc": ['gra', 'mw'],
    "bhadravācya": ['mw'],
    "bhadravādin": ['gra', 'mw'],
    "bhadrayava": ['mw'],
    "bhadrayoga": ['mw'],
    "bhadrayā": ['mw'],
    "bhadrayāna": ['mw'],
    "bhadrayānīya": ['mw'],
    "bhadraśaila": ['bhs'],
    "bhadraśarman": ['mw'],
    "bhadraśaunaka": ['mw'],
    "bhadraśilā": ['bhs', 'mw'],
    "bhadraśoci": ['gra', 'mw'],
    "bhadraśravas": ['mw'],
    "bhadraśraya": ['mw'],
    "bhadraśreṇya": ['mw'],
    "bhadraśriya": ['mw'],
    "bhadraśrut": ['mw'],
    "bhadraśrī": ['bhs', 'cae', 'mw'],
    "bhadraśrīmeruteja": ['bhs'],
    "bhadraśākha": ['mw'],
    "bhadraśālavana": ['mw'],
    "bhadraśīla": ['mw'],
    "bhadraṃkara": ['ap90', 'bhs', 'mw'],
    "bhadraṃkaraṇa": ['mw'],
    "bhadraṃyikā": ['mw'],
    "bhadraṃyā": ['mw'],
    "bhadraṅkara": ['ddsa'],
    "bhadraṣaṣṭhī": ['mw'],
    "bhadrendra": ['mw'],
    "bhadreśa": ['cae', 'mw'],
    "bhadreśvara": ['mw'],
    "bhadrika": ['bhs', 'mw'],
    "bhadrikā": ['ap90', 'bhs', 'mw'],
    "bhadriṇa": ['mw'],
    "bhadrodaya": ['mw'],
    "bhadropavāsavrata": ['mw'],
    "bhadrottamā": ['bhs'],
    "bhadrā": ['ap90', 'bhs', 'mw'],
    "bhadrābhadra": ['mw'],
    "bhadrāha": ['cae', 'mw'],
    "bhadrākaraṇa": ['mw'],
    "bhadrākāra": ['mw'],
    "bhadrākṛ": ['mw'],
    "bhadrākṛti": ['mw'],
    "bhadrākṣa": ['ddsa', 'mw'],
    "bhadrālapattrikā": ['mw'],
    "bhadrālī": ['mw'],
    "bhadrāmahiman": ['mw'],
    "bhadrānagara": ['mw'],
    "bhadrānanda": ['mw'],
    "bhadrāraka": ['mw'],
    "bhadrāsana": ['cae', 'mw'],
    "bhadrātmaja": ['mw'],
    "bhadrāvaha": ['cae', 'mw'],
    "bhadrāvakāśā": ['mw'],
    "bhadrāvatī": ['mw'],
    "bhadrāvrata": ['mw'],
    "bhadrāyudha": ['bhs', 'mw'],
    "bhadrāyus": ['mw'],
    "bhadrāśrama": ['mw'],
    "bhadrāśraya": ['mw'],
    "bhadrāśva": ['cae', 'mw'],
    "bhadrāṅga": ['mw'],
    "bhadāka": ['mw'],
    "bhadākaḥ": ['ap90'],
    "bhaga": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhagabhakta": ['gra', 'mw'],
    "bhagabhakṣaka": ['mw'],
    "bhagadaivata": ['cae', 'mw'],
    "bhagadaivatamāsa": ['mw'],
    "bhagadatta": ['cae', 'ddsa', 'mw'],
    "bhagadeva": ['mw'],
    "bhagadevata": ['cae', 'mw'],
    "bhagadevatā": ['mw'],
    "bhagadheya": ['mw'],
    "bhagadā": ['mw'],
    "bhagadāraṇa": ['mw'],
    "bhagaghna": ['mw'],
    "bhagahan": ['mw'],
    "bhagahārin": ['mw'],
    "bhagakāma": ['mw'],
    "bhagala": ['mw'],
    "bhagalā": ['mw'],
    "bhagama": ['mw'],
    "bhagana": ['mw'],
    "bhaganandā": ['mw'],
    "bhaganarāya": ['mw'],
    "bhagandalā": ['cped'],
    "bhaganetra": ['mw'],
    "bhaganetraghna": ['mw'],
    "bhaganetrahan": ['mw'],
    "bhaganetrahara": ['mw'],
    "bhaganetrahṛt": ['mw'],
    "bhaganetranipātana": ['mw'],
    "bhaganetrāntaka": ['mw'],
    "bhaganetrāpahārin": ['mw'],
    "bhagapura": ['mw'],
    "bhagas": ['ddsa', 'mw'],
    "bhagatti": ['cae', 'ddsa', 'gra', 'mw'],
    "bhagavac": ['mw'],
    "bhagavaccaraṇāravindadhyāna": ['mw'],
    "bhagavacchāstra": ['mw'],
    "bhagavad": ['mw'],
    "bhagavadarcana": ['mw'],
    "bhagavadarcanamāhātmya": ['mw'],
    "bhagavadarcanaprastāva": ['mw'],
    "bhagavadbhakti": ['mw'],
    "bhagavadbhakticandrikollāsa": ['mw'],
    "bhagavadbhakticandrikā": ['mw'],
    "bhagavadbhaktimāhātmya": ['mw'],
    "bhagavadbhaktinirṇaya": ['mw'],
    "bhagavadbhaktirasāyaṇa": ['mw'],
    "bhagavadbhaktiratnāvalī": ['mw'],
    "bhagavadbhaktistotra": ['mw'],
    "bhagavadbhaktisādhana": ['mw'],
    "bhagavadbhaktisārasaṃgraha": ['mw'],
    "bhagavadbhaktitaraṃgiṇī": ['mw'],
    "bhagavadbhaktivilāsa": ['mw'],
    "bhagavadbhaktiviveka": ['mw'],
    "bhagavadbhaṭṭa": ['mw'],
    "bhagavadbhāskara": ['mw'],
    "bhagavadbhāvaka": ['mw'],
    "bhagavaddharmavarṇana": ['mw'],
    "bhagavaddhyānamuktāvalī": ['mw'],
    "bhagavaddhyānasopāna": ['mw'],
    "bhagavaddruma": ['mw'],
    "bhagavaddāsa": ['mw'],
    "bhagavaddṛśa": ['mw'],
    "bhagavadgovinda": ['mw'],
    "bhagavadguṇa": ['mw'],
    "bhagavadguṇadarpaṇa": ['mw'],
    "bhagavadguṇasārasaṃgraha": ['mw'],
    "bhagavadgīta": ['cae', 'ddsa'],
    "bhagavadgītā": ['mw'],
    "bhagavadgītābhāvaprakāśa": ['mw'],
    "bhagavadgītābhāṣya": ['mw'],
    "bhagavadgītābhāṣyavivaraṇa": ['mw'],
    "bhagavadgītābodhaka": ['mw'],
    "bhagavadgītāgūḍhārthadīpikā": ['mw'],
    "bhagavadgītāhetunirṇaya": ['mw'],
    "bhagavadgītālaghuvyākhyā": ['mw'],
    "bhagavadgītālakṣābharaṇa": ['mw'],
    "bhagavadgītāmāhātmya": ['mw'],
    "bhagavadgītāprasthāna": ['mw'],
    "bhagavadgītāpratipada": ['mw'],
    "bhagavadgītārahasya": ['mw'],
    "bhagavadgītārthasaṃgraha": ['mw'],
    "bhagavadgītārthasaṃgraharakṣā": ['mw'],
    "bhagavadgītārthastotra": ['mw'],
    "bhagavadgītārthasāra": ['mw'],
    "bhagavadgītāsamaṅgalācāraślokapaddhati": ['mw'],
    "bhagavadgītāsāra": ['mw'],
    "bhagavadgītāsārasaṃgraha": ['mw'],
    "bhagavadgītātātparya": ['mw'],
    "bhagavadgītātātparyabodhikā": ['mw'],
    "bhagavadgītātātparyabodhinī": ['mw'],
    "bhagavadgītātātparyacandrikā": ['mw'],
    "bhagavadgītātātparyadīpikā": ['mw'],
    "bhagavadgītātātparyanirṇaya": ['mw'],
    "bhagavadgītāvivaraṇa": ['mw'],
    "bhagavadgītāvyākhyā": ['mw'],
    "bhagavadgītāśaya": ['mw'],
    "bhagavadgītāṭīkā": ['mw'],
    "bhagavadrāta": ['mw'],
    "bhagavadudyamanāṭaka": ['mw'],
    "bhagavadupanayana": ['mw'],
    "bhagavadvilāsaratnāvalī": ['mw'],
    "bhagavadviśeṣa": ['mw'],
    "bhagavadyauvanodgama": ['mw'],
    "bhagavadānanda": ['mw'],
    "bhagavadārādhana": ['mw'],
    "bhagavadārādhanakrama": ['mw'],
    "bhagavadārādhanasamarthana": ['mw'],
    "bhagavadāśrayabhūta": ['mw'],
    "bhagavadīya": ['mw'],
    "bhagavadīyatva": ['mw'],
    "bhagavadīyaḥ": ['ap90'],
    "bhagaval": ['mw'],
    "bhagavallāñchanadhāraṇapramāṇaśatapradarśana": ['mw'],
    "bhagavallīlācintāmaṇi": ['mw'],
    "bhagavan": ['mw'],
    "bhagavanmaya": ['ddsa', 'mw'],
    "bhagavanmānapūjā": ['mw'],
    "bhagavannandasaṃvāda": ['mw'],
    "bhagavannāma": ['mw'],
    "bhagavannāmakaumudī": ['mw'],
    "bhagavannāmamāhātmya": ['mw'],
    "bhagavannāmamāhātmyasaṃgraha": ['mw'],
    "bhagavannāmasmaraṇastuti": ['mw'],
    "bhagavannāmāmṛtarasodaya": ['mw'],
    "bhagavannāmāvalī": ['mw'],
    "bhagavant": ['bhs', 'cae', 'cped'],
    "bhagavanta": ['mw'],
    "bhagavantabhāskara": ['mw'],
    "bhagavantadeva": ['mw'],
    "bhagavat": ['ap90', 'ddsa', 'gra', 'mw'],
    "bhagavatpadī": ['mw'],
    "bhagavatprasādamālā": ['mw'],
    "bhagavatpratiṣṭhāvidhi": ['mw'],
    "bhagavatpādābhāṣaṇa": ['mw'],
    "bhagavatpādācārya": ['mw'],
    "bhagavatpūjāvidhi": ['mw'],
    "bhagavatsamārādhanavidhi": ['mw'],
    "bhagavatsiddhāntasaṃgraha": ['mw'],
    "bhagavatsmṛti": ['mw'],
    "bhagavatsvarūpa": ['mw'],
    "bhagavatsvarūpaviṣayaśaṅkānirāsa": ['mw'],
    "bhagavatsvatantratā": ['mw'],
    "bhagavattama": ['mw'],
    "bhagavattara": ['mw'],
    "bhagavattattvadīpikā": ['mw'],
    "bhagavattattvamañjarī": ['mw'],
    "bhagavattva": ['mw'],
    "bhagavatyaṅga": ['mw'],
    "bhagavatī": ['ap90', 'bhs', 'mw'],
    "bhagavatībhāgavatapurāṇa": ['mw'],
    "bhagavatīdāsa": ['mw'],
    "bhagavatīgītā": ['mw'],
    "bhagavatīkeśādipādastava": ['mw'],
    "bhagavatīkīlaka": ['mw'],
    "bhagavatīpadyapuṣpāñjali": ['mw'],
    "bhagavatīpurāṇa": ['mw'],
    "bhagavatīstuti": ['mw'],
    "bhagavatīsūtra": ['mw'],
    "bhagavedana": ['ddsa', 'mw'],
    "bhagavitta": ['mw'],
    "bhagavṛtti": ['mw'],
    "bhagaḥ": ['ap90'],
    "bhagaṃdara": ['mw'],
    "bhagaṃdaraḥ": ['ap90'],
    "bhagaṇa": ['mw'],
    "bhagevita": ['gra', 'mw'],
    "bhageśa": ['cae', 'mw'],
    "bhagga": ['cped'],
    "bhagin": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhaginikā": ['ap90', 'ddsa', 'mw'],
    "bhaginī": ['ap90', 'bhs', 'cped', 'mw'],
    "bhaginībhartṛ": ['mw'],
    "bhaginībhrātṛ": ['mw'],
    "bhaginīpati": ['cae', 'mw'],
    "bhaginīsuta": ['mw'],
    "bhaginīya": ['mw'],
    "bhaginīyaḥ": ['ap90'],
    "bhagna": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhagnabhāṇḍa": ['mw'],
    "bhagnabāhu": ['mw'],
    "bhagnaceṣṭa": ['mw'],
    "bhagnadantanakha": ['mw'],
    "bhagnadarpa": ['mw'],
    "bhagnadaṃṣṭra": ['mw'],
    "bhagnajānu": ['mw'],
    "bhagnaka": ['bhs'],
    "bhagnakrama": ['mw'],
    "bhagnakāma": ['mw'],
    "bhagnamanas": ['cae', 'mw'],
    "bhagnamanoratha": ['mw'],
    "bhagnamāna": ['mw'],
    "bhagnanetra": ['mw'],
    "bhagnanidra": ['mw'],
    "bhagnapariṇāma": ['mw'],
    "bhagnaprakrama": ['mw'],
    "bhagnaprakramatā": ['mw'],
    "bhagnapratijña": ['mw'],
    "bhagnapādarkṣa": ['mw'],
    "bhagnapārśva": ['mw'],
    "bhagnapṛṣṭha": ['mw'],
    "bhagnapṛṣṭhībhavati": ['bhs'],
    "bhagnapṛṣṭhīkaroti": ['bhs'],
    "bhagnasaṃdhi": ['mw'],
    "bhagnasaṃdhika": ['mw'],
    "bhagnatā": ['mw'],
    "bhagnatāla": ['mw'],
    "bhagnaviṣāṇaka": ['mw'],
    "bhagnavrata": ['cae', 'mw'],
    "bhagnayuga": ['cae'],
    "bhagnayuge": ['mw'],
    "bhagnayācña": ['mw'],
    "bhagnaśakti": ['mw'],
    "bhagnaśṛṅga": ['mw'],
    "bhagnodyama": ['mw'],
    "bhagnorudaṇḍa": ['mw'],
    "bhagnotsāhakriyātman": ['mw'],
    "bhagnāpad": ['mw'],
    "bhagnāsthi": ['cae', 'mw'],
    "bhagnāsthibandha": ['mw'],
    "bhagnātman": ['mw'],
    "bhagnāśa": ['cae', 'mw'],
    "bhagnī": ['ap90', 'mw'],
    "bhagola": ['mw'],
    "bhagos": ['cae', 'mw'],
    "bhagoḥ": ['ddsa'],
    "bhagā": ['mw'],
    "bhagādhāna": ['mw'],
    "bhagākṣihan": ['mw'],
    "bhagāla": ['ddsa', 'mw'],
    "bhagālaṃ": ['ap90'],
    "bhagālin": ['ap90', 'mw'],
    "bhagānāmnī": ['mw'],
    "bhagāpahārin": ['mw'],
    "bhagāsya": ['mw'],
    "bhagāṅka": ['ddsa', 'mw'],
    "bhagāṅkita": ['mw'],
    "bhagāṅkura": ['mw'],
    "bhagīna": ['mw'],
    "bhagīratha": ['cae', 'ddsa', 'mw'],
    "bhagīrathadatta": ['mw'],
    "bhagīrathakanyā": ['mw'],
    "bhagīrathapatha": ['mw'],
    "bhagīrathaprayatna": ['mw'],
    "bhagīrathasutā": ['mw'],
    "bhagīrathayaśas": ['mw'],
    "bhagīrathaḥ": ['ap90'],
    "bhagīrathopākhyāna": ['mw'],
    "bhaidika": ['mw'],
    "bhaikṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhaikṣabhuj": ['cae', 'mw'],
    "bhaikṣacaraṇa": ['cae', 'ddsa', 'mw'],
    "bhaikṣacarya": ['cae', 'mw'],
    "bhaikṣacaryā": ['mw'],
    "bhaikṣajīvikā": ['mw'],
    "bhaikṣaka": ['mw'],
    "bhaikṣakāla": ['mw'],
    "bhaikṣava": ['ddsa', 'mw'],
    "bhaikṣavat": ['ddsa', 'mw'],
    "bhaikṣavaṃ": ['ap90'],
    "bhaikṣavṛtti": ['cae', 'mw'],
    "bhaikṣopajīvin": ['cae', 'mw'],
    "bhaikṣuka": ['bhs', 'mw'],
    "bhaikṣya": ['mw'],
    "bhaikṣyaṃ": ['ap90'],
    "bhaikṣāhāra": ['cae', 'mw'],
    "bhaikṣāka": ['bhs', 'mw'],
    "bhaikṣākula": ['bhs', 'mw'],
    "bhaikṣānna": ['cae', 'mw'],
    "bhaikṣārthin": ['mw'],
    "bhaikṣāśin": ['cae', 'mw'],
    "bhaikṣāśya": ['cae', 'mw'],
    "bhaima": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhaimagava": ['mw'],
    "bhaimapravīṇa": ['mw'],
    "bhaimaratha": ['ddsa', 'mw'],
    "bhaimarathī": ['mw'],
    "bhaimasena": ['mw'],
    "bhaimaseni": ['mw'],
    "bhaimaseniḥ": ['ap90'],
    "bhaimasenya": ['mw'],
    "bhaimi": ['mw'],
    "bhaimāyana": ['mw'],
    "bhaimī": ['mw'],
    "bhaimīpariṇaya": ['mw'],
    "bhairava": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhairavadatta": ['mw'],
    "bhairavadīpadāna": ['mw'],
    "bhairavadīpana": ['mw'],
    "bhairavakāraka": ['mw'],
    "bhairavam": ['mw'],
    "bhairavamantra": ['mw'],
    "bhairavanavarasaratna": ['mw'],
    "bhairavanāmāvalī": ['mw'],
    "bhairavanāthatantra": ['mw'],
    "bhairavapaddhati": ['mw'],
    "bhairavaprasāda": ['mw'],
    "bhairavaprayoga": ['mw'],
    "bhairavaprādurbhāvanāṭaka": ['mw'],
    "bhairavapurāṇa": ['mw'],
    "bhairavasahasranāman": ['mw'],
    "bhairavasaparyāvidhi": ['mw'],
    "bhairavasaṃhitā": ['mw'],
    "bhairavasiṃha": ['mw'],
    "bhairavastava": ['mw'],
    "bhairavastotra": ['mw'],
    "bhairavatantra": ['mw'],
    "bhairavatarjaka": ['mw'],
    "bhairavatva": ['mw'],
    "bhairavayātanā": ['mw'],
    "bhairavendra": ['mw'],
    "bhairaveśa": ['mw'],
    "bhairavyaṣṭottaraśatanāmāvalī": ['mw'],
    "bhairavā": ['mw'],
    "bhairavāgratas": ['mw'],
    "bhairavānanda": ['mw'],
    "bhairavārcanakalpalatā": ['mw'],
    "bhairavārcāpārijāta": ['mw'],
    "bhairavārādhana": ['mw'],
    "bhairavāṣṭaka": ['mw'],
    "bhairavī": ['mw'],
    "bhairavīpaṭala": ['mw'],
    "bhairavīrahasya": ['mw'],
    "bhairavīrahasyavidhi": ['mw'],
    "bhairavītantra": ['mw'],
    "bhairavīya": ['ddsa', 'mw'],
    "bhairavīyapañcasaṃdhi": ['mw'],
    "bhairavīyatantra": ['mw'],
    "bhairika": ['mw'],
    "bhais": ['mw'],
    "bhaiyābhaṭṭa": ['mw'],
    "bhaiḍaka": ['mw'],
    "bhaiḥ": ['ddsa'],
    "bhaiṇḍaka": ['mw'],
    "bhaiṣaja": ['bhs', 'mw'],
    "bhaiṣajaṃ": ['ap90'],
    "bhaiṣajya": ['cae', 'ddsa', 'mw'],
    "bhaiṣajyaguruvaiḍūrya": ['bhs'],
    "bhaiṣajyaguruvaiḍūryaprabhā": ['mw'],
    "bhaiṣajyaratnākara": ['mw'],
    "bhaiṣajyaratnāvalī": ['mw'],
    "bhaiṣajyarāja": ['bhs', 'mw'],
    "bhaiṣajyarājasamudgata": ['bhs'],
    "bhaiṣajyasamudgata": ['bhs', 'mw'],
    "bhaiṣajyasena": ['bhs', 'mw'],
    "bhaiṣajyasāra": ['mw'],
    "bhaiṣajyasārāmṛtasaṃhitā": ['mw'],
    "bhaiṣajyavaidūryarāja": ['bhs'],
    "bhaiṣajyayajña": ['mw'],
    "bhaiṣajyaṃ": ['ap90'],
    "bhaiṣmaka": ['mw'],
    "bhaiṣmakī": ['ap90', 'mw'],
    "bhaiṣṇaja": ['mw'],
    "bhaiṣṇajya": ['mw'],
    "bhaj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhajagovindastotra": ['mw'],
    "bhajaka": ['cae', 'mw'],
    "bhajakaḥ": ['ap90'],
    "bhajamāna": ['ap90', 'cped', 'mw'],
    "bhajana": ['cae', 'cped', 'ddsa', 'mw'],
    "bhajanatā": ['mw'],
    "bhajanavārika": ['mw'],
    "bhajanaṃ": ['ap90'],
    "bhajanāmṛta": ['mw'],
    "bhajanānanda": ['mw'],
    "bhajanīya": ['cae', 'mw'],
    "bhajati": ['cped'],
    "bhajenya": ['cae', 'mw'],
    "bhajeratha": ['gra', 'mw'],
    "bhaji": ['cped', 'mw'],
    "bhajita": ['cped'],
    "bhajitabba": ['cped'],
    "bhajitavya": ['cae', 'mw'],
    "bhajitvā": ['cped'],
    "bhajjamāna": ['cped'],
    "bhajjati": ['bhs', 'cped'],
    "bhajji": ['cped'],
    "bhajjita": ['cped'],
    "bhajjitvā": ['cped'],
    "bhajjīyati": ['cped'],
    "bhajya": ['mw'],
    "bhakabhakāya": ['ddsa', 'mw'],
    "bhakakṣā": ['mw'],
    "bhakhituṁ": ['cped'],
    "bhakkha": ['cped'],
    "bhakkhaka": ['cped'],
    "bhakkhana": ['cped'],
    "bhakkhati": ['cped'],
    "bhakkheti": ['cped'],
    "bhakkhi": ['cped'],
    "bhakkhita": ['cped'],
    "bhakkikā": ['ap90', 'mw'],
    "bhakkura": ['mw'],
    "bhakkuḍa": ['mw'],
    "bhakta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "bhaktacchanda": ['mw'],
    "bhaktacheda": ['bhs'],
    "bhaktachinnaka": ['bhs'],
    "bhaktada": ['cae', 'mw'],
    "bhaktadveṣa": ['cae', 'mw'],
    "bhaktadveṣin": ['mw'],
    "bhaktadāsa": ['cae', 'mw'],
    "bhaktadātṛ": ['mw'],
    "bhaktadāyaka": ['cae', 'mw'],
    "bhaktadāyin": ['mw'],
    "bhaktagītāṭīkā": ['mw'],
    "bhaktajayantī": ['mw'],
    "bhaktajā": ['mw'],
    "bhaktaka": ['bhs'],
    "bhaktakara": ['mw'],
    "bhaktakaṃsa": ['mw'],
    "bhaktakāra": ['mw'],
    "bhaktakṛtya": ['bhs', 'mw'],
    "bhaktamayastotra": ['mw'],
    "bhaktamaṇḍa": ['mw'],
    "bhaktamaṇḍaka": ['mw'],
    "bhaktamodataraṃgiṇī": ['mw'],
    "bhaktamālā": ['mw'],
    "bhaktamālāgragrantha": ['mw'],
    "bhaktamīmāṃsā": ['mw'],
    "bhaktapratiṣṭhā": ['mw'],
    "bhaktapulāka": ['mw'],
    "bhaktapātra": ['mw'],
    "bhaktarocana": ['mw'],
    "bhaktaruci": ['cae', 'mw'],
    "bhaktasiktha": ['mw'],
    "bhaktasikthaka": ['mw'],
    "bhaktatva": ['mw'],
    "bhaktatā": ['mw'],
    "bhaktatūrya": ['mw'],
    "bhaktavaibhava": ['mw'],
    "bhaktavatsala": ['mw'],
    "bhaktavatsalamāhātmya": ['mw'],
    "bhaktavilāsa": ['mw'],
    "bhaktavrātasaṃtoṣika": ['mw'],
    "bhaktaśaraṇa": ['cae', 'mw'],
    "bhaktaśālā": ['mw'],
    "bhakti": ['cae', 'ddsa', 'gra', 'mw'],
    "bhaktibhava": ['mw'],
    "bhaktibhāj": ['cae', 'mw'],
    "bhaktibhāvapradīpa": ['mw'],
    "bhaktibhūṣaṇasaṃdarbha": ['mw'],
    "bhaktibindu": ['mw'],
    "bhakticandrikollāsa": ['mw'],
    "bhakticandrikā": ['mw'],
    "bhakticandrodaya": ['mw'],
    "bhakticcheda": ['cae', 'mw'],
    "bhaktidīpikā": ['mw'],
    "bhaktidūtī": ['mw'],
    "bhaktigamya": ['mw'],
    "bhaktihaṃsa": ['mw'],
    "bhaktihetunirṇaya": ['mw'],
    "bhaktihīna": ['cae', 'mw'],
    "bhaktijña": ['mw'],
    "bhaktijñatva": ['mw'],
    "bhaktijñatā": ['mw'],
    "bhaktika": ['ap90', 'mw'],
    "bhaktikalpalatā": ['mw'],
    "bhaktikalpataru": ['mw'],
    "bhaktikara": ['mw'],
    "bhaktila": ['ap90', 'mw'],
    "bhaktilaharī": ['mw'],
    "bhaktimahat": ['mw'],
    "bhaktimahodaya": ['mw'],
    "bhaktimant": ['cae'],
    "bhaktimat": ['ap90', 'mw'],
    "bhaktimañjarī": ['mw'],
    "bhaktimuktāvalī": ['mw'],
    "bhaktimārga": ['mw'],
    "bhaktimārganirūpaṇa": ['mw'],
    "bhaktimārgopadeśadīkṣā": ['mw'],
    "bhaktimīmāṃsāsūtra": ['mw'],
    "bhaktinamra": ['cae', 'mw'],
    "bhaktiprabhā": ['mw'],
    "bhaktiprakaraṇa": ['mw'],
    "bhaktipratipādaka": ['mw'],
    "bhaktipravaṇa": ['mw'],
    "bhaktipraśaṃsāvarṇana": ['mw'],
    "bhaktiprārthanā": ['mw'],
    "bhaktipūrvakam": ['mw'],
    "bhaktipūrvam": ['mw'],
    "bhaktipūrvapakṣa": ['mw'],
    "bhaktirasa": ['mw'],
    "bhaktirasābdhikaṇikā": ['mw'],
    "bhaktirasāmṛta": ['mw'],
    "bhaktirasāmṛtabindu": ['mw'],
    "bhaktirasāmṛtasindhu": ['mw'],
    "bhaktirasāyana": ['mw'],
    "bhaktiratna": ['mw'],
    "bhaktiratnākara": ['mw'],
    "bhaktiratnāvalī": ['mw'],
    "bhaktirāga": ['mw'],
    "bhaktisaṃdarbha": ['mw'],
    "bhaktisaṃdarbhapadyāvalī": ['mw'],
    "bhaktisaṃnyāsanirṇayavivaraṇa": ['mw'],
    "bhaktisaṃvardhanaśataka": ['mw'],
    "bhaktisiddhānta": ['mw'],
    "bhaktisudhodaya": ['mw'],
    "bhaktisāgara": ['mw'],
    "bhaktisāmānyanirūpaṇa": ['mw'],
    "bhaktisāra": ['mw'],
    "bhaktisārasaṃgraha": ['mw'],
    "bhaktisūtra": ['mw'],
    "bhaktitaraṃgiṇī": ['mw'],
    "bhaktitas": ['mw'],
    "bhaktitattvarasāyana": ['mw'],
    "bhaktivan": ['cae', 'mw'],
    "bhaktivardhinī": ['mw'],
    "bhaktivas": ['cae', 'mw'],
    "bhaktivijaya": ['mw'],
    "bhaktivilāsa": ['mw'],
    "bhaktivilāsatattvadīpikā": ['mw'],
    "bhaktivivṛddhyupāyagrantha": ['mw'],
    "bhaktivāda": ['cae', 'mw'],
    "bhaktiyoga": ['cae', 'mw'],
    "bhaktiśata": ['mw'],
    "bhaktiśataka": ['mw'],
    "bhaktiśāstra": ['mw'],
    "bhaktiḥ": ['ap90'],
    "bhaktoddeśaka": ['mw'],
    "bhaktopasādhaka": ['ddsa', 'mw'],
    "bhaktyadhikaraṇamālā": ['mw'],
    "bhaktyullāsamañjarī": ['mw'],
    "bhaktyupakrama": ['mw'],
    "bhaktyā": ['mw'],
    "bhaktābhilāṣa": ['mw'],
    "bhaktābhisāra": ['mw'],
    "bhaktāgra": ['bhs', 'mw'],
    "bhaktākāṅkṣā": ['mw'],
    "bhaktāmṛta": ['mw'],
    "bhaktāruci": ['mw'],
    "bhaktārādhanaprayogamaṇimālikā": ['mw'],
    "bhaktīdyāvāpṛthivya": ['mw'],
    "bhaktīdyāvāpṛthivī": ['mw'],
    "bhaktṛ": ['ap90', 'mw'],
    "bhaktṛtva": ['mw'],
    "bhakāra": ['mw'],
    "bhakṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhakṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "bhakṣabīja": ['mw'],
    "bhakṣacchandas": ['mw'],
    "bhakṣajapa": ['mw'],
    "bhakṣaka": ['ap90', 'cae', 'mw'],
    "bhakṣakāra": ['mw'],
    "bhakṣamantra": ['mw'],
    "bhakṣapattrī": ['mw'],
    "bhakṣavikāra": ['mw'],
    "bhakṣayitavya": ['cae', 'mw'],
    "bhakṣayitṛ": ['mw'],
    "bhakṣaḥ": ['ap90'],
    "bhakṣaṃkāra": ['mw'],
    "bhakṣaṃkṛta": ['mw'],
    "bhakṣaṇa": ['ap90', 'cae', 'gra', 'mw'],
    "bhakṣaṇīya": ['ap90', 'cae', 'mw'],
    "bhakṣaṇīyatā": ['mw'],
    "bhakṣaṭaka": ['mw'],
    "bhakṣi": ['ddsa'],
    "bhakṣikā": ['ap90', 'bhs', 'mw'],
    "bhakṣin": ['cae', 'mw'],
    "bhakṣita": ['ap90', 'cae', 'mw'],
    "bhakṣitavya": ['cae'],
    "bhakṣitaśeṣa": ['mw'],
    "bhakṣitaśeṣāhāra": ['mw'],
    "bhakṣitva": ['mw'],
    "bhakṣitṛ": ['cae', 'mw'],
    "bhakṣivan": ['cae', 'mw'],
    "bhakṣiṇī": ['mw'],
    "bhakṣya": ['ap90', 'cae', 'mw'],
    "bhakṣyabhakṣaka": ['mw'],
    "bhakṣyabhojya": ['cae'],
    "bhakṣyabhojyamaya": ['mw'],
    "bhakṣyabhojyavihāravat": ['mw'],
    "bhakṣyabīja": ['mw'],
    "bhakṣyakāra": ['mw'],
    "bhakṣyakāraka": ['mw'],
    "bhakṣyamālyāpaṇa": ['mw'],
    "bhakṣyavastu": ['mw'],
    "bhakṣyaṃkāra": ['mw'],
    "bhakṣyābhakṣya": ['cae', 'mw'],
    "bhakṣyālābu": ['mw'],
    "bhakṣālī": ['mw'],
    "bhal": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhala": ['cae', 'ddsa', 'gra', 'mw'],
    "bhalandana": ['mw'],
    "bhalatra": ['mw'],
    "bhalatā": ['mw'],
    "bhali": ['bhs'],
    "bhall": ['ap90', 'mw'],
    "bhalla": ['cae', 'ddsa', 'mw'],
    "bhallaka": ['mw'],
    "bhallakaḥ": ['ap90'],
    "bhallakīya": ['mw'],
    "bhallapucchī": ['mw'],
    "bhallapāla": ['mw'],
    "bhallavi": ['mw'],
    "bhallaḥ": ['ap90'],
    "bhallaṭa": ['mw'],
    "bhallaṭaśataka": ['mw'],
    "bhalli": ['mw'],
    "bhallika": ['bhs', 'mw'],
    "bhallikā": ['mw'],
    "bhallu": ['mw'],
    "bhalluka": ['bhs', 'mw'],
    "bhallukaḥ": ['ap90'],
    "bhallāka": ['mw'],
    "bhallākṣa": ['mw'],
    "bhallāla": ['mw'],
    "bhallālasaṃgraha": ['mw'],
    "bhallāta": ['ddsa', 'mw'],
    "bhallātaka": ['cped', 'mw'],
    "bhallātakataila": ['mw'],
    "bhallātaḥ": ['ap90'],
    "bhallāṭa": ['mw'],
    "bhallāṭanagara": ['mw'],
    "bhallī": ['mw'],
    "bhallūka": ['cae', 'ddsa', 'mw'],
    "bhallūkayuvan": ['mw'],
    "bhallūkaḥ": ['ap90'],
    "bhaluha": ['mw'],
    "bhalvāci": ['mw'],
    "bhalvāṭa": ['mw'],
    "bhalānas": ['gra', 'mw'],
    "bhalūṭa": ['mw'],
    "bhama": ['cped'],
    "bhamakāra": ['cped'],
    "bhamanta": ['cped'],
    "bhamara": ['cped'],
    "bhamarikā": ['cped'],
    "bhamati": ['cped'],
    "bhamaṇḍala": ['mw'],
    "bhambha": ['mw'],
    "bhambharālikā": ['mw'],
    "bhambharālī": ['ddsa', 'mw'],
    "bhambharāva": ['ddsa'],
    "bhambhā": ['mw'],
    "bhambhārava": ['mw'],
    "bhambhāsāra": ['mw'],
    "bhami": ['cped'],
    "bhamitvā": ['cped'],
    "bhamu": ['cped'],
    "bhamukā": ['cped'],
    "bhan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhanandana": ['mw'],
    "bhand": ['cae', 'ddsa', 'gra', 'mw'],
    "bhandadiṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "bhandana": ['cae', 'mw'],
    "bhandanā": ['gra', 'mw'],
    "bhandanāy": ['gra'],
    "bhandanāya": ['ddsa', 'mw'],
    "bhandanīya": ['mw'],
    "bhandhruka": ['mw'],
    "bhandhuka": ['mw'],
    "bhandila": ['mw'],
    "bhandiṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "bhandra": ['mw'],
    "bhanta": ['cped'],
    "bhantatta": ['cped'],
    "bhante": ['cped'],
    "bhapa": ['mw'],
    "bhapati": ['mw'],
    "bhapañjara": ['mw'],
    "bhappaṭa": ['ddsa', 'mw'],
    "bhapraśasta": ['mw'],
    "bhara": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bharad": ['mw'],
    "bharadhyai": ['cae', 'ddsa', 'mw'],
    "bharadvāja": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "bharadvājadhanvantari": ['mw'],
    "bharadvājagārgapariṇayapratiṣedhavādārtha": ['mw'],
    "bharadvājaka": ['mw'],
    "bharadvājapravraska": ['mw'],
    "bharadvājaprādurbhāva": ['mw'],
    "bharadvājasaṃhitā": ['mw'],
    "bharadvājasmṛti": ['mw'],
    "bharadvājasūtra": ['mw'],
    "bharadvājaśikṣā": ['mw'],
    "bharadvājaḥ": ['ap90'],
    "bharadvājin": ['mw'],
    "bharaga": ['mw'],
    "bharagatva": ['mw'],
    "bharahapāla": ['mw'],
    "bharaheśvaravṛtti": ['mw'],
    "bharahūti": ['cae', 'ddsa', 'gra', 'mw'],
    "bharama": ['mw'],
    "bharas": ['cae', 'gra', 'mw'],
    "bharat": ['ddsa', 'mw'],
    "bharata": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "bharatadvirūpakośa": ['mw'],
    "bharatadvādaśāha": ['mw'],
    "bharatajña": ['mw'],
    "bharatakhaṇḍa": ['mw'],
    "bharatamalla": ['mw'],
    "bharatamallika": ['mw'],
    "bharatamallīka": ['mw'],
    "bharataprasū": ['mw'],
    "bharatapura": ['mw'],
    "bharataputra": ['cae', 'mw'],
    "bharataputraka": ['mw'],
    "bharatapāla": ['mw'],
    "bharataroha": ['mw'],
    "bharatarṣabha": ['cae', 'mw'],
    "bharatasamuccaya": ['mw'],
    "bharatasattama": ['cae', 'mw'],
    "bharatasena": ['mw'],
    "bharatasvāmin": ['mw'],
    "bharatasūtra": ['mw'],
    "bharatasūtravṛtti": ['mw'],
    "bharatatva": ['mw'],
    "bharatavarṣa": ['mw'],
    "bharatavākya": ['cae', 'mw'],
    "bharataśeṣṭha": ['cae'],
    "bharataśreṣṭha": ['mw'],
    "bharataśārdūla": ['cae', 'mw'],
    "bharataśāstra": ['mw'],
    "bharataḥ": ['ap90'],
    "bharataṛṣabha": ['mw'],
    "bharataṭīkā": ['mw'],
    "bharateśvaratīrtha": ['mw'],
    "bharatha": ['mw'],
    "bharathaḥ": ['ap90'],
    "bharati": ['bhs', 'cped'],
    "bharatā": ['mw'],
    "bharatāgraja": ['mw'],
    "bharatārjunanāṭaka": ['mw'],
    "bharatārṇava": ['mw'],
    "bharatāvāsa": ['mw'],
    "bharatāśrama": ['mw'],
    "bharatī": ['mw'],
    "bharayati": ['bhs'],
    "bharaṃḍaḥ": ['ap90'],
    "bharaṇa": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bharaṇi": ['mw'],
    "bharaṇika": ['mw'],
    "bharaṇisena": ['mw'],
    "bharaṇiṣeṇa": ['mw'],
    "bharaṇya": ['mw'],
    "bharaṇyabhuj": ['mw'],
    "bharaṇyaṃ": ['ap90'],
    "bharaṇyu": ['mw'],
    "bharaṇyuḥ": ['ap90'],
    "bharaṇyāhvā": ['mw'],
    "bharaṇī": ['ap90', 'mw'],
    "bharaṇībhū": ['mw'],
    "bharaṇīya": ['cae', 'mw'],
    "bharaṇḍa": ['mw'],
    "bharaṇḍakeṣṇa": ['mw'],
    "bharaṭa": ['mw'],
    "bharaṭaka": ['mw'],
    "bharaṭakadvātriṃśikā": ['mw'],
    "bharaṭaḥ": ['ap90'],
    "bharaṭika": ['mw'],
    "bharb": ['mw'],
    "bharbh": ['mw'],
    "bharbharā": ['mw'],
    "bharchu": ['mw'],
    "bharehanagarī": ['mw'],
    "bhareṇa": ['mw'],
    "bhareṣujā": ['gra', 'mw'],
    "bharga": ['bhs', 'cae', 'ddsa', 'mw'],
    "bhargabhūmi": ['mw'],
    "bhargas": ['cae', 'gra', 'mw'],
    "bhargasvant": ['cae'],
    "bhargasvat": ['mw'],
    "bhargaśikhā": ['mw'],
    "bhargaḥ": ['ap90'],
    "bhargopaniṣad": ['mw'],
    "bhargya": ['mw'],
    "bhargyaḥ": ['ap90'],
    "bhargāyaṇa": ['mw'],
    "bhargāṅghribhūṣaṇa": ['mw'],
    "bhari": ['ap90', 'cae', 'cped', 'gra', 'mw'],
    "bharikā": ['bhs'],
    "bhariman": ['ap90', 'mw'],
    "bharita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bharitra": ['cae', 'gra', 'mw'],
    "bharitraṃ": ['ap90'],
    "bharitvā": ['cped'],
    "bhariyā": ['cped'],
    "bhariṇī": ['mw'],
    "bhariṣa": ['cae', 'gra', 'mw'],
    "bharj": ['ddsa'],
    "bharjana": ['ap90', 'cae', 'mw'],
    "bharjita": ['mw'],
    "bharjū": ['mw'],
    "bharma": ['mw'],
    "bharman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bharmaṃ": ['ap90'],
    "bharmaṇyā": ['ap90', 'mw'],
    "bharmin": ['mw'],
    "bharmyāśva": ['mw'],
    "bhartavya": ['cae', 'ddsa', 'mw'],
    "bhartrima": ['mw'],
    "bhartrī": ['ap90'],
    "bhartrīśvara": ['mw'],
    "bharts": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhartsaka": ['mw'],
    "bhartsakaḥ": ['ap90'],
    "bhartsana": ['cae', 'ddsa', 'mw'],
    "bhartsanaṃ": ['ap90'],
    "bhartsapattrikā": ['mw'],
    "bhartsita": ['ap90', 'cae', 'mw'],
    "bhartṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhartṛbhakta": ['cae', 'mw'],
    "bhartṛcittā": ['cae', 'mw'],
    "bhartṛdaivatā": ['mw'],
    "bhartṛdarśana": ['mw'],
    "bhartṛdarśanakāṅkṣā": ['mw'],
    "bhartṛdarśanalālasa": ['mw'],
    "bhartṛdevatā": ['mw'],
    "bhartṛduhitṛ": ['mw'],
    "bhartṛdāraka": ['cae', 'mw'],
    "bhartṛdārikā": ['mw'],
    "bhartṛdṛḍhavratā": ['mw'],
    "bhartṛghna": ['mw'],
    "bhartṛghnatva": ['mw'],
    "bhartṛghnī": ['cae', 'mw'],
    "bhartṛguṇa": ['mw'],
    "bhartṛhari": ['ap90', 'cae', 'mw'],
    "bhartṛhariśataka": ['mw'],
    "bhartṛhema": ['mw'],
    "bhartṛhāryadhana": ['mw'],
    "bhartṛhīna": ['mw'],
    "bhartṛjaya": ['mw'],
    "bhartṛka": ['cae', 'mw'],
    "bhartṛloka": ['cae', 'mw'],
    "bhartṛmatī": ['ap90', 'cae', 'mw'],
    "bhartṛmeṇṭha": ['cae', 'mw'],
    "bhartṛmeṇṭhatā": ['mw'],
    "bhartṛpriya": ['cae', 'mw'],
    "bhartṛprāptivrata": ['mw'],
    "bhartṛrājyāpaharaṇa": ['mw'],
    "bhartṛrūpa": ['cae', 'mw'],
    "bhartṛsneha": ['mw'],
    "bhartṛsnehaparīta": ['mw'],
    "bhartṛsthāna": ['mw'],
    "bhartṛsvāmin": ['mw'],
    "bhartṛsārasvata": ['mw'],
    "bhartṛsāt": ['ap90', 'mw'],
    "bhartṛsātkṛtā": ['mw'],
    "bhartṛsūkta": ['mw'],
    "bhartṛtva": ['mw'],
    "bhartṛtā": ['mw'],
    "bhartṛtāṃgata": ['mw'],
    "bhartṛvallabhatā": ['mw'],
    "bhartṛvatsalā": ['cae', 'mw'],
    "bhartṛvrata": ['cae', 'mw'],
    "bhartṛvratacāriṇī": ['mw'],
    "bhartṛvratā": ['cae', 'mw'],
    "bhartṛvratātva": ['mw'],
    "bhartṛvyasanapīḍita": ['mw'],
    "bhartṛvyatikrama": ['mw'],
    "bhartṛyajña": ['mw'],
    "bhartṛśoka": ['mw'],
    "bhartṛśokapara": ['mw'],
    "bhartṛśokaparītāṅgin": ['mw'],
    "bhartṛśokābhipīḍita": ['mw'],
    "bharu": ['cae', 'ddsa', 'mw'],
    "bharuja": ['cae', 'mw'],
    "bharujaḥ": ['ap90'],
    "bharuka": ['bhs', 'mw'],
    "bharukaccha": ['bhs', 'mw'],
    "bharukacchanivāsin": ['mw'],
    "bharuḥ": ['ap90'],
    "bharuṭaka": ['mw'],
    "bharuṭakaṃ": ['ap90'],
    "bharuṭā": ['mw'],
    "bharv": ['cae', 'ddsa', 'gra', 'mw'],
    "bharva": ['gra', 'mw'],
    "bharvara": ['mw'],
    "bharvu": ['mw'],
    "bharākrānta": ['cae'],
    "bharāt": ['mw'],
    "bharīman": ['cae', 'gra', 'mw'],
    "bharūja": ['mw'],
    "bharūjī": ['mw'],
    "bharūṭaka": ['mw'],
    "bharṇas": ['cae', 'gra', 'mw'],
    "bharṣṭavya": ['mw'],
    "bhas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhasad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhasadya": ['cae', 'mw'],
    "bhasala": ['mw'],
    "bhasamūha": ['mw'],
    "bhasana": ['mw'],
    "bhasanaḥ": ['ap90'],
    "bhasanta": ['mw'],
    "bhasat": ['mw'],
    "bhasati": ['bhs'],
    "bhasattas": ['mw'],
    "bhasaṃdhi": ['mw'],
    "bhasaṃtaḥ": ['ap90'],
    "bhasita": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhasma": ['cped', 'mw'],
    "bhasmabhūta": ['cae', 'mw'],
    "bhasmabāṇa": ['mw'],
    "bhasmacaya": ['mw'],
    "bhasmacchanna": ['cped', 'mw'],
    "bhasmadhāraṇa": ['mw'],
    "bhasmadhāraṇavidhi": ['mw'],
    "bhasmagandhikā": ['mw'],
    "bhasmagandhinī": ['mw'],
    "bhasmagandhā": ['mw'],
    "bhasmagarbha": ['mw'],
    "bhasmagarbhā": ['mw'],
    "bhasmagraha": ['bhs', 'mw'],
    "bhasmaguṇṭhana": ['mw'],
    "bhasmagātra": ['mw'],
    "bhasmajābālopaniṣad": ['mw'],
    "bhasmaka": ['mw'],
    "bhasmakaumudī": ['mw'],
    "bhasmakaṃ": ['ap90'],
    "bhasmakāra": ['mw'],
    "bhasmakūṭa": ['ddsa', 'mw'],
    "bhasmakṛt": ['mw'],
    "bhasmakṛta": ['cae', 'mw'],
    "bhasmalalāṭikā": ['mw'],
    "bhasmalepana": ['mw'],
    "bhasmameha": ['mw'],
    "bhasmamāhātmya": ['mw'],
    "bhasman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhasmanihuta": ['mw'],
    "bhasmapraharaṇa": ['mw'],
    "bhasmapriya": ['mw'],
    "bhasmapuñja": ['ddsa', 'mw'],
    "bhasmareṇu": ['cae', 'mw'],
    "bhasmaroga": ['mw'],
    "bhasmarogin": ['mw'],
    "bhasmarohā": ['mw'],
    "bhasmarudrākṣadhāraṇavidhi": ['mw'],
    "bhasmarudrākṣamāhātmya": ['mw'],
    "bhasmarājī": ['mw'],
    "bhasmarāśi": ['mw'],
    "bhasmarāśīkṛ": ['cae'],
    "bhasmarāśīkṛta": ['mw'],
    "bhasmasamīpa": ['mw'],
    "bhasmasaya": ['mw'],
    "bhasmasnāna": ['mw'],
    "bhasmasnānavidhi": ['mw'],
    "bhasmasā": ['mw'],
    "bhasmasāt": ['ap90', 'ddsa', 'mw'],
    "bhasmasātkṛ": ['cae'],
    "bhasmasūtakaraṇa": ['mw'],
    "bhasmatas": ['mw'],
    "bhasmatā": ['ap90', 'cae', 'mw'],
    "bhasmatūla": ['mw'],
    "bhasmavedhaka": ['mw'],
    "bhasmavidhi": ['mw'],
    "bhasmavādāvalī": ['mw'],
    "bhasmaśarkarā": ['mw'],
    "bhasmaśayyāśayāna": ['mw'],
    "bhasmaśuddhikara": ['mw'],
    "bhasmaśāyin": ['cae', 'mw'],
    "bhasmeśvara": ['bhs', 'mw'],
    "bhasmita": ['bhs', 'cae', 'ddsa'],
    "bhasmoddhūlana": ['mw'],
    "bhasmoddhūlitavigraha": ['mw'],
    "bhasmodvapana": ['mw'],
    "bhasmopaniṣad": ['mw'],
    "bhasmācala": ['mw'],
    "bhasmādilakṣaṇa": ['mw'],
    "bhasmāgni": ['mw'],
    "bhasmāhvaya": ['mw'],
    "bhasmākhya": ['ddsa', 'mw'],
    "bhasmākṛ": ['ap90', 'mw'],
    "bhasmālābuka": ['ddsa', 'mw'],
    "bhasmānta": ['cae', 'mw'],
    "bhasmānte": ['mw'],
    "bhasmānti": ['cae', 'mw'],
    "bhasmāp": ['cae', 'mw'],
    "bhasmāsura": ['mw'],
    "bhasmāvaśeṣa": ['cae', 'mw'],
    "bhasmāvṛtāṅga": ['mw'],
    "bhasmāṅga": ['mw'],
    "bhasmī": ['mw'],
    "bhasmībhāva": ['cae', 'ddsa', 'mw'],
    "bhasmībhū": ['ap90', 'mw'],
    "bhasmībhūta": ['cae', 'mw'],
    "bhasmīkaraṇa": ['cae', 'mw'],
    "bhasmīkaraṇaṃ": ['ap90'],
    "bhasmīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhasmīkṛta": ['ap90', 'mw'],
    "bhassa": ['cped'],
    "bhassamāna": ['cped'],
    "bhassanta": ['cped'],
    "bhassara": ['cped'],
    "bhassati": ['cped'],
    "bhassi": ['cped'],
    "bhassitvā": ['cped'],
    "bhassārāmatā": ['cped'],
    "bhastrakā": ['ap90', 'mw'],
    "bhastraphalā": ['mw'],
    "bhastrika": ['mw'],
    "bhastrikā": ['ap90', 'cae', 'mw'],
    "bhastrā": ['cae', 'ddsa', 'mw'],
    "bhastrākā": ['mw'],
    "bhastrāphalā": ['mw'],
    "bhastrāvat": ['mw'],
    "bhastrī": ['mw'],
    "bhastrīya": ['mw'],
    "bhastā": ['cped'],
    "bhasūcaka": ['mw'],
    "bhata": ['cped'],
    "bhataka": ['cped'],
    "bhati": ['cped'],
    "bhatila": ['mw'],
    "bhats": ['bhs'],
    "bhatta": ['cped'],
    "bhatta-vissagga-karaṇatthāya": ['cped'],
    "bhattagga": ['cped'],
    "bhattagāma": ['cped'],
    "bhattakicca": ['cped'],
    "bhattakilamatha": ['cped'],
    "bhattakāraka": ['cped'],
    "bhattapuṭa": ['cped'],
    "bhattar": ['cped'],
    "bhattasammada": ['cped'],
    "bhattavelā": ['cped'],
    "bhattavetana": ['cped'],
    "bhattavissagga": ['cped'],
    "bhatti": ['cped'],
    "bhattika": ['cped'],
    "bhattimant": ['cped'],
    "bhaugaka": ['mw'],
    "bhaujakaṭa": ['mw'],
    "bhaujaṃga": ['ap90', 'cae', 'mw'],
    "bhaujaṅga": ['ddsa'],
    "bhauji": ['mw'],
    "bhaujiṣya": ['cae', 'mw'],
    "bhaujya": ['ddsa', 'mw'],
    "bhaujīya": ['mw'],
    "bhauliki": ['mw'],
    "bhaulikividha": ['mw'],
    "bhaulikyā": ['mw'],
    "bhaulikāyani": ['mw'],
    "bhauliṅgi": ['mw'],
    "bhauliṅgika": ['mw'],
    "bhauliṅgī": ['mw'],
    "bhaulī": ['mw'],
    "bhauma": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "bhaumacāra": ['mw'],
    "bhaumadarśanacāra": ['mw'],
    "bhaumadevalipi": ['bhs', 'mw'],
    "bhaumaka": ['cae', 'mw'],
    "bhaumakaḥ": ['ap90'],
    "bhaumana": ['mw'],
    "bhaumanaḥ": ['ap90'],
    "bhaumapūjā": ['mw'],
    "bhaumapūjāvidhi": ['mw'],
    "bhaumaratna": ['mw'],
    "bhaumasaṃhitā": ['mw'],
    "bhaumastotra": ['mw'],
    "bhaumasūkta": ['mw'],
    "bhaumavrata": ['mw'],
    "bhaumavratakathā": ['mw'],
    "bhaumavratapūjāvidhi": ['mw'],
    "bhaumavāra": ['mw'],
    "bhaumavāravratavidhi": ['mw'],
    "bhaumayantra": ['mw'],
    "bhaumaśānti": ['mw'],
    "bhaumika": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhaumya": ['bhs', 'cae', 'mw'],
    "bhaumāvatāravarṇana": ['mw'],
    "bhaumī": ['mw'],
    "bhaupāla": ['mw'],
    "bhaupālaḥ": ['ap90'],
    "bhaura": ['mw'],
    "bhaurika": ['cae', 'ddsa', 'mw'],
    "bhaurikaḥ": ['ap90'],
    "bhauriki": ['mw'],
    "bhaurikika": ['mw'],
    "bhaurikividha": ['mw'],
    "bhaurikyā": ['mw'],
    "bhaurikāyaṇi": ['mw'],
    "bhaurikī": ['mw'],
    "bhaurja": ['cae', 'ddsa'],
    "bhauta": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhautaka": ['ap90'],
    "bhautaprāya": ['mw'],
    "bhautatulya": ['mw'],
    "bhautika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "bhautya": ['mw'],
    "bhautī": ['mw'],
    "bhauvana": ['cae', 'ddsa', 'mw'],
    "bhauvanaḥ": ['ap90'],
    "bhauvanāyana": ['mw'],
    "bhauvādika": ['ap90', 'ddsa', 'mw'],
    "bhauvāyana": ['mw'],
    "bhauṇikyā": ['mw'],
    "bhauṇḍa": ['mw'],
    "bhauṭa": ['ddsa', 'mw'],
    "bhauṭṭaḥ": ['ap90'],
    "bhava": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bhavabandheśa": ['mw'],
    "bhavabhaṅga": ['ddsa', 'mw'],
    "bhavabhoga": ['mw'],
    "bhavabhāj": ['mw'],
    "bhavabhāva": ['mw'],
    "bhavabhāvana": ['cae', 'mw'],
    "bhavabhāvanā": ['mw'],
    "bhavabhīru": ['mw'],
    "bhavabhīta": ['mw'],
    "bhavabhūta": ['mw'],
    "bhavabhūti": ['ap90', 'cae', 'mw'],
    "bhavacakka": ['cped'],
    "bhavacandra": ['mw'],
    "bhavaccheda": ['cae', 'mw'],
    "bhavacchid": ['cae', 'mw'],
    "bhavad": ['mw'],
    "bhavadantya": ['mw'],
    "bhavadanya": ['ddsa', 'mw'],
    "bhavadatta": ['mw'],
    "bhavadbhī": ['mw'],
    "bhavadbhūtabhavye": ['mw'],
    "bhavaddeva": ['mw'],
    "bhavadeva": ['bhs', 'mw'],
    "bhavadevagupta": ['bhs'],
    "bhavaduttaram": ['cae', 'ddsa', 'mw'],
    "bhavadvacana": ['mw'],
    "bhavadvasu": ['cae', 'mw'],
    "bhavadvidha": ['cae', 'mw'],
    "bhavadvidhi": ['mw'],
    "bhavadvirahanāma": ['ddsa', 'mw'],
    "bhavadā": ['mw'],
    "bhavadāhārārtham": ['mw'],
    "bhavadāru": ['mw'],
    "bhavadīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhavagga": ['cped'],
    "bhavaghasmara": ['mw'],
    "bhavagrāmīṇavādyokta": ['mw'],
    "bhavajala": ['cae', 'mw'],
    "bhavaka": ['ap90', 'ddsa', 'mw'],
    "bhavakalpa": ['mw'],
    "bhavaketu": ['bhs', 'mw'],
    "bhavakhāmi": ['mw'],
    "bhavakā": ['mw'],
    "bhavakāntāra": ['mw'],
    "bhavakṣiti": ['mw'],
    "bhavalābhalobhasatkāraparāṅmukha": ['mw'],
    "bhavamanyu": ['mw'],
    "bhavamaya": ['mw'],
    "bhavamocana": ['mw'],
    "bhavamāna": ['cped'],
    "bhavan": ['mw'],
    "bhavana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bhavanadvāra": ['cae', 'mw'],
    "bhavananda": ['ddsa', 'mw'],
    "bhavanandana": ['mw'],
    "bhavanandin": ['bhs', 'mw'],
    "bhavanapati": ['mw'],
    "bhavanasthāna": ['mw'],
    "bhavanasvāmin": ['mw'],
    "bhavanaśikhin": ['ddsa'],
    "bhavanaṃ": ['ap90'],
    "bhavanetrī": ['bhs'],
    "bhavanetrīka": ['bhs'],
    "bhavanetti": ['cped'],
    "bhavaneśa": ['mw'],
    "bhavanibandhavināśin": ['mw'],
    "bhavanigaḍanibandhacchedana": ['mw'],
    "bhavanigaḍanibandhavināśin": ['mw'],
    "bhavanmadhya": ['cae', 'ddsa', 'mw'],
    "bhavanmadhyam": ['mw'],
    "bhavanmanyu": ['mw'],
    "bhavanodara": ['mw'],
    "bhavanodyāna": ['cae', 'mw'],
    "bhavant": ['bhs', 'cae'],
    "bhavanta": ['cped', 'mw'],
    "bhavantaga": ['cped'],
    "bhavantara": ['cped'],
    "bhavanti": ['mw'],
    "bhavantī": ['ddsa', 'mw'],
    "bhavanādhīśa": ['mw'],
    "bhavanāga": ['mw'],
    "bhavanātha": ['mw'],
    "bhavanāśinī": ['ddsa', 'mw'],
    "bhavanīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhavapratisaṃdhi": ['mw'],
    "bhavarasa": ['mw'],
    "bhavarga": ['mw'],
    "bhavarud": ['mw'],
    "bhavasamudra": ['mw'],
    "bhavasaṁyojana": ['cped'],
    "bhavasaṃkrānti": ['bhs', 'mw'],
    "bhavasaṃskāra": ['bhs'],
    "bhavasaṃtati": ['mw'],
    "bhavasaṃśodhana": ['mw'],
    "bhavasaṅgin": ['mw'],
    "bhavasindhu": ['mw'],
    "bhavasvāmin": ['mw'],
    "bhavasyu": ['bhs'],
    "bhavasāgara": ['cae', 'mw'],
    "bhavasāra": ['mw'],
    "bhavasāyujya": ['mw'],
    "bhavat": ['ap90', 'ddsa', 'mw'],
    "bhavataṇhā": ['cped'],
    "bhavati": ['bhs', 'cped'],
    "bhavatputra": ['ddsa', 'mw'],
    "bhavatpūrva": ['cae', 'mw'],
    "bhavatpūrvam": ['mw'],
    "bhavatrāta": ['bhs', 'mw'],
    "bhavatsneha": ['mw'],
    "bhavatī": ['ap90', 'mw'],
    "bhavaviti": ['mw'],
    "bhavavratadhara": ['mw'],
    "bhavavyaya": ['cae', 'mw'],
    "bhavavārinidhi": ['mw'],
    "bhavayu": ['gra'],
    "bhavaśarman": ['mw'],
    "bhavaśekhara": ['mw'],
    "bhavaṃtaḥ": ['ap90'],
    "bhavaṃtī": ['ap90'],
    "bhavaṅga": ['cped'],
    "bhavesanā": ['cped'],
    "bhaveśa": ['mw'],
    "bhaveṇu": ['mw'],
    "bhavi": ['cped'],
    "bhavia": ['gra'],
    "bhavicārin": ['mw'],
    "bhavika": ['ap90', 'cae', 'mw'],
    "bhavila": ['ap90', 'bhs', 'mw'],
    "bhavin": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhavinaḥ": ['ap90'],
    "bhavinin": ['mw'],
    "bhavipulā": ['mw'],
    "bhavita": ['mw'],
    "bhavitabba": ['cped'],
    "bhavitavya": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhavitavyatā": ['ap90', 'mw'],
    "bhavitos": ['cae', 'mw'],
    "bhavitra": ['gra', 'mw'],
    "bhavituṁ": ['cped'],
    "bhavitvā": ['cped'],
    "bhavitṛ": ['ap90', 'cae', 'mw'],
    "bhavivādikathā": ['bhs'],
    "bhaviṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhaviṣyad": ['mw'],
    "bhaviṣyadanadyatana": ['mw'],
    "bhaviṣyadvaktṛ": ['mw'],
    "bhaviṣyadvācin": ['cae'],
    "bhaviṣyadvādin": ['mw'],
    "bhaviṣyadākṣepa": ['mw'],
    "bhaviṣyagaṅgā": ['mw'],
    "bhaviṣyajñāna": ['mw'],
    "bhaviṣyakāla": ['mw'],
    "bhaviṣyant": ['cae'],
    "bhaviṣyantī": ['ddsa', 'mw'],
    "bhaviṣyapurāṇa": ['ddsa', 'mw'],
    "bhaviṣyapurāṇīya": ['mw'],
    "bhaviṣyat": ['ap90', 'ddsa', 'mw'],
    "bhaviṣyatkāla": ['cae', 'mw'],
    "bhaviṣyatpurāṇa": ['cae', 'mw'],
    "bhaviṣyattva": ['mw'],
    "bhaviṣyattā": ['cae', 'mw'],
    "bhaviṣyottara": ['ddsa', 'mw'],
    "bhaviṣyottarapurāṇa": ['mw'],
    "bhaviṣṇu": ['ap90', 'cae', 'mw'],
    "bhaviṣṭha": ['cae', 'gra', 'mw'],
    "bhavoccheda": ['mw'],
    "bhavodadhi": ['cae', 'mw'],
    "bhavodbhava": ['mw'],
    "bhavogha": ['cped'],
    "bhavottāraka": ['mw'],
    "bhavya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "bhavyajīvana": ['mw'],
    "bhavyamanas": ['mw'],
    "bhavyarūpa": ['mw'],
    "bhavyatā": ['mw'],
    "bhavyā": ['mw'],
    "bhavyākṛti": ['mw'],
    "bhavā": ['mw'],
    "bhavābdhi": ['cae', 'mw'],
    "bhavābdhināvinavika": ['mw'],
    "bhavābhava": ['cped', 'mw'],
    "bhavābhibhāvin": ['mw'],
    "bhavābhāva": ['mw'],
    "bhavābhīṣṭa": ['mw'],
    "bhavācala": ['mw'],
    "bhavādṛkṣa": ['ap90', 'mw'],
    "bhavādṛś": ['ddsa', 'mw'],
    "bhavādṛśa": ['mw'],
    "bhavāgra": ['bhs', 'mw'],
    "bhavāmbudhi": ['mw'],
    "bhavāmburāśi": ['mw'],
    "bhavānanda": ['mw'],
    "bhavānandasaṃgraha": ['mw'],
    "bhavānandavyākhyā": ['mw'],
    "bhavānandī": ['mw'],
    "bhavānandīpradīpa": ['mw'],
    "bhavānandīprakāśa": ['mw'],
    "bhavānandīya": ['mw'],
    "bhavānandīyakhaṇḍana": ['mw'],
    "bhavāntakṛt": ['mw'],
    "bhavāntara": ['cae', 'ddsa', 'mw'],
    "bhavāntaraprāptimat": ['mw'],
    "bhavānyaṣṭaka": ['mw'],
    "bhavānī": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhavānībhujaṃga": ['mw'],
    "bhavānīdāsa": ['mw'],
    "bhavānīguru": ['mw'],
    "bhavānīkavaca": ['mw'],
    "bhavānīkānta": ['mw'],
    "bhavānīnandana": ['mw'],
    "bhavānīpara": ['mw'],
    "bhavānīpati": ['cae', 'mw'],
    "bhavānīpañcāṅga": ['mw'],
    "bhavānīprasāda": ['mw'],
    "bhavānīpūjāpaddhati": ['mw'],
    "bhavānīsahasranāmabījākṣarī": ['mw'],
    "bhavānīsahasranāman": ['mw'],
    "bhavānīsahasranāmastotra": ['mw'],
    "bhavānīsahasranāmayantra": ['mw'],
    "bhavānīsahāya": ['mw'],
    "bhavānīsakha": ['mw'],
    "bhavānīstavarāja": ['mw'],
    "bhavānīstavaśataka": ['mw'],
    "bhavānīstotra": ['mw'],
    "bhavānītāta": ['mw'],
    "bhavānīvallabha": ['cae', 'mw'],
    "bhavānīvilāsa": ['mw'],
    "bhavānīśaṃkara": ['mw'],
    "bhavāraṇya": ['mw'],
    "bhavāri": ['mw'],
    "bhavārta": ['mw'],
    "bhavārudra": ['cae', 'mw'],
    "bhavārṇava": ['cae', 'mw'],
    "bhavāsara": ['mw'],
    "bhavātiga": ['ddsa', 'mw'],
    "bhavātmaja": ['mw'],
    "bhavātmajā": ['mw'],
    "bhavāyanā": ['mw'],
    "bhavāyanī": ['mw'],
    "bhavāyya": ['mw'],
    "bhavāśarva": ['cae', 'mw'],
    "bhavāśarvīya": ['mw'],
    "bhavāṅgaṇa": ['mw'],
    "bhavītva": ['cae', 'mw'],
    "bhavīyas": ['gra', 'mw'],
    "bhavīyaṃs": ['cae'],
    "bhaya": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhaya-bherava": ['cped'],
    "bhayabhañjana": ['mw'],
    "bhayabhraṣṭa": ['mw'],
    "bhayabrāhmaṇa": ['mw'],
    "bhayacaurya": ['mw'],
    "bhayada": ['cae', 'mw'],
    "bhayadarśin": ['mw'],
    "bhayadassāvī": ['cped'],
    "bhayadassī": ['cped'],
    "bhayadhana": ['mw'],
    "bhayadruta": ['mw'],
    "bhayadāna": ['mw'],
    "bhayadāya": ['mw'],
    "bhayadāyin": ['cae', 'mw'],
    "bhayahartṛ": ['mw'],
    "bhayahetu": ['mw'],
    "bhayahāraka": ['mw'],
    "bhayahārin": ['mw'],
    "bhayaikapravaṇa": ['mw'],
    "bhayajāta": ['mw'],
    "bhayakampa": ['mw'],
    "bhayakara": ['cae', 'ddsa', 'mw'],
    "bhayakartṛ": ['cae', 'mw'],
    "bhayakṛt": ['cae', 'mw'],
    "bhayamāna": ['gra', 'mw'],
    "bhayana": ['mw'],
    "bhayanimīlitākṣa": ['mw'],
    "bhayanāśana": ['mw'],
    "bhayanāśin": ['mw'],
    "bhayanāśinī": ['mw'],
    "bhayaprada": ['cae', 'mw'],
    "bhayapradāyin": ['mw'],
    "bhayaprastāva": ['mw'],
    "bhayapratīkāra": ['mw'],
    "bhayasaṃhṛṣṭaroman": ['mw'],
    "bhayasaṃtrastamānasa": ['mw'],
    "bhayastha": ['cae', 'gra', 'mw'],
    "bhayasthāna": ['mw'],
    "bhayasthānaśata": ['mw'],
    "bhayatrasta": ['mw'],
    "bhayatrātṛ": ['mw'],
    "bhayavidhāyin": ['mw'],
    "bhayavihvala": ['mw'],
    "bhayavipluta": ['mw'],
    "bhayavyūha": ['mw'],
    "bhayaśokasamāviṣṭa": ['mw'],
    "bhayaśīla": ['mw'],
    "bhayaḍiṇḍima": ['mw'],
    "bhayaṃ": ['ap90'],
    "bhayaṃkara": ['ap90', 'bhs', 'cae', 'mw'],
    "bhayaṃkaram": ['mw'],
    "bhayaṃkartṛ": ['mw'],
    "bhayaṃkarī": ['mw'],
    "bhayaṅkara": ['cped'],
    "bhayeḍaka": ['cae', 'mw'],
    "bhayopaśama": ['mw'],
    "bhayottara": ['mw'],
    "bhayuj": ['mw'],
    "bhayya": ['cae', 'ddsa', 'mw'],
    "bhayābhaya": ['cae', 'mw'],
    "bhayābādha": ['mw'],
    "bhayākrānta": ['mw'],
    "bhayālu": ['cae', 'mw'],
    "bhayānaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bhayānakarasanirdeśa": ['mw'],
    "bhayānakatva": ['mw'],
    "bhayānakatā": ['mw'],
    "bhayānanā": ['mw'],
    "bhayānvita": ['mw'],
    "bhayāpaha": ['cae', 'ddsa', 'mw'],
    "bhayārta": ['cae', 'mw'],
    "bhayāt": ['mw'],
    "bhayātura": ['mw'],
    "bhayātīsāra": ['mw'],
    "bhayāvadīrṇa": ['mw'],
    "bhayāvaha": ['cae', 'cped', 'mw'],
    "bhañj": ['cae', 'ddsa', 'gra', 'mw'],
    "bhañjaka": ['cae', 'cped', 'ddsa', 'mw'],
    "bhañjam": ['mw'],
    "bhañjamāna": ['cped'],
    "bhañjana": ['cae', 'cped', 'mw'],
    "bhañjanaka": ['cped'],
    "bhañjanta": ['cped'],
    "bhañjanā": ['mw'],
    "bhañjanāgiri": ['mw'],
    "bhañjanī": ['bhs'],
    "bhañjaru": ['mw'],
    "bhañjati": ['cped'],
    "bhañji": ['cped'],
    "bhañjikā": ['mw'],
    "bhañjin": ['cae', 'mw'],
    "bhañjipattrikā": ['mw'],
    "bhañjita": ['cped'],
    "bhañjitvā": ['cped'],
    "bhañjā": ['mw'],
    "bhañjī": ['mw'],
    "bhaścu": ['mw'],
    "bhaśirā": ['mw'],
    "bhaḍa": ['cae', 'ddsa', 'mw'],
    "bhaḍaharīmātṛtīrtha": ['mw'],
    "bhaḍaḥ": ['ap90'],
    "bhaḍila": ['mw'],
    "bhaḍilaḥ": ['ap90'],
    "bhaḍita": ['mw'],
    "bhaḍḍalikā": ['bhs'],
    "bhaḥ": ['ap90'],
    "bhaṃbharālikā": ['ap90'],
    "bhaṃbhaḥ": ['ap90'],
    "bhaṃbhāravaḥ": ['ap90'],
    "bhaṃd": ['ap90'],
    "bhaṃdilaṃ": ['ap90'],
    "bhaṃgaḥ": ['ap90'],
    "bhaṃgilaṃ": ['ap90'],
    "bhaṃgiman": ['ap90'],
    "bhaṃgimat": ['ap90'],
    "bhaṃgin": ['ap90'],
    "bhaṃgiḥ": ['ap90'],
    "bhaṃgura": ['ap90'],
    "bhaṃgurayati": ['ap90'],
    "bhaṃgyaṃ": ['ap90'],
    "bhaṃgā": ['ap90'],
    "bhaṃgārī": ['ap90'],
    "bhaṃj": ['ap90'],
    "bhaṃjaka": ['ap90'],
    "bhaṃjana": ['ap90'],
    "bhaṃjanakaḥ": ['ap90'],
    "bhaṃjaruḥ": ['ap90'],
    "bhaṃjā": ['ap90'],
    "bhaṃktiḥ": ['ap90'],
    "bhaṃkārī": ['ap90', 'mw'],
    "bhaṃsas": ['cae', 'ddsa', 'gra', 'mw'],
    "bhaṃḍ": ['ap90'],
    "bhaṃḍakaḥ": ['ap90'],
    "bhaṃḍanaṃ": ['ap90'],
    "bhaṃḍaḥ": ['ap90'],
    "bhaṃḍila": ['ap90'],
    "bhaṃḍiḥ": ['ap90'],
    "bhaṅga": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhaṅgabhāj": ['mw'],
    "bhaṅgakara": ['mw'],
    "bhaṅgakkhaṇa": ['cped'],
    "bhaṅgakula": ['bhs'],
    "bhaṅgakārin": ['cae'],
    "bhaṅganaya": ['mw'],
    "bhaṅgasārtha": ['mw'],
    "bhaṅgavat": ['mw'],
    "bhaṅgavāsā": ['mw'],
    "bhaṅgaśravas": ['mw'],
    "bhaṅgi": ['cae', 'ddsa', 'mw'],
    "bhaṅgibhāva": ['mw'],
    "bhaṅgibhūta": ['mw'],
    "bhaṅgimant": ['cae'],
    "bhaṅgimat": ['ddsa', 'mw'],
    "bhaṅgin": ['cae', 'ddsa', 'mw'],
    "bhaṅgivikāra": ['mw'],
    "bhaṅgu": ['cae', 'mw'],
    "bhaṅgugiri": ['mw'],
    "bhaṅgura": ['cae', 'ddsa', 'gra', 'mw'],
    "bhaṅguraka": ['mw'],
    "bhaṅguraniścaya": ['mw'],
    "bhaṅguratā": ['mw'],
    "bhaṅguray": ['cae'],
    "bhaṅguraya": ['ddsa', 'mw'],
    "bhaṅgurā": ['mw'],
    "bhaṅgurāvant": ['cae'],
    "bhaṅgurāvat": ['gra', 'mw'],
    "bhaṅgurīkaraṇa": ['mw'],
    "bhaṅgurīkṛ": ['ddsa'],
    "bhaṅgya": ['mw'],
    "bhaṅgyantareṇa": ['mw'],
    "bhaṅgyaśravas": ['mw'],
    "bhaṅgyā": ['mw'],
    "bhaṅgā": ['mw'],
    "bhaṅgākaṭa": ['mw'],
    "bhaṅgāna": ['mw'],
    "bhaṅgānupassanā": ['cped'],
    "bhaṅgārī": ['mw'],
    "bhaṅgāsura": ['mw'],
    "bhaṅgāsvana": ['mw'],
    "bhaṅgī": ['cae', 'mw'],
    "bhaṅgībhakti": ['ddsa', 'mw'],
    "bhaṅgīka": ['mw'],
    "bhaṅgīla": ['mw'],
    "bhaṅktṛ": ['cae', 'ddsa', 'mw'],
    "bhaṇ": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhaṇa": ['cae', 'mw'],
    "bhaṇana": ['cae', 'ddsa', 'mw'],
    "bhaṇanaṃ": ['ap90'],
    "bhaṇanta": ['cped'],
    "bhaṇanīya": ['cae', 'mw'],
    "bhaṇata": ['cped'],
    "bhaṇati": ['cped', 'mw'],
    "bhaṇe": ['bhs', 'cped'],
    "bhaṇi": ['cped'],
    "bhaṇita": ['cae', 'cped', 'mw'],
    "bhaṇitabba": ['cped'],
    "bhaṇiti": ['mw'],
    "bhaṇitimaya": ['mw'],
    "bhaṇituṁ": ['cped'],
    "bhaṇitvā": ['cped'],
    "bhaṇitṛ": ['mw'],
    "bhaṇḍ": ['mw'],
    "bhaṇḍa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bhaṇḍadhūrtaniśācara": ['mw'],
    "bhaṇḍahāsinī": ['mw'],
    "bhaṇḍaka": ['cped', 'mw'],
    "bhaṇḍana": ['bhs', 'cped', 'mw'],
    "bhaṇḍanīya": ['mw'],
    "bhaṇḍara": ['mw'],
    "bhaṇḍatapasvin": ['mw'],
    "bhaṇḍati": ['bhs', 'cped'],
    "bhaṇḍatva": ['mw'],
    "bhaṇḍesi": ['cped'],
    "bhaṇḍeti": ['cped'],
    "bhaṇḍetvā": ['cped'],
    "bhaṇḍi": ['cae', 'cped', 'mw'],
    "bhaṇḍijaṅgha": ['mw'],
    "bhaṇḍikā": ['bhs', 'cped', 'mw'],
    "bhaṇḍila": ['mw'],
    "bhaṇḍiman": ['mw'],
    "bhaṇḍin": ['bhs', 'mw'],
    "bhaṇḍira": ['mw'],
    "bhaṇḍirī": ['mw'],
    "bhaṇḍita": ['mw'],
    "bhaṇḍu": ['cped', 'mw'],
    "bhaṇḍuka": ['mw'],
    "bhaṇḍukamma": ['cped'],
    "bhaṇḍā": ['mw'],
    "bhaṇḍāgāra": ['cped'],
    "bhaṇḍāgārika": ['cped'],
    "bhaṇḍākī": ['mw'],
    "bhaṇḍī": ['mw'],
    "bhaṇḍīla": ['mw'],
    "bhaṇḍīpuṣpanikāśa": ['mw'],
    "bhaṇḍīra": ['mw'],
    "bhaṇḍīralatikā": ['mw'],
    "bhaṇḍīratha": ['mw'],
    "bhaṇḍīrī": ['mw'],
    "bhaṇḍītakī": ['mw'],
    "bhaṇḍūka": ['ddsa', 'mw'],
    "bhaṇṭ": ['mw'],
    "bhaṇṭuka": ['mw'],
    "bhaṇṭākī": ['mw'],
    "bhaṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhaṣa": ['cae', 'ddsa', 'mw'],
    "bhaṣaka": ['cae', 'mw'],
    "bhaṣat": ['mw'],
    "bhaṣaḥ": ['ap90'],
    "bhaṣaṇa": ['mw'],
    "bhaṣaṇaḥ": ['ap90'],
    "bhaṣita": ['mw'],
    "bhaṣā": ['mw'],
    "bhaṣī": ['mw'],
    "bhaṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhaṭa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bhaṭabalāgra": ['mw'],
    "bhaṭabhaṭamātṛtīrtha": ['mw'],
    "bhaṭabhaṭāya": ['mw'],
    "bhaṭadīpikā": ['mw'],
    "bhaṭapeṭaka": ['mw'],
    "bhaṭaprakāśa": ['mw'],
    "bhaṭaprakāśikā": ['mw'],
    "bhaṭasenā": ['cped'],
    "bhaṭaḥ": ['ap90'],
    "bhaṭitra": ['ap90', 'mw'],
    "bhaṭkalā": ['mw'],
    "bhaṭodyoga": ['mw'],
    "bhaṭā": ['mw'],
    "bhaṭārka": ['mw'],
    "bhaṭīya": ['ddsa', 'mw'],
    "bhaṭīyadīpikā": ['mw'],
    "bhaṭṭa": ['cae', 'ddsa', 'mw'],
    "bhaṭṭabalabhadra": ['mw'],
    "bhaṭṭabhāskara": ['mw'],
    "bhaṭṭabhāskarīya": ['mw'],
    "bhaṭṭabhāṣya": ['mw'],
    "bhaṭṭabījaka": ['mw'],
    "bhaṭṭadivākara": ['mw'],
    "bhaṭṭadīpikā": ['mw'],
    "bhaṭṭagopāla": ['mw'],
    "bhaṭṭakedāra": ['mw'],
    "bhaṭṭakārikā": ['mw'],
    "bhaṭṭamadana": ['mw'],
    "bhaṭṭamalla": ['mw'],
    "bhaṭṭanārāyaṇa": ['cae', 'mw'],
    "bhaṭṭanāyaka": ['mw'],
    "bhaṭṭapaddhati": ['mw'],
    "bhaṭṭaphalguna": ['mw'],
    "bhaṭṭaprakāśa": ['mw'],
    "bhaṭṭaprayāga": ['mw'],
    "bhaṭṭapāda": ['mw'],
    "bhaṭṭaraka": ['mw'],
    "bhaṭṭarāma": ['mw'],
    "bhaṭṭasarvajña": ['mw'],
    "bhaṭṭasomeśvara": ['mw'],
    "bhaṭṭasvāmin": ['mw'],
    "bhaṭṭaviśveśvara": ['mw'],
    "bhaṭṭavārttika": ['ddsa', 'mw'],
    "bhaṭṭayaśas": ['mw'],
    "bhaṭṭaśaṃkara": ['mw'],
    "bhaṭṭaśiva": ['mw'],
    "bhaṭṭaśrīśaṃkara": ['mw'],
    "bhaṭṭaśālīyapītāmbara": ['mw'],
    "bhaṭṭaḥ": ['ap90'],
    "bhaṭṭha": ['cped'],
    "bhaṭṭi": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhaṭṭibodhinī": ['mw'],
    "bhaṭṭicandrikā": ['mw'],
    "bhaṭṭika": ['bhs', 'mw'],
    "bhaṭṭikāvya": ['mw'],
    "bhaṭṭinī": ['ap90', 'mw'],
    "bhaṭṭoji": ['cae', 'ddsa', 'mw'],
    "bhaṭṭojibhaṭṭa": ['mw'],
    "bhaṭṭojidīkṣita": ['cae', 'mw'],
    "bhaṭṭojīya": ['mw'],
    "bhaṭṭopama": ['mw'],
    "bhaṭṭotpala": ['ddsa', 'mw'],
    "bhaṭṭā": ['bhs', 'mw'],
    "bhaṭṭācārya": ['cae', 'mw'],
    "bhaṭṭācāryacūḍāmaṇi": ['mw'],
    "bhaṭṭācāryaśatāvadhāna": ['mw'],
    "bhaṭṭācāryaśiromaṇi": ['mw'],
    "bhaṭṭālaṃkāra": ['mw'],
    "bhaṭṭāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhaṭṭāraharicandra": ['mw'],
    "bhaṭṭāraka": ['ap90', 'cae', 'mw'],
    "bhaṭṭārakamaṭha": ['mw'],
    "bhaṭṭārakavāra": ['cae', 'mw'],
    "bhaṭṭārakāyatana": ['mw'],
    "bhaṭṭārasvāmin": ['mw'],
    "bhaṭṭārikā": ['ap90', 'mw'],
    "bhaṭṭīya": ['mw'],
    "bheda": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhedabuddhi": ['mw'],
    "bhedadarpaṇa": ['mw'],
    "bhedadarśin": ['mw'],
    "bhedadhikkāra": ['mw'],
    "bhedadhikkāranyakkārahuṃkṛti": ['mw'],
    "bhedadhikkāranyakkāranirūpaṇa": ['mw'],
    "bhedadhikkārasatkriyā": ['mw'],
    "bhedadhikkṛti": ['mw'],
    "bhedadhikkṛtitattvanivecana": ['mw'],
    "bhedadīpikā": ['mw'],
    "bhedadṛṣṭi": ['mw'],
    "bhedaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bhedakara": ['cae', 'cped', 'mw'],
    "bhedakhaṇḍana": ['mw'],
    "bhedakārin": ['cae', 'mw'],
    "bhedakṛt": ['mw'],
    "bhedana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bhedanadhamma": ['cped'],
    "bhedanaka": ['bhs', 'cped', 'mw'],
    "bhedanīya": ['cae', 'mw'],
    "bhedanīyatā": ['mw'],
    "bhedaprakāra": ['mw'],
    "bhedaprakāśa": ['mw'],
    "bhedapratyaya": ['mw'],
    "bhedasaha": ['mw'],
    "bhedatas": ['mw'],
    "bhedavibhīṣikā": ['mw'],
    "bhedavidhi": ['mw'],
    "bhedavādin": ['ddsa', 'mw'],
    "bhedavādividāriṇī": ['mw'],
    "bhedaḥ": ['ap90'],
    "bhedesi": ['cped'],
    "bhedeti": ['cped'],
    "bhedetvā": ['cped'],
    "bhedikā": ['ap90', 'mw'],
    "bhedin": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhedinī": ['mw'],
    "bhedira": ['mw'],
    "bhediraṃ": ['ap90'],
    "bhedita": ['ap90', 'cped', 'mw'],
    "bheditva": ['mw'],
    "bhedojjīvana": ['mw'],
    "bhedoktijīvana": ['mw'],
    "bhedonmukha": ['mw'],
    "bhedya": ['bhs', 'cae', 'mw'],
    "bhedyaka": ['mw'],
    "bhedyaliṅga": ['mw'],
    "bhedyaroga": ['mw'],
    "bhedyaṃ": ['ap90'],
    "bhedābheda": ['mw'],
    "bhedābhedavādin": ['mw'],
    "bhedīya": ['mw'],
    "bhejja": ['cped'],
    "bheka": ['cae', 'cped', 'ddsa', 'mw'],
    "bhekabhuj": ['mw'],
    "bhekaparṇī": ['mw'],
    "bhekaśabda": ['mw'],
    "bhekaḥ": ['ap90'],
    "bhekuri": ['mw'],
    "bhekī": ['mw'],
    "bhekīpati": ['cae', 'mw'],
    "bhekṣāka": ['bhs'],
    "bhela": ['ap90', 'mw'],
    "bhelaka": ['mw'],
    "bhelakaḥ": ['ap90'],
    "bhelana": ['mw'],
    "bhelu": ['bhs', 'mw'],
    "bheluka": ['mw'],
    "bhelā": ['bhs'],
    "bhelūpurā": ['mw'],
    "bhempura": ['mw'],
    "bhena": ['mw'],
    "bhera": ['mw'],
    "bherava": ['cped'],
    "bheraḥ": ['ap90'],
    "bheraṇḍa": ['bhs', 'cped'],
    "bheraṇḍaka": ['cped'],
    "bheri": ['cae', 'cped'],
    "bhericāraṇa": ['cped'],
    "bherisadda": ['cped'],
    "bheritala": ['cped'],
    "bherivādaka": ['cped'],
    "bherivādana": ['cped'],
    "bheriḥ": ['ap90'],
    "bherotsa": ['mw'],
    "bheruṃḍa": ['ap90'],
    "bheruṃḍakaḥ": ['ap90'],
    "bheruṇḍa": ['bhs', 'cae', 'ddsa', 'mw'],
    "bheruṇḍā": ['mw'],
    "bherī": ['cae', 'ddsa', 'mw'],
    "bherībhramaka": ['mw'],
    "bherībhāṃkāra": ['mw'],
    "bherībhāṃkārīya": ['mw'],
    "bherīghnat": ['mw'],
    "bherīnāda": ['mw'],
    "bherīsvanamahāsvanā": ['mw'],
    "bherītāḍana": ['mw'],
    "bherīśaṅkhavāda": ['mw'],
    "bhesajja": ['cped'],
    "bhesajjakapāla": ['cped'],
    "bhesajjamattā": ['cped'],
    "bhetavya": ['cae', 'ddsa', 'mw'],
    "bhettar": ['cped'],
    "bhettavai": ['mw'],
    "bhettavya": ['ddsa', 'mw'],
    "bhettṛ": ['ap90', 'cae', 'gra', 'mw'],
    "bhetāla": ['mw'],
    "bheya": ['cae', 'ddsa', 'mw'],
    "bheyapāla": ['mw'],
    "bheśa": ['mw'],
    "bheḍa": ['cae', 'mw'],
    "bheḍagiri": ['ddsa', 'mw'],
    "bheḍara": ['ddsa', 'mw'],
    "bheḍasaṃhitā": ['mw'],
    "bheḍaḥ": ['ap90'],
    "bheḍra": ['mw'],
    "bheḍraḥ": ['ap90'],
    "bheḍī": ['mw'],
    "bheṇḍa": ['mw'],
    "bheṇḍivāla": ['cped'],
    "bheṇḍu": ['cped'],
    "bheṇḍuka": ['cped'],
    "bheṇḍā": ['mw'],
    "bheṇḍī": ['mw'],
    "bheṇḍītaka": ['mw'],
    "bheṣ": ['ap90', 'mw'],
    "bheṣaja": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bheṣajabhakṣaṇa": ['mw'],
    "bheṣajacandra": ['mw'],
    "bheṣajakalpa": ['mw'],
    "bheṣajakalpasārasaṃgraha": ['mw'],
    "bheṣajakaraṇa": ['mw'],
    "bheṣajakṛta": ['cae', 'mw'],
    "bheṣajasarvasva": ['mw'],
    "bheṣajatarka": ['mw'],
    "bheṣajatā": ['cae', 'mw'],
    "bheṣajavīrya": ['mw'],
    "bheṣajya": ['ap90', 'cae', 'mw'],
    "bheṣajāgāra": ['mw'],
    "bheṣajāṅga": ['mw'],
    "bheṭaka": ['mw'],
    "bhid": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhidaka": ['mw'],
    "bhidakaḥ": ['ap90'],
    "bhidatha": ['mw'],
    "bhidelima": ['ap90', 'mw'],
    "bhidi": ['mw'],
    "bhidira": ['mw'],
    "bhidiḥ": ['ap90'],
    "bhidra": ['mw'],
    "bhidraṃ": ['ap90'],
    "bhidu": ['mw'],
    "bhidura": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhidurasvana": ['mw'],
    "bhidvat": ['mw'],
    "bhidya": ['cae', 'mw'],
    "bhidyaḥ": ['ap90'],
    "bhidā": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhidābhṛt": ['mw'],
    "bhidākara": ['mw'],
    "bhidāpana": ['mw'],
    "bhihu": ['mw'],
    "bhijjadhamma": ['cped'],
    "bhijjamāna": ['cped'],
    "bhijjana": ['cped'],
    "bhijjanadhamma": ['cped'],
    "bhijjati": ['cped'],
    "bhijji": ['cped'],
    "bhijjitvā": ['cped'],
    "bhikkhaka": ['cped'],
    "bhikkhamāna": ['cped'],
    "bhikkhana": ['cped'],
    "bhikkhanta": ['cped'],
    "bhikkhati": ['cped'],
    "bhikkhi": ['cped'],
    "bhikkhitvā": ['cped'],
    "bhikkhu": ['cped'],
    "bhikkhubhāva": ['cped'],
    "bhikkhusaṅgha": ['cped'],
    "bhikkhuṇī": ['cped'],
    "bhikkhā": ['cped'],
    "bhikkhācariyā": ['cped'],
    "bhikkhācāra": ['cped'],
    "bhikkhāhāra": ['cped'],
    "bhikṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhikṣaṇa": ['cae', 'ddsa', 'mw'],
    "bhikṣaṇaṃ": ['ap90'],
    "bhikṣin": ['cae', 'mw'],
    "bhikṣita": ['ap90', 'mw'],
    "bhikṣitavya": ['cae', 'mw'],
    "bhikṣopabhegin": ['mw'],
    "bhikṣopajīvin": ['mw'],
    "bhikṣotkara": ['mw'],
    "bhikṣu": ['cae', 'ddsa', 'mw'],
    "bhikṣubhāva": ['mw'],
    "bhikṣucaryā": ['cae', 'mw'],
    "bhikṣudeva": ['bhs'],
    "bhikṣuhala": ['mw'],
    "bhikṣuka": ['cae', 'mw'],
    "bhikṣukasatī": ['mw'],
    "bhikṣukaḥ": ['ap90'],
    "bhikṣukopaniṣad": ['mw'],
    "bhikṣukī": ['mw'],
    "bhikṣukīparāka": ['mw'],
    "bhikṣuprakīrṇaka": ['bhs'],
    "bhikṣurākṣasa": ['mw'],
    "bhikṣusaṃgha": ['mw'],
    "bhikṣusaṃghāṭī": ['mw'],
    "bhikṣusūtra": ['mw'],
    "bhikṣusūtrabhāṣyavārttika": ['mw'],
    "bhikṣutattva": ['mw'],
    "bhikṣuḥ": ['ap90'],
    "bhikṣuṇikā": ['bhs'],
    "bhikṣuṇī": ['bhs', 'mw'],
    "bhikṣuṇīkarmavācanā": ['bhs'],
    "bhikṣya": ['mw'],
    "bhikṣā": ['ap90', 'cae', 'gra', 'mw'],
    "bhikṣābhuj": ['mw'],
    "bhikṣābhāṇḍa": ['cae', 'mw'],
    "bhikṣābiḍāla": ['mw'],
    "bhikṣācara": ['mw'],
    "bhikṣācaraṇa": ['cae', 'mw'],
    "bhikṣācarya": ['cae', 'mw'],
    "bhikṣācaryacaraṇa": ['mw'],
    "bhikṣācāra": ['mw'],
    "bhikṣāda": ['bhs'],
    "bhikṣāhāra": ['cae', 'mw'],
    "bhikṣāka": ['ddsa', 'mw'],
    "bhikṣākaragupta": ['mw'],
    "bhikṣākaraṇa": ['mw'],
    "bhikṣākavṛtta": ['bhs'],
    "bhikṣākaḥ": ['ap90'],
    "bhikṣākī": ['mw'],
    "bhikṣāmāṇava": ['mw'],
    "bhikṣānna": ['cae', 'mw'],
    "bhikṣāpātra": ['cae', 'mw'],
    "bhikṣārha": ['mw'],
    "bhikṣārthin": ['cae', 'mw'],
    "bhikṣāvant": ['cae'],
    "bhikṣāvat": ['mw'],
    "bhikṣāvāsas": ['mw'],
    "bhikṣāvṛtti": ['cae', 'mw'],
    "bhikṣāyaṇa": ['mw'],
    "bhikṣāśin": ['cae', 'mw'],
    "bhikṣāśitva": ['cae', 'mw'],
    "bhikṣāṭana": ['cae', 'mw'],
    "bhikṣāṭanakāvya": ['mw'],
    "bhikṣāṭananāṭaka": ['mw'],
    "bhil": ['mw'],
    "bhilla": ['cae', 'ddsa', 'mw'],
    "bhillabhūṣaṇā": ['mw'],
    "bhillagavī": ['mw'],
    "bhillataru": ['mw'],
    "bhillaḥ": ['ap90'],
    "bhillin": ['mw'],
    "bhilloṭa": ['mw'],
    "bhilloṭaka": ['mw'],
    "bhilloṭaḥ": ['ap90'],
    "bhillī": ['mw'],
    "bhillīcakreśvara": ['mw'],
    "bhillīnātha": ['mw'],
    "bhilma": ['mw'],
    "bhind": ['mw'],
    "bhindana": ['cped'],
    "bhindanta": ['cped'],
    "bhindati": ['cped'],
    "bhinddhilavaṇā": ['mw'],
    "bhindi": ['cped'],
    "bhindipāla": ['cae', 'mw'],
    "bhindipālaka": ['cae', 'mw'],
    "bhindita": ['cped'],
    "bhindituṁ": ['cped'],
    "bhinditvā": ['cped'],
    "bhindu": ['cae', 'ddsa', 'gra', 'mw'],
    "bhindura": ['mw'],
    "bhinna": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bhinnabhinnātman": ['mw'],
    "bhinnabhāgahara": ['mw'],
    "bhinnabhājana": ['cae', 'mw'],
    "bhinnabhāva": ['cped'],
    "bhinnabhāṇḍa": ['cae', 'mw'],
    "bhinnadalā": ['mw'],
    "bhinnadarśin": ['mw'],
    "bhinnadeha": ['mw'],
    "bhinnadeśa": ['cae', 'mw'],
    "bhinnadeśatva": ['mw'],
    "bhinnadṛś": ['mw'],
    "bhinnagarbha": ['mw'],
    "bhinnagati": ['cae', 'mw'],
    "bhinnagaṇḍakaraṭa": ['mw'],
    "bhinnaghana": ['mw'],
    "bhinnaguṇana": ['mw'],
    "bhinnagātrikā": ['mw'],
    "bhinnahṛdaya": ['mw'],
    "bhinnahṛti": ['mw'],
    "bhinnajāti": ['mw'],
    "bhinnajātimat": ['mw'],
    "bhinnajātīya": ['mw'],
    "bhinnaka": ['mw'],
    "bhinnakalpa": ['mw'],
    "bhinnakaraṭa": ['mw'],
    "bhinnakarīndrakumbhamuktāmaya": ['mw'],
    "bhinnakarṇa": ['mw'],
    "bhinnakaḥ": ['ap90'],
    "bhinnakaṭa": ['mw'],
    "bhinnakleśa": ['mw'],
    "bhinnakleśatva": ['mw'],
    "bhinnakrama": ['mw'],
    "bhinnakumbha": ['mw'],
    "bhinnakāla": ['ddsa', 'mw'],
    "bhinnakī": ['mw'],
    "bhinnakīkṛ": ['ddsa'],
    "bhinnakūṭa": ['mw'],
    "bhinnaliṅga": ['mw'],
    "bhinnaliṅgaka": ['mw'],
    "bhinnamantra": ['mw'],
    "bhinnamariyāda": ['cped'],
    "bhinnamarman": ['mw'],
    "bhinnamaryāda": ['mw'],
    "bhinnamaryādin": ['mw'],
    "bhinnamastakapiṇḍaka": ['mw'],
    "bhinnamastakapiṇḍika": ['mw'],
    "bhinnanau": ['mw'],
    "bhinnanauka": ['mw'],
    "bhinnaparikarman": ['mw'],
    "bhinnapaṭa": ['cped'],
    "bhinnaprakāra": ['mw'],
    "bhinnaruci": ['cae', 'mw'],
    "bhinnasaṃhati": ['mw'],
    "bhinnasaṃkalana": ['mw'],
    "bhinnasaṃkalita": ['mw'],
    "bhinnasvara": ['cae', 'mw'],
    "bhinnasvaramukhavarṇa": ['mw'],
    "bhinnasīla": ['cped'],
    "bhinnatantra": ['mw'],
    "bhinnatta": ['cped'],
    "bhinnatva": ['cae', 'mw'],
    "bhinnavacana": ['mw'],
    "bhinnavarcas": ['mw'],
    "bhinnavarcastva": ['mw'],
    "bhinnavarga": ['mw'],
    "bhinnavartman": ['mw'],
    "bhinnavarṇa": ['mw'],
    "bhinnavat": ['mw'],
    "bhinnaviṭka": ['mw'],
    "bhinnaviṭkatva": ['mw'],
    "bhinnavyavakalita": ['mw'],
    "bhinnavṛtta": ['cae', 'mw'],
    "bhinnavṛtti": ['cae', 'mw'],
    "bhinnavṛttitā": ['mw'],
    "bhinnayojanī": ['mw'],
    "bhinnaśakṛt": ['mw'],
    "bhinnodara": ['mw'],
    "bhinnā": ['mw'],
    "bhinnābhinna": ['mw'],
    "bhinnārtha": ['cae', 'mw'],
    "bhinnārthatā": ['mw'],
    "bhinnāva": ['cped'],
    "bhinnāñjana": ['cae', 'mw'],
    "bhinnāñjanacayopama": ['mw'],
    "bhinnāñjanasaṃnibha": ['mw'],
    "bhinnāñjanavarṇa": ['mw'],
    "bhinnāñjanavarṇatā": ['mw'],
    "bhinnāñjanābha": ['mw'],
    "bhinnāñjanākāra": ['mw'],
    "bhiriṃṭikā": ['ap90'],
    "bhiriṇṭikā": ['mw'],
    "bhiru": ['bhs', 'mw'],
    "bhiruka": ['bhs'],
    "bhirukaccha": ['bhs', 'mw'],
    "bhisa": ['cped'],
    "bhisakka": ['cped'],
    "bhisamuḷāla": ['cped'],
    "bhisapuppha": ['cped'],
    "bhisi": ['cped'],
    "bhissaṭā": ['ap90', 'mw'],
    "bhissiṭā": ['ap90', 'mw'],
    "bhissā": ['ap90', 'mw'],
    "bhitra": ['mw'],
    "bhitta": ['cae', 'ddsa', 'mw'],
    "bhittaṃ": ['ap90'],
    "bhitti": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bhitticaura": ['mw'],
    "bhittika": ['mw'],
    "bhittikhātana": ['mw'],
    "bhittikā": ['ap90', 'mw'],
    "bhittipāda": ['cped'],
    "bhittipātana": ['mw'],
    "bhittivedikābandha": ['cae'],
    "bhittīphalaka": ['bhs'],
    "bhitvara": ['bhs'],
    "bhiyas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhiyasāna": ['cae', 'mw'],
    "bhiyyo": ['cped'],
    "bhiyyoso": ['cped'],
    "bhiyyoso mattāya": ['cped'],
    "bhiyā": ['ap90', 'mw'],
    "bhiyāna": ['mw'],
    "bhiścā": ['ddsa', 'mw'],
    "bhiḥkharāja": ['ddsa', 'mw'],
    "bhiṁsana": ['cped'],
    "bhiṁsanaka": ['cped'],
    "bhiṃdapālaḥ": ['ap90'],
    "bhiṃdipālaḥ": ['ap90'],
    "bhiṃdu": ['ap90'],
    "bhiṅka": ['cped'],
    "bhiṅkāra": ['cped'],
    "bhiṅsana": ['cped'],
    "bhiṅsanaka": ['cped'],
    "bhiṇḍa": ['ddsa', 'mw'],
    "bhiṇḍaka": ['mw'],
    "bhiṇḍimāla": ['mw'],
    "bhiṇḍipāla": ['bhs'],
    "bhiṇḍītaka": ['mw'],
    "bhiṣag": ['mw'],
    "bhiṣagbhadrā": ['mw'],
    "bhiṣagjita": ['mw'],
    "bhiṣagrājamiśra": ['mw'],
    "bhiṣagvara": ['mw'],
    "bhiṣagvatī": ['mw'],
    "bhiṣagvid": ['mw'],
    "bhiṣaj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhiṣaja": ['mw'],
    "bhiṣajy": ['cae', 'gra'],
    "bhiṣajya": ['cae', 'ddsa', 'mw'],
    "bhiṣajyaṃ": ['ap90'],
    "bhiṣajyita": ['mw'],
    "bhiṣajyā": ['mw'],
    "bhiṣajāvarta": ['mw'],
    "bhiṣajāvartaḥ": ['ap90'],
    "bhiṣak": ['mw'],
    "bhiṣakcakracittotsava": ['mw'],
    "bhiṣakcakranidāna": ['mw'],
    "bhiṣakpriyā": ['mw'],
    "bhiṣakpāśa": ['mw'],
    "bhiṣaktama": ['cae', 'mw'],
    "bhiṣaktara": ['cae', 'mw'],
    "bhiṣaktva": ['mw'],
    "bhiṣaya": ['mw'],
    "bhiṣaṅ": ['mw'],
    "bhiṣaṅka": ['bhs'],
    "bhiṣaṅmātṛ": ['mw'],
    "bhiṣaṭka": ['bhs'],
    "bhiṣmikā": ['ap90', 'mw'],
    "bhiṣmiṣṭā": ['mw'],
    "bhiṣmiṭā": ['ap90', 'mw'],
    "bhiṣmā": ['ap90', 'mw'],
    "bhiṣāyaka": ['ddsa', 'mw'],
    "bhiṣāyakapura": ['mw'],
    "bhiṣṇaj": ['gra'],
    "bhiṣṇaja": ['mw'],
    "bhiṣṇajy": ['cae'],
    "bhiṣṇajya": ['ddsa', 'mw'],
    "bhlakṣ": ['ap90', 'mw'],
    "bhleṣ": ['ap90', 'mw'],
    "bhlās": ['ap90', 'mw'],
    "bhlāś": ['ap90', 'mw'],
    "bho": ['cae', 'cped', 'ddsa', 'mw'],
    "bhobhavatpūrvakam": ['cae', 'ddsa', 'mw'],
    "bhobhāva": ['cae', 'mw'],
    "bhoga": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhogabhaṭṭa": ['mw'],
    "bhogabhuj": ['mw'],
    "bhogabhūmi": ['mw'],
    "bhogabhṛtaka": ['mw'],
    "bhogadattā": ['mw'],
    "bhogadeha": ['mw'],
    "bhogadeva": ['mw'],
    "bhogadā": ['mw'],
    "bhogagrāma": ['mw'],
    "bhogaguccha": ['mw'],
    "bhogagṛha": ['mw'],
    "bhogahetu": ['cped'],
    "bhogajāta": ['mw'],
    "bhogakara": ['ddsa', 'mw'],
    "bhogakarman": ['mw'],
    "bhogakkhandha": ['cped'],
    "bhogakārikā": ['mw'],
    "bhogalābha": ['mw'],
    "bhogamada": ['cped'],
    "bhogamaṇḍapa": ['mw'],
    "bhogamālinī": ['mw'],
    "bhoganagaraka": ['bhs'],
    "bhoganidhi": ['mw'],
    "bhoganātha": ['mw'],
    "bhogapati": ['cae', 'mw'],
    "bhogapiśācikā": ['mw'],
    "bhogaprastha": ['mw'],
    "bhogapāla": ['mw'],
    "bhogasadman": ['mw'],
    "bhogasaṃkrāntividhi": ['mw'],
    "bhogasena": ['mw'],
    "bhogasthāna": ['mw'],
    "bhogasvāmin": ['mw'],
    "bhogatva": ['mw'],
    "bhogatṛṣṇā": ['cae', 'mw'],
    "bhogavant": ['bhs', 'cae', 'cped'],
    "bhogavardhana": ['mw'],
    "bhogavarman": ['mw'],
    "bhogavastu": ['mw'],
    "bhogavat": ['ap90', 'ddsa', 'mw'],
    "bhogavatī": ['mw'],
    "bhogaḥ": ['ap90'],
    "bhogaṃkarā": ['mw'],
    "bhogeśvaratīrtha": ['mw'],
    "bhogga": ['cped'],
    "bhogi": ['mw'],
    "bhogibhuj": ['mw'],
    "bhogigandhikā": ['mw'],
    "bhogika": ['mw'],
    "bhogikaḥ": ['ap90'],
    "bhogikānta": ['mw'],
    "bhogin": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhoginandana": ['mw'],
    "bhoginī": ['mw'],
    "bhogipura": ['mw'],
    "bhogivallabha": ['mw'],
    "bhogya": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhogyatva": ['mw'],
    "bhogyatā": ['mw'],
    "bhogyā": ['mw'],
    "bhogyādhi": ['mw'],
    "bhogyārha": ['mw'],
    "bhogā": ['mw'],
    "bhogādhi": ['mw'],
    "bhogāma": ['cped'],
    "bhogānta": ['mw'],
    "bhogārha": ['mw'],
    "bhogārhya": ['mw'],
    "bhogāvalivṛtti": ['mw'],
    "bhogāvalī": ['mw'],
    "bhogāvāsa": ['mw'],
    "bhogāvāsā": ['mw'],
    "bhogāy": ['cae'],
    "bhogāyatana": ['cae', 'mw'],
    "bhogī": ['cped'],
    "bhogīna": ['mw'],
    "bhogīndra": ['cae', 'mw'],
    "bhogīndranandana": ['mw'],
    "bhogīndratanaya": ['mw'],
    "bhogīśa": ['cae', 'mw'],
    "bhohara": ['mw'],
    "bhoj": ['mw'],
    "bhoja": ['cae', 'ddsa', 'gra', 'mw'],
    "bhojacampū": ['mw'],
    "bhojacaritra": ['mw'],
    "bhojadeva": ['cae', 'ddsa', 'mw'],
    "bhojadevaśabdānuśāsana": ['mw'],
    "bhojaduhitṛ": ['mw'],
    "bhojaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bhojakanyā": ['mw'],
    "bhojakaṭa": ['mw'],
    "bhojakaṭīya": ['mw'],
    "bhojakulapradīpa": ['mw'],
    "bhojana": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhojanabhāṇḍa": ['mw'],
    "bhojanabhūmi": ['mw'],
    "bhojanagara": ['mw'],
    "bhojanagṛha": ['mw'],
    "bhojanaka": ['mw'],
    "bhojanakastūrī": ['mw'],
    "bhojanakutūhala": ['mw'],
    "bhojanakāla": ['cae', 'mw'],
    "bhojanakīsmṛti": ['mw'],
    "bhojananda": ['mw'],
    "bhojanarendra": ['ddsa', 'mw'],
    "bhojanasamaya": ['mw'],
    "bhojanasūtra": ['mw'],
    "bhojanatyāga": ['mw'],
    "bhojanavelā": ['mw'],
    "bhojanavidhi": ['mw'],
    "bhojanaviśeṣa": ['mw'],
    "bhojanavyagra": ['mw'],
    "bhojanavyaya": ['mw'],
    "bhojanavṛtti": ['ddsa', 'mw'],
    "bhojanidhi": ['mw'],
    "bhojaniya": ['cped'],
    "bhojanottara": ['mw'],
    "bhojanācchādana": ['mw'],
    "bhojanādhikāra": ['mw'],
    "bhojanārthin": ['cae', 'mw'],
    "bhojanīya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "bhojanīyamṛta": ['mw'],
    "bhojanṛpati": ['mw'],
    "bhojapati": ['mw'],
    "bhojapitṛ": ['ddsa', 'mw'],
    "bhojaprabandha": ['mw'],
    "bhojaprabandhasāra": ['mw'],
    "bhojapura": ['mw'],
    "bhojapurī": ['mw'],
    "bhojaputrī": ['mw'],
    "bhojarāja": ['ddsa', 'mw'],
    "bhojarājakavivarga": ['mw'],
    "bhojarājaprabandha": ['mw'],
    "bhojarājasaccarita": ['mw'],
    "bhojarājavijaya": ['mw'],
    "bhojarājavārttika": ['mw'],
    "bhojarājavṛtti": ['mw'],
    "bhojarājīya": ['mw'],
    "bhojas": ['gra', 'mw'],
    "bhojasmṛti": ['mw'],
    "bhojavyākaraṇa": ['mw'],
    "bhojayamāna": ['cped'],
    "bhojayitavya": ['cae', 'ddsa', 'mw'],
    "bhojayitvā": ['mw'],
    "bhojayitṛ": ['ap90', 'mw'],
    "bhojaḥ": ['ap90'],
    "bhojendra": ['mw'],
    "bhojenta": ['cped'],
    "bhojesi": ['cped'],
    "bhojeti": ['cped'],
    "bhojetuṁ": ['cped'],
    "bhojetvā": ['cped'],
    "bhojia": ['gra'],
    "bhojika": ['bhs', 'ddsa', 'mw'],
    "bhojin": ['ap90', 'cae', 'mw'],
    "bhojita": ['cped'],
    "bhojja": ['cped'],
    "bhojya": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "bhojyakāla": ['mw'],
    "bhojyamaya": ['mw'],
    "bhojyasambhava": ['mw'],
    "bhojyatva": ['mw'],
    "bhojyatā": ['mw'],
    "bhojyoṣṇa": ['mw'],
    "bhojyā": ['ap90', 'mw'],
    "bhojyānna": ['cae', 'mw'],
    "bhojā": ['mw'],
    "bhojādhipa": ['mw'],
    "bhojādhirāja": ['mw'],
    "bhojāntā": ['mw'],
    "bhojāpesi": ['cped'],
    "bhojāpeti": ['cped'],
    "bhojāpetvā": ['cped'],
    "bhojāpita": ['cped'],
    "bhojī": ['cped'],
    "bhoktavya": ['cae', 'ddsa', 'mw'],
    "bhoktukāma": ['cae'],
    "bhoktṛ": ['ap90', 'cae', 'mw'],
    "bhoktṛtva": ['mw'],
    "bhoktṛtvaṃ": ['ap90'],
    "bhoktṛśakti": ['mw'],
    "bhokṣyaka": ['mw'],
    "bhola": ['mw'],
    "bholi": ['mw'],
    "bholiḥ": ['ap90'],
    "bholānātha": ['mw'],
    "bhomīrā": ['ap90', 'mw'],
    "bhos": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhoskāra": ['bhs', 'mw'],
    "bhota": ['mw'],
    "bhoti": ['bhs', 'cped'],
    "bhottabba": ['cped'],
    "bhottuṁ": ['cped'],
    "bhovādin": ['mw'],
    "bhovādī": ['cped'],
    "bhoḥ": ['cae', 'mw'],
    "bhoḥśabda": ['ddsa', 'mw'],
    "bhoṃsala": ['mw'],
    "bhoṃsalavaṃśāvalī": ['mw'],
    "bhoṅkāra": ['bhs'],
    "bhoṭa": ['cae', 'ddsa', 'mw'],
    "bhoṭadeśa": ['mw'],
    "bhoṭago": ['mw'],
    "bhoṭaḥ": ['ap90'],
    "bhoṭānta": ['mw'],
    "bhoṭāṅga": ['mw'],
    "bhoṭīya": ['ap90', 'mw'],
    "bhoṭīyakośī": ['mw'],
    "bhra": ['mw'],
    "bhrabhaṃgaḥ": ['ap90'],
    "bhrabhaṅga": ['mw'],
    "bhraiṅgarika": ['bhs'],
    "bhraj": ['cae', 'ddsa', 'mw'],
    "bhraja": ['mw'],
    "bhrajas": ['mw'],
    "bhrajj": ['ddsa', 'mw'],
    "bhrajjana": ['mw'],
    "bhrajjanaṃ": ['ap90'],
    "bhrakuñca": ['mw'],
    "bhrakuṃsa": ['mw'],
    "bhrakuṃśa": ['mw'],
    "bhrakuṃśaḥ": ['ap90'],
    "bhrakuṭi": ['ap90', 'mw'],
    "bhrakuṭī": ['mw'],
    "bhrakuṭīmukha": ['mw'],
    "bhrakṣ": ['ap90', 'mw'],
    "bhram": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhrama": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "bhramabhūta": ['mw'],
    "bhramakuṭī": ['mw'],
    "bhramanta": ['mw'],
    "bhramantra": ['bhs'],
    "bhramara": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhramarabādhā": ['mw'],
    "bhramaracchallī": ['mw'],
    "bhramaradeva": ['mw'],
    "bhramaradūtakāvya": ['mw'],
    "bhramaragītaṭīkā": ['mw'],
    "bhramaraja": ['mw'],
    "bhramaraka": ['mw'],
    "bhramarakaraṇḍaka": ['mw'],
    "bhramarakaḥ": ['ap90'],
    "bhramarakuṇḍa": ['mw'],
    "bhramarakīṭa": ['mw'],
    "bhramaramaṇḍala": ['mw'],
    "bhramaramārī": ['mw'],
    "bhramaranikara": ['mw'],
    "bhramarapada": ['mw'],
    "bhramarapriya": ['mw'],
    "bhramarasadṛśakeśatā": ['mw'],
    "bhramarasaṃdeśakāvya": ['mw'],
    "bhramaravilasita": ['mw'],
    "bhramareṣṭa": ['mw'],
    "bhramareṣṭā": ['mw'],
    "bhramarikā": ['ap90', 'bhs', 'mw'],
    "bhramarikādṛṣṭi": ['mw'],
    "bhramarita": ['ddsa', 'mw'],
    "bhramarotsavā": ['mw'],
    "bhramarā": ['mw'],
    "bhramarālaka": ['mw'],
    "bhramarāmbākṣetra": ['mw'],
    "bhramarāmbākṣetramāhātmya": ['mw'],
    "bhramarāmbāṣṭaka": ['mw'],
    "bhramarānanda": ['mw'],
    "bhramarāri": ['mw'],
    "bhramarātithi": ['mw'],
    "bhramarāya": ['mw'],
    "bhramarāyate": ['ap90'],
    "bhramarāṣṭaka": ['mw'],
    "bhramarī": ['ddsa', 'mw'],
    "bhramat": ['ap90', 'mw'],
    "bhramatkuṭi": ['mw'],
    "bhramatva": ['mw'],
    "bhramaḥ": ['ap90'],
    "bhramaṇa": ['cae', 'ddsa', 'mw'],
    "bhramaṇavilasita": ['mw'],
    "bhramaṇaṃ": ['ap90'],
    "bhramaṇārthe": ['mw'],
    "bhramaṇī": ['mw'],
    "bhramaṇīya": ['cae'],
    "bhrami": ['bhs', 'cae', 'ddsa', 'mw'],
    "bhramin": ['ap90', 'mw'],
    "bhramita": ['mw'],
    "bhramiḥ": ['ap90'],
    "bhramu": ['bhs'],
    "bhramāsakta": ['mw'],
    "bhramāt": ['mw'],
    "bhramātra": ['bhs', 'mw'],
    "bhramāya": ['mw'],
    "bhrasj": ['ap90'],
    "bhrastā": ['cae', 'mw'],
    "bhrauveya": ['mw'],
    "bhrauṇaghna": ['mw'],
    "bhrauṇahatya": ['mw'],
    "bhrauṇahatyaṃ": ['ap90'],
    "bhraś": ['ap90', 'ddsa', 'gra', 'mw'],
    "bhraśiman": ['ap90', 'mw'],
    "bhraśiṣṭha": ['mw'],
    "bhraśīyas": ['mw'],
    "bhraṃs": ['ap90', 'mw'],
    "bhraṃsana": ['ap90'],
    "bhraṃś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhraṃśa": ['cae', 'ddsa', 'mw'],
    "bhraṃśakalākṛ": ['mw'],
    "bhraṃśana": ['ap90', 'cae', 'mw'],
    "bhraṃśanin": ['bhs'],
    "bhraṃśathu": ['mw'],
    "bhraṃśathuḥ": ['ap90'],
    "bhraṃśaḥ": ['ap90'],
    "bhraṃśin": ['ap90', 'cae', 'mw'],
    "bhraṃśita": ['ap90', 'mw'],
    "bhraṇ": ['ap90', 'mw'],
    "bhraṣa": ['mw'],
    "bhraṣṭa": ['cae', 'ddsa', 'mw'],
    "bhraṣṭaguda": ['mw'],
    "bhraṣṭaka": ['mw'],
    "bhraṣṭakakapiṣṭhala": ['mw'],
    "bhraṣṭakriya": ['mw'],
    "bhraṣṭamārga": ['mw'],
    "bhraṣṭanidra": ['mw'],
    "bhraṣṭapariśrama": ['mw'],
    "bhraṣṭarājya": ['mw'],
    "bhraṣṭavaiṣṇavakhaṇḍana": ['mw'],
    "bhraṣṭavya": ['mw'],
    "bhraṣṭayoga": ['mw'],
    "bhraṣṭaśrī": ['mw'],
    "bhraṣṭra": ['cae', 'mw'],
    "bhraṣṭā": ['mw'],
    "bhraṣṭādhikāra": ['mw'],
    "bhraṣṭādhikāratva": ['mw'],
    "bhraṣṭālā": ['bhs'],
    "bhrej": ['ap90', 'mw'],
    "bhreṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhreṣa": ['cae', 'ddsa', 'mw'],
    "bhreṣaḥ": ['ap90'],
    "bhreṣaṇa": ['mw'],
    "bhru": ['mw'],
    "bhrubhaṅga": ['mw'],
    "bhrukuṃsa": ['mw'],
    "bhrukuṃsaḥ": ['ap90'],
    "bhrukuṃśa": ['mw'],
    "bhrukuṃśaḥ": ['ap90'],
    "bhrukuṭi": ['cae', 'ddsa', 'mw'],
    "bhrukuṭibandha": ['cae'],
    "bhrukuṭiḥ": ['ap90'],
    "bhrukuṭī": ['cae', 'mw'],
    "bhrukuṭīkṛt": ['mw'],
    "bhrukuṭīmukha": ['cae', 'mw'],
    "bhrumukha": ['bhs'],
    "bhruva": ['cae', 'ddsa', 'mw'],
    "bhruḍ": ['ap90', 'mw'],
    "bhrādinī": ['mw'],
    "bhrāj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhrāja": ['cae', 'gra', 'mw'],
    "bhrājabhṛṣṭi": ['mw'],
    "bhrājadṛṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "bhrājajjanman": ['cae', 'gra', 'mw'],
    "bhrājaka": ['ap90', 'mw'],
    "bhrājana": ['ddsa', 'mw'],
    "bhrājanaṃ": ['ap90'],
    "bhrājas": ['cae', 'ddsa', 'gra', 'mw'],
    "bhrājasvant": ['cae'],
    "bhrājasvat": ['mw'],
    "bhrājasvin": ['cae', 'mw'],
    "bhrājat": ['mw'],
    "bhrājathu": ['mw'],
    "bhrājathumat": ['mw'],
    "bhrājathuḥ": ['ap90'],
    "bhrājaḥ": ['ap90'],
    "bhrāji": ['cae', 'mw'],
    "bhrājin": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhrājira": ['mw'],
    "bhrājis": ['mw'],
    "bhrājiṣmant": ['cae'],
    "bhrājiṣmat": ['mw'],
    "bhrājiṣṇu": ['ap90', 'cae', 'mw'],
    "bhrājiṣṇutā": ['mw'],
    "bhrājiṣṭha": ['cae', 'mw'],
    "bhrājobhrādantya": ['mw'],
    "bhrāma": ['cae', 'ddsa', 'mw'],
    "bhrāmaka": ['ap90', 'cae', 'mw'],
    "bhrāmakā": ['mw'],
    "bhrāmakādri": ['mw'],
    "bhrāmara": ['ap90', 'ddsa', 'mw'],
    "bhrāmarin": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhrāmarī": ['mw'],
    "bhrāmaḥ": ['ap90'],
    "bhrāmaṇa": ['cae', 'mw'],
    "bhrāmaṇaṃ": ['ap90'],
    "bhrāmaṇī": ['mw'],
    "bhrāmin": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhrāmita": ['mw'],
    "bhrānta": ['cae', 'ddsa', 'mw'],
    "bhrāntabuddhi": ['mw'],
    "bhrāntacitta": ['mw'],
    "bhrānti": ['cae', 'ddsa', 'mw'],
    "bhrāntidarśana": ['mw'],
    "bhrāntihara": ['mw'],
    "bhrāntikara": ['mw'],
    "bhrāntimant": ['cae'],
    "bhrāntimat": ['mw'],
    "bhrāntināśana": ['mw'],
    "bhrāntivilāsa": ['mw'],
    "bhrāntākulitacetana": ['mw'],
    "bhrās": ['ap90', 'mw'],
    "bhrāstreya": ['mw'],
    "bhrātara": ['gra'],
    "bhrātra": ['cae', 'ddsa', 'gra', 'mw'],
    "bhrātreya": ['mw'],
    "bhrātrya": ['cae', 'mw'],
    "bhrātryaṃ": ['ap90'],
    "bhrātrīya": ['ap90', 'mw'],
    "bhrātṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhrātṛbhaginī": ['mw'],
    "bhrātṛbhaginīdarśanavidhi": ['mw'],
    "bhrātṛbhāryā": ['cae', 'mw'],
    "bhrātṛbhāṇḍa": ['mw'],
    "bhrātṛdatta": ['cae', 'mw'],
    "bhrātṛdvitīyā": ['mw'],
    "bhrātṛgandhi": ['mw'],
    "bhrātṛgandhika": ['mw'],
    "bhrātṛhatyā": ['mw'],
    "bhrātṛja": ['mw'],
    "bhrātṛjā": ['mw'],
    "bhrātṛjāyā": ['cae', 'mw'],
    "bhrātṛka": ['ap90', 'cae', 'mw'],
    "bhrātṛmant": ['cae'],
    "bhrātṛmat": ['mw'],
    "bhrātṛpadmavana": ['mw'],
    "bhrātṛpatnī": ['mw'],
    "bhrātṛputra": ['mw'],
    "bhrātṛsaṃghātavat": ['mw'],
    "bhrātṛsiṃha": ['ddsa', 'mw'],
    "bhrātṛsthāna": ['mw'],
    "bhrātṛtva": ['cae', 'gra', 'mw'],
    "bhrātṛtvaṃ": ['ap90'],
    "bhrātṛvadhū": ['mw'],
    "bhrātṛvala": ['ap90', 'mw'],
    "bhrātṛvya": ['cae', 'ddsa', 'gra', 'mw'],
    "bhrātṛvyacātana": ['mw'],
    "bhrātṛvyadevatya": ['mw'],
    "bhrātṛvyaghnī": ['mw'],
    "bhrātṛvyahan": ['mw'],
    "bhrātṛvyajanman": ['mw'],
    "bhrātṛvyakṣayaṇa": ['mw'],
    "bhrātṛvyaloka": ['mw'],
    "bhrātṛvyaparāṇutti": ['mw'],
    "bhrātṛvyasahana": ['mw'],
    "bhrātṛvyavant": ['cae'],
    "bhrātṛvyavat": ['ddsa', 'mw'],
    "bhrātṛvyayajña": ['mw'],
    "bhrātṛvyaḥ": ['ap90'],
    "bhrātṛvyābhibhūti": ['mw'],
    "bhrātṛvyāpanutti": ['mw'],
    "bhrātṛśvaśura": ['mw'],
    "bhrāś": ['ap90', 'mw'],
    "bhrāśia": ['gra'],
    "bhrāśya": ['cae', 'ddsa', 'gra', 'mw'],
    "bhrāṃta": ['ap90'],
    "bhrāṃtimat": ['ap90'],
    "bhrāṃtiḥ": ['ap90'],
    "bhrāṣṭra": ['ddsa', 'mw'],
    "bhrāṣṭraja": ['mw'],
    "bhrāṣṭrajā": ['mw'],
    "bhrāṣṭraka": ['cae', 'mw'],
    "bhrāṣṭrakaṃ": ['ap90'],
    "bhrāṣṭraki": ['mw'],
    "bhrāṣṭrakṛt": ['mw'],
    "bhrāṣṭramindha": ['mw'],
    "bhrāṣṭramiṃdha": ['ap90'],
    "bhrāṣṭravratin": ['mw'],
    "bhrāṣṭraḥ": ['ap90'],
    "bhrāṣṭreya": ['mw'],
    "bhrī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhrū": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhrūbhaṅga": ['cae', 'ddsa', 'mw'],
    "bhrūbheda": ['cae', 'mw'],
    "bhrūbhedin": ['mw'],
    "bhrūcāpākṛṣṭamukta": ['mw'],
    "bhrūjāha": ['mw'],
    "bhrūkula": ['mw'],
    "bhrūkuṃsa": ['mw'],
    "bhrūkuṃsaḥ": ['ap90'],
    "bhrūkuṃśa": ['mw'],
    "bhrūkuṃśaḥ": ['ap90'],
    "bhrūkuṭika": ['bhs'],
    "bhrūkuṭī": ['mw'],
    "bhrūkuṭībandha": ['mw'],
    "bhrūkuṭīkuṭika": ['mw'],
    "bhrūkuṭīkuṭila": ['mw'],
    "bhrūkuṭīkuṭilānana": ['mw'],
    "bhrūkuṭīmukha": ['cae', 'mw'],
    "bhrūkuṭīracanā": ['mw'],
    "bhrūkṣepa": ['cae', 'mw'],
    "bhrūkṣepajihma": ['mw'],
    "bhrūkṣepaṇa": ['mw'],
    "bhrūkṣepālāpa": ['mw'],
    "bhrūlatā": ['cae', 'mw'],
    "bhrūlatākṣepa": ['mw'],
    "bhrūmadhya": ['mw'],
    "bhrūmaṇḍala": ['mw'],
    "bhrūmukha": ['bhs'],
    "bhrūsaṃgataka": ['mw'],
    "bhrūvañcita": ['mw'],
    "bhrūvibheda": ['mw'],
    "bhrūvibhrama": ['mw'],
    "bhrūviceṣṭita": ['mw'],
    "bhrūvijṛmbha": ['mw'],
    "bhrūvijṛmbhaṇa": ['mw'],
    "bhrūvikriyā": ['mw'],
    "bhrūvikāra": ['cae', 'mw'],
    "bhrūvikṣepa": ['cae', 'mw'],
    "bhrūvikṣepam": ['mw'],
    "bhrūvilāsa": ['cae', 'mw'],
    "bhrūṇ": ['ap90', 'mw'],
    "bhrūṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "bhrūṇabhid": ['cae', 'mw'],
    "bhrūṇadheya": ['bhs'],
    "bhrūṇaghna": ['cae', 'mw'],
    "bhrūṇahan": ['cae', 'mw'],
    "bhrūṇahanana": ['mw'],
    "bhrūṇahantṛ": ['cae', 'mw'],
    "bhrūṇahati": ['mw'],
    "bhrūṇahatyā": ['mw'],
    "bhrūṇavadha": ['cae', 'mw'],
    "bhrūṇaḥ": ['ap90'],
    "bhu": ['cae', 'ddsa', 'gra', 'mw'],
    "bhudhuka": ['bhs'],
    "bhugna": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhugnadṛś": ['mw'],
    "bhugnanetra": ['mw'],
    "bhuj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhuja": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bhujabalabhīma": ['mw'],
    "bhujabalin": ['mw'],
    "bhujabandhana": ['cae', 'mw'],
    "bhujacchāyā": ['cae', 'ddsa', 'mw'],
    "bhujadala": ['mw'],
    "bhujadaṇḍa": ['cae', 'mw'],
    "bhujadaṇḍaka": ['mw'],
    "bhujaga": ['cae', 'cped', 'ddsa', 'mw'],
    "bhujagabhojin": ['mw'],
    "bhujagadāraṇa": ['mw'],
    "bhujagalatā": ['mw'],
    "bhujagapati": ['cae', 'mw'],
    "bhujagapuṣpa": ['mw'],
    "bhujagarāja": ['cae', 'mw'],
    "bhujagarājāya": ['mw'],
    "bhujagatva": ['mw'],
    "bhujagavalaya": ['mw'],
    "bhujagaśiśusṛta": ['mw'],
    "bhujagaśiśusṛtā": ['mw'],
    "bhujagaḥ": ['ap90'],
    "bhujagendra": ['cae', 'mw'],
    "bhujageśvara": ['cae', 'mw'],
    "bhujagābhojin": ['mw'],
    "bhujagāhvaya": ['mw'],
    "bhujagāntaka": ['mw'],
    "bhujagāri": ['mw'],
    "bhujagātmajā": ['cae', 'mw'],
    "bhujagāśana": ['mw'],
    "bhujagī": ['mw'],
    "bhujajyā": ['mw'],
    "bhujakoṭara": ['mw'],
    "bhujalatā": ['cae', 'mw'],
    "bhujamadhya": ['cae', 'mw'],
    "bhujamūla": ['cae', 'mw'],
    "bhujanagara": ['mw'],
    "bhujapatta": ['cped'],
    "bhujaphala": ['mw'],
    "bhujapratibhuja": ['mw'],
    "bhujarāma": ['mw'],
    "bhujasambhoga": ['mw'],
    "bhujasaṃśraya": ['mw'],
    "bhujastambha": ['cae', 'mw'],
    "bhujasūtra": ['mw'],
    "bhujataruvana": ['mw'],
    "bhujavīrya": ['mw'],
    "bhujayaṣṭi": ['cae', 'mw'],
    "bhujayoktra": ['mw'],
    "bhujaśikhara": ['mw'],
    "bhujaśiras": ['mw'],
    "bhujaśālin": ['mw'],
    "bhujaḥ": ['ap90'],
    "bhujaṃga": ['cae', 'mw'],
    "bhujaṃgabha": ['mw'],
    "bhujaṃgabhogin": ['mw'],
    "bhujaṃgabhojin": ['mw'],
    "bhujaṃgabhuj": ['mw'],
    "bhujaṃgadamanī": ['mw'],
    "bhujaṃgadīrgha": ['mw'],
    "bhujaṃgaghātinī": ['mw'],
    "bhujaṃgahan": ['mw'],
    "bhujaṃgajihvā": ['mw'],
    "bhujaṃgakanyā": ['mw'],
    "bhujaṃgalatā": ['mw'],
    "bhujaṃgama": ['cae', 'mw'],
    "bhujaṃgamamaya": ['mw'],
    "bhujaṃgamaḥ": ['ap90'],
    "bhujaṃgamā": ['mw'],
    "bhujaṃgaparṇinī": ['mw'],
    "bhujaṃgapihita": ['mw'],
    "bhujaṃgaprayāta": ['cae', 'mw'],
    "bhujaṃgaprayātastotra": ['mw'],
    "bhujaṃgaprayātāṣṭaka": ['mw'],
    "bhujaṃgapuṣpa": ['mw'],
    "bhujaṃgasaṃgatā": ['mw'],
    "bhujaṃgastotra": ['mw'],
    "bhujaṃgavijṛmbhita": ['mw'],
    "bhujaṃgaśatru": ['cae', 'mw'],
    "bhujaṃgaśiśu": ['mw'],
    "bhujaṃgaḥ": ['ap90'],
    "bhujaṃgendra": ['cae', 'mw'],
    "bhujaṃgerita": ['mw'],
    "bhujaṃgeśa": ['cae', 'mw'],
    "bhujaṃgikā": ['mw'],
    "bhujaṃgākhya": ['mw'],
    "bhujaṃgākṣī": ['mw'],
    "bhujaṃgī": ['mw'],
    "bhujaṅga": ['cped', 'ddsa'],
    "bhujaṅgama": ['cped', 'ddsa'],
    "bhuji": ['cae', 'ddsa', 'gra', 'mw'],
    "bhujissa": ['cped'],
    "bhujiḥ": ['ap90'],
    "bhujiṅga": ['mw'],
    "bhujiṣya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "bhujiṣyatā": ['bhs', 'mw'],
    "bhujiṣyā": ['mw'],
    "bhujman": ['cae', 'ddsa', 'gra', 'mw'],
    "bhujopapīḍam": ['ddsa', 'mw'],
    "bhujyu": ['cae', 'gra', 'mw'],
    "bhujyuḥ": ['ap90'],
    "bhujā": ['ap90', 'mw'],
    "bhujābhuji": ['ddsa', 'mw'],
    "bhujādala": ['mw'],
    "bhujāghāta": ['mw'],
    "bhujāgra": ['ddsa'],
    "bhujākaṇṭa": ['mw'],
    "bhujālatā": ['mw'],
    "bhujāmadhya": ['mw'],
    "bhujāmūla": ['mw'],
    "bhujāntara": ['cae', 'mw'],
    "bhujāntaram": ['mw'],
    "bhujāntarāla": ['cae', 'mw'],
    "bhujāpīḍa": ['mw'],
    "bhujāṃsadeśa": ['mw'],
    "bhujāṅka": ['mw'],
    "bhuk": ['cae', 'mw'],
    "bhukka": ['mw'],
    "bhukkabhūpāla": ['mw'],
    "bhukkaraṇa": ['cped'],
    "bhukkāra": ['cped'],
    "bhukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhuktabhoga": ['mw'],
    "bhuktabhogya": ['mw'],
    "bhuktamātre": ['cae', 'mw'],
    "bhuktapīta": ['cae', 'mw'],
    "bhuktapūrvan": ['cae'],
    "bhuktapūrvin": ['mw'],
    "bhuktasamujjhita": ['mw'],
    "bhuktasupta": ['mw'],
    "bhuktavajjane": ['mw'],
    "bhuktavant": ['cae'],
    "bhuktavat": ['mw'],
    "bhuktavibhukta": ['mw'],
    "bhuktavṛddhi": ['mw'],
    "bhuktaśeṣa": ['cae', 'mw'],
    "bhukti": ['cae', 'ddsa', 'mw'],
    "bhuktidāna": ['mw'],
    "bhuktimatī": ['mw'],
    "bhuktiprada": ['mw'],
    "bhuktiprakaraṇa": ['mw'],
    "bhuktipātra": ['mw'],
    "bhuktisaptaśatī": ['mw'],
    "bhuktivarjita": ['mw'],
    "bhuktiḥ": ['ap90'],
    "bhuktocchiṣṭa": ['ddsa', 'mw'],
    "bhuktotohiṣṭa": ['mw'],
    "bhuktvā": ['mw'],
    "bhuktvāsuhita": ['mw'],
    "bhuktāsava": ['mw'],
    "bhuktāvin": ['bhs'],
    "bhukṣa": ['bhs'],
    "bhukṣita": ['bhs'],
    "bhukṣā": ['bhs'],
    "bhumanyu": ['mw'],
    "bhumma": ['cped'],
    "bhummantara": ['cped'],
    "bhummattharaṇa": ['cped'],
    "bhummaṭṭha": ['cped'],
    "bhumī": ['bhs'],
    "bhur": ['cae', 'ddsa', 'gra', 'mw'],
    "bhuraj": ['gra', 'mw'],
    "bhuraja": ['ddsa'],
    "bhuraṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "bhuraṇy": ['cae', 'gra'],
    "bhuraṇya": ['ddsa', 'mw'],
    "bhuraṇyu": ['cae', 'ddsa', 'gra', 'mw'],
    "bhuraṇyuḥ": ['ap90'],
    "bhurbhurikā": ['ap90', 'mw'],
    "bhurbhurī": ['mw'],
    "bhurij": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhuriṣah": ['gra', 'mw'],
    "bhuriṣāh": ['gra'],
    "bhuruṇḍa": ['mw'],
    "bhurvan": ['cae', 'mw'],
    "bhurvaṇi": ['cae', 'gra', 'mw'],
    "bhusa": ['cped'],
    "bhusaṁ": ['cped'],
    "bhussamāna": ['cped'],
    "bhussanta": ['cped'],
    "bhussati": ['cped'],
    "bhussi": ['cped'],
    "bhussitvā": ['cped'],
    "bhusuka": ['mw'],
    "bhusukha": ['mw'],
    "bhusura": ['mw'],
    "bhuta": ['bhs'],
    "bhutopasṛṣṭa": ['mw'],
    "bhutta": ['cped'],
    "bhuttāvī": ['cped'],
    "bhutvā": ['cped'],
    "bhuva": ['mw'],
    "bhuvabhartṛ": ['mw'],
    "bhuvad": ['mw'],
    "bhuvadvasu": ['mw'],
    "bhuvadvat": ['ap90', 'mw'],
    "bhuvana": ['cae', 'ddsa', 'gra', 'mw'],
    "bhuvanabhartṛ": ['cae', 'mw'],
    "bhuvanabhāvana": ['cae', 'mw'],
    "bhuvanacandra": ['mw'],
    "bhuvanacarita": ['mw'],
    "bhuvanacyava": ['cae', 'gra', 'mw'],
    "bhuvanadvaya": ['cae', 'mw'],
    "bhuvanadviṣ": ['mw'],
    "bhuvanadīpa": ['mw'],
    "bhuvanadīpaka": ['mw'],
    "bhuvanadīpakaśāstra": ['mw'],
    "bhuvanadīpikā": ['mw'],
    "bhuvanahita": ['mw'],
    "bhuvanajñāna": ['mw'],
    "bhuvanakośa": ['mw'],
    "bhuvanamallavīra": ['mw'],
    "bhuvanamatī": ['mw'],
    "bhuvanamātṛ": ['mw'],
    "bhuvanapati": ['cae', 'mw'],
    "bhuvanapradīpikā": ['mw'],
    "bhuvanapratiṣṭhādānavidhi": ['mw'],
    "bhuvanapraṇetṛ": ['mw'],
    "bhuvanapāla": ['mw'],
    "bhuvanapāvana": ['mw'],
    "bhuvanapāvanī": ['mw'],
    "bhuvanarāja": ['mw'],
    "bhuvanasad": ['mw'],
    "bhuvanatala": ['cae', 'mw'],
    "bhuvanatraya": ['cae', 'mw'],
    "bhuvanaukas": ['mw'],
    "bhuvanavidita": ['mw'],
    "bhuvanavinyāsa": ['mw'],
    "bhuvanavṛttānta": ['mw'],
    "bhuvanaśāsin": ['mw'],
    "bhuvanaṃ": ['ap90'],
    "bhuvaneśa": ['cae', 'mw'],
    "bhuvaneśvara": ['cae', 'mw'],
    "bhuvaneśvaramāhātmya": ['mw'],
    "bhuvaneśvaryarcanapaddhati": ['mw'],
    "bhuvaneśvarī": ['mw'],
    "bhuvaneśvarīdaṇḍaka": ['mw'],
    "bhuvaneśvarīdīpadāna": ['mw'],
    "bhuvaneśvarīkakṣapuṭatantra": ['mw'],
    "bhuvaneśvarīkalpa": ['mw'],
    "bhuvaneśvarīkavaca": ['mw'],
    "bhuvaneśvarīpaddhati": ['mw'],
    "bhuvaneśvarīpañcāṅga": ['mw'],
    "bhuvaneśvarīpaṭala": ['mw'],
    "bhuvaneśvarīpūjāyantra": ['mw'],
    "bhuvaneśvarīrahasya": ['mw'],
    "bhuvaneśvarīsahasranāman": ['mw'],
    "bhuvaneśvarīsahasranāmastotra": ['mw'],
    "bhuvaneśvarīstotra": ['mw'],
    "bhuvaneśvarīvarivasyārahasya": ['mw'],
    "bhuvaneśvarīśāntiprayoga": ['mw'],
    "bhuvaneśānī": ['mw'],
    "bhuvaneśī": ['mw'],
    "bhuvaneśīpārijāta": ['mw'],
    "bhuvaneśīyantra": ['mw'],
    "bhuvaneṣṭhā": ['cae', 'mw'],
    "bhuvanti": ['mw'],
    "bhuvanyuḥ": ['ap90'],
    "bhuvanābhyudaya": ['mw'],
    "bhuvanādbhuta": ['mw'],
    "bhuvanādhīśa": ['mw'],
    "bhuvanādhīśvara": ['mw'],
    "bhuvanālokana": ['mw'],
    "bhuvanānanda": ['mw'],
    "bhuvanāṇḍaka": ['ddsa', 'mw'],
    "bhuvapati": ['mw'],
    "bhuvar": ['ap90'],
    "bhuvas": ['cae', 'ddsa', 'mw'],
    "bhuvat": ['ddsa'],
    "bhuvaḥ": ['ap90'],
    "bhuvi": ['mw'],
    "bhuvis": ['ap90', 'mw'],
    "bhuvispṛś": ['mw'],
    "bhuviṣṭha": ['cae', 'ddsa', 'mw'],
    "bhuvādivarṇana": ['mw'],
    "bhuyo": ['bhs'],
    "bhuyya": ['ddsa', 'mw'],
    "bhuñjaka": ['cped'],
    "bhuñjamāna": ['cped'],
    "bhuñjana": ['cped'],
    "bhuñjanakāla": ['cped'],
    "bhuñjanta": ['cped'],
    "bhuñjati": ['cped'],
    "bhuñji": ['cped'],
    "bhuñjitabba": ['cped'],
    "bhuñjitar": ['cped'],
    "bhuñjituṁ": ['cped'],
    "bhuñjitvā": ['cped'],
    "bhuñjiya": ['cped'],
    "bhuñjāpaya": ['ddsa', 'mw'],
    "bhuśuṃḍiḥ": ['ap90'],
    "bhuśuṇḍa": ['mw'],
    "bhuśuṇḍi": ['cae', 'mw'],
    "bhuśuṇḍī": ['cae', 'mw'],
    "bhuḍhuka": ['bhs'],
    "bhuḍḍa": ['mw'],
    "bhuḥkhāra": ['ddsa', 'mw'],
    "bhuṃḍ": ['ap90'],
    "bhuṅ": ['mw'],
    "bhuṅkaraṇa": ['cped'],
    "bhuṅkari": ['cped'],
    "bhuṅkaritvā": ['cped'],
    "bhuṅkaronta": ['cped'],
    "bhuṅkaroti": ['cped'],
    "bhuṅkata": ['cped'],
    "bhuṅkatvā": ['cped'],
    "bhuṅkāra": ['cped'],
    "bhuṇika": ['mw'],
    "bhuṇḍ": ['mw'],
    "bhuṭva": ['mw'],
    "bhuṭṭa": ['ddsa', 'mw'],
    "bhuṭṭapura": ['mw'],
    "bhuṭṭeśvara": ['mw'],
    "bhva": ['mw'],
    "bhyas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhyasa": ['mw'],
    "bhā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhādiga": ['mw'],
    "bhādra": ['cae', 'ddsa', 'mw'],
    "bhādrabāhavī": ['mw'],
    "bhādrabāheya": ['mw'],
    "bhādradārava": ['mw'],
    "bhādramauñja": ['mw'],
    "bhādramātura": ['mw'],
    "bhādramāturaḥ": ['ap90'],
    "bhādrapada": ['cae', 'mw'],
    "bhādrapadā": ['mw'],
    "bhādrapadī": ['ap90', 'mw'],
    "bhādrasāma": ['mw'],
    "bhādravarmaṇa": ['mw'],
    "bhādraśarmi": ['mw'],
    "bhādraḥ": ['ap90'],
    "bhādrī": ['mw'],
    "bhāga": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhāgabhuj": ['mw'],
    "bhāgabhāj": ['cae', 'mw'],
    "bhāgadha": ['mw'],
    "bhāgadheya": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhāgadheyya": ['cped'],
    "bhāgadhā": ['mw'],
    "bhāgadhāna": ['mw'],
    "bhāgadugha": ['cae', 'mw'],
    "bhāgadā": ['mw'],
    "bhāgahara": ['cae', 'mw'],
    "bhāgahāra": ['mw'],
    "bhāgahārin": ['cae', 'mw'],
    "bhāgajāti": ['mw'],
    "bhāgajāticatuṣṭaya": ['mw'],
    "bhāgaka": ['mw'],
    "bhāgakalpanā": ['mw'],
    "bhāgakaḥ": ['ap90'],
    "bhāgala": ['mw'],
    "bhāgalaka": ['mw'],
    "bhāgalakṣaṇā": ['cae', 'mw'],
    "bhāgaleya": ['mw'],
    "bhāgali": ['mw'],
    "bhāgamukha": ['mw'],
    "bhāgamātṛ": ['mw'],
    "bhāganaṃ": ['ap90'],
    "bhāgapāṭha": ['mw'],
    "bhāgaso": ['cped'],
    "bhāgavant": ['cped'],
    "bhāgavata": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāgavatacampū": ['mw'],
    "bhāgavatacandracandrikā": ['mw'],
    "bhāgavatacūrṇikā": ['mw'],
    "bhāgavatakathāsaṃgraha": ['mw'],
    "bhāgavatakaumudī": ['mw'],
    "bhāgavatakramasaṃdarbha": ['mw'],
    "bhāgavatamuktāphala": ['mw'],
    "bhāgavatamāhātmya": ['mw'],
    "bhāgavatanibandhayojanā": ['mw'],
    "bhāgavatapadyatrayīvyākhyāna": ['mw'],
    "bhāgavatapurāṇa": ['cae', 'mw'],
    "bhāgavatapurāṇabandhana": ['mw'],
    "bhāgavatapurāṇabhāvārthadīpikāprakaraṇakramasaṃgraha": ['mw'],
    "bhāgavatapurāṇabhāvārthadīpikāsaṃgraha": ['mw'],
    "bhāgavatapurāṇabhūṣaṇa": ['mw'],
    "bhāgavatapurāṇabṛhatsaṃgraha": ['mw'],
    "bhāgavatapurāṇakroḍapattra": ['mw'],
    "bhāgavatapurāṇamahāvivaraṇa": ['mw'],
    "bhāgavatapurāṇamañjarī": ['mw'],
    "bhāgavatapurāṇaprakāśa": ['mw'],
    "bhāgavatapurāṇaprasaṅgadṛṣṭāntāvalī": ['mw'],
    "bhāgavatapurāṇaprathamaślokatrayīṭīkā": ['mw'],
    "bhāgavatapurāṇaprāmāṇya": ['mw'],
    "bhāgavatapurāṇasvarūpaviṣayakaśaṅkānirāsa": ['mw'],
    "bhāgavatapurāṇasārārthadarśinī": ['mw'],
    "bhāgavatapurāṇasūcikā": ['mw'],
    "bhāgavatapurāṇatattvasaṃgraha": ['mw'],
    "bhāgavatapurāṇādyaślokatrayīṭīkā": ['mw'],
    "bhāgavatapurāṇārkaprabhā": ['mw'],
    "bhāgavatarahasya": ['mw'],
    "bhāgavatasamuccayesahasranāmastotra": ['mw'],
    "bhāgavatasaptāhānukramaṇikā": ['mw'],
    "bhāgavatasaṃdarbha": ['mw'],
    "bhāgavatasaṃgraha": ['mw'],
    "bhāgavatasaṃkṣepavyākhyā": ['mw'],
    "bhāgavatasiddhāntasaṃgraha": ['mw'],
    "bhāgavatastotra": ['mw'],
    "bhāgavatasāra": ['mw'],
    "bhāgavatasārasamuccaya": ['mw'],
    "bhāgavatasārasaṃgraha": ['mw'],
    "bhāgavatatattvabhāskara": ['mw'],
    "bhāgavatatattvadipaprakāśāvaraṇabhaṅga": ['mw'],
    "bhāgavatatattvadīpa": ['mw'],
    "bhāgavatatattvasāra": ['mw'],
    "bhāgavatatātparya": ['mw'],
    "bhāgavatatātparyanirṇaya": ['mw'],
    "bhāgavatavāditoṣiṇī": ['mw'],
    "bhāgavataśrutigītā": ['mw'],
    "bhāgavati": ['mw'],
    "bhāgavatotpala": ['mw'],
    "bhāgavatāmṛta": ['mw'],
    "bhāgavatāmṛtakaṇikā": ['mw'],
    "bhāgavatāṣṭaka": ['mw'],
    "bhāgavatī": ['bhs', 'mw'],
    "bhāgavatīmatapaddhati": ['mw'],
    "bhāgavatīmāhātmya": ['mw'],
    "bhāgavatīsaṃhitā": ['mw'],
    "bhāgavijñeya": ['mw'],
    "bhāgavitta": ['mw'],
    "bhāgavitti": ['mw'],
    "bhāgavittika": ['mw'],
    "bhāgavittikīya": ['mw'],
    "bhāgavittāyana": ['mw'],
    "bhāgaviveka": ['mw'],
    "bhāgavṛtti": ['mw'],
    "bhāgavṛttikāra": ['mw'],
    "bhāgayati": ['bhs'],
    "bhāgaśas": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāgaḥ": ['ap90'],
    "bhāgaṃjaya": ['mw'],
    "bhāgaṇa": ['mw'],
    "bhāgika": ['ap90', 'ddsa', 'mw'],
    "bhāgin": ['ap90', 'cae', 'mw'],
    "bhāgineya": ['cae', 'ddsa', 'mw'],
    "bhāgineyaka": ['cae', 'mw'],
    "bhāgineyaḥ": ['ap90'],
    "bhāgineyya": ['cped'],
    "bhāgineyyā": ['cped'],
    "bhāgineyī": ['mw'],
    "bhāginī": ['mw'],
    "bhāgiya": ['cped'],
    "bhāgupta": ['bhs'],
    "bhāguri": ['cae', 'ddsa', 'mw'],
    "bhāgurāyaṇa": ['mw'],
    "bhāgurī": ['mw'],
    "bhāguṇimiśra": ['mw'],
    "bhāgya": ['cae', 'cped', 'ddsa', 'mw'],
    "bhāgyabhāva": ['mw'],
    "bhāgyakrama": ['cae'],
    "bhāgyakrameṇa": ['mw'],
    "bhāgyapañca": ['mw'],
    "bhāgyarahita": ['cae', 'mw'],
    "bhāgyarkṣa": ['mw'],
    "bhāgyasampad": ['mw'],
    "bhāgyasamṛddhi": ['mw'],
    "bhāgyasaṃkṣaya": ['mw'],
    "bhāgyavaiṣamya": ['mw'],
    "bhāgyavant": ['cae'],
    "bhāgyavat": ['ap90', 'mw'],
    "bhāgyavattā": ['cae', 'mw'],
    "bhāgyavaśa": ['cae'],
    "bhāgyavaśāt": ['mw'],
    "bhāgyaviparyaya": ['mw'],
    "bhāgyaviplava": ['mw'],
    "bhāgyavṛtti": ['mw'],
    "bhāgyayoga": ['mw'],
    "bhāgyaṃ": ['ap90'],
    "bhāgyena": ['mw'],
    "bhāgyodaya": ['cae', 'mw'],
    "bhāgyāyatta": ['mw'],
    "bhāgānubandhajāti": ['mw'],
    "bhāgānubhāgena": ['cae', 'mw'],
    "bhāgāpahārin": ['cae'],
    "bhāgāpavāhajāti": ['mw'],
    "bhāgāpavāhana": ['mw'],
    "bhāgārha": ['mw'],
    "bhāgārthin": ['cae', 'mw'],
    "bhāgāsura": ['mw'],
    "bhāgī": ['cped'],
    "bhāgīkṛ": ['ddsa', 'mw'],
    "bhāgīratha": ['bhs', 'cae', 'ddsa', 'mw'],
    "bhāgīrathatīrtha": ['mw'],
    "bhāgīrathī": ['ap90', 'cped', 'mw'],
    "bhāgīrathīcampū": ['mw'],
    "bhāgīrathīnātha": ['mw'],
    "bhāgīrathīprārthana": ['mw'],
    "bhāgīrathīvallabha": ['mw'],
    "bhāgīya": ['bhs', 'mw'],
    "bhāgīyaka": ['bhs'],
    "bhāgīyas": ['mw'],
    "bhāj": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhājak": ['mw'],
    "bhājaka": ['bhs', 'cped', 'mw'],
    "bhājakaḥ": ['ap90'],
    "bhājana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bhājanacārika": ['bhs', 'mw'],
    "bhājanaka": ['bhs'],
    "bhājanaloka": ['mw'],
    "bhājanatva": ['mw'],
    "bhājanatā": ['mw'],
    "bhājanavat": ['mw'],
    "bhājanavikati": ['cped'],
    "bhājanavārika": ['bhs', 'mw'],
    "bhājanaṃ": ['ap90'],
    "bhājanena": ['mw'],
    "bhājanībhū": ['ddsa'],
    "bhājanībhūta": ['mw'],
    "bhājayu": ['cae', 'gra', 'mw'],
    "bhājenta": ['cped'],
    "bhājesi": ['cped'],
    "bhājetabba": ['cped'],
    "bhājetar": ['cped'],
    "bhājeti": ['cped'],
    "bhājetvā": ['cped'],
    "bhājin": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhājita": ['ap90', 'cped', 'mw'],
    "bhājya": ['ap90', 'cae', 'mw'],
    "bhājā": ['mw'],
    "bhājī": ['ap90', 'mw'],
    "bhājīyati": ['cped'],
    "bhākośa": ['mw'],
    "bhākrama": ['bhs'],
    "bhākta": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāktika": ['mw'],
    "bhāktikaḥ": ['ap90'],
    "bhāktva": ['mw'],
    "bhākuri": ['mw'],
    "bhākuṭika": ['cped'],
    "bhākūṭa": ['mw'],
    "bhākṣa": ['ap90', 'mw'],
    "bhākṣālaka": ['mw'],
    "bhāla": ['cae', 'ddsa', 'mw'],
    "bhālacandra": ['mw'],
    "bhālacandrācārya": ['mw'],
    "bhāladarśana": ['mw'],
    "bhāladarśin": ['mw'],
    "bhāladṛś": ['mw'],
    "bhālakṛt": ['mw'],
    "bhālalocana": ['mw'],
    "bhālanayana": ['mw'],
    "bhālandana": ['mw'],
    "bhālandanaka": ['mw'],
    "bhālavibhūṣaṇa": ['mw'],
    "bhālayānandācārya": ['mw'],
    "bhālaṃ": ['ap90'],
    "bhālla": ['mw'],
    "bhāllakīya": ['mw'],
    "bhāllapāleya": ['mw'],
    "bhāllaveya": ['mw'],
    "bhāllaveyaśruti": ['mw'],
    "bhāllaveyopaniṣad": ['mw'],
    "bhāllavi": ['mw'],
    "bhāllavibrāhmaṇa": ['mw'],
    "bhāllaviśruti": ['mw'],
    "bhāllaviśākhā": ['mw'],
    "bhāllavyupaniṣad": ['mw'],
    "bhālleya": ['mw'],
    "bhālluka": ['mw'],
    "bhāllūka": ['mw'],
    "bhālu": ['mw'],
    "bhāluka": ['mw'],
    "bhālukaḥ": ['ap90'],
    "bhāluki": ['ddsa', 'mw'],
    "bhālukin": ['mw'],
    "bhāluḥ": ['ap90'],
    "bhālāṅka": ['mw'],
    "bhālūka": ['mw'],
    "bhām": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhāma": ['cae', 'ddsa', 'gra', 'mw'],
    "bhāmaha": ['cae', 'mw'],
    "bhāmaka": ['mw'],
    "bhāmakanakamuni": ['bhs'],
    "bhāmanī": ['mw'],
    "bhāmatī": ['mw'],
    "bhāmatīkāra": ['mw'],
    "bhāmatītilaka": ['mw'],
    "bhāmatīvilāsa": ['mw'],
    "bhāmaḥ": ['ap90'],
    "bhāmaṇḍala": ['mw'],
    "bhāmin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhāminī": ['ap90', 'mw'],
    "bhāminīvilāsa": ['cae', 'mw'],
    "bhāmita": ['cae', 'mw'],
    "bhāmā": ['mw'],
    "bhāna": ['bhs', 'cae', 'ddsa', 'mw'],
    "bhānaka": ['bhs'],
    "bhānatas": ['mw'],
    "bhānava": ['cae', 'ddsa', 'mw'],
    "bhānavat": ['mw'],
    "bhānavī": ['mw'],
    "bhānavīya": ['cae', 'mw'],
    "bhānaṃ": ['ap90'],
    "bhānda": ['mw'],
    "bhānemi": ['mw'],
    "bhānikara": ['mw'],
    "bhānta": ['mw'],
    "bhānu": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhānubhṛt": ['mw'],
    "bhānucandra": ['mw'],
    "bhānucandragaṇi": ['mw'],
    "bhānucaritra": ['mw'],
    "bhānudatta": ['mw'],
    "bhānudattaka": ['mw'],
    "bhānudeva": ['mw'],
    "bhānudina": ['mw'],
    "bhānuja": ['ddsa', 'mw'],
    "bhānuji": ['mw'],
    "bhānujit": ['mw'],
    "bhānukara": ['mw'],
    "bhānukesara": ['mw'],
    "bhānula": ['mw'],
    "bhānumant": ['cae'],
    "bhānumantu": ['cped'],
    "bhānumat": ['ap90', 'ddsa', 'gra', 'mw'],
    "bhānumataliṅgaśāstra": ['mw'],
    "bhānumataśilpaśāstra": ['mw'],
    "bhānumatin": ['mw'],
    "bhānumatī": ['mw'],
    "bhānumatīpariṇaya": ['mw'],
    "bhānumaya": ['mw'],
    "bhānumitra": ['cae', 'mw'],
    "bhānunātha": ['mw'],
    "bhānupaṇḍita": ['mw'],
    "bhānuphalā": ['mw'],
    "bhānuprabandha": ['mw'],
    "bhānuprabhā": ['bhs'],
    "bhānuratha": ['cae', 'mw'],
    "bhānusena": ['mw'],
    "bhānutā": ['mw'],
    "bhānuvana": ['mw'],
    "bhānuvant": ['bhs'],
    "bhānuvarman": ['mw'],
    "bhānuvāra": ['mw'],
    "bhānuśaktirāja": ['mw'],
    "bhānuḥ": ['ap90'],
    "bhānuṣeṇa": ['mw'],
    "bhāra": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhārabhārin": ['cae', 'mw'],
    "bhārabhūtitīrtha": ['mw'],
    "bhārabhṛt": ['cae', 'gra', 'mw'],
    "bhāradaṇḍa": ['mw'],
    "bhāradvāja": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "bhāradvājagārgyapariṇayapratiṣedhavādārtha": ['mw'],
    "bhāradvājaka": ['mw'],
    "bhāradvājakī": ['mw'],
    "bhāradvājaprayoga": ['mw'],
    "bhāradvājasaṃhitā": ['mw'],
    "bhāradvājaśikṣā": ['mw'],
    "bhāradvājaśrāddhakāṇḍavyākhyā": ['mw'],
    "bhāradvājaḥ": ['ap90'],
    "bhāradvājin": ['cae', 'ddsa', 'mw'],
    "bhāradvājāgnisaṃdhānādismārtaprayoga": ['mw'],
    "bhāradvājāyana": ['mw'],
    "bhāradvājī": ['mw'],
    "bhāradvājīputra": ['mw'],
    "bhāradvājīya": ['cae', 'mw'],
    "bhāraga": ['mw'],
    "bhārahara": ['mw'],
    "bhārahāra": ['cped'],
    "bhārahārika": ['mw'],
    "bhārahārin": ['mw'],
    "bhārajīvin": ['mw'],
    "bhāraka": ['ap90', 'ddsa', 'mw'],
    "bhārakṣama": ['mw'],
    "bhārama": ['mw'],
    "bhārameya": ['mw'],
    "bhāramocana": ['cped'],
    "bhāranikkhepana": ['cped'],
    "bhārapratyavara": ['ddsa', 'mw'],
    "bhārasaha": ['cae', 'ddsa', 'mw'],
    "bhārasādhana": ['cae', 'mw'],
    "bhārasādhin": ['cae', 'mw'],
    "bhārata": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhāratabhāvadīpa": ['mw'],
    "bhāratacampū": ['mw'],
    "bhāratakarṇa": ['mw'],
    "bhāratamañjarī": ['mw'],
    "bhāratamālākośa": ['mw'],
    "bhāratanirvacana": ['mw'],
    "bhāratapadaprakāśa": ['mw'],
    "bhāratara": ['mw'],
    "bhāratasattama": ['mw'],
    "bhāratasaṃgrahadīpikā": ['mw'],
    "bhāratasāvitrī": ['mw'],
    "bhāratasāvitrīstotra": ['mw'],
    "bhāratasūci": ['mw'],
    "bhāratasūtra": ['mw'],
    "bhāratatātparyanirṇaya": ['mw'],
    "bhāratatātparyasaṃgraha": ['mw'],
    "bhāratavarṣa": ['mw'],
    "bhāratavyākhyā": ['mw'],
    "bhārataśravaṇavidhi": ['mw'],
    "bhārateya": ['mw'],
    "bhāratācārya": ['mw'],
    "bhāratārthadīpikā": ['mw'],
    "bhāratārthaprakāśa": ['mw'],
    "bhāratī": ['gra', 'mw'],
    "bhāratīcandra": ['mw'],
    "bhāratīkavi": ['mw'],
    "bhāratīkṛṣṇācārya": ['mw'],
    "bhāratīnīrājana": ['mw'],
    "bhāratītīrtha": ['mw'],
    "bhāratītīrthīya": ['mw'],
    "bhāratīvat": ['ddsa', 'mw'],
    "bhāratīya": ['cae', 'mw'],
    "bhāratīyati": ['mw'],
    "bhāratīśrīnṛsiṃha": ['mw'],
    "bhārauhī": ['mw'],
    "bhārava": ['mw'],
    "bhāravah": ['mw'],
    "bhāravaha": ['mw'],
    "bhāravant": ['cae'],
    "bhāravat": ['mw'],
    "bhāravattva": ['mw'],
    "bhāravaṃ": ['ap90'],
    "bhāravi": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāraviḥ": ['ap90'],
    "bhāravoḍhṛ": ['mw'],
    "bhāravāha": ['cae', 'mw'],
    "bhāravāhaka": ['mw'],
    "bhāravāhana": ['cae', 'mw'],
    "bhāravāhika": ['mw'],
    "bhāravāhin": ['cae', 'mw'],
    "bhāravāhī": ['cped', 'mw'],
    "bhāravī": ['mw'],
    "bhāravṛkṣa": ['mw'],
    "bhāraya": ['mw'],
    "bhārayaḥ": ['ap90'],
    "bhārayaṣṭi": ['mw'],
    "bhāraśṛṅga": ['mw'],
    "bhāraḍasāman": ['mw'],
    "bhāraḥ": ['ap90'],
    "bhāraṃgī": ['ap90'],
    "bhāraṃḍaḥ": ['ap90'],
    "bhāraṅgika": ['mw'],
    "bhāraṅgī": ['mw'],
    "bhāraṇḍa": ['ddsa', 'mw'],
    "bhāraṇḍī": ['mw'],
    "bhārdvājī": ['mw'],
    "bhārga": ['cae', 'mw'],
    "bhārgabhūmi": ['mw'],
    "bhārgaleśvaratīrtha": ['mw'],
    "bhārgava": ['bhs', 'cae', 'ddsa', 'mw'],
    "bhārgavabhūmi": ['mw'],
    "bhārgavacampū": ['mw'],
    "bhārgavadīpikā": ['mw'],
    "bhārgavagraha": ['cae'],
    "bhārgavaka": ['mw'],
    "bhārgavakalpavallīcakravidyārahasya": ['mw'],
    "bhārgavamuhūrta": ['mw'],
    "bhārgavana": ['mw'],
    "bhārgavanāmasahasra": ['mw'],
    "bhārgavapañcāṅga": ['mw'],
    "bhārgavapriya": ['mw'],
    "bhārgavapurāṇa": ['mw'],
    "bhārgavarāghavīya": ['mw'],
    "bhārgavarāma": ['mw'],
    "bhārgavasarvasva": ['mw'],
    "bhārgavasūtra": ['mw'],
    "bhārgavaśreṣṭha": ['mw'],
    "bhārgavaḥ": ['ap90'],
    "bhārgavopapurāṇa": ['mw'],
    "bhārgavopākhyāna": ['mw'],
    "bhārgavārcanacandrikā": ['mw'],
    "bhārgavārcanadīpikā": ['mw'],
    "bhārgavāya": ['mw'],
    "bhārgavī": ['ap90', 'mw'],
    "bhārgavīya": ['ddsa', 'mw'],
    "bhārgaśrīkāntamiśra": ['mw'],
    "bhārgaḥ": ['ap90'],
    "bhārgi": ['mw'],
    "bhārgāyaṇa": ['cae', 'mw'],
    "bhārgī": ['mw'],
    "bhāri": ['mw'],
    "bhārika": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bhārikā": ['mw'],
    "bhārin": ['cae', 'mw'],
    "bhāritva": ['mw'],
    "bhāriya": ['cped'],
    "bhāriḥ": ['ap90'],
    "bhārman": ['cae', 'gra', 'mw'],
    "bhārmya": ['ddsa', 'mw'],
    "bhārmyaśva": ['ddsa', 'mw'],
    "bhāroddharaṇa": ['mw'],
    "bhārodvaha": ['ddsa', 'mw'],
    "bhāropajīvana": ['mw'],
    "bhāroḍhi": ['mw'],
    "bhāru": ['mw'],
    "bhāruci": ['mw'],
    "bhārujika": ['mw'],
    "bhāruṇḍa": ['mw'],
    "bhāruṣa": ['mw'],
    "bhārvara": ['gra', 'mw'],
    "bhārya": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāryaka": ['mw'],
    "bhāryaram": ['bhs'],
    "bhāryoḍha": ['mw'],
    "bhāryā": ['ap90', 'mw'],
    "bhāryācela": ['mw'],
    "bhāryādhikārika": ['mw'],
    "bhāryādrohin": ['cae', 'mw'],
    "bhāryājita": ['ddsa', 'mw'],
    "bhāryāka": ['bhs'],
    "bhāryāpati": ['mw'],
    "bhāryāpatitva": ['mw'],
    "bhāryārthin": ['mw'],
    "bhāryāru": ['mw'],
    "bhāryāruḥ": ['ap90'],
    "bhāryāsama": ['mw'],
    "bhāryāsauśruta": ['mw'],
    "bhāryātva": ['cae', 'mw'],
    "bhāryāvant": ['cae'],
    "bhāryāvat": ['mw'],
    "bhāryāvṛkṣa": ['mw'],
    "bhāryāṭa": ['mw'],
    "bhāryāṭika": ['mw'],
    "bhārākrānta": ['cae', 'mw'],
    "bhārākrāntā": ['mw'],
    "bhārāvataraṇa": ['mw'],
    "bhārāvatāraṇa": ['mw'],
    "bhārāya": ['ddsa', 'mw'],
    "bhārāyate": ['ap90'],
    "bhārīṭa": ['mw'],
    "bhārśya": ['mw'],
    "bhārśyaṃ": ['ap90'],
    "bhārūjika": ['mw'],
    "bhārūpa": ['cae', 'mw'],
    "bhār̥jīka": ['ddsa'],
    "bhārṅgī": ['mw'],
    "bhārṇikārdami": ['mw'],
    "bhās": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhāsa": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāsada": ['cae', 'gra', 'mw'],
    "bhāsaka": ['ap90', 'cae', 'mw'],
    "bhāsakarṇa": ['mw'],
    "bhāsakatva": ['mw'],
    "bhāsana": ['cae', 'cped', 'mw'],
    "bhāsanaṃ": ['ap90'],
    "bhāsanta": ['cped', 'mw'],
    "bhāsantara": ['cped'],
    "bhāsantī": ['mw'],
    "bhāsarvajña": ['mw'],
    "bhāsas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhāsati": ['cped'],
    "bhāsatā": ['ap90', 'cae', 'mw'],
    "bhāsavilāsasaṃvāda": ['mw'],
    "bhāsaḥ": ['ap90'],
    "bhāsaṃta": ['ap90'],
    "bhāsi": ['cped'],
    "bhāsin": ['cae', 'ddsa', 'mw'],
    "bhāsinikā": ['bhs'],
    "bhāsita": ['cae', 'cped'],
    "bhāsitabba": ['cped'],
    "bhāsitar": ['cped'],
    "bhāsitvā": ['cped'],
    "bhāskara": ['cae', 'ddsa', 'mw'],
    "bhāskarabhāṣya": ['mw'],
    "bhāskaracaritra": ['mw'],
    "bhāskaradeva": ['bhs', 'mw'],
    "bhāskaradina": ['mw'],
    "bhāskarakaṇṭha": ['mw'],
    "bhāskaralavaṇa": ['mw'],
    "bhāskaranandin": ['cae', 'mw'],
    "bhāskaranṛsiṃha": ['mw'],
    "bhāskarapradīpa": ['bhs'],
    "bhāskarapriya": ['mw'],
    "bhāskaraputravāsara": ['mw'],
    "bhāskararāya": ['mw'],
    "bhāskarasaptamī": ['mw'],
    "bhāskarasena": ['mw'],
    "bhāskarastotra": ['mw'],
    "bhāskaravarman": ['mw'],
    "bhāskaravat": ['mw'],
    "bhāskaravrata": ['mw'],
    "bhāskaraśarman": ['mw'],
    "bhāskaraśiṣya": ['mw'],
    "bhāskaraṇa": ['mw'],
    "bhāskareṣṭā": ['mw'],
    "bhāskari": ['mw'],
    "bhāskarācārya": ['mw'],
    "bhāskarāhnika": ['mw'],
    "bhāskarāvarta": ['mw'],
    "bhāskarīya": ['mw'],
    "bhāskhara": ['mw'],
    "bhāsmana": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāsmāyana": ['mw'],
    "bhāsmāyanya": ['mw'],
    "bhāsoka": ['mw'],
    "bhāspati": ['mw'],
    "bhāspheru": ['mw'],
    "bhāstrāyaṇa": ['mw'],
    "bhāstrāyaṇaka": ['mw'],
    "bhāsu": ['mw'],
    "bhāsura": ['ap90', 'cped', 'mw'],
    "bhāsuradeha": ['cae', 'mw'],
    "bhāsurahemarāśi": ['mw'],
    "bhāsuraka": ['mw'],
    "bhāsuramūrti": ['mw'],
    "bhāsurapuṣpā": ['mw'],
    "bhāsuratva": ['mw'],
    "bhāsurānandanātha": ['mw'],
    "bhāsuḥ": ['ap90'],
    "bhāsvant": ['cae'],
    "bhāsvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāsvaravarṇa": ['mw'],
    "bhāsvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "bhāsvatī": ['mw'],
    "bhāsvatīkaraṇa": ['mw'],
    "bhāsvatīvivaraṇa": ['mw'],
    "bhāsya": ['cae', 'ddsa', 'mw'],
    "bhāsyasūtra": ['mw'],
    "bhāsyatva": ['mw'],
    "bhāsā": ['cped'],
    "bhāsāketu": ['ddsa', 'gra', 'mw'],
    "bhāsāya": ['mw'],
    "bhāsī": ['cped', 'mw'],
    "bhāsṛjīka": ['gra'],
    "bhāta": ['ap90', 'mw'],
    "bhātar": ['cped'],
    "bhāti": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bhātika": ['cped'],
    "bhātiḥ": ['ap90'],
    "bhātu": ['mw'],
    "bhātvakṣas": ['cae', 'gra', 'mw'],
    "bhātvakṣās": ['ddsa'],
    "bhāulācārya": ['mw'],
    "bhāva": ['cae', 'cped', 'ddsa', 'mw'],
    "bhāvabala": ['mw'],
    "bhāvabandhana": ['cae', 'mw'],
    "bhāvabhaṭṭa": ['mw'],
    "bhāvabodha": ['mw'],
    "bhāvabodhaka": ['mw'],
    "bhāvacandrikā": ['mw'],
    "bhāvaceṣṭita": ['mw'],
    "bhāvacintā": ['mw'],
    "bhāvacintāmaṇi": ['mw'],
    "bhāvacūḍāmaṇi": ['mw'],
    "bhāvadarśin": ['mw'],
    "bhāvadevī": ['mw'],
    "bhāvadharmagaṇi": ['mw'],
    "bhāvadyotanikā": ['mw'],
    "bhāvadāsa": ['mw'],
    "bhāvadīpa": ['mw'],
    "bhāvadīpikā": ['mw'],
    "bhāvagambhīram": ['mw'],
    "bhāvagamya": ['mw'],
    "bhāvagarhā": ['mw'],
    "bhāvagrantha": ['mw'],
    "bhāvagrāhin": ['mw'],
    "bhāvagrāhya": ['mw'],
    "bhāvaguptiśataka": ['mw'],
    "bhāvaikarasa": ['mw'],
    "bhāvaja": ['mw'],
    "bhāvajña": ['mw'],
    "bhāvajñā": ['mw'],
    "bhāvaka": ['ap90', 'cae', 'mw'],
    "bhāvakalpa": ['mw'],
    "bhāvakalpalatā": ['mw'],
    "bhāvakarman": ['mw'],
    "bhāvakartṛka": ['cae', 'mw'],
    "bhāvakaumudī": ['mw'],
    "bhāvakeralīya": ['mw'],
    "bhāvakā": ['mw'],
    "bhāvalavavyākhyā": ['mw'],
    "bhāvaleśaprakāśikā": ['mw'],
    "bhāvalā": ['mw'],
    "bhāvamadhura": ['cae', 'mw'],
    "bhāvamiśra": ['cae', 'mw'],
    "bhāvana": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "bhāvanatā": ['bhs'],
    "bhāvanayā": ['mw'],
    "bhāvaneri": ['mw'],
    "bhāvanikā": ['ddsa', 'mw'],
    "bhāvanopaniṣad": ['mw'],
    "bhāvanā": ['bhs', 'cped', 'mw'],
    "bhāvanāmaya": ['cped', 'mw'],
    "bhāvanāmayī": ['mw'],
    "bhāvanāmārga": ['mw'],
    "bhāvanānuyoga": ['cped'],
    "bhāvanāpuruṣottamanāṭaka": ['mw'],
    "bhāvanārāyaṇamāhātmya": ['mw'],
    "bhāvanāsārasaṃgraha": ['mw'],
    "bhāvanātha": ['mw'],
    "bhāvanāvicāra": ['mw'],
    "bhāvanāvidhāna": ['cped'],
    "bhāvanāviveka": ['mw'],
    "bhāvanāyukta": ['mw'],
    "bhāvanāśraya": ['mw'],
    "bhāvanīya": ['cae', 'cped', 'ddsa', 'mw'],
    "bhāvapadārtha": ['mw'],
    "bhāvaphala": ['mw'],
    "bhāvaphalādhyāya": ['mw'],
    "bhāvaprabodhinī": ['mw'],
    "bhāvapradīpa": ['mw'],
    "bhāvapradīpikā": ['mw'],
    "bhāvapradīpoddyota": ['mw'],
    "bhāvaprakāśa": ['mw'],
    "bhāvaprakāśaka": ['mw'],
    "bhāvaprakāśakośa": ['mw'],
    "bhāvaprakāśanighaṇṭu": ['mw'],
    "bhāvaprakāśikā": ['mw'],
    "bhāvapratidūṣita": ['ddsa'],
    "bhāvapratyayavādārtha": ['mw'],
    "bhāvapratyayaśaktivicāra": ['mw'],
    "bhāvapuṣpa": ['mw'],
    "bhāvapāda": ['mw'],
    "bhāvarahasyasāmānya": ['mw'],
    "bhāvaratna": ['mw'],
    "bhāvaratnakośa": ['mw'],
    "bhāvaratnasamuccaya": ['mw'],
    "bhāvarāmakṛṣṇa": ['mw'],
    "bhāvarūpa": ['cae', 'ddsa', 'mw'],
    "bhāvasamanvita": ['mw'],
    "bhāvasamāhita": ['cae', 'mw'],
    "bhāvasarga": ['mw'],
    "bhāvasaṃdhi": ['mw'],
    "bhāvasaṃśuddhi": ['cae', 'mw'],
    "bhāvasena": ['mw'],
    "bhāvasiṃha": ['mw'],
    "bhāvasiṃhaprakriyā": ['mw'],
    "bhāvaskhalita": ['cae', 'mw'],
    "bhāvasnigdha": ['mw'],
    "bhāvastha": ['cae', 'mw'],
    "bhāvasthira": ['mw'],
    "bhāvasu": ['bhs'],
    "bhāvasvabhāva": ['mw'],
    "bhāvasāra": ['mw'],
    "bhāvasāraviveka": ['mw'],
    "bhāvat": ['mw'],
    "bhāvata": ['ap90', 'mw'],
    "bhāvataraṃgiṇī": ['mw'],
    "bhāvatas": ['mw'],
    "bhāvati": ['bhs'],
    "bhāvatka": ['ddsa', 'mw'],
    "bhāvatribhaṅgī": ['mw'],
    "bhāvatva": ['mw'],
    "bhāvavacana": ['cae', 'mw'],
    "bhāvavant": ['cae'],
    "bhāvavat": ['mw'],
    "bhāvavibhāvinī": ['mw'],
    "bhāvavidyeśvara": ['mw'],
    "bhāvavikāra": ['mw'],
    "bhāvavilāsa": ['mw'],
    "bhāvaviveka": ['mw'],
    "bhāvaviśodhinī": ['mw'],
    "bhāvavācaka": ['mw'],
    "bhāvavṛtta": ['mw'],
    "bhāvavṛttī": ['mw'],
    "bhāvaya": ['ddsa'],
    "bhāvayamāna": ['cped'],
    "bhāvayatin": ['mw'],
    "bhāvayatībhū": ['mw'],
    "bhāvayavya": ['mw'],
    "bhāvayitavya": ['cae', 'mw'],
    "bhāvayitavyitṛ": ['mw'],
    "bhāvayitṛ": ['cae'],
    "bhāvayu": ['cae', 'gra', 'mw'],
    "bhāvaśabalatva": ['mw'],
    "bhāvaśabalatā": ['mw'],
    "bhāvaśabalā": ['mw'],
    "bhāvaśabda": ['mw'],
    "bhāvaśarman": ['mw'],
    "bhāvaśataka": ['mw'],
    "bhāvaśuddhi": ['cae', 'mw'],
    "bhāvaśānti": ['mw'],
    "bhāvaśūnya": ['cae', 'mw'],
    "bhāvaḍa": ['mw'],
    "bhāvaḥ": ['ap90'],
    "bhāvaṃgama": ['mw'],
    "bhāvena": ['mw'],
    "bhāventa": ['cped'],
    "bhāvesi": ['cped'],
    "bhāvetabba": ['cped'],
    "bhāveti": ['cped'],
    "bhāvetuṁ": ['cped'],
    "bhāvetvā": ['cped'],
    "bhāveśaphala": ['mw'],
    "bhāvi": ['mw'],
    "bhāvicakravartin": ['ddsa', 'mw'],
    "bhāvika": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāvin": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāvinī": ['mw'],
    "bhāviprāyaścitta": ['mw'],
    "bhāvita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bhāvitabhāvana": ['mw'],
    "bhāvitabuddhi": ['mw'],
    "bhāvitaka": ['mw'],
    "bhāvitakaṃ": ['ap90'],
    "bhāvitatta": ['cped'],
    "bhāvitavat": ['mw'],
    "bhāvitra": ['mw'],
    "bhāvitraṃ": ['ap90'],
    "bhāvitva": ['cae', 'ddsa', 'mw'],
    "bhāvitvaṃ": ['ap90'],
    "bhāvitā": ['ap90', 'ddsa', 'mw'],
    "bhāvitātma": ['bhs'],
    "bhāvitātman": ['ddsa', 'mw'],
    "bhāvodaya": ['cae', 'ddsa', 'mw'],
    "bhāvuka": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāvukā": ['mw'],
    "bhāvya": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāvyaratha": ['mw'],
    "bhāvyatva": ['mw'],
    "bhāvyatā": ['cae', 'mw'],
    "bhāvyupadha": ['mw'],
    "bhāvābhāsa": ['mw'],
    "bhāvācārya": ['mw'],
    "bhāvādhyāya": ['mw'],
    "bhāvādiprābhṛta": ['mw'],
    "bhāvādvaita": ['mw'],
    "bhāvāgaṇeśadīkṣita": ['mw'],
    "bhāvākūta": ['cae', 'ddsa', 'mw'],
    "bhāvālīnā": ['mw'],
    "bhāvānandī": ['mw'],
    "bhāvāntara": ['mw'],
    "bhāvānuga": ['mw'],
    "bhāvānugā": ['mw'],
    "bhāvārtha": ['mw'],
    "bhāvārthacaraṇa": ['mw'],
    "bhāvārthacaraṇabhāṣya": ['mw'],
    "bhāvārthacintāmaṇi": ['mw'],
    "bhāvārthadīpikā": ['mw'],
    "bhāvārthakaustubha": ['mw'],
    "bhāvārthaprakāśikā": ['mw'],
    "bhāvārthatva": ['mw'],
    "bhāvārthādhikaraṇa": ['mw'],
    "bhāvātmaka": ['mw'],
    "bhāvātmakatā": ['mw'],
    "bhāvāva": ['ap90', 'mw'],
    "bhāvāviśvanāthadīkṣita": ['mw'],
    "bhāvāṭa": ['mw'],
    "bhāvāṭaḥ": ['ap90'],
    "bhāvī": ['cped'],
    "bhāyajātya": ['mw'],
    "bhāyanta": ['cped'],
    "bhāyati": ['bhs', 'cped'],
    "bhāyavaśānti": ['mw'],
    "bhāyaya": ['ddsa'],
    "bhāyi": ['cped'],
    "bhāyitabba": ['cped'],
    "bhāyitvā": ['cped'],
    "bhāyāpesi": ['cped'],
    "bhāyāpeti": ['cped'],
    "bhāyāpetvā": ['cped'],
    "bhāyāpita": ['cped'],
    "bhāḍilāyana": ['mw'],
    "bhāḍita": ['mw'],
    "bhāḍitya": ['mw'],
    "bhāḍitāyana": ['mw'],
    "bhāḥkara": ['ap90', 'mw'],
    "bhāḥkūṭa": ['cae', 'ddsa', 'mw'],
    "bhāḥsatya": ['mw'],
    "bhāṃga": ['ap90'],
    "bhāṃgakaḥ": ['ap90'],
    "bhāṃgīnaṃ": ['ap90'],
    "bhāṃkāra": ['mw'],
    "bhāṃkṛta": ['mw'],
    "bhāṃśa": ['mw'],
    "bhāṃḍakaḥ": ['ap90'],
    "bhāṃḍaṃ": ['ap90'],
    "bhāṃḍikaḥ": ['ap90'],
    "bhāṃḍikā": ['ap90'],
    "bhāṃḍinī": ['ap90'],
    "bhāṃḍiḥ": ['ap90'],
    "bhāṃḍāraṃ": ['ap90'],
    "bhāṃḍārika": ['ap90'],
    "bhāṃḍārin": ['ap90'],
    "bhāṃḍīraḥ": ['ap90'],
    "bhāṅga": ['cae', 'ddsa', 'mw'],
    "bhāṅgaka": ['bhs', 'mw'],
    "bhāṅgeya": ['bhs'],
    "bhāṅgila": ['mw'],
    "bhāṅgileya": ['mw'],
    "bhāṅgāsuri": ['cae', 'ddsa', 'mw'],
    "bhāṅgāsurinṛpājñā": ['mw'],
    "bhāṅgīna": ['mw'],
    "bhāṇ": ['cae', 'mw'],
    "bhāṇa": ['cae', 'ddsa', 'mw'],
    "bhāṇaka": ['bhs', 'cae', 'cped', 'mw'],
    "bhāṇakaḥ": ['ap90'],
    "bhāṇasthāna": ['mw'],
    "bhāṇavāra": ['cped'],
    "bhāṇaḥ": ['ap90'],
    "bhāṇikā": ['mw'],
    "bhāṇin": ['bhs'],
    "bhāṇī": ['cped'],
    "bhāṇḍa": ['bhs', 'cae', 'ddsa', 'mw'],
    "bhāṇḍabhajaka": ['mw'],
    "bhāṇḍabharaka": ['mw'],
    "bhāṇḍagopaka": ['mw'],
    "bhāṇḍaka": ['mw'],
    "bhāṇḍamūlya": ['mw'],
    "bhāṇḍana": ['bhs', 'mw'],
    "bhāṇḍapati": ['mw'],
    "bhāṇḍapratibhāṇḍaka": ['mw'],
    "bhāṇḍapuṣpa": ['mw'],
    "bhāṇḍapuṭa": ['mw'],
    "bhāṇḍapūrṇa": ['mw'],
    "bhāṇḍarañjakamṛttikā": ['mw'],
    "bhāṇḍavādana": ['cae', 'mw'],
    "bhāṇḍavādya": ['cae', 'mw'],
    "bhāṇḍaśālā": ['mw'],
    "bhāṇḍi": ['mw'],
    "bhāṇḍijaṅghi": ['mw'],
    "bhāṇḍika": ['mw'],
    "bhāṇḍikā": ['bhs', 'mw'],
    "bhāṇḍila": ['mw'],
    "bhāṇḍilāyana": ['mw'],
    "bhāṇḍinī": ['mw'],
    "bhāṇḍita": ['mw'],
    "bhāṇḍitya": ['mw'],
    "bhāṇḍitāyana": ['mw'],
    "bhāṇḍivāha": ['mw'],
    "bhāṇḍiśālā": ['mw'],
    "bhāṇḍodara": ['mw'],
    "bhāṇḍopapurāṇa": ['mw'],
    "bhāṇḍyāyana": ['bhs'],
    "bhāṇḍāgāra": ['cae', 'mw'],
    "bhāṇḍāgārika": ['mw'],
    "bhāṇḍānusārin": ['mw'],
    "bhāṇḍāpura": ['ddsa', 'mw'],
    "bhāṇḍāra": ['cae', 'ddsa', 'mw'],
    "bhāṇḍāragṛha": ['mw'],
    "bhāṇḍārika": ['ddsa', 'mw'],
    "bhāṇḍārin": ['mw'],
    "bhāṇḍāvakāśada": ['cae', 'mw'],
    "bhāṇḍāvārī": ['bhs'],
    "bhāṇḍāyana": ['ddsa', 'mw'],
    "bhāṇḍāyani": ['mw'],
    "bhāṇḍī": ['mw'],
    "bhāṇḍīka": ['mw'],
    "bhāṇḍīra": ['ddsa', 'mw'],
    "bhāṇḍīrabhāṣāvyākaraṇa": ['mw'],
    "bhāṇḍīravananandana": ['mw'],
    "bhāṇḍīravanavāsin": ['mw'],
    "bhāṛjīka": ['gra', 'mw'],
    "bhāṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāṣa": ['mw'],
    "bhāṣaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāṣamānaka": ['bhs'],
    "bhāṣaṇa": ['cae', 'mw'],
    "bhāṣaṇaka": ['bhs'],
    "bhāṣaṇaṃ": ['ap90'],
    "bhāṣaṇī": ['mw'],
    "bhāṣaṇīkṣaulema": ['mw'],
    "bhāṣika": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāṣikasvara": ['mw'],
    "bhāṣikasūtra": ['mw'],
    "bhāṣikā": ['ap90', 'mw'],
    "bhāṣin": ['ap90', 'cae', 'mw'],
    "bhāṣipakṣin": ['ddsa', 'mw'],
    "bhāṣita": ['ap90', 'cae', 'mw'],
    "bhāṣitapuṃska": ['mw'],
    "bhāṣitapuṃskatva": ['mw'],
    "bhāṣitavya": ['cae', 'mw'],
    "bhāṣitṛ": ['cae', 'mw'],
    "bhāṣiṇikā": ['bhs'],
    "bhāṣya": ['cae', 'ddsa', 'mw'],
    "bhāṣyabhānuprabhā": ['mw'],
    "bhāṣyabhūta": ['mw'],
    "bhāṣyacandrikā": ['mw'],
    "bhāṣyadīpikā": ['mw'],
    "bhāṣyakaiyaṭīya": ['mw'],
    "bhāṣyakāra": ['cae', 'mw'],
    "bhāṣyakāraprapatti": ['mw'],
    "bhāṣyakārastotra": ['mw'],
    "bhāṣyakṛt": ['cae', 'mw'],
    "bhāṣyanavāhnika": ['mw'],
    "bhāṣyapradīpa": ['mw'],
    "bhāṣyapradīpavivaraṇa": ['mw'],
    "bhāṣyapradīpoddyotana": ['mw'],
    "bhāṣyapratyaya": ['mw'],
    "bhāṣyapratyayodbodha": ['mw'],
    "bhāṣyaratnaprabhā": ['mw'],
    "bhāṣyaratnaprakāśikā": ['mw'],
    "bhāṣyaratnāvalī": ['mw'],
    "bhāṣyarāja": ['mw'],
    "bhāṣyaviṣayavākyadīpikā": ['mw'],
    "bhāṣyavyākhyā": ['mw'],
    "bhāṣyavārttika": ['mw'],
    "bhāṣyaṃ": ['ap90'],
    "bhāṣyaṭīkā": ['mw'],
    "bhāṣyārthasaṃgraha": ['mw'],
    "bhāṣyāvatārikā": ['mw'],
    "bhāṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhāṣācitraka": ['mw'],
    "bhāṣājña": ['cae', 'mw'],
    "bhāṣākaumudī": ['mw'],
    "bhāṣākumudamañjarī": ['mw'],
    "bhāṣālīlāvatī": ['mw'],
    "bhāṣāmañjarī": ['mw'],
    "bhāṣāntara": ['mw'],
    "bhāṣānuśāsana": ['mw'],
    "bhāṣāpariccheda": ['mw'],
    "bhāṣāprakāśikā": ['mw'],
    "bhāṣāpāda": ['mw'],
    "bhāṣāratna": ['mw'],
    "bhāṣārṇava": ['mw'],
    "bhāṣāsama": ['mw'],
    "bhāṣāsamiti": ['mw'],
    "bhāṣāvivṛtigītā": ['mw'],
    "bhāṣāvṛtti": ['mw'],
    "bhāṣāvṛttyarthavṛtti": ['mw'],
    "bhāṣṭa": ['bhs'],
    "bhāṭa": ['cae', 'mw'],
    "bhāṭaka": ['cae', 'mw'],
    "bhāṭakajīvikā": ['mw'],
    "bhāṭaṃ": ['ap90'],
    "bhāṭi": ['cae', 'ddsa', 'mw'],
    "bhāṭiḥ": ['ap90'],
    "bhāṭm, bhāṭaka": ['ddsa'],
    "bhāṭṭa": ['cae', 'ddsa', 'mw'],
    "bhāṭṭabhāskara": ['mw'],
    "bhāṭṭacintāmaṇi": ['mw'],
    "bhāṭṭadeśa": ['mw'],
    "bhāṭṭadinakara": ['mw'],
    "bhāṭṭadinakarīya": ['mw'],
    "bhāṭṭadīpikā": ['mw'],
    "bhāṭṭadīpikānyakkāra": ['mw'],
    "bhāṭṭadīpikāsaṃgraha": ['mw'],
    "bhāṭṭakaustubha": ['mw'],
    "bhāṭṭanayoddyota": ['mw'],
    "bhāṭṭaparibhāṣā": ['mw'],
    "bhāṭṭaparibhāṣāprakāśikā": ['mw'],
    "bhāṭṭarahasya": ['mw'],
    "bhāṭṭasaṃgraha": ['mw'],
    "bhāṭṭasāra": ['mw'],
    "bhāṭṭasārakārikā": ['mw'],
    "bhāṭṭatantra": ['mw'],
    "bhāṭṭaśabdapariccheda": ['mw'],
    "bhāṭṭaśabdenduśekhara": ['mw'],
    "bhāṭṭaḥ": ['ap90'],
    "bhāṭṭotpāṭana": ['mw'],
    "bhāṭṭālaṃkāra": ['mw'],
    "bhī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhīkara": ['ddsa', 'mw'],
    "bhīlabhūṣaṇā": ['mw'],
    "bhīlu": ['mw'],
    "bhīluka": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhīlukaḥ": ['ap90'],
    "bhīlū": ['ap90'],
    "bhīlūkaḥ": ['ap90'],
    "bhīma": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhīmabala": ['cae', 'mw'],
    "bhīmabhavā": ['mw'],
    "bhīmabhavībhū": ['mw'],
    "bhīmabhaṭa": ['mw'],
    "bhīmabhaṭṭa": ['mw'],
    "bhīmabhuja": ['mw'],
    "bhīmacandra": ['mw'],
    "bhīmadarśana": ['cae', 'mw'],
    "bhīmadarśanā": ['bhs'],
    "bhīmadeva": ['mw'],
    "bhīmadhanvan": ['mw'],
    "bhīmadhanvāyana": ['mw'],
    "bhīmadvādaśī": ['mw'],
    "bhīmadvādaśīvrata": ['mw'],
    "bhīmadāsabhūpāla": ['mw'],
    "bhīmagava": ['mw'],
    "bhīmagrāhavat": ['mw'],
    "bhīmagu": ['mw'],
    "bhīmagupta": ['mw'],
    "bhīmahāsa": ['mw'],
    "bhīmaikādaśī": ['mw'],
    "bhīmajananī": ['mw'],
    "bhīmajā": ['mw'],
    "bhīmajānu": ['mw'],
    "bhīmaka": ['mw'],
    "bhīmakalambaka": ['mw'],
    "bhīmakarman": ['cae', 'ddsa', 'mw'],
    "bhīmakhaṇḍa": ['mw'],
    "bhīmakārmuka": ['mw'],
    "bhīmakāvya": ['mw'],
    "bhīmala": ['cae', 'mw'],
    "bhīmamukha": ['mw'],
    "bhīmanagara": ['mw'],
    "bhīmant": ['cae'],
    "bhīmanāda": ['cae', 'mw'],
    "bhīmanātha": ['mw'],
    "bhīmanāyaka": ['mw'],
    "bhīmaparākrama": ['cae', 'mw'],
    "bhīmapura": ['mw'],
    "bhīmaputrikā": ['mw'],
    "bhīmapāla": ['mw'],
    "bhīmapūrvaja": ['mw'],
    "bhīmara": ['mw'],
    "bhīmaratha": ['bhs', 'mw'],
    "bhīmarathā": ['mw'],
    "bhīmarathī": ['mw'],
    "bhīmaraṃ": ['ap90'],
    "bhīmarikā": ['mw'],
    "bhīmarūpa": ['mw'],
    "bhīmarūpistotra": ['mw'],
    "bhīmasaṃdṛś": ['cae', 'gra'],
    "bhīmasena": ['cae', 'mw'],
    "bhīmasenamaya": ['mw'],
    "bhīmasiṃha": ['mw'],
    "bhīmasiṃhapaṇḍita": ['mw'],
    "bhīmasutā": ['mw'],
    "bhīmasvāmin": ['mw'],
    "bhīmasāhi": ['mw'],
    "bhīmat": ['mw'],
    "bhīmatithi": ['mw'],
    "bhīmatā": ['mw'],
    "bhīmaujas": ['cae', 'ddsa', 'mw'],
    "bhīmavega": ['mw'],
    "bhīmavegarava": ['mw'],
    "bhīmavigraha": ['mw'],
    "bhīmavikrama": ['mw'],
    "bhīmavikrānta": ['mw'],
    "bhīmavinoda": ['mw'],
    "bhīmayu": ['ap90', 'cae', 'gra', 'mw'],
    "bhīmaśara": ['mw'],
    "bhīmaśaṃkara": ['mw'],
    "bhīmaśukla": ['mw'],
    "bhīmaśāha": ['mw'],
    "bhīmaśāsana": ['mw'],
    "bhīmeśa": ['mw'],
    "bhīmeśvara": ['mw'],
    "bhīmeśvarabhaṭṭa": ['mw'],
    "bhīmeśvaramāhātmya": ['mw'],
    "bhīmeśvaratīrtha": ['mw'],
    "bhīmodarī": ['mw'],
    "bhīmottara": ['bhs', 'mw'],
    "bhīmā": ['ap90', 'bhs', 'mw'],
    "bhīmādeva": ['mw'],
    "bhīmādyupākhyāna": ['mw'],
    "bhīmākāra": ['mw'],
    "bhīmāmāhātmya": ['mw'],
    "bhīmāṅgada": ['cae', 'mw'],
    "bhīra": ['cae', 'ddsa', 'mw'],
    "bhīraka": ['mw'],
    "bhīru": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhīrubhīru": ['mw'],
    "bhīrubāla": ['mw'],
    "bhīrucetas": ['mw'],
    "bhīruhṛdaya": ['mw'],
    "bhīrujana": ['mw'],
    "bhīruka": ['ap90', 'cae', 'cped', 'mw'],
    "bhīrukaccha": ['mw'],
    "bhīrukajana": ['mw'],
    "bhīruparṇī": ['mw'],
    "bhīrupattrī": ['mw'],
    "bhīrurandhra": ['mw'],
    "bhīrusattva": ['mw'],
    "bhīruttāna": ['cped'],
    "bhīrutva": ['mw'],
    "bhīrutā": ['ap90', 'mw'],
    "bhīruyodha": ['mw'],
    "bhīruṣṭhāna": ['mw'],
    "bhīrū": ['ap90'],
    "bhīs": ['gra'],
    "bhīsana": ['cped'],
    "bhīta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bhītabhīta": ['cae', 'mw'],
    "bhītacitta": ['mw'],
    "bhītacārin": ['mw'],
    "bhītagāyana": ['mw'],
    "bhītam": ['mw'],
    "bhītaparitrāṇavastūpālambhapaṇḍita": ['mw'],
    "bhītavat": ['mw'],
    "bhītaṃkāra": ['ap90'],
    "bhītaṃkāram": ['mw'],
    "bhītaṃkāraṃ": ['ap90'],
    "bhīti": ['cae', 'cped', 'ddsa', 'mw'],
    "bhīticchid": ['mw'],
    "bhītikṛt": ['mw'],
    "bhītimant": ['cae'],
    "bhītimat": ['mw'],
    "bhītināṭitaka": ['mw'],
    "bhītitas": ['mw'],
    "bhītiḥ": ['ap90'],
    "bhītī": ['mw'],
    "bhīyoso mattāya": ['cped'],
    "bhīṇī": ['mw'],
    "bhīṣaka": ['mw'],
    "bhīṣay": ['cae'],
    "bhīṣaya": ['mw'],
    "bhīṣayati": ['mw'],
    "bhīṣaṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "bhīṣaṇaka": ['ap90', 'mw'],
    "bhīṣaṇatva": ['mw'],
    "bhīṣaṇikā": ['bhs'],
    "bhīṣaṇā": ['mw'],
    "bhīṣaṇīya": ['bhs', 'mw'],
    "bhīṣaṭācārya": ['mw'],
    "bhīṣidāsa": ['mw'],
    "bhīṣikā": ['cae', 'mw'],
    "bhīṣita": ['ap90', 'mw'],
    "bhīṣma": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "bhīṣmagarjitaghoṣasvararāja": ['mw'],
    "bhīṣmagarjitanirghoṣasvara": ['bhs'],
    "bhīṣmajananī": ['mw'],
    "bhīṣmaka": ['mw'],
    "bhīṣmakaḥ": ['ap90'],
    "bhīṣmakātmajā": ['mw'],
    "bhīṣmamiśra": ['mw'],
    "bhīṣmamuktipradāyaka": ['mw'],
    "bhīṣmamātaṅga": ['bhs'],
    "bhīṣmaparvan": ['mw'],
    "bhīṣmapañcaka": ['mw'],
    "bhīṣmapañcakavrata": ['mw'],
    "bhīṣmapañjarastotra": ['mw'],
    "bhīṣmaratnaparikṣā": ['mw'],
    "bhīṣmastavarāja": ['mw'],
    "bhīṣmastuti": ['mw'],
    "bhīṣmasvararāja": ['mw'],
    "bhīṣmasū": ['mw'],
    "bhīṣmayaśas": ['bhs'],
    "bhīṣmottaranirghoṣa": ['bhs'],
    "bhīṣmāṣṭamī": ['mw'],
    "bhīṣugati": ['mw'],
    "bhīṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhū": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhūbadarī": ['mw'],
    "bhūbala": ['mw'],
    "bhūbhartṛ": ['cae', 'mw'],
    "bhūbhaṭa": ['mw'],
    "bhūbhaṭṭa": ['mw'],
    "bhūbhramavādakhaṇḍananirāsa": ['mw'],
    "bhūbhramaṇavicāra": ['mw'],
    "bhūbhuj": ['cae', 'mw'],
    "bhūbhāga": ['mw'],
    "bhūbhāra": ['cae'],
    "bhūbhū": ['mw'],
    "bhūbhṛt": ['cae', 'mw'],
    "bhūbhṛtsabha": ['mw'],
    "bhūbimba": ['mw'],
    "bhūcakra": ['mw'],
    "bhūcara": ['cae', 'mw'],
    "bhūcaryā": ['mw'],
    "bhūcarī": ['bhs'],
    "bhūchāya": ['mw'],
    "bhūchāyā": ['mw'],
    "bhūdarībhavā": ['mw'],
    "bhūdeva": ['cae', 'mw'],
    "bhūdevaśukla": ['mw'],
    "bhūdhana": ['mw'],
    "bhūdhara": ['cae', 'mw'],
    "bhūdharaguhāntaratas": ['mw'],
    "bhūdharaja": ['mw'],
    "bhūdhararāja": ['mw'],
    "bhūdharatā": ['mw'],
    "bhūdharayantra": ['mw'],
    "bhūdhareśvara": ['mw'],
    "bhūdharādhīśa": ['mw'],
    "bhūdharāraṇya": ['cae', 'mw'],
    "bhūdharātmaka": ['mw'],
    "bhūdhra": ['ddsa', 'mw'],
    "bhūdhātirī": ['mw'],
    "bhūdina": ['ddsa', 'mw'],
    "bhūdivasa": ['mw'],
    "bhūdāra": ['mw'],
    "bhūgandhapati": ['mw'],
    "bhūgara": ['mw'],
    "bhūgarbha": ['mw'],
    "bhūgata": ['cae', 'mw'],
    "bhūgeha": ['mw'],
    "bhūghana": ['mw'],
    "bhūghnī": ['mw'],
    "bhūgola": ['cae', 'mw'],
    "bhūgolahastāmalaka": ['mw'],
    "bhūgolaka": ['cae', 'mw'],
    "bhūgolakhagolavirodhaparihāra": ['mw'],
    "bhūgolasaṃgraha": ['mw'],
    "bhūgolasāra": ['mw'],
    "bhūgolavarṇana": ['mw'],
    "bhūgolavidyā": ['mw'],
    "bhūgolavistāra": ['mw'],
    "bhūgolavyavasthātantroktā": ['mw'],
    "bhūgolavṛttānta": ['mw'],
    "bhūgṛha": ['mw'],
    "bhūjambu": ['mw'],
    "bhūjambū": ['mw'],
    "bhūjantu": ['mw'],
    "bhūka": ['mw'],
    "bhūkadamba": ['mw'],
    "bhūkadambaka": ['mw'],
    "bhūkadambikā": ['mw'],
    "bhūkala": ['mw'],
    "bhūkalaḥ": ['ap90'],
    "bhūkampa": ['cae', 'ddsa', 'mw'],
    "bhūkampalakṣaṇa": ['mw'],
    "bhūkampavicāra": ['mw'],
    "bhūkanda": ['mw'],
    "bhūkapittha": ['mw'],
    "bhūkarbudāraka": ['mw'],
    "bhūkarṇa": ['mw'],
    "bhūkarṇi": ['mw'],
    "bhūkaśyapa": ['mw'],
    "bhūkaḥ": ['ap90'],
    "bhūkeśa": ['mw'],
    "bhūkeśā": ['mw'],
    "bhūkeśī": ['mw'],
    "bhūkharjūrī": ['mw'],
    "bhūkhaṇḍa": ['mw'],
    "bhūkumbhī": ['mw'],
    "bhūkuṣmāṇḍī": ['mw'],
    "bhūkāka": ['mw'],
    "bhūkāśyapa": ['mw'],
    "bhūkāṇḍa": ['mw'],
    "bhūkṣit": ['mw'],
    "bhūkṣīravāṭikā": ['mw'],
    "bhūlagnā": ['mw'],
    "bhūlakṣaṇapaṭala": ['mw'],
    "bhūlatā": ['mw'],
    "bhūlavaṇa": ['mw'],
    "bhūliṅga": ['mw'],
    "bhūliṅgaśakuna": ['mw'],
    "bhūliṅgaśakuni": ['mw'],
    "bhūliṅgā": ['mw'],
    "bhūloka": ['cae', 'ddsa', 'mw'],
    "bhūlokakailāsamāhātmya": ['mw'],
    "bhūlokasuranāyaka": ['mw'],
    "bhūma": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bhūmahendra": ['cae', 'mw'],
    "bhūmaka": ['cped'],
    "bhūmakatṛtīyā": ['mw'],
    "bhūman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhūmanyu": ['mw'],
    "bhūmat": ['ap90', 'mw'],
    "bhūmavidyā": ['mw'],
    "bhūmaya": ['ap90', 'mw'],
    "bhūmayati": ['ap90'],
    "bhūmayī": ['mw'],
    "bhūmaṇḍala": ['cae', 'ddsa', 'mw'],
    "bhūmi": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhūmia": ['gra'],
    "bhūmibalavaiśāradyadhara": ['bhs'],
    "bhūmibhedin": ['mw'],
    "bhūmibhuj": ['cae', 'mw'],
    "bhūmibhāga": ['cae', 'cped', 'mw'],
    "bhūmibhūta": ['mw'],
    "bhūmibhṛt": ['cae', 'mw'],
    "bhūmibudhna": ['cae', 'mw'],
    "bhūmicala": ['cae', 'mw'],
    "bhūmicalana": ['mw'],
    "bhūmicampaka": ['mw'],
    "bhūmicchattra": ['mw'],
    "bhūmicchidra": ['mw'],
    "bhūmida": ['cae', 'mw'],
    "bhūmideva": ['bhs', 'cae', 'mw'],
    "bhūmidevī": ['mw'],
    "bhūmidhara": ['cae', 'mw'],
    "bhūmidundubhi": ['cae', 'mw'],
    "bhūmidāna": ['cae', 'mw'],
    "bhūmidṛṃha": ['mw'],
    "bhūmiga": ['mw'],
    "bhūmigarbha": ['mw'],
    "bhūmigarta": ['cae', 'mw'],
    "bhūmigata": ['cae', 'cped', 'mw'],
    "bhūmigocara": ['mw'],
    "bhūmiguhā": ['mw'],
    "bhūmigṛha": ['cae', 'mw'],
    "bhūmija": ['cae', 'mw'],
    "bhūmijaguggulu": ['mw'],
    "bhūmijambu": ['mw'],
    "bhūmijambukā": ['mw'],
    "bhūmijambū": ['mw'],
    "bhūmijoṣaṇa": ['mw'],
    "bhūmijā": ['mw'],
    "bhūmijāta": ['cae', 'mw'],
    "bhūmijīvin": ['mw'],
    "bhūmika": ['bhs'],
    "bhūmikadamba": ['mw'],
    "bhūmikampa": ['cae', 'mw'],
    "bhūmikampana": ['mw'],
    "bhūmikampā": ['cped'],
    "bhūmikandaka": ['mw'],
    "bhūmikandalī": ['ddsa', 'mw'],
    "bhūmikandara": ['mw'],
    "bhūmikapāla": ['mw'],
    "bhūmikharjūrikā": ['mw'],
    "bhūmikharjūrī": ['mw'],
    "bhūmikhaṇḍa": ['mw'],
    "bhūmikuṣmāṇḍa": ['mw'],
    "bhūmikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhūmikābhāga": ['cae', 'mw'],
    "bhūmikāgata": ['mw'],
    "bhūmikūśmaṇḍa": ['mw'],
    "bhūmikṣaya": ['ddsa', 'mw'],
    "bhūmilepana": ['mw'],
    "bhūmiloka": ['cae', 'mw'],
    "bhūmilābha": ['mw'],
    "bhūmimat": ['mw'],
    "bhūmimati": ['bhs'],
    "bhūmimaya": ['mw'],
    "bhūmimayī": ['mw'],
    "bhūmimaṇḍa": ['mw'],
    "bhūmimaṇḍapabhūṣaṇā": ['mw'],
    "bhūmimaṇḍā": ['mw'],
    "bhūmimitra": ['mw'],
    "bhūmin": ['bhs'],
    "bhūminanda": ['mw'],
    "bhūminātha": ['mw'],
    "bhūmipa": ['cae', 'mw'],
    "bhūmipakṣa": ['mw'],
    "bhūmiparidṛṃhaṇa": ['mw'],
    "bhūmiparimāṇa": ['cae', 'mw'],
    "bhūmiparpaṭaka": ['bhs'],
    "bhūmipati": ['cae', 'mw'],
    "bhūmipatitva": ['mw'],
    "bhūmipiśāca": ['mw'],
    "bhūmippadesa": ['cped'],
    "bhūmipra": ['cae', 'mw'],
    "bhūmipracala": ['cae', 'mw'],
    "bhūmiprāpta": ['mw'],
    "bhūmipuraṃdara": ['mw'],
    "bhūmiputra": ['mw'],
    "bhūmipāla": ['cae', 'mw'],
    "bhūmipāśa": ['mw'],
    "bhūmipāśakā": ['mw'],
    "bhūmirakṣaka": ['mw'],
    "bhūmirathika": ['mw'],
    "bhūmiruha": ['mw'],
    "bhūmisambhava": ['mw'],
    "bhūmisambhavā": ['mw'],
    "bhūmisattra": ['mw'],
    "bhūmisava": ['mw'],
    "bhūmisaṃniveśa": ['mw'],
    "bhūmisena": ['mw'],
    "bhūmisenāpati": ['cped'],
    "bhūmisnu": ['mw'],
    "bhūmispṛś": ['cae', 'mw'],
    "bhūmistoma": ['mw'],
    "bhūmisuta": ['cae', 'mw'],
    "bhūmisvāmin": ['mw'],
    "bhūmisāmrājya": ['mw'],
    "bhūmisūcaka": ['bhs'],
    "bhūmitala": ['cae', 'cped', 'mw'],
    "bhūmitanaya": ['mw'],
    "bhūmitra": ['mw'],
    "bhūmitraya": ['mw'],
    "bhūmituṇḍika": ['mw'],
    "bhūmitva": ['cae', 'mw'],
    "bhūmivajramaṇi": ['cae', 'mw'],
    "bhūmivalli": ['mw'],
    "bhūmivardhana": ['mw'],
    "bhūmivāsin": ['mw'],
    "bhūmiāṇa": ['mw'],
    "bhūmiśaya": ['cae', 'mw'],
    "bhūmiśayana": ['mw'],
    "bhūmiśayyā": ['mw'],
    "bhūmiḥ": ['ap90'],
    "bhūmiṃjaya": ['mw'],
    "bhūmiṣṭha": ['cae', 'mw'],
    "bhūmnā": ['mw'],
    "bhūmy": ['mw'],
    "bhūmya": ['bhs', 'cae', 'gra', 'mw'],
    "bhūmyanantara": ['ddsa', 'mw'],
    "bhūmyanṛta": ['cae', 'mw'],
    "bhūmyavacāraṇānugama": ['bhs'],
    "bhūmyekadeśa": ['mw'],
    "bhūmyāhulya": ['mw'],
    "bhūmyāmalakī": ['mw'],
    "bhūmyāmalī": ['mw'],
    "bhūmānandasarasvatī": ['mw'],
    "bhūmī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhūmībhuj": ['mw'],
    "bhūmībhṛt": ['ddsa', 'mw'],
    "bhūmīcchā": ['ddsa', 'mw'],
    "bhūmīkadamba": ['mw'],
    "bhūmīkurabaka": ['mw'],
    "bhūmīndra": ['mw'],
    "bhūmīpati": ['mw'],
    "bhūmīruh": ['cae', 'mw'],
    "bhūmīruha": ['cae', 'mw'],
    "bhūmīsaha": ['mw'],
    "bhūmīyāṇa": ['mw'],
    "bhūmīśayya": ['mw'],
    "bhūmīśvara": ['mw'],
    "bhūmīśvaramāhātmya": ['mw'],
    "bhūnandana": ['mw'],
    "bhūnetṛ": ['mw'],
    "bhūnimba": ['mw'],
    "bhūnā": ['cae', 'mw'],
    "bhūnāga": ['mw'],
    "bhūnāman": ['mw'],
    "bhūnāyaka": ['mw'],
    "bhūnīlāpañcasūkta": ['mw'],
    "bhūnīpa": ['mw'],
    "bhūpa": ['cae', 'mw'],
    "bhūpada": ['mw'],
    "bhūpadī": ['mw'],
    "bhūpala": ['mw'],
    "bhūpalāśa": ['mw'],
    "bhūpaputra": ['mw'],
    "bhūparidhi": ['mw'],
    "bhūparpaṭaka": ['bhs'],
    "bhūpasamuccayatantra": ['mw'],
    "bhūpasiṃha": ['mw'],
    "bhūpasuta": ['mw'],
    "bhūpati": ['cae', 'mw'],
    "bhūpatistuti": ['mw'],
    "bhūpatita": ['cae', 'mw'],
    "bhūpativeśman": ['mw'],
    "bhūpatā": ['mw'],
    "bhūpavitra": ['mw'],
    "bhūpeṣṭa": ['mw'],
    "bhūphala": ['mw'],
    "bhūpiṭharī": ['mw'],
    "bhūpradāna": ['mw'],
    "bhūprakampa": ['mw'],
    "bhūpratimādāna": ['mw'],
    "bhūpura": ['mw'],
    "bhūputra": ['mw'],
    "bhūputrī": ['mw'],
    "bhūpādiskandhalakṣaṇa": ['mw'],
    "bhūpāla": ['cae', 'mw'],
    "bhūpālabhūṣaṇa": ['mw'],
    "bhūpālaloka": ['mw'],
    "bhūpālana": ['mw'],
    "bhūpālastotra": ['mw'],
    "bhūpālasāhi": ['mw'],
    "bhūpālavallabha": ['mw'],
    "bhūpālaśrī": ['mw'],
    "bhūpālī": ['mw'],
    "bhūpāta": ['mw'],
    "bhūpāṭalī": ['mw'],
    "bhūpūga": ['mw'],
    "bhūr": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhūramaṇa": ['mw'],
    "bhūrati": ['mw'],
    "bhūratna": ['mw'],
    "bhūrbhuva": ['mw'],
    "bhūrbhuvakara": ['mw'],
    "bhūrbhuvatīrtha": ['mw'],
    "bhūrbhuveśvaratīrtha": ['mw'],
    "bhūrbhūra": ['mw'],
    "bhūrbhūva": ['mw'],
    "bhūri": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bhūriakṣa": ['gra'],
    "bhūribala": ['mw'],
    "bhūribalā": ['mw'],
    "bhūribhaṭṭa": ['mw'],
    "bhūribhoja": ['mw'],
    "bhūribhāra": ['cae', 'gra', 'mw'],
    "bhūricakṣas": ['gra', 'mw'],
    "bhūrida": ['cae', 'mw'],
    "bhūridakṣiṇa": ['cae', 'mw'],
    "bhūridakṣiṇam": ['mw'],
    "bhūridhana": ['cae', 'mw'],
    "bhūridhāman": ['cae', 'mw'],
    "bhūridhāra": ['gra', 'mw'],
    "bhūridhāyas": ['cae', 'gra', 'mw'],
    "bhūridugdhā": ['mw'],
    "bhūridyumna": ['mw'],
    "bhūridā": ['gra', 'mw'],
    "bhūridātra": ['cae', 'gra', 'mw'],
    "bhūridāvan": ['cae', 'gra', 'mw'],
    "bhūridāvat": ['gra', 'mw'],
    "bhūridāvattara": ['mw'],
    "bhūrigadgadam": ['mw'],
    "bhūrigama": ['mw'],
    "bhūrigandhā": ['mw'],
    "bhūrigu": ['cae', 'gra', 'mw'],
    "bhūriguṇa": ['mw'],
    "bhūrihan": ['mw'],
    "bhūrij": ['ap90', 'mw'],
    "bhūrija": ['mw'],
    "bhūrijanman": ['gra', 'mw'],
    "bhūrijyeṣṭha": ['mw'],
    "bhūrika": ['bhs', 'mw'],
    "bhūrikarman": ['gra', 'mw'],
    "bhūrikālam": ['ddsa', 'mw'],
    "bhūrikṛtrimamāṇikyamaya": ['mw'],
    "bhūrilagnā": ['mw'],
    "bhūriloha": ['mw'],
    "bhūrilābha": ['mw'],
    "bhūrimallī": ['mw'],
    "bhūrimedha": ['cped'],
    "bhūrimāya": ['mw'],
    "bhūrimūla": ['mw'],
    "bhūrimūlikā": ['mw'],
    "bhūrinidhana": ['mw'],
    "bhūriojas": ['gra'],
    "bhūripalitadā": ['mw'],
    "bhūripattra": ['mw'],
    "bhūripañña": ['cped'],
    "bhūriphalī": ['mw'],
    "bhūriphenā": ['mw'],
    "bhūripoṣin": ['cae', 'gra', 'mw'],
    "bhūriprayoga": ['mw'],
    "bhūriprayogagaṇadhātuṭīkā": ['mw'],
    "bhūriprayogatva": ['mw'],
    "bhūripreman": ['mw'],
    "bhūriputra": ['mw'],
    "bhūripuṣpā": ['mw'],
    "bhūripādāta": ['mw'],
    "bhūripāśa": ['cae', 'gra', 'mw'],
    "bhūripāṇi": ['mw'],
    "bhūrirasa": ['mw'],
    "bhūriretas": ['cae', 'gra', 'mw'],
    "bhūrirāma": ['mw'],
    "bhūrisakha": ['mw'],
    "bhūrisattva": ['bhs'],
    "bhūristhātra": ['cae', 'gra', 'mw'],
    "bhūritara": ['mw'],
    "bhūritejas": ['cae', 'mw'],
    "bhūritejasa": ['mw'],
    "bhūritoka": ['cae', 'mw'],
    "bhūritā": ['cae', 'mw'],
    "bhūrivarcas": ['cae', 'mw'],
    "bhūrivarpas": ['cae', 'gra', 'mw'],
    "bhūrivasu": ['cae', 'mw'],
    "bhūrivetasa": ['mw'],
    "bhūrivikrama": ['mw'],
    "bhūrivilambin": ['cae'],
    "bhūriviyoga": ['mw'],
    "bhūrivāra": ['cae', 'gra', 'mw'],
    "bhūrivṛṣṭi": ['mw'],
    "bhūriāsuti": ['gra'],
    "bhūriśas": ['cae', 'mw'],
    "bhūriśravas": ['cae', 'mw'],
    "bhūriśreṣṭhaka": ['mw'],
    "bhūriśreṣṭhika": ['mw'],
    "bhūriśṛṅga": ['cae', 'gra', 'mw'],
    "bhūriṇī": ['bhs'],
    "bhūriṣah": ['gra', 'mw'],
    "bhūriṣeṇa": ['mw'],
    "bhūriṣāh": ['gra', 'mw'],
    "bhūrja": ['cae', 'ddsa', 'mw'],
    "bhūrjadruma": ['cae', 'mw'],
    "bhūrjakaṇṭaka": ['mw'],
    "bhūrjakaṇṭhaka": ['cae'],
    "bhūrjapattra": ['mw'],
    "bhūrjaḥ": ['ap90'],
    "bhūrloka": ['cae', 'ddsa', 'mw'],
    "bhūruh": ['cae', 'ddsa', 'mw'],
    "bhūruha": ['cae', 'mw'],
    "bhūruṇḍa": ['bhs'],
    "bhūruṇḍī": ['mw'],
    "bhūry": ['mw'],
    "bhūryakṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "bhūryojas": ['cae', 'gra', 'mw'],
    "bhūryāsuti": ['gra', 'mw'],
    "bhūrṇi": ['cae', 'ddsa', 'gra', 'mw'],
    "bhūrṇiḥ": ['ap90'],
    "bhūsana": ['cped'],
    "bhūsaṃskāra": ['mw'],
    "bhūsenta": ['cped'],
    "bhūsesi": ['cped'],
    "bhūseti": ['cped'],
    "bhūsetvā": ['cped'],
    "bhūsita": ['cped'],
    "bhūsphoṭa": ['mw'],
    "bhūspṛś": ['mw'],
    "bhūstha": ['cae', 'mw'],
    "bhūsthita": ['mw'],
    "bhūstuti": ['mw'],
    "bhūstṛṇa": ['cae', 'mw'],
    "bhūsura": ['cae', 'mw'],
    "bhūsuta": ['ddsa', 'mw'],
    "bhūsutā": ['mw'],
    "bhūsvarga": ['mw'],
    "bhūsvargāya": ['mw'],
    "bhūsvāmin": ['mw'],
    "bhūsā": ['cped'],
    "bhūsāpesi": ['cped'],
    "bhūsāpeti": ['cped'],
    "bhūsāpetvā": ['cped'],
    "bhūsāpita": ['cped'],
    "bhūsūkta": ['mw'],
    "bhūsūktabhāṣya": ['mw'],
    "bhūt": ['bhs'],
    "bhūta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bhūtabali": ['mw'],
    "bhūtabhairava": ['mw'],
    "bhūtabhairavatantra": ['mw'],
    "bhūtabhartṛ": ['cae', 'mw'],
    "bhūtabhautika": ['mw'],
    "bhūtabhava": ['mw'],
    "bhūtabhavya": ['cae', 'mw'],
    "bhūtabhavyeśa": ['cae', 'mw'],
    "bhūtabhāvana": ['cae', 'mw'],
    "bhūtabhāvanabhāvana": ['mw'],
    "bhūtabhāvin": ['cae', 'mw'],
    "bhūtabhāṣita": ['mw'],
    "bhūtabhāṣā": ['cae', 'mw'],
    "bhūtabhāṣāmaya": ['mw'],
    "bhūtabhṛt": ['cae', 'mw'],
    "bhūtabrahman": ['mw'],
    "bhūtabālagrahonmāda": ['mw'],
    "bhūtacaitanika": ['mw'],
    "bhūtacaitanya": ['mw'],
    "bhūtacaram": ['bhs'],
    "bhūtacaturdaśī": ['mw'],
    "bhūtacintā": ['mw'],
    "bhūtacārin": ['mw'],
    "bhūtadamanī": ['mw'],
    "bhūtadarśimant": ['bhs'],
    "bhūtadattā": ['mw'],
    "bhūtadayā": ['mw'],
    "bhūtadhara": ['mw'],
    "bhūtadharā": ['cae', 'mw'],
    "bhūtadhāman": ['mw'],
    "bhūtadhāriṇī": ['cae', 'mw'],
    "bhūtadhātrī": ['mw'],
    "bhūtadruh": ['mw'],
    "bhūtadruma": ['mw'],
    "bhūtadrāvin": ['mw'],
    "bhūtadāhīya": ['mw'],
    "bhūtagandhā": ['mw'],
    "bhūtagaṇa": ['cae', 'mw'],
    "bhūtagaṇādhipa": ['mw'],
    "bhūtaghna": ['mw'],
    "bhūtaghnī": ['mw'],
    "bhūtagrasta": ['mw'],
    "bhūtagrāma": ['cae', 'mw'],
    "bhūtagāha": ['cped'],
    "bhūtagāma": ['cped'],
    "bhūtagṛhya": ['mw'],
    "bhūtahan": ['mw'],
    "bhūtahantrī": ['mw'],
    "bhūtahara": ['mw'],
    "bhūtahatyā": ['mw'],
    "bhūtahārin": ['mw'],
    "bhūtahāsa": ['mw'],
    "bhūtajananī": ['cae', 'mw'],
    "bhūtajaya": ['mw'],
    "bhūtajaṭā": ['mw'],
    "bhūtajyotis": ['mw'],
    "bhūtakaraṇa": ['ddsa', 'mw'],
    "bhūtakaraṇavatī": ['mw'],
    "bhūtakarman": ['mw'],
    "bhūtakartṛ": ['cae', 'mw'],
    "bhūtakesarā": ['mw'],
    "bhūtaketu": ['mw'],
    "bhūtakeśa": ['mw'],
    "bhūtakeśī": ['mw'],
    "bhūtakoṭi": ['bhs', 'mw'],
    "bhūtakrānti": ['mw'],
    "bhūtakāla": ['cae', 'cped', 'mw'],
    "bhūtakālika": ['mw'],
    "bhūtakāya": ['cped'],
    "bhūtakṛt": ['cae', 'mw'],
    "bhūtala": ['cae', 'ddsa', 'mw'],
    "bhūtalakṣaṇa": ['mw'],
    "bhūtalastha": ['mw'],
    "bhūtalasthāna": ['mw'],
    "bhūtalikā": ['mw'],
    "bhūtalipi": ['mw'],
    "bhūtalonmathana": ['mw'],
    "bhūtamaheśvara": ['cae', 'mw'],
    "bhūtamaya": ['ap90', 'cae', 'mw'],
    "bhūtamukha": ['bhs'],
    "bhūtamārī": ['mw'],
    "bhūtamātotsava": ['mw'],
    "bhūtamātra": ['mw'],
    "bhūtamātrā": ['cae', 'mw'],
    "bhūtamātṛ": ['cae', 'mw'],
    "bhūtamātṛkā": ['mw'],
    "bhūtananda": ['mw'],
    "bhūtanicaya": ['mw'],
    "bhūtanātha": ['mw'],
    "bhūtanāyikā": ['mw'],
    "bhūtanāśana": ['mw'],
    "bhūtapati": ['cae', 'cped', 'mw'],
    "bhūtapattrī": ['mw'],
    "bhūtaprakṛti": ['mw'],
    "bhūtapratiṣedha": ['mw'],
    "bhūtapretapiśācādya": ['mw'],
    "bhūtaprāya": ['mw'],
    "bhūtapubbaṁ": ['cped'],
    "bhūtapura": ['mw'],
    "bhūtapurī": ['mw'],
    "bhūtapurīmāhātmya": ['mw'],
    "bhūtapuṣpa": ['mw'],
    "bhūtapāla": ['mw'],
    "bhūtapūrva": ['cae', 'mw'],
    "bhūtapūrvaka": ['cae'],
    "bhūtapūrvam": ['mw'],
    "bhūtapūrvaṭā": ['mw'],
    "bhūtapūrṇimā": ['mw'],
    "bhūtaraya": ['mw'],
    "bhūtaraśmi": ['bhs'],
    "bhūtarāj": ['mw'],
    "bhūtarūpa": ['mw'],
    "bhūtasammohana": ['mw'],
    "bhūtasamplava": ['mw'],
    "bhūtasampṛkta": ['mw'],
    "bhūtasamāgama": ['mw'],
    "bhūtasarga": ['cae', 'mw'],
    "bhūtasaṃcāra": ['mw'],
    "bhūtasaṃcārin": ['mw'],
    "bhūtasaṃgha": ['mw'],
    "bhūtasaṃkrāmin": ['mw'],
    "bhūtasaṃplava": ['cae'],
    "bhūtasaṃsāra": ['cae', 'mw'],
    "bhūtasaṃtāpa": ['mw'],
    "bhūtasaṃtāpana": ['mw'],
    "bhūtastha": ['cae', 'mw'],
    "bhūtasthāna": ['mw'],
    "bhūtasādhana": ['mw'],
    "bhūtasādhanī": ['mw'],
    "bhūtasākṣin": ['cae', 'mw'],
    "bhūtasāra": ['mw'],
    "bhūtasārī": ['mw'],
    "bhūtasūkṣma": ['mw'],
    "bhūtasṛṣṭi": ['mw'],
    "bhūtatanmātra": ['mw'],
    "bhūtatantra": ['mw'],
    "bhūtatta": ['cped'],
    "bhūtatva": ['mw'],
    "bhūtatā": ['mw'],
    "bhūtatṛṇa": ['mw'],
    "bhūtavarga": ['mw'],
    "bhūtavat": ['cae', 'ddsa', 'mw'],
    "bhūtavejja": ['cped'],
    "bhūtaveṣī": ['mw'],
    "bhūtavid": ['cae', 'mw'],
    "bhūtavidyā": ['cae', 'mw'],
    "bhūtavijjā": ['cped'],
    "bhūtavijñāna": ['mw'],
    "bhūtavikriyā": ['mw'],
    "bhūtavināyaka": ['mw'],
    "bhūtaviveka": ['mw'],
    "bhūtaviṣṇu": ['mw'],
    "bhūtavādin": ['mw'],
    "bhūtavādī": ['cped'],
    "bhūtavāhana": ['mw'],
    "bhūtavāhanasarathi": ['mw'],
    "bhūtavāsa": ['mw'],
    "bhūtavīra": ['mw'],
    "bhūtavṛkṣa": ['mw'],
    "bhūtayajña": ['cae', 'mw'],
    "bhūtayoni": ['cae', 'mw'],
    "bhūtaśarman": ['mw'],
    "bhūtaśuddhi": ['mw'],
    "bhūtaḍāmara": ['bhs', 'mw'],
    "bhūtaḍāmarī": ['mw'],
    "bhūtechad": ['ddsa', 'mw'],
    "bhūtejya": ['cae', 'ddsa', 'mw'],
    "bhūtendriyajayin": ['mw'],
    "bhūteśa": ['cae', 'mw'],
    "bhūteśvara": ['cae', 'mw'],
    "bhūteṣṭakā": ['mw'],
    "bhūteṣṭā": ['mw'],
    "bhūti": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "bhūtibali": ['mw'],
    "bhūtibhūṣaṇa": ['mw'],
    "bhūtida": ['cae', 'mw'],
    "bhūtidatta": ['mw'],
    "bhūtigarbha": ['mw'],
    "bhūtigaurī": ['mw'],
    "bhūtika": ['bhs', 'cped', 'mw'],
    "bhūtikalaśa": ['mw'],
    "bhūtikarman": ['cae', 'ddsa', 'mw'],
    "bhūtikaṃ": ['ap90'],
    "bhūtikāla": ['mw'],
    "bhūtikāma": ['cae', 'mw'],
    "bhūtikīla": ['mw'],
    "bhūtikīrtana": ['mw'],
    "bhūtikṛt": ['cae', 'mw'],
    "bhūtikṛtya": ['cae', 'mw'],
    "bhūtilaya": ['mw'],
    "bhūtimalina": ['mw'],
    "bhūtimant": ['cae'],
    "bhūtimat": ['mw'],
    "bhūtimitra": ['mw'],
    "bhūtinanda": ['mw'],
    "bhūtinidhāna": ['mw'],
    "bhūtirāja": ['mw'],
    "bhūtisita": ['mw'],
    "bhūtisṛj": ['mw'],
    "bhūtitīrthā": ['mw'],
    "bhūtivardhana": ['mw'],
    "bhūtivarman": ['mw'],
    "bhūtivāhana": ['mw'],
    "bhūtiyuvaka": ['mw'],
    "bhūtiśiva": ['mw'],
    "bhūtiśubhra": ['mw'],
    "bhūtiḥ": ['ap90'],
    "bhūtodana": ['mw'],
    "bhūtonmāda": ['mw'],
    "bhūtopadeśa": ['mw'],
    "bhūtopahata": ['mw'],
    "bhūtopahatacitta": ['mw'],
    "bhūtopamā": ['mw'],
    "bhūtopasarga": ['mw'],
    "bhūtoḍḍāmara": ['mw'],
    "bhūttama": ['mw'],
    "bhūtumbī": ['mw'],
    "bhūtvā": ['cped'],
    "bhūtvāśraddha": ['bhs'],
    "bhūtyakaṇṭaka": ['mw'],
    "bhūtyartham": ['ddsa', 'mw'],
    "bhūtā": ['mw'],
    "bhūtābhiṣaṅga": ['mw'],
    "bhūtādhipati": ['cae', 'mw'],
    "bhūtādi": ['cae', 'mw'],
    "bhūtādika": ['mw'],
    "bhūtālī": ['mw'],
    "bhūtānadyatana": ['cae', 'mw'],
    "bhūtāntaka": ['mw'],
    "bhūtānukampā": ['mw'],
    "bhūtārabdha": ['mw'],
    "bhūtāri": ['mw'],
    "bhūtārma": ['mw'],
    "bhūtārta": ['mw'],
    "bhūtārtha": ['cae', 'mw'],
    "bhūtārthakathana": ['mw'],
    "bhūtārthaketu": ['bhs'],
    "bhūtārthavarṇana": ['mw'],
    "bhūtārthavyāhṛti": ['mw'],
    "bhūtārthika": ['bhs'],
    "bhūtārthānubhava": ['mw'],
    "bhūtāsana": ['mw'],
    "bhūtātmaka": ['ddsa', 'mw'],
    "bhūtātman": ['cae', 'mw'],
    "bhūtāveśa": ['mw'],
    "bhūtāviṣṭa": ['mw'],
    "bhūtāvāsa": ['cae', 'mw'],
    "bhūtāyana": ['mw'],
    "bhūtāṃśa": ['gra', 'mw'],
    "bhūtāṅkuśa": ['mw'],
    "bhūtīka": ['mw'],
    "bhūtīśvaratīrtha": ['mw'],
    "bhūtṛṇa": ['mw'],
    "bhūvah": ['mw'],
    "bhūvalaya": ['mw'],
    "bhūvallabha": ['mw'],
    "bhūvallūra": ['mw'],
    "bhūvarī": ['mw'],
    "bhūvāka": ['mw'],
    "bhūvārāhaprayogavidhi": ['mw'],
    "bhūvṛtta": ['mw'],
    "bhūya": ['ddsa', 'mw'],
    "bhūyarūpa": ['mw'],
    "bhūyas": ['ap90', 'ddsa', 'gra', 'mw'],
    "bhūyaskara": ['mw'],
    "bhūyaskāma": ['mw'],
    "bhūyaskāmatā": ['bhs', 'mw'],
    "bhūyaskṛt": ['mw'],
    "bhūyastaram": ['ddsa', 'mw'],
    "bhūyastarām": ['mw'],
    "bhūyastva": ['cae', 'ddsa', 'mw'],
    "bhūyastvaṃ": ['ap90'],
    "bhūyastvena": ['mw'],
    "bhūyasvin": ['mw'],
    "bhūyasya": ['bhs'],
    "bhūyasā": ['mw'],
    "bhūyatva": ['mw'],
    "bhūyaś": ['mw'],
    "bhūyaśas": ['ap90', 'ddsa', 'mw'],
    "bhūyaśchandika": ['bhs', 'mw'],
    "bhūyaḥ": ['mw'],
    "bhūyaḥpalāyana": ['ddsa', 'mw'],
    "bhūyaḥsannivṛtti": ['ddsa'],
    "bhūyaḥsaṃnivṛtti": ['mw'],
    "bhūyaḥstana": ['mw'],
    "bhūyaṃ": ['ap90'],
    "bhūyaṃs": ['cae'],
    "bhūyiṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhūyiṣṭhabhāj": ['mw'],
    "bhūyiṣṭham": ['mw'],
    "bhūyiṣṭhatara": ['mw'],
    "bhūyiṣṭhaśas": ['mw'],
    "bhūyiṣṭhena": ['mw'],
    "bhūyo": ['mw'],
    "bhūyobhartṛsamāgama": ['mw'],
    "bhūyobhiprāya": ['bhs'],
    "bhūyobhāva": ['mw'],
    "bhūyodarśana": ['mw'],
    "bhūyodarśanavāda": ['mw'],
    "bhūyoguṇa": ['ddsa', 'mw'],
    "bhūyokṣara": ['mw'],
    "bhūyokṣaratara": ['mw'],
    "bhūyomātra": ['mw'],
    "bhūyonāgamana": ['mw'],
    "bhūyoruci": ['mw'],
    "bhūyorucitā": ['bhs', 'mw'],
    "bhūyosya": ['bhs'],
    "bhūyovidya": ['mw'],
    "bhūyuktā": ['mw'],
    "bhūśakra": ['mw'],
    "bhūśamī": ['mw'],
    "bhūśarkarā": ['mw'],
    "bhūśaya": ['cae', 'mw'],
    "bhūśayyā": ['mw'],
    "bhūśelu": ['mw'],
    "bhūśravas": ['mw'],
    "bhūśuddhi": ['mw'],
    "bhūśuddhilakṣaṇa": ['mw'],
    "bhūśvabhra": ['mw'],
    "bhūḥ": ['ap90'],
    "bhūḥkhāra": ['ddsa', 'mw'],
    "bhūṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhūṣayitavya": ['cae', 'ddsa', 'mw'],
    "bhūṣaṇa": ['cae', 'ddsa', 'mw'],
    "bhūṣaṇabhaṭṭa": ['mw'],
    "bhūṣaṇabhūṣaṇa": ['mw'],
    "bhūṣaṇadeva": ['mw'],
    "bhūṣaṇadāyaka": ['mw'],
    "bhūṣaṇakānti": ['mw'],
    "bhūṣaṇapeṭikā": ['mw'],
    "bhūṣaṇasāra": ['mw'],
    "bhūṣaṇatā": ['mw'],
    "bhūṣaṇavāsas": ['mw'],
    "bhūṣaṇaṃ": ['ap90'],
    "bhūṣaṇaṭīkā": ['mw'],
    "bhūṣaṇendraprabha": ['bhs', 'mw'],
    "bhūṣaṇā": ['bhs'],
    "bhūṣaṇācchādanāśana": ['mw'],
    "bhūṣaṇīya": ['mw'],
    "bhūṣika": ['mw'],
    "bhūṣin": ['cae', 'ddsa', 'mw'],
    "bhūṣita": ['ap90'],
    "bhūṣiṇikā": ['bhs'],
    "bhūṣya": ['cae', 'ddsa', 'mw'],
    "bhūṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhūṣāpeṭī": ['mw'],
    "bhūṣāy": ['cae'],
    "bhūṣāya": ['ddsa', 'mw'],
    "bhūṣṇu": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bhṛg": ['ap90', 'mw'],
    "bhṛgala": ['mw'],
    "bhṛgamātrika": ['mw'],
    "bhṛgavāṇa": ['gra', 'mw'],
    "bhṛgin": ['bhs'],
    "bhṛgu": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "bhṛgubharatasaṃvāda": ['mw'],
    "bhṛgubhavā": ['mw'],
    "bhṛgubhūmi": ['mw'],
    "bhṛgudeva": ['mw'],
    "bhṛgudevata": ['mw'],
    "bhṛgugītā": ['mw'],
    "bhṛguharītakī": ['mw'],
    "bhṛguja": ['mw'],
    "bhṛgukaccha": ['mw'],
    "bhṛgukacchatīrtha": ['mw'],
    "bhṛgukulodvaha": ['mw'],
    "bhṛgukṣetra": ['mw'],
    "bhṛgukṣetramāhātmya": ['mw'],
    "bhṛgumaṇḍala": ['mw'],
    "bhṛgunandana": ['cae', 'mw'],
    "bhṛgupatana": ['mw'],
    "bhṛgupati": ['cae', 'mw'],
    "bhṛgupaṭala": ['mw'],
    "bhṛguprasravaṇa": ['mw'],
    "bhṛguputra": ['mw'],
    "bhṛgupāta": ['mw'],
    "bhṛgurāja": ['mw'],
    "bhṛgurākṣasa": ['mw'],
    "bhṛgusattama": ['mw'],
    "bhṛgusaṃhitā": ['mw'],
    "bhṛgusaṃhitāsāra": ['mw'],
    "bhṛgusiddhānta": ['mw'],
    "bhṛgusmṛti": ['mw'],
    "bhṛgusuta": ['mw'],
    "bhṛgusūnu": ['mw'],
    "bhṛgusūtra": ['mw'],
    "bhṛgutanaya": ['mw'],
    "bhṛgutuṅga": ['cae', 'mw'],
    "bhṛgutīrthamāhātmya": ['mw'],
    "bhṛguvallyupaniṣad": ['mw'],
    "bhṛguvallī": ['mw'],
    "bhṛguvat": ['gra'],
    "bhṛguvaṃśa": ['mw'],
    "bhṛguvāra": ['mw'],
    "bhṛguvāruṇīyopaniṣadbhāṣya": ['mw'],
    "bhṛguvāsara": ['mw'],
    "bhṛguśreṣṭha": ['mw'],
    "bhṛguśārdūla": ['mw'],
    "bhṛguḥ": ['ap90'],
    "bhṛgv": ['mw'],
    "bhṛgvandīya": ['mw'],
    "bhṛgvaṅgiras": ['mw'],
    "bhṛgvaṅgirasikā": ['mw'],
    "bhṛgvaṅgirovid": ['mw'],
    "bhṛgvīśvaratīrtha": ['mw'],
    "bhṛgūdvaha": ['cae', 'mw'],
    "bhṛgūlāpati": ['mw'],
    "bhṛgūpaniṣad": ['mw'],
    "bhṛj": ['ap90', 'mw'],
    "bhṛjj": ['cae', 'gra', 'mw'],
    "bhṛjja": ['mw'],
    "bhṛjjakaṇṭaka": ['mw'],
    "bhṛjjakaṇṭha": ['mw'],
    "bhṛjjakaṇṭhaka": ['mw'],
    "bhṛjjana": ['cae', 'ddsa'],
    "bhṛjjanaṃ": ['ap90'],
    "bhṛjyakaṇṭha": ['ddsa'],
    "bhṛjāyana": ['mw'],
    "bhṛkta": ['mw'],
    "bhṛkuṃsa": ['mw'],
    "bhṛkuṃsaka": ['mw'],
    "bhṛkuṃsaḥ": ['ap90'],
    "bhṛkuṃśa": ['mw'],
    "bhṛkuṃśaḥ": ['ap90'],
    "bhṛkuṭi": ['cae', 'ddsa', 'mw'],
    "bhṛkuṭidhara": ['mw'],
    "bhṛkuṭika": ['bhs'],
    "bhṛkuṭinī": ['bhs'],
    "bhṛkuṭiḥ": ['ap90'],
    "bhṛkuṭī": ['bhs', 'cae', 'mw'],
    "bhṛkuṭīka": ['bhs'],
    "bhṛkṣ": ['mw'],
    "bhṛma": ['cae', 'ddsa', 'gra', 'mw'],
    "bhṛmala": ['cae', 'ddsa', 'mw'],
    "bhṛmaḥ": ['ap90'],
    "bhṛmi": ['cae', 'ddsa', 'gra', 'mw'],
    "bhṛmiḥ": ['ap90'],
    "bhṛmyaśva": ['mw'],
    "bhṛt": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhṛtabhūti": ['mw'],
    "bhṛtaka": ['ap90', 'cae', 'mw'],
    "bhṛtakādhyayana": ['mw'],
    "bhṛtakādhyāpaka": ['cae', 'mw'],
    "bhṛtakādhyāpana": ['mw'],
    "bhṛtakādhyāpita": ['cae', 'mw'],
    "bhṛtarandhra": ['mw'],
    "bhṛtha": ['cae', 'ddsa', 'gra', 'mw'],
    "bhṛti": ['cae', 'ddsa', 'gra', 'mw'],
    "bhṛtibhuj": ['mw'],
    "bhṛtikarmakara": ['mw'],
    "bhṛtikā": ['bhs', 'mw'],
    "bhṛtin": ['mw'],
    "bhṛtirūpa": ['mw'],
    "bhṛtiḥ": ['ap90'],
    "bhṛtra": ['mw'],
    "bhṛtrima": ['ap90'],
    "bhṛttva": ['ddsa', 'mw'],
    "bhṛtya": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhṛtyabharaṇa": ['mw'],
    "bhṛtyabhartṛ": ['mw'],
    "bhṛtyabhāva": ['cae', 'mw'],
    "bhṛtyabhāvin": ['mw'],
    "bhṛtyadhyāpana": ['mw'],
    "bhṛtyajana": ['mw'],
    "bhṛtyakāmakṛt": ['mw'],
    "bhṛtyanna": ['ddsa', 'mw'],
    "bhṛtyaparamāṇu": ['ddsa', 'mw'],
    "bhṛtyartham": ['mw'],
    "bhṛtyatva": ['mw'],
    "bhṛtyatā": ['ap90', 'mw'],
    "bhṛtyavarga": ['mw'],
    "bhṛtyavātsalya": ['cae', 'mw'],
    "bhṛtyavṛtti": ['mw'],
    "bhṛtyaśālin": ['mw'],
    "bhṛtyā": ['mw'],
    "bhṛtyābhāva": ['mw'],
    "bhṛtyādhyāpana": ['mw'],
    "bhṛtyāy": ['cae'],
    "bhṛtyāya": ['ddsa', 'mw'],
    "bhṛtyāyate": ['ap90'],
    "bhṛtyībhū": ['ap90', 'ddsa', 'mw'],
    "bhṛtādhyāpana": ['mw'],
    "bhṛś": ['ap90', 'mw'],
    "bhṛśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "bhṛśadaṇḍa": ['cae', 'mw'],
    "bhṛśaduḥkhita": ['mw'],
    "bhṛśadāruṇa": ['mw'],
    "bhṛśakopana": ['mw'],
    "bhṛśam": ['mw'],
    "bhṛśanāstika": ['mw'],
    "bhṛśapattrikā": ['mw'],
    "bhṛśapīḍita": ['mw'],
    "bhṛśasaṃhṛṣṭa": ['mw'],
    "bhṛśasaṃyuta": ['mw'],
    "bhṛśasvid": ['mw'],
    "bhṛśatā": ['mw'],
    "bhṛśavedanā": ['mw'],
    "bhṛśavismita": ['mw'],
    "bhṛśaśokavardhana": ['mw'],
    "bhṛśāya": ['mw'],
    "bhṛśāyate": ['ap90'],
    "bhṛśībhū": ['mw'],
    "bhṛḍ": ['mw'],
    "bhṛṃgakaḥ": ['ap90'],
    "bhṛṃgaḥ": ['ap90'],
    "bhṛṃgeriṭiḥ": ['ap90'],
    "bhṛṃgin": ['ap90'],
    "bhṛṃgiriṭiḥ": ['ap90'],
    "bhṛṃgirīṭiḥ": ['ap90'],
    "bhṛṃgālikā": ['ap90'],
    "bhṛṃgāraḥ": ['ap90'],
    "bhṛṃś": ['mw'],
    "bhṛṃḍiḥ": ['ap90'],
    "bhṛṃṭikā": ['ap90'],
    "bhṛṅga": ['cae', 'ddsa', 'mw'],
    "bhṛṅgaja": ['mw'],
    "bhṛṅgajā": ['mw'],
    "bhṛṅgaka": ['mw'],
    "bhṛṅgamārī": ['mw'],
    "bhṛṅgamūlikā": ['mw'],
    "bhṛṅgaparṇikā": ['mw'],
    "bhṛṅgapriyā": ['mw'],
    "bhṛṅgaraja": ['mw'],
    "bhṛṅgarajas": ['mw'],
    "bhṛṅgarasa": ['mw'],
    "bhṛṅgariṭi": ['mw'],
    "bhṛṅgarola": ['mw'],
    "bhṛṅgarāja": ['mw'],
    "bhṛṅgarājaka": ['mw'],
    "bhṛṅgarājarasa": ['mw'],
    "bhṛṅgarīṭa": ['mw'],
    "bhṛṅgarīṭi": ['mw'],
    "bhṛṅgasodara": ['mw'],
    "bhṛṅgasvāmin": ['mw'],
    "bhṛṅgasārtha": ['cae', 'mw'],
    "bhṛṅgavallabha": ['mw'],
    "bhṛṅgavallabhā": ['mw'],
    "bhṛṅgavṛkṣa": ['mw'],
    "bhṛṅgeriṭi": ['mw'],
    "bhṛṅgeśasaṃhitā": ['mw'],
    "bhṛṅgeṣṭā": ['mw'],
    "bhṛṅgi": ['mw'],
    "bhṛṅgin": ['bhs', 'ddsa', 'mw'],
    "bhṛṅgiriṭa": ['ddsa', 'mw'],
    "bhṛṅgiriṭi": ['mw'],
    "bhṛṅgirīṭi": ['mw'],
    "bhṛṅgiṇī": ['mw'],
    "bhṛṅgā": ['mw'],
    "bhṛṅgābhīṣṭa": ['mw'],
    "bhṛṅgādhipa": ['mw'],
    "bhṛṅgāhva": ['mw'],
    "bhṛṅgāhvā": ['mw'],
    "bhṛṅgāli": ['cae'],
    "bhṛṅgālī": ['ddsa', 'mw'],
    "bhṛṅgānandā": ['mw'],
    "bhṛṅgānaṅga": ['bhs'],
    "bhṛṅgāra": ['cae', 'ddsa', 'mw'],
    "bhṛṅgāraka": ['mw'],
    "bhṛṅgāri": ['mw'],
    "bhṛṅgārikā": ['mw'],
    "bhṛṅgāru": ['mw'],
    "bhṛṅgārī": ['mw'],
    "bhṛṅgārīṭa": ['mw'],
    "bhṛṅgāvalī": ['mw'],
    "bhṛṅgāy": ['cae'],
    "bhṛṅgāya": ['ddsa', 'mw'],
    "bhṛṅgāṇa": ['mw'],
    "bhṛṅgāṣṭaka": ['mw'],
    "bhṛṅgī": ['mw'],
    "bhṛṅgīphala": ['mw'],
    "bhṛṅgīriṭi": ['mw'],
    "bhṛṅgīśa": ['mw'],
    "bhṛṇīya": ['mw'],
    "bhṛṇḍi": ['mw'],
    "bhṛṇṭikā": ['mw'],
    "bhṛṣṭa": ['ap90', 'ddsa', 'mw'],
    "bhṛṣṭakāra": ['mw'],
    "bhṛṣṭapiṣṭa": ['mw'],
    "bhṛṣṭataṇḍula": ['mw'],
    "bhṛṣṭayava": ['mw'],
    "bhṛṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "bhṛṣṭimant": ['cae'],
    "bhṛṣṭimat": ['gra', 'mw'],
    "bhṛṣṭiḥ": ['ap90'],
    "bhṛṣṭānna": ['mw'],
    "bhṛṣṭī": ['mw'],
    "bhṝ": ['ap90', 'mw'],
    "bibboka": ['ddsa', 'mw'],
    "bibbokaḥ": ['ap90'],
    "bibhakṣayiṣu": ['mw'],
    "bibhakṣayiṣudaṃṣṭrin": ['mw'],
    "bibhakṣayiṣā": ['ddsa', 'mw'],
    "bibhatsa": ['bhs'],
    "bibhatsana": ['bhs'],
    "bibhaṇiṣu": ['ddsa', 'mw'],
    "bibhedayiṣu": ['ddsa', 'mw'],
    "bibhitsu": ['ap90', 'mw'],
    "bibhitsā": ['ap90', 'ddsa', 'mw'],
    "bibhradvāja": ['mw'],
    "bibhrajjiṣu": ['ap90', 'mw'],
    "bibhrajjiṣuprakhya": ['mw'],
    "bibhrakṣu": ['ap90', 'mw'],
    "bibhrat": ['mw'],
    "bibhīṣaka": ['ap90'],
    "bibhīṣaṇa": ['ap90'],
    "bibhīṣikā": ['ap90', 'mw'],
    "bibibābhavat": ['mw'],
    "bibodhayiṣu": ['mw'],
    "bid": ['ap90', 'mw'],
    "bida": ['mw'],
    "bidakula": ['mw'],
    "bidala": ['cae', 'cped', 'ddsa', 'mw'],
    "bidalakārī": ['mw'],
    "bidalasaṃhita": ['mw'],
    "bidalaṃ": ['ap90'],
    "bidura": ['mw'],
    "bidālaka": ['mw'],
    "bidālikā": ['mw'],
    "bidāpuṭa": ['mw'],
    "bihlaṇa": ['mw'],
    "bil": ['ap90', 'mw'],
    "bila": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "biladhāvana": ['mw'],
    "bilakārin": ['mw'],
    "bilasa": ['mw'],
    "bilaso": ['cped'],
    "bilasvarga": ['mw'],
    "bilaukas": ['cae', 'ddsa', 'mw'],
    "bilavat": ['mw'],
    "bilavāsa": ['cae', 'mw'],
    "bilavāsin": ['cae', 'mw'],
    "bilayoni": ['mw'],
    "bilaśaya": ['cae', 'mw'],
    "bilaśāyin": ['cae', 'mw'],
    "bilaṃ": ['ap90'],
    "bilaṃgama": ['mw'],
    "bilaṃgamaḥ": ['ap90'],
    "bilaṅga": ['cped'],
    "bilaṅgathālikā": ['cped'],
    "bilevāsin": ['mw'],
    "bileśaya": ['cae', 'ddsa', 'mw'],
    "bileśayaḥ": ['ap90'],
    "bileśvara": ['mw'],
    "bilhaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "bilhaṇacaritra": ['mw'],
    "bilhaṇakāvya": ['mw'],
    "bilhaṇapañcāśikā": ['mw'],
    "bilhaṇaśataka": ['mw'],
    "bilhaṇaḥ": ['ap90'],
    "bilhaṇīya": ['mw'],
    "bilintha": ['mw'],
    "biliśa": ['bhs', 'cae', 'mw'],
    "billa": ['cped', 'mw'],
    "billamūlā": ['mw'],
    "billasū": ['mw'],
    "billaṃ": ['ap90'],
    "bilma": ['cae', 'ddsa', 'gra', 'mw'],
    "bilmagrahaṇa": ['mw'],
    "bilmaṃ": ['ap90'],
    "bilmin": ['cae', 'mw'],
    "bilva": ['cae', 'ddsa', 'mw'],
    "bilvadaṇḍa": ['mw'],
    "bilvadaṇḍin": ['mw'],
    "bilvaja": ['mw'],
    "bilvaka": ['mw'],
    "bilvakīyā": ['ap90', 'mw'],
    "bilvala": ['mw'],
    "bilvamadhya": ['mw'],
    "bilvamaṅgala": ['mw'],
    "bilvamaṅgalastotra": ['mw'],
    "bilvamaṅgalaṭīkā": ['mw'],
    "bilvamātra": ['cae', 'mw'],
    "bilvanātha": ['mw'],
    "bilvaparṇī": ['mw'],
    "bilvapattra": ['mw'],
    "bilvapattramaya": ['mw'],
    "bilvapattrikā": ['mw'],
    "bilvapeśikā": ['mw'],
    "bilvapeśī": ['mw'],
    "bilvapāṇḍara": ['mw'],
    "bilvapāṇḍura": ['mw'],
    "bilvatejas": ['mw'],
    "bilvavana": ['mw'],
    "bilvavanamāhātmya": ['mw'],
    "bilvaḥ": ['ap90'],
    "bilveśvaramāhātmya": ['mw'],
    "bilvodakeśvara": ['mw'],
    "bilvopaniṣad": ['mw'],
    "bilvā": ['mw'],
    "bilvāmraka": ['mw'],
    "bilvāmrakamāhātmya": ['mw'],
    "bilvāntara": ['mw'],
    "bilvāraṇyamāhātmya": ['mw'],
    "bilvāṣṭaka": ['mw'],
    "bilāla": ['mw'],
    "bilāsin": ['mw'],
    "bilāyana": ['mw'],
    "bimba": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bimbahu": ['bhs'],
    "bimbajā": ['mw'],
    "bimbaka": ['bhs', 'mw'],
    "bimbaki": ['ddsa', 'mw'],
    "bimbalakṣaṇa": ['mw'],
    "bimbaphala": ['mw'],
    "bimbaphalādharoṣṭha": ['mw'],
    "bimbapratibimba": ['mw'],
    "bimbapratibimbabhāva": ['mw'],
    "bimbapratibimbatva": ['mw'],
    "bimbapratibimbatā": ['ddsa', 'mw'],
    "bimbapratibimbavāda": ['mw'],
    "bimbapratiṣṭhā": ['mw'],
    "bimbapratiṣṭhāvidhi": ['mw'],
    "bimbara": ['bhs', 'mw'],
    "bimbasāra": ['bhs', 'mw'],
    "bimbatattvaprakāśikā": ['mw'],
    "bimbaṭa": ['mw'],
    "bimbeśvara": ['ddsa', 'mw'],
    "bimbi": ['bhs'],
    "bimbikā": ['cped'],
    "bimbinī": ['mw'],
    "bimbisāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "bimbita": ['cae', 'ddsa', 'mw'],
    "bimbiya": ['ddsa', 'mw'],
    "bimboka": ['mw'],
    "bimbopadhāna": ['bhs', 'mw'],
    "bimboṣṭha": ['mw'],
    "bimbu": ['mw'],
    "bimbā": ['cped', 'mw'],
    "bimbādhara": ['cae', 'mw'],
    "bimbāgata": ['mw'],
    "bimbānubimbatva": ['mw'],
    "bimbāva": ['mw'],
    "bimbī": ['cped', 'mw'],
    "bind": ['mw'],
    "binda": ['mw'],
    "bindavi": ['mw'],
    "bindavīya": ['mw'],
    "bindu": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bindubheda": ['mw'],
    "bindubrahmānandīya": ['mw'],
    "binducitra": ['mw'],
    "binducitraka": ['mw'],
    "bindudeva": ['mw'],
    "bindughṛta": ['mw'],
    "binduhrada": ['mw'],
    "bindujāla": ['mw'],
    "bindujālaka": ['mw'],
    "binduka": ['cae', 'mw'],
    "bindukita": ['mw'],
    "bindula": ['mw'],
    "bindumant": ['cae'],
    "bindumat": ['ddsa', 'mw'],
    "bindumatta": ['cped'],
    "bindumattaṁ": ['cped'],
    "bindumatī": ['mw'],
    "bindumādhava": ['mw'],
    "bindumālin": ['mw'],
    "bindunātha": ['mw'],
    "bindupattra": ['mw'],
    "bindupattraka": ['mw'],
    "binduphala": ['mw'],
    "bindupratiṣṭhāmaya": ['mw'],
    "binduraka": ['mw'],
    "bindurekhaka": ['mw'],
    "bindurekhā": ['mw'],
    "bindurāji": ['mw'],
    "bindusaras": ['mw'],
    "bindusarastīrtha": ['mw'],
    "bindusaṃdīpana": ['mw'],
    "bindusaṃgraha": ['mw'],
    "bindusena": ['cae', 'mw'],
    "bindusāra": ['bhs', 'cae', 'mw'],
    "bindutantra": ['mw'],
    "bindutīrtha": ['mw'],
    "bindutīrthamāhātmya": ['mw'],
    "binduvāsara": ['mw'],
    "binduśarman": ['mw'],
    "bindūpaniṣad": ['mw'],
    "bindūy": ['cae'],
    "bindūya": ['mw'],
    "birada": ['mw'],
    "biruda": ['mw'],
    "birāla": ['mw'],
    "bis": ['ap90', 'mw'],
    "bisa": ['cae', 'ddsa', 'gra', 'mw'],
    "bisagranthi": ['mw'],
    "bisaguṇa": ['mw'],
    "bisaja": ['mw'],
    "bisakaṇṭhikā": ['mw'],
    "bisakaṇṭhin": ['mw'],
    "bisakhā": ['gra', 'mw'],
    "bisakhādikā": ['mw'],
    "bisakisalayacchedapātheyavat": ['mw'],
    "bisakusuma": ['mw'],
    "bisala": ['mw'],
    "bisalatā": ['mw'],
    "bisalaṃ": ['ap90'],
    "bisalāvam": ['mw'],
    "bisamṛṇala": ['mw'],
    "bisanābhi": ['mw'],
    "bisanāsikā": ['mw'],
    "bisaprasūna": ['cae', 'mw'],
    "bisapuṣpa": ['mw'],
    "bisatantu": ['cae', 'mw'],
    "bisatantumaya": ['mw'],
    "bisavartman": ['mw'],
    "bisavatī": ['ap90', 'cae', 'mw'],
    "bisaśālūka": ['mw'],
    "bisaṃ": ['ap90'],
    "bisila": ['ap90', 'mw'],
    "bisinī": ['ap90', 'cae', 'ddsa', 'mw'],
    "bisinīpattra": ['mw'],
    "bisorṇā": ['mw'],
    "bistaḥ": ['ap90'],
    "bisābharaṇa": ['mw'],
    "bisākara": ['mw'],
    "bisākāra": ['mw'],
    "biś": ['mw'],
    "biśa": ['mw'],
    "biśāyaka": ['mw'],
    "biḍ": ['mw'],
    "biḍaujas": ['ap90'],
    "biḍaṃ": ['ap90'],
    "biḍāla": ['cae', 'ddsa', 'mw'],
    "biḍālabhastrā": ['bhs'],
    "biḍālaka": ['cae'],
    "biḍālakaḥ": ['ap90'],
    "biḍālapada": ['mw'],
    "biḍālapadaka": ['mw'],
    "biḍālaputra": ['mw'],
    "biḍālavaṇij": ['mw'],
    "biḍālavratika": ['mw'],
    "biḍālaḥ": ['ap90'],
    "biḍālā": ['mw'],
    "biḍālākṣa": ['cae', 'mw'],
    "biḍālākṣī": ['mw'],
    "biḍālī": ['mw'],
    "biḍāraka": ['mw'],
    "biḷālī": ['cped'],
    "biḷāra": ['cped'],
    "biḷārabhastā": ['cped'],
    "biṃbakaṃ": ['ap90'],
    "biṃbaḥ": ['ap90'],
    "biṃbaṭaḥ": ['ap90'],
    "biṃbikā": ['ap90'],
    "biṃbita": ['ap90'],
    "biṃdaviḥ": ['ap90'],
    "biṃduḥ": ['ap90'],
    "biṣa": ['mw'],
    "biṣkala": ['mw'],
    "biṣkalā": ['cae', 'mw'],
    "biṭ": ['ap90', 'mw'],
    "biṭaka": ['mw'],
    "biṭakaḥ": ['ap90'],
    "biṭhaka": ['mw'],
    "biṭhaṃ": ['ap90'],
    "bleṣka": ['cae', 'ddsa', 'mw'],
    "bleṣkaṃ": ['ap90'],
    "blī": ['mw'],
    "boddhavya": ['cae', 'ddsa', 'mw'],
    "boddhṛ": ['cae', 'mw'],
    "boddhṛtva": ['mw'],
    "bodha": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bodhacittavivaraṇa": ['mw'],
    "bodhadhiṣaṇa": ['mw'],
    "bodhagamya": ['mw'],
    "bodhaghanācārya": ['mw'],
    "bodhaikasiddhi": ['mw'],
    "bodhaka": ['ap90', 'cae', 'mw'],
    "bodhakara": ['mw'],
    "bodhakatva": ['mw'],
    "bodhamaya": ['cae', 'ddsa', 'mw'],
    "bodhana": ['ap90', 'cae', 'cped', 'mw'],
    "bodhanamantra": ['mw'],
    "bodhaneyya": ['cped'],
    "bodhanmanas": ['mw'],
    "bodhanī": ['mw'],
    "bodhanīya": ['cae', 'cped', 'mw'],
    "bodhapañcadaśikā": ['mw'],
    "bodhaprakriyā": ['mw'],
    "bodhapūrvam": ['mw'],
    "bodhapṛthvīdhara": ['mw'],
    "bodharāyācārya": ['mw'],
    "bodhasiddhi": ['mw'],
    "bodhasudhākara": ['mw'],
    "bodhasāra": ['mw'],
    "bodhatas": ['mw'],
    "bodhavatī": ['mw'],
    "bodhavilāsa": ['mw'],
    "bodhavāsara": ['mw'],
    "bodhayitavya": ['cae', 'ddsa', 'mw'],
    "bodhayitṛ": ['ap90', 'cae', 'gra', 'mw'],
    "bodhayiṣṇu": ['cae', 'mw'],
    "bodhendra": ['mw'],
    "bodhenta": ['cped'],
    "bodhesi": ['cped'],
    "bodhetar": ['cped'],
    "bodheti": ['cped'],
    "bodhetvā": ['cped'],
    "bodheya": ['mw'],
    "bodhi": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bodhibhadra": ['mw'],
    "bodhicitta": ['bhs'],
    "bodhicittavivaraṇa": ['mw'],
    "bodhicittotpādanaśāstra": ['mw'],
    "bodhicittāsaṃpramoṣa": ['bhs'],
    "bodhida": ['mw'],
    "bodhidharma": ['mw'],
    "bodhidruma": ['bhs', 'mw'],
    "bodhika": ['bhs'],
    "bodhiketu": ['bhs'],
    "bodhila": ['mw'],
    "bodhimaha": ['cped'],
    "bodhimaṇḍa": ['bhs', 'cped', 'ddsa', 'mw'],
    "bodhimaṇḍacūḍa": ['bhs'],
    "bodhimaṇḍala": ['bhs', 'mw'],
    "bodhimaṇḍamakuṭa": ['bhs'],
    "bodhimaṇḍavibuddhaśrīcandra": ['bhs'],
    "bodhimaṇḍālaṃkārasurucirā": ['bhs'],
    "bodhimaṇḍālaṃkāravyūha": ['bhs'],
    "bodhimūla": ['cped'],
    "bodhimūlasūtra": ['bhs'],
    "bodhin": ['ap90', 'cae', 'gra', 'mw'],
    "bodhinmanas": ['gra', 'mw'],
    "bodhinyāsa": ['mw'],
    "bodhipakkhika": ['cped'],
    "bodhipakkhiya": ['cped'],
    "bodhipakṣa": ['bhs'],
    "bodhipakṣadharma": ['mw'],
    "bodhipakṣadharmanirdeśa": ['mw'],
    "bodhipakṣanirdeśa": ['bhs'],
    "bodhipakṣika": ['bhs', 'mw'],
    "bodhipakṣya": ['bhs'],
    "bodhiparicārika": ['bhs'],
    "bodhipariniṣpatti": ['mw'],
    "bodhipaṭapattrakā": ['bhs'],
    "bodhipādapa": ['cped'],
    "bodhipākṣika": ['bhs'],
    "bodhipūjā": ['cped'],
    "bodhiruci": ['mw'],
    "bodhirukkha": ['cped'],
    "bodhisattva": ['bhs', 'cae', 'mw'],
    "bodhisattvabhūmi": ['bhs', 'mw'],
    "bodhisattvabuddhānusmṛtisamādhi": ['mw'],
    "bodhisattvacaryā": ['mw'],
    "bodhisattvacaryāvatāra": ['mw'],
    "bodhisattvajanman": ['bhs'],
    "bodhisattvakṣāntilābhāya": ['bhs'],
    "bodhisattvapakṣanirdeśa": ['mw'],
    "bodhisattvapiṭaka": ['bhs', 'mw'],
    "bodhisattvaprātimokṣa": ['bhs'],
    "bodhisattvasamuccayā": ['bhs', 'mw'],
    "bodhisattvasamādhi": ['bhs'],
    "bodhisattvasaṃcodiṇī": ['mw'],
    "bodhisattvasūtrapiṭaka": ['bhs'],
    "bodhisattvatā": ['mw'],
    "bodhisattvavimokṣa": ['bhs'],
    "bodhisattvayāna": ['bhs'],
    "bodhisattvāvadānakalpalatā": ['mw'],
    "bodhisattvāṃśa": ['mw'],
    "bodhisaṃghārāma": ['mw'],
    "bodhisiddhi": ['mw'],
    "bodhita": ['ap90', 'cped', 'mw'],
    "bodhitaru": ['mw'],
    "bodhitavya": ['cae', 'mw'],
    "bodhivaṭa": ['bhs'],
    "bodhivṛkṣa": ['mw'],
    "bodhiyaṣṭi": ['bhs'],
    "bodhiḥ": ['ap90'],
    "bodhiṅgaṇa": ['cped'],
    "bodhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "bodhyagītā": ['mw'],
    "bodhyaṅga": ['bhs', 'mw'],
    "bodhyaṅgavatī": ['bhs', 'mw'],
    "bodhyaṅgika": ['bhs'],
    "bodhyaṅgāyuṣya": ['bhs'],
    "bodhāna": ['ap90', 'mw'],
    "bodhānandaghana": ['mw'],
    "bodhāraṇyayati": ['mw'],
    "bodhāryā": ['mw'],
    "bodhātman": ['mw'],
    "bodhāyana": ['mw'],
    "bodhāyanakalpavivaraṇa": ['mw'],
    "bodhāyanaprayoga": ['mw'],
    "bodhāyanasūtra": ['mw'],
    "bodhāyanaśrauta": ['mw'],
    "bodhāyanīya": ['mw'],
    "bodhāyanīyagṛhyamālā": ['mw'],
    "bodhāyanīyā": ['mw'],
    "bohittha": ['mw'],
    "bojjhaṅga": ['cped'],
    "bokaḍī": ['mw'],
    "bokaṇa": ['mw'],
    "bokkāṇa": ['mw'],
    "bollaka": ['bhs', 'mw'],
    "bondi": ['cped'],
    "bopadeva": ['mw'],
    "bopaṇṇabhaṭṭīya": ['mw'],
    "borasiddhi": ['mw'],
    "bradhma": ['mw'],
    "bradhna": ['cae', 'ddsa', 'gra', 'mw'],
    "bradhnabimba": ['mw'],
    "bradhnacakra": ['mw'],
    "bradhnaloka": ['mw'],
    "bradhnamaṇḍala": ['mw'],
    "bradhnatva": ['mw'],
    "bradhnaśva": ['mw'],
    "bradhnaḥ": ['ap90'],
    "brahanta": ['cped'],
    "brahm": ['mw'],
    "brahma": ['cae', 'cped', 'ddsa', 'mw'],
    "brahmabala": ['mw'],
    "brahmabali": ['mw'],
    "brahmabandhava": ['mw'],
    "brahmabandhu": ['cped', 'mw'],
    "brahmabandhutā": ['mw'],
    "brahmabhadrā": ['mw'],
    "brahmabhavana": ['cae', 'mw'],
    "brahmabhaṭṭa": ['mw'],
    "brahmabhid": ['mw'],
    "brahmabhraṣṭa": ['mw'],
    "brahmabhuvana": ['cae', 'mw'],
    "brahmabhāga": ['cae', 'mw'],
    "brahmabhāva": ['cae', 'mw'],
    "brahmabhāvana": ['mw'],
    "brahmabhāvastotra": ['mw'],
    "brahmabhūmijā": ['mw'],
    "brahmabhūta": ['cae', 'cped', 'mw'],
    "brahmabhūti": ['mw'],
    "brahmabhūya": ['cae', 'mw'],
    "brahmabhūyas": ['mw'],
    "brahmabhūyatva": ['mw'],
    "brahmabhūyaṃs": ['cae'],
    "brahmabileya": ['mw'],
    "brahmabindu": ['mw'],
    "brahmabindūpaniṣad": ['mw'],
    "brahmabodha": ['mw'],
    "brahmabodhinī": ['mw'],
    "brahmabodhyā": ['mw'],
    "brahmabruva": ['mw'],
    "brahmabruvāṇa": ['mw'],
    "brahmabīja": ['mw'],
    "brahmacaitanyayati": ['mw'],
    "brahmacakra": ['mw'],
    "brahmacandrikā": ['mw'],
    "brahmacariya": ['bhs'],
    "brahmacariyā": ['cped'],
    "brahmacarya": ['cae', 'mw'],
    "brahmacaryaskhalana": ['mw'],
    "brahmacaryatva": ['mw'],
    "brahmacaryavat": ['mw'],
    "brahmacaryavrata": ['mw'],
    "brahmacaryāśrama": ['cae', 'mw'],
    "brahmacintananirākaraṇa": ['mw'],
    "brahmaciti": ['mw'],
    "brahmacodana": ['gra', 'mw'],
    "brahmacāraṇī": ['mw'],
    "brahmacārika": ['mw'],
    "brahmacārin": ['cae', 'gra', 'mw'],
    "brahmacārivāsa": ['mw'],
    "brahmacārivāsin": ['mw'],
    "brahmacāriṇī": ['mw'],
    "brahmacārī": ['cped'],
    "brahmada": ['cae', 'mw'],
    "brahmadaitya": ['mw'],
    "brahmadarbhā": ['mw'],
    "brahmadatta": ['bhs', 'cae', 'mw'],
    "brahmadattā": ['bhs'],
    "brahmadaṇḍa": ['bhs', 'cae', 'cped', 'mw'],
    "brahmadaṇḍin": ['mw'],
    "brahmadaṇḍī": ['mw'],
    "brahmadeva": ['bhs', 'mw'],
    "brahmadeya": ['cae', 'mw'],
    "brahmadeyya": ['cped'],
    "brahmadeyānusaṃtāna": ['mw'],
    "brahmadeyātmasaṃtāna": ['mw'],
    "brahmadhara": ['mw'],
    "brahmadharmadviṣ": ['mw'],
    "brahmadhvaja": ['bhs', 'mw'],
    "brahmadhvajopaniṣad": ['mw'],
    "brahmadhvaṃsadeva": ['bhs'],
    "brahmadhāman": ['mw'],
    "brahmadhātu": ['mw'],
    "brahmadina": ['mw'],
    "brahmadveṣa": ['cae', 'mw'],
    "brahmadveṣin": ['mw'],
    "brahmadviṣ": ['cae', 'gra', 'mw'],
    "brahmadvāra": ['mw'],
    "brahmadvārapāra": ['mw'],
    "brahmadāna": ['cae', 'mw'],
    "brahmadāru": ['mw'],
    "brahmadāsa": ['mw'],
    "brahmadātṛ": ['cae', 'mw'],
    "brahmadāya": ['cae', 'mw'],
    "brahmadāyahara": ['mw'],
    "brahmadāyopahārin": ['mw'],
    "brahmadāyāda": ['mw'],
    "brahmadūṣaka": ['mw'],
    "brahmagandha": ['mw'],
    "brahmagarbha": ['mw'],
    "brahmagarbhasmṛti": ['mw'],
    "brahmagarbhā": ['mw'],
    "brahmagaurava": ['mw'],
    "brahmagavī": ['mw'],
    "brahmaghna": ['cae', 'mw'],
    "brahmaghnī": ['mw'],
    "brahmaghosa": ['cped'],
    "brahmaghoṣa": ['bhs', 'mw'],
    "brahmaghoṣarava": ['mw'],
    "brahmaghātaka": ['cae', 'mw'],
    "brahmaghātin": ['cae', 'mw'],
    "brahmaghātinī": ['mw'],
    "brahmagiri": ['mw'],
    "brahmagola": ['mw'],
    "brahmagraha": ['mw'],
    "brahmagranthi": ['mw'],
    "brahmagrāhin": ['mw'],
    "brahmagupta": ['bhs', 'cae', 'mw'],
    "brahmaguptīya": ['mw'],
    "brahmagārgya": ['mw'],
    "brahmagāthāstuti": ['mw'],
    "brahmagāyatrī": ['mw'],
    "brahmagītikā": ['cae', 'mw'],
    "brahmagītā": ['mw'],
    "brahmagītāparātmānusaṃdhāna": ['mw'],
    "brahmagītāvyākhyā": ['mw'],
    "brahmahan": ['cae', 'mw'],
    "brahmahari": ['mw'],
    "brahmahatyā": ['cae', 'mw'],
    "brahmahaṃsopaniṣad": ['mw'],
    "brahmahrada": ['mw'],
    "brahmahuta": ['mw'],
    "brahmahṛdaya": ['mw'],
    "brahmaikyaprakaraṇa": ['mw'],
    "brahmaja": ['mw'],
    "brahmajacca": ['cped'],
    "brahmajajña": ['mw'],
    "brahmajanman": ['cae', 'mw'],
    "brahmajapa": ['mw'],
    "brahmajaṭin": ['mw'],
    "brahmajaṭā": ['mw'],
    "brahmajijñāsā": ['mw'],
    "brahmajuṣṭa": ['cae', 'mw'],
    "brahmajya": ['cae', 'mw'],
    "brahmajyeya": ['cae', 'mw'],
    "brahmajyeṣṭha": ['mw'],
    "brahmajyotirvikrīḍitābhijña": ['bhs'],
    "brahmajyotis": ['mw'],
    "brahmajña": ['cae', 'mw'],
    "brahmajñāna": ['cae', 'mw'],
    "brahmajñānamahātantrarāja": ['mw'],
    "brahmajñānatantra": ['mw'],
    "brahmajñānavipratipatti": ['mw'],
    "brahmajñānin": ['mw'],
    "brahmajñānopadeśa": ['mw'],
    "brahmajālasūtra": ['mw'],
    "brahmajāmala": ['mw'],
    "brahmajāra": ['mw'],
    "brahmajātaka": ['mw'],
    "brahmajāyā": ['cae', 'gra', 'mw'],
    "brahmajīvanirṇaya": ['mw'],
    "brahmajīvin": ['mw'],
    "brahmajūta": ['cae', 'gra', 'mw'],
    "brahmakaivartapurāṇa": ['mw'],
    "brahmakalpa": ['cae', 'mw'],
    "brahmakalā": ['mw'],
    "brahmakanya": ['mw'],
    "brahmakanyaka": ['mw'],
    "brahmakanyakā": ['mw'],
    "brahmakara": ['mw'],
    "brahmakarman": ['mw'],
    "brahmakarmapradāyaka": ['mw'],
    "brahmakarmaprakāśaka": ['mw'],
    "brahmakarmapustaka": ['mw'],
    "brahmakarmasamādhi": ['mw'],
    "brahmaketu": ['bhs', 'mw'],
    "brahmakhaṇḍa": ['mw'],
    "brahmakilbiṣa": ['cae', 'gra', 'mw'],
    "brahmakileya": ['mw'],
    "brahmakośa": ['mw'],
    "brahmakośī": ['mw'],
    "brahmakuśa": ['bhs'],
    "brahmakuśā": ['mw'],
    "brahmakuṇḍa": ['mw'],
    "brahmakāra": ['cae', 'gra', 'mw'],
    "brahmakāraṇavāda": ['mw'],
    "brahmakāya": ['bhs', 'mw'],
    "brahmakāyika": ['bhs', 'cped', 'mw'],
    "brahmakāṇḍa": ['mw'],
    "brahmakāṣṭha": ['mw'],
    "brahmakīrti": ['bhs'],
    "brahmakūrca": ['cae', 'mw'],
    "brahmakūrcavidhi": ['mw'],
    "brahmakūṭa": ['mw'],
    "brahmakṛt": ['cae', 'gra', 'mw'],
    "brahmakṛta": ['mw'],
    "brahmakṛti": ['cae', 'gra', 'mw'],
    "brahmakṣatra": ['cae', 'mw'],
    "brahmakṣatrasava": ['cae', 'mw'],
    "brahmakṣetra": ['mw'],
    "brahmalakṣaṇavākyārtha": ['mw'],
    "brahmalaukika": ['mw'],
    "brahmalekha": ['mw'],
    "brahmalikhita": ['mw'],
    "brahmaloka": ['cae', 'cped', 'ddsa', 'mw'],
    "brahmalokūpaga": ['cped'],
    "brahmamaha": ['mw'],
    "brahmamantra": ['mw'],
    "brahmamati": ['bhs', 'mw'],
    "brahmamaya": ['ap90', 'cae', 'mw'],
    "brahmamaṅgaladevatā": ['mw'],
    "brahmamaṇḍūkī": ['mw'],
    "brahmamaṭha": ['mw'],
    "brahmamedhyā": ['mw'],
    "brahmamekhala": ['mw'],
    "brahmamitra": ['mw'],
    "brahmamuhūrta": ['mw'],
    "brahmamukha": ['mw'],
    "brahmamāla": ['mw'],
    "brahmamāṇḍūkī": ['mw'],
    "brahmamīmāṃsā": ['cae', 'mw'],
    "brahmamūrdhabhṛt": ['mw'],
    "brahmamūrti": ['mw'],
    "brahman": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "brahmanadī": ['mw'],
    "brahmanandin": ['mw'],
    "brahmanirukta": ['mw'],
    "brahmanirvāṇa": ['cae', 'ddsa', 'mw'],
    "brahmanirūpaṇa": ['mw'],
    "brahmanirṇaya": ['mw'],
    "brahmaniṣṭha": ['cae', 'mw'],
    "brahmanutta": ['mw'],
    "brahmanābha": ['mw'],
    "brahmanāga": ['mw'],
    "brahmanāla": ['mw'],
    "brahmanāmāvali": ['mw'],
    "brahmanīḍa": ['mw'],
    "brahmapada": ['mw'],
    "brahmapalāśa": ['mw'],
    "brahmapannaga": ['mw'],
    "brahmaparipṛcchā": ['bhs'],
    "brahmapariṣad": ['mw'],
    "brahmapariṣadya": ['mw'],
    "brahmaparvata": ['mw'],
    "brahmaparṇī": ['mw'],
    "brahmapatha": ['cae', 'mw'],
    "brahmapathakovida": ['mw'],
    "brahmapati": ['mw'],
    "brahmapattra": ['mw'],
    "brahmapavitra": ['mw'],
    "brahmapitṛ": ['mw'],
    "brahmapiśāca": ['mw'],
    "brahmappatta": ['cped'],
    "brahmaprabha": ['bhs', 'mw'],
    "brahmaprajāpati": ['mw'],
    "brahmaprakṛtika": ['mw'],
    "brahmaprakṛtikatva": ['mw'],
    "brahmapralaya": ['mw'],
    "brahmaprasūta": ['mw'],
    "brahmapratiṣṭhāprayoga": ['mw'],
    "brahmapriya": ['cae', 'mw'],
    "brahmaprāpta": ['cae', 'mw'],
    "brahmaprāpti": ['mw'],
    "brahmaprāyaścitta": ['mw'],
    "brahmaprī": ['cae', 'gra', 'mw'],
    "brahmapura": ['cae', 'mw'],
    "brahmapuraka": ['mw'],
    "brahmapuramāhātmya": ['mw'],
    "brahmapurogava": ['mw'],
    "brahmapurohita": ['bhs', 'mw'],
    "brahmapurustāt": ['mw'],
    "brahmapuruṣa": ['mw'],
    "brahmapurābhidheya": ['mw'],
    "brahmapurākhya": ['mw'],
    "brahmapurāṇa": ['cae', 'mw'],
    "brahmapurī": ['mw'],
    "brahmapurīmāhātmya": ['mw'],
    "brahmaputra": ['cae', 'gra', 'mw'],
    "brahmaputratā": ['mw'],
    "brahmaputrī": ['mw'],
    "brahmapuṣpa": ['mw'],
    "brahmapāda": ['mw'],
    "brahmapādapa": ['mw'],
    "brahmapādastotra": ['mw'],
    "brahmapālikā": ['bhs'],
    "brahmapāra": ['mw'],
    "brahmapāramaya": ['mw'],
    "brahmapārastotra": ['mw'],
    "brahmapāriṣadya": ['bhs'],
    "brahmapārāyaṇa": ['mw'],
    "brahmapārṣadya": ['mw'],
    "brahmapāśa": ['mw'],
    "brahmapūta": ['mw'],
    "brahmapṛṣṭa": ['mw'],
    "brahmapṛṣṭha": ['mw'],
    "brahmarahasyasaṃhitā": ['mw'],
    "brahmarakṣas": ['cae', 'mw'],
    "brahmarandhra": ['mw'],
    "brahmarasa": ['mw'],
    "brahmarasāsava": ['mw'],
    "brahmaratha": ['mw'],
    "brahmaratna": ['mw'],
    "brahmarava": ['mw'],
    "brahmarekhā": ['mw'],
    "brahmarāja": ['mw'],
    "brahmarājanya": ['cae', 'mw'],
    "brahmarākṣasa": ['mw'],
    "brahmarākṣasī": ['mw'],
    "brahmarāta": ['cae', 'mw'],
    "brahmarāti": ['mw'],
    "brahmarātra": ['mw'],
    "brahmarātri": ['mw'],
    "brahmarāśi": ['cae', 'mw'],
    "brahmarīti": ['mw'],
    "brahmarūpa": ['mw'],
    "brahmarūpiṇī": ['mw'],
    "brahmarṣi": ['cae', 'ddsa', 'mw'],
    "brahmarṣideśa": ['cae', 'mw'],
    "brahmarṣitva": ['mw'],
    "brahmarṣitā": ['mw'],
    "brahmasabhā": ['bhs', 'mw'],
    "brahmasadana": ['cae', 'mw'],
    "brahmasadas": ['cae', 'mw'],
    "brahmasama": ['bhs'],
    "brahmasambandha": ['mw'],
    "brahmasambhava": ['mw'],
    "brahmasambhavasmṛti": ['mw'],
    "brahmasaras": ['cae', 'mw'],
    "brahmasarpa": ['mw'],
    "brahmasattra": ['cae', 'mw'],
    "brahmasattrin": ['mw'],
    "brahmasatī": ['mw'],
    "brahmasava": ['cae', 'gra', 'mw'],
    "brahmasaṃhitā": ['mw'],
    "brahmasaṃhitāvyākhyā": ['mw'],
    "brahmasaṃsad": ['cae', 'mw'],
    "brahmasaṃstha": ['cae', 'mw'],
    "brahmasaṃśita": ['cae', 'gra', 'mw'],
    "brahmasiddhi": ['mw'],
    "brahmasiddhivyākhyāratna": ['mw'],
    "brahmasiddhānta": ['cae', 'mw'],
    "brahmasiddhāntapaddhati": ['mw'],
    "brahmasoma": ['mw'],
    "brahmaspasa": ['bhs'],
    "brahmasphuṭasiddhānta": ['mw'],
    "brahmastamba": ['mw'],
    "brahmastena": ['cae', 'mw'],
    "brahmasteya": ['cae', 'mw'],
    "brahmasthala": ['bhs', 'cae', 'mw'],
    "brahmasthāna": ['mw'],
    "brahmastuti": ['mw'],
    "brahmasuta": ['mw'],
    "brahmasutā": ['mw'],
    "brahmasuvarcalā": ['cae', 'mw'],
    "brahmasva": ['cae', 'mw'],
    "brahmasvara": ['bhs'],
    "brahmasvaranādābhinandita": ['bhs'],
    "brahmasvarūpa": ['mw'],
    "brahmasvāmin": ['mw'],
    "brahmasāgara": ['mw'],
    "brahmasāma": ['mw'],
    "brahmasāman": ['mw'],
    "brahmasāmika": ['mw'],
    "brahmasārṣṭitā": ['cae', 'mw'],
    "brahmasāt": ['ap90'],
    "brahmasātkṛta": ['mw'],
    "brahmasāvarṇa": ['mw'],
    "brahmasāyujya": ['mw'],
    "brahmasū": ['mw'],
    "brahmasūkta": ['mw'],
    "brahmasūnu": ['mw'],
    "brahmasūtra": ['cae', 'mw'],
    "brahmasūtrabhāṣya": ['mw'],
    "brahmasūtrabhāṣyadīpikā": ['mw'],
    "brahmasūtrabhāṣyasāra": ['mw'],
    "brahmasūtrabhāṣyavārttika": ['mw'],
    "brahmasūtracandrikā": ['mw'],
    "brahmasūtrakārikā": ['mw'],
    "brahmasūtralaghuvārttika": ['mw'],
    "brahmasūtrapada": ['mw'],
    "brahmasūtrapradīpa": ['mw'],
    "brahmasūtrasaṃgati": ['mw'],
    "brahmasūtratantradīpikā": ['mw'],
    "brahmasūtratātparya": ['mw'],
    "brahmasūtravṛtti": ['mw'],
    "brahmasūtravṛttivārttika": ['mw'],
    "brahmasūtraṛjuvyākhyā": ['mw'],
    "brahmasūtrin": ['mw'],
    "brahmasūtropanyāsa": ['mw'],
    "brahmasūtropanyāsavṛtti": ['mw'],
    "brahmasūtrādvaitavṛtti": ['mw'],
    "brahmasūtrānubhāṣya": ['mw'],
    "brahmasūtrānubhāṣyapradīpa": ['mw'],
    "brahmasūtrānubhāṣyavivaraṇa": ['mw'],
    "brahmasūtrānuvyākhyāna": ['mw'],
    "brahmasūtrārthamaṇimālā": ['mw'],
    "brahmasūtrārthaprakāśikā": ['mw'],
    "brahmasṛj": ['mw'],
    "brahmatantra": ['mw'],
    "brahmatantregāyatrīpañjara": ['mw'],
    "brahmatarkastava": ['mw'],
    "brahmatarkastavavivaraṇa": ['mw'],
    "brahmatas": ['mw'],
    "brahmatattva": ['mw'],
    "brahmatattvapraśnottararatnāvalī": ['mw'],
    "brahmatattvasaṃhitoddipanī": ['mw'],
    "brahmatattvasubodhinī": ['mw'],
    "brahmatattvavivaraṇa": ['mw'],
    "brahmatejas": ['bhs', 'mw'],
    "brahmatejomaya": ['mw'],
    "brahmatulya": ['mw'],
    "brahmatulyagaṇita": ['mw'],
    "brahmatulyasiddhānta": ['mw'],
    "brahmatulyaṭīkā": ['mw'],
    "brahmatuṅga": ['mw'],
    "brahmatva": ['cae', 'mw'],
    "brahmatvac": ['mw'],
    "brahmatvapaddhati": ['mw'],
    "brahmatvaprayoga": ['mw'],
    "brahmatā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "brahmatāla": ['mw'],
    "brahmatīrtha": ['mw'],
    "brahmaudana": ['cae', 'mw'],
    "brahmaupagava": ['mw'],
    "brahmavada": ['mw'],
    "brahmavadha": ['cae', 'mw'],
    "brahmavadhyā": ['mw'],
    "brahmavadhyākṛta": ['cae', 'mw'],
    "brahmavadya": ['mw'],
    "brahmavaivarta": ['cae', 'mw'],
    "brahmavaivartaka": ['cae', 'mw'],
    "brahmavaivartarahasya": ['mw'],
    "brahmavaivartasāra": ['mw'],
    "brahmavaktṛ": ['mw'],
    "brahmavala": ['mw'],
    "brahmavali": ['bhs'],
    "brahmavallī": ['mw'],
    "brahmavallīlipi": ['mw'],
    "brahmavani": ['cae', 'mw'],
    "brahmavant": ['cae'],
    "brahmavaraṇa": ['mw'],
    "brahmavarcas": ['mw'],
    "brahmavarcasa": ['cae', 'mw'],
    "brahmavarcasakāma": ['cae', 'mw'],
    "brahmavarcasin": ['mw'],
    "brahmavarcasya": ['mw'],
    "brahmavardhana": ['mw'],
    "brahmavarman": ['mw'],
    "brahmavarta": ['mw'],
    "brahmavat": ['ap90', 'mw'],
    "brahmavatī": ['bhs'],
    "brahmaveda": ['cae', 'mw'],
    "brahmavedamaya": ['mw'],
    "brahmavedapariśiṣṭa": ['mw'],
    "brahmavedhyā": ['mw'],
    "brahmavedi": ['mw'],
    "brahmavedin": ['cae', 'mw'],
    "brahmavid": ['cae', 'mw'],
    "brahmavidvas": ['mw'],
    "brahmavidvaṃs": ['cae'],
    "brahmavidviṣ": ['cae', 'mw'],
    "brahmavidyopaniṣad": ['mw'],
    "brahmavidyā": ['cae', 'mw'],
    "brahmavidyābharaṇa": ['mw'],
    "brahmavidyāmahodadhi": ['mw'],
    "brahmavidyāpaddhati": ['mw'],
    "brahmavidyātīrtha": ['mw'],
    "brahmavidyāvijaya": ['mw'],
    "brahmavidyāvilāsa": ['mw'],
    "brahmavidāśīrvādapaddhati": ['mw'],
    "brahmavihāra": ['bhs', 'cped', 'mw'],
    "brahmavimāna": ['cped'],
    "brahmavittva": ['cae', 'mw'],
    "brahmavivardhana": ['mw'],
    "brahmaviśeṣacintiparipṛcchā": ['bhs'],
    "brahmaviśeṣacittaparipṛcchā": ['mw'],
    "brahmaviṣṇumaheśvaradāna": ['mw'],
    "brahmaviṣṇvarkavat": ['mw'],
    "brahmavrata": ['cae', 'mw'],
    "brahmavratadhara": ['mw'],
    "brahmavyavahāra": ['mw'],
    "brahmavāc": ['cae', 'mw'],
    "brahmavāda": ['cae', 'mw'],
    "brahmavādin": ['mw'],
    "brahmavāditva": ['mw'],
    "brahmavādya": ['mw'],
    "brahmavādārtha": ['mw'],
    "brahmavāhas": ['gra', 'mw'],
    "brahmavāluka": ['mw'],
    "brahmavāsa": ['mw'],
    "brahmavāṭīya": ['mw'],
    "brahmavīṇā": ['mw'],
    "brahmavṛddha": ['cae', 'mw'],
    "brahmavṛddhi": ['mw'],
    "brahmavṛkṣa": ['mw'],
    "brahmavṛnda": ['mw'],
    "brahmavṛndā": ['mw'],
    "brahmavṛtti": ['mw'],
    "brahmayajña": ['cae', 'mw'],
    "brahmayajñadevarṣipitṛtarpaṇa": ['mw'],
    "brahmayajñaprayoga": ['mw'],
    "brahmayajñasaṃhitā": ['mw'],
    "brahmayajñatarpaṇa": ['mw'],
    "brahmayajñopaniṣad": ['mw'],
    "brahmayajñādividhi": ['mw'],
    "brahmayaśas": ['mw'],
    "brahmayaśasa": ['mw'],
    "brahmayaśasin": ['mw'],
    "brahmayaśaḥsvāmin": ['mw'],
    "brahmayaṣṭi": ['mw'],
    "brahmayoga": ['cae', 'mw'],
    "brahmayogin": ['mw'],
    "brahmayoni": ['cae', 'mw'],
    "brahmayonistha": ['mw'],
    "brahmayuga": ['mw'],
    "brahmayuj": ['cae', 'gra', 'mw'],
    "brahmayāga": ['cae', 'mw'],
    "brahmayāmala": ['mw'],
    "brahmayāmila": ['mw'],
    "brahmayātu": ['mw'],
    "brahmayūpa": ['mw'],
    "brahmañña": ['cped'],
    "brahmaññatā": ['cped'],
    "brahmaśabda": ['mw'],
    "brahmaśabdavāda": ['mw'],
    "brahmaśabdaśaktivāda": ['mw'],
    "brahmaśabdārthavicāra": ['mw'],
    "brahmaśabdārthavāda": ['mw'],
    "brahmaśalya": ['mw'],
    "brahmaśambhu": ['mw'],
    "brahmaśiras": ['cae', 'mw'],
    "brahmaśiraḥkhaṇḍana": ['mw'],
    "brahmaśrī": ['mw'],
    "brahmaśuddha": ['bhs'],
    "brahmaśumbhita": ['mw'],
    "brahmaśālā": ['cae', 'mw'],
    "brahmaśāsana": ['mw'],
    "brahmaśāyin": ['mw'],
    "brahmaśīrṣan": ['cae'],
    "brahmaṃ": ['ap90'],
    "brahmaṇakaññā": ['cped'],
    "brahmaṇaspati": ['cae', 'ddsa', 'gra', 'mw'],
    "brahmaṇaspatisūkta": ['mw'],
    "brahmaṇaspatnī": ['cae', 'mw'],
    "brahmaṇiā": ['gra'],
    "brahmaṇvant": ['cae'],
    "brahmaṇvat": ['ap90', 'cae', 'ddsa', 'mw'],
    "brahmaṇvatī": ['mw'],
    "brahmaṇy": ['cae', 'gra'],
    "brahmaṇya": ['ap90', 'cae', 'ddsa', 'mw'],
    "brahmaṇyabhāskara": ['mw'],
    "brahmaṇyadeva": ['mw'],
    "brahmaṇyatā": ['cae', 'mw'],
    "brahmaṇyatīrtha": ['mw'],
    "brahmaṇyā": ['gra', 'mw'],
    "brahmaṛṣi": ['mw'],
    "brahmeddha": ['cae', 'mw'],
    "brahmendra": ['mw'],
    "brahmendracūḍa": ['bhs'],
    "brahmendrarāja": ['bhs'],
    "brahmeśavaiṣṇava": ['mw'],
    "brahmeśaya": ['ddsa', 'mw'],
    "brahmeśayaḥ": ['ap90'],
    "brahmeśvara": ['bhs', 'mw'],
    "brahmeśvaratīrtha": ['mw'],
    "brahmin": ['ap90', 'ddsa', 'mw'],
    "brahmiṣṭha": ['ap90', 'cae', 'ddsa', 'mw'],
    "brahmiṣṭhā": ['mw'],
    "brahmodatīrtha": ['mw'],
    "brahmodumbara": ['mw'],
    "brahmodya": ['cae', 'mw'],
    "brahmodyā": ['mw'],
    "brahmojjha": ['cae', 'ddsa', 'mw'],
    "brahmojjhatva": ['mw'],
    "brahmojjhatā": ['mw'],
    "brahmopadeśa": ['mw'],
    "brahmopadeśanetṛ": ['mw'],
    "brahmopanetṛ": ['mw'],
    "brahmopaniṣad": ['cae', 'mw'],
    "brahmopeta": ['mw'],
    "brahmopāsanā": ['mw'],
    "brahmottama": ['bhs'],
    "brahmottara": ['bhs', 'mw'],
    "brahmottarakhaṇḍa": ['mw'],
    "brahmoḍumbara": ['mw'],
    "brahmābhyāsa": ['cae', 'mw'],
    "brahmādanī": ['mw'],
    "brahmādarśa": ['mw'],
    "brahmādhigama": ['mw'],
    "brahmādhigamana": ['mw'],
    "brahmādhigamika": ['cae', 'mw'],
    "brahmādijātā": ['mw'],
    "brahmāditya": ['mw'],
    "brahmādiśīrṣa": ['mw'],
    "brahmādrijātā": ['mw'],
    "brahmādya": ['cae', 'mw'],
    "brahmāgrabhū": ['mw'],
    "brahmāgāra": ['mw'],
    "brahmāhuta": ['mw'],
    "brahmāhuti": ['cae', 'mw'],
    "brahmākṣara": ['ddsa', 'mw'],
    "brahmākṣaramaya": ['mw'],
    "brahmālaya": ['bhs'],
    "brahmālaṃkāra": ['mw'],
    "brahmāmbhas": ['mw'],
    "brahmāmṛta": ['mw'],
    "brahmāmṛtavarṣiṇī": ['mw'],
    "brahmānana": ['bhs'],
    "brahmānanda": ['mw'],
    "brahmānandabhāratī": ['mw'],
    "brahmānandagiri": ['mw'],
    "brahmānandaparamahaṃsa": ['mw'],
    "brahmānandasarasvatī": ['mw'],
    "brahmānandastava": ['mw'],
    "brahmānandasūtramuktāvali": ['mw'],
    "brahmānandavallī": ['mw'],
    "brahmānandavilāsa": ['mw'],
    "brahmānandayogin": ['mw'],
    "brahmānandayogīndra": ['mw'],
    "brahmānandin": ['mw'],
    "brahmānandīya": ['mw'],
    "brahmānandīyakhaṇḍana": ['mw'],
    "brahmāpeta": ['mw'],
    "brahmārambha": ['cae', 'mw'],
    "brahmāraṇya": ['cae', 'mw'],
    "brahmāraṇyamāhātmya": ['mw'],
    "brahmārgha": ['cae', 'mw'],
    "brahmārka": ['mw'],
    "brahmārpaṇa": ['mw'],
    "brahmāsana": ['mw'],
    "brahmāsananiviṣṭa": ['mw'],
    "brahmāsandī": ['mw'],
    "brahmāsanā": ['mw'],
    "brahmāstra": ['cae', 'mw'],
    "brahmāstrakalpa": ['mw'],
    "brahmāstrakavaca": ['mw'],
    "brahmāstrakāryasādhana": ['mw'],
    "brahmāstrapaddhati": ['mw'],
    "brahmāstravidhānapaddhati": ['mw'],
    "brahmāstravidyāpūjāpaddhati": ['mw'],
    "brahmāsya": ['mw'],
    "brahmātithi": ['mw'],
    "brahmātmabhū": ['mw'],
    "brahmāvabodha": ['mw'],
    "brahmāvabodhavivekasindhu": ['mw'],
    "brahmāvalībhāṣya": ['mw'],
    "brahmāvarta": ['cae', 'mw'],
    "brahmāvartatīrtha": ['mw'],
    "brahmāvatī": ['bhs', 'mw'],
    "brahmāvādanagara": ['mw'],
    "brahmāvāsa": ['mw'],
    "brahmāya": ['ddsa', 'mw'],
    "brahmāyana": ['mw'],
    "brahmāyatana": ['mw'],
    "brahmāyatanīya": ['mw'],
    "brahmāyaṇa": ['mw'],
    "brahmāyu": ['bhs'],
    "brahmāyus": ['ddsa', 'mw'],
    "brahmāñjali": ['cae', 'mw'],
    "brahmāñjalikṛta": ['mw'],
    "brahmāṅgabhū": ['mw'],
    "brahmāṇī": ['ap90', 'cae', 'ddsa', 'mw'],
    "brahmāṇīmantra": ['mw'],
    "brahmāṇḍa": ['cae', 'ddsa', 'mw'],
    "brahmāṇḍabhāṇḍodara": ['mw'],
    "brahmāṇḍajñānamahārājatantra": ['mw'],
    "brahmāṇḍakalpa": ['mw'],
    "brahmāṇḍakapāla": ['mw'],
    "brahmāṇḍakaṭāha": ['mw'],
    "brahmāṇḍapurāṇa": ['mw'],
    "brahmāṇḍatantra": ['mw'],
    "brahmāṇḍayāmalepañcamīsādhana": ['mw'],
    "brahmī": ['ap90', 'gra', 'mw'],
    "brahmībhūta": ['mw'],
    "brahmīyas": ['mw'],
    "bravas": ['ddsa'],
    "bravitu": ['cped'],
    "braṇ": ['mw'],
    "bruva": ['ap90', 'cae', 'ddsa', 'mw'],
    "bruvanta": ['cped'],
    "bruvat": ['ddsa'],
    "bruvitvā": ['cped'],
    "bruvāṇa": ['mw'],
    "bruḍ": ['mw'],
    "brādhnāyanya": ['mw'],
    "brāhma": ['ap90', 'cae', 'ddsa', 'mw'],
    "brāhmadattāyana": ['mw'],
    "brāhmadaṇḍa": ['mw'],
    "brāhmadeya": ['mw'],
    "brāhmagupta": ['mw'],
    "brāhmaguptīya": ['mw'],
    "brāhmaka": ['mw'],
    "brāhmakārikā": ['mw'],
    "brāhmakṛteya": ['mw'],
    "brāhmalaukika": ['mw'],
    "brāhmamuhūrta": ['mw'],
    "brāhmapalāśa": ['mw'],
    "brāhmaparvan": ['mw'],
    "brāhmapiṅgā": ['mw'],
    "brāhmaprajāpatya": ['mw'],
    "brāhmapurāṇa": ['mw'],
    "brāhmapuṣpi": ['mw'],
    "brāhmarāti": ['mw'],
    "brāhmasiddhānta": ['mw'],
    "brāhmaudanika": ['mw'],
    "brāhmavivāha": ['mw'],
    "brāhmaṇa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "brāhmaṇabhakta": ['mw'],
    "brāhmaṇabhojana": ['cae', 'mw'],
    "brāhmaṇabhojanavidhi": ['mw'],
    "brāhmaṇabhāva": ['mw'],
    "brāhmaṇabhāṣya": ['mw'],
    "brāhmaṇabhūyiṣṭha": ['mw'],
    "brāhmaṇabruva": ['cae', 'mw'],
    "brāhmaṇacela": ['mw'],
    "brāhmaṇacāṇḍāla": ['cae', 'mw'],
    "brāhmaṇadhana": ['cae', 'mw'],
    "brāhmaṇadravya": ['mw'],
    "brāhmaṇadveṣin": ['mw'],
    "brāhmaṇadārikā": ['mw'],
    "brāhmaṇaghna": ['cae', 'mw'],
    "brāhmaṇagṛha": ['mw'],
    "brāhmaṇahita": ['mw'],
    "brāhmaṇaja": ['mw'],
    "brāhmaṇajuṣṭa": ['mw'],
    "brāhmaṇajāta": ['cae', 'mw'],
    "brāhmaṇajāti": ['mw'],
    "brāhmaṇajātīya": ['mw'],
    "brāhmaṇajīvikā": ['mw'],
    "brāhmaṇaka": ['bhs', 'cae', 'mw'],
    "brāhmaṇakalpa": ['cae', 'mw'],
    "brāhmaṇakaḥ": ['ap90'],
    "brāhmaṇakula": ['cae', 'mw'],
    "brāhmaṇakumāra": ['cae', 'mw'],
    "brāhmaṇakāmyā": ['cae', 'mw'],
    "brāhmaṇakāraka": ['mw'],
    "brāhmaṇakīya": ['mw'],
    "brāhmaṇakṛta": ['mw'],
    "brāhmaṇakṛteya": ['mw'],
    "brāhmaṇalakṣaṇa": ['mw'],
    "brāhmaṇaliṅga": ['mw'],
    "brāhmaṇamahimādarśa": ['mw'],
    "brāhmaṇamukhīna": ['mw'],
    "brāhmaṇanindaka": ['mw'],
    "brāhmaṇanipāta": ['bhs'],
    "brāhmaṇapaddhati": ['mw'],
    "brāhmaṇapatha": ['mw'],
    "brāhmaṇapañcikā": ['mw'],
    "brāhmaṇaprasaṅga": ['mw'],
    "brāhmaṇapriya": ['cae', 'mw'],
    "brāhmaṇaprātiveśya": ['mw'],
    "brāhmaṇaputraka": ['cae', 'mw'],
    "brāhmaṇapāla": ['mw'],
    "brāhmaṇarūpabhṛt": ['mw'],
    "brāhmaṇasambhāṣa": ['mw'],
    "brāhmaṇasarvasva": ['mw'],
    "brāhmaṇasattama": ['mw'],
    "brāhmaṇasava": ['mw'],
    "brāhmaṇasaṃstha": ['mw'],
    "brāhmaṇasaṃtarpaṇa": ['mw'],
    "brāhmaṇaspatya": ['cae', 'ddsa'],
    "brāhmaṇastuti": ['mw'],
    "brāhmaṇasva": ['cae', 'ddsa', 'mw'],
    "brāhmaṇasvara": ['mw'],
    "brāhmaṇasāt": ['ap90', 'mw'],
    "brāhmaṇasātkṛ": ['cae', 'ddsa'],
    "brāhmaṇasūtra": ['bhs'],
    "brāhmaṇatarpaṇa": ['mw'],
    "brāhmaṇatrā": ['ap90', 'mw'],
    "brāhmaṇatva": ['mw'],
    "brāhmaṇatvavicāra": ['mw'],
    "brāhmaṇatā": ['ap90', 'cae', 'mw'],
    "brāhmaṇavacana": ['cae', 'mw'],
    "brāhmaṇavadha": ['cae', 'mw'],
    "brāhmaṇavara": ['mw'],
    "brāhmaṇavarcasa": ['cae', 'mw'],
    "brāhmaṇavarṇin": ['mw'],
    "brāhmaṇavat": ['ddsa', 'mw'],
    "brāhmaṇavatī": ['mw'],
    "brāhmaṇavedam": ['mw'],
    "brāhmaṇavidhi": ['cae', 'mw'],
    "brāhmaṇavihita": ['cae', 'mw'],
    "brāhmaṇavilāpa": ['cae', 'mw'],
    "brāhmaṇavācana": ['mw'],
    "brāhmaṇavācanaka": ['cped'],
    "brāhmaṇavākya": ['cae', 'mw'],
    "brāhmaṇavāṭaka": ['cped'],
    "brāhmaṇayajña": ['mw'],
    "brāhmaṇayaṣṭikā": ['mw'],
    "brāhmaṇayaṣṭī": ['mw'],
    "brāhmaṇayoni": ['mw'],
    "brāhmaṇaśramaṇanyāya": ['mw'],
    "brāhmaṇaśramaṇanyāyāt": ['mw'],
    "brāhmaṇaḍimbha": ['cae', 'mw'],
    "brāhmaṇeṣṭa": ['mw'],
    "brāhmaṇi": ['mw'],
    "brāhmaṇibruvā": ['mw'],
    "brāhmaṇicelī": ['mw'],
    "brāhmaṇigotrā": ['mw'],
    "brāhmaṇihatā": ['mw'],
    "brāhmaṇika": ['mw'],
    "brāhmaṇikalpā": ['mw'],
    "brāhmaṇikā": ['mw'],
    "brāhmaṇimatā": ['mw'],
    "brāhmaṇirūpā": ['mw'],
    "brāhmaṇitamā": ['mw'],
    "brāhmaṇitarā": ['mw'],
    "brāhmaṇokta": ['cae', 'ddsa', 'mw'],
    "brāhmaṇya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "brāhmaṇābhyupapatti": ['mw'],
    "brāhmaṇābhāṣaṇa": ['mw'],
    "brāhmaṇācchaṃsin": ['ap90', 'cae', 'ddsa', 'mw'],
    "brāhmaṇācchaṃsinaukthya": ['mw'],
    "brāhmaṇācchaṃsiprayoga": ['mw'],
    "brāhmaṇācchaṃsiśastra": ['mw'],
    "brāhmaṇācchaṃsya": ['mw'],
    "brāhmaṇācchaṃsīya": ['mw'],
    "brāhmaṇācchaṃsīyā": ['mw'],
    "brāhmaṇāda": ['mw'],
    "brāhmaṇādarśana": ['mw'],
    "brāhmaṇākriya": ['mw'],
    "brāhmaṇāpaśraya": ['mw'],
    "brāhmaṇātikrama": ['ddsa', 'mw'],
    "brāhmaṇātmaka": ['mw'],
    "brāhmaṇāvekṣa": ['mw'],
    "brāhmaṇāyana": ['cae', 'mw'],
    "brāhmaṇāyanaḥ": ['ap90'],
    "brāhmaṇī": ['ap90', 'cae', 'mw'],
    "brāhmaṇībhū": ['ddsa', 'mw'],
    "brāhmaṇīgāmin": ['mw'],
    "brāhmaṇīsattamā": ['mw'],
    "brāhmaṇītva": ['mw'],
    "brāhmeṣṭi": ['mw'],
    "brāhmi": ['cae', 'mw'],
    "brāhmikā": ['mw'],
    "brāhmotsava": ['mw'],
    "brāhmoḍhā": ['cae', 'mw'],
    "brāhmya": ['ap90', 'cae', 'ddsa', 'mw'],
    "brāhmyahuta": ['mw'],
    "brāhmyamuhūrta": ['mw'],
    "brāhmyatīrtha": ['mw'],
    "brāhmyā": ['mw'],
    "brāhmāhorātra": ['mw'],
    "brāhmāṇī": ['mw'],
    "brāhmī": ['ap90', 'bhs', 'ddsa', 'mw'],
    "brāhmīkanda": ['mw'],
    "brāhmīkunda": ['mw'],
    "brāhmīputra": ['cae', 'mw'],
    "brāhmītantra": ['mw'],
    "brāhmīśāntisaṃkalpa": ['mw'],
    "brāhmīśāntyavadhānakrama": ['mw'],
    "brū": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "brūhana": ['cped'],
    "brūhenta": ['cped'],
    "brūhesi": ['cped'],
    "brūhetar": ['cped'],
    "brūheti": ['cped'],
    "brūhetvā": ['cped'],
    "brūhita": ['cped'],
    "brūs": ['mw'],
    "brūti": ['cped'],
    "bubbula": ['cped'],
    "bubbulaka": ['cped'],
    "bubhukkhati": ['cped'],
    "bubhukkhi": ['cped'],
    "bubhukkhita": ['cped'],
    "bubhukṣita": ['ap90', 'cae', 'mw'],
    "bubhukṣitaka": ['bhs'],
    "bubhukṣu": ['ap90', 'cae', 'mw'],
    "bubhukṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "bubhukṣāpanaya": ['mw'],
    "bubhukṣāpīḍita": ['mw'],
    "bubhutsita": ['mw'],
    "bubhutsu": ['ap90', 'cae', 'mw'],
    "bubhutsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "bubhūrṣu": ['cae', 'mw'],
    "bubhūrṣā": ['cae', 'ddsa', 'mw'],
    "bubhūṣaka": ['ddsa', 'mw'],
    "bubhūṣu": ['ap90', 'cae', 'mw'],
    "bubhūṣā": ['ap90', 'cae', 'mw'],
    "bubodhayiṣu": ['ddsa', 'mw'],
    "bubura": ['mw'],
    "buburaṃ": ['ap90'],
    "bud": ['ap90', 'mw'],
    "budbuda": ['cae', 'ddsa', 'gra', 'mw'],
    "budbudaka": ['bhs'],
    "budbudatva": ['mw'],
    "budbudayāśu": ['gra', 'mw'],
    "budbudaḥ": ['ap90'],
    "budbudā": ['mw'],
    "budbudākāratā": ['mw'],
    "budbudākṣa": ['bhs', 'mw'],
    "buddha": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "buddhabala": ['cped'],
    "buddhabhadra": ['mw'],
    "buddhabhaṭṭa": ['mw'],
    "buddhabhāva": ['cped'],
    "buddhabhūmi": ['bhs', 'cped', 'mw'],
    "buddhabhūmisūtra": ['mw'],
    "buddhabhūta": ['cped'],
    "buddhacakkhu": ['cped'],
    "buddhacakṣus": ['mw'],
    "buddhacarita": ['mw'],
    "buddhacaritra": ['mw'],
    "buddhacarya": ['mw'],
    "buddhacchāyā": ['mw'],
    "buddhadatta": ['mw'],
    "buddhadeva": ['mw'],
    "buddhadharma": ['cae', 'mw'],
    "buddhadharmasaṃgha": ['mw'],
    "buddhadiś": ['mw'],
    "buddhadravya": ['mw'],
    "buddhadrumarāja": ['bhs'],
    "buddhadvādaśīvrata": ['mw'],
    "buddhadāsa": ['mw'],
    "buddhagaganaprabhāsacūḍa": ['bhs'],
    "buddhagayā": ['mw'],
    "buddhaghoṣa": ['mw'],
    "buddhagupta": ['mw'],
    "buddhaguru": ['mw'],
    "buddhaguṇa": ['cped'],
    "buddhaiḍūka": ['mw'],
    "buddhajñāna": ['mw'],
    "buddhajñānaśrī": ['mw'],
    "buddhaka": ['bhs', 'mw'],
    "buddhakalpa": ['mw'],
    "buddhakapāla": ['bhs'],
    "buddhakapālinī": ['mw'],
    "buddhakkhetta": ['cped'],
    "buddhakolāhala": ['cped'],
    "buddhakāla": ['cped'],
    "buddhakārakadhamma": ['cped'],
    "buddhakāyavarṇapariniṣpattyabhinirhārā": ['bhs', 'mw'],
    "buddhakṣetra": ['bhs', 'mw'],
    "buddhakṣetrapariśodhaka": ['mw'],
    "buddhakṣetravaralocana": ['mw'],
    "buddhalocanā": ['bhs'],
    "buddhalīḷhā": ['cped'],
    "buddhamantra": ['mw'],
    "buddhamati": ['bhs'],
    "buddhamitra": ['mw'],
    "buddhamāmaka": ['cped'],
    "buddhamārga": ['cae', 'mw'],
    "buddhanandi": ['mw'],
    "buddhanirmāṇa": ['mw'],
    "buddhantara": ['cped'],
    "buddhapakṣa": ['mw'],
    "buddhapiṇḍī": ['mw'],
    "buddhaprabhāmaṇḍalaśrīpradīpā": ['bhs'],
    "buddhapurāṇa": ['mw'],
    "buddhaputta": ['cped'],
    "buddhapāla": ['mw'],
    "buddhapālita": ['bhs', 'mw'],
    "buddharakṣita": ['bhs', 'cae', 'mw'],
    "buddharakṣitā": ['mw'],
    "buddharasmi": ['cped'],
    "buddharaṁsi": ['cped'],
    "buddharāja": ['mw'],
    "buddhasaṃgīti": ['bhs', 'mw'],
    "buddhasena": ['mw'],
    "buddhasiṃha": ['mw'],
    "buddhasāsana": ['cped'],
    "buddhati": ['bhs'],
    "buddhatta": ['cped'],
    "buddhatva": ['cae', 'mw'],
    "buddhavacana": ['cped', 'mw'],
    "buddhavajrasaṃdhāraṇasaṃdhi": ['bhs'],
    "buddhavanagiri": ['mw'],
    "buddhavapurdhārin": ['mw'],
    "buddhavat": ['mw'],
    "buddhaveneyya": ['cped'],
    "buddhavicīrṇā": ['bhs'],
    "buddhavisaya": ['cped'],
    "buddhaviṣaya": ['mw'],
    "buddhaviṣayāvatāra": ['mw'],
    "buddhayāna": ['bhs'],
    "buddhañāṇa": ['cped'],
    "buddhaśrīgarbha": ['bhs'],
    "buddhaḍākinī": ['bhs'],
    "buddhaṅkura": ['cped'],
    "buddhi": ['cae', 'cped', 'ddsa', 'mw'],
    "buddhibala": ['mw'],
    "buddhibheda": ['cae', 'mw'],
    "buddhibhrama": ['mw'],
    "buddhibhṛt": ['mw'],
    "buddhicchāyā": ['mw'],
    "buddhicintaka": ['mw'],
    "buddhicyuta": ['mw'],
    "buddhidevī": ['mw'],
    "buddhidyūta": ['mw'],
    "buddhigamya": ['mw'],
    "buddhigrāhya": ['cae', 'mw'],
    "buddhihīna": ['cae', 'mw'],
    "buddhihīnatva": ['mw'],
    "buddhijīvin": ['cae', 'mw'],
    "buddhika": ['bhs'],
    "buddhikara": ['mw'],
    "buddhikāmā": ['mw'],
    "buddhikārī": ['mw'],
    "buddhikṛt": ['ddsa', 'mw'],
    "buddhikṛta": ['cae', 'mw'],
    "buddhilakṣaṇa": ['mw'],
    "buddhilāghava": ['mw'],
    "buddhimant": ['cae', 'cped'],
    "buddhimat": ['ap90', 'mw'],
    "buddhimatikā": ['mw'],
    "buddhimattara": ['mw'],
    "buddhimattva": ['mw'],
    "buddhimattā": ['ap90', 'mw'],
    "buddhimaya": ['mw'],
    "buddhimoha": ['cae', 'mw'],
    "buddhiprabha": ['mw'],
    "buddhipradāna": ['mw'],
    "buddhipradīpa": ['mw'],
    "buddhiprāgalbhī": ['mw'],
    "buddhipura": ['mw'],
    "buddhipuramāhātmya": ['mw'],
    "buddhipuraḥsara": ['mw'],
    "buddhipūrva": ['cae', 'mw'],
    "buddhipūrvaka": ['cae', 'mw'],
    "buddhipūrvakam": ['mw'],
    "buddhipūrvakatva": ['mw'],
    "buddhipūrvam": ['mw'],
    "buddhirāja": ['mw'],
    "buddhisahāya": ['mw'],
    "buddhisampanna": ['cped', 'mw'],
    "buddhisaṃkīrṇa": ['mw'],
    "buddhiskandhamaya": ['mw'],
    "buddhistha": ['mw'],
    "buddhisthatva": ['mw'],
    "buddhisāgara": ['cae', 'mw'],
    "buddhitas": ['mw'],
    "buddhitattva": ['mw'],
    "buddhivaibhava": ['mw'],
    "buddhivant": ['bhs'],
    "buddhivara": ['mw'],
    "buddhivarjita": ['cae', 'mw'],
    "buddhividhvaṃsaka": ['mw'],
    "buddhivilāsa": ['mw'],
    "buddhivilāsinī": ['mw'],
    "buddhivināśa": ['mw'],
    "buddhivirodhin": ['mw'],
    "buddhivisphuraṇa": ['mw'],
    "buddhivivardhana": ['cae', 'mw'],
    "buddhiviṣaya": ['mw'],
    "buddhivāda": ['mw'],
    "buddhivṛddhi": ['cae', 'mw'],
    "buddhivṛddhikara": ['mw'],
    "buddhiyoga": ['mw'],
    "buddhiyogamaya": ['mw'],
    "buddhiyukta": ['cae', 'mw'],
    "buddhiśakti": ['mw'],
    "buddhiśarīra": ['cae', 'mw'],
    "buddhiśastra": ['mw'],
    "buddhiśreṣṭha": ['mw'],
    "buddhiśrīgarbha": ['mw'],
    "buddhiśuddha": ['cae', 'mw'],
    "buddhiśuddhi": ['cae', 'mw'],
    "buddhiśālin": ['cae', 'mw'],
    "buddhiḥ": ['ap90'],
    "buddhoktasaṃsārāmaya": ['mw'],
    "buddhopaṭṭhāka": ['cped'],
    "buddhoppāda": ['cped'],
    "buddhopāsaka": ['cae', 'ddsa', 'mw'],
    "buddhyadhika": ['cae', 'mw'],
    "buddhyatīta": ['mw'],
    "buddhyavajñāna": ['mw'],
    "buddhyāyate": ['bhs'],
    "buddhāgama": ['cae', 'mw'],
    "buddhālambana": ['cped'],
    "buddhālaṃkāravyūha": ['bhs'],
    "buddhālaṃkārādhiṣṭhitā": ['bhs', 'mw'],
    "buddhānta": ['cae', 'mw'],
    "buddhānubhāva": ['cped'],
    "buddhānusmṛti": ['bhs', 'mw'],
    "buddhānussati": ['cped'],
    "buddhārammaṇa": ['cped'],
    "buddhāvataṃsaka": ['bhs', 'mw'],
    "buddhāvatāra": ['mw'],
    "buddhāṇḍaka": ['mw'],
    "buddhīndriya": ['cae', 'ddsa', 'mw'],
    "budh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "budha": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "budhacāra": ['mw'],
    "budhadarśanacāra": ['mw'],
    "budhadeśa": ['mw'],
    "budhadina": ['mw'],
    "budhagupta": ['mw'],
    "budhajana": ['mw'],
    "budhaka": ['mw'],
    "budhakauśika": ['mw'],
    "budhamanohara": ['mw'],
    "budhanvat": ['mw'],
    "budhanāḍi": ['mw'],
    "budhaprakāśa": ['mw'],
    "budhapūjā": ['mw'],
    "budharatna": ['mw'],
    "budharañjiṇī": ['mw'],
    "budhasmṛti": ['mw'],
    "budhasuta": ['mw'],
    "budhasānu": ['mw'],
    "budhasūkta": ['mw'],
    "budhatāta": ['mw'],
    "budhavāra": ['cped', 'mw'],
    "budhaśānti": ['mw'],
    "budhe": ['mw'],
    "budheya": ['mw'],
    "budhila": ['ap90', 'mw'],
    "budhita": ['ap90', 'mw'],
    "budhna": ['cae', 'ddsa', 'gra', 'mw'],
    "budhnaroga": ['mw'],
    "budhnavat": ['mw'],
    "budhnaḥ": ['ap90'],
    "budhnia": ['gra'],
    "budhniya": ['mw'],
    "budhnya": ['cae', 'ddsa', 'gra', 'mw'],
    "budhya": ['ap90', 'gra', 'mw'],
    "budhyana": ['bhs'],
    "budhyāpaka": ['bhs'],
    "budhyāpana": ['bhs'],
    "budhā": ['mw'],
    "budhāna": ['ap90', 'ddsa', 'mw'],
    "budhāṣṭamī": ['mw'],
    "budhāṣṭamīvrata": ['mw'],
    "budhāṣṭamīvratakālanirṇaya": ['mw'],
    "buhnā": ['mw'],
    "bujjhamāna": ['cped'],
    "bujjhana": ['cped'],
    "bujjhanaka": ['cped'],
    "bujjhanta": ['cped'],
    "bujjhati": ['cped'],
    "bujjhi": ['cped'],
    "bujjhitar": ['cped'],
    "bujjhitvā": ['cped'],
    "buk": ['ap90', 'mw'],
    "buka": ['cae', 'mw'],
    "bukin": ['mw'],
    "bukk": ['ap90', 'mw'],
    "bukka": ['mw'],
    "bukkan": ['ap90', 'mw'],
    "bukkana": ['mw'],
    "bukkanaṃ": ['ap90'],
    "bukkasa": ['mw'],
    "bukkasaḥ": ['ap90'],
    "bukkasī": ['mw'],
    "bukkati": ['bhs'],
    "bukkaḥ": ['ap90'],
    "bukkā": ['ap90', 'cae', 'ddsa'],
    "bukkāgramāṃsa": ['mw'],
    "bukkāra": ['bhs', 'mw'],
    "bul": ['ap90', 'ddsa', 'mw'],
    "bula": ['mw'],
    "bulaka": ['bhs'],
    "bulba": ['mw'],
    "buli": ['bhs', 'mw'],
    "bulila": ['mw'],
    "buliḥ": ['ap90'],
    "bulla": ['cae', 'ddsa', 'mw'],
    "bulva": ['ap90', 'cae'],
    "bulya": ['mw'],
    "bumbhikā": ['mw'],
    "bumbhī": ['mw'],
    "bund": ['mw'],
    "bunda": ['cae', 'ddsa', 'gra', 'mw'],
    "bundh": ['mw'],
    "bundira": ['mw'],
    "buri": ['mw'],
    "buruḍa": ['cae', 'ddsa', 'mw'],
    "bus": ['ap90', 'mw'],
    "busa": ['cae', 'ddsa', 'gra', 'mw'],
    "busaplāvī": ['bhs', 'mw'],
    "busasa": ['mw'],
    "busaṃ": ['ap90'],
    "bust": ['ap90', 'mw'],
    "busta": ['mw'],
    "bustaṃ": ['ap90'],
    "busā": ['mw'],
    "buvam": ['mw'],
    "buśa": ['mw'],
    "buśm, buṣa": ['ddsa'],
    "buḍ": ['ap90', 'mw'],
    "buḍabuḍa": ['mw'],
    "buḍila": ['cae', 'mw'],
    "buḍḍha": ['cped'],
    "buḍḍhatara": ['cped'],
    "buṃd": ['ap90'],
    "buṅg": ['mw'],
    "buṣa": ['mw'],
    "buṣaṃ": ['ap90'],
    "buṭ": ['ap90', 'mw'],
    "byaggha": ['cped'],
    "byañjana": ['cped'],
    "byus": ['mw'],
    "byāma": ['cped'],
    "byāmappabhā": ['cped'],
    "byāpāda": ['cped'],
    "byūha": ['cped'],
    "bābakhānacaritra": ['mw'],
    "bābara": ['mw'],
    "bāberī": ['mw'],
    "bābhrava": ['cae', 'ddsa', 'mw'],
    "bābhravadānacyuta": ['mw'],
    "bābhravaśālaṅkāyana": ['mw'],
    "bābhravya": ['cae', 'mw'],
    "bābhravyaka": ['mw'],
    "bābhravyā": ['mw'],
    "bābhravyāyaṇī": ['mw'],
    "bābhravāyaṇi": ['mw'],
    "bābhravī": ['ap90', 'mw'],
    "bābhravīya": ['mw'],
    "bābhruka": ['ap90', 'mw'],
    "bābujīvyāsa": ['mw'],
    "bādaksāna": ['mw'],
    "bādara": ['ap90', 'cae', 'ddsa', 'mw'],
    "bādari": ['ddsa', 'mw'],
    "bādarika": ['ap90', 'mw'],
    "bādarāyaṇa": ['cae', 'ddsa', 'mw'],
    "bādarāyaṇapraśna": ['mw'],
    "bādarāyaṇasūtra": ['mw'],
    "bādarāyaṇaḥ": ['ap90'],
    "bādarāyaṇi": ['mw'],
    "bādarāyaṇiḥ": ['ap90'],
    "bādh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bādha": ['cae', 'ddsa', 'gra', 'mw'],
    "bādhabuddhipratibadhyapratibandhakabhāvavāda": ['mw'],
    "bādhabuddhipratibadhyatāvāda": ['mw'],
    "bādhabuddhipratibandhakatāvicāra": ['mw'],
    "bādhabuddhivicāra": ['mw'],
    "bādhabuddhivāda": ['mw'],
    "bādhabuddhivādārtha": ['mw'],
    "bādhacintāmaṇi": ['mw'],
    "bādhaka": ['ap90', 'cae', 'cped', 'mw'],
    "bādhakamaya": ['mw'],
    "bādhakatta": ['cped'],
    "bādhakatva": ['mw'],
    "bādhakatā": ['mw'],
    "bādhana": ['ap90', 'cae', 'cped', 'mw'],
    "bādhanā": ['mw'],
    "bādhanīya": ['mw'],
    "bādhapūrvapakṣagranthakroḍa": ['mw'],
    "bādhapūrvapakṣagranthaprakāśa": ['mw'],
    "bādhapūrvapakṣagranthavivecana": ['mw'],
    "bādhapūrvapakṣagranthaṭīkā": ['mw'],
    "bādhapūrvapakṣagranthānugama": ['mw'],
    "bādharahasya": ['mw'],
    "bādhasiddhāntagranthakroḍa": ['mw'],
    "bādhasiddhāntagranthaprakāśa": ['mw'],
    "bādhasiddhāntagranthavivecana": ['mw'],
    "bādhasiddhāntagranthaṭīkā": ['mw'],
    "bādhasiddhāntagranthānugama": ['mw'],
    "bādhati": ['cped'],
    "bādhatā": ['mw'],
    "bādhavibhājaka": ['mw'],
    "bādhavicāra": ['mw'],
    "bādhavāda": ['mw'],
    "bādhayitrī": ['mw'],
    "bādhayitṛ": ['mw'],
    "bādhaḥ": ['ap90'],
    "bādhenta": ['cped'],
    "bādhesi": ['cped'],
    "bādheti": ['cped'],
    "bādhetvā": ['cped'],
    "bādhi": ['cped'],
    "bādhin": ['mw'],
    "bādhiraka": ['mw'],
    "bādhirika": ['mw'],
    "bādhirya": ['cae', 'ddsa', 'mw'],
    "bādhiryaṃ": ['ap90'],
    "bādhita": ['ap90', 'cped', 'mw'],
    "bādhitatva": ['cae', 'mw'],
    "bādhitavya": ['cae', 'mw'],
    "bādhitvā": ['cped', 'mw'],
    "bādhitṛ": ['cae', 'mw'],
    "bādhva": ['cae', 'mw'],
    "bādhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "bādhyabādhakatā": ['mw'],
    "bādhyamānatva": ['mw'],
    "bādhyaretas": ['mw'],
    "bādhyatva": ['mw'],
    "bādhyaugāyana": ['mw'],
    "bādhyoga": ['mw'],
    "bādhā": ['cped'],
    "bādhānta": ['mw'],
    "bādhūla": ['mw'],
    "bādhūlasmṛti": ['mw'],
    "bādhūlaśiṣya": ['mw'],
    "bādāma": ['mw'],
    "bāh": ['gra', 'mw'],
    "bāha": ['mw'],
    "bāhadura": ['mw'],
    "bāhalya": ['mw'],
    "bāhanikā": ['bhs'],
    "bāhannopaniṣad": ['mw'],
    "bāhava": ['cae', 'ddsa', 'gra', 'mw'],
    "bāhavi": ['ddsa', 'mw'],
    "bāhaya": ['ddsa'],
    "bāhayati": ['bhs'],
    "bāhaḍa": ['mw'],
    "bāhaḥ": ['ap90'],
    "bāhaṭa": ['mw'],
    "bāhaṭanighaṇṭu": ['mw'],
    "bāhaṭīya": ['mw'],
    "bāhesi": ['cped'],
    "bāheti": ['cped'],
    "bāhetvā": ['cped'],
    "bāhira": ['bhs', 'cped'],
    "bāhiraka": ['bhs', 'cped'],
    "bāhirakapabbajjā": ['cped'],
    "bāhiratta": ['cped'],
    "bāhirvedika": ['mw'],
    "bāhirī": ['bhs'],
    "bāhita": ['cped'],
    "bāhitaka": ['bhs'],
    "bāhlaka": ['mw'],
    "bāhli": ['cae', 'mw'],
    "bāhlika": ['cae', 'mw'],
    "bāhlīka": ['cae', 'mw'],
    "bāhlīkī": ['mw'],
    "bāhu": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bāhubala": ['cae', 'mw'],
    "bāhubali": ['mw'],
    "bāhubalika": ['bhs'],
    "bāhubalin": ['cae', 'mw'],
    "bāhubandha": ['cae'],
    "bāhubandhana": ['cae', 'mw'],
    "bāhubhaṅgi": ['mw'],
    "bāhubhedin": ['mw'],
    "bāhubhāṣya": ['mw'],
    "bāhubhāṣyaṃ": ['ap90'],
    "bāhubhūṣaṇa": ['mw'],
    "bāhubhūṣā": ['mw'],
    "bāhubādha": ['mw'],
    "bāhucchinna": ['mw'],
    "bāhucyut": ['mw'],
    "bāhucyuta": ['ddsa', 'gra', 'mw'],
    "bāhucāpa": ['mw'],
    "bāhudantaka": ['mw'],
    "bāhudanteya": ['mw'],
    "bāhudantin": ['mw'],
    "bāhudantiputra": ['mw'],
    "bāhudaṃtakaṃ": ['ap90'],
    "bāhudaṃtin": ['ap90'],
    "bāhudaṇḍa": ['cae', 'mw'],
    "bāhudā": ['ap90', 'cae', 'mw'],
    "bāhudānadīmāhātmya": ['mw'],
    "bāhugarta": ['mw'],
    "bāhuguṇya": ['cae', 'ddsa', 'mw'],
    "bāhuguṇyaṃ": ['ap90'],
    "bāhuja": ['mw'],
    "bāhujanya": ['bhs', 'mw'],
    "bāhujañña": ['cped'],
    "bāhujyā": ['mw'],
    "bāhujūta": ['cae', 'gra', 'mw'],
    "bāhuk": ['mw'],
    "bāhuka": ['ap90', 'cae', 'ddsa', 'mw'],
    "bāhukara": ['mw'],
    "bāhukubja": ['mw'],
    "bāhukuleyaka": ['mw'],
    "bāhukuntha": ['mw'],
    "bāhukuṇṭha": ['mw'],
    "bāhukā": ['mw'],
    "bāhukīṭa": ['mw'],
    "bāhukṣad": ['gra', 'mw'],
    "bāhula": ['ap90', 'ddsa', 'mw'],
    "bāhulagrīva": ['mw'],
    "bāhulaka": ['mw'],
    "bāhulakaṃ": ['ap90'],
    "bāhulatikā": ['mw'],
    "bāhulatā": ['cae', 'ddsa', 'mw'],
    "bāhulatāntara": ['mw'],
    "bāhuleya": ['mw'],
    "bāhuleyaḥ": ['ap90'],
    "bāhuli": ['mw'],
    "bāhulika": ['bhs', 'cped'],
    "bāhulkāt": ['mw'],
    "bāhulla": ['cped'],
    "bāhullaya": ['cped'],
    "bāhulya": ['cae', 'ddsa', 'mw'],
    "bāhulyaṃ": ['ap90'],
    "bāhulyena": ['mw'],
    "bāhulyāt": ['mw'],
    "bāhumadhya": ['mw'],
    "bāhumant": ['cae'],
    "bāhumat": ['ap90', 'mw'],
    "bāhumatī": ['mw'],
    "bāhumaya": ['mw'],
    "bāhumitrāyaṇa": ['mw'],
    "bāhumātra": ['cae', 'mw'],
    "bāhumūla": ['cae', 'mw'],
    "bāhumūlavibhūṣaṇa": ['mw'],
    "bāhunikā": ['bhs'],
    "bāhuniḥsṛta": ['mw'],
    "bāhuojas": ['gra'],
    "bāhuphala": ['mw'],
    "bāhupracālakam": ['mw'],
    "bāhupraharaṇa": ['mw'],
    "bāhuprasāra": ['mw'],
    "bāhupratibāhu": ['mw'],
    "bāhupāśa": ['cae', 'mw'],
    "bāhurakṣā": ['mw'],
    "bāhurūpya": ['mw'],
    "bāhurūpyaṃ": ['ap90'],
    "bāhusacca": ['cped'],
    "bāhusahasrabhṛt": ['mw'],
    "bāhusahasrin": ['mw'],
    "bāhusambhava": ['mw'],
    "bāhusvastika": ['mw'],
    "bāhutaraṇa": ['mw'],
    "bāhutrāṇa": ['mw'],
    "bāhutā": ['cae', 'gra', 'mw'],
    "bāhuvartaka": ['mw'],
    "bāhuvat": ['mw'],
    "bāhuviddha": ['mw'],
    "bāhuvighaṭṭaṇa": ['mw'],
    "bāhuvighaṭṭita": ['mw'],
    "bāhuvikṣepa": ['ddsa', 'mw'],
    "bāhuvimarda": ['mw'],
    "bāhuvyāyāma": ['mw'],
    "bāhuvāra": ['mw'],
    "bāhuvīrya": ['cae', 'mw'],
    "bāhuvṛkta": ['gra', 'mw'],
    "bāhuyodha": ['cae', 'mw'],
    "bāhuyodhin": ['cae', 'mw'],
    "bāhuyuddha": ['cae', 'mw'],
    "bāhuśakti": ['mw'],
    "bāhuśardhin": ['gra', 'mw'],
    "bāhuśikhara": ['mw'],
    "bāhuśrutya": ['bhs', 'cae', 'ddsa', 'mw'],
    "bāhuśrutyaṃ": ['ap90'],
    "bāhuśrutīya": ['bhs'],
    "bāhuśāla": ['mw'],
    "bāhuśālaguḍa": ['mw'],
    "bāhuśālin": ['cae', 'mw'],
    "bāhuḥ": ['ap90'],
    "bāhv": ['mw'],
    "bāhvaṅka": ['cae', 'mw'],
    "bāhvaṭa": ['mw'],
    "bāhvojas": ['cae', 'ddsa', 'gra', 'mw'],
    "bāhvṛcya": ['cae', 'ddsa', 'mw'],
    "bāhvṛcyaṃ": ['ap90'],
    "bāhya": ['ap90', 'cae', 'mw'],
    "bāhyadruti": ['mw'],
    "bāhyaka": ['bhs'],
    "bāhyakakṣa": ['mw'],
    "bāhyakaraṇa": ['cae', 'ddsa', 'mw'],
    "bāhyakarṇa": ['mw'],
    "bāhyakasṛñjarī": ['mw'],
    "bāhyakuṇḍa": ['mw'],
    "bāhyakā": ['mw'],
    "bāhyaliṅgin": ['mw'],
    "bāhyam": ['mw'],
    "bāhyaprakṛti": ['mw'],
    "bāhyaprayatna": ['mw'],
    "bāhyarata": ['mw'],
    "bāhyasambhoga": ['mw'],
    "bāhyasparśa": ['cae', 'mw'],
    "bāhyataddhita": ['mw'],
    "bāhyatara": ['mw'],
    "bāhyatas": ['cae', 'mw'],
    "bāhyatonara": ['mw'],
    "bāhyatva": ['mw'],
    "bāhyatā": ['mw'],
    "bāhyavastu": ['mw'],
    "bāhyavāsin": ['mw'],
    "bāhye": ['mw'],
    "bāhyena": ['mw'],
    "bāhyendriya": ['cae', 'mw'],
    "bāhyopavana": ['mw'],
    "bāhyā": ['mw'],
    "bāhyābhyantara": ['mw'],
    "bāhyālaya": ['mw'],
    "bāhyānta": ['mw'],
    "bāhyāntar": ['cae', 'mw'],
    "bāhyārtha": ['mw'],
    "bāhyārthabhaṅganirākaraṇa": ['mw'],
    "bāhyārthavāda": ['mw'],
    "bāhyārthavādin": ['mw'],
    "bāhyāt": ['mw'],
    "bāhyāyāma": ['mw'],
    "bāhyāśakala": ['mw'],
    "bāhyāśva": ['mw'],
    "bāhyāṃsa": ['ddsa', 'mw'],
    "bāhā": ['ap90', 'bhs', 'cped'],
    "bāhābala": ['cped'],
    "bāhābāhavi": ['mw'],
    "bāhādura": ['mw'],
    "bāhīka": ['ap90', 'cae', 'ddsa', 'mw'],
    "bāhūbāhavi": ['ap90', 'cae', 'ddsa', 'mw'],
    "bāhūpapīḍam": ['mw'],
    "bāhūtkṣepam": ['cae', 'ddsa', 'mw'],
    "bājabahāduracandra": ['mw'],
    "bāka": ['mw'],
    "bākarukā": ['mw'],
    "bākula": ['ddsa', 'mw'],
    "bākulaṃ": ['ap90'],
    "bākura": ['cae', 'ddsa', 'gra', 'mw'],
    "bākāyana": ['mw'],
    "bāl": ['cae', 'mw'],
    "bāla": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "bālabandhana": ['cae', 'mw'],
    "bālabhadraka": ['mw'],
    "bālabhairavīdīpadāna": ['mw'],
    "bālabhaiṣajya": ['mw'],
    "bālabhañjaka": ['mw'],
    "bālabhojya": ['mw'],
    "bālabhārata": ['cae', 'mw'],
    "bālabhāva": ['cae', 'mw'],
    "bālabhāṣāvyākaraṇasūtravṛtti": ['mw'],
    "bālabhūṣā": ['mw'],
    "bālabhūṣāsāra": ['mw'],
    "bālabhṛtya": ['mw'],
    "bālabodha": ['mw'],
    "bālabodhaka": ['mw'],
    "bālabodhanī": ['mw'],
    "bālabodhanībhāvaprakāśa": ['mw'],
    "bālabodhanīnyāsa": ['mw'],
    "bālabodhasaṃgraha": ['mw'],
    "bālabodhikā": ['mw'],
    "bālabuddhiprakāśinī": ['mw'],
    "bālacandra": ['cae', 'mw'],
    "bālacandrikā": ['mw'],
    "bālacarita": ['mw'],
    "bālacaritanāman": ['mw'],
    "bālacaritva": ['mw'],
    "bālacarya": ['mw'],
    "bālacaryā": ['mw'],
    "bālacikitsā": ['mw'],
    "bālacāturbhadrikā": ['mw'],
    "bālacūta": ['mw'],
    "bāladalaka": ['mw'],
    "bāladarśam": ['mw'],
    "bāladeva": ['cae', 'mw'],
    "bāladhana": ['cae', 'mw'],
    "bālagaja": ['mw'],
    "bālagarbhiṇī": ['mw'],
    "bālagaurītīrtha": ['mw'],
    "bālagaṇapatipūjā": ['mw'],
    "bālaghna": ['cae', 'mw'],
    "bālagopāla": ['mw'],
    "bālagopālatīrtha": ['mw'],
    "bālagopālayatīndra": ['mw'],
    "bālagovinda": ['mw'],
    "bālagraha": ['mw'],
    "bālagrahapratiṣedha": ['mw'],
    "bālagrahayogaśānti": ['mw'],
    "bālagrahopaśamana": ['mw'],
    "bālagādādharī": ['mw'],
    "bālahan": ['cae', 'mw'],
    "bālahatyā": ['mw'],
    "bālajātaka": ['mw'],
    "bālajātīya": ['mw'],
    "bālaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "bālakadalī": ['mw'],
    "bālakahatyā": ['mw'],
    "bālakamalinī": ['cae', 'mw'],
    "bālakapralapita": ['mw'],
    "bālakapriya": ['mw'],
    "bālakapriyā": ['mw'],
    "bālakatva": ['mw'],
    "bālakavi": ['mw'],
    "bālakeli": ['cae', 'mw'],
    "bālakelī": ['cae', 'mw'],
    "bālakhilya": ['mw'],
    "bālakriyā": ['mw'],
    "bālakrīḍana": ['cae', 'mw'],
    "bālakrīḍanaka": ['cae', 'mw'],
    "bālakrīḍā": ['mw'],
    "bālakrīḍākāvya": ['mw'],
    "bālakrīḍāvarṇana": ['mw'],
    "bālakunda": ['mw'],
    "bālakundānuviddha": ['mw'],
    "bālakāvya": ['mw'],
    "bālakāṇḍa": ['mw'],
    "bālakāṇḍasūtra": ['bhs'],
    "bālakīya": ['ap90', 'mw'],
    "bālakṛṣṇa": ['mw'],
    "bālakṛṣṇacampū": ['mw'],
    "bālakṛṣṇakrīḍākāvya": ['mw'],
    "bālakṛṣṇānanda": ['mw'],
    "bālakṛṣṇāṣṭaka": ['mw'],
    "bālalatā": ['mw'],
    "bālalīlā": ['cae', 'mw'],
    "bālamallavenasiddhānta": ['mw'],
    "bālamandāravṛkṣa": ['mw'],
    "bālamanoramā": ['mw'],
    "bālamaraṇa": ['mw'],
    "bālamaraṇavidhikartavyatā": ['mw'],
    "bālamati": ['cae', 'mw'],
    "bālambhaṭṭa": ['mw'],
    "bālambhaṭṭīya": ['mw'],
    "bālamitra": ['cae', 'mw'],
    "bālamukundācārya": ['mw'],
    "bālamūla": ['mw'],
    "bālamūlaka": ['mw'],
    "bālamūlikā": ['mw'],
    "bālamūṣikā": ['mw'],
    "bālamṛga": ['mw'],
    "bālamṛṇāla": ['mw'],
    "bālandana": ['mw'],
    "bālanetra": ['mw'],
    "bālapattra": ['mw'],
    "bālapattraka": ['mw'],
    "bālapaṇḍita": ['bhs', 'mw'],
    "bālaprabodhikā": ['mw'],
    "bālaprabodhinī": ['mw'],
    "bālaprakāśa": ['mw'],
    "bālapramathanī": ['mw'],
    "bālaputra": ['mw'],
    "bālaputraka": ['cae', 'mw'],
    "bālapuṣpikā": ['mw'],
    "bālapuṣpī": ['mw'],
    "bālapādapa": ['mw'],
    "bālapāśyā": ['mw'],
    "bālapāṭha": ['mw'],
    "bālarakṣaṇa": ['mw'],
    "bālarakṣaṇavidhāna": ['mw'],
    "bālarakṣā": ['mw'],
    "bālarakṣāstava": ['mw'],
    "bālarakṣāstotra": ['mw'],
    "bālarañjinī": ['mw'],
    "bālaroga": ['cae', 'mw'],
    "bālarāghavīya": ['mw'],
    "bālarāja": ['mw'],
    "bālarāmabharata": ['mw'],
    "bālarāmāyaṇa": ['cae', 'mw'],
    "bālarūpa": ['mw'],
    "bālarūpadhara": ['mw'],
    "bālarūpadhṛk": ['mw'],
    "bālasakhi": ['cae', 'mw'],
    "bālasakhitva": ['mw'],
    "bālasarasvatī": ['mw'],
    "bālasarasvatīya": ['mw'],
    "bālasaṃdhyā": ['mw'],
    "bālasaṃdhyābha": ['mw'],
    "bālasaṃjīvana": ['mw'],
    "bālasiṃha": ['mw'],
    "bālasthāna": ['mw'],
    "bālasuhṛd": ['cae', 'mw'],
    "bālasārayantra": ['mw'],
    "bālasātmya": ['mw'],
    "bālasūrya": ['mw'],
    "bālasūryaka": ['mw'],
    "bālatanaya": ['mw'],
    "bālatantra": ['mw'],
    "bālataru": ['mw'],
    "bālatva": ['mw'],
    "bālatā": ['cae', 'cped', 'mw'],
    "bālatṛṇa": ['mw'],
    "bālavaidhavya": ['cae', 'mw'],
    "bālavanitā": ['mw'],
    "bālavatsa": ['mw'],
    "bālavaḥ": ['ap90'],
    "bālavinaṣṭa": ['mw'],
    "bālavinaṣṭaka": ['mw'],
    "bālavinodinī": ['mw'],
    "bālavivekinī": ['mw'],
    "bālavrata": ['mw'],
    "bālavyañjana": ['bhs'],
    "bālavyākaraṇa": ['mw'],
    "bālavāhya": ['mw'],
    "bālavṛkṣa": ['mw'],
    "bālayajñopavītaka": ['mw'],
    "bālayati": ['bhs'],
    "bālaśarman": ['mw'],
    "bālaśāstrin": ['mw'],
    "bālaśṛṅga": ['mw'],
    "bālbaja": ['cae', 'mw'],
    "bālbajabhārika": ['mw'],
    "bālbajika": ['mw'],
    "bālendu": ['ddsa', 'mw'],
    "bāleya": ['ap90', 'cae', 'ddsa', 'mw'],
    "bāleyaśāka": ['mw'],
    "bāleyārdhika": ['mw'],
    "bāleśvara": ['mw'],
    "bāleṣṭa": ['mw'],
    "bālhakāḥ": ['ap90'],
    "bālhava": ['mw'],
    "bālhi": ['cae', 'ddsa', 'mw'],
    "bālhija": ['mw'],
    "bālhijāta": ['mw'],
    "bālhika": ['cae', 'mw'],
    "bālhikeyamiśra": ['mw'],
    "bālhiḥ": ['ap90'],
    "bālhāyana": ['mw'],
    "bālhīka": ['cae', 'ddsa', 'mw'],
    "bālhīkabhāṣā": ['mw'],
    "bālhīkeśa": ['mw'],
    "bālhīkī": ['mw'],
    "bālhīśvara": ['mw'],
    "bāli": ['mw'],
    "bālikā": ['ap90', 'bhs', 'ddsa'],
    "bāliman": ['ap90', 'mw'],
    "bālin": ['ap90', 'mw'],
    "bālinī": ['ap90'],
    "bālisika": ['cped'],
    "bāliśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "bāliśamati": ['mw'],
    "bāliśatva": ['mw'],
    "bāliśatā": ['cae', 'mw'],
    "bāliśya": ['mw'],
    "bāliśyaṃ": ['ap90'],
    "bāliḥ": ['ap90'],
    "bāloka": ['mw'],
    "bālopacaraṇa": ['ddsa', 'mw'],
    "bālopacaraṇiya": ['mw'],
    "bālopacaraṇīya": ['mw'],
    "bālopaniṣad": ['mw'],
    "bālopavīta": ['mw'],
    "bālu": ['mw'],
    "bālukā": ['ap90'],
    "bālukī": ['ap90'],
    "bāluḥ": ['ap90'],
    "bālya": ['cae', 'cped', 'ddsa', 'mw'],
    "bālyakāla": ['mw'],
    "bālyatā": ['mw'],
    "bālyaṃ": ['ap90'],
    "bālā": ['ap90', 'cped', 'ddsa', 'mw'],
    "bālābhyāsa": ['mw'],
    "bālācārya": ['mw'],
    "bālādhyāpaka": ['cae', 'mw'],
    "bālādhyāpakatā": ['mw'],
    "bālāditya": ['cae', 'mw'],
    "bālādityavrata": ['mw'],
    "bālādīkṣita": ['mw'],
    "bālāgra": ['mw'],
    "bālāgrapūtikā": ['bhs'],
    "bālāha": ['bhs', 'mw'],
    "bālāhaka": ['bhs', 'mw'],
    "bālāhatyā": ['mw'],
    "bālākalpa": ['mw'],
    "bālākavaca": ['mw'],
    "bālāki": ['mw'],
    "bālākyā": ['mw'],
    "bālālokasaṃkṣepa": ['mw'],
    "bālāmaya": ['mw'],
    "bālāmayapratiṣedha": ['mw'],
    "bālānucaragopta": ['mw'],
    "bālānucaragupta": ['mw'],
    "bālāpaddhati": ['mw'],
    "bālāpatya": ['cae', 'mw'],
    "bālāpañcaratna": ['mw'],
    "bālārcāpaddhati": ['mw'],
    "bālāriṣṭa": ['mw'],
    "bālāriṣṭādhyāya": ['mw'],
    "bālārka": ['cae', 'mw'],
    "bālārkakomala": ['mw'],
    "bālārkapratimā": ['mw'],
    "bālārkavarṇa": ['mw'],
    "bālārkāya": ['mw'],
    "bālāruṇa": ['mw'],
    "bālāsura": ['mw'],
    "bālāsuravadha": ['mw'],
    "bālātantra": ['mw'],
    "bālātapa": ['cae', 'ddsa', 'mw'],
    "bālātaparakta": ['mw'],
    "bālātripurasundarīpūjanaprayoga": ['mw'],
    "bālāvabodha": ['mw'],
    "bālāvabodhana": ['mw'],
    "bālāvabodhapaddhati": ['mw'],
    "bālāvarṇana": ['mw'],
    "bālāvastha": ['mw'],
    "bālāvasthā": ['mw'],
    "bālāyani": ['mw'],
    "bālāśoka": ['mw'],
    "bālāṣṭaka": ['mw'],
    "bālāṣṭottaraśatanāmastotra": ['mw'],
    "bālī": ['ap90'],
    "bālīvardineya": ['mw'],
    "bālīyas": ['ddsa'],
    "bālīśa": ['mw'],
    "bālīśaḥ": ['ap90'],
    "bālūkaḥ": ['ap90'],
    "bāl̤ha": ['mw'],
    "bāndhakeya": ['mw'],
    "bāndhaki": ['mw'],
    "bāndhakineya": ['mw'],
    "bāndhava": ['cae', 'ddsa', 'mw'],
    "bāndhavadhurā": ['cae', 'mw'],
    "bāndhavajana": ['mw'],
    "bāndhavaka": ['mw'],
    "bāndhavatā": ['mw'],
    "bāndhavya": ['cae', 'mw'],
    "bāndhavī": ['mw'],
    "bāndhuka": ['mw'],
    "bāndhukineya": ['mw'],
    "bāndhukya": ['mw'],
    "bāndhupata": ['mw'],
    "bāpaya": ['mw'],
    "bāpaṇṇabhaṭṭa": ['mw'],
    "bāpubhaṭṭa": ['mw'],
    "bāpyadeva": ['mw'],
    "bāpūdeva": ['mw'],
    "bāra": ['cae', 'gra', 'mw'],
    "bārahaṭa": ['mw'],
    "bārasa": ['cped'],
    "bārbara": ['mw'],
    "bārbaraka": ['mw'],
    "bārbarīṭa": ['mw'],
    "bārbaṭīraḥ": ['ap90'],
    "bārejya": ['mw'],
    "bārha": ['ap90', 'cae', 'mw'],
    "bārhad": ['mw'],
    "bārhadagna": ['mw'],
    "bārhadbala": ['mw'],
    "bārhaddaivata": ['ddsa', 'mw'],
    "bārhadgira": ['mw'],
    "bārhadratha": ['mw'],
    "bārhadrathaḥ": ['ap90'],
    "bārhadrathi": ['mw'],
    "bārhaduktha": ['mw'],
    "bārhadīṣava": ['mw'],
    "bārhas": ['mw'],
    "bārhaspata": ['ap90', 'cae', 'ddsa', 'mw'],
    "bārhaspatya": ['ap90', 'cae', 'mw'],
    "bārhaspatyajyotirgrantha": ['mw'],
    "bārhaspatyajyotiḥśāstra": ['mw'],
    "bārhaspatyamahiman": ['mw'],
    "bārhaspatyamuhūrtavidhāna": ['mw'],
    "bārhaspatyasaṃhitā": ['mw'],
    "bārhaspatyasmṛti": ['mw'],
    "bārhaspatyasūtraṭīkā": ['mw'],
    "bārhaspatyatantra": ['mw'],
    "bārhat": ['mw'],
    "bārhata": ['cae', 'ddsa', 'gra', 'mw'],
    "bārhataka": ['cae', 'mw'],
    "bārhatsāmā": ['mw'],
    "bārhatānuṣṭubha": ['mw'],
    "bārhavata": ['mw'],
    "bārhiḥṣada": ['mw'],
    "bārhiṇa": ['ap90'],
    "bārhiṇalakṣmaṇa": ['mw'],
    "bārhiṣada": ['mw'],
    "bārāṇasī": ['cped'],
    "bārāṇasīṇaseyyaka": ['cped'],
    "bārḍhya": ['mw'],
    "bāsa": ['ddsa', 'mw'],
    "bāskala": ['mw'],
    "bāspa": ['mw'],
    "bāsta": ['ap90', 'cae', 'ddsa', 'mw'],
    "bāsteya": ['mw'],
    "bāstika": ['cae', 'mw'],
    "bāstāyana": ['mw'],
    "bāveru": ['mw'],
    "bāverujātaka": ['mw'],
    "bāvādeva": ['mw'],
    "bāvāśāstrin": ['mw'],
    "bāvīsati": ['cped'],
    "bāyabhaṭṭa": ['mw'],
    "bāḍ": ['ap90', 'mw'],
    "bāḍaba": ['mw'],
    "bāḍabhīkara": ['mw'],
    "bāḍavaḥ": ['ap90'],
    "bāḍaveya": ['ap90'],
    "bāḍavya": ['ap90'],
    "bāḍeyīputra": ['mw'],
    "bāḍha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bāḍham": ['mw'],
    "bāḍhasṛtvan": ['gra', 'mw'],
    "bāḍhavikrama": ['mw'],
    "bāḍita": ['bhs', 'mw'],
    "bāḍīra": ['mw'],
    "bāḍīraḥ": ['ap90'],
    "bāḷha": ['cped'],
    "bāḷhaṁ": ['cped'],
    "bāṃdhakineyaḥ": ['ap90'],
    "bāṃdhavaḥ": ['ap90'],
    "bāṃdhavyaṃ": ['ap90'],
    "bāṇa": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bāṇabhaṭṭa": ['mw'],
    "bāṇadhi": ['cae', 'cped', 'mw'],
    "bāṇagaṅgā": ['mw'],
    "bāṇagocara": ['mw'],
    "bāṇahan": ['mw'],
    "bāṇajit": ['mw'],
    "bāṇaliṅga": ['mw'],
    "bāṇamaya": ['mw'],
    "bāṇamokṣaṇa": ['mw'],
    "bāṇamukha": ['mw'],
    "bāṇamukti": ['mw'],
    "bāṇanikṛta": ['mw'],
    "bāṇanāśā": ['mw'],
    "bāṇaparṇi": ['mw'],
    "bāṇapatha": ['cae', 'mw'],
    "bāṇapathavartin": ['mw'],
    "bāṇapathātīta": ['mw'],
    "bāṇapañcānana": ['mw'],
    "bāṇapur": ['mw'],
    "bāṇapura": ['mw'],
    "bāṇapuṅkhā": ['mw'],
    "bāṇapāta": ['cae', 'mw'],
    "bāṇapātavartin": ['cae', 'mw'],
    "bāṇapāṇi": ['mw'],
    "bāṇarekhā": ['mw'],
    "bāṇasaṃdhāna": ['mw'],
    "bāṇasiddhi": ['mw'],
    "bāṇasutā": ['mw'],
    "bāṇatā": ['mw'],
    "bāṇatūṇa": ['mw'],
    "bāṇatūṇīkṛta": ['mw'],
    "bāṇavant": ['cae'],
    "bāṇavarṣaṇa": ['mw'],
    "bāṇavarṣin": ['mw'],
    "bāṇavat": ['ddsa', 'mw'],
    "bāṇavāra": ['mw'],
    "bāṇavṛṣṭi": ['mw'],
    "bāṇayojana": ['mw'],
    "bāṇaśabda": ['cae'],
    "bāṇaḥ": ['ap90'],
    "bāṇeya": ['mw'],
    "bāṇeśvara": ['mw'],
    "bāṇi": ['mw'],
    "bāṇija": ['mw'],
    "bāṇin": ['cae', 'ddsa', 'mw'],
    "bāṇinī": ['ap90'],
    "bāṇā": ['mw'],
    "bāṇābhyāsa": ['mw'],
    "bāṇāparṇi": ['mw'],
    "bāṇāri": ['mw'],
    "bāṇāsana": ['cae', 'mw'],
    "bāṇāsanīkṛ": ['mw'],
    "bāṇāsura": ['mw'],
    "bāṇāsuravadha": ['mw'],
    "bāṇāsuravijaya": ['mw'],
    "bāṇāvalī": ['ddsa', 'mw'],
    "bāṇāśraya": ['mw'],
    "bāṇī": ['mw'],
    "bāṇḍyāyana": ['bhs'],
    "bāṣkala": ['ddsa', 'mw'],
    "bāṣkalaka": ['mw'],
    "bāṣkalaśākhā": ['mw'],
    "bāṣkali": ['mw'],
    "bāṣkalikā": ['mw'],
    "bāṣkalopaniṣad": ['mw'],
    "bāṣkaya": ['mw'],
    "bāṣkiha": ['mw'],
    "bāṣpa": ['bhs', 'cae', 'ddsa', 'mw'],
    "bāṣpabindu": ['mw'],
    "bāṣpacandra": ['mw'],
    "bāṣpadurdina": ['mw'],
    "bāṣpadurdinākṣa": ['mw'],
    "bāṣpagrathita": ['mw'],
    "bāṣpahatekṣaṇa": ['mw'],
    "bāṣpaka": ['mw'],
    "bāṣpakala": ['mw'],
    "bāṣpakaṇṭha": ['cae', 'mw'],
    "bāṣpakā": ['mw'],
    "bāṣpamocana": ['mw'],
    "bāṣpamokṣa": ['cae', 'mw'],
    "bāṣpamukha": ['mw'],
    "bāṣpaparyākulekṣaṇa": ['mw'],
    "bāṣpapihitalocana": ['mw'],
    "bāṣpaprakara": ['mw'],
    "bāṣpapramocana": ['mw'],
    "bāṣpapūra": ['mw'],
    "bāṣpasalila": ['cae', 'mw'],
    "bāṣpasaṃdigdha": ['mw'],
    "bāṣpaviklaba": ['mw'],
    "bāṣpaviklababhāṣin": ['mw'],
    "bāṣpavṛṣṭi": ['mw'],
    "bāṣpaḥ": ['ap90'],
    "bāṣpikā": ['mw'],
    "bāṣpin": ['ddsa', 'mw'],
    "bāṣpodbhava": ['mw'],
    "bāṣpotpīḍa": ['cae', 'ddsa', 'mw'],
    "bāṣpākula": ['mw'],
    "bāṣpāmbu": ['cae', 'mw'],
    "bāṣpāmbupūra": ['mw'],
    "bāṣpāmbuśīkara": ['mw'],
    "bāṣpāpluta": ['mw'],
    "bāṣpāsāra": ['cae', 'mw'],
    "bāṣpāvilekṣaṇa": ['mw'],
    "bāṣpāy": ['cae'],
    "bāṣpāya": ['ddsa', 'mw'],
    "bāṣpāyate": ['ap90'],
    "bāṣpāyati": ['bhs'],
    "bāṣpī": ['mw'],
    "bāṣpīkā": ['mw'],
    "bībh": ['mw'],
    "bībhacca": ['cped'],
    "bībhats": ['cae'],
    "bībhatsa": ['ap90', 'cae', 'ddsa', 'mw'],
    "bībhatsaka": ['bhs', 'mw'],
    "bībhatsakarman": ['mw'],
    "bībhatsana": ['bhs'],
    "bībhatsatā": ['mw'],
    "bībhatsu": ['ap90', 'cae', 'gra', 'mw'],
    "bībhatsā": ['mw'],
    "bīja": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "bījabhūta": ['mw'],
    "bījabīja": ['cped'],
    "bījacintāmaṇitantra": ['mw'],
    "bījadarśaka": ['mw'],
    "bījadharman": ['mw'],
    "bījadhānya": ['mw'],
    "bījadhānī": ['mw'],
    "bījadravya": ['mw'],
    "bījagarbha": ['mw'],
    "bījagaṇita": ['mw'],
    "bījagaṇitaprabodha": ['mw'],
    "bījagaṇitodāharaṇa": ['mw'],
    "bījagupti": ['mw'],
    "bījagāma": ['cped'],
    "bījaharā": ['mw'],
    "bījahāriṇī": ['mw'],
    "bījajāta": ['cped'],
    "bījaka": ['cae', 'mw'],
    "bījakartṛ": ['mw'],
    "bījakaḥ": ['ap90'],
    "bījakosa": ['cped'],
    "bījakośa": ['cae', 'mw'],
    "bījakośoddhāra": ['mw'],
    "bījakośī": ['mw'],
    "bījakriyā": ['mw'],
    "bījakāṇḍaprarohin": ['cae', 'mw'],
    "bījakāṇḍaruha": ['cae', 'mw'],
    "bījakṛt": ['mw'],
    "bījala": ['ap90', 'mw'],
    "bījalīlāvatī": ['mw'],
    "bījamantra": ['mw'],
    "bījamati": ['mw'],
    "bījamuktāvalī": ['mw'],
    "bījamuṣṭi": ['mw'],
    "bījamātra": ['mw'],
    "bījamātṛkā": ['mw'],
    "bījanighaṇṭu": ['mw'],
    "bījanirvāpaṇa": ['mw'],
    "bījanyāsa": ['mw'],
    "bījanātha": ['mw'],
    "bījapallava": ['mw'],
    "bījapeśikā": ['mw'],
    "bījaphalaka": ['mw'],
    "bījaprabhava": ['mw'],
    "bījaprada": ['cae', 'mw'],
    "bījapraroha": ['mw'],
    "bījaprarohin": ['mw'],
    "bījapura": ['mw'],
    "bījapuruṣa": ['mw'],
    "bījapuṣpa": ['mw'],
    "bījapuṣpikā": ['mw'],
    "bījapādapa": ['mw'],
    "bījapūra": ['cae', 'mw'],
    "bījapūraka": ['cae', 'mw'],
    "bījapūrarasa": ['mw'],
    "bījapūrī": ['mw'],
    "bījapūrṇa": ['mw'],
    "bījaratna": ['mw'],
    "bījarecana": ['mw'],
    "bījaruha": ['mw'],
    "bījaruhākṛ": ['mw'],
    "bījaryā": ['mw'],
    "bījasaṃcaya": ['mw'],
    "bījasaṃhṛtimat": ['mw'],
    "bījasektṛ": ['mw'],
    "bījasū": ['mw'],
    "bījatas": ['mw'],
    "bījatva": ['mw'],
    "bījavant": ['cae'],
    "bījavapana": ['mw'],
    "bījavara": ['mw'],
    "bījavat": ['mw'],
    "bījavivṛti": ['mw'],
    "bījavivṛtikalpalatāvatāra": ['mw'],
    "bījavāhana": ['mw'],
    "bījavāpa": ['cae', 'mw'],
    "bījavāpagṛhya": ['mw'],
    "bījavāpin": ['mw'],
    "bījavṛkṣa": ['mw'],
    "bījayajña": ['mw'],
    "bījaśeṣamātra": ['mw'],
    "bījaṃ": ['ap90'],
    "bījika": ['ap90', 'mw'],
    "bījin": ['ap90', 'cae', 'ddsa', 'mw'],
    "bījita": ['mw'],
    "bījodaka": ['mw'],
    "bījodāharaṇabālabodhinī": ['mw'],
    "bījopanayana": ['mw'],
    "bījopti": ['mw'],
    "bījopticakra": ['mw'],
    "bījoptividhi": ['mw'],
    "bījotkraṣṭṛ": ['cae', 'ddsa', 'mw'],
    "bījotkṛṣṭa": ['mw'],
    "bījya": ['ap90', 'mw'],
    "bījā": ['mw'],
    "bījābhidhāna": ['mw'],
    "bījādhyakṣa": ['mw'],
    "bījākara": ['mw'],
    "bījākṛ": ['mw'],
    "bījākṛta": ['mw'],
    "bījākṣara": ['ddsa', 'mw'],
    "bījāmla": ['mw'],
    "bījāpahāriṇī": ['mw'],
    "bījārtha": ['mw'],
    "bījārṇavatantra": ['mw'],
    "bījāñjali": ['mw'],
    "bījāśva": ['cae', 'mw'],
    "bījāḍhya": ['cae', 'mw'],
    "bījāṅkura": ['cae', 'mw'],
    "bījāṅkuranyāya": ['mw'],
    "bījāṅkuravat": ['mw'],
    "bīraṇa": ['cped'],
    "bīraṇatthambha": ['cped'],
    "bīriṇa": ['mw'],
    "bīriṭa": ['gra', 'mw'],
    "bīriṭaḥ": ['ap90'],
    "bīśa": ['mw'],
    "bīṭaka": ['mw'],
    "būbaśarman": ['mw'],
    "būkhan": ['mw'],
    "būkka": ['mw'],
    "būkkaṃ": ['ap90'],
    "būtkāra": ['mw'],
    "būṣa": ['mw'],
    "bṛbaduktha": ['cae', 'gra', 'mw'],
    "bṛbu": ['cae', 'ddsa', 'gra', 'mw'],
    "bṛbūka": ['gra', 'mw'],
    "bṛgala": ['cae', 'ddsa', 'mw'],
    "bṛh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "bṛhac": ['mw'],
    "bṛhaccañcu": ['mw'],
    "bṛhacchabdenduśekhara": ['mw'],
    "bṛhacchada": ['mw'],
    "bṛhacchalka": ['mw'],
    "bṛhacchandas": ['mw'],
    "bṛhaccharīra": ['gra', 'mw'],
    "bṛhacchattrā": ['mw'],
    "bṛhacchimbī": ['mw'],
    "bṛhacchiras": ['mw'],
    "bṛhacchloka": ['cae', 'mw'],
    "bṛhacchoka": ['cae', 'mw'],
    "bṛhacchravas": ['cae', 'gra', 'mw'],
    "bṛhacchrīkrama": ['mw'],
    "bṛhacchuka": ['mw'],
    "bṛhacchāla": ['mw'],
    "bṛhacchāntistava": ['mw'],
    "bṛhacchātātapa": ['mw'],
    "bṛhacchṛṅgāratilaka": ['mw'],
    "bṛhaccintāmaṇi": ['mw'],
    "bṛhaccintāmaṇiṭīkā": ['mw'],
    "bṛhaccitta": ['mw'],
    "bṛhaccāṇakya": ['ddsa', 'mw'],
    "bṛhad": ['mw'],
    "bṛhadabhidhānacintāmaṇi": ['mw'],
    "bṛhadagni": ['mw'],
    "bṛhadagnimukha": ['mw'],
    "bṛhadamara": ['mw'],
    "bṛhadamarakośa": ['mw'],
    "bṛhadambālikā": ['mw'],
    "bṛhadambāśataka": ['mw'],
    "bṛhadamla": ['mw'],
    "bṛhadanīka": ['mw'],
    "bṛhadarka": ['mw'],
    "bṛhadasṛṅmati": ['mw'],
    "bṛhadatri": ['mw'],
    "bṛhadaśman": ['cae'],
    "bṛhadaśva": ['cae', 'mw'],
    "bṛhadaṅga": ['ddsa', 'mw'],
    "bṛhadaṅgiras": ['mw'],
    "bṛhadaṣṭavarga": ['mw'],
    "bṛhadbala": ['mw'],
    "bṛhadbhaya": ['mw'],
    "bṛhadbhaṭṭa": ['mw'],
    "bṛhadbhaṭṭārikā": ['mw'],
    "bṛhadbhuja": ['mw'],
    "bṛhadbhāgavatāmṛta": ['mw'],
    "bṛhadbhānu": ['cae', 'gra', 'mw'],
    "bṛhadbhās": ['cae', 'mw'],
    "bṛhadbhāsa": ['mw'],
    "bṛhadbhāsā": ['mw'],
    "bṛhadbrahman": ['mw'],
    "bṛhadbrahmasaṃhitā": ['mw'],
    "bṛhadbrahmottarakhaṇḍa": ['mw'],
    "bṛhadbīja": ['mw'],
    "bṛhadbṛhaspati": ['mw'],
    "bṛhaddala": ['mw'],
    "bṛhaddantī": ['mw'],
    "bṛhaddarbha": ['mw'],
    "bṛhaddevasthāna": ['mw'],
    "bṛhaddevatā": ['cae', 'mw'],
    "bṛhaddhala": ['mw'],
    "bṛhaddhan": ['mw'],
    "bṛhaddhanus": ['mw'],
    "bṛhaddharman": ['mw'],
    "bṛhaddharmaprakāśa": ['mw'],
    "bṛhaddharmapurāṇa": ['mw'],
    "bṛhaddhemādri": ['mw'],
    "bṛhaddhomapaddhati": ['mw'],
    "bṛhaddhustūra": ['mw'],
    "bṛhaddhvaja": ['mw'],
    "bṛhaddhvanī": ['mw'],
    "bṛhaddhārāvalī": ['mw'],
    "bṛhaddhārīta": ['mw'],
    "bṛhaddhātrī": ['mw'],
    "bṛhaddiva": ['cae', 'gra', 'mw'],
    "bṛhaddiveṣu": ['mw'],
    "bṛhaddivā": ['gra', 'mw'],
    "bṛhaddurga": ['mw'],
    "bṛhaddyumna": ['cae', 'mw'],
    "bṛhaddyuti": ['cae', 'mw'],
    "bṛhadelā": ['mw'],
    "bṛhadgala": ['mw'],
    "bṛhadgarbha": ['mw'],
    "bṛhadgaurīvrata": ['mw'],
    "bṛhadgaurīvratakathā": ['mw'],
    "bṛhadgiri": ['cae', 'gra', 'mw'],
    "bṛhadgola": ['mw'],
    "bṛhadgrāvan": ['cae', 'mw'],
    "bṛhadguha": ['mw'],
    "bṛhadguru": ['mw'],
    "bṛhadgurvāvalipūjāśāntividhāna": ['mw'],
    "bṛhadgītāvyākhyā": ['mw'],
    "bṛhadgṛha": ['mw'],
    "bṛhadiṣu": ['mw'],
    "bṛhadopaśā": ['mw'],
    "bṛhadratha": ['bhs', 'cae', 'gra', 'mw'],
    "bṛhadrathaṃtara": ['mw'],
    "bṛhadrathaṃtarasāman": ['mw'],
    "bṛhadrathā": ['mw'],
    "bṛhadratnakārikā": ['mw'],
    "bṛhadratnākara": ['mw'],
    "bṛhadravas": ['cae', 'mw'],
    "bṛhadrayi": ['cae', 'gra', 'mw'],
    "bṛhadraṇa": ['mw'],
    "bṛhadreṇu": ['gra', 'mw'],
    "bṛhadri": ['cae', 'gra', 'mw'],
    "bṛhadroma": ['mw'],
    "bṛhadromapaṭṭana": ['mw'],
    "bṛhadrāja": ['mw'],
    "bṛhadrājamārtaṇḍa": ['mw'],
    "bṛhadrāvan": ['mw'],
    "bṛhadrāvin": ['mw'],
    "bṛhadrūpa": ['mw'],
    "bṛhaduktha": ['cae', 'ddsa', 'gra', 'mw'],
    "bṛhadukthi": ['mw'],
    "bṛhadukṣ": ['cae', 'gra', 'mw'],
    "bṛhadukṣa": ['cae', 'mw'],
    "bṛhadukṣan": ['cae', 'gra', 'mw'],
    "bṛhaduttaratāpinī": ['mw'],
    "bṛhadvadha": ['mw'],
    "bṛhadvaiyākaraṇabhūṣaṇa": ['mw'],
    "bṛhadvalka": ['mw'],
    "bṛhadvasiṣṭha": ['mw'],
    "bṛhadvasu": ['cae', 'mw'],
    "bṛhadvat": ['mw'],
    "bṛhadvatī": ['mw'],
    "bṛhadvayas": ['cae', 'mw'],
    "bṛhadvivāhapaṭala": ['mw'],
    "bṛhadviṣṇu": ['mw'],
    "bṛhadvrata": ['cae', 'mw'],
    "bṛhadvyākaraṇabhūṣaṇa": ['mw'],
    "bṛhadvyāsa": ['mw'],
    "bṛhadvādin": ['cae', 'mw'],
    "bṛhadvāruṇī": ['mw'],
    "bṛhadvārāhayantramāhātmya": ['mw'],
    "bṛhadvāsiṣṭha": ['mw'],
    "bṛhadvāta": ['mw'],
    "bṛhadvṛtti": ['mw'],
    "bṛhadyama": ['mw'],
    "bṛhadyogiyājñavalkyasmṛti": ['mw'],
    "bṛhadyājñavalkya": ['mw'],
    "bṛhadyātrā": ['mw'],
    "bṛhadāra": ['mw'],
    "bṛhadāraṇya": ['mw'],
    "bṛhadāraṇyaka": ['cae', 'mw'],
    "bṛhadāraṇyakabhāṣya": ['mw'],
    "bṛhadāraṇyakabhāṣyavārttika": ['mw'],
    "bṛhadāraṇyakabhāṣyaṭīkā": ['mw'],
    "bṛhadāraṇyakaviveka": ['mw'],
    "bṛhadāraṇyakaviṣayanirṇaya": ['mw'],
    "bṛhadāraṇyakavyākhyā": ['mw'],
    "bṛhadāraṇyakavārttikasāra": ['mw'],
    "bṛhadāraṇyakopaniṣad": ['mw'],
    "bṛhadāraṇyakopaniṣadvārttika": ['mw'],
    "bṛhadāraṇyakopaniṣatkhaṇḍārtha": ['mw'],
    "bṛhadātreya": ['mw'],
    "bṛhadīśvaradīkṣitīya": ['mw'],
    "bṛhadīśvarapurāṇa": ['mw'],
    "bṛhaj": ['mw'],
    "bṛhajjaghana": ['mw'],
    "bṛhajjana": ['mw'],
    "bṛhajjyotis": ['cae', 'mw'],
    "bṛhajjābālopaniṣad": ['mw'],
    "bṛhajjāla": ['mw'],
    "bṛhajjātaka": ['cae', 'mw'],
    "bṛhajjātakaślokavyākhyāna": ['mw'],
    "bṛhajjīraka": ['mw'],
    "bṛhajjīvantikā": ['mw'],
    "bṛhajjīvantī": ['mw'],
    "bṛhajjīvā": ['mw'],
    "bṛhaka": ['mw'],
    "bṛhal": ['mw'],
    "bṛhallakṣahoma": ['mw'],
    "bṛhallohita": ['mw'],
    "bṛhan": ['mw'],
    "bṛhanmadhya": ['cae', 'mw'],
    "bṛhanmanas": ['mw'],
    "bṛhanmantra": ['mw'],
    "bṛhanmanu": ['mw'],
    "bṛhanmati": ['cae', 'gra', 'mw'],
    "bṛhannakhī": ['mw'],
    "bṛhannala": ['cae', 'ddsa', 'mw'],
    "bṛhannaukā": ['mw'],
    "bṛhannaḍa": ['cae', 'mw'],
    "bṛhannaṭa": ['mw'],
    "bṛhannetra": ['mw'],
    "bṛhannighaṇṭi": ['mw'],
    "bṛhannirvāṇatantra": ['mw'],
    "bṛhanniveśa": ['mw'],
    "bṛhannālika": ['mw'],
    "bṛhannāradapurāṇa": ['mw'],
    "bṛhannāradīya": ['mw'],
    "bṛhannāradīyapurāṇa": ['mw'],
    "bṛhannāradīyatantra": ['mw'],
    "bṛhannārāyaṇa": ['mw'],
    "bṛhannārāyaṇopaniṣad": ['mw'],
    "bṛhannārāyaṇī": ['mw'],
    "bṛhannāyakīdaṇḍaka": ['mw'],
    "bṛhannāṭa": ['mw'],
    "bṛhannāṭaka": ['mw'],
    "bṛhannīlatantra": ['mw'],
    "bṛhannīlī": ['mw'],
    "bṛhant": ['cae'],
    "bṛhanta": ['cae', 'mw'],
    "bṛhaspati": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "bṛhaspaticakra": ['mw'],
    "bṛhaspaticāra": ['mw'],
    "bṛhaspatidatta": ['mw'],
    "bṛhaspatigupta": ['bhs', 'mw'],
    "bṛhaspatika": ['mw'],
    "bṛhaspatikaraṇa": ['mw'],
    "bṛhaspatila": ['mw'],
    "bṛhaspatimat": ['ddsa', 'mw'],
    "bṛhaspatimata": ['mw'],
    "bṛhaspatimiśra": ['mw'],
    "bṛhaspatipakṣatā": ['mw'],
    "bṛhaspatiprasūta": ['gra', 'mw'],
    "bṛhaspatipraṇutta": ['mw'],
    "bṛhaspatipurohita": ['mw'],
    "bṛhaspatisama": ['mw'],
    "bṛhaspatisava": ['mw'],
    "bṛhaspatisavahautraprayoga": ['mw'],
    "bṛhaspatisavakḷpti": ['mw'],
    "bṛhaspatisavaprayoga": ['mw'],
    "bṛhaspatisaṃhitā": ['mw'],
    "bṛhaspatisiddhānta": ['mw'],
    "bṛhaspatismṛti": ['mw'],
    "bṛhaspatistoma": ['mw'],
    "bṛhaspatistotra": ['mw'],
    "bṛhaspatisuratā": ['mw'],
    "bṛhaspatisuta": ['mw'],
    "bṛhaspatisūtra": ['mw'],
    "bṛhaspatitantra": ['mw'],
    "bṛhaspativat": ['mw'],
    "bṛhaspativāra": ['mw'],
    "bṛhaspatiya": ['mw'],
    "bṛhaspatiśiras": ['mw'],
    "bṛhaspatiśānti": ['mw'],
    "bṛhaspatiśāntikarman": ['mw'],
    "bṛhaspatiḥ": ['ap90'],
    "bṛhat": ['ap90', 'ddsa', 'gra', 'mw'],
    "bṛhata": ['cae', 'mw'],
    "bṛhatikā": ['ap90', 'bhs', 'cae', 'mw'],
    "bṛhatka": ['mw'],
    "bṛhatkalpa": ['mw'],
    "bṛhatkalpalatā": ['mw'],
    "bṛhatkanda": ['mw'],
    "bṛhatkapola": ['mw'],
    "bṛhatkarman": ['mw'],
    "bṛhatkathā": ['cae', 'ddsa', 'mw'],
    "bṛhatkathāmañjarī": ['mw'],
    "bṛhatkathāsārasaṃgraha": ['mw'],
    "bṛhatkathāvivaraṇa": ['mw'],
    "bṛhatkaustubhālaṃkāra": ['mw'],
    "bṛhatketu": ['cae', 'gra', 'mw'],
    "bṛhatkośalakhaṇḍa": ['mw'],
    "bṛhatkośātakī": ['mw'],
    "bṛhatkukṣi": ['mw'],
    "bṛhatkuśaṇḍikā": ['mw'],
    "bṛhatkālajñāna": ['mw'],
    "bṛhatkālaśāka": ['mw'],
    "bṛhatkāya": ['mw'],
    "bṛhatkāśa": ['mw'],
    "bṛhatkīrti": ['cae', 'mw'],
    "bṛhatkṛṣṇagaṇoddeśadīpikā": ['mw'],
    "bṛhatkṣata": ['mw'],
    "bṛhatkṣatra": ['mw'],
    "bṛhatkṣaya": ['mw'],
    "bṛhatkṣaṇa": ['mw'],
    "bṛhatkṣetra": ['mw'],
    "bṛhatpalāśa": ['cae', 'mw'],
    "bṛhatparibhāṣāsaṃgraha": ['mw'],
    "bṛhatparvamālā": ['mw'],
    "bṛhatparāśara": ['mw'],
    "bṛhatpattra": ['mw'],
    "bṛhatpattrā": ['mw'],
    "bṛhatphala": ['bhs', 'mw'],
    "bṛhatphalā": ['mw'],
    "bṛhatpracetas": ['mw'],
    "bṛhatprayoga": ['mw'],
    "bṛhatpuṣpa": ['mw'],
    "bṛhatpuṣpī": ['mw'],
    "bṛhatpāda": ['cae', 'mw'],
    "bṛhatpālin": ['mw'],
    "bṛhatpārevata": ['mw'],
    "bṛhatpāṭali": ['mw'],
    "bṛhatpīlu": ['mw'],
    "bṛhatpṛṣṭha": ['mw'],
    "bṛhatsahāya": ['mw'],
    "bṛhatsarvānukramaṇī": ['mw'],
    "bṛhatsaṃhitā": ['cae', 'mw'],
    "bṛhatsaṃketa": ['mw'],
    "bṛhatsaṃvarta": ['mw'],
    "bṛhatsena": ['cae', 'mw'],
    "bṛhatsenā": ['mw'],
    "bṛhatsoma": ['mw'],
    "bṛhatsphij": ['mw'],
    "bṛhatsumna": ['cae', 'gra', 'mw'],
    "bṛhatsāgaranāgarājaparipṛcchā": ['bhs'],
    "bṛhatsāman": ['mw'],
    "bṛhatsūryasiddhānta": ['mw'],
    "bṛhattantrapati": ['mw'],
    "bṛhattantrapatitva": ['mw'],
    "bṛhattapas": ['mw'],
    "bṛhattapovrata": ['mw'],
    "bṛhattarkataraṃgiṇī": ['mw'],
    "bṛhattejas": ['mw'],
    "bṛhattiktā": ['mw'],
    "bṛhattoḍalatantra": ['mw'],
    "bṛhattuhinaśarkara": ['mw'],
    "bṛhattva": ['cae', 'mw'],
    "bṛhattvac": ['mw'],
    "bṛhattvan": ['mw'],
    "bṛhattāla": ['mw'],
    "bṛhattīrthamāhātmya": ['mw'],
    "bṛhattṛṇa": ['cae', 'mw'],
    "bṛhatī": ['mw'],
    "bṛhatīdvaya": ['mw'],
    "bṛhatīka": ['mw'],
    "bṛhatīkalpa": ['mw'],
    "bṛhatīkāram": ['mw'],
    "bṛhatīpati": ['mw'],
    "bṛhatīsahasra": ['mw'],
    "bṛhatīśastra": ['mw'],
    "bṛhatīṣaṣṭhī": ['mw'],
    "bṛhatṣoḍaśakāraṇapūjā": ['mw'],
    "bṛhaḍ": ['mw'],
    "bṛhaḍḍhakkā": ['mw'],
    "bṛhaṭ": ['mw'],
    "bṛhaṭṭika": ['ddsa', 'mw'],
    "bṛhaṭṭīkā": ['mw'],
    "bṛhmaṇa": ['mw'],
    "bṛndāraṇya": ['mw'],
    "bṛsaya": ['ddsa', 'gra', 'mw'],
    "bṛsikā": ['bhs', 'mw'],
    "bṛsī": ['cae', 'ddsa', 'mw'],
    "bṛśī": ['ap90'],
    "bṛḍha": ['mw'],
    "bṛṃh": ['ap90', 'mw'],
    "bṛṃhayitar": ['bhs'],
    "bṛṃhayitavya": ['mw'],
    "bṛṃhayitṛ": ['mw'],
    "bṛṃhaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "bṛṃhaṇatva": ['mw'],
    "bṛṃhaṇīya": ['mw'],
    "bṛṃhita": ['ap90', 'cae', 'mw'],
    "bṛṃhitā": ['mw'],
    "bṛṅga": ['bhs'],
    "bṛṣī": ['mw'],
    "bṝ": ['mw'],
    "ca": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "cacara": ['cae', 'gra', 'mw'],
    "caccapuṭa": ['mw'],
    "caccara": ['bhs', 'cped'],
    "caccarī": ['mw'],
    "caccatpuṭa": ['mw'],
    "caceṇḍā": ['mw'],
    "cad": ['ap90', 'mw'],
    "cadira": ['mw'],
    "cadiraḥ": ['ap90'],
    "cagghati": ['bhs'],
    "cagh": ['mw'],
    "cah": ['ap90', 'mw'],
    "caidia": ['gra'],
    "caidika": ['mw'],
    "caidya": ['cae', 'ddsa', 'gra', 'mw'],
    "caidyaḥ": ['ap90'],
    "caidyā": ['mw'],
    "caikayata": ['mw'],
    "caikita": ['mw'],
    "caikitsita": ['mw'],
    "caikitsitya": ['mw'],
    "caikitya": ['mw'],
    "caikitāna": ['mw'],
    "caikitāneya": ['mw'],
    "caikitāyana": ['mw'],
    "caikīrṣata": ['mw'],
    "caikīrṣita": ['mw'],
    "caila": ['ap90', 'cae', 'ddsa', 'mw'],
    "cailadhāva": ['cae', 'mw'],
    "cailaka": ['bhs', 'mw'],
    "cailakaḥ": ['ap90'],
    "cailaki": ['mw'],
    "cailavat": ['cae'],
    "caileya": ['mw'],
    "cailika": ['mw'],
    "cailikaḥ": ['ap90'],
    "cailoṇḍūka": ['bhs'],
    "cailāśaka": ['cae', 'mw'],
    "caintita": ['mw'],
    "caitaki": ['mw'],
    "caitanaka": ['bhs'],
    "caitanya": ['cae', 'ddsa', 'mw'],
    "caitanyabhairavī": ['mw'],
    "caitanyacandrodaya": ['cae', 'mw'],
    "caitanyacaraṇāmṛta": ['mw'],
    "caitanyacaritra": ['mw'],
    "caitanyacaritāmṛta": ['mw'],
    "caitanyadeva": ['mw'],
    "caitanyamaṅgala": ['mw'],
    "caitanyayukta": ['mw'],
    "caitanyaṃ": ['ap90'],
    "caitanyāmṛta": ['mw'],
    "caitasika": ['bhs', 'mw'],
    "caitayata": ['mw'],
    "caitika": ['bhs', 'mw'],
    "caitra": ['cae', 'ddsa', 'mw'],
    "caitrabhānava": ['mw'],
    "caitradaṇḍika": ['bhs'],
    "caitraga": ['mw'],
    "caitraka": ['mw'],
    "caitrakaḥ": ['ap90'],
    "caitrakuṭī": ['mw'],
    "caitrakūṭī": ['mw'],
    "caitraratha": ['bhs', 'cae', 'mw'],
    "caitrarathaṃ": ['ap90'],
    "caitrarathi": ['mw'],
    "caitrarathya": ['mw'],
    "caitrarathyaṃ": ['ap90'],
    "caitrarathī": ['mw'],
    "caitrasakha": ['mw'],
    "caitrasaṃkrānti": ['mw'],
    "caitraseni": ['mw'],
    "caitravatī": ['mw'],
    "caitravibhāvarī": ['cae'],
    "caitravāhanī": ['mw'],
    "caitraḥ": ['ap90'],
    "caitreya": ['mw'],
    "caitri": ['mw'],
    "caitrika": ['mw'],
    "caitrin": ['mw'],
    "caitriyāyaṇa": ['mw'],
    "caitriḥ": ['ap90'],
    "caitrāvalī": ['mw'],
    "caitrāyaṇa": ['mw'],
    "caitrī": ['ap90', 'ddsa', 'mw'],
    "caitrīpakṣa": ['mw'],
    "caitta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "caittasika": ['ap90'],
    "caittika": ['ap90', 'mw'],
    "caitya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "caityadru": ['mw'],
    "caityadruma": ['cae', 'mw'],
    "caityaka": ['bhs', 'mw'],
    "caityamukha": ['mw'],
    "caityapāla": ['mw'],
    "caityasthāna": ['mw'],
    "caityataru": ['cae', 'mw'],
    "caityavṛkṣa": ['cae', 'mw'],
    "caityayajña": ['mw'],
    "caityaśaila": ['mw'],
    "caiṭayata": ['mw'],
    "caiṭayatavidha": ['mw'],
    "caiṭayatyā": ['mw'],
    "caiṭayatāyani": ['mw'],
    "cajamāna": ['cped'],
    "cajati": ['cped'],
    "cajitvā": ['cped'],
    "cajitvāna": ['cped'],
    "cak": ['ap90', 'cae', 'ddsa', 'mw'],
    "caka": ['mw'],
    "cakadra": ['mw'],
    "cakana": ['mw'],
    "cakaṭi": ['bhs'],
    "cakaṭyodana": ['mw'],
    "cakhvas": ['gra', 'mw'],
    "cakita": ['ap90', 'cae', 'ddsa', 'mw'],
    "cakitacakita": ['mw'],
    "cakitacakitam": ['mw'],
    "cakitagati": ['mw'],
    "cakitahṛdaya": ['mw'],
    "cakitam": ['mw'],
    "cakitā": ['mw'],
    "cakk": ['ap90', 'mw'],
    "cakka": ['cped', 'mw'],
    "cakkabheda": ['cped'],
    "cakkacchinna": ['cped'],
    "cakkala": ['ap90', 'mw'],
    "cakkalaka": ['ddsa', 'mw'],
    "cakkalika": ['cped'],
    "cakkalī": ['cped'],
    "cakkana": ['mw'],
    "cakkaratana": ['cped'],
    "cakkasamārūḷha": ['cped'],
    "cakkavattī(n)": ['cped'],
    "cakkavaṭṭaka": ['cped'],
    "cakkayuga": ['cped'],
    "cakkhu": ['cped'],
    "cakkhubhūta": ['cped'],
    "cakkhuda": ['cped'],
    "cakkhudada": ['cped'],
    "cakkhudhātu": ['cped'],
    "cakkhukaraṇa": ['cped'],
    "cakkhuma(t)": ['cped'],
    "cakkhundriya": ['cped'],
    "cakkhupatha": ['cped'],
    "cakkhussa": ['cped'],
    "cakkhuviññeyya": ['cped'],
    "cakkhuviññāṇa": ['cped'],
    "cakkhāyatana": ['cped'],
    "cakkhūndriya,": ['cped'],
    "cakkānuvattaka": ['cped'],
    "caknasa": ['mw'],
    "caknasaḥ": ['ap90'],
    "cakora": ['cae', 'ddsa', 'mw'],
    "cakoradṛś": ['mw'],
    "cakoraka": ['bhs', 'mw'],
    "cakoranetra": ['cae', 'mw'],
    "cakoravrata": ['cae', 'mw'],
    "cakoraḥ": ['ap90'],
    "cakorākṣa": ['cae'],
    "cakorāya": ['ddsa', 'mw'],
    "cakorī": ['mw'],
    "cakra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "cakrabandha": ['mw'],
    "cakrabandham": ['mw'],
    "cakrabandhanā": ['mw'],
    "cakrabhaṅga": ['cae', 'mw'],
    "cakrabheda": ['bhs'],
    "cakrabhedinī": ['mw'],
    "cakrabhrama": ['mw'],
    "cakrabhramaṇa": ['mw'],
    "cakrabhrami": ['mw'],
    "cakrabhrānti": ['mw'],
    "cakrabhānu": ['mw'],
    "cakrabhṛt": ['mw'],
    "cakrabālā": ['mw'],
    "cakrabāndhava": ['mw'],
    "cakracara": ['mw'],
    "cakracārin": ['mw'],
    "cakracūḍāmaṇi": ['mw'],
    "cakradantī": ['mw'],
    "cakradantībīja": ['mw'],
    "cakradatta": ['mw'],
    "cakradattanāmakagrantha": ['mw'],
    "cakradaṃṣṭra": ['mw'],
    "cakradeva": ['mw'],
    "cakradhanus": ['mw'],
    "cakradhara": ['cae', 'mw'],
    "cakradharman": ['mw'],
    "cakradhāra": ['mw'],
    "cakradhāraṇa": ['mw'],
    "cakradhārā": ['mw'],
    "cakradundubhya": ['mw'],
    "cakradvāra": ['mw'],
    "cakradīpikā": ['mw'],
    "cakradṛś": ['mw'],
    "cakragaja": ['mw'],
    "cakragati": ['mw'],
    "cakragaṇḍu": ['mw'],
    "cakragoptṛ": ['cae', 'ddsa', 'mw'],
    "cakragrahaṇī": ['mw'],
    "cakraguccha": ['mw'],
    "cakragulma": ['mw'],
    "cakrahasta": ['mw'],
    "cakrahrada": ['mw'],
    "cakrajāti": ['mw'],
    "cakrajīvaka": ['mw'],
    "cakrajīvin": ['mw'],
    "cakraka": ['ap90', 'bhs', 'mw'],
    "cakrakulyā": ['mw'],
    "cakrakā": ['mw'],
    "cakrakāraka": ['mw'],
    "cakrakāśraya": ['mw'],
    "cakrala": ['mw'],
    "cakralakṣaṇikā": ['mw'],
    "cakralakṣaṇā": ['mw'],
    "cakralatāmra": ['mw'],
    "cakralā": ['mw'],
    "cakramanda": ['mw'],
    "cakramarda": ['mw'],
    "cakramardaka": ['mw'],
    "cakramardikā": ['mw'],
    "cakramauli": ['mw'],
    "cakramaulin": ['mw'],
    "cakramaṇḍalin": ['mw'],
    "cakramaṭha": ['mw'],
    "cakramedinī": ['mw'],
    "cakramelaka": ['mw'],
    "cakramukha": ['mw'],
    "cakramusala": ['mw'],
    "cakramāsaja": ['gra', 'mw'],
    "cakramīmāṃsā": ['mw'],
    "cakranadī": ['mw'],
    "cakranakha": ['mw'],
    "cakranemi": ['mw'],
    "cakranitamba": ['mw'],
    "cakranābhi": ['cae', 'mw'],
    "cakranāman": ['mw'],
    "cakranārāyaṇīsaṃhitā": ['mw'],
    "cakranāyaka": ['mw'],
    "cakrapadmāṭa": ['mw'],
    "cakrapakṣa": ['mw'],
    "cakraparivyādha": ['mw'],
    "cakraparṇī": ['mw'],
    "cakrapatha": ['mw'],
    "cakrapeyāla": ['bhs'],
    "cakraphala": ['mw'],
    "cakrapura": ['mw'],
    "cakrapuṣkariṇī": ['mw'],
    "cakrapāda": ['mw'],
    "cakrapāla": ['mw'],
    "cakrapālita": ['mw'],
    "cakrapāta": ['mw'],
    "cakrapāṇi": ['mw'],
    "cakrapāṇidatta": ['mw'],
    "cakrapāṇin": ['mw'],
    "cakrarada": ['mw'],
    "cakrarakṣa": ['cae', 'mw'],
    "cakrarakṣin": ['cae'],
    "cakraratna": ['cae', 'mw'],
    "cakrarāja": ['mw'],
    "cakrasaktha": ['mw'],
    "cakrasaṃjña": ['mw'],
    "cakrasaṃvara": ['mw'],
    "cakrasena": ['mw'],
    "cakrasenā": ['mw'],
    "cakrasvastikanandyāvarta": ['mw'],
    "cakrasvāmin": ['mw'],
    "cakrasāhvaya": ['mw'],
    "cakrataila": ['mw'],
    "cakratalāmra": ['mw'],
    "cakratuṇḍa": ['mw'],
    "cakratīrtha": ['mw'],
    "cakravadgati": ['cae', 'mw'],
    "cakravarman": ['mw'],
    "cakravarmiṇī": ['bhs'],
    "cakravarta": ['mw'],
    "cakravartidatta": ['bhs'],
    "cakravartin": ['bhs', 'cae', 'mw'],
    "cakravartinī": ['bhs', 'mw'],
    "cakravartisūtra": ['bhs'],
    "cakravartitva": ['mw'],
    "cakravartitā": ['cae', 'mw'],
    "cakravat": ['ap90', 'mw'],
    "cakravegā": ['bhs'],
    "cakravicitra": ['bhs'],
    "cakravimala": ['bhs', 'mw'],
    "cakravyūha": ['bhs', 'cae', 'mw'],
    "cakravāka": ['cae', 'gra', 'mw'],
    "cakravākabandhu": ['mw'],
    "cakravākamaya": ['mw'],
    "cakravākavatī": ['mw'],
    "cakravākin": ['mw'],
    "cakravākopakūjita": ['mw'],
    "cakravākī": ['mw'],
    "cakravāla": ['cae', 'mw'],
    "cakravāladhi": ['mw'],
    "cakravālagupta": ['bhs'],
    "cakravālaka": ['mw'],
    "cakravālayamaka": ['mw'],
    "cakravālātman": ['mw'],
    "cakravāta": ['cae', 'mw'],
    "cakravāḍa": ['bhs', 'mw'],
    "cakravāṭa": ['mw'],
    "cakravṛddhi": ['cae', 'mw'],
    "cakravṛtta": ['mw'],
    "cakrayodhin": ['mw'],
    "cakrayoga": ['mw'],
    "cakrayāna": ['mw'],
    "cakraśatapattra": ['bhs', 'mw'],
    "cakraśreṇī": ['mw'],
    "cakraṃ": ['ap90'],
    "cakraṇadī": ['mw'],
    "cakraṇitamba": ['mw'],
    "cakrendraka": ['mw'],
    "cakreśa": ['ddsa', 'mw'],
    "cakreśvara": ['mw'],
    "cakreśvarī": ['mw'],
    "cakri": ['cae', 'gra', 'mw'],
    "cakrika": ['bhs', 'mw'],
    "cakrikaḥ": ['ap90'],
    "cakrikā": ['bhs', 'ddsa', 'mw'],
    "cakrin": ['ap90', 'cae', 'mw'],
    "cakriya": ['ap90', 'mw'],
    "cakrollāsa": ['mw'],
    "cakrottha": ['mw'],
    "cakru": ['mw'],
    "cakrus": ['ddsa'],
    "cakruvṛtta": ['mw'],
    "cakrā": ['mw'],
    "cakrādhivāsin": ['mw'],
    "cakrāhva": ['cae', 'mw'],
    "cakrāhvaya": ['cae', 'mw'],
    "cakrāhvā": ['mw'],
    "cakrākāra": ['mw'],
    "cakrākī": ['ap90', 'mw'],
    "cakrākṛti": ['mw'],
    "cakrākṣaraparivartavyūha": ['bhs'],
    "cakrālu": ['mw'],
    "cakrāntara": ['bhs'],
    "cakrārdhacakravāla": ['mw'],
    "cakrāti": ['mw'],
    "cakrāvalī": ['mw'],
    "cakrāvarta": ['mw'],
    "cakrāyodhya": ['mw'],
    "cakrāyudha": ['ddsa', 'mw'],
    "cakrāśman": ['mw'],
    "cakrāṅga": ['cae', 'mw'],
    "cakrāṅganā": ['mw'],
    "cakrāṅgā": ['mw'],
    "cakrāṅgī": ['mw'],
    "cakrāṅkita": ['cae'],
    "cakrāṅkitapāda": ['mw'],
    "cakrāṅkitapāṇipādatalatā": ['mw'],
    "cakrāṅkitā": ['ddsa', 'mw'],
    "cakrāṅkā": ['mw'],
    "cakrāṅkī": ['mw'],
    "cakrāṇa": ['ddsa', 'mw'],
    "cakrāṭa": ['mw'],
    "cakrī": ['gra', 'mw'],
    "cakrībhū": ['mw'],
    "cakrīkṛ": ['ap90', 'ddsa', 'mw'],
    "cakrīvat": ['ap90', 'ddsa', 'mw'],
    "cakvana": ['mw'],
    "cakāra": ['cae', 'ddsa', 'mw'],
    "cakās": ['ap90', 'cae', 'ddsa', 'mw'],
    "cakāsita": ['ap90', 'mw'],
    "cakṛvat": ['mw'],
    "cakṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cakṣa": ['mw'],
    "cakṣan": ['ap90', 'cae', 'ddsa', 'mw'],
    "cakṣas": ['ap90', 'cae', 'gra', 'mw'],
    "cakṣaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "cakṣaṇaṃ": ['ap90'],
    "cakṣaṇi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cakṣorākṣa": ['mw'],
    "cakṣu": ['ap90', 'cae', 'gra', 'mw'],
    "cakṣuka": ['bhs'],
    "cakṣunirodha": ['mw'],
    "cakṣupīḍana": ['mw'],
    "cakṣur": ['mw'],
    "cakṣurapeta": ['mw'],
    "cakṣurbahala": ['mw'],
    "cakṣurbhṛt": ['mw'],
    "cakṣurdā": ['mw'],
    "cakṣurdāna": ['mw'],
    "cakṣurgocara": ['mw'],
    "cakṣurgrahaṇa": ['mw'],
    "cakṣurhan": ['mw'],
    "cakṣurindriya": ['mw'],
    "cakṣurloka": ['mw'],
    "cakṣurmala": ['mw'],
    "cakṣurmantra": ['mw'],
    "cakṣurmaya": ['mw'],
    "cakṣurmukha": ['mw'],
    "cakṣurmuṣ": ['mw'],
    "cakṣurnimita": ['mw'],
    "cakṣurnirodha": ['mw'],
    "cakṣurvahana": ['mw'],
    "cakṣurvanya": ['mw'],
    "cakṣurvardhanikā": ['mw'],
    "cakṣurviṣaya": ['cae', 'ddsa', 'mw'],
    "cakṣus": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "cakṣuś": ['mw'],
    "cakṣuścit": ['mw'],
    "cakṣuḥ": ['mw'],
    "cakṣuḥpatha": ['mw'],
    "cakṣuḥpīḍā": ['mw'],
    "cakṣuḥśravas": ['ddsa', 'mw'],
    "cakṣuḥśrotra": ['mw'],
    "cakṣuḥśruti": ['mw'],
    "cakṣuṣ": ['mw'],
    "cakṣuṣa": ['mw'],
    "cakṣuṣkarṇa": ['mw'],
    "cakṣuṣkāma": ['mw'],
    "cakṣuṣmant": ['cae'],
    "cakṣuṣmat": ['ap90', 'gra', 'mw'],
    "cakṣuṣmattva": ['mw'],
    "cakṣuṣmattā": ['mw'],
    "cakṣuṣmatī": ['bhs'],
    "cakṣuṣpatha": ['cae', 'mw'],
    "cakṣuṣpati": ['ddsa', 'mw'],
    "cakṣuṣprīti": ['cae', 'mw'],
    "cakṣuṣpā": ['mw'],
    "cakṣuṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "cakṣuṣyā": ['mw'],
    "cakṣuṣṭas": ['mw'],
    "cakṣuṣṭva": ['mw'],
    "cakṣū": ['mw'],
    "cakṣūkṛ": ['mw'],
    "cakṣūroga": ['mw'],
    "cakṣūrāga": ['cae', 'ddsa', 'mw'],
    "cal": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "cala": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "calacañcu": ['mw'],
    "calacitta": ['cae', 'mw'],
    "calacittatā": ['mw'],
    "calad": ['mw'],
    "caladala": ['mw'],
    "caladanta": ['mw'],
    "caladaṅga": ['mw'],
    "caladaṅgaka": ['mw'],
    "caladgu": ['mw'],
    "caladruma": ['mw'],
    "caladviṣaḥ": ['ap90'],
    "calaghnī": ['mw'],
    "calaka": ['cped'],
    "calakalpaka": ['bhs'],
    "calakalpā": ['bhs'],
    "calakarṇa": ['mw'],
    "calaketu": ['mw'],
    "calakuṇḍala": ['mw'],
    "calamakuṭa": ['bhs'],
    "calana": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "calanaka": ['cae', 'mw'],
    "calanakaṃ": ['ap90'],
    "calaniketa": ['ddsa', 'mw'],
    "calanikā": ['mw'],
    "calanī": ['mw'],
    "calanīya": ['mw'],
    "calapattra": ['mw'],
    "calaprakṛti": ['mw'],
    "calapuccha": ['mw'],
    "calas": ['mw'],
    "calasaṃdhi": ['mw'],
    "calasvabhāva": ['mw'],
    "calat": ['mw'],
    "calati": ['cped'],
    "calatpadam": ['mw'],
    "calatpūrṇimā": ['mw'],
    "calatsaṭa": ['mw'],
    "calatthā": ['bhs'],
    "calatva": ['mw'],
    "calatā": ['mw'],
    "calayati": ['cped'],
    "calendriya": ['mw'],
    "calesi": ['cped'],
    "caleti": ['cped'],
    "caleṣu": ['mw'],
    "cali": ['mw'],
    "calita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "calitasthāna": ['mw'],
    "calitavya": ['ddsa', 'mw'],
    "caliḥ": ['ap90'],
    "calormi": ['ddsa', 'mw'],
    "calu": ['mw'],
    "caluka": ['ddsa', 'mw'],
    "calukaḥ": ['ap90'],
    "caluśiras": ['bhs'],
    "caluḥ": ['ap90'],
    "calā": ['ddsa', 'mw'],
    "calācala": ['cae', 'ddsa', 'gra', 'mw'],
    "calācaleṣu": ['mw'],
    "calātaṅka": ['mw'],
    "calātman": ['cae', 'ddsa', 'mw'],
    "calīkṛ": ['mw'],
    "cam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cam, camp": ['ddsa'],
    "cama": ['mw'],
    "camaka": ['ddsa', 'mw'],
    "camakasūkta": ['mw'],
    "camana": ['cae', 'ddsa', 'mw'],
    "camara": ['bhs', 'cae', 'ddsa', 'mw'],
    "camaraka": ['mw'],
    "camarapuccha": ['mw'],
    "camaravāla": ['mw'],
    "camaravījanī": ['cped'],
    "camaraḥ": ['ap90'],
    "camarika": ['mw'],
    "camarikaḥ": ['ap90'],
    "camarākṛti": ['mw'],
    "camarī": ['mw'],
    "camasa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "camasaḥ": ['ap90'],
    "camasi": ['mw'],
    "camasin": ['mw'],
    "camasiḥ": ['ap90'],
    "camasodbheda": ['mw'],
    "camasodbhedana": ['mw'],
    "camasādhvaryu": ['mw'],
    "camasī": ['mw'],
    "camat": ['cae', 'mw'],
    "camatkaraṇa": ['cae', 'ddsa', 'mw'],
    "camatkaraṇaṃ": ['ap90'],
    "camatkāra": ['mw'],
    "camatkāracandrikā": ['mw'],
    "camatkāracintāmaṇi": ['mw'],
    "camatkāranagara": ['mw'],
    "camatkāranṛtya": ['mw'],
    "camatkārin": ['ap90', 'mw'],
    "camatkārita": ['mw'],
    "camatkāritā": ['mw'],
    "camatkṛ": ['ddsa', 'mw'],
    "camatkṛta": ['mw'],
    "camatkṛti": ['mw'],
    "camb": ['mw'],
    "camma": ['cped'],
    "cammakhaṇḍa": ['cped'],
    "cammakāra": ['cped'],
    "cammapaṭṭa": ['cped'],
    "cammavedhaviddha": ['cped'],
    "cammavinaddha": ['cped'],
    "cammayodhi(n)": ['cped'],
    "camp": ['mw'],
    "campa": ['cae', 'ddsa', 'mw'],
    "campaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "campakacaturdaśī": ['mw'],
    "campakadeśa": ['mw'],
    "campakagandha": ['mw'],
    "campakalatā": ['mw'],
    "campakamālā": ['mw'],
    "campakanātha": ['mw'],
    "campakaprabhu": ['mw'],
    "campakapura": ['mw'],
    "campakarambhā": ['mw'],
    "campakavarṇā": ['bhs'],
    "campakavatī": ['cae', 'mw'],
    "campakavimalaprabha": ['bhs'],
    "campakavyavahārikathā": ['mw'],
    "campakaśreṣṭhikathānaka": ['mw'],
    "campakolba": ['mw'],
    "campakośa": ['mw'],
    "campakunda": ['mw'],
    "campakā": ['mw'],
    "campakālu": ['mw'],
    "campakāraṇya": ['mw'],
    "campakāvatī": ['mw'],
    "campana": ['mw'],
    "campeyyaka": ['cped'],
    "campeśa": ['mw'],
    "campopalakṣita": ['mw'],
    "campā": ['ddsa', 'mw'],
    "campādhipa": ['mw'],
    "campālu": ['mw'],
    "campāpurī": ['mw'],
    "campāvatī": ['cae', 'mw'],
    "campāṣaṣṭhī": ['mw'],
    "campū": ['cae', 'ddsa', 'mw'],
    "campūbhārata": ['mw'],
    "campūkathāsūtra": ['mw'],
    "campūrāmāyaṇa": ['mw'],
    "camriṣ": ['ap90', 'gra', 'mw'],
    "camrīṣa": ['gra', 'mw'],
    "camu": ['bhs'],
    "camupati": ['mw'],
    "camīkāra": ['mw'],
    "camīkṛ": ['mw'],
    "camū": ['cae', 'ddsa', 'gra', 'mw'],
    "camūcara": ['mw'],
    "camūgati": ['cae'],
    "camūhara": ['mw'],
    "camūnātha": ['cae', 'mw'],
    "camūnāyaka": ['mw'],
    "camūpa": ['cae', 'mw'],
    "camūpati": ['cae', 'mw'],
    "camūpāla": ['cae', 'mw'],
    "camūru": ['mw'],
    "camūrudṛś": ['mw'],
    "camūrunetrā": ['mw'],
    "camūruḥ": ['ap90'],
    "camūḥ": ['ap90'],
    "camūṣad": ['gra', 'mw'],
    "can": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "canas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "canasaya": ['mw'],
    "canasita": ['ap90', 'mw'],
    "canasitavat": ['mw'],
    "canasitottara": ['mw'],
    "canasy": ['cae', 'gra'],
    "canasya": ['ddsa', 'mw'],
    "canasyati": ['ap90'],
    "cand": ['ddsa', 'gra', 'mw'],
    "canda": ['cped', 'mw'],
    "candaggāha": ['cped'],
    "candaka": ['mw'],
    "candakapuṣpa": ['mw'],
    "candaladevī": ['mw'],
    "candalā": ['ddsa', 'mw'],
    "candamaṇḍala": ['cped'],
    "candana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "candanabhānu": ['mw'],
    "candanacuṇṇa": ['cped'],
    "candanadāsa": ['mw'],
    "candanagandha": ['bhs', 'mw'],
    "candanagaura": ['mw'],
    "candanagaṇṭhi": ['cped'],
    "candanaghaṭikā": ['cped'],
    "candanagiri": ['mw'],
    "candanagodhā": ['bhs'],
    "candanagopā": ['mw'],
    "candanaka": ['cae', 'mw'],
    "candanamaya": ['cae', 'mw'],
    "candanamaṇḍita": ['cped'],
    "candanamaṇḍitasāragandhika": ['cped'],
    "candanamegha": ['bhs'],
    "candanamāla": ['bhs'],
    "candanapaṅka": ['cae', 'mw'],
    "candanaprabha": ['bhs'],
    "candanapura": ['cae', 'mw'],
    "candanaputrikā": ['mw'],
    "candanaputrī": ['mw'],
    "candanapuṣpa": ['mw'],
    "candanapuṣpaka": ['mw'],
    "candanapāla": ['mw'],
    "candanapāta": ['mw'],
    "candanapīṭha": ['bhs'],
    "candanarasa": ['cae', 'mw'],
    "candanasāra": ['cped', 'mw'],
    "candanasārivā": ['mw'],
    "candanavanī": ['mw'],
    "candanavatī": ['bhs'],
    "candanavāri": ['mw'],
    "candanaśrī": ['bhs'],
    "candanaśrīcandra": ['bhs'],
    "candanaśrīgarbha": ['bhs'],
    "candani": ['cped'],
    "candanikā": ['cped'],
    "candanin": ['mw'],
    "candaniyā": ['cped'],
    "candanodaka": ['cae', 'ddsa', 'mw'],
    "candanodakadundubhi": ['mw'],
    "candanokkhita": ['cped'],
    "candanussada": ['cped'],
    "candanā": ['mw'],
    "candanācala": ['mw'],
    "candanādri": ['mw'],
    "candanāgrya": ['mw'],
    "candanāmbhas": ['mw'],
    "candanāvatī": ['mw'],
    "candanāy": ['cae'],
    "candanāya": ['ddsa', 'mw'],
    "candanī": ['mw'],
    "candanīyā": ['mw'],
    "candarābhā": ['cped'],
    "candhana": ['mw'],
    "candila": ['mw'],
    "candima(s)": ['cped'],
    "candimasuriyā": ['cped'],
    "candimasūriyā": ['cped'],
    "candimā": ['cped'],
    "candira": ['mw'],
    "candra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "candraagra": ['gra'],
    "candrabha": ['mw'],
    "candrabhā": ['mw'],
    "candrabhāga": ['mw'],
    "candrabhāgasarit": ['mw'],
    "candrabhāgā": ['mw'],
    "candrabhāgī": ['mw'],
    "candrabhānu": ['bhs', 'mw'],
    "candrabhāsa": ['mw'],
    "candrabhīru": ['mw'],
    "candrabhūti": ['mw'],
    "candrabimba": ['cae', 'mw'],
    "candrabimbamaya": ['mw'],
    "candrabimbaprabhā": ['bhs', 'mw'],
    "candrabindu": ['mw'],
    "candrabuddhi": ['bhs'],
    "candrabudhna": ['gra', 'mw'],
    "candrabāhu": ['mw'],
    "candrabālā": ['mw'],
    "candracañcala": ['mw'],
    "candracañcalā": ['mw'],
    "candracitra": ['mw'],
    "candracūḍa": ['cae', 'mw'],
    "candracūḍāmaṇi": ['cae', 'mw'],
    "candracūḍāṣṭaka": ['mw'],
    "candradakṣiṇa": ['mw'],
    "candradatta": ['mw'],
    "candradeva": ['mw'],
    "candradhvajaketu": ['bhs', 'mw'],
    "candradhvajaśrīketu": ['bhs'],
    "candradhvajā": ['bhs'],
    "candradvīpa": ['mw'],
    "candradyuti": ['mw'],
    "candradāra": ['mw'],
    "candradīpikā": ['mw'],
    "candradūta": ['mw'],
    "candragarbha": ['bhs', 'mw'],
    "candragiri": ['mw'],
    "candragolastha": ['mw'],
    "candragolikā": ['mw'],
    "candragomin": ['mw'],
    "candragraha": ['mw'],
    "candragrahaṇa": ['mw'],
    "candragrahaṇodāharaṇa": ['mw'],
    "candragupta": ['cae', 'mw'],
    "candraguptaka": ['mw'],
    "candragupti": ['mw'],
    "candragūtīgiri": ['mw'],
    "candrahan": ['mw'],
    "candrahantṛ": ['mw'],
    "candrahanu": ['mw'],
    "candrahāsa": ['mw'],
    "candrahāsatīrtha": ['mw'],
    "candrahāsā": ['mw'],
    "candraja": ['mw'],
    "candrajanaka": ['mw'],
    "candrajasiṃha": ['mw'],
    "candrajñāna": ['mw'],
    "candrajñānatantra": ['mw'],
    "candraka": ['bhs', 'cae', 'mw'],
    "candrakalā": ['mw'],
    "candrakalātantra": ['mw'],
    "candrakamalākara": ['mw'],
    "candrakavat": ['mw'],
    "candrakavi": ['mw'],
    "candrakesarin": ['mw'],
    "candraketu": ['mw'],
    "candrakeśa": ['mw'],
    "candrakin": ['mw'],
    "candrakita": ['ddsa', 'mw'],
    "candrakośa": ['mw'],
    "candrakrīḍa": ['mw'],
    "candrakula": ['mw'],
    "candrakulyā": ['ddsa', 'mw'],
    "candrakumāraśikhara": ['mw'],
    "candrakuṇḍa": ['mw'],
    "candrakāli": ['bhs'],
    "candrakālānala": ['mw'],
    "candrakālānalacakra": ['mw'],
    "candrakānta": ['cae', 'mw'],
    "candrakāntamaya": ['mw'],
    "candrakāntamaṇimaya": ['mw'],
    "candrakāntaratnamaya": ['mw'],
    "candrakānti": ['mw'],
    "candrakāntā": ['bhs', 'mw'],
    "candrakāntīya": ['mw'],
    "candrakāṭuki": ['mw'],
    "candrakīrti": ['mw'],
    "candrakūṭa": ['mw'],
    "candrakṣaya": ['cae', 'mw'],
    "candrakṣānta": ['mw'],
    "candralalāma": ['mw'],
    "candralalāṭa": ['mw'],
    "candralauha": ['mw'],
    "candralauhaka": ['mw'],
    "candralekha": ['mw'],
    "candralekhā": ['cae', 'mw'],
    "candralocana": ['mw'],
    "candralohaka": ['mw'],
    "candraloka": ['mw'],
    "candralā": ['mw'],
    "candramaha": ['mw'],
    "candramanas": ['mw'],
    "candramas": ['cae', 'gra', 'mw'],
    "candramasa": ['mw'],
    "candramasā": ['mw'],
    "candramata": ['mw'],
    "candramauli": ['cae', 'mw'],
    "candramaulin": ['cae', 'mw'],
    "candramaya": ['mw'],
    "candramaṇi": ['mw'],
    "candramaṇḍala": ['cae', 'mw'],
    "candramukha": ['mw'],
    "candramukhavarman": ['mw'],
    "candramukhī": ['mw'],
    "candramukuṭa": ['cae', 'mw'],
    "candramā": ['mw'],
    "candramālā": ['mw'],
    "candramārga": ['mw'],
    "candramāsa": ['cae', 'mw'],
    "candranibha": ['mw'],
    "candranibhānanā": ['cae'],
    "candranirṇij": ['gra', 'mw'],
    "candranābha": ['mw'],
    "candrapadma": ['bhs'],
    "candraparvata": ['mw'],
    "candrapati": ['mw'],
    "candrapañcāṅga": ['mw'],
    "candraprabha": ['bhs', 'cae', 'mw'],
    "candraprabhasvāmicaritra": ['mw'],
    "candraprabhā": ['bhs', 'mw'],
    "candraprabhāsatīrtha": ['mw'],
    "candraprabhāsvararāja": ['bhs', 'mw'],
    "candraprabhāsā": ['bhs'],
    "candraprabhāva": ['mw'],
    "candrapradīpa": ['bhs'],
    "candrapradīpasamādhi": ['bhs'],
    "candrapradīpasūtra": ['bhs'],
    "candraprajñapti": ['mw'],
    "candraprakāśa": ['mw'],
    "candrapramardana": ['mw'],
    "candrapramāṇa": ['mw'],
    "candrapriya": ['mw'],
    "candraprāsāda": ['mw'],
    "candrapura": ['mw'],
    "candraputra": ['mw'],
    "candrapuṣpā": ['mw'],
    "candrapāda": ['cae', 'mw'],
    "candrapāla": ['mw'],
    "candrapṛṣṭha": ['mw'],
    "candraratha": ['gra', 'mw'],
    "candraratna": ['mw'],
    "candrarekhā": ['cae', 'mw'],
    "candrareṇu": ['mw'],
    "candrartu": ['mw'],
    "candrarāja": ['ddsa', 'mw'],
    "candrasaciva": ['mw'],
    "candrasambhava": ['mw'],
    "candrasambhavā": ['mw'],
    "candrasaras": ['cae', 'mw'],
    "candrasaṃjña": ['cae', 'mw'],
    "candrasena": ['mw'],
    "candrasiṃha": ['cae', 'mw'],
    "candraskandhārcitabrahman": ['bhs'],
    "candrasoma": ['mw'],
    "candrasthalanagara": ['mw'],
    "candrasurasa": ['mw'],
    "candrasuta": ['mw'],
    "candrasvararāja": ['bhs'],
    "candrasvāmin": ['mw'],
    "candrasāhi": ['mw'],
    "candrasālokya": ['mw'],
    "candrasāman": ['mw'],
    "candrasāra": ['mw'],
    "candrasūkta": ['mw'],
    "candrasūri": ['mw'],
    "candrasūrya": ['mw'],
    "candrasūryajihmīkaraprabha": ['bhs'],
    "candrasūryajihmīkaraṇa": ['bhs'],
    "candrasūryajihmīkaraṇaprabha": ['mw'],
    "candrasūryapradīpa": ['bhs', 'mw'],
    "candrasūryavimalaprabhāsaśrī": ['bhs'],
    "candrasūryākṣa": ['mw'],
    "candrasūtra": ['mw'],
    "candrataram": ['mw'],
    "candrateja": ['bhs'],
    "candratva": ['cae', 'mw'],
    "candratāla": ['mw'],
    "candratāpana": ['mw'],
    "candratāraka": ['cae', 'mw'],
    "candravadanā": ['mw'],
    "candravaktrā": ['mw'],
    "candravallarī": ['mw'],
    "candravallī": ['mw'],
    "candravandya": ['mw'],
    "candravant": ['cae'],
    "candravapus": ['cae', 'mw'],
    "candravaralocana": ['mw'],
    "candravarcasa": ['mw'],
    "candravarman": ['mw'],
    "candravartman": ['mw'],
    "candravarṇa": ['cae', 'gra', 'mw'],
    "candravasā": ['mw'],
    "candravat": ['gra', 'mw'],
    "candravatsa": ['mw'],
    "candravatī": ['mw'],
    "candravaśā": ['mw'],
    "candravaṃśa": ['cae', 'mw'],
    "candravaṃśin": ['mw'],
    "candravihaṃgama": ['mw'],
    "candravijña": ['mw'],
    "candravikrama": ['mw'],
    "candravimala": ['bhs', 'mw'],
    "candravimalasūryaprabhāsaśrī": ['bhs', 'mw'],
    "candraviśuddha": ['cae'],
    "candravrata": ['mw'],
    "candravyākaraṇa": ['mw'],
    "candravāhana": ['mw'],
    "candrayoga": ['mw'],
    "candraśakala": ['mw'],
    "candraśarman": ['mw'],
    "candraśekhara": ['cae', 'mw'],
    "candraśekharacampūprabandha": ['mw'],
    "candraśilā": ['mw'],
    "candraśrī": ['bhs', 'mw'],
    "candraśubha": ['bhs'],
    "candraśubhra": ['mw'],
    "candraśukla": ['mw'],
    "candraśālikā": ['mw'],
    "candraśālā": ['cae', 'mw'],
    "candraśītā": ['mw'],
    "candraśūra": ['mw'],
    "candraṭa": ['mw'],
    "candreśaliṅga": ['mw'],
    "candreśvaratīrtha": ['mw'],
    "candreṣṭā": ['mw'],
    "candrikā": ['ddsa', 'mw'],
    "candrikādrāva": ['mw'],
    "candrikāmbuja": ['mw'],
    "candrikāpāyin": ['mw'],
    "candrikātulya": ['mw'],
    "candrikāya": ['mw'],
    "candrikāśana": ['mw'],
    "candrila": ['mw'],
    "candrima": ['bhs'],
    "candrimā": ['mw'],
    "candrin": ['cae', 'ddsa', 'mw'],
    "candrobhāsa": ['bhs'],
    "candrodaya": ['cae', 'ddsa', 'mw'],
    "candrodayamakaradhvaja": ['mw'],
    "candrodayavarṇana": ['mw'],
    "candrodayā": ['mw'],
    "candrodgata": ['bhs'],
    "candrolkādhārin": ['bhs'],
    "candronmīlana": ['mw'],
    "candropala": ['mw'],
    "candropaniṣad": ['bhs'],
    "candroparāga": ['mw'],
    "candrottarajñānin": ['bhs'],
    "candrottarya": ['mw'],
    "candrottarā": ['bhs'],
    "candrā": ['mw'],
    "candrābha": ['bhs'],
    "candrābhavaktra": ['mw'],
    "candrābhāsa": ['mw'],
    "candrācārya": ['mw'],
    "candrādiloka": ['mw'],
    "candrāditya": ['mw'],
    "candrāgra": ['gra', 'mw'],
    "candrāhvaya": ['mw'],
    "candrākara": ['mw'],
    "candrākṛti": ['mw'],
    "candrāloka": ['mw'],
    "candrāmṛtarasa": ['mw'],
    "candrānana": ['bhs', 'mw'],
    "candrāpura": ['mw'],
    "candrāpīḍa": ['cae', 'mw'],
    "candrārdha": ['cae', 'mw'],
    "candrārdhacūḍāmaṇi": ['mw'],
    "candrārdhakṛtaśekhara": ['mw'],
    "candrārdhamauli": ['mw'],
    "candrāri": ['mw'],
    "candrārka": ['mw'],
    "candrārkadīpa": ['bhs', 'mw'],
    "candrārkamardana": ['mw'],
    "candrārkī": ['mw'],
    "candrāspadā": ['mw'],
    "candrātapa": ['cae', 'mw'],
    "candrātmaja": ['mw'],
    "candrātreya": ['mw'],
    "candrāvabhāsa": ['bhs'],
    "candrāvaloka": ['mw'],
    "candrāvalī": ['mw'],
    "candrāvartā": ['mw'],
    "candrāvataṃsaka": ['mw'],
    "candrāvatī": ['mw'],
    "candrāya": ['mw'],
    "candrāśma": ['mw'],
    "candrāśman": ['mw'],
    "candrāśva": ['mw'],
    "candrāṃśu": ['cae', 'ddsa', 'mw'],
    "candrāṃśujālamaṇḍalagarbha": ['bhs'],
    "candrāṅgada": ['mw'],
    "candrī": ['mw'],
    "candābhibhū": ['bhs'],
    "candābhā": ['cped'],
    "candī": ['cped'],
    "candīsaka": ['bhs'],
    "caniṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cano": ['mw'],
    "canodhā": ['cae', 'mw'],
    "canohita": ['gra', 'mw'],
    "cap": ['ap90', 'mw'],
    "capa": ['mw'],
    "capala": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "capalagaṇa": ['cae', 'mw'],
    "capalaka": ['ap90', 'mw'],
    "capalam": ['bhs', 'mw'],
    "capalatā": ['ap90', 'cae', 'mw'],
    "capalatāśaya": ['mw'],
    "capalaya": ['ddsa', 'mw'],
    "capalā": ['ap90', 'ddsa', 'mw'],
    "capalājana": ['mw'],
    "capalākṣa": ['mw'],
    "capalātmaka": ['mw'],
    "capalāya": ['ddsa', 'mw'],
    "capalāyate": ['ap90'],
    "capalāṅga": ['mw'],
    "capaṭa": ['mw'],
    "capaṭaḥ": ['ap90'],
    "capeṭa": ['cae', 'ddsa', 'mw'],
    "capeṭaḥ": ['ap90'],
    "capeṭikā": ['mw'],
    "capeṭā": ['ap90', 'mw'],
    "capeṭāghāta": ['mw'],
    "capeṭāpātana": ['mw'],
    "capeṭāpātanātithi": ['mw'],
    "capeṭī": ['mw'],
    "caphaṭṭaka": ['mw'],
    "cappaṭṭaka": ['mw'],
    "capucapukārakaṁ": ['cped'],
    "capya": ['mw'],
    "car": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cara": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "cara(t)": ['cped'],
    "carabha": ['mw'],
    "carabhavana": ['mw'],
    "caradala": ['mw'],
    "caradalajā": ['mw'],
    "caradeva": ['ddsa', 'mw'],
    "caradhyai": ['cae'],
    "caradravya": ['mw'],
    "caragṛha": ['mw'],
    "carahi": ['cped'],
    "carajyā": ['mw'],
    "carajā": ['mw'],
    "caraka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "carakabhāṣya": ['mw'],
    "carakagrantha": ['mw'],
    "carakatantra": ['mw'],
    "carakatantravyākhyā": ['mw'],
    "carakaḥ": ['ap90'],
    "carakhaṇḍa": ['mw'],
    "carakā": ['bhs'],
    "carakācārya": ['mw'],
    "carakādhvaryu": ['cae', 'mw'],
    "carakī": ['mw'],
    "carama": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "caramabhavika": ['bhs', 'mw'],
    "caramagiri": ['mw'],
    "caramakāla": ['mw'],
    "caramakṣmābhṛt": ['mw'],
    "caramam": ['mw'],
    "caramatas": ['mw'],
    "caramavaiyākaraṇa": ['mw'],
    "caramavayas": ['cae', 'mw'],
    "caramaśairṣika": ['mw'],
    "caramaśayana": ['bhs'],
    "caramya": ['mw'],
    "caramācala": ['mw'],
    "caramādri": ['mw'],
    "caramājā": ['mw'],
    "caramāna": ['cped'],
    "caramāvasthā": ['mw'],
    "caramūrti": ['mw'],
    "caranta": ['cped', 'mw'],
    "carapurā": ['cped'],
    "carapuṣṭa": ['mw'],
    "caratha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "caravya": ['mw'],
    "caraśiñjinī": ['mw'],
    "caraṇa": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "caraṇabhaṅga": ['mw'],
    "caraṇadāsa": ['mw'],
    "caraṇagata": ['mw'],
    "caraṇagranthi": ['mw'],
    "caraṇaguru": ['cae'],
    "caraṇaka": ['ddsa', 'mw'],
    "caraṇakamala": ['mw'],
    "caraṇakisalaya": ['mw'],
    "caraṇalagna": ['mw'],
    "caraṇanyāsa": ['cae', 'mw'],
    "caraṇapa": ['mw'],
    "caraṇapadma": ['mw'],
    "caraṇaparvan": ['mw'],
    "caraṇapatana": ['cae', 'mw'],
    "caraṇapatita": ['mw'],
    "caraṇaprasāra": ['mw'],
    "caraṇapāta": ['mw'],
    "caraṇapṛṣṭha": ['mw'],
    "caraṇarāga": ['cae'],
    "caraṇasa": ['mw'],
    "caraṇasampanna": ['cped'],
    "caraṇasaṃskāra": ['cae'],
    "caraṇasevā": ['mw'],
    "caraṇatra": ['mw'],
    "caraṇava(t)": ['cped'],
    "caraṇavat": ['mw'],
    "caraṇavikṣepa": ['cae'],
    "caraṇavipanna": ['cped'],
    "caraṇavyūha": ['cae', 'mw'],
    "caraṇayodhin": ['mw'],
    "caraṇayuga": ['mw'],
    "caraṇaśuśrūṣā": ['mw'],
    "caraṇaḥ": ['ap90'],
    "caraṇi": ['gra', 'mw'],
    "caraṇila": ['mw'],
    "caraṇiḥ": ['ap90'],
    "caraṇodaka": ['mw'],
    "caraṇopadhāna": ['mw'],
    "caraṇopaga": ['mw'],
    "caraṇy": ['gra'],
    "caraṇya": ['mw'],
    "caraṇyu": ['ap90', 'cae', 'gra', 'mw'],
    "caraṇābharaṇa": ['mw'],
    "caraṇākṣa": ['mw'],
    "caraṇāmṛta": ['mw'],
    "caraṇānamita": ['mw'],
    "caraṇānati": ['mw'],
    "caraṇāravinda": ['mw'],
    "caraṇārdha": ['mw'],
    "caraṇāskandana": ['mw'],
    "caraṇāyudha": ['mw'],
    "caraṇīy": ['gra'],
    "caraṇīyamāna": ['mw'],
    "caraṇṭī": ['mw'],
    "caraṭa": ['mw'],
    "caraṭaḥ": ['ap90'],
    "caraṭī": ['mw'],
    "carb": ['ap90', 'mw'],
    "carbhaṭa": ['mw'],
    "carbhaṭaḥ": ['ap90'],
    "carbhaṭī": ['ap90', 'mw'],
    "carc": ['ap90', 'cae', 'ddsa', 'mw'],
    "carca": ['mw'],
    "carcaka": ['ap90', 'mw'],
    "carcakamālā": ['mw'],
    "carcana": ['ddsa', 'mw'],
    "carcanaṃ": ['ap90'],
    "carcara": ['bhs', 'gra', 'mw'],
    "carcarikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "carcarī": ['cae', 'ddsa', 'mw'],
    "carcarīka": ['mw'],
    "carcarīkaḥ": ['ap90'],
    "carcas": ['ap90', 'mw'],
    "carcaḥ": ['ap90'],
    "carci": ['bhs', 'mw'],
    "carcikya": ['mw'],
    "carcikyaṃ": ['ap90'],
    "carcikā": ['mw'],
    "carcita": ['ap90', 'cae', 'ddsa', 'mw'],
    "carciḥ": ['ap90'],
    "carcā": ['ap90', 'cae', 'ddsa', 'mw'],
    "carcāpada": ['mw'],
    "carcāpāra": ['mw'],
    "carcāya": ['mw'],
    "care": ['bhs'],
    "carendra": ['bhs'],
    "cargh": ['ap90', 'mw'],
    "cari": ['bhs', 'cped', 'mw'],
    "carima": ['bhs'],
    "carimaka": ['bhs', 'cped'],
    "carimha": ['cped'],
    "carita": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "carita(r)": ['cped'],
    "caritabba": ['cped'],
    "caritaguṇatva": ['mw'],
    "caritaka": ['cped'],
    "caritamaya": ['mw'],
    "caritapūrva": ['cae', 'ddsa', 'mw'],
    "caritavant": ['bhs'],
    "caritave": ['cae', 'ddsa'],
    "caritavrata": ['cae', 'ddsa', 'mw'],
    "caritavya": ['ap90', 'ddsa', 'mw'],
    "caritra": ['cae', 'ddsa', 'gra', 'mw'],
    "caritrabandhaka": ['mw'],
    "caritrapuṣpa": ['mw'],
    "caritravat": ['mw'],
    "caritraṃ": ['ap90'],
    "caritrā": ['mw'],
    "caritrāvaśeṣa": ['mw'],
    "caritvā": ['cped'],
    "caritvāna": ['cped'],
    "caritārtha": ['cae', 'ddsa', 'mw'],
    "caritārthatva": ['mw'],
    "caritārthatā": ['mw'],
    "caritārthaya": ['ddsa', 'mw'],
    "caritārthin": ['mw'],
    "caritārthita": ['mw'],
    "caritāvin": ['bhs'],
    "cariya": ['cped'],
    "cariyā": ['bhs', 'cped'],
    "cariḥ": ['ap90'],
    "cariṁ": ['cped'],
    "cariṁsu": ['cped'],
    "cariṣṇu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cariṣṇudhūma": ['gra', 'mw'],
    "carkarīta": ['mw'],
    "carkṛti": ['cae', 'ddsa', 'gra', 'mw'],
    "carkṛtia": ['gra'],
    "carkṛtiḥ": ['ap90'],
    "carkṛtya": ['cae', 'gra', 'mw'],
    "carkṛṣe": ['ddsa'],
    "carma": ['cae', 'ddsa', 'mw'],
    "carmabandha": ['mw'],
    "carmabandhana": ['mw'],
    "carmabhastrikā": ['mw'],
    "carmacaṭaka": ['bhs', 'mw'],
    "carmacaṭakā": ['mw'],
    "carmacaṭikā": ['mw'],
    "carmacaṭī": ['mw'],
    "carmacela": ['mw'],
    "carmacitraka": ['mw'],
    "carmadala": ['mw'],
    "carmadaṇḍa": ['mw'],
    "carmadruma": ['mw'],
    "carmadūṣikā": ['mw'],
    "carmaghaṭikā": ['mw'],
    "carmagoṇī": ['mw'],
    "carmagrīva": ['mw'],
    "carmahantrī": ['mw'],
    "carmaja": ['cae', 'mw'],
    "carmakaraṇa": ['mw'],
    "carmakarta": ['mw'],
    "carmakaśā": ['mw'],
    "carmakaṣā": ['mw'],
    "carmakhaṇḍa": ['mw'],
    "carmakhaṇḍika": ['mw'],
    "carmakāra": ['cae', 'mw'],
    "carmakāraka": ['mw'],
    "carmakārin": ['cae', 'mw'],
    "carmakāriṇī": ['mw'],
    "carmakārya": ['cae', 'mw'],
    "carmakārāluka": ['mw'],
    "carmakārī": ['mw'],
    "carmakāṣṭhamaya": ['mw'],
    "carmakāṣṭhikā": ['mw'],
    "carmakīla": ['mw'],
    "carmakūpa": ['mw'],
    "carmakṛt": ['cae', 'mw'],
    "carmamaya": ['ap90', 'cae', 'mw'],
    "carmamaṇḍala": ['mw'],
    "carmamna": ['mw'],
    "carmamnā": ['gra'],
    "carmamuṇḍā": ['mw'],
    "carman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "carmanāsikā": ['mw'],
    "carmapattrā": ['mw'],
    "carmapaṭṭa": ['ddsa', 'mw'],
    "carmapaṭṭikā": ['mw'],
    "carmaprabhedikā": ['mw'],
    "carmaprasevaka": ['mw'],
    "carmaprasevikā": ['mw'],
    "carmapuṭa": ['mw'],
    "carmapuṭaka": ['mw'],
    "carmapādukā": ['mw'],
    "carmapūram": ['mw'],
    "carmaratna": ['mw'],
    "carmaratnabhastrikā": ['mw'],
    "carmaraṅga": ['mw'],
    "carmaraṅgā": ['mw'],
    "carmaru": ['mw'],
    "carmaruḥ": ['ap90'],
    "carmarī": ['mw'],
    "carmasambhavā": ['mw'],
    "carmasamudbhava": ['mw'],
    "carmasāhvā": ['mw'],
    "carmasāra": ['mw'],
    "carmataraṃga": ['mw'],
    "carmatila": ['mw'],
    "carmavasana": ['mw'],
    "carmavat": ['mw'],
    "carmavaṃśa": ['mw'],
    "carmavraṇa": ['mw'],
    "carmavādya": ['mw'],
    "carmavṛkṣa": ['mw'],
    "carmayaṣṭi": ['mw'],
    "carmaśilpin": ['mw'],
    "carmaṃ": ['ap90'],
    "carmaṇvant": ['cae'],
    "carmaṇvat": ['mw'],
    "carmaṇvatī": ['ap90', 'mw'],
    "carmaṇya": ['ap90', 'cae', 'ddsa', 'mw'],
    "carmaṇā": ['mw'],
    "carmika": ['ap90', 'mw'],
    "carmin": ['ap90', 'cae', 'ddsa', 'mw'],
    "carmivṛkṣa": ['mw'],
    "carmācchādita": ['mw'],
    "carmākhya": ['mw'],
    "carmāmbara": ['mw'],
    "carmāmbhas": ['mw'],
    "carmānta": ['mw'],
    "carmānurañjana": ['mw'],
    "carmāra": ['mw'],
    "carmāraka": ['mw'],
    "carmāsimat": ['mw'],
    "carmāvakartana": ['mw'],
    "carmāvakartin": ['cae', 'ddsa', 'mw'],
    "carmāvakarttṛ": ['cae', 'mw'],
    "carmāvanaddha": ['mw'],
    "carmāvṛta": ['mw'],
    "carpaṭa": ['bhs', 'cae', 'ddsa', 'mw'],
    "carpaṭaka": ['bhs'],
    "carpaṭaḥ": ['ap90'],
    "carpaṭikā": ['bhs'],
    "carpaṭin": ['mw'],
    "carpaṭā": ['mw'],
    "carpaṭī": ['ap90', 'mw'],
    "cartana": ['ap90'],
    "cartavya": ['mw'],
    "cartya": ['ap90', 'mw'],
    "caru": ['cae', 'ddsa', 'gra', 'mw'],
    "carucelin": ['mw'],
    "caruhoma": ['mw'],
    "carusthālī": ['mw'],
    "caruvraṇa": ['mw'],
    "caruśrapaṇa": ['mw'],
    "caruḥ": ['ap90'],
    "carv": ['ap90', 'cae', 'ddsa', 'mw'],
    "carvan": ['mw'],
    "carvaṇa": ['cae', 'ddsa', 'mw'],
    "carvaṇaṃ": ['ap90'],
    "carvaṇā": ['mw'],
    "carvaṇīya": ['mw'],
    "carvita": ['ap90', 'mw'],
    "carvitacarvaṇa": ['mw'],
    "carvitapātra": ['mw'],
    "carvitapātraka": ['mw'],
    "carvya": ['ap90', 'mw'],
    "carvā": ['ap90'],
    "carya": ['ap90', 'cae', 'ddsa', 'mw'],
    "caryā": ['ap90', 'bhs', 'mw'],
    "caryācaraṇa": ['mw'],
    "caryāgata": ['bhs'],
    "caryākārā": ['bhs'],
    "caryānātha": ['mw'],
    "caryāpratipattibhūmi": ['bhs'],
    "caryāvatāra": ['mw'],
    "carā": ['mw'],
    "carācara": ['cae', 'ddsa', 'gra', 'mw'],
    "carācaraguru": ['mw'],
    "carātha": ['mw'],
    "carī": ['bhs', 'mw'],
    "carītra": ['mw'],
    "carītraṃ": ['ap90'],
    "carṣaṇa": ['mw'],
    "carṣaṇi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "carṣaṇiprā": ['cae', 'gra', 'mw'],
    "carṣaṇī": ['ddsa', 'mw'],
    "carṣaṇīdhṛt": ['cae', 'gra', 'mw'],
    "carṣaṇīdhṛti": ['cae', 'mw'],
    "carṣaṇīsah": ['cae', 'gra', 'mw'],
    "casamāsa": ['mw'],
    "cat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "catasṛ": ['cae', 'ddsa', 'mw'],
    "catasṛkā": ['mw'],
    "catat": ['mw'],
    "catin": ['cae', 'gra', 'mw'],
    "catita": ['ap90', 'mw'],
    "catta": ['cped', 'mw'],
    "cattarātra": ['mw'],
    "cattra": ['mw'],
    "cattālīsa(ṁ)": ['cped'],
    "cattālīsaka": ['cped'],
    "cattārisaka": ['cped'],
    "cattārivassa-sahassāyuka": ['cped'],
    "cattārīsa(ṁ)": ['cped'],
    "cattārīsachabbassasatāyukā": ['cped'],
    "cattārīsavassasahassāyuka": ['cped'],
    "cattārīsavassāyuka": ['cped'],
    "cattāḷīsaka": ['cped'],
    "catu": ['mw'],
    "catu(b)bhāga": ['cped'],
    "catu(g)guṇa": ['cped'],
    "catu(k)kuṇḍika": ['cped'],
    "catu(k)kuṭika": ['cped'],
    "catu(m)mahāpatha": ['cped'],
    "catu(m)mūlaka": ['cped'],
    "catu(n)navuti": ['cped'],
    "catu(r)": ['cped'],
    "catubbhidaṁ": ['cped'],
    "catubbhidena": ['cped'],
    "catubbhidha": ['cped'],
    "catucakka": ['cped'],
    "catucattālīsa(ṁ)": ['cped'],
    "catucattārīsa(ṁ)": ['cped'],
    "catucattāḷīsa(ṁ)": ['cped'],
    "catuddasa": ['cped'],
    "catuddisaṁ": ['cped'],
    "catuddisā": ['cped'],
    "catudhā": ['cped'],
    "catudoṇika": ['cped'],
    "catuha": ['cped'],
    "catuhattha": ['cped'],
    "catukka": ['cped'],
    "catukkabhata": ['cped'],
    "catukkanipāta": ['cped'],
    "catukkaṁsaparama": ['cped'],
    "catukkaṇṇa": ['cped'],
    "catukkaṇṇaka": ['cped'],
    "catukkhattuṁ": ['cped'],
    "catula": ['ap90', 'mw'],
    "catumāsa": ['cped'],
    "catumāsā": ['cped'],
    "catumūlika": ['cped'],
    "catuporisa": ['cped'],
    "catuppad": ['cped'],
    "catuppada": ['cped'],
    "catuppādaka": ['cped'],
    "catupurisa": ['cped'],
    "catur": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "catura": ['ap90', 'cae', 'ddsa', 'mw'],
    "caturadhyāyika": ['mw'],
    "caturadhyāyikā": ['mw'],
    "caturadhyāyī": ['mw'],
    "caturaga": ['mw'],
    "caturagnivat": ['mw'],
    "caturaha": ['cae', 'mw'],
    "caturahika": ['bhs'],
    "caturaka": ['cae', 'mw'],
    "caturakrama": ['mw'],
    "caturakṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "caturakṣara": ['cae', 'ddsa', 'mw'],
    "caturakṣaraśas": ['mw'],
    "caturam": ['mw'],
    "caturamla": ['mw'],
    "caturanta": ['cae', 'mw'],
    "caturanteśa": ['mw'],
    "caturantā": ['mw'],
    "caturanugāna": ['mw'],
    "caturanīka": ['cae', 'ddsa', 'gra', 'mw'],
    "caturapassena": ['cped'],
    "caturartha": ['mw'],
    "caturarṇava": ['cae'],
    "caturasra": ['mw'],
    "caturasraka": ['bhs', 'mw'],
    "caturasravadana": ['bhs'],
    "caturasrayāna": ['mw'],
    "caturasraśobhin": ['mw'],
    "caturassa": ['cped'],
    "caturassaka": ['cped'],
    "caturatva": ['mw'],
    "caturatā": ['ddsa', 'mw'],
    "caturavarārdhya": ['mw'],
    "caturavatta": ['mw'],
    "caturavattin": ['mw'],
    "caturaśra": ['cae', 'mw'],
    "caturaśraka": ['mw'],
    "caturaśratā": ['mw'],
    "caturaśri": ['cae', 'gra', 'mw'],
    "caturaśrita": ['bhs'],
    "caturaśrīkṛ": ['mw'],
    "caturaśīta": ['mw'],
    "caturaśīti": ['mw'],
    "caturaśītisāhasra": ['mw'],
    "caturaśītitama": ['mw'],
    "caturaśītiyogādhyāya": ['mw'],
    "caturaṁsa": ['cped'],
    "caturaṃśavat": ['mw'],
    "caturaṅga": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "caturaṅgabala": ['bhs', 'mw'],
    "caturaṅgabalādhipatya": ['mw'],
    "caturaṅgabalādhyakṣa": ['mw'],
    "caturaṅgakrīḍā": ['mw'],
    "caturaṅgasainya": ['mw'],
    "caturaṅgasamannāgata": ['cped'],
    "caturaṅgavinoda": ['mw'],
    "caturaṅgi(n)": ['cped'],
    "caturaṅgin": ['cae', 'ddsa', 'mw'],
    "caturaṅgiṇī": ['mw'],
    "caturaṅgula": ['cped', 'mw'],
    "caturaṅgulaparyavanaddha": ['mw'],
    "caturaṅgulika": ['cped'],
    "caturaṅgā": ['mw'],
    "caturaṇuka": ['mw'],
    "caturaṣṭaka": ['mw'],
    "caturbhadra": ['mw'],
    "caturbhadratara": ['mw'],
    "caturbhadrikā": ['mw'],
    "caturbhuja": ['cae', 'mw'],
    "caturbhujabhaṭṭācārya": ['mw'],
    "caturbhujamiśra": ['mw'],
    "caturbhāga": ['cae', 'mw'],
    "caturbhāgīyā": ['mw'],
    "caturbhūmika": ['cae', 'mw'],
    "caturbhūyas": ['mw'],
    "caturbhṛṣṭi": ['gra', 'mw'],
    "caturbila": ['mw'],
    "caturbāhu": ['cae', 'ddsa', 'mw'],
    "caturbīja": ['mw'],
    "caturdaiva": ['mw'],
    "caturdala": ['mw'],
    "caturdanta": ['ddsa', 'mw'],
    "caturdat": ['mw'],
    "caturdaśa": ['cae', 'ddsa', 'mw'],
    "caturdaśadhā": ['cae', 'mw'],
    "caturdaśaguṇa": ['mw'],
    "caturdaśaguṇanāman": ['mw'],
    "caturdaśaguṇasthāna": ['mw'],
    "caturdaśaka": ['mw'],
    "caturdaśama": ['cae', 'mw'],
    "caturdaśamataviveka": ['mw'],
    "caturdaśan": ['cae', 'gra', 'mw'],
    "caturdaśarca": ['mw'],
    "caturdaśarātra": ['mw'],
    "caturdaśasamadvandva": ['mw'],
    "caturdaśasvapanavicāra": ['mw'],
    "caturdaśavidha": ['mw'],
    "caturdaśika": ['mw'],
    "caturdaśākṣara": ['mw'],
    "caturdaśī": ['mw'],
    "caturdaśīśānti": ['mw'],
    "caturdaṃṣṭra": ['mw'],
    "caturdhara": ['mw'],
    "caturdharmakasūtra": ['bhs'],
    "caturdhā": ['ap90', 'cae', 'gra', 'mw'],
    "caturdhābhū": ['mw'],
    "caturdhākaraṇa": ['mw'],
    "caturdhākṛ": ['mw'],
    "caturdhārin": ['mw'],
    "caturdhātu": ['mw'],
    "caturdhāvihita": ['mw'],
    "caturdhāśānti": ['mw'],
    "caturdikka": ['bhs'],
    "caturdikkam": ['cae', 'mw'],
    "caturdikṣu": ['mw'],
    "caturdiśam": ['cae', 'mw'],
    "caturdola": ['mw'],
    "caturdos": ['mw'],
    "caturdvāra": ['mw'],
    "caturdvāramukha": ['mw'],
    "caturdvīpacakravartin": ['mw'],
    "caturdvīpakacakravartin": ['bhs'],
    "caturdvīpeśvara": ['bhs'],
    "caturdārikā": ['mw'],
    "caturgandha": ['mw'],
    "caturgati": ['mw'],
    "caturgava": ['mw'],
    "caturgaṇa": ['mw'],
    "caturgrāma": ['mw'],
    "caturguṇa": ['cae', 'ddsa', 'mw'],
    "caturguṇam": ['bhs'],
    "caturgṛhīta": ['mw'],
    "caturgṛhītin": ['mw'],
    "caturhanu": ['mw'],
    "caturhasta": ['mw'],
    "caturhita": ['mw'],
    "caturhotra": ['mw'],
    "caturhotraka": ['mw'],
    "caturhotṛ": ['mw'],
    "caturhotṛtva": ['mw'],
    "caturhrasva": ['mw'],
    "caturhāyana": ['mw'],
    "caturhāyaṇa": ['mw'],
    "caturhāyaṇī": ['mw'],
    "caturikā": ['mw'],
    "caturindriya": ['mw'],
    "caturiḍaspadastobha": ['mw'],
    "caturjāta": ['mw'],
    "caturjātaka": ['mw'],
    "caturlekha": ['mw'],
    "caturmahāpatha": ['bhs', 'mw'],
    "caturmahārāja": ['mw'],
    "caturmahārājakāyika": ['bhs', 'mw'],
    "caturmahārājika": ['bhs', 'mw'],
    "caturmedha": ['mw'],
    "caturmuhūrtam": ['mw'],
    "caturmukha": ['cae', 'mw'],
    "caturmukharasa": ['mw'],
    "caturmukhatva": ['mw'],
    "caturmukhatīrtha": ['mw'],
    "caturmuṣṭi": ['mw'],
    "caturmuṣṭika": ['mw'],
    "caturmāsa": ['mw'],
    "caturmāsya": ['mw'],
    "caturmāsī": ['mw'],
    "caturmūrti": ['cae', 'mw'],
    "caturmūrtitva": ['mw'],
    "caturnavata": ['mw'],
    "caturnavati": ['mw'],
    "caturnavatitama": ['mw'],
    "caturnetṛ": ['mw'],
    "caturnidhana": ['mw'],
    "caturoghottīrṇa": ['mw'],
    "caturtha": ['ap90', 'cae', 'ddsa', 'mw'],
    "caturthabhaktakṣapaṇa": ['mw'],
    "caturthabhāj": ['mw'],
    "caturthaka": ['ap90', 'mw'],
    "caturthakāla": ['cae', 'ddsa', 'mw'],
    "caturthakālam": ['mw'],
    "caturthakāle": ['mw'],
    "caturthakālika": ['cae', 'mw'],
    "caturtham": ['mw'],
    "caturthamandrātisvārya": ['mw'],
    "caturthaphala": ['mw'],
    "caturthasvara": ['mw'],
    "caturthi": ['mw'],
    "caturthikā": ['mw'],
    "caturthiprabhṛti": ['mw'],
    "caturthodāttatama": ['mw'],
    "caturthāśrama": ['mw'],
    "caturthāṃśa": ['cae', 'ddsa', 'mw'],
    "caturthāṃśin": ['mw'],
    "caturthī": ['ap90', 'mw'],
    "caturthīkarman": ['ddsa', 'mw'],
    "caturuttara": ['cae', 'mw'],
    "caturuttarastoma": ['mw'],
    "caturuṣṭra": ['mw'],
    "caturvaiśāradyaviśārada": ['mw'],
    "caturvaktra": ['cae', 'mw'],
    "caturvarga": ['cae', 'mw'],
    "caturvargacintāmaṇi": ['mw'],
    "caturvarṇa": ['mw'],
    "caturvarṇamaya": ['mw'],
    "caturvarṇādi": ['mw'],
    "caturvarṣaśatāyus": ['mw'],
    "caturvarṣikā": ['mw'],
    "caturvaya": ['cae', 'gra', 'mw'],
    "caturveda": ['cae', 'mw'],
    "caturvedavid": ['cae'],
    "caturvedin": ['mw'],
    "caturvibhakta": ['mw'],
    "caturvidha": ['cae', 'mw'],
    "caturvidham": ['mw'],
    "caturvidhasaṃśayodbheda": ['mw'],
    "caturvidhāhāramaya": ['mw'],
    "caturvidya": ['mw'],
    "caturvidyā": ['mw'],
    "caturviṃśa": ['cae', 'mw'],
    "caturviṃśacchata": ['mw'],
    "caturviṃśaka": ['mw'],
    "caturviṃśastoma": ['mw'],
    "caturviṃśat": ['cae', 'mw'],
    "caturviṃśati": ['cae', 'mw'],
    "caturviṃśatidaṇḍakastava": ['mw'],
    "caturviṃśatidhā": ['mw'],
    "caturviṃśatigava": ['mw'],
    "caturviṃśatika": ['mw'],
    "caturviṃśatikṛtvas": ['mw'],
    "caturviṃśatima": ['mw'],
    "caturviṃśatimata": ['mw'],
    "caturviṃśatimāna": ['mw'],
    "caturviṃśatipurāṇa": ['mw'],
    "caturviṃśatismṛti": ['mw'],
    "caturviṃśatisāhasra": ['mw'],
    "caturviṃśatitama": ['cae', 'mw'],
    "caturviṃśatitīrthaṃkarapūjā": ['mw'],
    "caturviṃśativikrama": ['mw'],
    "caturviṃśatyaha": ['mw'],
    "caturviṃśatyakṣara": ['mw'],
    "caturviṃśatyavatāracaritra": ['mw'],
    "caturviṃśika": ['mw'],
    "caturviṃśākṣara": ['mw'],
    "caturvyavasitayamaka": ['mw'],
    "caturvyaṅga": ['mw'],
    "caturvyāpin": ['mw'],
    "caturvyūha": ['mw'],
    "caturvyūhavādin": ['mw'],
    "caturvāhin": ['mw'],
    "caturvīra": ['mw'],
    "caturvṛṣa": ['mw'],
    "caturya": ['bhs', 'mw'],
    "caturyama": ['mw'],
    "caturyuga": ['cae', 'gra', 'mw'],
    "caturyuj": ['cae', 'gra', 'mw'],
    "caturyukta": ['cae', 'mw'],
    "caturādhiṭṭhāna": ['cped'],
    "caturādhyāyika": ['mw'],
    "caturādhyāyikā": ['mw'],
    "caturādhyāyī": ['mw'],
    "caturānana": ['cae', 'mw'],
    "caturāpāssena": ['cped'],
    "caturāsīti": ['cped'],
    "caturāsītiṁ": ['cped'],
    "caturātman": ['mw'],
    "caturāśramin": ['mw'],
    "caturāśramya": ['mw'],
    "caturāśīti": ['bhs'],
    "caturūdhnī": ['mw'],
    "caturūrdhvapad": ['mw'],
    "caturūṣaṇa": ['mw'],
    "caturṇavata": ['mw'],
    "caturṛca": ['mw'],
    "caturṛddhipādacaraṇatalasupratiṣṭhita": ['mw'],
    "catus": ['cae', 'ddsa', 'mw'],
    "catusacca": ['cped'],
    "catusaccāni": ['cped'],
    "catusahassa": ['cped'],
    "catusaṭṭhi": ['cped'],
    "catustanā": ['mw'],
    "catusthāna": ['mw'],
    "catustotra": ['mw'],
    "catustridvyekabhāga": ['mw'],
    "catustriṃśa": ['cae', 'ddsa', 'mw'],
    "catustriṃśadakṣara": ['mw'],
    "catustriṃśadrātram": ['mw'],
    "catustriṃśajjātakajña": ['mw'],
    "catustriṃśat": ['cae', 'gra', 'mw'],
    "catustriṃśatsammita": ['mw'],
    "catustāla": ['mw'],
    "catutha": ['bhs'],
    "catuttari": ['cped'],
    "catuttha": ['cped'],
    "catutthaka": ['cped'],
    "catutthaṁ": ['cped'],
    "catutthe": ['cped'],
    "catutāla": ['cped'],
    "catuvagga": ['cped'],
    "catuvidha": ['cped'],
    "catuvīsa": ['cped'],
    "catuvīsati": ['cped'],
    "catuvīsatima": ['cped'],
    "catuyojanasitika": ['cped'],
    "catuyojanika": ['cped'],
    "catuś": ['mw'],
    "catuścakra": ['mw'],
    "catuścalita": ['mw'],
    "catuścaraṇa": ['mw'],
    "catuścatvāriṃśa": ['cae', 'ddsa', 'mw'],
    "catuścatvāriṃśat": ['cae', 'mw'],
    "catuścatvāriṃśin": ['mw'],
    "catuścitya": ['mw'],
    "catuḥ": ['mw'],
    "catuḥka": ['ddsa'],
    "catuḥkala": ['bhs'],
    "catuḥkarṇa": ['bhs'],
    "catuḥpañca": ['mw'],
    "catuḥpañcāśa": ['mw'],
    "catuḥsahasra": ['cae', 'gra', 'mw'],
    "catuḥsama": ['mw'],
    "catuḥsamudra": ['cae', 'gra', 'mw'],
    "catuḥsana": ['mw'],
    "catuḥsandhi": ['ddsa'],
    "catuḥsaptata": ['mw'],
    "catuḥsaptati": ['mw'],
    "catuḥsaptatitama": ['mw'],
    "catuḥsaptātman": ['mw'],
    "catuḥsauvarṇaka": ['mw'],
    "catuḥsauvarṇika": ['cae'],
    "catuḥsaṃdhi": ['mw'],
    "catuḥsaṃkara": ['mw'],
    "catuḥsaṃstha": ['mw'],
    "catuḥsrakti": ['mw'],
    "catuḥstanā": ['mw'],
    "catuḥsthāna": ['mw'],
    "catuḥstotra": ['mw'],
    "catuḥsuvarṇaka": ['mw'],
    "catuḥsādhana": ['mw'],
    "catuḥsāhasraka": ['mw'],
    "catuḥsīta": ['mw'],
    "catuḥśaila": ['bhs'],
    "catuḥśamī": ['mw'],
    "catuḥśapha": ['cae', 'mw'],
    "catuḥśarāva": ['mw'],
    "catuḥśata": ['cae', 'ddsa', 'gra', 'mw'],
    "catuḥśatatama": ['mw'],
    "catuḥśatī": ['mw'],
    "catuḥśikha": ['mw'],
    "catuḥśikhaṇḍa": ['mw'],
    "catuḥśila": ['mw'],
    "catuḥśrotra": ['mw'],
    "catuḥśruti": ['mw'],
    "catuḥśākha": ['mw'],
    "catuḥśāla": ['cae', 'mw'],
    "catuḥśālaka": ['cae', 'mw'],
    "catuḥśālikā": ['mw'],
    "catuḥśṛṅga": ['gra', 'mw'],
    "catuḥṣaṣṭa": ['mw'],
    "catuḥṣaṣṭi": ['ddsa', 'mw'],
    "catuḥṣaṣṭikalāgama": ['mw'],
    "catuḥṣaṣṭikalāśāstra": ['mw'],
    "catuḥṣaṣṭitama": ['mw'],
    "catuḥṣaṣṭyaṅga": ['mw'],
    "catuḥṣaṣṭyupacāramānasapūjāstotrastotra": ['mw'],
    "catuḥṣṭoma": ['mw'],
    "catuṣ": ['mw'],
    "catuṣcatvāriṃśadakṣara": ['mw'],
    "catuṣka": ['ap90', 'cae', 'ddsa', 'mw'],
    "catuṣkala": ['mw'],
    "catuṣkanipāta": ['bhs'],
    "catuṣkaparda": ['gra', 'mw'],
    "catuṣkarṇa": ['mw'],
    "catuṣkarṇatayā": ['mw'],
    "catuṣkarṇatā": ['mw'],
    "catuṣkarṇī": ['mw'],
    "catuṣkaveśman": ['mw'],
    "catuṣkhaṇḍa": ['mw'],
    "catuṣkikā": ['ap90', 'ddsa', 'mw'],
    "catuṣkin": ['mw'],
    "catuṣkiṣku": ['mw'],
    "catuṣkoṇa": ['mw'],
    "catuṣkoṭikā": ['bhs'],
    "catuṣkrama": ['mw'],
    "catuṣkumbhikā": ['bhs'],
    "catuṣkārin": ['mw'],
    "catuṣkī": ['mw'],
    "catuṣkṛṣṇa": ['mw'],
    "catuṣpad": ['cae', 'ddsa', 'gra', 'mw'],
    "catuṣpada": ['cae', 'mw'],
    "catuṣpadaka": ['bhs'],
    "catuṣpadavastuka": ['cae'],
    "catuṣpadikā": ['mw'],
    "catuṣpadottha": ['cae'],
    "catuṣpadā": ['mw'],
    "catuṣpadī": ['mw'],
    "catuṣpadīgamana": ['mw'],
    "catuṣpakṣa": ['mw'],
    "catuṣparva": ['mw'],
    "catuṣparyāya": ['mw'],
    "catuṣparṇī": ['mw'],
    "catuṣparṣadasūtra": ['bhs'],
    "catuṣpatha": ['cae', 'mw'],
    "catuṣpathakṛtāśaya": ['mw'],
    "catuṣpathaniketā": ['mw'],
    "catuṣpatharatā": ['mw'],
    "catuṣpathasad": ['mw'],
    "catuṣpattrī": ['mw'],
    "catuṣpañca": ['ddsa', 'mw'],
    "catuṣpañcan": ['mw'],
    "catuṣpañcāśa": ['mw'],
    "catuṣpañcāśadadhikaśata": ['mw'],
    "catuṣpañcāśat": ['cae', 'mw'],
    "catuṣpañcāśattama": ['mw'],
    "catuṣphalā": ['mw'],
    "catuṣprasthānika": ['mw'],
    "catuṣputra": ['mw'],
    "catuṣpuṇḍrā": ['mw'],
    "catuṣpuṭa": ['mw'],
    "catuṣpād": ['cae', 'mw'],
    "catuṣpāda": ['cae', 'mw'],
    "catuṣpādaka": ['bhs', 'mw'],
    "catuṣpādasamanvaya": ['mw'],
    "catuṣpādasiddhi": ['mw'],
    "catuṣpādika": ['bhs'],
    "catuṣpādī": ['mw'],
    "catuṣpārśva": ['mw'],
    "catuṣpāṇi": ['mw'],
    "catuṣpāṭhī": ['mw'],
    "catuṣpāṭī": ['mw'],
    "catuṣṭaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "catuṣṭoma": ['mw'],
    "catvara": ['cae', 'ddsa', 'mw'],
    "catvarataru": ['mw'],
    "catvaravāsinī": ['mw'],
    "catvaraṃ": ['ap90'],
    "catvarī": ['mw'],
    "catvāla": ['mw'],
    "catvālaḥ": ['ap90'],
    "catvār": ['cae', 'ddsa'],
    "catvāra": ['bhs'],
    "catvāraka": ['mw'],
    "catvāriṃśa": ['cae', 'ddsa', 'gra', 'mw'],
    "catvāriṃśadakṣara": ['mw'],
    "catvāriṃśadrātra": ['mw'],
    "catvāriṃśanmāna": ['mw'],
    "catvāriṃśat": ['ap90', 'cae', 'gra', 'mw'],
    "catvāriṃśati": ['cae', 'mw'],
    "catvāriṃśatpada": ['mw'],
    "catya": ['mw'],
    "catū": ['mw'],
    "catūha": ['cped'],
    "catūhapañcāha": ['cped'],
    "catūhapaṭicchanna": ['cped'],
    "catūrājī": ['mw'],
    "catūrātra": ['cae', 'ddsa', 'mw'],
    "catūrātram": ['mw'],
    "caudrāyaṇa": ['mw'],
    "caudāyani": ['mw'],
    "cauhittha": ['mw'],
    "cauhāna": ['mw'],
    "cauhāra": ['mw'],
    "cauhāṇa": ['mw'],
    "caukrya": ['mw'],
    "caukṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "caukṣya": ['cae', 'mw'],
    "caula": ['cae', 'ddsa', 'mw'],
    "caulakarman": ['mw'],
    "caulakāyana": ['mw'],
    "caulaśrīpatitīrtha": ['mw'],
    "cauli": ['mw'],
    "caulukya": ['mw'],
    "caupayata": ['mw'],
    "caupayatavidha": ['mw'],
    "caupayatyā": ['mw'],
    "caupayatāyani": ['mw'],
    "caupāyana": ['mw'],
    "caura": ['cae', 'ddsa', 'mw'],
    "caurabhavānī": ['mw'],
    "cauradhvajabaddhaka": ['mw'],
    "cauragata": ['mw'],
    "caurahṛta": ['mw'],
    "cauraka": ['mw'],
    "caurakarman": ['mw'],
    "caurakilbiṣa": ['cae', 'mw'],
    "caurapañcāśikā": ['mw'],
    "caurapuṣpauṣadhi": ['mw'],
    "caurarūpa": ['mw'],
    "caurarūpin": ['mw'],
    "caurasyakula": ['mw'],
    "cauratara": ['mw'],
    "cauratas": ['mw'],
    "cauraśaṅkin": ['cae'],
    "cauraḥ": ['ap90'],
    "cauraṃkāram": ['mw'],
    "cauraṅgin": ['mw'],
    "caurikayā": ['mw'],
    "caurikā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "caurikāka": ['mw'],
    "cauroddharaṇa": ['mw'],
    "cauroddharaṇika": ['mw'],
    "cauroddhartṛ": ['ddsa', 'mw'],
    "caurola": ['mw'],
    "caurya": ['bhs', 'cae', 'ddsa', 'mw'],
    "cauryaka": ['cae', 'mw'],
    "cauryakaṃ": ['ap90'],
    "cauryarata": ['mw'],
    "cauryasurata": ['mw'],
    "cauryavidyā": ['mw'],
    "cauryavṛtti": ['mw'],
    "cauryaṃ": ['ap90'],
    "cauryārjita": ['mw'],
    "caurādika": ['mw'],
    "caurāpahṛta": ['mw'],
    "caurāṃśā": ['mw'],
    "caurāṭavī": ['mw'],
    "caurī": ['mw'],
    "caurībhūta": ['mw'],
    "caurīsurata": ['mw'],
    "caurīsuratapañcāśikā": ['cae'],
    "cautapallava": ['ddsa', 'mw'],
    "cauḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "cauḍadeśa": ['mw'],
    "cauḍakarman": ['mw'],
    "cauḍi": ['mw'],
    "cauḍikya": ['mw'],
    "cauḍitikya": ['mw'],
    "cauḍāli": ['mw'],
    "cauḍārya": ['mw'],
    "cauṇḍa": ['mw'],
    "cauṇḍapa": ['mw'],
    "cauṇḍarāja": ['mw'],
    "cauṇḍya": ['mw'],
    "cauṇṭya": ['mw'],
    "cavamāna": ['cped'],
    "cavana": ['mw'],
    "cavanadhamma": ['cped'],
    "cavanatā": ['cped'],
    "cavanta": ['cped'],
    "cavati": ['bhs', 'cped'],
    "cavi": ['cped', 'mw'],
    "cavika": ['ddsa', 'mw'],
    "cavikā": ['mw'],
    "cavittha": ['cped'],
    "cavitvā": ['cped'],
    "caviya": ['cped'],
    "caviyāna(ṁ": ['cped'],
    "cavya": ['cae', 'mw'],
    "cavyajā": ['mw'],
    "cavyaphala": ['mw'],
    "cavyā": ['mw'],
    "cavī": ['mw'],
    "cay": ['ap90', 'mw'],
    "caya": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "cayaka": ['mw'],
    "cayana": ['cae', 'ddsa', 'mw'],
    "cayanakārikā": ['mw'],
    "cayanapaddhati": ['mw'],
    "cayanaprayoga": ['mw'],
    "cayanasūtra": ['mw'],
    "cayanaṃ": ['ap90'],
    "cayanānta": ['mw'],
    "cayanīya": ['mw'],
    "cayaḥ": ['ap90'],
    "cañc": ['cae', 'ddsa', 'mw'],
    "cañca": ['bhs', 'mw'],
    "cañcala": ['cae', 'ddsa', 'mw'],
    "cañcalahṛdaya": ['mw'],
    "cañcalalocana": ['cae'],
    "cañcalataila": ['mw'],
    "cañcalatara": ['mw'],
    "cañcalatva": ['mw'],
    "cañcalatā": ['mw'],
    "cañcalita": ['mw'],
    "cañcalā": ['ddsa', 'mw'],
    "cañcalākhya": ['mw'],
    "cañcalākṣikā": ['mw'],
    "cañcalī": ['mw'],
    "cañcarin": ['cae', 'ddsa', 'mw'],
    "cañcarī": ['mw'],
    "cañcarīka": ['cae', 'mw'],
    "cañcarīkāvalī": ['mw'],
    "cañcatka": ['mw'],
    "cañcatpuṭa": ['mw'],
    "cañcitāśraya": ['bhs'],
    "cañcu": ['bhs', 'cae', 'ddsa', 'mw'],
    "cañcubhṛt": ['mw'],
    "cañcukā": ['mw'],
    "cañcula": ['mw'],
    "cañcumat": ['mw'],
    "cañcuparṇikā": ['mw'],
    "cañcupattra": ['mw'],
    "cañcuprahāra": ['mw'],
    "cañcupuṭa": ['cae', 'mw'],
    "cañcupuṭaka": ['mw'],
    "cañcupuṭī": ['mw'],
    "cañcura": ['mw'],
    "cañcusūci": ['mw'],
    "cañcusūcika": ['mw'],
    "cañcutaila": ['mw'],
    "cañcutva": ['mw'],
    "cañcutā": ['mw'],
    "cañcā": ['bhs', 'cae', 'ddsa', 'mw'],
    "cañcāpuruṣa": ['mw'],
    "cañcū": ['mw'],
    "cañcūka": ['mw'],
    "cañcūpuṭa": ['cae', 'mw'],
    "cañcūryamāṇa": ['mw'],
    "cañcūḍa": ['mw'],
    "caṃb": ['ap90'],
    "caṃc": ['ap90'],
    "caṃcala": ['ap90'],
    "caṃcarin": ['ap90'],
    "caṃcarī": ['ap90'],
    "caṃcatka": ['ap90'],
    "caṃcaḥ": ['ap90'],
    "caṃcu": ['ap90'],
    "caṃcukā": ['ap90'],
    "caṃcura": ['ap90'],
    "caṃd": ['ap90'],
    "caṃdakaḥ": ['ap90'],
    "caṃdanaḥ": ['ap90'],
    "caṃdanin": ['ap90'],
    "caṃdanīyā": ['ap90'],
    "caṃdaḥ": ['ap90'],
    "caṃdiraḥ": ['ap90'],
    "caṃdra": ['ap90'],
    "caṃdrakavat": ['ap90'],
    "caṃdrakaḥ": ['ap90'],
    "caṃdrakin": ['ap90'],
    "caṃdramahaḥ": ['ap90'],
    "caṃdramas": ['ap90'],
    "caṃdrikā": ['ap90'],
    "caṃdrilaḥ": ['ap90'],
    "caṃdrimā": ['ap90'],
    "caṃdrin": ['ap90'],
    "caṃga": ['ap90'],
    "caṃgiman": ['ap90'],
    "caṃkramaṇaṃ": ['ap90'],
    "caṃkramā": ['ap90'],
    "caṃkuṇaḥ": ['ap90'],
    "caṃp": ['ap90'],
    "caṃpakaḥ": ['ap90'],
    "caṃpakāluḥ": ['ap90'],
    "caṃpakāvatī": ['ap90'],
    "caṃpaḥ": ['ap90'],
    "caṃpāluḥ": ['ap90'],
    "caṃpūḥ": ['ap90'],
    "caṃḍa": ['ap90'],
    "caṃḍavat": ['ap90'],
    "caṃḍilaḥ": ['ap90'],
    "caṃḍiman": ['ap90'],
    "caṃḍiḥ": ['ap90'],
    "caṃḍuḥ": ['ap90'],
    "caṃḍā": ['ap90'],
    "caṃḍāla": ['ap90'],
    "caṃḍālikā": ['ap90'],
    "caṃḍātakaḥ": ['ap90'],
    "caṃḍātaḥ": ['ap90'],
    "caṃḍīkṛ": ['ap90'],
    "caṅga": ['cae', 'ddsa', 'mw'],
    "caṅgadāsa": ['mw'],
    "caṅgavāra": ['cped'],
    "caṅgerika": ['mw'],
    "caṅgerikā": ['mw'],
    "caṅgerī": ['mw'],
    "caṅkama": ['cped'],
    "caṅkama(t)": ['cped'],
    "caṅkamamāna": ['cped'],
    "caṅkamanasālā": ['cped'],
    "caṅkamanta": ['cped'],
    "caṅkamati": ['cped'],
    "caṅkami": ['cped'],
    "caṅkamitabba": ['cped'],
    "caṅkamitvā": ['cped'],
    "caṅkrama": ['bhs', 'cae', 'ddsa', 'mw'],
    "caṅkramamāṇa": ['mw'],
    "caṅkramati": ['bhs'],
    "caṅkramaṇa": ['bhs', 'cae', 'mw'],
    "caṅkramita": ['mw'],
    "caṅkramyayuktāḥ": ['bhs'],
    "caṅkramā": ['mw'],
    "caṅkramāvat": ['mw'],
    "caṅkura": ['mw'],
    "caṅkuṇa": ['ddsa', 'mw'],
    "caṇ": ['ap90', 'mw'],
    "caṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "caṇabhojin": ['mw'],
    "caṇadruma": ['mw'],
    "caṇaka": ['cae', 'mw'],
    "caṇakalavaṇa": ['mw'],
    "caṇakaloṇī": ['mw'],
    "caṇakaḥ": ['ap90'],
    "caṇakā": ['mw'],
    "caṇakāmlaka": ['mw'],
    "caṇakāmlavār": ['mw'],
    "caṇakātmaja": ['mw'],
    "caṇapattrī": ['mw'],
    "caṇatva": ['mw'],
    "caṇava": ['mw'],
    "caṇeśvarī": ['mw'],
    "caṇikā": ['mw'],
    "caṇin": ['mw'],
    "caṇārarūpya": ['mw'],
    "caṇīdruma": ['mw'],
    "caṇḍ": ['mw'],
    "caṇḍa": ['cae', 'cped', 'ddsa', 'mw'],
    "caṇḍabala": ['mw'],
    "caṇḍabhujaṃga": ['mw'],
    "caṇḍabhānu": ['mw'],
    "caṇḍabhārgava": ['mw'],
    "caṇḍacukrā": ['mw'],
    "caṇḍadhāman": ['mw'],
    "caṇḍadīdhiti": ['cae', 'mw'],
    "caṇḍaghaṇṭā": ['mw'],
    "caṇḍaghoṣa": ['mw'],
    "caṇḍagiri": ['bhs'],
    "caṇḍagirika": ['bhs', 'mw'],
    "caṇḍagrāhavat": ['mw'],
    "caṇḍaka": ['bhs'],
    "caṇḍakara": ['cae', 'ddsa', 'mw'],
    "caṇḍakarman": ['ddsa', 'mw'],
    "caṇḍakarāya": ['ddsa', 'mw'],
    "caṇḍakauśika": ['cae', 'mw'],
    "caṇḍaketu": ['mw'],
    "caṇḍakiraṇa": ['cae', 'mw'],
    "caṇḍakolāhalā": ['mw'],
    "caṇḍakāpālika": ['mw'],
    "caṇḍam": ['mw'],
    "caṇḍamahāroṣaṇa": ['bhs'],
    "caṇḍamahāroṣaṇatantra": ['mw'],
    "caṇḍamahāsena": ['mw'],
    "caṇḍamarīci": ['mw'],
    "caṇḍamuṇḍā": ['mw'],
    "caṇḍamāruta": ['mw'],
    "caṇḍamṛga": ['bhs', 'mw'],
    "caṇḍanāyikā": ['mw'],
    "caṇḍaparvata": ['bhs'],
    "caṇḍapotaka": ['mw'],
    "caṇḍaprabha": ['mw'],
    "caṇḍapradyota": ['mw'],
    "caṇḍarava": ['mw'],
    "caṇḍaraśmi": ['cae', 'mw'],
    "caṇḍarocis": ['mw'],
    "caṇḍarudrikā": ['mw'],
    "caṇḍarūpā": ['mw'],
    "caṇḍasiṃha": ['cae', 'mw'],
    "caṇḍatuṇḍaka": ['mw'],
    "caṇḍatva": ['mw'],
    "caṇḍatā": ['cae', 'mw'],
    "caṇḍatāla": ['mw'],
    "caṇḍavajrapāṇi": ['bhs'],
    "caṇḍavarman": ['mw'],
    "caṇḍavat": ['mw'],
    "caṇḍavatī": ['mw'],
    "caṇḍavega": ['mw'],
    "caṇḍavegā": ['mw'],
    "caṇḍavegāsaṃgamatīrtha": ['mw'],
    "caṇḍavikrama": ['mw'],
    "caṇḍavīra": ['mw'],
    "caṇḍavṛtti": ['mw'],
    "caṇḍavṛṣṭiprapāta": ['mw'],
    "caṇḍaśakti": ['mw'],
    "caṇḍaśīla": ['mw'],
    "caṇḍeśa": ['mw'],
    "caṇḍeśvara": ['cae', 'ddsa', 'mw'],
    "caṇḍeśvarapraśnavidyā": ['mw'],
    "caṇḍeśvararasa": ['mw'],
    "caṇḍi": ['mw'],
    "caṇḍidāsa": ['mw'],
    "caṇḍika": ['mw'],
    "caṇḍikaghaṇṭa": ['mw'],
    "caṇḍikā": ['bhs', 'cae', 'ddsa', 'mw'],
    "caṇḍikāgṛha": ['mw'],
    "caṇḍikālaya": ['mw'],
    "caṇḍikāmahānavamī": ['mw'],
    "caṇḍikāmāhātmya": ['mw'],
    "caṇḍikāśataka": ['mw'],
    "caṇḍila": ['mw'],
    "caṇḍilā": ['mw'],
    "caṇḍiman": ['ddsa', 'mw'],
    "caṇḍograśūlapāṇi": ['mw'],
    "caṇḍogrā": ['mw'],
    "caṇḍu": ['mw'],
    "caṇḍā": ['bhs', 'mw'],
    "caṇḍādityatīrtha": ['mw'],
    "caṇḍākṣī": ['bhs'],
    "caṇḍāla": ['cae', 'cped', 'ddsa', 'mw'],
    "caṇḍālaka": ['bhs'],
    "caṇḍālakanda": ['mw'],
    "caṇḍālatva": ['mw'],
    "caṇḍālatā": ['mw'],
    "caṇḍālavallakī": ['mw'],
    "caṇḍālavaṁsa": ['cped'],
    "caṇḍālavaṁsadhovana": ['cped'],
    "caṇḍālavaṁsika": ['cped'],
    "caṇḍālikā": ['bhs', 'mw'],
    "caṇḍālikābandham": ['mw'],
    "caṇḍālinī": ['bhs'],
    "caṇḍālā": ['mw'],
    "caṇḍālī": ['bhs', 'cped', 'mw'],
    "caṇḍāntika": ['mw'],
    "caṇḍāta": ['mw'],
    "caṇḍātaka": ['cae', 'mw'],
    "caṇḍāśoka": ['mw'],
    "caṇḍāṃśu": ['cae', 'mw'],
    "caṇḍī": ['mw'],
    "caṇḍīcarita": ['mw'],
    "caṇḍīdevīśarman": ['mw'],
    "caṇḍīdāsa": ['mw'],
    "caṇḍīgṛha": ['mw'],
    "caṇḍīkata": ['cped'],
    "caṇḍīkucapañcaśatī": ['mw'],
    "caṇḍīkusuma": ['mw'],
    "caṇḍīkṛ": ['cae', 'ddsa'],
    "caṇḍīkṛta": ['mw'],
    "caṇḍīmāhātmya": ['mw'],
    "caṇḍīpati": ['ddsa', 'mw'],
    "caṇḍīpurāṇa": ['mw'],
    "caṇḍīpāṭha": ['mw'],
    "caṇḍīrahasya": ['mw'],
    "caṇḍīstotra": ['cae', 'mw'],
    "caṇḍīvidhi": ['mw'],
    "caṇḍīvidhāna": ['mw'],
    "caṇḍīvilāsa": ['mw'],
    "caṇḍīśa": ['cae', 'mw'],
    "caṇḍīśaparyākrama": ['mw'],
    "caṇḍīśapurāṇa": ['mw'],
    "caṇḍīśatīrtha": ['mw'],
    "caṇḍīśvara": ['cae', 'mw'],
    "caṇḍīḍāmara": ['mw'],
    "caṣ": ['ap90', 'mw'],
    "caṣaka": ['cae', 'ddsa', 'mw'],
    "caṣakaḥ": ['ap90'],
    "caṣakāya": ['mw'],
    "caṣatiḥ": ['ap90'],
    "caṣāla": ['cae', 'ddsa', 'gra', 'mw'],
    "caṣālamukha": ['mw'],
    "caṣālavat": ['gra', 'mw'],
    "caṣālayūpa": ['mw'],
    "caṣālaḥ": ['ap90'],
    "caṣṭa": ['mw'],
    "caṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "caṭa": ['mw'],
    "caṭacaṭ": ['ddsa'],
    "caṭacaṭa": ['mw'],
    "caṭacaṭā": ['ap90', 'mw'],
    "caṭacaṭāya": ['mw'],
    "caṭacaṭāyana": ['mw'],
    "caṭacaṭāyanaṃ": ['ap90'],
    "caṭacaṭāyate": ['ap90'],
    "caṭacaṭāyita": ['mw'],
    "caṭacaṭāśabda": ['mw'],
    "caṭaccaṭiti": ['mw'],
    "caṭaditi": ['mw'],
    "caṭaka": ['cae', 'ddsa', 'mw'],
    "caṭakakā": ['mw'],
    "caṭakaḥ": ['ap90'],
    "caṭakikā": ['mw'],
    "caṭakā": ['ap90', 'mw'],
    "caṭakāśiras": ['mw'],
    "caṭana": ['mw'],
    "caṭanaṃ": ['ap90'],
    "caṭat": ['mw'],
    "caṭatkāra": ['mw'],
    "caṭatkṛti": ['ddsa', 'mw'],
    "caṭikā": ['mw'],
    "caṭikāśira": ['mw'],
    "caṭikāśiras": ['mw'],
    "caṭita": ['bhs', 'mw'],
    "caṭitaka": ['bhs', 'mw'],
    "caṭu": ['cae', 'ddsa', 'mw'],
    "caṭugrāma": ['mw'],
    "caṭuka": ['mw'],
    "caṭukāra": ['mw'],
    "caṭula": ['ap90', 'cae', 'ddsa', 'mw'],
    "caṭulaya": ['mw'],
    "caṭulita": ['mw'],
    "caṭullola": ['mw'],
    "caṭulola": ['ap90'],
    "caṭulā": ['mw'],
    "caṭulālasa": ['mw'],
    "caṭulāya": ['ddsa', 'mw'],
    "caṭuḥ": ['ap90'],
    "caṭūpamā": ['cae', 'ddsa', 'mw'],
    "caṭṭa": ['mw'],
    "ce": ['cped'],
    "cecca": ['cped'],
    "cecced": ['mw'],
    "ceccet": ['ddsa'],
    "ced": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cedi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cedibhūbhuj": ['mw'],
    "cedibhūbhṛt": ['mw'],
    "cedihūṇa": ['mw'],
    "cedika": ['mw'],
    "cedinagarī": ['mw'],
    "cedipa": ['mw'],
    "cedipati": ['mw'],
    "cedipurī": ['mw'],
    "cedirāj": ['mw'],
    "cedirāja": ['mw'],
    "cedisaṃvat": ['mw'],
    "cediviṣaya": ['mw'],
    "cediḥ": ['ap90'],
    "cedācitta": ['bhs'],
    "cekitāna": ['cae', 'ddsa', 'mw'],
    "cekitānaḥ": ['ap90'],
    "cekriya": ['mw'],
    "cekrīyita": ['mw'],
    "cel": ['ap90', 'mw'],
    "cela": ['cae', 'cped', 'ddsa', 'mw'],
    "celacīrā": ['mw'],
    "celagaṅgā": ['mw'],
    "celaka": ['bhs', 'cped', 'mw'],
    "celakaṇṭhin": ['mw'],
    "celaknopam": ['mw'],
    "celanirṇejaka": ['mw'],
    "celapattikā": ['cped'],
    "celapaṭikā": ['cped'],
    "celaprakṣālaka": ['mw'],
    "celarucikā": ['mw'],
    "celaṃ": ['ap90'],
    "celaṇḍuka": ['cped'],
    "celicīma": ['mw'],
    "celikā": ['ap90', 'mw'],
    "cell": ['ap90', 'mw'],
    "celuka": ['mw'],
    "celukaḥ": ['ap90'],
    "celā": ['bhs'],
    "celāla": ['mw'],
    "celāna": ['mw'],
    "celāpahāra": ['mw'],
    "celāpaka": ['cped'],
    "celāpikā": ['cped'],
    "celāśaka": ['mw'],
    "celīma": ['mw'],
    "cera": ['mw'],
    "ceraka": ['mw'],
    "cerala": ['mw'],
    "cerapāda": ['mw'],
    "ceru": ['cae', 'gra', 'mw'],
    "cet": ['mw'],
    "ceta": ['cped'],
    "ceta(s)": ['cped'],
    "cetaka": ['ap90', 'mw'],
    "cetakhila": ['cped'],
    "cetakī": ['mw'],
    "cetana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cetanabhāva": ['mw'],
    "cetanaka": ['bhs'],
    "cetanakā": ['mw'],
    "cetanakī": ['mw'],
    "cetanatva": ['mw'],
    "cetanatā": ['ddsa', 'mw'],
    "cetanikā": ['mw'],
    "cetanā": ['cped', 'mw'],
    "cetanācetana": ['mw'],
    "cetanāvat": ['ap90', 'mw'],
    "cetanāṣṭaka": ['mw'],
    "cetanī": ['mw'],
    "cetanībhū": ['mw'],
    "cetanīkṛ": ['mw'],
    "cetanīyā": ['mw'],
    "cetapariccañāṇa": ['cped'],
    "cetapariya": ['cped'],
    "cetapariyañāṇa": ['cped'],
    "cetapariyāya": ['cped'],
    "cetapharaṇatā": ['cped'],
    "cetas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cetasa": ['cped'],
    "cetasa ceto paricca": ['cped'],
    "cetasaka": ['mw'],
    "cetasam": ['mw'],
    "cetasika": ['bhs', 'cped'],
    "cetavasippatta": ['cped'],
    "cetavimutta": ['cped'],
    "cetavimutti": ['cped'],
    "cetavimutti(n)": ['cped'],
    "cetavivaraṇasappāya": ['cped'],
    "cetavivaṭṭa": ['cped'],
    "cetavya": ['mw'],
    "cetaya": ['mw'],
    "cetayamāna": ['cped'],
    "cetayati": ['bhs', 'cped'],
    "cetayika": ['bhs'],
    "cetayita": ['cped'],
    "cetayitavya": ['mw'],
    "cetayitvā": ['cped'],
    "cetayitṛ": ['ddsa', 'mw'],
    "cetayāna": ['mw'],
    "cetayī": ['cped'],
    "cetaḥ": ['mw'],
    "cetaḥparyāya": ['bhs'],
    "cetaḥpīḍā": ['mw'],
    "ceteti": ['cped'],
    "ceti": ['bhs'],
    "cetika": ['bhs'],
    "cetiya": ['bhs', 'cped'],
    "cetiyarukkha": ['cped'],
    "cetiā": ['gra'],
    "cetiṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "ceto": ['mw'],
    "cetobhava": ['cae', 'mw'],
    "cetobhū": ['cae', 'ddsa', 'mw'],
    "cetohara": ['mw'],
    "cetomat": ['ap90', 'mw'],
    "cetomukha": ['cae', 'mw'],
    "cetosamādhi": ['bhs'],
    "cetovikāra": ['mw'],
    "cetovikārin": ['mw'],
    "cetovimukta": ['bhs'],
    "cetovimukti": ['bhs'],
    "cettṛ": ['cae', 'gra', 'mw'],
    "cetu": ['cae', 'gra', 'mw'],
    "cetuyā": ['mw'],
    "cetya": ['cped', 'mw'],
    "cetyā": ['gra', 'mw'],
    "cetāpana": ['cped'],
    "cetāpanna": ['cped'],
    "cetāpenta": ['cped'],
    "cetāpesi": ['cped'],
    "cetāpetabba": ['cped'],
    "cetāpeti": ['cped'],
    "cetāpetvā": ['cped'],
    "cetāpita": ['cped'],
    "cetāya": ['mw'],
    "cetī": ['mw'],
    "cetīkṛ": ['mw'],
    "cetṛ": ['cae', 'gra', 'mw'],
    "cevī": ['mw'],
    "ceya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ceḍa": ['mw'],
    "ceḍaka": ['mw'],
    "ceḍaḥ": ['ap90'],
    "ceḍikā": ['mw'],
    "ceḍī": ['mw'],
    "ceṣṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "ceṣṭa": ['cae', 'ddsa', 'mw'],
    "ceṣṭaka": ['ap90', 'mw'],
    "ceṣṭana": ['cae', 'mw'],
    "ceṣṭanaṃ": ['ap90'],
    "ceṣṭayitṛ": ['mw'],
    "ceṣṭaṃ": ['ap90'],
    "ceṣṭita": ['ap90', 'cae', 'mw'],
    "ceṣṭitavya": ['mw'],
    "ceṣṭā": ['ap90', 'mw'],
    "ceṣṭānirūpaṇa": ['mw'],
    "ceṣṭānāśa": ['mw'],
    "ceṣṭāpṛthaktvanivartin": ['mw'],
    "ceṣṭārha": ['mw'],
    "ceṣṭāvant": ['cae'],
    "ceṣṭāvat": ['mw'],
    "ceṭa": ['cae', 'ddsa', 'mw'],
    "ceṭaka": ['cae', 'cped', 'ddsa', 'mw'],
    "ceṭakaḥ": ['ap90'],
    "ceṭaḥ": ['ap90'],
    "ceṭikā": ['ap90', 'mw'],
    "ceṭī": ['mw'],
    "cha": ['ap90', 'cped', 'mw'],
    "cha(d)disā": ['cped'],
    "cha(d)disāpaṭicchādi(n)": ['cped'],
    "cha(m)māsa": ['cped'],
    "cha(m)māsika": ['cped'],
    "cha(p)paññāsā": ['cped'],
    "cha(p)paññāsā(ṁ)": ['cped'],
    "cha(p)paṇṇāsa": ['cped'],
    "chabbaggiya": ['cped'],
    "chabbīsa": ['cped'],
    "chabbīsati": ['cped'],
    "chacattārīsā": ['cped'],
    "chacattāḷīsa(ṁ)": ['cped'],
    "chacchikā": ['mw'],
    "chad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "chada": ['cae', 'ddsa', 'mw'],
    "chadana": ['cae', 'cped', 'mw'],
    "chadapattra": ['mw'],
    "chadaḥ": ['ap90'],
    "chaddhvaṃ": ['bhs'],
    "chadhātura": ['cped'],
    "chadi": ['cae', 'mw'],
    "chadin": ['cae', 'mw'],
    "chadirdarśa": ['mw'],
    "chadis": ['cae', 'gra', 'mw'],
    "chadistṛṇa": ['mw'],
    "chadiḥ": ['ap90'],
    "chadiḥsammita": ['mw'],
    "chadiṣmat": ['mw'],
    "chadma": ['mw'],
    "chadmadyūta": ['mw'],
    "chadmagati": ['mw'],
    "chadmaghātin": ['mw'],
    "chadman": ['ap90', 'cae', 'ddsa', 'mw'],
    "chadmarūpeṇa": ['mw'],
    "chadmarūpin": ['cae', 'ddsa', 'mw'],
    "chadmastha": ['mw'],
    "chadmasthita": ['mw'],
    "chadmatāpasa": ['mw'],
    "chadmavallabha": ['mw'],
    "chadmaveṣa": ['mw'],
    "chadmaveṣin": ['mw'],
    "chadmaṭ": ['mw'],
    "chadmikā": ['mw'],
    "chadmin": ['ap90', 'cae', 'ddsa', 'mw'],
    "chadvara": ['mw'],
    "chaga": ['mw'],
    "chagala": ['cae', 'ddsa', 'mw'],
    "chagalaka": ['mw'],
    "chagalakaḥ": ['ap90'],
    "chagalapāda": ['bhs'],
    "chagalaḥ": ['ap90'],
    "chagalikā": ['mw'],
    "chagalin": ['mw'],
    "chagalā": ['mw'],
    "chagalāntrikā": ['mw'],
    "chagalāntrin": ['mw'],
    "chagalāntrī": ['mw'],
    "chagalāṅghrī": ['mw'],
    "chagalāṇḍa": ['mw'],
    "chagalāṇḍī": ['mw'],
    "chagalī": ['mw'],
    "chagalīpayas": ['mw'],
    "chagaḥ": ['ap90'],
    "chagaṇa": ['mw'],
    "chagaṇaḥ": ['ap90'],
    "chaidika": ['mw'],
    "chaidikaḥ": ['ap90'],
    "chajjū": ['mw'],
    "chaka": ['bhs'],
    "chakalaka": ['cped'],
    "chakana": ['cped'],
    "chakaṇa": ['cped'],
    "chakaṇati": ['cped'],
    "chakka": ['cped'],
    "chakkanipāta": ['cped'],
    "chakkhattuṁ": ['cped'],
    "chakāra": ['mw'],
    "chal": ['mw'],
    "chala": ['cae', 'ddsa', 'mw'],
    "chaladyūta": ['mw'],
    "chalaka": ['ap90', 'mw'],
    "chalakāraka": ['mw'],
    "chalakārin": ['mw'],
    "chalana": ['cae', 'mw'],
    "chalanaṃ": ['ap90'],
    "chalanā": ['mw'],
    "chalanāpara": ['mw'],
    "chalapāta": ['mw'],
    "chalatā": ['mw'],
    "chalavāc": ['mw'],
    "chalay": ['cae'],
    "chalaya": ['ddsa'],
    "chalayati": ['ap90'],
    "chalaḥ": ['ap90'],
    "chalika": ['cae', 'ddsa', 'mw'],
    "chalikaṃ": ['ap90'],
    "chalin": ['ap90', 'mw'],
    "chalita": ['ap90', 'mw'],
    "chalitaka": ['mw'],
    "chalitakayoga": ['mw'],
    "chalitarāma": ['mw'],
    "chalitasvāmin": ['mw'],
    "challa": ['bhs'],
    "challi": ['mw'],
    "challita": ['mw'],
    "challiḥ": ['ap90'],
    "challī": ['mw'],
    "chalokti": ['mw'],
    "chalā": ['mw'],
    "chalākṣarasūtra": ['mw'],
    "cham": ['ap90', 'mw'],
    "chamacchamikāratna": ['mw'],
    "chamacchamita": ['ap90', 'mw'],
    "chamaṃḍaḥ": ['ap90'],
    "chamaṇḍa": ['mw'],
    "chamaṇḍala": ['mw'],
    "chambati": ['bhs'],
    "chambaṃkāram": ['mw'],
    "chambaṭ": ['mw'],
    "chambaṭkara": ['mw'],
    "chambaṭkāra": ['mw'],
    "chambaṭkāram": ['mw'],
    "chambaṭkṛ": ['mw'],
    "chambhati": ['cped'],
    "chambhi(n)": ['cped'],
    "chambhin": ['bhs'],
    "chambhita": ['bhs', 'cped'],
    "chambhitatta": ['cped'],
    "chambhitatva": ['bhs'],
    "chambin": ['bhs'],
    "chambitatva": ['bhs'],
    "champ": ['mw'],
    "champaṇa": ['mw'],
    "chamā": ['cped'],
    "chamānikhitta": ['cped'],
    "chamānikiṇṇa": ['cped'],
    "chamāya(ṁ)": ['cped'],
    "chamāṁ": ['cped'],
    "chamūlaka": ['cped'],
    "chana": ['bhs'],
    "chanacchan": ['ap90'],
    "chanacchaniti": ['ddsa', 'mw'],
    "chand": ['cae', 'ddsa', 'gra', 'mw'],
    "chanda": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "chanda(s)": ['cped'],
    "chandacārin": ['mw'],
    "chandagami(n)": ['cped'],
    "chandagati": ['mw'],
    "chandahānis": ['mw'],
    "chandaja": ['mw'],
    "chandaka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "chandakanivartana": ['bhs', 'mw'],
    "chandakapātana": ['mw'],
    "chandamṛtyu": ['mw'],
    "chandana": ['cae', 'mw'],
    "chandapraśasti": ['mw'],
    "chandapātana": ['mw'],
    "chandarāga": ['cped'],
    "chandas": ['cae', 'ddsa', 'gra', 'mw'],
    "chandasa": ['cped'],
    "chandasia": ['gra'],
    "chandasikā": ['mw'],
    "chandaska": ['mw'],
    "chandaskṛta": ['cae', 'mw'],
    "chandaspakṣa": ['mw'],
    "chandastva": ['mw'],
    "chandasvant": ['cae'],
    "chandasvat": ['mw'],
    "chandasvinī": ['bhs'],
    "chandasya": ['cae', 'gra', 'mw'],
    "chandasyā": ['mw'],
    "chandatas": ['mw'],
    "chandavāsinī": ['cped'],
    "chandayācaka": ['bhs'],
    "chandaś": ['mw'],
    "chandaścit": ['mw'],
    "chandaścūḍāmaṇi": ['mw'],
    "chandaḥ": ['mw'],
    "chandaḥkalpa": ['mw'],
    "chandaḥkalpalatā": ['mw'],
    "chandaḥprakaraṇa": ['mw'],
    "chandaḥprakāśa": ['mw'],
    "chandaḥpratiṣṭhāna": ['mw'],
    "chandaḥpraśasti": ['mw'],
    "chandaḥpuruṣa": ['mw'],
    "chandaḥsaṃgraha": ['mw'],
    "chandaḥsiddhi": ['mw'],
    "chandaḥstubh": ['cae', 'gra', 'mw'],
    "chandaḥstut": ['cae', 'mw'],
    "chandaḥsudhākara": ['mw'],
    "chandaḥsāra": ['mw'],
    "chandaḥsūtra": ['cae', 'mw'],
    "chandaḥśāstra": ['cae', 'mw'],
    "chandena": ['cped', 'mw'],
    "chandi(n)": ['cped'],
    "chandia": ['gra'],
    "chandika": ['bhs', 'cped'],
    "chandikata": ['cped'],
    "chandita": ['mw'],
    "chando": ['mw'],
    "chandobaddha": ['mw'],
    "chandobhaṅgavat": ['mw'],
    "chandobhāga": ['mw'],
    "chandobhāṣya": ['mw'],
    "chandobhāṣā": ['mw'],
    "chandodeva": ['mw'],
    "chandodevī": ['mw'],
    "chandodīpikā": ['mw'],
    "chandoga": ['cae', 'ddsa', 'mw'],
    "chandogabrāhmaṇa": ['mw'],
    "chandogamāhaki": ['mw'],
    "chandogapaddhati": ['mw'],
    "chandogapariśiṣṭa": ['mw'],
    "chandogasopāna": ['mw'],
    "chandogavṛṣotsargatattva": ['mw'],
    "chandogaśruti": ['mw'],
    "chandogaśrāddhatattvapramāṇa": ['mw'],
    "chandogaśākhā": ['mw'],
    "chandogovinda": ['mw'],
    "chandograntha": ['mw'],
    "chandogāhnikapaddhati": ['mw'],
    "chandoka": ['cped'],
    "chandoma": ['ddsa', 'mw'],
    "chandomadaśarātra": ['mw'],
    "chandomadaśāha": ['mw'],
    "chandomapavamānatrirātra": ['mw'],
    "chandomatrikakud": ['mw'],
    "chandomavat": ['mw'],
    "chandomavatparāka": ['mw'],
    "chandomaya": ['cae', 'mw'],
    "chandomañjari": ['cae', 'mw'],
    "chandomañjarī": ['cae', 'mw'],
    "chandomālā": ['mw'],
    "chandomāna": ['mw'],
    "chandomārtaṇḍa": ['mw'],
    "chandonuvṛtta": ['mw'],
    "chandonuśāsanavṛtti": ['mw'],
    "chandonāma": ['mw'],
    "chandonāman": ['mw'],
    "chandopahārāvali": ['mw'],
    "chandoratnākara": ['mw'],
    "chandoruṭstoma": ['mw'],
    "chandorūpa": ['mw'],
    "chandovatī": ['mw'],
    "chandoviciti": ['cae', 'mw'],
    "chandovivṛti": ['mw'],
    "chandovṛtta": ['cae', 'mw'],
    "chandu": ['cae', 'gra', 'mw'],
    "chandya": ['cae', 'mw'],
    "chandāgati": ['cped'],
    "chandānidāna": ['cped'],
    "chandānugāmin": ['ddsa', 'mw'],
    "chandānunīta": ['cped'],
    "chandānuvartin": ['mw'],
    "chandānuvṛtta": ['mw'],
    "chandāraha": ['cped'],
    "chandārhin": ['bhs'],
    "chandāt": ['mw'],
    "chandāva": ['cped'],
    "chandīka": ['cped'],
    "channa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "channadaśa": ['bhs'],
    "channam": ['mw'],
    "channe": ['mw'],
    "chapaka": ['cped'],
    "chapakī": ['cped'],
    "chaphassāyatanika": ['cped'],
    "chaporisa": ['cped'],
    "chappañca": ['cped'],
    "chappañcavassika": ['cped'],
    "chard": ['ap90', 'ddsa'],
    "charda": ['mw'],
    "chardana": ['cae', 'ddsa', 'mw'],
    "chardanīya": ['mw'],
    "chardayitavya": ['mw'],
    "chardaḥ": ['ap90'],
    "chardi": ['mw'],
    "chardighna": ['mw'],
    "chardikā": ['mw'],
    "chardikāripu": ['mw'],
    "chardis": ['ap90', 'cae', 'gra', 'mw'],
    "chardita": ['mw'],
    "chardiṣpā": ['gra', 'mw'],
    "chardyāyanikā": ['mw'],
    "chardyāyanī": ['mw'],
    "chardāpanīkā": ['mw'],
    "chasahassa": ['cped'],
    "chasamannāgata": ['cped'],
    "chasattati": ['cped'],
    "chatra": ['cped'],
    "chatrakaḥ": ['ap90'],
    "chatraḥ": ['ap90'],
    "chatrikaḥ": ['ap90'],
    "chatrin": ['ap90'],
    "chatrā": ['ap90'],
    "chatta": ['cped'],
    "chattaka": ['cped'],
    "chattanāḷi": ['cped'],
    "chattappagahita": ['cped'],
    "chattapāṇī": ['cped'],
    "chattiṁsa": ['cped'],
    "chattiṁsaka": ['cped'],
    "chattiṁsakkhattuṁ": ['cped'],
    "chattiṁsati": ['cped'],
    "chattiṁsatī": ['cped'],
    "chattiṁsā": ['cped'],
    "chattra": ['cae', 'mw'],
    "chattrabhaṅga": ['mw'],
    "chattracakra": ['mw'],
    "chattradhānya": ['mw'],
    "chattradhāra": ['cae', 'mw'],
    "chattradhāratva": ['mw'],
    "chattradhāraṇa": ['cae', 'mw'],
    "chattradhārin": ['cae', 'mw'],
    "chattragrāhiṇī": ['mw'],
    "chattraguccha": ['mw'],
    "chattragṛha": ['mw'],
    "chattrahaya": ['mw'],
    "chattraka": ['bhs', 'mw'],
    "chattramukhā": ['bhs', 'mw'],
    "chattrapa": ['mw'],
    "chattraparṇa": ['mw'],
    "chattrapati": ['mw'],
    "chattrapattra": ['mw'],
    "chattrapuṣpaka": ['mw'],
    "chattrasiṃha": ['mw'],
    "chattrasāla": ['mw'],
    "chattravant": ['cae'],
    "chattravat": ['mw'],
    "chattravatī": ['mw'],
    "chattravṛkṣa": ['cae', 'mw'],
    "chattrayukti": ['mw'],
    "chattrika": ['mw'],
    "chattrikā": ['mw'],
    "chattrin": ['cae', 'mw'],
    "chattrinyāya": ['mw'],
    "chattriṇa": ['mw'],
    "chattropānaha": ['cae', 'mw'],
    "chattrā": ['mw'],
    "chattrādi": ['mw'],
    "chattrāka": ['cae', 'mw'],
    "chattrākāra": ['bhs'],
    "chattrākāraśiras": ['mw'],
    "chattrākī": ['mw'],
    "chattrāticchattra": ['mw'],
    "chattrāticchattrā": ['mw'],
    "chattrī": ['mw'],
    "chattrīkṛ": ['mw'],
    "chattvara": ['mw'],
    "chatvaraḥ": ['ap90'],
    "chatāla": ['cped'],
    "chat‍trāka": ['ddsa'],
    "chat‍‍‍tra": ['ddsa'],
    "chat‍‍‍trīkṛ": ['ddsa'],
    "chautu": ['mw'],
    "chava": ['bhs', 'cped'],
    "chavadussa": ['cped'],
    "chavadāhaka": ['cped'],
    "chavaka": ['cped'],
    "chavakuṭikā": ['cped'],
    "chavasisa": ['cped'],
    "chavasitta": ['cped'],
    "chavaḍāhaka": ['cped'],
    "chavaṭṭhika": ['cped'],
    "chavi": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "chavillākara": ['ddsa', 'mw'],
    "chaviḥ": ['ap90'],
    "chavālāta": ['cped'],
    "chavī": ['mw'],
    "chayika": ['bhs'],
    "chayojanasatika": ['cped'],
    "chayojanika": ['cped'],
    "chaḍī": ['mw'],
    "chaḍḍalikā": ['mw'],
    "chaḍḍanīyadhamma": ['cped'],
    "chaḍḍayati": ['cped'],
    "chaḍḍayitvāna": ['cped'],
    "chaḍḍenta": ['cped'],
    "chaḍḍesi": ['cped'],
    "chaḍḍesuṁ": ['cped'],
    "chaḍḍetabba": ['cped'],
    "chaḍḍeti": ['bhs', 'cped'],
    "chaḍḍetuṁ": ['cped'],
    "chaḍḍetvā": ['cped'],
    "chaḍḍita": ['cped'],
    "chaḍḍitapaccaya": ['cped'],
    "chaḍḍiya": ['cped'],
    "chaḍḍiyadhamma": ['cped'],
    "chaḍḍāpeti": ['cped'],
    "chaḍḍīyati": ['cped'],
    "chaḍḍīyyati": ['cped'],
    "chaḍḍūna": ['cped'],
    "chaḷ": ['cped'],
    "chaḷabhiñña": ['cped'],
    "chaṃd": ['ap90'],
    "chaṃda": ['ap90'],
    "chaṃdakaḥ": ['ap90'],
    "chaṃdana": ['ap90'],
    "chaṃdas": ['ap90'],
    "chaṃdasya": ['ap90'],
    "chaṃdita": ['ap90'],
    "chaṃdu": ['ap90'],
    "chaṃp": ['ap90'],
    "chaṇa": ['cped'],
    "chaṇḍikā": ['bhs'],
    "chaṣ": ['ap90', 'mw'],
    "chaṭa": ['bhs'],
    "chaṭachaṭā": ['bhs'],
    "chaṭā": ['ap90', 'cae', 'ddsa', 'mw'],
    "chaṭābhā": ['mw'],
    "chaṭāphala": ['mw'],
    "chaṭṭayati": ['cped'],
    "chaṭṭeti": ['cped'],
    "chaṭṭha": ['cped'],
    "checchati": ['cped'],
    "cheda": ['bhs', 'cae', 'ddsa', 'mw'],
    "chedagama": ['mw'],
    "chedagāmi(n)": ['cped'],
    "chedaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "chedakara": ['mw'],
    "chedana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "chedanabandhana": ['cped'],
    "chedanaka": ['cped'],
    "chedanā": ['cped'],
    "chedanīya": ['cae', 'mw'],
    "chedaḥ": ['ap90'],
    "chedetabba": ['cped'],
    "chedetvā": ['cped'],
    "chedi": ['ap90', 'mw'],
    "chedin": ['ap90', 'cae', 'mw'],
    "chedita": ['ap90', 'mw'],
    "cheditavya": ['mw'],
    "chedopasthāpanīya": ['mw'],
    "chedya": ['ap90', 'bhs', 'cae', 'mw'],
    "chedyaka": ['mw'],
    "chedyakādhyāya": ['mw'],
    "chedādi": ['mw'],
    "chedāpaya(t)": ['cped'],
    "chedāpayati": ['cped'],
    "chedāpayitvāna": ['cped'],
    "chedāpenta": ['cped'],
    "chedāpesi": ['cped'],
    "chedāpetabba": ['cped'],
    "chedāpeti": ['cped'],
    "chedāpetvā": ['cped'],
    "chedāpita": ['cped'],
    "chedī": ['mw'],
    "chejja": ['cped'],
    "chejjabhejja": ['cped'],
    "chejjavatthu": ['cped'],
    "chejjā": ['cped'],
    "cheka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "chekala": ['mw'],
    "chekila": ['mw'],
    "chekokti": ['cae', 'mw'],
    "chekāla": ['ap90', 'mw'],
    "chekānuprāsa": ['mw'],
    "chelaka": ['cae', 'ddsa', 'mw'],
    "chelakaḥ": ['ap90'],
    "chelikā": ['mw'],
    "chelu": ['mw'],
    "chemaṃḍaḥ": ['ap90'],
    "chemaṇḍa": ['mw'],
    "chemuṇḍā": ['mw'],
    "cheppa": ['mw'],
    "cheppā": ['cped'],
    "cheta(r)": ['cped'],
    "chetabba": ['cped'],
    "chetta(r)": ['cped'],
    "chettabba": ['cped'],
    "chettavya": ['cae', 'ddsa', 'mw'],
    "chettuṁ": ['cped'],
    "chettṛ": ['ap90', 'cae', 'mw'],
    "chetuṁ": ['cped'],
    "chetvā": ['cped'],
    "chetvāna": ['cped'],
    "chi": ['mw'],
    "chid": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "chida": ['mw'],
    "chidaka": ['mw'],
    "chidakaṃ": ['ap90'],
    "chidda": ['cped'],
    "chiddakarin": ['cped'],
    "chiddava(t)": ['cped'],
    "chiddāvacchidda": ['cped'],
    "chidi": ['mw'],
    "chidira": ['mw'],
    "chidiraḥ": ['ap90'],
    "chidiḥ": ['ap90'],
    "chidra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "chidradarśana": ['mw'],
    "chidradarśin": ['mw'],
    "chidradātṛtva": ['mw'],
    "chidrakarṇa": ['mw'],
    "chidrapippalī": ['mw'],
    "chidratā": ['mw'],
    "chidravaidehī": ['mw'],
    "chidray": ['cae'],
    "chidraya": ['ddsa', 'mw'],
    "chidrayati": ['ap90'],
    "chidrin": ['cae', 'ddsa', 'mw'],
    "chidrita": ['ap90', 'mw'],
    "chidrodara": ['mw'],
    "chidrodarin": ['mw'],
    "chidrāchidra": ['bhs'],
    "chidrāntar": ['mw'],
    "chidrānusaṃdhānin": ['mw'],
    "chidrānusārin": ['cae', 'ddsa', 'mw'],
    "chidrānveṣaṇa": ['mw'],
    "chidrānveṣin": ['mw'],
    "chidrānvita": ['mw'],
    "chidrāpaya": ['mw'],
    "chidrāphala": ['mw'],
    "chidrātman": ['mw'],
    "chidrāṃśa": ['mw'],
    "chidrīkaraṇa": ['bhs'],
    "chidrīkaroti": ['bhs'],
    "chidrīkāra": ['bhs'],
    "chidura": ['ap90', 'cae', 'ddsa', 'mw'],
    "chiduretara": ['mw'],
    "chidvara": ['ap90', 'mw'],
    "chidā": ['ap90', 'mw'],
    "chiggala": ['cped'],
    "chiggaḷa": ['cped'],
    "chijjamāna": ['cped'],
    "chijjatha": ['cped'],
    "chijjati": ['cped'],
    "chikkana": ['mw'],
    "chikkanī": ['mw'],
    "chikkara": ['cae', 'ddsa', 'mw'],
    "chikkika": ['mw'],
    "chikkikā": ['mw'],
    "chikkā": ['ap90', 'cae', 'ddsa', 'mw'],
    "chikkākāraka": ['mw'],
    "chikkāra": ['cae', 'ddsa', 'mw'],
    "chilihiṇḍa": ['mw'],
    "chinda(t)": ['cped'],
    "chindaka": ['mw'],
    "chindanta": ['cped'],
    "chindati": ['cped'],
    "chindatprāṇi": ['mw'],
    "chindi": ['cped'],
    "chindita": ['cped'],
    "chindita(r)": ['cped'],
    "chindituṁ": ['cped'],
    "chinditvā": ['cped'],
    "chindiya": ['cped'],
    "chindiṁsu": ['cped'],
    "chinna": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "chinnababbhara": ['cped'],
    "chinnabandhana": ['mw'],
    "chinnabhabbhara": ['cped'],
    "chinnabhakta": ['bhs', 'mw'],
    "chinnabhinna": ['mw'],
    "chinnabhūyiṣṭhadhūma": ['mw'],
    "chinnadhanvan": ['mw'],
    "chinnadruma": ['mw'],
    "chinnadvaidha": ['cae', 'mw'],
    "chinnagranthinikā": ['mw'],
    "chinnahasta": ['mw'],
    "chinnaka": ['cped', 'mw'],
    "chinnakarṇa": ['mw'],
    "chinnakatara": ['mw'],
    "chinnakeśa": ['mw'],
    "chinnama": ['mw'],
    "chinnamastakā": ['mw'],
    "chinnamastakīkṛ": ['mw'],
    "chinnamastā": ['mw'],
    "chinnamūla": ['cae', 'mw'],
    "chinnamūlaka": ['cped'],
    "chinnanāsa": ['mw'],
    "chinnanāsya": ['cae', 'mw'],
    "chinnapakṣa": ['cae', 'mw'],
    "chinnapapātaṁ": ['cped'],
    "chinnapattrī": ['mw'],
    "chinnapilotika": ['cped'],
    "chinnapātaṁ": ['cped'],
    "chinnaruha": ['mw'],
    "chinnaruhā": ['mw'],
    "chinnasassara": ['cped'],
    "chinnasaṃśaya": ['cae', 'mw'],
    "chinnasota": ['cped'],
    "chinnasthūṇa": ['mw'],
    "chinnataraka": ['mw'],
    "chinnavat": ['mw'],
    "chinnavaṭuma": ['cped'],
    "chinnaveṣikā": ['mw'],
    "chinnavārṣika": ['bhs'],
    "chinnaśāsa": ['mw'],
    "chinniriyāpatha": ['cped'],
    "chinnodbhavā": ['mw'],
    "chinnā": ['mw'],
    "chinnābhra": ['cae', 'mw'],
    "chinnāntra": ['mw'],
    "chippikā": ['mw'],
    "chismaka": ['mw'],
    "chita": ['ap90', 'ddsa', 'mw'],
    "chittapa": ['mw'],
    "chitti": ['mw'],
    "chittiḥ": ['ap90'],
    "chittvara": ['mw'],
    "chitvara": ['ap90'],
    "chitvāsuta": ['bhs'],
    "chiḥ": ['ap90'],
    "chiṭi": ['bhs', 'mw'],
    "cho": ['ap90', 'mw'],
    "choja": ['ddsa', 'mw'],
    "cholaṃgaḥ": ['ap90'],
    "cholaṅga": ['mw'],
    "chorayati": ['bhs'],
    "choraṇa": ['bhs', 'mw'],
    "choraṇaṃ": ['ap90'],
    "chorita": ['mw'],
    "choḍayati": ['bhs'],
    "choṭana": ['cae', 'ddsa', 'mw'],
    "choṭi": ['mw'],
    "choṭikā": ['ap90', 'cae', 'mw'],
    "choṭin": ['ap90', 'mw'],
    "choṭita": ['mw'],
    "chubuka": ['cae', 'ddsa', 'gra', 'mw'],
    "chubukaṃ": ['ap90'],
    "chucchu": ['cae', 'ddsa', 'mw'],
    "chucchukabhaṭṭa": ['mw'],
    "chucchundara": ['cae', 'ddsa', 'mw'],
    "chucchundari": ['cae', 'mw'],
    "chucchundarī": ['mw'],
    "chucchūndara": ['cae', 'ddsa'],
    "chuchuṃdaraḥ": ['ap90'],
    "chuddha": ['cped'],
    "chuddhūna": ['cped'],
    "chudra": ['mw'],
    "chudraṃ": ['ap90'],
    "chup": ['ap90', 'mw'],
    "chupa": ['mw'],
    "chupana": ['cped'],
    "chupanta": ['cped'],
    "chupati": ['cped'],
    "chupaḥ": ['ap90'],
    "chupi": ['cped'],
    "chupita": ['cped'],
    "chupitabba": ['cped'],
    "chur": ['ap90', 'cae', 'ddsa', 'mw'],
    "churaṇa": ['mw'],
    "churaṇaṃ": ['ap90'],
    "churikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "churikābandhaprayoga": ['mw'],
    "churikāphala": ['mw'],
    "churita": ['ap90', 'mw'],
    "churā": ['ap90', 'mw'],
    "churī": ['ap90', 'mw'],
    "chuḍ": ['ap90', 'cae', 'ddsa', 'mw'],
    "chuḍḍa": ['ddsa', 'mw'],
    "chuḍḍā": ['mw'],
    "chuḍḍūna": ['cped'],
    "chuṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "chuṭī": ['bhs'],
    "chuṭṭa": ['bhs'],
    "chyu": ['ap90', 'mw'],
    "chā": ['cae', 'ddsa', 'mw'],
    "chāchikā": ['mw'],
    "chāda": ['bhs', 'mw'],
    "chādaka": ['cae', 'ddsa', 'mw'],
    "chādana": ['cae', 'cped', 'mw'],
    "chādanaṃ": ['ap90'],
    "chādapeti": ['cped'],
    "chādayati": ['bhs', 'cped'],
    "chādayitvāna": ['cped'],
    "chādaṃ": ['ap90'],
    "chādenta": ['cped'],
    "chādesi": ['cped'],
    "chādetabba": ['cped'],
    "chādeti": ['cped'],
    "chādetvā": ['cped'],
    "chādin": ['cae', 'mw'],
    "chādinī": ['mw'],
    "chādita": ['ap90', 'mw'],
    "chādiṣeya": ['mw'],
    "chādmika": ['ap90', 'cae', 'ddsa', 'mw'],
    "chādya": ['mw'],
    "chādīyati": ['cped'],
    "chāga": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "chāgaka": ['mw'],
    "chāgakarṇa": ['mw'],
    "chāgala": ['ap90', 'cae', 'mw'],
    "chāgalaka": ['bhs', 'mw'],
    "chāgalakṣaṇa": ['mw'],
    "chāgaleya": ['mw'],
    "chāgaleyin": ['mw'],
    "chāgali": ['mw'],
    "chāgalānta": ['mw'],
    "chāgalāntrikā": ['mw'],
    "chāgalāntrin": ['mw'],
    "chāgalāntrī": ['mw'],
    "chāgalāṇḍa": ['mw'],
    "chāgamaya": ['mw'],
    "chāgamitra": ['mw'],
    "chāgamitrika": ['mw'],
    "chāgamukha": ['mw'],
    "chāgamāṃsa": ['cae', 'mw'],
    "chāganāśana": ['mw'],
    "chāgaratha": ['mw'],
    "chāgaromamaya": ['mw'],
    "chāgavya": ['mw'],
    "chāgavāhana": ['mw'],
    "chāgaśatru": ['mw'],
    "chāgaṇa": ['mw'],
    "chāgaṇaḥ": ['ap90'],
    "chāgeya": ['mw'],
    "chāgikā": ['ap90', 'mw'],
    "chāgyāyani": ['mw'],
    "chāgā": ['mw'],
    "chāgī": ['mw'],
    "chāgīkṣīranāśa": ['mw'],
    "chāhapaṭicchanna": ['cped'],
    "chāla": ['mw'],
    "chālaḥ": ['ap90'],
    "chālikya": ['cae', 'ddsa', 'mw'],
    "chānda": ['mw'],
    "chāndasa": ['cae', 'ddsa', 'mw'],
    "chāndasabaṭhara": ['mw'],
    "chāndasaka": ['mw'],
    "chāndasatva": ['mw'],
    "chāndasatā": ['mw'],
    "chāndasīya": ['mw'],
    "chāndaḍa": ['mw'],
    "chāndobhāṣa": ['mw'],
    "chāndoga": ['mw'],
    "chāndogabrāhmaṇa": ['mw'],
    "chāndogasūtra": ['mw'],
    "chāndogeya": ['mw'],
    "chāndogi": ['mw'],
    "chāndogika": ['mw'],
    "chāndogya": ['cae', 'ddsa', 'mw'],
    "chāndogyabhāṣya": ['mw'],
    "chāndogyabrāhmaṇa": ['cae', 'mw'],
    "chāndogyamantrabhāṣya": ['mw'],
    "chāndogyaveda": ['mw'],
    "chāndogyopaniṣad": ['cae', 'mw'],
    "chāndogyopaniṣadbhāṣya": ['mw'],
    "chāndoma": ['mw'],
    "chāndomika": ['mw'],
    "chāndomāna": ['mw'],
    "chāndovicita": ['mw'],
    "chāpa": ['cped'],
    "chāpi": ['cped'],
    "chāratta": ['cped'],
    "chārattaparamaṁ": ['cped'],
    "chārattaṁ": ['cped'],
    "chārattūna": ['cped'],
    "chārikā": ['cped'],
    "chāta": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "chātrakaṃ": ['ap90'],
    "chātraḥ": ['ap90'],
    "chāttra": ['cae', 'mw'],
    "chāttradarśana": ['mw'],
    "chāttragaṇḍa": ['mw'],
    "chāttragomin": ['mw'],
    "chāttraka": ['bhs', 'mw'],
    "chāttramitra": ['mw'],
    "chāttranilaya": ['mw'],
    "chāttrapriya": ['mw'],
    "chāttratā": ['mw'],
    "chāttravyaṃsaka": ['mw'],
    "chāttri": ['mw'],
    "chāttrikya": ['mw'],
    "chāttriśāla": ['mw'],
    "chāttriśālā": ['mw'],
    "chāttryādi": ['mw'],
    "chāt‍tra": ['ddsa'],
    "chāya": ['bhs', 'cae', 'ddsa', 'mw'],
    "chāyaka": ['mw'],
    "chāyika": ['bhs'],
    "chāyā": ['ap90', 'cped', 'gra', 'mw'],
    "chāyābhartṛ": ['mw'],
    "chāyābhinna": ['mw'],
    "chāyābhṛt": ['mw'],
    "chāyādruma": ['cae', 'mw'],
    "chāyādvitīya": ['cae', 'mw'],
    "chāyāgraha": ['ddsa', 'mw'],
    "chāyāgrāha": ['mw'],
    "chāyākara": ['mw'],
    "chāyāmaya": ['ap90', 'cae', 'mw'],
    "chāyāmitra": ['mw'],
    "chāyāmāna": ['mw'],
    "chāyāmṛgadhara": ['mw'],
    "chāyānaṭṭa": ['mw'],
    "chāyānāṭaka": ['cae', 'mw'],
    "chāyāpatha": ['mw'],
    "chāyāpiṅga": ['mw'],
    "chāyāpuruṣa": ['mw'],
    "chāyāsaṃjñā": ['cae', 'mw'],
    "chāyāsuta": ['mw'],
    "chāyātanaya": ['mw'],
    "chāyātapa": ['cae'],
    "chāyātaru": ['cae', 'mw'],
    "chāyātmaja": ['mw'],
    "chāyātman": ['mw'],
    "chāyātoḍī": ['mw'],
    "chāyāvant": ['cae'],
    "chāyāvat": ['mw'],
    "chāyāvyavahāra": ['mw'],
    "chāyāvṛkṣa": ['mw'],
    "chāyāyantra": ['mw'],
    "chāyāṅka": ['mw'],
    "chāṃdasa": ['ap90'],
    "chāṃdasīya": ['ap90'],
    "chāṃdomika": ['ap90'],
    "chāṇaka": ['mw'],
    "chāṭā": ['mw'],
    "chūrikā": ['cae', 'cped', 'ddsa', 'mw'],
    "chūrikāpattrī": ['mw'],
    "chūrī": ['mw'],
    "chṛd": ['ap90', 'cae', 'ddsa', 'mw'],
    "chṛp": ['mw'],
    "chṛṣ": ['ap90'],
    "ci": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cibi": ['mw'],
    "cibu": ['mw'],
    "cibuka": ['cae', 'ddsa', 'mw'],
    "cibukaṃ": ['ap90'],
    "cic": ['mw'],
    "cicaliṣu": ['ddsa', 'mw'],
    "cicariṣu": ['ddsa', 'mw'],
    "cicca": ['bhs'],
    "ciccandrikā": ['mw'],
    "cicchaka": ['bhs'],
    "cicchakti": ['ddsa', 'mw'],
    "cicchila": ['mw'],
    "cicchilāḥ": ['ap90'],
    "cicchitsu": ['mw'],
    "cicchuka": ['mw'],
    "cicchukī": ['mw'],
    "ciccika": ['cae', 'ddsa', 'gra', 'mw'],
    "cicciṭi": ['cped'],
    "cicciṭiṅga": ['mw'],
    "cicciṭāti": ['cped'],
    "cicciṭāyati": ['cped'],
    "ciciṃḍaḥ": ['ap90'],
    "ciciṇḍa": ['mw'],
    "cicīkucī": ['mw'],
    "cicīkūcī": ['mw'],
    "cicīṣat": ['mw'],
    "cid": ['cae', 'ddsa', 'gra', 'mw'],
    "cidacicchaktiyukta": ['mw'],
    "cidacinmaya": ['mw'],
    "cidacit": ['mw'],
    "cidambara": ['mw'],
    "cidambarapura": ['mw'],
    "cidambararahasya": ['mw'],
    "cidambarasthala": ['mw'],
    "cidasthimālā": ['mw'],
    "cidgaganacandrikā": ['mw'],
    "cidghana": ['mw'],
    "cidratha": ['mw'],
    "cidrathī": ['mw'],
    "cidratnacaṣaka": ['mw'],
    "cidrūpa": ['mw'],
    "cidrūpatva": ['mw'],
    "cidullāsa": ['mw'],
    "cidvilāsa": ['mw'],
    "cidvṛtti": ['mw'],
    "cidānanda": ['mw'],
    "cidānandadaśaślokī": ['mw'],
    "cidānandamaya": ['mw'],
    "cidānandastavarāja": ['mw'],
    "cidānandāśrama": ['mw'],
    "cidātmaka": ['mw'],
    "cidātman": ['ddsa', 'mw'],
    "cihacihābhinadita": ['cped'],
    "cihaṇa": ['ap90', 'mw'],
    "cihaṇakantha": ['mw'],
    "cihn": ['ap90'],
    "cihna": ['cae', 'mw'],
    "cihnabhūta": ['mw'],
    "cihnadhara": ['bhs', 'mw'],
    "cihnadhāriṇī": ['mw'],
    "cihnaka": ['mw'],
    "cihnakārin": ['mw'],
    "cihnana": ['mw'],
    "cihnay": ['cae'],
    "cihnaya": ['mw'],
    "cihnayitavya": ['mw'],
    "cihnaṃ": ['ap90'],
    "cihnita": ['ap90', 'mw'],
    "cihnīkṛta": ['mw'],
    "cihura": ['ap90', 'mw'],
    "cikariṣu": ['mw'],
    "cikartiṣu": ['mw'],
    "cikartiṣā": ['ddsa', 'mw'],
    "cikaśa": ['mw'],
    "ciketas": ['cae', 'mw'],
    "cikhalla": ['mw'],
    "cikhallaḥ": ['ap90'],
    "cikhalli": ['mw'],
    "cikhyāpayiṣā": ['mw'],
    "cikhādiṣu": ['mw'],
    "cikila": ['mw'],
    "cikilaḥ": ['ap90'],
    "cikina": ['ap90', 'mw'],
    "cikit": ['cae', 'ddsa', 'gra', 'mw'],
    "cikita": ['ap90', 'mw'],
    "cikiti": ['cae', 'mw'],
    "cikits": ['cae'],
    "cikitsa": ['ddsa'],
    "cikitsaka": ['cae', 'mw'],
    "cikitsakaḥ": ['ap90'],
    "cikitsana": ['cae', 'mw'],
    "cikitsanaṃ": ['ap90'],
    "cikitsanīya": ['mw'],
    "cikitsikā": ['bhs'],
    "cikitsita": ['ap90', 'mw'],
    "cikitsu": ['mw'],
    "cikitsya": ['mw'],
    "cikitsā": ['ap90', 'mw'],
    "cikitsādarpaṇa": ['mw'],
    "cikitsājñāna": ['mw'],
    "cikitsākalikā": ['mw'],
    "cikitsākalikāṭīkā": ['mw'],
    "cikitsākaumudī": ['mw'],
    "cikitsāparatantra": ['mw'],
    "cikitsāprābhṛta": ['mw'],
    "cikitsātattvajñāna": ['mw'],
    "cikitsāśāstra": ['mw'],
    "cikitu": ['ap90', 'cae', 'gra', 'mw'],
    "cikitvan": ['ap90', 'cae', 'gra', 'mw'],
    "cikitvas": ['ap90', 'ddsa', 'mw'],
    "cikitvaṃs": ['cae'],
    "cikitvinmanas": ['gra', 'mw'],
    "cikitvit": ['ap90', 'gra', 'mw'],
    "cikitāna": ['ap90', 'mw'],
    "cikitāyana": ['mw'],
    "cikk": ['ap90', 'mw'],
    "cikka": ['ap90', 'bhs', 'mw'],
    "cikkasa": ['mw'],
    "cikkasaḥ": ['ap90'],
    "cikkaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "cikkaṇakantha": ['mw'],
    "cikkaṇatva": ['mw'],
    "cikkaṇatā": ['mw'],
    "cikkaṇā": ['ap90', 'mw'],
    "cikkhalla": ['cped'],
    "cikkira": ['mw'],
    "cikkiraḥ": ['ap90'],
    "cikkiṇa": ['ap90', 'mw'],
    "cikkiṇā": ['mw'],
    "cikkā": ['mw'],
    "ciklida": ['mw'],
    "ciklidaṃ": ['ap90'],
    "cikraṃsā": ['mw'],
    "cikrīḍiṣu": ['mw'],
    "cikrīḍiṣā": ['mw'],
    "cikura": ['ap90', 'cae', 'ddsa', 'mw'],
    "cikurabhāra": ['mw'],
    "cikurahasta": ['mw'],
    "cikurakalāpa": ['mw'],
    "cikuranikara": ['mw'],
    "cikurapakṣa": ['mw'],
    "cikurapāśa": ['mw'],
    "cikuraracanā": ['mw'],
    "cikurita": ['mw'],
    "cikuroccaya": ['mw'],
    "cikāriṣu": ['mw'],
    "cikīraṣā": ['mw'],
    "cikīrṣ": ['cae', 'mw'],
    "cikīrṣa": ['ddsa'],
    "cikīrṣaka": ['ap90', 'mw'],
    "cikīrṣita": ['ap90', 'cae', 'mw'],
    "cikīrṣu": ['ap90', 'cae', 'mw'],
    "cikīrṣuka": ['mw'],
    "cikīrṣya": ['mw'],
    "cikīrṣā": ['ap90', 'cae', 'mw'],
    "cikūra": ['mw'],
    "cikūraḥ": ['ap90'],
    "cikṣipas": ['ddsa'],
    "cil": ['ap90', 'mw'],
    "cilamilikā": ['ap90'],
    "cilamīlikā": ['ap90', 'mw'],
    "cili": ['mw'],
    "cilicima": ['mw'],
    "cilicīma": ['mw'],
    "cilicīmi": ['mw'],
    "cilikā": ['mw'],
    "cilimikā": ['cped'],
    "cilimilika": ['bhs'],
    "ciliminikā": ['mw'],
    "cilimīlikā": ['mw'],
    "cilimīnaka": ['mw'],
    "cill": ['ap90', 'mw'],
    "cilla": ['ap90', 'bhs', 'mw'],
    "cillabhakṣyā": ['mw'],
    "cilladevī": ['mw'],
    "cillaka": ['mw'],
    "cillakā": ['ap90', 'mw'],
    "cillaḍa": ['mw'],
    "cillaṭa": ['mw'],
    "cilli": ['cae', 'ddsa', 'mw'],
    "cillikā": ['mw'],
    "cillikālatā": ['mw'],
    "cillābha": ['mw'],
    "cillī": ['mw'],
    "cilvaṭi": ['mw'],
    "cilāti": ['mw'],
    "cilātiputra": ['mw'],
    "cimi": ['mw'],
    "cimicimā": ['mw'],
    "cimicimāya": ['mw'],
    "cimika": ['mw'],
    "cimilika": ['cped'],
    "cimiḥ": ['ap90'],
    "cin": ['mw'],
    "cinha": ['ddsa'],
    "cinhaya": ['ddsa'],
    "cinitvā": ['cped'],
    "cinmaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "cinmātra": ['cae', 'mw'],
    "cinmātraṃ": ['ap90'],
    "cinna": ['mw'],
    "cinnaka": ['bhs'],
    "cint": ['cae', 'ddsa', 'mw'],
    "cintaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "cintana": ['cae', 'mw'],
    "cintanīya": ['cae', 'mw'],
    "cintayamāna": ['cped'],
    "cintayanta": ['cped'],
    "cintayati": ['cped'],
    "cintayi": ['cped'],
    "cintayitavya": ['mw'],
    "cintayitvā": ['cped'],
    "cintayāna": ['cae', 'mw'],
    "cintenta": ['cped'],
    "cintetabba": ['cped'],
    "cinteti": ['cped'],
    "cinti": ['mw'],
    "cintin": ['mw'],
    "cintisurāṣṭra": ['mw'],
    "cintita": ['cae', 'cped', 'ddsa', 'mw'],
    "cintiti": ['mw'],
    "cintitopanata": ['mw'],
    "cintitopasthita": ['mw'],
    "cintitā": ['mw'],
    "cintiyamāna": ['cped'],
    "cintiyā": ['mw'],
    "cintiḍī": ['mw'],
    "cintokti": ['mw'],
    "cintya": ['cae', 'ddsa', 'mw'],
    "cintyadyota": ['mw'],
    "cintyasaṃgraha": ['mw'],
    "cintā": ['cae', 'cped', 'ddsa', 'mw'],
    "cintābhara": ['mw'],
    "cintākarman": ['mw'],
    "cintākavi": ['cped'],
    "cintākula": ['mw'],
    "cintākārin": ['mw'],
    "cintākṛtya": ['mw'],
    "cintāmaya": ['cped', 'mw'],
    "cintāmaṇi": ['cae', 'mw'],
    "cintāmaṇicaturmukha": ['mw'],
    "cintāmaṇitīrtha": ['mw'],
    "cintāmaṇivaralocana": ['mw'],
    "cintāmoha": ['cae'],
    "cintāpara": ['cae', 'mw'],
    "cintāparīta": ['mw'],
    "cintāratna": ['mw'],
    "cintāratnāyita": ['mw'],
    "cintārāja": ['bhs'],
    "cintāvat": ['mw'],
    "cintāvaśa": ['mw'],
    "cintāveśman": ['mw'],
    "cintāvidheya": ['mw'],
    "cintāvivikta": ['mw'],
    "cintāyajña": ['mw'],
    "cipaṭa": ['ap90', 'mw'],
    "cipiṭa": ['cae', 'ddsa', 'mw'],
    "cipiṭaghrāṇa": ['mw'],
    "cipiṭagrīva": ['mw'],
    "cipiṭaka": ['mw'],
    "cipiṭakaḥ": ['ap90'],
    "cipiṭanāsa": ['mw'],
    "cipiṭanāsika": ['mw'],
    "cipiṭaviṣāṇa": ['mw'],
    "cipiṭaḥ": ['ap90'],
    "cipiṭikā": ['mw'],
    "cipiṭikāvat": ['mw'],
    "cipiṭā": ['mw'],
    "cipiṭāsya": ['mw'],
    "cipiṭī": ['mw'],
    "cipiṭīkṛ": ['ddsa'],
    "cipiṭīkṛta": ['mw'],
    "cippa": ['mw'],
    "cippaḥ": ['ap90'],
    "cippaṭa": ['mw'],
    "cippaṭajayāpīḍa": ['mw'],
    "cippitika": ['bhs'],
    "cipuṭa": ['mw'],
    "cipya": ['mw'],
    "cipyate": ['bhs'],
    "cira": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "cirabhāvin": ['mw'],
    "cirabilva": ['mw'],
    "ciraceṣṭita": ['mw'],
    "ciradikkhita": ['cped'],
    "ciradivasam": ['mw'],
    "ciradiṭṭha": ['cped'],
    "ciradātṛ": ['mw'],
    "ciradṛṣṭa": ['cae'],
    "ciragata": ['mw'],
    "ciraja": ['mw'],
    "cirajāta": ['mw'],
    "cirajātatara": ['mw'],
    "cirajīvaka": ['mw'],
    "cirajīvikā": ['cae', 'mw'],
    "cirajīvin": ['cae', 'mw'],
    "cirajīvitā": ['mw'],
    "cirakrameṇa": ['cae'],
    "cirakriya": ['mw'],
    "cirakāla": ['cae', 'mw'],
    "cirakālam": ['mw'],
    "cirakālapālita": ['mw'],
    "cirakālika": ['mw'],
    "cirakālopārjita": ['mw'],
    "cirakālāt": ['mw'],
    "cirakālāya": ['mw'],
    "cirakālīna": ['mw'],
    "cirakāra": ['cae', 'ddsa', 'mw'],
    "cirakāri": ['cae', 'mw'],
    "cirakārika": ['mw'],
    "cirakārin": ['cae', 'mw'],
    "cirakīrti": ['mw'],
    "cirakṛta": ['cae', 'mw'],
    "ciralabdha": ['mw'],
    "ciralokaloka": ['mw'],
    "ciram": ['mw'],
    "cirambhaṇa": ['mw'],
    "ciramehin": ['mw'],
    "ciramitra": ['cae', 'mw'],
    "ciramocana": ['mw'],
    "ciranirgata": ['mw'],
    "ciranissina": ['cped'],
    "ciraniviṣṭa": ['mw'],
    "ciranivāsī(n)": ['cped'],
    "cirantana": ['cae', 'ddsa', 'mw'],
    "cirapabbajita": ['cped'],
    "ciraparicita": ['mw'],
    "ciraparṇa": ['mw'],
    "cirapaṭika": ['cped'],
    "cirapaṭikā": ['cped'],
    "cirappanaṭṭha": ['cped'],
    "cirappavāsi(n)": ['cped'],
    "ciraprasūtā": ['mw'],
    "cirapravāsin": ['mw'],
    "cirapravṛtta": ['mw'],
    "cirapraṇaṣṭa": ['mw'],
    "cirapura": ['ddsa', 'mw'],
    "cirapuṣpa": ['mw'],
    "cirapākin": ['mw'],
    "ciraratta": ['cped'],
    "cirarattaṁ": ['cped'],
    "ciraroga": ['mw'],
    "cirarātra": ['cae', 'ddsa', 'mw'],
    "cirarātram": ['mw'],
    "cirarātrepsita": ['mw'],
    "cirarātroṣita": ['mw'],
    "cirarātrāya": ['mw'],
    "cirasambhṛta": ['mw'],
    "cirasaṃcita": ['mw'],
    "cirasaṃsthita": ['mw'],
    "cirasaṃvṛddha": ['mw'],
    "cirasevaka": ['mw'],
    "cirassa": ['cped'],
    "cirassaṁ": ['cped'],
    "cirassuta": ['cped'],
    "cirastha": ['mw'],
    "cirasthita": ['cae', 'mw'],
    "cirasthitika": ['bhs', 'mw'],
    "cirasthāyin": ['mw'],
    "cirasthāyitā": ['mw'],
    "cirasuptabuddhi": ['mw'],
    "cirasya": ['mw'],
    "cirasūtikā": ['mw'],
    "cirasūtā": ['mw'],
    "ciratama": ['mw'],
    "ciratamena": ['mw'],
    "ciratara": ['mw'],
    "ciratarakena": ['bhs'],
    "cirataraṁ": ['cped'],
    "ciratareṇa": ['mw'],
    "ciratikta": ['mw'],
    "ciratiktā": ['mw'],
    "ciratna": ['ap90', 'mw'],
    "ciratta": ['cped'],
    "cirattaṁ": ['cped'],
    "ciratā": ['mw'],
    "ciravelayā": ['mw'],
    "ciravelā": ['cae', 'mw'],
    "ciraviproṣita": ['mw'],
    "ciravāsa": ['cae', 'mw'],
    "ciravṛtta": ['mw'],
    "ciray": ['cae'],
    "ciraya": ['ddsa', 'mw'],
    "cirayapanā": ['cped'],
    "cirayvippavuttha": ['cped'],
    "cirayāta": ['mw'],
    "ciraṁ": ['cped'],
    "ciraṃ": ['bhs'],
    "ciraṃjīva": ['ap90', 'mw'],
    "ciraṃjīvin": ['mw'],
    "ciraṃjīvā": ['mw'],
    "ciraṃtana": ['ap90'],
    "ciraṃṭī": ['ap90'],
    "ciraṇḍhī": ['ddsa', 'mw'],
    "ciraṇṭhī": ['mw'],
    "ciraṇṭī": ['mw'],
    "ciraṭṭhitika": ['cped'],
    "cirbhaṭa": ['cae', 'mw'],
    "cirbhaṭikā": ['ddsa', 'mw'],
    "cirbhaṭiḥ": ['ap90'],
    "cirbhaṭī": ['mw'],
    "cirbhiṭa": ['cae', 'ddsa', 'mw'],
    "cirbhiṭikā": ['mw'],
    "cire": ['mw'],
    "cireṇa": ['mw'],
    "ciri": ['ap90', 'cae', 'ddsa', 'mw'],
    "ciribilva": ['mw'],
    "cirikā": ['mw'],
    "cirikāka": ['mw'],
    "cirilla": ['mw'],
    "cirillī": ['mw'],
    "ciriḥ": ['ap90'],
    "ciriṇṭī": ['mw'],
    "ciriṭīka": ['mw'],
    "cirojjhita": ['mw'],
    "cirotsuka": ['mw'],
    "cirottha": ['mw'],
    "ciroṣita": ['cae', 'ddsa', 'mw'],
    "ciru": ['mw'],
    "ciruḥ": ['ap90'],
    "cirābhilaṣita": ['mw'],
    "cirāciraṁ": ['cped'],
    "cirād": ['mw'],
    "cirāntaka": ['mw'],
    "cirārodha": ['mw'],
    "cirāt": ['mw'],
    "cirātikta": ['mw'],
    "cirāy": ['cae'],
    "cirāya": ['cped', 'ddsa', 'mw'],
    "cirāyati": ['ap90'],
    "cirāyita": ['mw'],
    "cirāyu": ['mw'],
    "cirāyuka": ['mw'],
    "cirāyus": ['cae', 'mw'],
    "cirāyuṣa": ['cae', 'ddsa', 'mw'],
    "cirāyuṣya": ['mw'],
    "cirāyāt": ['mw'],
    "cirāśrita": ['mw'],
    "cirāṭikā": ['mw'],
    "cirīṭīka": ['mw'],
    "cit": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cita": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "citaidha": ['ddsa', 'mw'],
    "citaka": ['cped'],
    "citantaraṁsa": ['cped'],
    "citavistara": ['bhs', 'mw'],
    "citi": ['cae', 'ddsa', 'mw'],
    "citighana": ['mw'],
    "citikā": ['ap90', 'ddsa', 'mw'],
    "citikḷpti": ['mw'],
    "citimat": ['mw'],
    "citipurīṣa": ['mw'],
    "citipād": ['gra'],
    "citivat": ['mw'],
    "citivyavahāra": ['mw'],
    "citiśakti": ['mw'],
    "citiḥ": ['ap90'],
    "citkaṇakantha": ['mw'],
    "citkāra": ['ddsa', 'mw'],
    "citkāravat": ['mw'],
    "citkāraśabda": ['mw'],
    "citpara": ['mw'],
    "citpati": ['mw'],
    "citprabhā": ['mw'],
    "citpravṛtti": ['mw'],
    "citpāvan": ['mw'],
    "citra": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "citrabalagaccha": ['mw'],
    "citrabarha": ['mw'],
    "citrabarhin": ['mw'],
    "citrabarhis": ['gra', 'mw'],
    "citrabheṣajā": ['mw'],
    "citrabhitti": ['cae', 'mw'],
    "citrabhānu": ['bhs', 'cae', 'gra', 'mw'],
    "citrabhārata": ['mw'],
    "citrabhāṣya": ['mw'],
    "citrabhūta": ['mw'],
    "citrabāhu": ['mw'],
    "citrabāṇa": ['mw'],
    "citrabīja": ['mw'],
    "citrabījā": ['mw'],
    "citrachada": ['cped'],
    "citrachattra": ['bhs'],
    "citracāpa": ['mw'],
    "citradarśana": ['mw'],
    "citradaṇḍaka": ['mw'],
    "citradeva": ['mw'],
    "citradevī": ['mw'],
    "citradhara": ['mw'],
    "citradharman": ['mw'],
    "citradhrajati": ['gra', 'mw'],
    "citradhvaja": ['bhs', 'mw'],
    "citradhā": ['mw'],
    "citradīpa": ['mw'],
    "citradṛśīka": ['gra', 'mw'],
    "citraga": ['cae', 'mw'],
    "citragandha": ['mw'],
    "citragata": ['cae', 'mw'],
    "citraghnī": ['mw'],
    "citragrāvan": ['mw'],
    "citragrīva": ['cae', 'mw'],
    "citragu": ['mw'],
    "citragupta": ['mw'],
    "citragṛha": ['cae', 'mw'],
    "citrahasta": ['mw'],
    "citrahemajāla": ['bhs'],
    "citrahetu": ['mw'],
    "citraja": ['mw'],
    "citrajalpa": ['mw'],
    "citrajavanikā": ['cae', 'mw'],
    "citrajña": ['mw'],
    "citraka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "citrakambala": ['mw'],
    "citrakara": ['cae', 'mw'],
    "citrakarman": ['cae', 'mw'],
    "citrakarmavid": ['mw'],
    "citrakarṇa": ['mw'],
    "citrakatha": ['mw'],
    "citrakathi(n)": ['cped'],
    "citrakathālāpasukha": ['mw'],
    "citrakavitva": ['mw'],
    "citrakaṇṭaka": ['mw'],
    "citrakaṇṭha": ['mw'],
    "citraketu": ['bhs', 'mw'],
    "citrakeśa": ['bhs'],
    "citrakeśatā": ['mw'],
    "citrakola": ['mw'],
    "citrakriyā": ['mw'],
    "citrakuṇḍala": ['mw'],
    "citrakuṣṭha": ['mw'],
    "citrakāli": ['bhs'],
    "citrakāra": ['cae', 'mw'],
    "citrakāraḥ": ['bhs'],
    "citrakāya": ['mw'],
    "citrakāṇḍālī": ['mw'],
    "citrakūlā": ['mw'],
    "citrakūṭa": ['cae', 'mw'],
    "citrakūṭamāhātmya": ['mw'],
    "citrakūṭā": ['mw'],
    "citrakṛt": ['mw'],
    "citrakṛtya": ['mw'],
    "citrakṣatra": ['gra', 'mw'],
    "citrala": ['ap90', 'mw'],
    "citralatā": ['mw'],
    "citralekhaka": ['mw'],
    "citralekhanikā": ['mw'],
    "citralekhā": ['cae', 'mw'],
    "citralikhana": ['cae', 'mw'],
    "citralikhita": ['cae', 'mw'],
    "citralocanā": ['mw'],
    "citralā": ['mw'],
    "citram": ['mw'],
    "citramahas": ['gra', 'mw'],
    "citramakuṭa": ['bhs'],
    "citramalla": ['bhs'],
    "citramanas": ['mw'],
    "citramañca": ['mw'],
    "citramaṇḍala": ['mw'],
    "citramekhala": ['mw'],
    "citramekhalaka": ['mw'],
    "citramāla": ['bhs'],
    "citramālya": ['bhs'],
    "citramīmāṃsā": ['mw'],
    "citramīmāṃsākhaṇḍana": ['mw'],
    "citramṛga": ['mw'],
    "citranetrā": ['mw'],
    "citranyasta": ['cae', 'mw'],
    "citranātha": ['mw'],
    "citrapada": ['mw'],
    "citrapadakramam": ['mw'],
    "citrapadā": ['mw'],
    "citrapakṣa": ['mw'],
    "citrapakṣmatā": ['mw'],
    "citraparicaya": ['cae'],
    "citraparṇikā": ['mw'],
    "citraparṇī": ['mw'],
    "citrapattra": ['mw'],
    "citrapattraka": ['mw'],
    "citrapattrikā": ['mw'],
    "citrapattrī": ['mw'],
    "citrapaṭa": ['cae', 'mw'],
    "citrapaṭṭa": ['cae', 'mw'],
    "citrapaṭṭagata": ['mw'],
    "citrapaṭṭikā": ['mw'],
    "citraphala": ['mw'],
    "citraphalaka": ['cae', 'mw'],
    "citraphalakagata": ['cae'],
    "citraphalā": ['mw'],
    "citrapiccha": ['mw'],
    "citrapicchaka": ['mw'],
    "citrapiśācikā": ['bhs'],
    "citrapratikṛti": ['mw'],
    "citrapriyakatha": ['mw'],
    "citrapura": ['mw'],
    "citraputrikā": ['mw'],
    "citraputrikāyita": ['mw'],
    "citrapuṅkha": ['mw'],
    "citrapuṣpī": ['mw'],
    "citrapādā": ['mw'],
    "citrapāṭala": ['bhs', 'mw'],
    "citrapāṭalī": ['cped'],
    "citrapṛṣṭha": ['mw'],
    "citraratha": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "citrarathabāhlika": ['mw'],
    "citrarathā": ['mw'],
    "citrarathī": ['mw'],
    "citrarañjaka": ['mw'],
    "citraraśmi": ['mw'],
    "citrarekhā": ['mw'],
    "citrarepha": ['mw'],
    "citrarādhas": ['cae', 'gra', 'mw'],
    "citrarāti": ['cae', 'gra', 'mw'],
    "citrasarpa": ['mw'],
    "citrasaṃstha": ['mw'],
    "citrasaṅga": ['mw'],
    "citrasena": ['bhs', 'cae', 'gra', 'mw'],
    "citrasenā": ['bhs', 'mw'],
    "citrastavana": ['bhs'],
    "citrastha": ['mw'],
    "citrasthala": ['mw'],
    "citrasudhānidhi": ['mw'],
    "citrasvana": ['mw'],
    "citratala": ['mw'],
    "citratanu": ['mw'],
    "citrataṇḍula": ['mw'],
    "citrataṇḍulā": ['mw'],
    "citratvac": ['mw'],
    "citratāla": ['mw'],
    "citratūlikā": ['mw'],
    "citraudana": ['mw'],
    "citravadāla": ['mw'],
    "citravahā": ['mw'],
    "citravalayā": ['mw'],
    "citravallika": ['mw'],
    "citravallī": ['mw'],
    "citravana": ['mw'],
    "citravant": ['cae'],
    "citravarman": ['mw'],
    "citravarti": ['cae'],
    "citravartikā": ['cae', 'mw'],
    "citravartiṇī": ['mw'],
    "citravarṇa": ['bhs'],
    "citravarṇī": ['mw'],
    "citravarṣin": ['mw'],
    "citravat": ['mw'],
    "citravatī": ['mw'],
    "citravegika": ['mw'],
    "citraveṣa": ['mw'],
    "citravicitra": ['mw'],
    "citravidyā": ['mw'],
    "citravyāghra": ['mw'],
    "citravāhana": ['mw'],
    "citravāja": ['cae', 'gra', 'mw'],
    "citravīrya": ['mw'],
    "citravṛtti": ['mw'],
    "citray": ['cae'],
    "citraya": ['ddsa', 'mw'],
    "citrayajña": ['mw'],
    "citrayati": ['ap90'],
    "citrayodhin": ['mw'],
    "citrayāma": ['gra', 'mw'],
    "citrayāna": ['mw'],
    "citraāyus": ['gra'],
    "citraśayana": ['bhs'],
    "citraśikhaṇḍadhara": ['mw'],
    "citraśikhaṇḍija": ['mw'],
    "citraśikhaṇḍin": ['cae', 'mw'],
    "citraśikhaṇḍiprasūta": ['mw'],
    "citraśilā": ['mw'],
    "citraśiras": ['mw'],
    "citraśocis": ['gra', 'mw'],
    "citraśoka": ['mw'],
    "citraśravas": ['gra'],
    "citraśravastama": ['cae', 'mw'],
    "citraśākāpūpabhakṣyavikārakriyā": ['mw'],
    "citraśālikā": ['cae', 'mw'],
    "citraśālā": ['cae', 'ddsa', 'mw'],
    "citraśīrṣaka": ['mw'],
    "citraṇā": ['bhs'],
    "citraṭa": ['mw'],
    "citreśa": ['mw'],
    "citria": ['gra'],
    "citrika": ['bhs', 'mw'],
    "citrikaḥ": ['ap90'],
    "citrikāra": ['bhs'],
    "citrin": ['ap90', 'gra', 'mw'],
    "citrita": ['ap90', 'ddsa', 'mw'],
    "citritaka": ['bhs'],
    "citriya": ['ddsa', 'mw'],
    "citriṇī": ['ap90', 'mw'],
    "citrokti": ['mw'],
    "citropacitra": ['bhs'],
    "citropalā": ['mw'],
    "citroti": ['gra', 'mw'],
    "citrotpalā": ['mw'],
    "citrya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "citrā": ['ap90', 'bhs', 'mw'],
    "citrāhuti": ['mw'],
    "citrākṛti": ['cae', 'mw'],
    "citrākṣa": ['bhs', 'mw'],
    "citrākṣupa": ['mw'],
    "citrākṣī": ['mw'],
    "citrāmagha": ['gra', 'mw'],
    "citrānna": ['mw'],
    "citrānta": ['bhs'],
    "citrāpūpa": ['mw'],
    "citrāpūrṇamāsa": ['mw'],
    "citrārambha": ['mw'],
    "citrārcis": ['mw'],
    "citrārpita": ['cae', 'mw'],
    "citrārpitārambha": ['mw'],
    "citrārtha": ['bhs'],
    "citrāsaṅga": ['mw'],
    "citrāstaraṇavat": ['mw'],
    "citrāsvātī": ['mw'],
    "citrāvasu": ['mw'],
    "citrāyasa": ['mw'],
    "citrāyudha": ['mw'],
    "citrāyus": ['gra', 'mw'],
    "citrāśva": ['mw'],
    "citrāṅga": ['bhs', 'cae', 'ddsa', 'mw'],
    "citrāṅgada": ['cae', 'mw'],
    "citrāṅgadasū": ['mw'],
    "citrāṅgadā": ['mw'],
    "citrāṅgasadana": ['mw'],
    "citrāṅguli": ['bhs'],
    "citrāṅgulitā": ['mw'],
    "citrāṅgī": ['mw'],
    "citrāṇḍaja": ['mw'],
    "citrāṭīra": ['mw'],
    "citrī": ['mw'],
    "citrīkaraṇa": ['bhs', 'mw'],
    "citrīkaraṇaṃ": ['ap90'],
    "citrīkaroti": ['bhs'],
    "citrīkāra": ['bhs', 'mw'],
    "citrīkṛ": ['ap90', 'cae', 'ddsa'],
    "citrīkṛta": ['ap90', 'mw'],
    "citrīy": ['cae'],
    "citrīya": ['ddsa', 'mw'],
    "citrīyate": ['ap90'],
    "citrīyā": ['ddsa', 'mw'],
    "citsabheśānandatīrtha": ['mw'],
    "citsukha": ['mw'],
    "citsukhī": ['mw'],
    "citsvarūpa": ['mw'],
    "citta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "citta(p)pamāthi(n)": ['cped'],
    "cittabhava": ['mw'],
    "cittabheda": ['mw'],
    "cittabhrama": ['cae', 'mw'],
    "cittabhramacikitsā": ['mw'],
    "cittabhrānti": ['mw'],
    "cittabhāvanā": ['cped'],
    "cittabhū": ['mw'],
    "cittacaura": ['cae', 'mw'],
    "cittacetasika": ['mw'],
    "cittacārin": ['mw'],
    "cittadhāraṇa": ['mw'],
    "cittadhārā": ['bhs', 'mw'],
    "cittadhārābuddhisaṃkusumitābhyudgata": ['bhs', 'mw'],
    "cittadravībhāva": ['mw'],
    "cittadravībhāvamaya": ['mw'],
    "cittadubbhaka": ['cped'],
    "cittagarbha": ['gra'],
    "cittagarbhā": ['mw'],
    "cittagrāha": ['bhs'],
    "cittahārin": ['mw'],
    "cittahṛt": ['mw'],
    "cittaikya": ['mw'],
    "cittaja": ['cae', 'mw'],
    "cittajanman": ['cae', 'mw'],
    "cittajña": ['mw'],
    "cittajñatā": ['mw'],
    "cittaka": ['bhs'],
    "cittakali": ['cped'],
    "cittakalita": ['mw'],
    "cittakamma": ['cped'],
    "cittakata": ['cped'],
    "cittakathika": ['cped'],
    "cittakathī(n)": ['cped'],
    "cittakelisa": ['cped'],
    "cittakhata": ['cped'],
    "cittakheda": ['cae', 'ddsa', 'mw'],
    "cittakkhepa": ['cped'],
    "cittaklesa": ['cped'],
    "cittakā": ['cped'],
    "cittakāra": ['cped'],
    "cittakāraka": ['cped'],
    "cittakṣaṇa": ['bhs'],
    "cittala": ['mw'],
    "cittamoha": ['mw'],
    "cittanirvṛti": ['mw'],
    "cittantara": ['cped'],
    "cittanvaya": ['cped'],
    "cittanātha": ['cae', 'mw'],
    "cittanāśa": ['mw'],
    "cittapa": ['mw'],
    "cittaparikkhāra": ['cped'],
    "cittaparyāya": ['bhs'],
    "cittappakopana": ['cped'],
    "cittappamaddi(n)": ['cped'],
    "cittapramāthin": ['mw'],
    "cittaprasannatā": ['mw'],
    "cittaprasāda": ['mw'],
    "cittaprasādana": ['mw'],
    "cittapraśama": ['mw'],
    "cittapāvan": ['mw'],
    "cittapāṭalī, citrapāṭalī": ['cped'],
    "cittarakṣin": ['mw'],
    "cittaratha": ['bhs'],
    "cittarāga": ['cae', 'mw'],
    "cittarāja": ['mw'],
    "cittarūpaṁ": ['cped'],
    "cittasamunnati": ['mw'],
    "cittasamuṭṭhāna": ['cped'],
    "cittasamādhāna": ['cped'],
    "cittasaṃhati": ['mw'],
    "cittasaṃkhya": ['mw'],
    "cittasaṅkhara": ['cped'],
    "cittastha": ['mw'],
    "cittasthita": ['bhs', 'mw'],
    "cittatara": ['cped'],
    "cittatāpa": ['mw'],
    "cittavaikalya": ['mw'],
    "cittavaiklavya": ['mw'],
    "cittavant": ['cae'],
    "cittavat": ['ap90', 'mw'],
    "cittavatkartṛka": ['mw'],
    "cittavedanā": ['mw'],
    "cittavibhrama": ['mw'],
    "cittavibhraṃśa": ['mw'],
    "cittavikkhepa": ['cped'],
    "cittavikāra": ['cae', 'mw'],
    "cittavikārin": ['mw'],
    "cittavikṣepa": ['cae', 'mw'],
    "cittavināśana": ['mw'],
    "cittavipallāssa": ['cped'],
    "cittavipariyesa": ['cped'],
    "cittavipariyāsakata": ['cped'],
    "cittaviplava": ['mw'],
    "cittavirāga": ['mw'],
    "cittavistarā": ['bhs'],
    "cittaviśleṣa": ['mw'],
    "cittavṛtti": ['cae', 'mw'],
    "cittayoni": ['mw'],
    "cittaśānti": ['mw'],
    "cittaśāśvata": ['bhs'],
    "cittekagga": ['cped'],
    "citti": ['cae', 'ddsa', 'gra', 'mw'],
    "cittika": ['cped'],
    "cittikata": ['cped'],
    "cittikāra": ['bhs'],
    "cittin": ['ap90', 'cae', 'ddsa', 'mw'],
    "cittita": ['cped'],
    "cittiḥ": ['ap90'],
    "cittiṁkaritvā": ['cped'],
    "cittiṁkaritvānā": ['cped'],
    "cittonnatti": ['mw'],
    "cittotpāda": ['bhs'],
    "cittotpādika": ['bhs'],
    "cittottha": ['mw'],
    "cittābhijvalana": ['mw'],
    "cittābhoga": ['mw'],
    "cittādhipatya": ['mw'],
    "cittāgāra": ['cped'],
    "cittākarṣaṇa": ['ddsa', 'mw'],
    "cittākarṣin": ['cae', 'mw'],
    "cittākūta": ['mw'],
    "cittālaṅkāra": ['cped'],
    "cittālaṅkāracittaparikkhāra": ['cped'],
    "cittānubodha": ['mw'],
    "cittānupassi(n)": ['cped'],
    "cittānurakkhi(n)": ['cped'],
    "cittānuvartin": ['cae', 'mw'],
    "cittānuvartitva": ['mw'],
    "cittānuvṛtti": ['cae', 'mw'],
    "cittānuvṛttitva": ['mw'],
    "cittāpahāraka": ['mw'],
    "cittāpahārin": ['mw'],
    "cittārpita": ['mw'],
    "cittāsaṅga": ['mw'],
    "cittāsukha": ['mw'],
    "cittī": ['mw'],
    "cittīka": ['cped'],
    "cittīkata": ['cped'],
    "cittīkataṁ": ['cped'],
    "cittīkatvā": ['cped'],
    "cittīkatvānā": ['cped'],
    "cittīkāra": ['cped'],
    "cittīkṛta": ['mw'],
    "citya": ['ap90', 'cae', 'ddsa', 'mw'],
    "cityagni": ['mw'],
    "cityayūpa": ['mw'],
    "cityupaniṣad": ['mw'],
    "cityā": ['mw'],
    "citā": ['ap90', 'ddsa', 'mw'],
    "citābhūmi": ['mw'],
    "citācaityacihna": ['mw'],
    "citācūḍaka": ['mw'],
    "citādhirohaṇa": ['mw'],
    "citādhūma": ['cae', 'mw'],
    "citāgni": ['cae', 'mw'],
    "citānala": ['mw'],
    "citāntarāṃśatā": ['mw'],
    "citāpraveśa": ['mw'],
    "citāṅguli": ['bhs'],
    "citī": ['mw'],
    "citīka": ['mw'],
    "civarapativisa": ['cped'],
    "civillikā": ['mw'],
    "civiḥ": ['ap90'],
    "civiṭa": ['ap90', 'mw'],
    "civukaṃ": ['ap90'],
    "ciya": ['bhs'],
    "ciñ": ['ddsa'],
    "ciñcikā": ['mw'],
    "ciñcinī": ['mw'],
    "ciñciṇī": ['mw'],
    "ciñcoṭaka": ['mw'],
    "ciñcā": ['cae', 'ddsa', 'mw'],
    "ciñcāmla": ['mw'],
    "ciñcāsāra": ['mw'],
    "ciñcāṭaka": ['mw'],
    "ciñcī": ['mw'],
    "ciściṣākāram": ['mw'],
    "ciścā": ['gra', 'mw'],
    "ciṃcā": ['ap90'],
    "ciṃgaṭaḥ": ['ap90'],
    "ciṃt": ['ap90'],
    "ciṃtaka": ['ap90'],
    "ciṃtanaṃ": ['ap90'],
    "ciṃtita": ['ap90'],
    "ciṃtitiḥ": ['ap90'],
    "ciṃtiḍī": ['ap90'],
    "ciṃtya": ['ap90'],
    "ciṃtā": ['ap90'],
    "ciṅgaḍa": ['mw'],
    "ciṅgaṭa": ['mw'],
    "ciṅgulaka": ['cped'],
    "ciṅgulayitvā": ['cped'],
    "ciṅgulika": ['cped'],
    "ciṅgulāyitvā": ['cped'],
    "ciṅkhala": ['bhs'],
    "ciṇī": ['mw'],
    "ciṇṇa": ['cped'],
    "ciṇṇamānatta": ['cped'],
    "ciṣṭā": ['bhs'],
    "ciṭ": ['ap90', 'mw'],
    "ciṭiciṭāya": ['mw'],
    "ciṭiciṭāyati": ['bhs', 'cped'],
    "ciṭiṅga": ['mw'],
    "co": ['bhs'],
    "coca": ['cae', 'ddsa', 'mw'],
    "cocaka": ['mw'],
    "cocakaḥ": ['ap90'],
    "cocapāna": ['cped'],
    "cocaṃ": ['ap90'],
    "coda": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "codaka": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "codana": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "codanā": ['ap90', 'bhs', 'cped', 'mw'],
    "codanāguḍa": ['mw'],
    "codanāvatthu": ['cped'],
    "codanī": ['mw'],
    "codapravṛddha": ['gra', 'mw'],
    "codas": ['gra', 'mw'],
    "codayamāna": ['cped'],
    "codayanmati": ['gra', 'mw'],
    "codayati": ['bhs', 'cped'],
    "codayitavya": ['mw'],
    "codayitrī": ['gra'],
    "codayitvā": ['cped'],
    "codayitṛ": ['cae', 'mw'],
    "codenta": ['cped'],
    "codesi": ['cped'],
    "codesuṁ)": ['cped'],
    "codeta(r)": ['cped'],
    "codetabba": ['cped'],
    "codeti": ['cped'],
    "codetvā": ['cped'],
    "codita": ['ap90', 'cped', 'mw'],
    "coditatva": ['mw'],
    "coditṛ": ['cae', 'gra', 'mw'],
    "codiyamāna": ['cped'],
    "codiṣṭha": ['gra', 'mw'],
    "codya": ['ap90', 'mw'],
    "codāpeti": ['cped'],
    "codāyani": ['mw'],
    "coka": ['cae', 'ddsa', 'mw'],
    "cokṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "cola": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "colabhāṇa": ['mw'],
    "colaka": ['cped', 'mw'],
    "colakaḥ": ['ap90'],
    "colakin": ['ap90', 'mw'],
    "colamaṇḍala": ['cae', 'mw'],
    "colapaṭṭaka": ['mw'],
    "colaḥ": ['ap90'],
    "colaṃḍukaḥ": ['ap90'],
    "coloṃḍukaḥ": ['ap90'],
    "coloṇḍuka": ['mw'],
    "colī": ['mw'],
    "copaka": ['mw'],
    "copana": ['ap90', 'mw'],
    "copayati": ['cped'],
    "copaḍa": ['mw'],
    "copeti": ['cped'],
    "cora": ['cae', 'cped', 'ddsa', 'mw'],
    "coraghāta": ['cped'],
    "coraghātaka": ['cped'],
    "coragāmanī": ['cped'],
    "coragāmaṇika": ['cped'],
    "coraka": ['cae', 'cped', 'mw'],
    "corakabandham": ['mw'],
    "corakaraṇa": ['mw'],
    "corakaṇṭaka": ['mw'],
    "corapaccatthika": ['cped'],
    "corapuṣpikā": ['mw'],
    "corapuṣpī": ['mw'],
    "corasnāyu": ['mw'],
    "corasādhāraṇa": ['cped'],
    "coraḥ": ['ap90'],
    "coraṃkāram": ['mw'],
    "corikā": ['ap90', 'cped', 'mw'],
    "corikāvivāha": ['cae', 'mw'],
    "corikāya": ['cped'],
    "corita": ['ap90', 'mw'],
    "coritaka": ['ddsa', 'mw'],
    "coritakaṃ": ['ap90'],
    "corā": ['mw'],
    "corābhinīta": ['cped'],
    "corāyita": ['mw'],
    "corī": ['cped', 'mw'],
    "corīvaṭṭhāpana": ['cped'],
    "coska": ['mw'],
    "coskaḥ": ['ap90'],
    "coḍa": ['bhs', 'cae', 'ddsa', 'mw'],
    "coḍaka": ['bhs', 'mw'],
    "coḍakarṇa": ['mw'],
    "coḍaḥ": ['ap90'],
    "coḍā": ['mw'],
    "coḷa": ['cped'],
    "coḷabhisi": ['cped'],
    "coḷaka": ['cped'],
    "coḷapaṭṭa": ['cped'],
    "coḷavaṭṭi": ['cped'],
    "coḷaveṇi": ['cped'],
    "coṣa": ['cae', 'ddsa', 'mw'],
    "coṣaḥ": ['ap90'],
    "coṣaṇa": ['cae', 'mw'],
    "coṣaṇaṃ": ['ap90'],
    "coṣkūyamaṇa": ['mw'],
    "coṣya": ['mw'],
    "coṣyaṃ": ['ap90'],
    "coṭa": ['bhs'],
    "coṭikā": ['mw'],
    "coṭī": ['ap90', 'mw'],
    "cubra": ['mw'],
    "cubraṃ": ['ap90'],
    "cubuka": ['cae', 'ddsa', 'mw'],
    "cubukadaghna": ['mw'],
    "cubukaḥ": ['ap90'],
    "cuccu": ['cae', 'ddsa', 'mw'],
    "cuccukārakam": ['bhs'],
    "cuccuparṇikā": ['mw'],
    "cuccū": ['cae', 'mw'],
    "cuci": ['mw'],
    "cuciḥ": ['ap90'],
    "cucu": ['mw'],
    "cucuka": ['mw'],
    "cucukaḥ": ['ap90'],
    "cucundarī": ['mw'],
    "cucupa": ['mw'],
    "cucy": ['mw'],
    "cucūka": ['mw'],
    "cud": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cuddasa": ['cped'],
    "cuddasaka": ['cped'],
    "cuddasama": ['cped'],
    "cudita": ['cped'],
    "cuditaka": ['cped'],
    "cukk": ['ap90', 'mw'],
    "cukkasa": ['mw'],
    "cukkāra": ['mw'],
    "cukkāraḥ": ['ap90'],
    "cuknat": ['mw'],
    "cukopayiṣu": ['mw'],
    "cukra": ['bhs', 'cae', 'ddsa', 'mw'],
    "cukracaṇḍikā": ['mw'],
    "cukraka": ['mw'],
    "cukrakaṃ": ['ap90'],
    "cukraphala": ['mw'],
    "cukravedhaka": ['mw'],
    "cukravāstūka": ['mw'],
    "cukraḥ": ['ap90'],
    "cukrikā": ['mw'],
    "cukriman": ['ap90', 'mw'],
    "cukrā": ['ap90', 'mw'],
    "cukrāmla": ['mw'],
    "cukrāmlā": ['mw'],
    "cukrī": ['mw'],
    "cukṣobhayiṣu": ['ddsa', 'mw'],
    "cukṣā": ['ap90', 'mw'],
    "cul": ['ap90', 'mw'],
    "cula": ['mw'],
    "culaka": ['mw'],
    "culhi": ['mw'],
    "cull": ['ap90', 'mw'],
    "culla": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "cullakaḥ": ['ap90'],
    "cullakī": ['mw'],
    "cullapantha": ['bhs'],
    "cullapatka": ['mw'],
    "cullasīla": ['cped'],
    "culli": ['mw'],
    "culliḥ": ['ap90'],
    "cullākṣa": ['mw'],
    "cullāsīti": ['cped'],
    "cullī": ['ap90', 'cae', 'ddsa', 'mw'],
    "culu": ['mw'],
    "culuculāyati": ['bhs'],
    "culuka": ['cae', 'ddsa', 'mw'],
    "culukay": ['cae'],
    "culukaya": ['ddsa'],
    "culukaḥ": ['ap90'],
    "culukin": ['ap90', 'mw'],
    "culukya": ['mw'],
    "culukā": ['mw'],
    "culukīkṛ": ['ddsa', 'mw'],
    "culump": ['ddsa', 'mw'],
    "culumpa": ['mw'],
    "culumpin": ['mw'],
    "culumpā": ['mw'],
    "culuṃp": ['ap90'],
    "culuṃpaḥ": ['ap90'],
    "culuṃpā": ['ap90'],
    "culya": ['mw'],
    "cumb": ['cae', 'ddsa', 'mw'],
    "cumba": ['mw'],
    "cumbaka": ['mw'],
    "cumbakamaṇi": ['ddsa', 'mw'],
    "cumbana": ['cae', 'ddsa', 'mw'],
    "cumbanadāna": ['mw'],
    "cumbaṭa": ['cped'],
    "cumbin": ['cae', 'mw'],
    "cumbita": ['mw'],
    "cumbā": ['mw'],
    "cump": ['gra'],
    "cumucumāyana": ['mw'],
    "cumuri": ['gra', 'mw'],
    "cunanda": ['bhs', 'mw'],
    "cund": ['mw'],
    "cunda": ['bhs', 'mw'],
    "cundadvīla": ['bhs'],
    "cundikā": ['mw'],
    "cundā": ['bhs'],
    "cundādhāraṇī": ['bhs'],
    "cundī": ['mw'],
    "cup": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cupa": ['mw'],
    "cupadāsaka": ['mw'],
    "cupuṇīkā": ['mw'],
    "cur": ['ap90', 'cae', 'ddsa', 'mw'],
    "cura": ['ap90'],
    "curaṇaṃ": ['ap90'],
    "curaṇya": ['mw'],
    "curcura": ['mw'],
    "curcuradhvani": ['ddsa', 'mw'],
    "curcuraśabda": ['mw'],
    "curiḥ": ['ap90'],
    "curu": ['mw'],
    "curucurā": ['mw'],
    "curā": ['ap90', 'mw'],
    "curādi": ['ddsa', 'mw'],
    "curī": ['mw'],
    "custa": ['mw'],
    "custaḥ": ['ap90'],
    "cut": ['ap90', 'mw'],
    "cuta": ['cped', 'mw'],
    "cutaḥ": ['ap90'],
    "cuti": ['bhs', 'cped'],
    "cutūpapāta": ['cped'],
    "cuñcu": ['cae', 'ddsa', 'mw'],
    "cuñcula": ['mw'],
    "cuñculi": ['mw'],
    "cuñculī": ['mw'],
    "cuñcurī": ['mw'],
    "cuścuṣā": ['mw'],
    "cuścuṣākāra": ['mw'],
    "cuścuṣākāram": ['mw'],
    "cuḍ": ['ap90', 'mw'],
    "cuḍḍ": ['ap90', 'mw'],
    "cuṃb": ['ap90'],
    "cuṃbakaḥ": ['ap90'],
    "cuṃbanaṃ": ['ap90'],
    "cuṃbaḥ": ['ap90'],
    "cuṃbin": ['ap90'],
    "cuṃbita": ['ap90'],
    "cuṃcu": ['ap90'],
    "cuṃcurī": ['ap90'],
    "cuṃdī": ['ap90'],
    "cuṃḍ": ['ap90'],
    "cuṃṭ": ['ap90'],
    "cuṃṭā": ['ap90'],
    "cuṇ": ['ap90', 'mw'],
    "cuṇḍ": ['mw'],
    "cuṇḍhī": ['mw'],
    "cuṇḍya": ['mw'],
    "cuṇṇa": ['cped'],
    "cuṇṇacālanī": ['cped'],
    "cuṇṇaka": ['cped'],
    "cuṇṇakajāta": ['cped'],
    "cuṇṇakamakkhita": ['cped'],
    "cuṇṇeti": ['cped'],
    "cuṇṭ": ['mw'],
    "cuṇṭh": ['mw'],
    "cuṇṭā": ['mw'],
    "cuṇṭī": ['cae', 'ddsa', 'mw'],
    "cuṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "cuṭī": ['mw'],
    "cuṭṭ": ['ap90', 'mw'],
    "cyautna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cyava": ['cae', 'gra', 'mw'],
    "cyavam": ['ddsa'],
    "cyavana": ['cae', 'ddsa', 'gra', 'mw'],
    "cyavanadharma": ['mw'],
    "cyavanadharman": ['mw'],
    "cyavanadharmin": ['mw'],
    "cyavananahuṣasaṃvāda": ['mw'],
    "cyavanaprāśa": ['mw'],
    "cyavanasamāgama": ['mw'],
    "cyavanasmṛti": ['mw'],
    "cyavanaṃ": ['ap90'],
    "cyavanopākhyāna": ['mw'],
    "cyavas": ['cae', 'gra', 'mw'],
    "cyavati": ['bhs'],
    "cyavatāna": ['gra', 'mw'],
    "cyavāna": ['cae', 'ddsa', 'gra', 'mw'],
    "cyota": ['mw'],
    "cyotaṃ": ['ap90'],
    "cyu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cyupa": ['mw'],
    "cyupaḥ": ['ap90'],
    "cyus": ['ap90', 'mw'],
    "cyut": ['ap90', 'cae', 'ddsa', 'mw'],
    "cyuta": ['ap90', 'mw'],
    "cyutadattākṣara": ['mw'],
    "cyutaka": ['mw'],
    "cyutapathaka": ['mw'],
    "cyutasaṃskāra": ['mw'],
    "cyutasaṃskṛti": ['mw'],
    "cyuti": ['cae', 'ddsa', 'gra', 'mw'],
    "cyutiḥ": ['ap90'],
    "cyutopapāda": ['bhs'],
    "cyutotsāha": ['mw'],
    "cyutācāra": ['mw'],
    "cyutādhikāra": ['mw'],
    "cyutākṣara": ['mw'],
    "cyāva": ['mw'],
    "cyāvana": ['ap90', 'cae', 'ddsa', 'mw'],
    "cyāvayitṛ": ['mw'],
    "cyāvita": ['mw'],
    "cyūta": ['mw'],
    "cyūtaḥ": ['ap90'],
    "cyūḍika": ['bhs'],
    "cābukā": ['mw'],
    "cācali": ['mw'],
    "cācapuṭa": ['mw'],
    "cācari": ['ddsa', 'mw'],
    "cādi": ['mw'],
    "cāga": ['cped'],
    "cāgava(t)": ['cped'],
    "cāgādiṭṭhāna": ['cped'],
    "cāgānussati": ['cped'],
    "cāhava": ['mw'],
    "cāhuvāṇa": ['mw'],
    "cāhuyāṇa": ['mw'],
    "cāhūāṇa": ['mw'],
    "cākacakya": ['mw'],
    "cākacakyaṃ": ['ap90'],
    "cākaciccā": ['mw'],
    "cākacikya": ['mw'],
    "cākhāyitṛ": ['mw'],
    "cākra": ['ap90', 'mw'],
    "cākragartaka": ['mw'],
    "cākrapāleya": ['mw'],
    "cākravarmaṇa": ['mw'],
    "cākravāka": ['mw'],
    "cākravākeya": ['mw'],
    "cākravāleya": ['mw'],
    "cākreya": ['ap90', 'mw'],
    "cākri": ['ddsa'],
    "cākrika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "cākrikatā": ['mw'],
    "cākriṇa": ['mw'],
    "cākriṇaḥ": ['ap90'],
    "cākrāyaṇa": ['mw'],
    "cākṣma": ['ap90', 'cae', 'gra', 'mw'],
    "cākṣuṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "cākṣuṣajñāna": ['mw'],
    "cākṣuṣatva": ['mw'],
    "cākṣuṣya": ['bhs'],
    "cāla": ['bhs', 'cae', 'ddsa', 'mw'],
    "cālaka": ['mw'],
    "cālakaḥ": ['ap90'],
    "cālana": ['cae', 'mw'],
    "cālanaṃ": ['ap90'],
    "cālanikā": ['mw'],
    "cālanī": ['mw'],
    "cālanīya": ['ap90', 'mw'],
    "cālaḥ": ['ap90'],
    "cālesi": ['cped'],
    "cālikya": ['mw'],
    "cālita": ['cped'],
    "cāluki": ['mw'],
    "cālukya": ['mw'],
    "cālukyavikramakāla": ['mw'],
    "cālya": ['cae', 'mw'],
    "cāmara": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "cāmarachattagāhakā": ['cped'],
    "cāmaradhāri": ['mw'],
    "cāmaradhāriṇī": ['mw'],
    "cāmaragrāha": ['mw'],
    "cāmaragrāhika": ['mw'],
    "cāmaragrāhiṇī": ['mw'],
    "cāmarapuṣpa": ['mw'],
    "cāmarapuṣpaka": ['mw'],
    "cāmarasāhvaya": ['mw'],
    "cāmaravyajana": ['mw'],
    "cāmaraḥ": ['ap90'],
    "cāmarika": ['bhs', 'mw'],
    "cāmarikaḥ": ['ap90'],
    "cāmarikā": ['mw'],
    "cāmarin": ['ap90', 'mw'],
    "cāmarā": ['bhs', 'mw'],
    "cāmasya": ['mw'],
    "cāmasāyana": ['mw'],
    "cāmpeya": ['bhs', 'ddsa', 'mw'],
    "cāmpeyaka": ['mw'],
    "cāmpilā": ['mw'],
    "cāmuṃḍā": ['ap90'],
    "cāmuṇḍa": ['cae', 'ddsa', 'mw'],
    "cāmuṇḍarāja": ['mw'],
    "cāmuṇḍā": ['mw'],
    "cāmuṇḍāmantra": ['mw'],
    "cāmuṇḍātantra": ['mw'],
    "cāmuṇḍī": ['mw'],
    "cāmya": ['mw'],
    "cāmyaṃ": ['ap90'],
    "cāmīkara": ['cae', 'ddsa', 'mw'],
    "cāmīkaragaura": ['bhs'],
    "cāmīkaramaya": ['mw'],
    "cāmīkaraprakhya": ['mw'],
    "cāmīkaraṃ": ['ap90'],
    "cāmīkarācala": ['mw'],
    "cāmīkarādri": ['mw'],
    "cāmīkarīya": ['ddsa', 'mw'],
    "cānarāṭa": ['mw'],
    "cānaś": ['ddsa'],
    "cāndana": ['ddsa', 'mw'],
    "cāndanagandhika": ['mw'],
    "cāndhanāyana": ['mw'],
    "cāndra": ['cae', 'ddsa', 'mw'],
    "cāndrabhāgeya": ['mw'],
    "cāndrabhāgi": ['mw'],
    "cāndrabhāgyā": ['mw'],
    "cāndrabhāgā": ['mw'],
    "cāndrabhāgī": ['mw'],
    "cāndragupta": ['mw'],
    "cāndraka": ['mw'],
    "cāndrama": ['mw'],
    "cāndramasa": ['mw'],
    "cāndramasāyana": ['mw'],
    "cāndramasāyani": ['mw'],
    "cāndramasī": ['mw'],
    "cāndramāsa": ['mw'],
    "cāndrapura": ['mw'],
    "cāndravatsara": ['mw'],
    "cāndravratika": ['cae', 'mw'],
    "cāndri": ['mw'],
    "cāndrākhya": ['mw'],
    "cāndrāyaṇa": ['cae', 'ddsa', 'mw'],
    "cāndrāyaṇabhakta": ['mw'],
    "cāndrāyaṇavidhāna": ['mw'],
    "cāndrāyaṇavrata": ['mw'],
    "cāndrāyaṇika": ['mw'],
    "cāndrī": ['mw'],
    "cānāḥ": ['bhs'],
    "cānūra": ['mw'],
    "cāpa": ['cae', 'cped', 'ddsa', 'mw'],
    "cāpadhara": ['mw'],
    "cāpadāsī": ['mw'],
    "cāpaguṇa": ['cae', 'mw'],
    "cāpala": ['cae', 'ddsa', 'mw'],
    "cāpalasuṇa": ['cped'],
    "cāpalatā": ['ddsa', 'mw'],
    "cāpalaṃ": ['ap90'],
    "cāpalekhā": ['mw'],
    "cāpalla": ['cped'],
    "cāpalya": ['cae', 'cped', 'mw'],
    "cāpalāyana": ['mw'],
    "cāpalāśraya": ['mw'],
    "cāpanigama": ['mw'],
    "cāpapaṭa": ['mw'],
    "cāparava": ['mw'],
    "cāpavaṭa": ['mw'],
    "cāpaveda": ['cae', 'mw'],
    "cāpaya": ['mw'],
    "cāpayaṣṭi": ['cae', 'mw'],
    "cāpaḍa": ['mw'],
    "cāpaḥ": ['ap90'],
    "cāphaṭṭaki": ['mw'],
    "cāphaṭṭakya": ['mw'],
    "cāpin": ['ap90', 'cae', 'ddsa', 'mw'],
    "cāpodara": ['bhs'],
    "cāpotkaṭa": ['mw'],
    "cāppaṭṭakya": ['mw'],
    "cāpācārya": ['mw'],
    "cāpādhiropa": ['mw'],
    "cāpādhiropaṇa": ['cae'],
    "cāpāla": ['bhs', 'mw'],
    "cāpālya": ['bhs'],
    "cāpāropaṇa": ['cae', 'mw'],
    "cāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "cārabhaṭa": ['mw'],
    "cārabhaṭī": ['mw'],
    "cāracakṣus": ['cae', 'mw'],
    "cāracaṇa": ['mw'],
    "cāracuñcu": ['mw'],
    "cāradṛś": ['mw'],
    "cārajyā": ['mw'],
    "cāraka": ['ap90', 'bhs', 'cae', 'mw'],
    "cārakatrirātra": ['mw'],
    "cārakā": ['bhs'],
    "cārakīṇa": ['mw'],
    "cāramika": ['mw'],
    "cārapatha": ['mw'],
    "cārapuruṣa": ['ddsa', 'mw'],
    "cārapāla": ['mw'],
    "cāratha": ['ap90', 'cae', 'gra', 'mw'],
    "cāratūla": ['mw'],
    "cāravāyu": ['mw'],
    "cārayati": ['bhs'],
    "cārayin": ['bhs'],
    "cāraḥ": ['ap90'],
    "cāraṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "cāraṇadāra": ['mw'],
    "cāraṇaikamaya": ['mw'],
    "cāraṇatva": ['mw'],
    "cāraṇatvaṃ": ['ap90'],
    "cāraṇavaidya": ['mw'],
    "cāraṇavidya": ['mw'],
    "cāraṇaḥ": ['ap90'],
    "cāraṇika": ['cped'],
    "cāraṇī": ['mw'],
    "cāraṭikā": ['mw'],
    "cāraṭī": ['mw'],
    "cārcika": ['ap90', 'mw'],
    "cārcikya": ['cae', 'ddsa', 'mw'],
    "cārcikyaṃ": ['ap90'],
    "cārekṣaṇa": ['cae', 'ddsa', 'mw'],
    "cāri": ['bhs', 'cped'],
    "cāri(ṁ)": ['cped'],
    "cārika": ['bhs', 'mw'],
    "cārikā": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "cārin": ['ap90', 'cae', 'ddsa', 'mw'],
    "cārita": ['ap90', 'mw'],
    "cāritra": ['bhs', 'cae', 'ddsa', 'mw'],
    "cāritrakavaca": ['mw'],
    "cāritramati": ['bhs'],
    "cāritrasiṃhagaṇi": ['mw'],
    "cāritravant": ['bhs'],
    "cāritravatī": ['bhs', 'mw'],
    "cāritraṃ": ['ap90'],
    "cāritrin": ['ddsa', 'mw'],
    "cāritrya": ['cae', 'mw'],
    "cāritrā": ['mw'],
    "cāritrāvaśeṣa": ['cae'],
    "cāritta": ['cped'],
    "cārittakilamatha": ['cped'],
    "cāritārthya": ['cae', 'ddsa', 'mw'],
    "cāritārthyaṃ": ['ap90'],
    "cārivāc": ['mw'],
    "cāriṇī": ['mw'],
    "cāriṭī": ['mw'],
    "cārma": ['ap90', 'mw'],
    "cārmaṇa": ['ap90', 'mw'],
    "cārmika": ['ap90', 'cae', 'ddsa', 'mw'],
    "cārmikya": ['mw'],
    "cārmikāyaṇi": ['mw'],
    "cārmiṇa": ['mw'],
    "cārmiṇaṃ": ['ap90'],
    "cārmīya": ['mw'],
    "cāru": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "cārubhadra": ['mw'],
    "cārubhānu": ['bhs'],
    "cārubāhu": ['mw'],
    "cārucandra": ['mw'],
    "cārucaraṇa": ['bhs'],
    "cārucaryā": ['mw'],
    "cārucaryāśataka": ['mw'],
    "cāruchada": ['bhs'],
    "cārucitra": ['mw'],
    "cārucitrāṅgada": ['mw'],
    "cārudanta": ['bhs'],
    "cārudarśana": ['cae'],
    "cārudarśanā": ['mw'],
    "cārudassana": ['cped'],
    "cārudatta": ['cae', 'mw'],
    "cārudeha": ['mw'],
    "cārudeva": ['mw'],
    "cārudeṣṇa": ['mw'],
    "cārudharman": ['mw'],
    "cārudhiṣṇya": ['mw'],
    "cārudhāman": ['mw'],
    "cārudhāmā": ['mw'],
    "cārudhārā": ['mw'],
    "cārudāru": ['mw'],
    "cārugandha": ['bhs'],
    "cārugarbha": ['mw'],
    "cārughoṇa": ['mw'],
    "cārugiri": ['mw'],
    "cārugucchā": ['mw'],
    "cārugupta": ['mw'],
    "cārugāmitā": ['mw'],
    "cārugīta": ['mw'],
    "cārugīti": ['cae', 'mw'],
    "cāruhāsin": ['cae', 'mw'],
    "cāruhāsinī": ['mw'],
    "cāruka": ['mw'],
    "cārukarṇa": ['mw'],
    "cārukesarā": ['mw'],
    "cārulocana": ['cae', 'mw'],
    "cārulocanā": ['mw'],
    "cārumant": ['bhs'],
    "cārumat": ['mw'],
    "cārumati": ['mw'],
    "cārumatī": ['mw'],
    "cārumukha": ['mw'],
    "cārumukhī": ['mw'],
    "cārunetra": ['bhs', 'cae', 'mw'],
    "cārunetrā": ['mw'],
    "cārunālaka": ['mw'],
    "cārupada": ['mw'],
    "cāruparṇī": ['mw'],
    "cārupattramaya": ['mw'],
    "cārupayodhara": ['mw'],
    "cāruphalā": ['mw'],
    "cārupratīka": ['cae', 'gra', 'mw'],
    "cārupuṭa": ['mw'],
    "cāruratha": ['mw'],
    "cārurava": ['mw'],
    "cārurāvā": ['mw'],
    "cārurūpa": ['cae', 'mw'],
    "cārusarvāṅga": ['mw'],
    "cārusarvāṅgadarśana": ['mw'],
    "cārusaṃkāśin": ['mw'],
    "cārusāra": ['mw'],
    "cārutama": ['mw'],
    "cārutva": ['gra', 'mw'],
    "cārutā": ['cae', 'mw'],
    "cāruvadana": ['mw'],
    "cāruvaha": ['mw'],
    "cāruvaktra": ['mw'],
    "cāruvardhanā": ['mw'],
    "cāruvarman": ['mw'],
    "cāruvarṇa": ['bhs'],
    "cāruveśa": ['mw'],
    "cāruveṇī": ['mw'],
    "cāruveṣa": ['mw'],
    "cāruvinda": ['mw'],
    "cāruvratā": ['mw'],
    "cāruvāc": ['mw'],
    "cāruvādin": ['mw'],
    "cāruvṛkṣa": ['mw'],
    "cāruyaśas": ['mw'],
    "cāruśilā": ['mw'],
    "cāruśravas": ['mw'],
    "cāruśīrṣa": ['mw'],
    "cāruśṛṅgin": ['mw'],
    "cārv": ['mw'],
    "cārvadana": ['mw'],
    "cārvāc": ['mw'],
    "cārvādi": ['mw'],
    "cārvāghāta": ['mw'],
    "cārvāghāṭa": ['mw'],
    "cārvāka": ['cae', 'ddsa', 'mw'],
    "cārvākadarśana": ['mw'],
    "cārvākamata": ['mw'],
    "cārvākamatanibarhaṇa": ['mw'],
    "cārvākaḥ": ['ap90'],
    "cārvāṭa": ['mw'],
    "cārvī": ['ap90', 'mw'],
    "cārya": ['cae', 'ddsa', 'mw'],
    "cārādhikāra": ['mw'],
    "cārādhikārin": ['mw'],
    "cārāntarita": ['mw'],
    "cārāyaṇa": ['bhs', 'mw'],
    "cārāyaṇaka": ['mw'],
    "cārāyaṇī": ['mw'],
    "cārāyaṇīya": ['mw'],
    "cārī": ['mw'],
    "cārīkā": ['bhs'],
    "cāsa": ['mw'],
    "cātaka": ['cae', 'ddsa', 'mw'],
    "cātakaḥ": ['ap90'],
    "cātaki": ['mw'],
    "cātakānandana": ['mw'],
    "cātakāy": ['cae'],
    "cātakāṣṭaka": ['mw'],
    "cātakī": ['mw'],
    "cātana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cātraṃ": ['ap90'],
    "cāttarātra": ['mw'],
    "cāttra": ['cae', 'mw'],
    "cātuddasa": ['cped'],
    "cātuddasika": ['cped'],
    "cātuddasī": ['cped'],
    "cātuddasīṁ": ['cped'],
    "cātuddisa": ['cped'],
    "cātuddīpa": ['cped'],
    "cātuddīpaka": ['cped'],
    "cātudvīpa": ['bhs'],
    "cātumahābhūtika": ['cped'],
    "cātumahāpatha": ['cped'],
    "cātumahārājika": ['cped'],
    "cātummahābhūtika": ['cped'],
    "cātummahāpatha": ['cped'],
    "cātummahārājika": ['cped'],
    "cātummāsa": ['cped'],
    "cātumāsa": ['cped'],
    "cātumāsā": ['cped'],
    "cātumāsīnī": ['cped'],
    "cātura": ['ap90', 'ddsa', 'mw'],
    "cāturaka": ['ap90', 'mw'],
    "cāturakṣa": ['bhs', 'mw'],
    "cāturakṣaṃ": ['ap90'],
    "cāturanta": ['bhs', 'cped'],
    "cāturarthika": ['mw'],
    "cāturarthikaḥ": ['ap90'],
    "cāturarṇavānta": ['bhs'],
    "cāturbhadra": ['mw'],
    "cāturbhadraka": ['mw'],
    "cāturbhautika": ['ap90', 'mw'],
    "cāturbhuji": ['mw'],
    "cāturbīja": ['mw'],
    "cāturdaiva": ['mw'],
    "cāturdaśa": ['ap90', 'mw'],
    "cāturdaśika": ['ap90', 'bhs', 'mw'],
    "cāturdeva": ['bhs'],
    "cāturdhākāraṇika": ['ddsa', 'mw'],
    "cāturdiśa": ['bhs'],
    "cāturdvīpa": ['bhs'],
    "cāturdvīpaka": ['bhs'],
    "cāturdvīpeśvara": ['bhs'],
    "cāturdvīpika": ['bhs'],
    "cāturhotra": ['ap90', 'cae', 'mw'],
    "cāturhotriya": ['mw'],
    "cāturhotriyaḥ": ['ap90'],
    "cāturhotrīyabrāhmaṇa": ['mw'],
    "cāturhotṛka": ['mw'],
    "cāturika": ['mw'],
    "cāturikaḥ": ['ap90'],
    "cāturjāta": ['mw'],
    "cāturjātaka": ['mw'],
    "cāturmahābhautika": ['bhs'],
    "cāturmahābhūtika": ['bhs'],
    "cāturmahādvīpaka": ['bhs'],
    "cāturmahārājakāyika": ['bhs', 'mw'],
    "cāturmahārājika": ['bhs', 'mw'],
    "cāturmāsa": ['ap90', 'mw'],
    "cāturmāsaka": ['ap90', 'mw'],
    "cāturmāsika": ['mw'],
    "cāturmāsin": ['mw'],
    "cāturmāsya": ['cae', 'mw'],
    "cāturmāsyadevatā": ['mw'],
    "cāturmāsyakārikā": ['mw'],
    "cāturmāsyatva": ['mw'],
    "cāturmāsyayājin": ['mw'],
    "cāturmāsyaṃ": ['ap90'],
    "cāturmāsī": ['ddsa', 'mw'],
    "cāturtha": ['ddsa', 'mw'],
    "cāturthaka": ['ap90', 'cae', 'mw'],
    "cāturthakārirasa": ['mw'],
    "cāturthika": ['cae', 'mw'],
    "cāturthya": ['bhs'],
    "cāturthāhnika": ['ap90', 'mw'],
    "cāturvaidya": ['cae', 'mw'],
    "cāturvarṇya": ['ap90', 'cae', 'ddsa', 'mw'],
    "cāturvedya": ['mw'],
    "cāturvidhya": ['mw'],
    "cāturvidhyaṃ": ['ap90'],
    "cāturvidya": ['ap90', 'cae', 'mw'],
    "cāturviṃśaka": ['mw'],
    "cāturviṃśika": ['mw'],
    "cāturya": ['cae', 'ddsa', 'mw'],
    "cāturyacintāmaṇi": ['mw'],
    "cāturyaṃ": ['ap90'],
    "cāturāryasatya": ['bhs'],
    "cāturāśramika": ['ap90', 'mw'],
    "cāturāśramin": ['mw'],
    "cāturāśramya": ['mw'],
    "cāturāśramyaṃ": ['ap90'],
    "cāturī": ['mw'],
    "cātuvaṇṇi(n)": ['cped'],
    "cātuyāmasaṁvara": ['cped'],
    "cātuyāmasusaṁvuta": ['cped'],
    "cātuścaraṇika": ['mw'],
    "cātuścaraṇikā": ['mw'],
    "cātuḥsvarya": ['mw'],
    "cātuḥsāgarika": ['mw'],
    "cātuḥśabdya": ['mw'],
    "cātuḥṣaṣṭika": ['mw'],
    "cātuṣkoṭika": ['bhs', 'mw'],
    "cātuṣkāṃḍika": ['ap90'],
    "cātuṣpada": ['bhs'],
    "cātuṣpadaka": ['bhs'],
    "cātuṣpatha": ['ddsa', 'mw'],
    "cātuṣprāharika": ['mw'],
    "cātuṣprāśya": ['cae', 'mw'],
    "cātuṣpāda": ['bhs'],
    "cātuṣṭaya": ['ap90', 'mw'],
    "cātvāla": ['ddsa', 'mw'],
    "cātvālavat": ['mw'],
    "cātvālaḥ": ['ap90'],
    "cātvāriṃśa": ['mw'],
    "cātvāriṃśatka": ['mw'],
    "cāt‍tra": ['ddsa'],
    "cāvana": ['cped'],
    "cāvanādhipāya": ['cped'],
    "cāvayamanā": ['cped'],
    "cāvayati": ['cped'],
    "cāvesi": ['cped'],
    "cāvetabba": ['cped'],
    "cāveti": ['cped'],
    "cāy": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "cāyaka": ['mw'],
    "cāyamāna": ['gra', 'mw'],
    "cāyanīya": ['ap90', 'ddsa', 'mw'],
    "cāyitṛ": ['ap90', 'mw'],
    "cāyu": ['ap90', 'cae', 'gra', 'mw'],
    "cāñcalya": ['cae', 'ddsa', 'mw'],
    "cāñcava": ['ddsa', 'mw'],
    "cāṃcalyaṃ": ['ap90'],
    "cāṃdanika": ['ap90'],
    "cāṃdra": ['ap90'],
    "cāṃdrakaṃ": ['ap90'],
    "cāṃdramasa": ['ap90'],
    "cāṃdramasāyanaḥ": ['ap90'],
    "cāṃdrāyaṇaṃ": ['ap90'],
    "cāṃdrāyaṇika": ['ap90'],
    "cāṃgaḥ": ['ap90'],
    "cāṃpeyakaṃ": ['ap90'],
    "cāṃpeyaḥ": ['ap90'],
    "cāṃpilā": ['ap90'],
    "cāṃḍaṃ": ['ap90'],
    "cāṃḍālaḥ": ['ap90'],
    "cāṃḍālikā": ['ap90'],
    "cāṅga": ['mw'],
    "cāṅgerī": ['mw'],
    "cāṇaka": ['mw'],
    "cāṇakya": ['cae', 'ddsa', 'mw'],
    "cāṇakyamūlaka": ['mw'],
    "cāṇakyaśloka": ['mw'],
    "cāṇakyaḥ": ['ap90'],
    "cāṇakīna": ['ap90', 'mw'],
    "cāṇārarūpya": ['mw'],
    "cāṇūra": ['cae', 'ddsa', 'mw'],
    "cāṇūramardana": ['mw'],
    "cāṇūrasūdana": ['mw'],
    "cāṇūraḥ": ['ap90'],
    "cāṇḍa": ['mw'],
    "cāṇḍikā": ['bhs', 'mw'],
    "cāṇḍāla": ['cae', 'ddsa', 'mw'],
    "cāṇḍālaka": ['mw'],
    "cāṇḍālaki": ['mw'],
    "cāṇḍālaveśa": ['mw'],
    "cāṇḍāli": ['mw'],
    "cāṇḍālikā": ['mw'],
    "cāṇḍālikāśrama": ['mw'],
    "cāṇḍālinī": ['mw'],
    "cāṇḍālī": ['mw'],
    "cāṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "cāṣamaya": ['mw'],
    "cāṣavaktra": ['mw'],
    "cāṣaḥ": ['ap90'],
    "cāṭa": ['cae', 'ddsa', 'mw'],
    "cāṭabhaṭa": ['mw'],
    "cāṭaka": ['bhs'],
    "cāṭakadeśa": ['mw'],
    "cāṭakaira": ['mw'],
    "cāṭakairaḥ": ['ap90'],
    "cāṭakāyana": ['mw'],
    "cāṭalikā": ['ddsa', 'mw'],
    "cāṭaḥ": ['ap90'],
    "cāṭi": ['cped'],
    "cāṭigrāma": ['mw'],
    "cāṭu": ['cae', 'ddsa', 'mw'],
    "cāṭuka": ['mw'],
    "cāṭukaśata": ['mw'],
    "cāṭukaḥ": ['ap90'],
    "cāṭukāra": ['cae', 'mw'],
    "cāṭukārin": ['mw'],
    "cāṭulola": ['mw'],
    "cāṭupaṭu": ['mw'],
    "cāṭuvacana": ['mw'],
    "cāṭuvaṭu": ['mw'],
    "cāṭuśata": ['mw'],
    "cāṭuḥ": ['ap90'],
    "cāṭī": ['cped'],
    "cāṭūkti": ['mw'],
    "cīb": ['mw'],
    "cībh": ['ap90', 'mw'],
    "cīcīkūcī": ['mw'],
    "cīk": ['ap90', 'mw'],
    "cīlikā": ['ap90', 'mw'],
    "cīllakā": ['mw'],
    "cīna": ['cae', 'ddsa', 'mw'],
    "cīnaja": ['mw'],
    "cīnaka": ['mw'],
    "cīnakarkaṭikā": ['mw'],
    "cīnakarpūra": ['mw'],
    "cīnapati": ['mw'],
    "cīnapaṭṭa": ['mw'],
    "cīnapiṣṭa": ['mw'],
    "cīnapiṣṭamaya": ['mw'],
    "cīnarājaputra": ['mw'],
    "cīnasicaya": ['mw'],
    "cīnavaṅga": ['mw'],
    "cīnaḥ": ['ap90'],
    "cīnācāraprayogavidhi": ['mw'],
    "cīnāka": ['mw'],
    "cīnākarkaṭī": ['mw'],
    "cīnākaḥ": ['ap90'],
    "cīnāṃśuka": ['cae', 'mw'],
    "cīpudru": ['mw'],
    "cīra": ['cae', 'ddsa', 'mw'],
    "cīrabhavantī": ['mw'],
    "cīrabhṛt": ['mw'],
    "cīracīracīvaraka": ['bhs'],
    "cīracīvara": ['cae', 'mw'],
    "cīraka": ['bhs'],
    "cīrakavāsika": ['cped'],
    "cīrakaḥ": ['ap90'],
    "cīrakhaṇḍa": ['mw'],
    "cīrakā": ['mw'],
    "cīralli": ['mw'],
    "cīramocana": ['mw'],
    "cīranivasana": ['mw'],
    "cīraparṇa": ['mw'],
    "cīrapattrikā": ['mw'],
    "cīraprāvaraṇa": ['mw'],
    "cīravasana": ['cae', 'mw'],
    "cīravāsas": ['cae', 'mw'],
    "cīraṃ": ['ap90'],
    "cīri": ['mw'],
    "cīrikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "cīrikāsadda": ['cped'],
    "cīrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "cīrita": ['ap90', 'mw'],
    "cīritacchadā": ['mw'],
    "cīritapattrikā": ['mw'],
    "cīriḥ": ['ap90'],
    "cīriḷikā": ['cped'],
    "cīriḷikāsadda": ['cped'],
    "cīriṇī": ['mw'],
    "cīruka": ['mw'],
    "cīrukā": ['ap90', 'mw'],
    "cīrā": ['mw'],
    "cīrāmbara": ['mw'],
    "cīrī": ['ddsa', 'mw'],
    "cīrīvāka": ['cae', 'mw'],
    "cīrṇa": ['ap90', 'ddsa', 'mw'],
    "cīrṇakarkaṭī": ['mw'],
    "cīrṇaparṇa": ['mw'],
    "cīrṇavrata": ['cae', 'mw'],
    "cīt": ['mw'],
    "cīti": ['cae', 'mw'],
    "cītkāra": ['cae', 'ddsa', 'mw'],
    "cītkāravant": ['cae'],
    "cītkāravat": ['mw'],
    "cītkāraḥ": ['ap90'],
    "cītkṛta": ['cae', 'mw'],
    "cītkṛti": ['mw'],
    "cīv": ['ap90', 'mw'],
    "cīvara": ['cae', 'cped', 'ddsa', 'mw'],
    "cīvarabhajaka": ['mw'],
    "cīvarabhisī": ['cped'],
    "cīvarabhājaka": ['cped'],
    "cīvaracetāpana": ['cped'],
    "cīvaracetāpanna": ['cped'],
    "cīvaradhāraṇa": ['cped'],
    "cīvaradussa": ['cped'],
    "cīvaragopaka": ['bhs', 'mw'],
    "cīvarahetu": ['cped'],
    "cīvaraka": ['bhs'],
    "cīvarakamma": ['cped'],
    "cīvarakarman": ['mw'],
    "cīvarakarṇika": ['mw'],
    "cīvarakālasamaya": ['cped'],
    "cīvarakārasamaya": ['cped'],
    "cīvaralesa": ['cped'],
    "cīvaranidahaka": ['cped'],
    "cīvaranidāhaka": ['cped'],
    "cīvaranivasana": ['mw'],
    "cīvarapaccāsā": ['cped'],
    "cīvarapaṭiggāhaka": ['cped'],
    "cīvarapaṭivisa": ['cped'],
    "cīvarapaṭiviṁsa": ['cped'],
    "cīvarapaṭivīsa": ['cped'],
    "cīvararajju": ['cped'],
    "cīvarasaṅkamanīya": ['cped'],
    "cīvaravat": ['mw'],
    "cīvaravaṁsa": ['cped'],
    "cīvaravibhaṅga": ['cped'],
    "cīvaravicāraṇa": ['cped'],
    "cīvaraya": ['mw'],
    "cīvaraṃ": ['ap90'],
    "cīvarika": ['bhs'],
    "cīvarin": ['ap90', 'mw'],
    "cīvillikā": ['mw'],
    "cīvivāc": ['mw'],
    "cīy": ['mw'],
    "cīyate": ['cped'],
    "cīyati": ['cped'],
    "cīāka": ['mw'],
    "cīḍā": ['mw'],
    "cīṇa": ['mw'],
    "cīṇaka": ['mw'],
    "cīṭhikā": ['mw'],
    "cūcuka": ['cae', 'ddsa', 'mw'],
    "cūcukatā": ['mw'],
    "cūcukaṃ": ['ap90'],
    "cūcukāgra": ['mw'],
    "cūcupa": ['mw'],
    "cūla": ['mw'],
    "cūlaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "cūlapanthaka": ['bhs'],
    "cūlaḥ": ['ap90'],
    "cūlha": ['cae'],
    "cūlika": ['mw'],
    "cūlikaṃ": ['ap90'],
    "cūlikopaniṣad": ['mw'],
    "cūlikā": ['ap90', 'mw'],
    "cūlikāpaiśācika": ['mw'],
    "cūlikāpaiśācī": ['mw'],
    "cūlin": ['ap90', 'cae', 'ddsa', 'mw'],
    "cūlitaka": ['mw'],
    "cūlla": ['bhs'],
    "cūlā": ['mw'],
    "cūlīyā": ['bhs'],
    "cūr": ['ap90', 'cae', 'ddsa', 'mw'],
    "cūrti": ['mw'],
    "cūrtiḥ": ['ap90'],
    "cūru": ['cae', 'ddsa', 'mw'],
    "cūrī": ['ap90', 'mw'],
    "cūrṇ": ['ap90', 'mw'],
    "cūrṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "cūrṇaka": ['mw'],
    "cūrṇakaḥ": ['ap90'],
    "cūrṇakeśa": ['mw'],
    "cūrṇakhaṇḍa": ['mw'],
    "cūrṇakuntala": ['mw'],
    "cūrṇakuṭṭa": ['bhs'],
    "cūrṇakāra": ['mw'],
    "cūrṇakṛt": ['mw'],
    "cūrṇamuṣṭi": ['mw'],
    "cūrṇana": ['cae', 'ddsa', 'mw'],
    "cūrṇanaṃ": ['ap90'],
    "cūrṇapada": ['ddsa', 'mw'],
    "cūrṇapeṣam": ['mw'],
    "cūrṇapārada": ['mw'],
    "cūrṇatva": ['mw'],
    "cūrṇatā": ['mw'],
    "cūrṇavṛddhi": ['cae', 'mw'],
    "cūrṇay": ['cae'],
    "cūrṇaya": ['ddsa'],
    "cūrṇayoga": ['mw'],
    "cūrṇaśas": ['cae', 'mw'],
    "cūrṇaśākāṅka": ['mw'],
    "cūrṇaḥ": ['ap90'],
    "cūrṇi": ['mw'],
    "cūrṇika": ['bhs'],
    "cūrṇikā": ['ap90', 'mw'],
    "cūrṇikāra": ['mw'],
    "cūrṇikṛt": ['mw'],
    "cūrṇin": ['ap90', 'mw'],
    "cūrṇita": ['ap90', 'mw'],
    "cūrṇiḥ": ['ap90'],
    "cūrṇādi": ['mw'],
    "cūrṇī": ['mw'],
    "cūrṇībhū": ['ap90', 'mw'],
    "cūrṇīcikīrṣu": ['mw'],
    "cūrṇīkaraṇa": ['cae', 'mw'],
    "cūrṇīkṛ": ['ap90', 'ddsa', 'mw'],
    "cūrṇīkṛta": ['mw'],
    "cūta": ['cae', 'ddsa', 'mw'],
    "cūtaka": ['mw'],
    "cūtakaḥ": ['ap90'],
    "cūtalatikā": ['cae', 'mw'],
    "cūtamañjarī": ['cae', 'mw'],
    "cūtaśara": ['cae'],
    "cūtaḥ": ['ap90'],
    "cūti": ['mw'],
    "cūtiḥ": ['ap90'],
    "cūḍa": ['bhs', 'cae', 'ddsa', 'mw'],
    "cūḍaka": ['mw'],
    "cūḍakaḥ": ['ap90'],
    "cūḍakā": ['bhs', 'mw'],
    "cūḍapanthaka": ['bhs'],
    "cūḍaya": ['mw'],
    "cūḍaḥ": ['ap90'],
    "cūḍeśvara": ['bhs'],
    "cūḍika": ['ap90', 'bhs', 'mw'],
    "cūḍikalā": ['mw'],
    "cūḍikā": ['mw'],
    "cūḍikābaddha": ['bhs'],
    "cūḍikāvabaddha": ['bhs'],
    "cūḍin": ['mw'],
    "cūḍitaka": ['mw'],
    "cūḍitika": ['mw'],
    "cūḍopanayana": ['mw'],
    "cūḍā": ['ap90', 'bhs', 'mw'],
    "cūḍābhikṣuṇī": ['mw'],
    "cūḍādanta": ['mw'],
    "cūḍākaraṇa": ['cae', 'ddsa', 'mw'],
    "cūḍākarman": ['cae', 'mw'],
    "cūḍākarṇa": ['mw'],
    "cūḍāla": ['ddsa', 'mw'],
    "cūḍālakṣaṇa": ['mw'],
    "cūḍālaveśa": ['mw'],
    "cūḍālā": ['mw'],
    "cūḍāmaha": ['bhs', 'mw'],
    "cūḍāmaṇi": ['cae', 'mw'],
    "cūḍāmaṇibhaṭṭācārya": ['mw'],
    "cūḍāmaṇidhara": ['bhs', 'mw'],
    "cūḍāmaṇitā": ['mw'],
    "cūḍāmla": ['mw'],
    "cūḍāmlaṃ": ['ap90'],
    "cūḍāpakṣāvadāna": ['mw'],
    "cūḍāpanthaka": ['bhs'],
    "cūḍāpratigrahaṇa": ['bhs', 'mw'],
    "cūḍāpāśa": ['mw'],
    "cūḍāpīḍa": ['cae'],
    "cūḍāra": ['ap90', 'mw'],
    "cūḍāraka": ['mw'],
    "cūḍāratna": ['mw'],
    "cūḍārha": ['mw'],
    "cūḍāvalambin": ['mw'],
    "cūḍāvana": ['mw'],
    "cūḍāvat": ['mw'],
    "cūḍīya": ['mw'],
    "cūḷanika": ['cped'],
    "cūḷasīla": ['cped'],
    "cūḷikābaddha": ['cped'],
    "cūḷāsīti": ['cped'],
    "cūṃkṛta": ['mw'],
    "cūṇ": ['ap90', 'mw'],
    "cūṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "cūṣaka": ['bhs'],
    "cūṣaṇa": ['cae', 'ddsa', 'mw'],
    "cūṣaṇīya": ['mw'],
    "cūṣita": ['mw'],
    "cūṣiṇī": ['mw'],
    "cūṣya": ['mw'],
    "cūṣyaṃ": ['ap90'],
    "cūṣyā": ['mw'],
    "cūṣā": ['ap90', 'mw'],
    "cṛp": ['mw'],
    "cṛt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "da": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "daasvat": ['gra'],
    "dabba": ['cped'],
    "dabbajātika": ['cped'],
    "dabbha": ['cped'],
    "dabbigāha": ['cped'],
    "dabbī": ['cped'],
    "dabbīhoma": ['cped'],
    "dabdha": ['mw'],
    "dabdhi": ['mw'],
    "dabdhiḥ": ['ap90'],
    "dabh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dabha": ['cae', 'gra', 'mw'],
    "dabhaḥ": ['ap90'],
    "dabhia": ['gra'],
    "dabhna": ['mw'],
    "dabhra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dabhrabuddhi": ['mw'],
    "dabhracetas": ['gra', 'mw'],
    "dabhram": ['mw'],
    "dabhya": ['cae', 'ddsa', 'gra', 'mw'],
    "dabhīti": ['cae', 'ddsa', 'gra', 'mw'],
    "dacchada": ['cae', 'ddsa', 'mw'],
    "dad": ['ap90', 'cae', 'gra', 'mw'],
    "dada": ['ap90', 'bhs', 'cae', 'mw'],
    "dada(t)": ['cped'],
    "dadadas": ['mw'],
    "dadamāna": ['cped'],
    "dadana": ['bhs', 'mw'],
    "dadanaṃ": ['ap90'],
    "dadanta": ['cped'],
    "dadantaka": ['bhs'],
    "dadantu": ['cped'],
    "dadari": ['mw'],
    "dadda": ['mw'],
    "daddallamāna": ['cped'],
    "daddara": ['cped'],
    "daddu": ['cped'],
    "daddulabhakka": ['cped'],
    "dade": ['cped'],
    "dadehi": ['cped'],
    "dadetha": ['cped'],
    "dadeyya": ['cped'],
    "dadeyyaṁ": ['cped'],
    "dadeyyuṁ": ['cped'],
    "dadeyyāma": ['cped'],
    "dadeyyāsi": ['cped'],
    "dadh": ['ap90', 'ddsa', 'mw'],
    "dadha": ['ap90', 'mw'],
    "dadhan": ['cae', 'ddsa', 'gra', 'mw'],
    "dadhana": ['mw'],
    "dadhanvant": ['cae'],
    "dadhanvat": ['gra', 'mw'],
    "dadhate": ['cped'],
    "dadhi": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dadhiac": ['gra'],
    "dadhibhakta": ['cae'],
    "dadhibhakṣa": ['mw'],
    "dadhibhāṇḍa": ['cae', 'mw'],
    "dadhicāra": ['mw'],
    "dadhidhenu": ['mw'],
    "dadhidhānī": ['mw'],
    "dadhidrapsa": ['cae', 'mw'],
    "dadhighana": ['mw'],
    "dadhigharma": ['mw'],
    "dadhigharmahoma": ['mw'],
    "dadhigraha": ['mw'],
    "dadhigrahapātra": ['mw'],
    "dadhija": ['mw'],
    "dadhika": ['mw'],
    "dadhikarṇa": ['cae', 'ddsa', 'mw'],
    "dadhikaṭuka": ['mw'],
    "dadhikra": ['mw'],
    "dadhikrā": ['cae', 'gra', 'mw'],
    "dadhikrāvan": ['cae', 'gra', 'mw'],
    "dadhikrāvatī": ['mw'],
    "dadhikulyā": ['mw'],
    "dadhikūrcikā": ['mw'],
    "dadhimantha": ['mw'],
    "dadhimanthana": ['mw'],
    "dadhimaṇḍa": ['cae', 'mw'],
    "dadhimaṇḍaka": ['cped'],
    "dadhimaṇḍoda": ['mw'],
    "dadhimaṇḍodaka": ['mw'],
    "dadhimukha": ['bhs', 'mw'],
    "dadhimālin": ['bhs'],
    "dadhinadī": ['mw'],
    "dadhiparṇa": ['mw'],
    "dadhipayas": ['mw'],
    "dadhiphala": ['mw'],
    "dadhipiṇḍa": ['mw'],
    "dadhipradyotika": ['bhs'],
    "dadhipuccha": ['ddsa', 'mw'],
    "dadhipuṣpikā": ['mw'],
    "dadhipuṣpī": ['mw'],
    "dadhipūpaka": ['mw'],
    "dadhipūraṇa": ['mw'],
    "dadhipūrvamukha": ['mw'],
    "dadhipṛṣātaka": ['mw'],
    "dadhisaktu": ['mw'],
    "dadhisambhava": ['mw'],
    "dadhisamudra": ['mw'],
    "dadhisaṃbhava": ['cae'],
    "dadhiskanda": ['mw'],
    "dadhisneha": ['mw'],
    "dadhisveda": ['mw'],
    "dadhisya": ['mw'],
    "dadhisyati": ['ap90'],
    "dadhisāra": ['mw'],
    "dadhittha": ['cae', 'ddsa', 'mw'],
    "dadhittharasa": ['mw'],
    "dadhitthaḥ": ['ap90'],
    "dadhitthākhya": ['mw'],
    "dadhivaktra": ['mw'],
    "dadhivant": ['cae'],
    "dadhivat": ['mw'],
    "dadhividarbha": ['mw'],
    "dadhivāhana": ['mw'],
    "dadhivāmana": ['mw'],
    "dadhivāri": ['mw'],
    "dadhiāśir": ['gra'],
    "dadhiśara": ['mw'],
    "dadhiśoṇa": ['mw'],
    "dadhiṣu": ['cae', 'mw'],
    "dadhiṣāyya": ['mw'],
    "dadhiṣāyyaḥ": ['ap90'],
    "dadhna": ['mw'],
    "dadhy": ['mw'],
    "dadhyac": ['gra', 'mw'],
    "dadhyagra": ['mw'],
    "dadhyanna": ['ddsa', 'mw'],
    "dadhyasya": ['mw'],
    "dadhyañc": ['cae'],
    "dadhyika": ['bhs'],
    "dadhyodana": ['cae', 'mw'],
    "dadhyuda": ['mw'],
    "dadhyuttara": ['mw'],
    "dadhyuttaraga": ['mw'],
    "dadhyuttarā": ['mw'],
    "dadhyāhva": ['mw'],
    "dadhyāhvaya": ['mw'],
    "dadhyākara": ['mw'],
    "dadhyānī": ['mw'],
    "dadhyāśir": ['gra', 'mw'],
    "dadhāti": ['cped'],
    "dadhīca": ['mw'],
    "dadhīcakṣupasaṃvāda": ['mw'],
    "dadhīcaḥ": ['ap90'],
    "dadhīci": ['mw'],
    "dadhīcyasthi": ['mw'],
    "dadhīmukha": ['mw'],
    "dadhīy": ['cae'],
    "dadhīya": ['mw'],
    "dadhṛk": ['gra', 'mw'],
    "dadhṛṣ": ['cae', 'ddsa', 'mw'],
    "dadhṛṣa": ['gra', 'mw'],
    "dadhṛṣi": ['mw'],
    "dadhṛṣvaṇi": ['cae', 'gra', 'mw'],
    "dadhṛṣvān": ['ddsa'],
    "dadi": ['cae', 'gra', 'mw'],
    "dadittha": ['mw'],
    "daditvā": ['cped'],
    "daditṛ": ['cae', 'mw'],
    "dadiṁsu": ['cped'],
    "dadru": ['cae', 'ddsa', 'mw'],
    "dadrughna": ['mw'],
    "dadruka": ['mw'],
    "dadrukaḥ": ['ap90'],
    "dadrukuṣṭha": ['mw'],
    "dadrula": ['bhs'],
    "dadrunāśinī": ['mw'],
    "dadruroga": ['mw'],
    "dadrurogin": ['mw'],
    "dadruḥ": ['ap90'],
    "dadruṇa": ['ap90', 'cae', 'mw'],
    "dadrū": ['cae', 'mw'],
    "dadrūghna": ['mw'],
    "dadrūrogin": ['mw'],
    "dadrūṇa": ['ap90', 'mw'],
    "dadā": ['mw'],
    "dadāma": ['cped'],
    "dadāmase": ['cped'],
    "dadāti": ['cae', 'cped', 'ddsa', 'mw'],
    "dadāyudha": ['mw'],
    "dadṛt": ['mw'],
    "dadṛśānapavi": ['ddsa', 'gra', 'mw'],
    "dagdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "dagdhajaṭhara": ['mw'],
    "dagdhakilbiṣa": ['cae', 'mw'],
    "dagdhakāka": ['mw'],
    "dagdhamandirasāra": ['mw'],
    "dagdhamaraṇa": ['mw'],
    "dagdhamatsya": ['mw'],
    "dagdhaputra": ['mw'],
    "dagdharatha": ['mw'],
    "dagdharuha": ['mw'],
    "dagdharuhā": ['mw'],
    "dagdhavarṇaka": ['mw'],
    "dagdhavraṇa": ['mw'],
    "dagdhavya": ['ddsa', 'mw'],
    "dagdhayoni": ['mw'],
    "dagdheṣṭakā": ['mw'],
    "dagdhikā": ['ap90'],
    "dagdhodara": ['ddsa', 'mw'],
    "dagdhodarābhibhūta": ['bhs'],
    "dagdhā": ['mw'],
    "dagdhākṣara": ['mw'],
    "dagdhānna": ['mw'],
    "dagdhṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "dagh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "daghna": ['ap90', 'cae', 'ddsa', 'mw'],
    "dagodara": ['bhs'],
    "dagu": ['mw'],
    "dagārgala": ['mw'],
    "dagārgalaṃ": ['ap90'],
    "dah": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "daha": ['cped'],
    "daha(t)": ['cped'],
    "dahadahā": ['mw'],
    "dahana": ['ap90', 'cae', 'ddsa', 'mw'],
    "dahanagarbha": ['mw'],
    "dahanakalpa": ['mw'],
    "dahanakarman": ['mw'],
    "dahanaketana": ['mw'],
    "dahanapriyā": ['mw'],
    "dahanarkṣa": ['mw'],
    "dahanasārathi": ['mw'],
    "dahanatā": ['mw'],
    "dahanavat": ['mw'],
    "dahanolkā": ['mw'],
    "dahanopakaraṇa": ['mw'],
    "dahanopala": ['mw'],
    "dahanta": ['cped'],
    "dahanā": ['mw'],
    "dahanāguru": ['mw'],
    "dahanārāti": ['mw'],
    "dahanī": ['mw'],
    "dahanīya": ['ap90', 'mw'],
    "dahanīyatva": ['mw'],
    "dahanīyatā": ['mw'],
    "dahara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "daharaka": ['bhs', 'cped', 'mw'],
    "daharapṛṣṭha": ['mw'],
    "daharasūtra": ['mw'],
    "daharatagge": ['cped'],
    "dahati": ['bhs', 'cped', 'mw'],
    "dahetvā": ['cped'],
    "dahitvā": ['cped'],
    "dahra": ['ap90', 'bhs', 'cae', 'mw'],
    "dahram": ['mw'],
    "dahrāgni": ['mw'],
    "dahuka": ['bhs'],
    "dahyu": ['mw'],
    "dahāpeti": ['cped'],
    "dai": ['ap90', 'ddsa', 'mw'],
    "daidhiṣavya": ['mw'],
    "daigambara": ['mw'],
    "daihika": ['ap90', 'cae', 'ddsa', 'mw'],
    "daihya": ['ap90', 'ddsa', 'mw'],
    "daikṣa": ['cae', 'ddsa', 'mw'],
    "dailīpi": ['mw'],
    "daina": ['ap90', 'mw'],
    "dainaṃ": ['ap90'],
    "dainaṃdina": ['mw'],
    "dainaṃdinadānakāṇḍa": ['mw'],
    "dainaṃdinapralaya": ['mw'],
    "dainaṃdinasadācāradarpaṇa": ['mw'],
    "dainika": ['mw'],
    "dainikī": ['ap90', 'mw'],
    "dainya": ['cae', 'ddsa', 'mw'],
    "dainyatā": ['bhs'],
    "daipa": ['ddsa', 'mw'],
    "dairgha": ['mw'],
    "dairgharātrika": ['mw'],
    "dairghatama": ['mw'],
    "dairghatamasa": ['mw'],
    "dairghavaratra": ['mw'],
    "dairghaśravasa": ['mw'],
    "dairghya": ['cae', 'ddsa', 'mw'],
    "dairghyaṃ": ['ap90'],
    "daiteya": ['cae', 'mw'],
    "daiteyaḥ": ['ap90'],
    "daiteyī": ['mw'],
    "daitya": ['cae', 'ddsa', 'mw'],
    "daityadeva": ['mw'],
    "daityadvīpa": ['mw'],
    "daityadānavamardana": ['cae', 'mw'],
    "daityaguru": ['mw'],
    "daityahan": ['mw'],
    "daityahantṛ": ['cae', 'mw'],
    "daityamedaja": ['mw'],
    "daityamedajā": ['mw'],
    "daityamātṛ": ['mw'],
    "daityanibarhaṇa": ['cae'],
    "daityanisūdana": ['mw'],
    "daityaniṣūdana": ['cae', 'mw'],
    "daityanāśana": ['mw'],
    "daityapa": ['mw'],
    "daityapati": ['mw'],
    "daityapurodhas": ['mw'],
    "daityapurohita": ['mw'],
    "daityapūjya": ['mw'],
    "daityartvij": ['mw'],
    "daityasenā": ['mw'],
    "daityayuga": ['mw'],
    "daityaḥ": ['ap90'],
    "daityejya": ['mw'],
    "daityendra": ['cae', 'mw'],
    "daityendrapūjya": ['mw'],
    "daityā": ['ap90', 'mw'],
    "daityāhorātra": ['mw'],
    "daityāntaka": ['cae', 'mw'],
    "daityāri": ['cae', 'mw'],
    "daityāripaṇḍita": ['mw'],
    "daityāya": ['mw'],
    "daiva": ['ap90', 'cae', 'ddsa', 'mw'],
    "daivacintaka": ['mw'],
    "daivacintana": ['mw'],
    "daivacintā": ['mw'],
    "daivadarśanin": ['mw'],
    "daivadatta": ['ddsa', 'mw'],
    "daivadattaśaṭhin": ['mw'],
    "daivadatti": ['mw'],
    "daivadattika": ['mw'],
    "daivadoṣa": ['mw'],
    "daivadurvipāka": ['cae', 'mw'],
    "daivadārava": ['mw'],
    "daivadīpa": ['mw'],
    "daivagati": ['cae', 'mw'],
    "daivahata": ['mw'],
    "daivahataka": ['cae', 'mw'],
    "daivahava": ['mw'],
    "daivahavya": ['mw'],
    "daivahīna": ['mw'],
    "daivajana": ['mw'],
    "daivajña": ['cae', 'mw'],
    "daivajñabhūṣaṇa": ['mw'],
    "daivajñacintāmaṇi": ['mw'],
    "daivajñadīpakalikā": ['mw'],
    "daivajñadīpikā": ['mw'],
    "daivajñajātaka": ['mw'],
    "daivajñakalānidhi": ['mw'],
    "daivajñamanohara": ['mw'],
    "daivajñamukhamaṇḍana": ['mw'],
    "daivajñasanmuni": ['mw'],
    "daivajñatva": ['mw'],
    "daivajñavallabha": ['mw'],
    "daivajñavallabhā": ['mw'],
    "daivajñavidhivilāsa": ['mw'],
    "daivajñavilāsa": ['mw'],
    "daivajñaśarman": ['mw'],
    "daivajñaśiromaṇi": ['mw'],
    "daivajñā": ['mw'],
    "daivajñālaṃkṛti": ['mw'],
    "daivaka": ['mw'],
    "daivakarman": ['mw'],
    "daivakaḥ": ['ap90'],
    "daivakovida": ['mw'],
    "daivakulika": ['bhs'],
    "daivakī": ['mw'],
    "daivakīnandana": ['mw'],
    "daivakṛta": ['ddsa', 'mw'],
    "daivakṣatri": ['mw'],
    "daivala": ['mw'],
    "daivalaka": ['mw'],
    "daivalaukika": ['mw'],
    "daivalaḥ": ['ap90'],
    "daivalekhaka": ['mw'],
    "daivali": ['mw'],
    "daivamati": ['mw'],
    "daivamitri": ['mw'],
    "daivamānuṣaka": ['cae', 'mw'],
    "daivanirmita": ['cae', 'mw'],
    "daivantyāyana": ['mw'],
    "daivapara": ['mw'],
    "daivaparāyaṇa": ['cae'],
    "daivaparīkṣā": ['mw'],
    "daivapraśna": ['mw'],
    "daivarakṣita": ['mw'],
    "daivaratha": ['mw'],
    "daivarathāyani": ['mw'],
    "daivarāja": ['mw'],
    "daivarājaka": ['mw'],
    "daivarājika": ['mw'],
    "daivarājya": ['mw'],
    "daivarāti": ['mw'],
    "daivasaka": ['mw'],
    "daivasampanna": ['mw'],
    "daivasampannatā": ['mw'],
    "daivasika": ['bhs'],
    "daivasthāni": ['mw'],
    "daivata": ['ap90', 'cae', 'ddsa', 'mw'],
    "daivatakāṇḍa": ['mw'],
    "daivatantra": ['mw'],
    "daivatapara": ['mw'],
    "daivatapati": ['mw'],
    "daivatapratimā": ['mw'],
    "daivatarasa": ['mw'],
    "daivatareya": ['mw'],
    "daivatas": ['ap90', 'cae', 'ddsa', 'mw'],
    "daivatasarit": ['mw'],
    "daivatya": ['ap90', 'cae', 'ddsa', 'mw'],
    "daivatīrtha": ['mw'],
    "daivavaśa": ['cae', 'mw'],
    "daivavaśāt": ['mw'],
    "daivavid": ['cae', 'mw'],
    "daivavidhi": ['mw'],
    "daivavāta": ['gra', 'mw'],
    "daivavāṇī": ['mw'],
    "daivayajñapiṇḍasūrya": ['mw'],
    "daivayajñi": ['mw'],
    "daivayoga": ['cae', 'mw'],
    "daivayogena": ['mw'],
    "daivayogāt": ['mw'],
    "daivayuga": ['mw'],
    "daivayuta": ['mw'],
    "daivayāneya": ['cae', 'mw'],
    "daivayātava": ['mw'],
    "daivayātavaka": ['mw'],
    "daivaśarmi": ['mw'],
    "daivaśarmīya": ['mw'],
    "daivaśrāddha": ['mw'],
    "daivejya": ['mw'],
    "daivia": ['gra'],
    "daivika": ['ap90', 'cae', 'ddsa', 'mw'],
    "daivikadharmanirūpaṇa": ['mw'],
    "daivin": ['ap90'],
    "daivodaasa": ['gra'],
    "daivodyāna": ['mw'],
    "daivodāsa": ['gra', 'mw'],
    "daivodāsi": ['mw'],
    "daivopahata": ['mw'],
    "daivopahataka": ['mw'],
    "daivoḍhā": ['cae', 'ddsa', 'mw'],
    "daivoḍhāja": ['mw'],
    "daivya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "daivyahotṛ": ['mw'],
    "daivādhīna": ['mw'],
    "daivādika": ['ddsa', 'mw'],
    "daivādyanta": ['cae', 'ddsa', 'mw'],
    "daivāhorātra": ['mw'],
    "daivākari": ['mw'],
    "daivākarī": ['mw'],
    "daivānurodhin": ['mw'],
    "daivānvita": ['mw'],
    "daivānīka": ['mw'],
    "daivāpa": ['mw'],
    "daivāripa": ['mw'],
    "daivāripaḥ": ['ap90'],
    "daivāsura": ['mw'],
    "daivāsuraṃ": ['ap90'],
    "daivāt": ['mw'],
    "daivātitha": ['mw'],
    "daivātyaya": ['mw'],
    "daivāvṛdh": ['mw'],
    "daivāvṛdha": ['mw'],
    "daivāyatta": ['mw'],
    "daivī": ['cae', 'gra', 'mw'],
    "daivīdik": ['mw'],
    "daiyāmpāti": ['mw'],
    "daiśeya": ['mw'],
    "daiśika": ['ap90', 'cae', 'ddsa', 'mw'],
    "daiḍa": ['mw'],
    "daiṣṇa": ['gra'],
    "daiṣṭika": ['ap90', 'mw'],
    "daiṣṭikatva": ['mw'],
    "daiṣṭikatā": ['ddsa', 'mw'],
    "dajja(ṁ)": ['cped'],
    "dajjehi": ['cped'],
    "dajjeyyāma": ['cped'],
    "dajjeyyāsi": ['cped'],
    "dajjeyyātha": ['cped'],
    "dajjuṁ": ['cped'],
    "dajjā": ['cped'],
    "dajjāmi": ['cped'],
    "daka": ['bhs', 'cped', 'mw'],
    "dakalāvaṇika": ['mw'],
    "dakarākṣasa": ['mw'],
    "dakaṃ": ['ap90'],
    "dakkha": ['cped'],
    "dakkhati": ['cped'],
    "dakkhi": ['cped'],
    "dakkhisatti": ['cped'],
    "dakkhisaṁ": ['cped'],
    "dakkhissaṁ": ['cped'],
    "dakkhiti": ['cped'],
    "dakkhituṁ": ['cped'],
    "dakkhitāye": ['cped'],
    "dakkhiṇa": ['cped'],
    "dakkhiṇato": ['cped'],
    "dakkhiṇeyya": ['cped'],
    "dakkhiṇāpatha": ['cped'],
    "dakkhiṇāpathaka": ['cped'],
    "dakkhiṇāvattaka": ['cped'],
    "dakkhiṇāvaṭṭaka": ['cped'],
    "dakkhuṁ": ['cped'],
    "dakodara": ['mw'],
    "dakodarika": ['bhs'],
    "dakodarin": ['bhs'],
    "dakāra": ['mw'],
    "dakārgalaṃ": ['ap90'],
    "dakāsaya": ['cped'],
    "dakṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dakṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dakṣajā": ['mw'],
    "dakṣajāpati": ['mw'],
    "dakṣakanyā": ['cae', 'mw'],
    "dakṣakratu": ['cae', 'ddsa', 'mw'],
    "dakṣamakhamathana": ['mw'],
    "dakṣamathana": ['mw'],
    "dakṣanidhana": ['mw'],
    "dakṣapati": ['gra', 'mw'],
    "dakṣapitṛ": ['cae', 'gra', 'mw'],
    "dakṣaputra": ['mw'],
    "dakṣas": ['cae', 'gra', 'mw'],
    "dakṣasmṛti": ['mw'],
    "dakṣastha": ['mw'],
    "dakṣasuta": ['cae', 'mw'],
    "dakṣasutā": ['mw'],
    "dakṣasādhana": ['gra', 'mw'],
    "dakṣasāvarṇa": ['mw'],
    "dakṣasāvarṇi": ['mw'],
    "dakṣat": ['cae', 'mw'],
    "dakṣatā": ['cae', 'mw'],
    "dakṣatāti": ['mw'],
    "dakṣavihitā": ['mw'],
    "dakṣavṛdh": ['mw'],
    "dakṣayajña": ['mw'],
    "dakṣayajñaprabhañjana": ['mw'],
    "dakṣayajñavidhvaṃsa": ['mw'],
    "dakṣayajñavidhvaṃsana": ['mw'],
    "dakṣayajñavināśinī": ['mw'],
    "dakṣaśāpa": ['mw'],
    "dakṣaṇidhana": ['mw'],
    "dakṣeśvaraliṅga": ['mw'],
    "dakṣi": ['mw'],
    "dakṣiṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dakṣiṇabhāga": ['mw'],
    "dakṣiṇadagh": ['mw'],
    "dakṣiṇadhurīṇa": ['mw'],
    "dakṣiṇadvārika": ['mw'],
    "dakṣiṇais": ['cae', 'ddsa'],
    "dakṣiṇaiḥ": ['mw'],
    "dakṣiṇajānvakna": ['mw'],
    "dakṣiṇajānvakta": ['ddsa'],
    "dakṣiṇaka": ['bhs'],
    "dakṣiṇakālikā": ['mw'],
    "dakṣiṇakālīmāhātmya": ['mw'],
    "dakṣiṇalipi": ['mw'],
    "dakṣiṇam": ['mw'],
    "dakṣiṇamānasa": ['mw'],
    "dakṣiṇamārga": ['mw'],
    "dakṣiṇapavana": ['cae'],
    "dakṣiṇapañcāla": ['mw'],
    "dakṣiṇapaścima": ['cae', 'mw'],
    "dakṣiṇapaścārdha": ['ddsa', 'mw'],
    "dakṣiṇapaścāt": ['mw'],
    "dakṣiṇaprācī": ['mw'],
    "dakṣiṇaprākpravaṇa": ['mw'],
    "dakṣiṇapāñcālaka": ['mw'],
    "dakṣiṇapūrva": ['cae', 'mw'],
    "dakṣiṇapūrvaka": ['mw'],
    "dakṣiṇapūrveṇa": ['mw'],
    "dakṣiṇapūrvā": ['mw'],
    "dakṣiṇapūrvārdha": ['mw'],
    "dakṣiṇapūrvāyata": ['mw'],
    "dakṣiṇarāḍhā": ['mw'],
    "dakṣiṇasad": ['mw'],
    "dakṣiṇasavya": ['mw'],
    "dakṣiṇastha": ['mw'],
    "dakṣiṇatas": ['cae', 'ddsa', 'gra', 'mw'],
    "dakṣiṇataskaparda": ['gra', 'mw'],
    "dakṣiṇataupacāra": ['mw'],
    "dakṣiṇataupavītin": ['mw'],
    "dakṣiṇataḥ": ['ap90'],
    "dakṣiṇataḥsad": ['mw'],
    "dakṣiṇatonyāya": ['mw'],
    "dakṣiṇatrā": ['cae', 'gra', 'mw'],
    "dakṣiṇatva": ['cae', 'mw'],
    "dakṣiṇe": ['mw'],
    "dakṣiṇena": ['ap90', 'cae', 'ddsa', 'mw'],
    "dakṣiṇerma": ['mw'],
    "dakṣiṇerman": ['mw'],
    "dakṣiṇetara": ['cae', 'ddsa', 'mw'],
    "dakṣiṇeti": ['mw'],
    "dakṣiṇeya": ['bhs'],
    "dakṣiṇit": ['gra', 'mw'],
    "dakṣiṇodagdvāra": ['mw'],
    "dakṣiṇopakrama": ['mw'],
    "dakṣiṇottara": ['cae', 'ddsa', 'mw'],
    "dakṣiṇottarin": ['mw'],
    "dakṣiṇottarāyata": ['mw'],
    "dakṣiṇottarāyāma": ['mw'],
    "dakṣiṇottāna": ['mw'],
    "dakṣiṇya": ['cae', 'mw'],
    "dakṣiṇā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dakṣiṇābandha": ['mw'],
    "dakṣiṇābdhi": ['mw'],
    "dakṣiṇābhimukha": ['cae', 'mw'],
    "dakṣiṇābhimukhasthita": ['mw'],
    "dakṣiṇāc": ['mw'],
    "dakṣiṇācala": ['mw'],
    "dakṣiṇācāra": ['mw'],
    "dakṣiṇācāratantra": ['mw'],
    "dakṣiṇācārin": ['mw'],
    "dakṣiṇācāritantra": ['mw'],
    "dakṣiṇādeśana": ['mw'],
    "dakṣiṇādeśanā": ['bhs', 'mw'],
    "dakṣiṇādhipati": ['mw'],
    "dakṣiṇādvāra": ['ddsa', 'mw'],
    "dakṣiṇādvāta": ['mw'],
    "dakṣiṇāgavī": ['mw'],
    "dakṣiṇāgiri": ['bhs'],
    "dakṣiṇāgni": ['ddsa', 'mw'],
    "dakṣiṇāgra": ['mw'],
    "dakṣiṇāhi": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "dakṣiṇājyotis": ['mw'],
    "dakṣiṇākaparda": ['mw'],
    "dakṣiṇākāla": ['mw'],
    "dakṣiṇālipi": ['mw'],
    "dakṣiṇāmukha": ['cae', 'mw'],
    "dakṣiṇāmūrti": ['mw'],
    "dakṣiṇāmūrtimantra": ['mw'],
    "dakṣiṇāmūrtiprayoga": ['mw'],
    "dakṣiṇāmūrtisaṃhitā": ['mw'],
    "dakṣiṇāmūrtistava": ['mw'],
    "dakṣiṇāmūrtistotra": ['mw'],
    "dakṣiṇāmūrtyupaniṣad": ['mw'],
    "dakṣiṇāntikā": ['mw'],
    "dakṣiṇānyāya": ['mw'],
    "dakṣiṇāpada": ['mw'],
    "dakṣiṇāpara": ['cae', 'mw'],
    "dakṣiṇāparābhimukha": ['mw'],
    "dakṣiṇāpatha": ['cae', 'mw'],
    "dakṣiṇāpathika": ['mw'],
    "dakṣiṇāpavarga": ['mw'],
    "dakṣiṇāpraharaṇa": ['mw'],
    "dakṣiṇāpratigraha": ['mw'],
    "dakṣiṇāpratyac": ['mw'],
    "dakṣiṇāpratyagapavarga": ['mw'],
    "dakṣiṇāpratyak": ['mw'],
    "dakṣiṇāpratyakpravaṇa": ['mw'],
    "dakṣiṇāpratyañc": ['cae'],
    "dakṣiṇāpratīcī": ['mw'],
    "dakṣiṇāpravaṇa": ['cae', 'mw'],
    "dakṣiṇāpraṣṭi": ['mw'],
    "dakṣiṇāprāgagra": ['mw'],
    "dakṣiṇāprāñc": ['mw'],
    "dakṣiṇāraṇya": ['cae', 'ddsa', 'mw'],
    "dakṣiṇārdha": ['mw'],
    "dakṣiṇārdhapaścārdha": ['mw'],
    "dakṣiṇārdhapūrvārdha": ['mw'],
    "dakṣiṇārdhya": ['mw'],
    "dakṣiṇārdhyapūrvārdhya": ['mw'],
    "dakṣiṇārdhāparārdha": ['mw'],
    "dakṣiṇārha": ['mw'],
    "dakṣiṇārus": ['mw'],
    "dakṣiṇāsad": ['mw'],
    "dakṣiṇāsaṃcara": ['mw'],
    "dakṣiṇāsūtra": ['bhs'],
    "dakṣiṇāt": ['ap90', 'cae', 'ddsa', 'mw'],
    "dakṣiṇātinayana": ['mw'],
    "dakṣiṇātsad": ['mw'],
    "dakṣiṇātva": ['mw'],
    "dakṣiṇāvacara": ['mw'],
    "dakṣiṇāvah": ['gra', 'mw'],
    "dakṣiṇāvant": ['cae'],
    "dakṣiṇāvarjam": ['mw'],
    "dakṣiṇāvarta": ['bhs', 'cae', 'ddsa', 'mw'],
    "dakṣiṇāvartaka": ['mw'],
    "dakṣiṇāvartakī": ['mw'],
    "dakṣiṇāvat": ['ddsa', 'gra', 'mw'],
    "dakṣiṇāvibhaṅgasūtra": ['bhs'],
    "dakṣiṇāvṛt": ['cae', 'gra', 'mw'],
    "dakṣiṇāvṛtta": ['mw'],
    "dakṣiṇāyana": ['cae', 'ddsa', 'mw'],
    "dakṣiṇāyugya": ['mw'],
    "dakṣiṇāśiras": ['cae', 'ddsa', 'mw'],
    "dakṣiṇāśroṇi": ['mw'],
    "dakṣiṇāśā": ['mw'],
    "dakṣiṇāśāpati": ['mw'],
    "dakṣiṇāśārati": ['mw'],
    "dakṣiṇīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "dakṣiṇīya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "dakṣu": ['cae', 'gra', 'mw'],
    "dakṣus": ['cae', 'gra', 'mw'],
    "dakṣya": ['bhs'],
    "dakṣā": ['mw'],
    "dakṣādhvara": ['mw'],
    "dakṣādhvaradhvaṃsaka": ['mw'],
    "dakṣādhvaradhvaṃsakṛt": ['mw'],
    "dakṣādhvaradhvaṃsana": ['mw'],
    "dakṣāri": ['mw'],
    "dakṣātmajāpati": ['mw'],
    "dakṣāyia": ['gra'],
    "dakṣāyya": ['cae', 'gra', 'mw'],
    "dakṣāyyaḥ": ['ap90'],
    "dakṣāṇḍa": ['mw'],
    "dakṣī": ['gra'],
    "dal": ['ap90', 'cae', 'ddsa', 'mw'],
    "dala": ['cae', 'ddsa', 'mw'],
    "daladdhṛdaya": ['mw'],
    "dalaja": ['mw'],
    "dalakapāṭa": ['mw'],
    "dalakomala": ['mw'],
    "dalakośa": ['mw'],
    "dalamodaka": ['mw'],
    "dalamālinī": ['mw'],
    "dalana": ['cae', 'mw'],
    "dalanagara": ['mw'],
    "dalanaṃ": ['ap90'],
    "dalanirmoka": ['mw'],
    "dalanī": ['ap90', 'mw'],
    "dalapa": ['mw'],
    "dalapati": ['mw'],
    "dalapaḥ": ['ap90'],
    "dalapuṣpā": ['mw'],
    "dalapuṣpī": ['mw'],
    "dalasnasā": ['mw'],
    "dalasāriṇī": ['mw'],
    "dalasāyasī": ['mw'],
    "dalasūci": ['mw'],
    "dalataru": ['mw'],
    "dalatṛ": ['mw'],
    "dalavīṭaka": ['mw'],
    "dalayoga": ['mw'],
    "dalaśas": ['cae', 'ddsa', 'mw'],
    "dalaśaḥ": ['ap90'],
    "dalaśālinī": ['mw'],
    "dalaḥ": ['ap90'],
    "dalbha": ['mw'],
    "dalbhaḥ": ['ap90'],
    "dalbhya": ['mw'],
    "dalegandhi": ['mw'],
    "dali": ['mw'],
    "dalidda": ['cped'],
    "daliddaka": ['cped'],
    "dalika": ['mw'],
    "dalikaṃ": ['ap90'],
    "dalin": ['mw'],
    "dalita": ['ap90', 'mw'],
    "dalmi": ['mw'],
    "dalmimat": ['mw'],
    "dalmiḥ": ['ap90'],
    "dalodbhava": ['mw'],
    "dalya": ['mw'],
    "dalādhīśvara": ['mw'],
    "dalāditva": ['ddsa', 'mw'],
    "dalāgralohita": ['mw'],
    "dalākhya": ['mw'],
    "dalāmala": ['mw'],
    "dalāmla": ['mw'],
    "dalāḍhaka": ['mw'],
    "dalāḍhya": ['mw'],
    "dalīkṛta": ['mw'],
    "dam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dama": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "damadamā": ['bhs'],
    "damadamāya": ['mw'],
    "damadāna": ['cae', 'mw'],
    "damaghoṣa": ['cae', 'ddsa', 'mw'],
    "damaghoṣaja": ['mw'],
    "damaghoṣasuta": ['mw'],
    "damaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "damakartṛ": ['mw'],
    "damamaya": ['cae', 'mw'],
    "damana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "damanabhañjikā": ['mw'],
    "damanaka": ['cae', 'ddsa', 'mw'],
    "damanakaḥ": ['ap90'],
    "damany": ['gra'],
    "damanya": ['mw'],
    "damanāropaṇa": ['mw'],
    "damanī": ['mw'],
    "damanīya": ['mw'],
    "damassu": ['cped'],
    "damasvasṛ": ['mw'],
    "damatha": ['bhs', 'cped', 'mw'],
    "damathaḥ": ['ap90'],
    "damathu": ['mw'],
    "damatra": ['mw'],
    "damaya(t)": ['cped'],
    "damayahi": ['cped'],
    "damayantikā": ['mw'],
    "damayantī": ['cae', 'ddsa', 'mw'],
    "damayantīkathā": ['mw'],
    "damayantīkāvya": ['mw'],
    "damayantīpariṇaya": ['mw'],
    "damayati": ['cped'],
    "damayaṃtī": ['ap90'],
    "damayissaṁ": ['cped'],
    "damayitṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "damaśarīrin": ['mw'],
    "damaḥ": ['ap90'],
    "dambh": ['gra', 'mw'],
    "dambha": ['cae', 'ddsa', 'mw'],
    "dambhacaryā": ['mw'],
    "dambhaka": ['cae', 'mw'],
    "dambhamuni": ['ddsa', 'mw'],
    "dambhana": ['cae', 'gra', 'mw'],
    "dambhayajña": ['mw'],
    "dambhin": ['cae', 'ddsa', 'mw'],
    "dambhodbhava": ['ddsa', 'mw'],
    "dambholi": ['cae', 'ddsa', 'mw'],
    "dambholipāta": ['mw'],
    "dambholipātāya": ['ddsa', 'mw'],
    "dambholipāṇi": ['cae', 'mw'],
    "damessati": ['cped'],
    "dameta(r)": ['cped'],
    "dameti": ['cped'],
    "damia": ['gra'],
    "damin": ['ap90', 'cae', 'ddsa', 'mw'],
    "damita": ['ap90', 'cped', 'mw'],
    "damitṛ": ['cae', 'gra', 'mw'],
    "damma": ['cped'],
    "dammago": ['cped'],
    "dammi": ['cped'],
    "damopeta": ['cae', 'mw'],
    "dampati": ['ddsa', 'gra', 'mw'],
    "damunas": ['ap90', 'mw'],
    "damya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "damyasārathi": ['mw'],
    "damāvandu": ['mw'],
    "damāy": ['cae', 'gra'],
    "damāya": ['mw'],
    "damūnas": ['ap90', 'cae', 'gra', 'mw'],
    "dan": ['cae', 'gra', 'mw'],
    "dandaśa": ['mw'],
    "dandaśūka": ['cae', 'ddsa', 'mw'],
    "dandha": ['cped'],
    "dandhati": ['cped'],
    "dandhayati": ['cped'],
    "dandhaṁ": ['cped'],
    "dandheti": ['cped'],
    "dandhvana": ['mw'],
    "dandhābbhiñña": ['cped'],
    "dandhāyita": ['cped'],
    "dandhāyitatta": ['cped'],
    "dandramaṇa": ['mw'],
    "dant": ['cae', 'ddsa'],
    "danta": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dantabhaṅga": ['mw'],
    "dantabhāga": ['mw'],
    "dantabhūmi": ['cped'],
    "dantabīja": ['mw'],
    "dantabījaka": ['mw'],
    "dantabījā": ['mw'],
    "dantacchada": ['cae', 'ddsa', 'mw'],
    "dantacchadana": ['mw'],
    "dantacchadopamā": ['mw'],
    "dantacchadā": ['mw'],
    "dantacchedana": ['mw'],
    "dantacāla": ['mw'],
    "dantadarśana": ['mw'],
    "dantadhāva": ['cae', 'mw'],
    "dantadhāvana": ['mw'],
    "dantadhāvanaka": ['mw'],
    "dantadhāvanaprakaraṇa": ['mw'],
    "dantadhāvanavidhi": ['mw'],
    "dantadyut": ['mw'],
    "dantagharṣa": ['mw'],
    "dantaghāta": ['cae', 'mw'],
    "dantaghāṭa": ['cae', 'mw'],
    "dantaghāṭaka": ['cae', 'mw'],
    "dantagrāhitā": ['mw'],
    "dantaharṣa": ['mw'],
    "dantaharṣaka": ['mw'],
    "dantaharṣaṇa": ['mw'],
    "dantahastin": ['mw'],
    "dantahīna": ['mw'],
    "dantajanman": ['mw'],
    "dantajāha": ['mw'],
    "dantajāta": ['cae', 'mw'],
    "dantaka": ['cae', 'mw'],
    "dantakarṣaṇa": ['mw'],
    "dantakaśa": ['mw'],
    "dantakaṭṭha": ['cped'],
    "dantakrūra": ['mw'],
    "dantakumāra": ['mw'],
    "dantakāra": ['cped', 'mw'],
    "dantakāraka": ['bhs'],
    "dantakāsāva": ['cped'],
    "dantakāṣṭha": ['mw'],
    "dantakāṣṭhaka": ['mw'],
    "dantakāṣṭhābhakṣaṇa": ['mw'],
    "dantakūra": ['mw'],
    "dantakūṭa": ['cped'],
    "dantalekhaka": ['mw'],
    "dantalīna": ['mw'],
    "dantamadhya": ['mw'],
    "dantamala": ['mw'],
    "dantamaya": ['cae', 'mw'],
    "dantamāṃsa": ['cae', 'mw'],
    "dantamūla": ['cae', 'mw'],
    "dantamūlikā": ['mw'],
    "dantamūlīya": ['cae', 'mw'],
    "dantaniṣkāśita": ['mw'],
    "dantapattra": ['mw'],
    "dantapattraka": ['mw'],
    "dantapattrikā": ['mw'],
    "dantapavana": ['mw'],
    "dantaphala": ['mw'],
    "dantaphalā": ['mw'],
    "dantapoṇa": ['cped'],
    "dantaprakṣālana": ['cae', 'mw'],
    "dantapraveṣṭa": ['mw'],
    "dantapuppuṭa": ['mw'],
    "dantapuppuṭaka": ['mw'],
    "dantapura": ['bhs', 'mw'],
    "dantapuṣpa": ['mw'],
    "dantapāli": ['mw'],
    "dantapālī": ['mw'],
    "dantapāta": ['mw'],
    "dantapāvana": ['mw'],
    "dantapāñcālikā": ['cae', 'mw'],
    "dantaracanā": ['cae', 'mw'],
    "dantarajas": ['mw'],
    "dantaroga": ['mw'],
    "dantarogin": ['mw'],
    "dantasadman": ['mw'],
    "dantasaṃgharṣa": ['mw'],
    "dantaskavana": ['mw'],
    "dantauṣṭhaka": ['mw'],
    "dantavaidarbha": ['mw'],
    "dantavakra": ['mw'],
    "dantavaktra": ['mw'],
    "dantavalka": ['mw'],
    "dantavarṇa": ['mw'],
    "dantavastra": ['mw'],
    "dantavat": ['mw'],
    "dantavatā": ['cped'],
    "dantavaṇṇaka": ['cped'],
    "dantaveṣṭa": ['cae', 'mw'],
    "dantaveṣṭaka": ['mw'],
    "dantaveṣṭana": ['mw'],
    "dantavidaṁsaka": ['cped'],
    "dantavidaṁsakaṁ": ['cped'],
    "dantavidradhī": ['mw'],
    "dantavighāta": ['mw'],
    "dantavyasana": ['mw'],
    "dantavyāpāra": ['mw'],
    "dantavāsas": ['mw'],
    "dantavāṇijya": ['mw'],
    "dantavīṇā": ['mw'],
    "dantaśarkarā": ['mw'],
    "dantaśayana": ['bhs'],
    "dantaśaṅku": ['mw'],
    "dantaśaṭha": ['mw'],
    "dantaśaṭhā": ['mw'],
    "dantaśirā": ['mw'],
    "dantaśliṣṭa": ['mw'],
    "dantaśodhana": ['mw'],
    "dantaśodhanacūrṇa": ['mw'],
    "dantaśodhanī": ['mw'],
    "dantaśopha": ['mw'],
    "dantaśuddhi": ['cae', 'mw'],
    "dantaśāṇa": ['mw'],
    "dantaśūla": ['mw'],
    "danteya": ['mw'],
    "danti": ['mw'],
    "dantidaitya": ['mw'],
    "dantidanta": ['cae', 'mw'],
    "dantidantamaya": ['mw'],
    "dantidurga": ['mw'],
    "dantijā": ['mw'],
    "dantikā": ['mw'],
    "dantila": ['mw'],
    "dantimada": ['mw'],
    "dantin": ['cae', 'ddsa', 'mw'],
    "dantinikā": ['bhs'],
    "dantinī": ['mw'],
    "dantistha": ['mw'],
    "dantivaktra": ['mw'],
    "dantocchiṣṭa": ['mw'],
    "dantodbheda": ['mw'],
    "dantolūkhala": ['mw'],
    "dantolūkhalika": ['cae', 'ddsa', 'mw'],
    "dantolūkhalin": ['cae', 'mw'],
    "dantoṣṭhaka": ['mw'],
    "dantura": ['cae', 'mw'],
    "danturacchada": ['mw'],
    "danturaka": ['mw'],
    "danturatā": ['mw'],
    "danturay": ['cae'],
    "danturaya": ['ddsa', 'mw'],
    "danturita": ['mw'],
    "danturā": ['bhs'],
    "dantya": ['cae', 'ddsa', 'mw'],
    "dantyauṣṭhya": ['mw'],
    "dantyoṣṭhya": ['mw'],
    "dantā": ['bhs'],
    "dantāda": ['mw'],
    "dantādanti": ['cae', 'ddsa', 'mw'],
    "dantāghāta": ['mw'],
    "dantāgra": ['cae', 'ddsa', 'mw'],
    "dantāgrīya": ['mw'],
    "dantājina": ['cped'],
    "dantālaya": ['mw'],
    "dantāli": ['cae', 'mw'],
    "dantālikā": ['mw'],
    "dantālī": ['mw'],
    "dantāntara": ['ddsa', 'mw'],
    "dantāntaradhiṣṭhita": ['mw'],
    "dantāntaragata": ['mw'],
    "dantārbuda": ['mw'],
    "dantāvala": ['ddsa', 'mw'],
    "dantāvalī": ['cae', 'mw'],
    "dantāyudha": ['mw'],
    "dantāñji": ['mw'],
    "dantāśliṣṭa": ['mw'],
    "dantī": ['mw'],
    "dantūla": ['mw'],
    "dantūllehakam": ['cped'],
    "danu": ['cae', 'ddsa', 'mw'],
    "danuja": ['cae', 'mw'],
    "danujadviṣ": ['mw'],
    "danujendra": ['mw'],
    "danujāri": ['mw'],
    "danukabandha": ['ddsa', 'mw'],
    "danusambhava": ['mw'],
    "danusūnu": ['mw'],
    "danuḥ": ['ap90'],
    "danv": ['mw'],
    "danāyus": ['mw'],
    "danāyū": ['mw'],
    "danīdhvaṃsa": ['mw'],
    "dapharakhāna": ['mw'],
    "dar": ['gra'],
    "dara": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "darad": ['ap90', 'cae', 'ddsa', 'mw'],
    "darada": ['cae', 'mw'],
    "daradalipi": ['bhs', 'mw'],
    "daradāḥ": ['ap90'],
    "darahāra": ['mw'],
    "daraka": ['ap90', 'mw'],
    "darakara": ['mw'],
    "darakaṇṭikā": ['mw'],
    "daram": ['mw'],
    "daramanthara": ['mw'],
    "daramukulita": ['mw'],
    "darasāna": ['mw'],
    "daratha": ['cped', 'mw'],
    "darathaḥ": ['ap90'],
    "daratimira": ['mw'],
    "daratpura": ['mw'],
    "daratpurī": ['mw'],
    "daravidalita": ['mw'],
    "daravrīḍā": ['mw'],
    "daraślatha": ['mw'],
    "daraṇa": ['cae', 'ddsa', 'mw'],
    "daraṇaṃ": ['ap90'],
    "daraṇi": ['ap90', 'mw'],
    "daraṇīya": ['mw'],
    "darbh": ['gra'],
    "darbha": ['cae', 'ddsa', 'gra', 'mw'],
    "darbhabaṭu": ['mw'],
    "darbhacīra": ['mw'],
    "darbhagrumuṣṭi": ['mw'],
    "darbhagurumuṣṭi": ['mw'],
    "darbhaka": ['mw'],
    "darbhakusuma": ['mw'],
    "darbhakuṇḍikā": ['mw'],
    "darbhakātyāyana": ['bhs'],
    "darbhalavaṇa": ['mw'],
    "darbhamaya": ['cae', 'ddsa', 'mw'],
    "darbhamuṣṭi": ['cae', 'mw'],
    "darbhamūlī": ['mw'],
    "darbhana": ['mw'],
    "darbhapattra": ['mw'],
    "darbhapavitra": ['mw'],
    "darbhapavitrapāṇi": ['mw'],
    "darbhapiñjula": ['cae'],
    "darbhapiñjūla": ['cae', 'mw'],
    "darbhapiñjūlavat": ['mw'],
    "darbhapiñjūlī": ['mw'],
    "darbhapuñjīla": ['cae', 'mw'],
    "darbhapuṣpa": ['mw'],
    "darbhapūla": ['mw'],
    "darbhapūtika": ['mw'],
    "darbhapūtīka": ['mw'],
    "darbhara": ['mw'],
    "darbharajju": ['mw'],
    "darbhasaṃstara": ['mw'],
    "darbhastamba": ['cae', 'mw'],
    "darbhasūci": ['mw'],
    "darbhataruṇaka": ['mw'],
    "darbhaśara": ['mw'],
    "darbhaḥ": ['ap90'],
    "darbhaṇa": ['cae'],
    "darbhaṭa": ['mw'],
    "darbhaṭaṃ": ['ap90'],
    "darbheṇḍva": ['mw'],
    "darbheṣīkā": ['mw'],
    "darbhi": ['mw'],
    "darbhin": ['mw'],
    "darbhāhvaya": ['mw'],
    "darbhānūpa": ['mw'],
    "dardara": ['ap90', 'bhs', 'mw'],
    "dardaraka": ['bhs'],
    "dardarā": ['bhs'],
    "dardarāmra": ['mw'],
    "dardarī": ['mw'],
    "dardarīka": ['mw'],
    "dardarīkaḥ": ['ap90'],
    "dardru": ['cae', 'mw'],
    "dardruḥ": ['ap90'],
    "dardruṇa": ['ap90', 'mw'],
    "dardrū": ['mw'],
    "dardrūḥ": ['ap90'],
    "dardrūṇa": ['ap90', 'mw'],
    "dardula": ['bhs'],
    "dardulaka": ['bhs'],
    "dardura": ['bhs', 'cae', 'ddsa', 'mw'],
    "darduracchadā": ['mw'],
    "darduraka": ['mw'],
    "darduraparṇī": ['mw'],
    "dardurapuṭa": ['mw'],
    "darduraḥ": ['ap90'],
    "dardurā": ['bhs'],
    "dardurāmra": ['mw'],
    "dardū": ['mw'],
    "darendra": ['mw'],
    "dari": ['cae', 'gra', 'mw'],
    "daridra": ['ap90', 'cae', 'ddsa', 'mw'],
    "daridraka": ['bhs'],
    "daridranindā": ['mw'],
    "daridrat": ['mw'],
    "daridratva": ['mw'],
    "daridratā": ['ddsa', 'mw'],
    "daridratātura": ['cae'],
    "daridrin": ['mw'],
    "daridrita": ['ap90', 'mw'],
    "daridritṛ": ['mw'],
    "daridrā": ['ap90', 'cae', 'ddsa'],
    "daridrātura": ['cae'],
    "daridrāyaka": ['ap90', 'mw'],
    "daridrāṇa": ['mw'],
    "daridrāṇaṃ": ['ap90'],
    "daridrī": ['mw'],
    "daridrībhūta": ['mw'],
    "daridrīkṛtya": ['mw'],
    "darin": ['mw'],
    "darita": ['ap90', 'mw'],
    "dariḥ": ['ap90'],
    "darma": ['ap90', 'cae', 'gra', 'mw'],
    "darman": ['cae', 'gra', 'mw'],
    "darodara": ['ap90', 'mw'],
    "darpa": ['cae', 'ddsa', 'mw'],
    "darpacchid": ['mw'],
    "darpada": ['mw'],
    "darpadhmāta": ['mw'],
    "darpaha": ['mw'],
    "darpahan": ['mw'],
    "darpahara": ['mw'],
    "darpaka": ['ap90', 'mw'],
    "darpanārāyaṇa": ['mw'],
    "darpapattraka": ['mw'],
    "darpapūrṇa": ['mw'],
    "darparja": ['cae'],
    "darpasāra": ['ddsa', 'mw'],
    "darpaḥ": ['ap90'],
    "darpaṇa": ['cae', 'ddsa', 'mw'],
    "darpaṇakāra": ['mw'],
    "darpaṇamaya": ['mw'],
    "darpaṇaḥ": ['ap90'],
    "darpaṇikā": ['ddsa', 'mw'],
    "darpin": ['mw'],
    "darpita": ['ap90', 'mw'],
    "darpitapura": ['ddsa', 'mw'],
    "darpopaśānti": ['mw'],
    "darpārambha": ['mw'],
    "dartnu": ['cae', 'gra', 'mw'],
    "dartṛ": ['cae', 'gra', 'mw'],
    "darva": ['cae', 'ddsa', 'mw'],
    "darvarīka": ['mw'],
    "darvarīkaḥ": ['ap90'],
    "darvaḥ": ['ap90'],
    "darvaṭa": ['mw'],
    "darvaṭaḥ": ['ap90'],
    "darvi": ['cae', 'gra', 'mw'],
    "darvibhṛt": ['ddsa', 'mw'],
    "darvidā": ['mw'],
    "darvihoma": ['mw'],
    "darvihomin": ['mw'],
    "darvika": ['mw'],
    "darvikaḥ": ['ap90'],
    "darvikā": ['bhs', 'mw'],
    "darviḥ": ['ap90'],
    "darvya": ['mw'],
    "darvyudāyuvana": ['mw'],
    "darvā": ['mw'],
    "darvī": ['ap90', 'cae', 'mw'],
    "darvīhoma": ['mw'],
    "darvīkara": ['cae', 'ddsa', 'mw'],
    "darvīpralepa": ['mw'],
    "darvīsaṃkramaṇa": ['mw'],
    "darya": ['mw'],
    "daryaka": ['ddsa', 'mw'],
    "darāyya": ['mw'],
    "darī": ['mw'],
    "darībhṛt": ['mw'],
    "darīman": ['cae', 'gra', 'mw'],
    "darīmat": ['mw'],
    "darīmukha": ['ddsa', 'mw'],
    "darīvant": ['cae'],
    "darīvat": ['mw'],
    "darśa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "darśaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "darśam": ['ddsa'],
    "darśana": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "darśanabhūmi": ['bhs', 'mw'],
    "darśanagocara": ['cae', 'ddsa', 'mw'],
    "darśanagṛha": ['mw'],
    "darśanakāṅkṣin": ['cae', 'mw'],
    "darśanakṣama": ['bhs'],
    "darśanalālasa": ['mw'],
    "darśanapatha": ['cae', 'mw'],
    "darśanapratibhū": ['mw'],
    "darśanaprātibhāvya": ['cae', 'mw'],
    "darśanapāla": ['mw'],
    "darśanatā": ['bhs'],
    "darśanaviveka": ['mw'],
    "darśanaviṣaya": ['cae', 'mw'],
    "darśanepsu": ['mw'],
    "darśaniya": ['bhs'],
    "darśanojjvalā": ['mw'],
    "darśanotsuka": ['cae', 'mw'],
    "darśanā": ['bhs'],
    "darśanāgni": ['mw'],
    "darśanāntaragata": ['cae', 'ddsa', 'mw'],
    "darśanārtha": ['mw'],
    "darśanārtham": ['mw'],
    "darśanāvaraṇa": ['mw'],
    "darśanāvaraṇīya": ['mw'],
    "darśanī": ['mw'],
    "darśanīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "darśanīyamānin": ['mw'],
    "darśanīyaṃmanya": ['mw'],
    "darśanīyā": ['mw'],
    "darśanīyākānta": ['mw'],
    "darśanīyākṛti": ['cae'],
    "darśanīyāsama": ['mw'],
    "darśapa": ['mw'],
    "darśapaurṇamāsa": ['mw'],
    "darśapaurṇamāsahautra": ['mw'],
    "darśapaurṇamāsaprāyaścittavidhi": ['mw'],
    "darśapaurṇamāsavidhi": ['mw'],
    "darśapaurṇamāseṣṭi": ['mw'],
    "darśapūrṇamāsa": ['cae', 'ddsa', 'mw'],
    "darśapūrṇamāsadevatā": ['mw'],
    "darśapūrṇamāsaprayoga": ['mw'],
    "darśapūrṇamāsaprāyaścitti": ['mw'],
    "darśapūrṇamāsayājin": ['mw'],
    "darśapūrṇamāseṣṭi": ['mw'],
    "darśapūrṇamāsin": ['mw'],
    "darśapūrṇamāsāyana": ['mw'],
    "darśata": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "darśataśrī": ['gra', 'mw'],
    "darśavipad": ['mw'],
    "darśayati": ['bhs'],
    "darśayin": ['bhs'],
    "darśayitavya": ['cae', 'ddsa', 'mw'],
    "darśayitukāma": ['mw'],
    "darśayitṛ": ['ap90', 'cae', 'mw'],
    "darśayāga": ['mw'],
    "darśayāminī": ['mw'],
    "darśaśrāddha": ['mw'],
    "darśaṃdarśaṃ": ['mw'],
    "darśia": ['gra'],
    "darśimant": ['bhs'],
    "darśin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "darśita": ['ap90', 'mw'],
    "darśitadvār": ['mw'],
    "darśitavat": ['mw'],
    "darśivas": ['mw'],
    "darśya": ['cae', 'gra', 'mw'],
    "darśāpita": ['mw'],
    "darśāvin": ['bhs'],
    "das": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dasa": ['cae', 'cped', 'gra', 'mw'],
    "dasabala": ['cped'],
    "dasabalāni": ['cped'],
    "dasaddha": ['cped'],
    "dasadhā": ['cped'],
    "dasadisā": ['cped'],
    "dasaha": ['cped'],
    "dasahā": ['cped'],
    "dasahāpaṭicchanna": ['cped'],
    "dasaka": ['cped'],
    "dasakanipāta": ['cped'],
    "dasakkhattuṁ": ['cped'],
    "dasama": ['cped'],
    "dasamūlaka": ['cped'],
    "dasanaṃ": ['ap90'],
    "dasapada": ['cped'],
    "dasasahassī": ['cped'],
    "dasasata": ['cped'],
    "dasasatakkhatuṁ": ['cped'],
    "dasasikkhāpadika": ['cped'],
    "dasavagga": ['cped'],
    "dasavaggika": ['cped'],
    "dasavassa": ['cped'],
    "dasavassuddesika": ['cped'],
    "dasavassāyuka": ['cped'],
    "dasavāsa": ['cped'],
    "daserakaḥ": ['ap90'],
    "dasika": ['cped'],
    "dasikasutta": ['cped'],
    "dasikā": ['cped'],
    "dasma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dasmant": ['cae'],
    "dasmat": ['ap90', 'gra'],
    "dasmatama": ['mw'],
    "dasmatkṛ": ['mw'],
    "dasmavarcas": ['cae', 'gra', 'mw'],
    "dasmia": ['gra'],
    "dasmya": ['ap90', 'cae', 'gra', 'mw'],
    "dasra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dasradevatā": ['mw'],
    "dasrasū": ['mw'],
    "dassana": ['cped'],
    "dassanakāma": ['cped'],
    "dassananuttariya": ['cped'],
    "dassaneyya": ['cped'],
    "dassanānuttariya": ['cped'],
    "dassanīya": ['cped'],
    "dassanīyatara": ['cped'],
    "dassati": ['cped'],
    "dassaya(t)": ['cped'],
    "dassayati": ['cped'],
    "dassaṁ": ['cped'],
    "dassenta": ['cped'],
    "dassesi": ['cped'],
    "dassesu": ['cped'],
    "dassesuṁ": ['cped'],
    "dasseta(r)": ['cped'],
    "dassetabba": ['cped'],
    "dasseti": ['cped'],
    "dassetuṁ": ['cped'],
    "dassetvā": ['cped'],
    "dassi(n)": ['cped'],
    "dassita": ['cped'],
    "dassita(r)": ['cped'],
    "dassukhīla": ['cped'],
    "dassāma": ['cped'],
    "dassāmi": ['cped'],
    "dassāpetvā": ['cped'],
    "dassāvi(n)": ['cped'],
    "dasta": ['ap90', 'mw'],
    "dasyu": ['cae', 'ddsa', 'gra', 'mw'],
    "dasyuhan": ['cae', 'gra', 'mw'],
    "dasyuhantama": ['mw'],
    "dasyuhatya": ['cae', 'gra', 'mw'],
    "dasyujīvin": ['mw'],
    "dasyujūta": ['gra', 'mw'],
    "dasyusādbhū": ['mw'],
    "dasyutarhaṇa": ['gra', 'mw'],
    "dasyuḥ": ['ap90'],
    "dasā": ['cped'],
    "dat": ['ap90', 'ddsa', 'gra', 'mw'],
    "datra": ['cae', 'ddsa', 'gra'],
    "datravat": ['gra'],
    "datraṃ": ['ap90'],
    "datta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "dattabhujaṃgastotra": ['mw'],
    "dattadaṇḍin": ['mw'],
    "dattadṛṣṭi": ['cae', 'mw'],
    "dattagītā": ['mw'],
    "dattahasta": ['mw'],
    "dattairaṇḍapallaka": ['mw'],
    "dattaka": ['bhs', 'cae', 'mw'],
    "dattakacandrikā": ['mw'],
    "dattakamīmāṃsā": ['mw'],
    "dattakarṇa": ['ddsa', 'mw'],
    "dattakaḥ": ['ap90'],
    "dattakṣaṇa": ['mw'],
    "dattamahiman": ['mw'],
    "dattamārga": ['mw'],
    "dattanṛtyopahāra": ['mw'],
    "dattaprāṇa": ['mw'],
    "dattapūrvoktaśāpabhī": ['mw'],
    "dattavara": ['cae', 'mw'],
    "dattavat": ['mw'],
    "dattaśarman": ['mw'],
    "dattaśatru": ['mw'],
    "dattaśulkā": ['cae', 'mw'],
    "datteya": ['mw'],
    "dattha": ['cped'],
    "datti": ['cae', 'cped', 'ddsa', 'mw'],
    "dattika": ['cped', 'mw'],
    "dattila": ['mw'],
    "dattiya": ['cped', 'mw'],
    "dattiḥ": ['ap90'],
    "dattogni": ['mw'],
    "dattoni": ['mw'],
    "dattopaniṣad": ['mw'],
    "dattottara": ['cae', 'ddsa', 'mw'],
    "dattottaratva": ['mw'],
    "dattra": ['mw'],
    "dattravat": ['mw'],
    "dattrima": ['ap90', 'cae', 'mw'],
    "dattrimadaṇḍikaputra": ['bhs'],
    "dattu": ['cped'],
    "dattupaññata": ['cped'],
    "dattvā": ['ddsa', 'mw'],
    "dattvādāna": ['mw'],
    "dattā": ['bhs', 'mw'],
    "dattādara": ['mw'],
    "dattādatta": ['mw'],
    "dattāgārgyāyaṇī": ['mw'],
    "dattākārīṣagandhyā": ['mw'],
    "dattākṣa": ['mw'],
    "dattākṣara": ['mw'],
    "dattāmitra": ['mw'],
    "dattāmitrā": ['mw'],
    "dattānapakarman": ['mw'],
    "dattāpahṛta": ['mw'],
    "dattāpradānika": ['mw'],
    "dattārdhacandraka": ['mw'],
    "dattāsana": ['mw'],
    "dattātaṅka": ['cae', 'ddsa', 'mw'],
    "dattātman": ['mw'],
    "dattātreya": ['mw'],
    "dattātreyopaniṣad": ['mw'],
    "dattātreyāṣṭottaraśatanāmastotra": ['mw'],
    "dattātreyīya": ['mw'],
    "dattātri": ['mw'],
    "dattāvadhāna": ['mw'],
    "datvant": ['cae'],
    "datvat": ['gra', 'mw'],
    "datvatī": ['mw'],
    "datvā": ['cped'],
    "datṛma": ['bhs'],
    "dat‍trima": ['ddsa'],
    "daugūlaḥ": ['ap90'],
    "dauhadika": ['ddsa', 'mw'],
    "dauhika": ['mw'],
    "dauhitra": ['cae', 'ddsa', 'mw'],
    "dauhitradauhitra": ['mw'],
    "dauhitraka": ['mw'],
    "dauhitravat": ['mw'],
    "dauhitraḥ": ['ap90'],
    "dauhitrāyaṇa": ['mw'],
    "dauhitrāyaṇaḥ": ['ap90'],
    "dauhitrī": ['ap90', 'mw'],
    "dauhṛda": ['cae', 'ddsa', 'mw'],
    "dauhṛdinī": ['ap90', 'mw'],
    "daukūla": ['mw'],
    "daukūlaka": ['bhs'],
    "daukūlaḥ": ['ap90'],
    "dauleya": ['mw'],
    "dauleyaḥ": ['ap90'],
    "daulmi": ['mw'],
    "daulmiḥ": ['ap90'],
    "daumya": ['bhs'],
    "daundubhi": ['mw'],
    "daundubhī": ['mw'],
    "daur": ['mw'],
    "daurbala": ['mw'],
    "daurbalya": ['cae', 'ddsa', 'mw'],
    "daurbalyaṃ": ['ap90'],
    "daurbhikṣa": ['mw'],
    "daurbhrātra": ['mw'],
    "daurbhrātraṃ": ['ap90'],
    "daurbhāgineya": ['mw'],
    "daurbhāgineyaḥ": ['ap90'],
    "daurbhāgineyī": ['mw'],
    "daurbhāgya": ['cae', 'ddsa', 'mw'],
    "daurbhāgyaṃ": ['ap90'],
    "daurbrāhmaṇya": ['mw'],
    "daureśravasa": ['mw'],
    "daureśruta": ['mw'],
    "daurga": ['cae', 'ddsa', 'mw'],
    "daurgaha": ['cae', 'ddsa', 'gra', 'mw'],
    "daurgandha": ['bhs', 'mw'],
    "daurgandhi": ['mw'],
    "daurgandhya": ['ddsa', 'mw'],
    "daurgasiṃha": ['mw'],
    "daurgatya": ['cae', 'ddsa', 'mw'],
    "daurgatyaṃ": ['ap90'],
    "daurgaṃdhyaṃ": ['ap90'],
    "daurgrahaḥ": ['ap90'],
    "daurgya": ['mw'],
    "daurgyaṃ": ['ap90'],
    "daurgāyaṇa": ['mw'],
    "daurhārda": ['mw'],
    "daurhṛda": ['cae', 'ddsa', 'mw'],
    "daurhṛdayaṃ": ['ap90'],
    "daurhṛdaṃ": ['ap90'],
    "daurhṛdinī": ['mw'],
    "daurita": ['cae', 'mw'],
    "dauritaṃ": ['ap90'],
    "daurjana": ['mw'],
    "daurjanya": ['cae', 'ddsa', 'mw'],
    "daurjanyaṃ": ['ap90'],
    "daurjīvitya": ['mw'],
    "daurjīvityaṃ": ['ap90'],
    "daurlabhya": ['mw'],
    "daurlabhyaṃ": ['ap90'],
    "daurmadya": ['mw'],
    "daurmanasya": ['cae', 'ddsa', 'mw'],
    "daurmanasyatā": ['bhs'],
    "daurmanasyaṃ": ['ap90'],
    "daurmanasyita": ['bhs'],
    "daurmanasāyana": ['mw'],
    "daurmantrya": ['ddsa', 'mw'],
    "daurmatya": ['mw'],
    "daurmaṃtryaṃ": ['ap90'],
    "daurmitri": ['mw'],
    "daurmukhi": ['mw'],
    "daurudhara": ['mw'],
    "daurvacasya": ['bhs', 'mw'],
    "daurvacasyaṃ": ['ap90'],
    "daurvarṇika": ['bhs', 'mw'],
    "daurvratya": ['cae', 'ddsa', 'mw'],
    "daurvāsa": ['mw'],
    "daurvāsasa": ['mw'],
    "daurvīṇa": ['mw'],
    "daurvīṇaṃ": ['ap90'],
    "dauryodhana": ['mw'],
    "dauryodhani": ['mw'],
    "daurārddhi": ['mw'],
    "daurātmya": ['cae', 'ddsa', 'mw'],
    "daurātmyaka": ['mw'],
    "daurātmyaṃ": ['ap90'],
    "dautya": ['cae', 'ddsa', 'mw'],
    "dautyaka": ['cae', 'mw'],
    "dautyaṃ": ['ap90'],
    "dauvālika": ['mw'],
    "dauvārika": ['cae', 'ddsa', 'mw'],
    "dauvārikaḥ": ['ap90'],
    "dauś": ['mw'],
    "dauścarmya": ['cae', 'ddsa', 'mw'],
    "dauścarya": ['mw'],
    "dauścaryaṃ": ['ap90'],
    "dauḥ": ['mw'],
    "dauḥsraṃ": ['ap90'],
    "dauḥsthya": ['ddsa', 'mw'],
    "dauḥstra": ['mw'],
    "dauḥsādhikaḥ": ['ap90'],
    "dauḥśaleya": ['mw'],
    "dauḥśāsana": ['mw'],
    "dauḥśāsani": ['mw'],
    "dauḥśīlya": ['cae', 'ddsa', 'mw'],
    "dauḥśīlyaṃ": ['ap90'],
    "dauḥṣanti": ['cae', 'ddsa', 'mw'],
    "dauḥṣvapnya": ['cae', 'mw'],
    "dauḥṣṭhava": ['mw'],
    "dauṣ": ['mw'],
    "dauṣka": ['ap90', 'mw'],
    "dauṣkula": ['ap90', 'cae', 'mw'],
    "dauṣkuleya": ['cae', 'mw'],
    "dauṣkulya": ['cae', 'mw'],
    "dauṣkṛtya": ['cae', 'ddsa', 'mw'],
    "dauṣmanta": ['cae', 'mw'],
    "dauṣmanti": ['mw'],
    "dauṣmaṃtiḥ": ['ap90'],
    "dauṣprajña": ['bhs'],
    "dauṣprajñiya": ['bhs'],
    "dauṣpuruṣya": ['mw'],
    "dauṣyanta": ['cae', 'ddsa', 'mw'],
    "dauṣyanti": ['cae', 'ddsa', 'mw'],
    "dauṣyaṃtiḥ": ['ap90'],
    "dauṣṭhava": ['mw'],
    "dauṣṭhulya": ['bhs'],
    "dauṣṭya": ['cae', 'ddsa', 'mw'],
    "dauṣṭyaṃ": ['ap90'],
    "dava": ['cae', 'cped', 'ddsa', 'mw'],
    "davadagdhaka": ['mw'],
    "davadahana": ['mw'],
    "davadāha": ['cped'],
    "davadāna": ['mw'],
    "davara": ['mw'],
    "davaraka": ['mw'],
    "davathu": ['cae', 'mw'],
    "davathuḥ": ['ap90'],
    "davaya": ['mw'],
    "davayati": ['ap90'],
    "davaḍāha": ['cped'],
    "davaḍāhaka": ['cped'],
    "davaḥ": ['ap90'],
    "daviṣāṇi": ['ddsa'],
    "daviṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "daviṣṭham": ['mw'],
    "davāgni": ['cae', 'mw'],
    "davānala": ['cae', 'mw'],
    "davīyas": ['ap90', 'gra', 'mw'],
    "davīyaṃs": ['cae'],
    "day": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "daya": ['cped'],
    "dayamāna": ['cae'],
    "dayati": ['bhs', 'cped'],
    "dayhamāna": ['cped'],
    "dayhanta": ['cped'],
    "dayhati": ['cped'],
    "dayita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "dayitnu": ['ap90', 'mw'],
    "dayitā": ['mw'],
    "dayitādhīna": ['mw'],
    "dayitāmaya": ['mw'],
    "dayitāyamāna": ['mw'],
    "dayiṣṭha": ['gra'],
    "dayormi": ['mw'],
    "dayā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dayākara": ['mw'],
    "dayākūrca": ['mw'],
    "dayākṛt": ['mw'],
    "dayālasa": ['mw'],
    "dayālu": ['ap90', 'cae', 'ddsa', 'mw'],
    "dayāluka": ['mw'],
    "dayālutva": ['mw'],
    "dayālutā": ['mw'],
    "dayānidhi": ['mw'],
    "dayānvita": ['mw'],
    "dayāpanna": ['cped'],
    "dayāpūrvam": ['mw'],
    "dayārāma": ['mw'],
    "dayāvat": ['ddsa', 'mw'],
    "dayāvatī": ['mw'],
    "dayāvīra": ['mw'],
    "dayāyukta": ['mw'],
    "dayāśaṃkara": ['mw'],
    "dayāśīla": ['mw'],
    "daïṣṭha": ['gra'],
    "daś": ['bhs', 'ddsa', 'gra'],
    "daśa": ['cae', 'mw'],
    "daśabaddha": ['mw'],
    "daśabala": ['bhs', 'mw'],
    "daśabalabalin": ['mw'],
    "daśabalakāśyapa": ['mw'],
    "daśabalasūtra": ['bhs'],
    "daśabandha": ['cae', 'mw'],
    "daśabandhaka": ['mw'],
    "daśabhuji": ['gra', 'mw'],
    "daśabhujā": ['mw'],
    "daśabhūmaka": ['bhs'],
    "daśabhūmi": ['mw'],
    "daśabhūmiga": ['mw'],
    "daśabhūmika": ['mw'],
    "daśabhūmīśa": ['mw'],
    "daśabhūmīśvara": ['mw'],
    "daśabrāhmaṇa": ['mw'],
    "daśabāhu": ['mw'],
    "daśabṛhat": ['mw'],
    "daśacandra": ['mw'],
    "daśacatuṣka": ['mw'],
    "daśacchadin": ['mw'],
    "daśadaśin": ['cae', 'ddsa', 'mw'],
    "daśadaśāvayava": ['mw'],
    "daśadhanus": ['mw'],
    "daśadharmagata": ['mw'],
    "daśadharmasūtra": ['bhs'],
    "daśadhā": ['ap90', 'cae', 'ddsa', 'mw'],
    "daśadhīva": ['mw'],
    "daśadigvyavalokana": ['mw'],
    "daśadiś": ['cae', 'mw'],
    "daśadiṅmukha": ['cae'],
    "daśadyu": ['gra', 'mw'],
    "daśadāsa": ['mw'],
    "daśadṛṣṭāntakathā": ['mw'],
    "daśagaṇī": ['mw'],
    "daśagoṇi": ['mw'],
    "daśagrāma": ['mw'],
    "daśagrāmapati": ['cae', 'mw'],
    "daśagrāmika": ['mw'],
    "daśagrāmin": ['mw'],
    "daśagrāmī": ['mw'],
    "daśagrīva": ['cae', 'ddsa', 'mw'],
    "daśagu": ['mw'],
    "daśaguṇa": ['cae', 'mw'],
    "daśaguṇam": ['mw'],
    "daśaguṇita": ['mw'],
    "daśagva": ['cae', 'ddsa', 'gra', 'mw'],
    "daśagvin": ['cae', 'gra', 'mw'],
    "daśagārgya": ['mw'],
    "daśagīti": ['mw'],
    "daśagītikā": ['mw'],
    "daśahala": ['mw'],
    "daśaharā": ['mw'],
    "daśaharākathā": ['mw'],
    "daśaharāstotra": ['mw'],
    "daśahotṛ": ['mw'],
    "daśaikādaśika": ['mw'],
    "daśajyoti": ['mw'],
    "daśajyotis": ['mw'],
    "daśaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "daśakakṣia": ['gra'],
    "daśakakṣya": ['gra', 'mw'],
    "daśakamāsika": ['mw'],
    "daśakandhara": ['mw'],
    "daśakanyātīrtha": ['mw'],
    "daśakarmapaddhati": ['mw'],
    "daśakaṃdhara": ['cae'],
    "daśakaṇṭha": ['cae', 'mw'],
    "daśakaṇṭhajit": ['mw'],
    "daśakaṇṭhanigraha": ['mw'],
    "daśakaṇṭhāri": ['mw'],
    "daśakaṇṭhāya": ['mw'],
    "daśakumāracarita": ['mw'],
    "daśakumāracaritra": ['mw'],
    "daśakāmajavyasana": ['mw'],
    "daśakṣitigarbha": ['mw'],
    "daśakṣīra": ['mw'],
    "daśalakṣaṇa": ['mw'],
    "daśalakṣaṇaka": ['cae', 'mw'],
    "daśalakṣaṇī": ['mw'],
    "daśama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "daśamabhāva": ['mw'],
    "daśamahāvidyā": ['mw'],
    "daśamam": ['mw'],
    "daśamin": ['ap90', 'mw'],
    "daśamukha": ['cae', 'mw'],
    "daśamukharipu": ['mw'],
    "daśamukhavadha": ['mw'],
    "daśamukhāntaka": ['mw'],
    "daśamukhī": ['mw'],
    "daśamāla": ['mw'],
    "daśamālika": ['mw'],
    "daśamālī": ['mw'],
    "daśamānika": ['mw'],
    "daśamārikā": ['mw'],
    "daśamāsia": ['gra'],
    "daśamāsya": ['cae', 'ddsa', 'gra', 'mw'],
    "daśamāya": ['gra', 'mw'],
    "daśamī": ['ap90', 'mw'],
    "daśamīstha": ['cae', 'mw'],
    "daśamūla": ['mw'],
    "daśamūlī": ['mw'],
    "daśamūtraka": ['mw'],
    "daśan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "daśana": ['ap90', 'cae', 'ddsa', 'mw'],
    "daśanabīja": ['mw'],
    "daśanacchada": ['cae', 'mw'],
    "daśanakha": ['cae', 'mw'],
    "daśanapada": ['mw'],
    "daśanavasana": ['mw'],
    "daśanavasanāṅgarāga": ['mw'],
    "daśanavyaya": ['mw'],
    "daśanavāsas": ['mw'],
    "daśanaśikhara": ['mw'],
    "daśanaḥ": ['ap90'],
    "daśanocchiṣṭa": ['mw'],
    "daśanāli": ['mw'],
    "daśanāmaka": ['mw'],
    "daśanāḍhyā": ['mw'],
    "daśanāṃśu": ['mw'],
    "daśanāṅka": ['mw'],
    "daśapa": ['mw'],
    "daśapada": ['mw'],
    "daśapadma": ['mw'],
    "daśapadmavat": ['mw'],
    "daśapadya": ['mw'],
    "daśapakṣa": ['mw'],
    "daśapala": ['cae', 'ddsa', 'mw'],
    "daśaparvī": ['mw'],
    "daśapaśu": ['mw'],
    "daśapaṭu": ['mw'],
    "daśapeya": ['mw'],
    "daśaphalavrata": ['mw'],
    "daśapiṇḍaśrāddha": ['mw'],
    "daśapramati": ['gra', 'mw'],
    "daśapura": ['ap90', 'cae', 'mw'],
    "daśapuraṃdara": ['mw'],
    "daśapuruṣam": ['mw'],
    "daśapuruṣaṃrājya": ['mw'],
    "daśapuruṣānūkam": ['mw'],
    "daśapurī": ['mw'],
    "daśaputra": ['mw'],
    "daśapādī": ['mw'],
    "daśapāramitādhara": ['mw'],
    "daśapūlī": ['mw'],
    "daśapūra": ['mw'],
    "daśapūruṣa": ['mw'],
    "daśapūrvaratha": ['mw'],
    "daśapūrvin": ['mw'],
    "daśaratha": ['cae', 'gra', 'mw'],
    "daśarathalalitāvrata": ['mw'],
    "daśarathatattva": ['mw'],
    "daśarathavijaya": ['mw'],
    "daśarathayajñārambha": ['mw'],
    "daśaraśmiśata": ['mw'],
    "daśarca": ['cae', 'mw'],
    "daśarātra": ['cae', 'mw'],
    "daśarātraparvan": ['mw'],
    "daśarātraparyuṣita": ['mw'],
    "daśarūpa": ['cae', 'mw'],
    "daśarūpabhṛt": ['mw'],
    "daśarūpaka": ['cae', 'mw'],
    "daśarūpāloka": ['mw'],
    "daśarūpāvaloka": ['mw'],
    "daśarṣabha": ['mw'],
    "daśas": ['gra'],
    "daśasahaika": ['mw'],
    "daśasani": ['mw'],
    "daśasaptā": ['mw'],
    "daśastobha": ['mw'],
    "daśasvarṇa": ['cae'],
    "daśasy": ['cae', 'gra'],
    "daśasya": ['ddsa', 'mw'],
    "daśasyā": ['gra', 'mw'],
    "daśasāhasra": ['cae', 'mw'],
    "daśasāhasram": ['mw'],
    "daśasāhasrika": ['mw'],
    "daśat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "daśatas": ['mw'],
    "daśataulika": ['mw'],
    "daśataya": ['ap90', 'cae', 'gra', 'mw'],
    "daśatayī": ['mw'],
    "daśati": ['cae', 'ddsa', 'mw'],
    "daśatva": ['mw'],
    "daśavadana": ['mw'],
    "daśavaikālika": ['mw'],
    "daśavaktra": ['mw'],
    "daśavarga": ['bhs', 'mw'],
    "daśavarṣa": ['cae', 'mw'],
    "daśavarṣin": ['mw'],
    "daśavarṣīya": ['cae', 'mw'],
    "daśavidha": ['cae', 'mw'],
    "daśavidhasnānamantra": ['mw'],
    "daśavraja": ['gra', 'mw'],
    "daśavājin": ['mw'],
    "daśavāra": ['mw'],
    "daśavārṣika": ['cae', 'mw'],
    "daśavīra": ['mw'],
    "daśavṛkṣa": ['mw'],
    "daśavṛṣa": ['mw'],
    "daśayantra": ['gra', 'mw'],
    "daśayogabhaṅga": ['mw'],
    "daśayojana": ['gra', 'mw'],
    "daśayojanī": ['mw'],
    "daśayoktra": ['gra', 'mw'],
    "daśaśala": ['mw'],
    "daśaśata": ['cae', 'mw'],
    "daśaśatakaradhārin": ['cae', 'mw'],
    "daśaśatanayana": ['mw'],
    "daśaśataraśmi": ['mw'],
    "daśaśatatama": ['mw'],
    "daśaśatākṣa": ['mw'],
    "daśaśatāra": ['mw'],
    "daśaśatāṅghri": ['mw'],
    "daśaśatī": ['mw'],
    "daśaśipra": ['gra', 'mw'],
    "daśaśiras": ['bhs', 'cae', 'mw'],
    "daśaślokī": ['mw'],
    "daśaśākha": ['gra', 'mw'],
    "daśaśīrṣa": ['cae', 'mw'],
    "daśaṃdaśin": ['mw'],
    "daśaṭīkāsarvasva": ['mw'],
    "daśendhana": ['mw'],
    "daśendra": ['mw'],
    "daśendriya": ['mw'],
    "daśera": ['ap90', 'mw'],
    "daśeraka": ['cae', 'ddsa', 'mw'],
    "daśerakagaḍeraka": ['mw'],
    "daśerakaḥ": ['ap90'],
    "daśeruka": ['cae'],
    "daśeśa": ['cae', 'ddsa', 'mw'],
    "daśikā": ['bhs'],
    "daśin": ['ap90', 'cae', 'ddsa', 'mw'],
    "daśonasi": ['mw'],
    "daśonāsa": ['cae'],
    "daśopaniṣadbhāṣya": ['mw'],
    "daśottara": ['cae', 'mw'],
    "daśottarapadasaṃdhilipi": ['bhs'],
    "daśoṇi": ['gra', 'mw'],
    "daśoṇia": ['gra'],
    "daśoṇya": ['gra', 'mw'],
    "daśra": ['mw'],
    "daśā": ['ap90', 'cae', 'ddsa', 'mw'],
    "daśābdākhya": ['mw'],
    "daśābhīśu": ['gra', 'mw'],
    "daśādhipati": ['mw'],
    "daśāgni": ['mw'],
    "daśāha": ['cae', 'mw'],
    "daśākarṣa": ['mw'],
    "daśākarṣin": ['mw'],
    "daśākṣa": ['mw'],
    "daśākṣara": ['cae', 'mw'],
    "daśālakṣaṇa": ['mw'],
    "daśālambin": ['ddsa'],
    "daśālaṃkāramañjarī": ['mw'],
    "daśāmaya": ['mw'],
    "daśānana": ['cae', 'mw'],
    "daśānika": ['mw'],
    "daśānta": ['mw'],
    "daśāntaruṣya": ['cae', 'gra', 'mw'],
    "daśānugāna": ['mw'],
    "daśānīkinī": ['mw'],
    "daśāpanna": ['mw'],
    "daśāparipāka": ['mw'],
    "daśāpati": ['mw'],
    "daśāpavitra": ['mw'],
    "daśāphala": ['mw'],
    "daśāpāka": ['mw'],
    "daśārdha": ['cae', 'ddsa', 'mw'],
    "daśārdhabāṇa": ['mw'],
    "daśārdhatā": ['mw'],
    "daśārdhavayas": ['mw'],
    "daśārha": ['cae', 'ddsa', 'mw'],
    "daśārhaka": ['mw'],
    "daśārhī": ['mw'],
    "daśāritra": ['gra', 'mw'],
    "daśāruhā": ['mw'],
    "daśārṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "daśārṇeyu": ['mw'],
    "daśārṇā": ['mw'],
    "daśārṇāḥ": ['ap90'],
    "daśāsya": ['cae', 'mw'],
    "daśāsyajit": ['mw'],
    "daśāsyāntaka": ['mw'],
    "daśāvani": ['gra'],
    "daśāvara": ['cae', 'ddsa', 'mw'],
    "daśāvarta": ['mw'],
    "daśāvasthā": ['mw'],
    "daśāvat": ['mw'],
    "daśāvatāra": ['mw'],
    "daśāvatāracarita": ['mw'],
    "daśāvayava": ['mw'],
    "daśāvipāka": ['cae', 'mw'],
    "daśāviśeṣa": ['mw'],
    "daśāśva": ['mw'],
    "daśāśvamedha": ['mw'],
    "daśāśvamedhika": ['mw'],
    "daśāṃśa": ['ddsa', 'mw'],
    "daśāṅgula": ['cae', 'gra', 'mw'],
    "daśīvidarbha": ['mw'],
    "daḍī": ['mw'],
    "daḍḍha": ['cped'],
    "daḷha": ['cped'],
    "daḷhadamma": ['cped'],
    "daḷhadamma(n)": ['cped'],
    "daḷhadammi(n)": ['cped'],
    "daḷhamaṭṭalākoṭṭhaka": ['cped'],
    "daḷhaṁ": ['cped'],
    "daḷhikamma": ['cped'],
    "daḷhuddāpa": ['cped'],
    "daḷhīkamma": ['cped'],
    "daḷidda": ['cped'],
    "daḷiddaka": ['cped'],
    "daṃbh": ['ap90'],
    "daṃbhaka": ['ap90'],
    "daṃbhanaṃ": ['ap90'],
    "daṃbhaḥ": ['ap90'],
    "daṃbhin": ['ap90'],
    "daṃbholiḥ": ['ap90'],
    "daṃdaśaḥ": ['ap90'],
    "daṃdaśūka": ['ap90'],
    "daṃgh": ['ap90'],
    "daṃh": ['mw'],
    "daṃpati": ['cae'],
    "daṃpatī": ['ap90'],
    "daṃs": ['cae', 'ddsa', 'gra', 'mw'],
    "daṃsana": ['cae', 'ddsa', 'gra', 'mw'],
    "daṃsanaṃ": ['ap90'],
    "daṃsanā": ['cae', 'gra', 'mw'],
    "daṃsanāvat": ['gra', 'mw'],
    "daṃsas": ['cae', 'gra', 'mw'],
    "daṃsayitṛ": ['mw'],
    "daṃsi": ['mw'],
    "daṃsiṣṭha": ['cae', 'gra', 'mw'],
    "daṃsu": ['cae', 'ddsa', 'gra', 'mw'],
    "daṃsujūta": ['gra', 'mw'],
    "daṃsupatnī": ['cae', 'gra', 'mw'],
    "daṃtaka": ['ap90'],
    "daṃtaḥ": ['ap90'],
    "daṃtula": ['ap90'],
    "daṃtura": ['ap90'],
    "daṃturita": ['ap90'],
    "daṃtya": ['ap90'],
    "daṃtādaṃti": ['ap90'],
    "daṃtāvalaḥ": ['ap90'],
    "daṃś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "daṃśa": ['cae', 'ddsa', 'mw'],
    "daṃśabhīru": ['mw'],
    "daṃśabhīruka": ['mw'],
    "daṃśaccheda": ['cae'],
    "daṃśaka": ['ap90', 'mw'],
    "daṃśamaśaka": ['cae', 'mw'],
    "daṃśamūla": ['mw'],
    "daṃśana": ['cae', 'mw'],
    "daṃśanaṃ": ['ap90'],
    "daṃśanāśinī": ['mw'],
    "daṃśavadana": ['mw'],
    "daṃśaḥ": ['ap90'],
    "daṃśera": ['ap90', 'mw'],
    "daṃśikā": ['mw'],
    "daṃśin": ['ap90', 'mw'],
    "daṃśita": ['ap90', 'cae', 'mw'],
    "daṃśman": ['cae', 'mw'],
    "daṃśuka": ['cae', 'mw'],
    "daṃśī": ['ap90', 'mw'],
    "daṃḍ": ['ap90'],
    "daṃḍakaḥ": ['ap90'],
    "daṃḍanaṃ": ['ap90'],
    "daṃḍanīya": ['ap90'],
    "daṃḍavat": ['ap90'],
    "daṃḍaḥ": ['ap90'],
    "daṃḍikaḥ": ['ap90'],
    "daṃḍikā": ['ap90'],
    "daṃḍin": ['ap90'],
    "daṃḍita": ['ap90'],
    "daṃḍya": ['ap90'],
    "daṃḍādaṃḍi": ['ap90'],
    "daṃḍāraḥ": ['ap90'],
    "daṃḍāyate": ['ap90'],
    "daṃṣṭra": ['cae', 'ddsa', 'gra', 'mw'],
    "daṃṣṭrasena": ['bhs'],
    "daṃṣṭrika": ['ap90', 'mw'],
    "daṃṣṭrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "daṃṣṭrā": ['ap90', 'mw'],
    "daṃṣṭrādaṇḍa": ['mw'],
    "daṃṣṭrākarāla": ['cae', 'mw'],
    "daṃṣṭrākarālavat": ['mw'],
    "daṃṣṭrāla": ['ap90', 'mw'],
    "daṃṣṭrānivāsin": ['bhs', 'mw'],
    "daṃṣṭrāsena": ['mw'],
    "daṃṣṭrāviṣa": ['mw'],
    "daṃṣṭrāyudha": ['cae', 'mw'],
    "daṃṣṭrīkā": ['mw'],
    "daṃṣṭṛ": ['cae', 'mw'],
    "daṅgh": ['mw'],
    "daṅkṣṇu": ['cae', 'mw'],
    "daṇḍa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "daṇḍabhaya": ['mw'],
    "daṇḍabhaṅga": ['mw'],
    "daṇḍabhāj": ['cae', 'mw'],
    "daṇḍabhāsa": ['bhs', 'mw'],
    "daṇḍabhīti": ['mw'],
    "daṇḍabhṛt": ['cae', 'mw'],
    "daṇḍabāhu": ['mw'],
    "daṇḍacakra": ['cae', 'mw'],
    "daṇḍacchadana": ['mw'],
    "daṇḍadhara": ['cae', 'mw'],
    "daṇḍadharādhipati": ['mw'],
    "daṇḍadhāra": ['cae', 'mw'],
    "daṇḍadhāraka": ['mw'],
    "daṇḍadhāraṇa": ['cae', 'mw'],
    "daṇḍadhārin": ['cae', 'mw'],
    "daṇḍadhṛk": ['mw'],
    "daṇḍadāsa": ['cae', 'mw'],
    "daṇḍagaurī": ['mw'],
    "daṇḍaghaṭanā": ['mw'],
    "daṇḍaghna": ['cae', 'mw'],
    "daṇḍagrahaṇa": ['mw'],
    "daṇḍagrāha": ['mw'],
    "daṇḍahasta": ['cae', 'mw'],
    "daṇḍajita": ['cae', 'mw'],
    "daṇḍaka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "daṇḍakala": ['mw'],
    "daṇḍakalitavat": ['mw'],
    "daṇḍakamaṇḍalu": ['bhs', 'mw'],
    "daṇḍakamma": ['cped'],
    "daṇḍakandaka": ['mw'],
    "daṇḍakapālin": ['mw'],
    "daṇḍakarman": ['mw'],
    "daṇḍakartṛ": ['mw'],
    "daṇḍakathālikā": ['cped'],
    "daṇḍakaṭhina": ['cped'],
    "daṇḍaketu": ['mw'],
    "daṇḍaki": ['bhs'],
    "daṇḍakuśa": ['mw'],
    "daṇḍakā": ['mw'],
    "daṇḍakāka": ['mw'],
    "daṇḍakāla": ['cae'],
    "daṇḍakālasaka": ['ddsa', 'mw'],
    "daṇḍakāraṇya": ['cae', 'mw'],
    "daṇḍakāraṇyaprasthāna": ['mw'],
    "daṇḍakāsana": ['mw'],
    "daṇḍakāvana": ['mw'],
    "daṇḍakāṣṭha": ['cae', 'ddsa', 'mw'],
    "daṇḍakūla": ['mw'],
    "daṇḍalagna": ['bhs'],
    "daṇḍaleśa": ['cae', 'mw'],
    "daṇḍamatsya": ['mw'],
    "daṇḍamukha": ['mw'],
    "daṇḍamukhya": ['mw'],
    "daṇḍamānavaka": ['cped'],
    "daṇḍamātaṅga": ['mw'],
    "daṇḍamātha": ['mw'],
    "daṇḍamāṇava": ['mw'],
    "daṇḍamāṇavaka": ['cped'],
    "daṇḍana": ['cae', 'ddsa', 'mw'],
    "daṇḍanavidhi": ['mw'],
    "daṇḍanetṛ": ['cae', 'ddsa', 'mw'],
    "daṇḍanetṛtva": ['mw'],
    "daṇḍanidhāna": ['mw'],
    "daṇḍanigaḍa": ['cae'],
    "daṇḍanipātana": ['mw'],
    "daṇḍaniyoga": ['mw'],
    "daṇḍanāyaka": ['cae', 'ddsa', 'mw'],
    "daṇḍanāyakapuruṣa": ['mw'],
    "daṇḍanīti": ['cae', 'mw'],
    "daṇḍanītimat": ['mw'],
    "daṇḍanīya": ['cae', 'ddsa', 'mw'],
    "daṇḍapa": ['mw'],
    "daṇḍapadmāsana": ['mw'],
    "daṇḍapakṣaka": ['mw'],
    "daṇḍaparissāvana": ['cped'],
    "daṇḍaparāyana": ['cped'],
    "daṇḍaparāyaṇa": ['bhs', 'mw'],
    "daṇḍapesuṁ": ['cped'],
    "daṇḍapiṅgalaka": ['mw'],
    "daṇḍapoṇa": ['bhs', 'mw'],
    "daṇḍapradāna": ['mw'],
    "daṇḍaprajita": ['mw'],
    "daṇḍapraṇayana": ['mw'],
    "daṇḍapraṇāma": ['mw'],
    "daṇḍapāda": ['bhs'],
    "daṇḍapāla": ['cae', 'mw'],
    "daṇḍapālaka": ['mw'],
    "daṇḍapāruṣya": ['cae', 'mw'],
    "daṇḍapāruṣyavat": ['mw'],
    "daṇḍapāta": ['cae', 'mw'],
    "daṇḍapātana": ['mw'],
    "daṇḍapātanipāta": ['mw'],
    "daṇḍapātin": ['mw'],
    "daṇḍapāśa": ['cae'],
    "daṇḍapāśaka": ['mw'],
    "daṇḍapāśika": ['mw'],
    "daṇḍapāṃsula": ['mw'],
    "daṇḍapāṇi": ['bhs', 'cae', 'ddsa', 'mw'],
    "daṇḍapāṇī": ['cped'],
    "daṇḍasatthaka": ['cped'],
    "daṇḍasaṃkhyā": ['mw'],
    "daṇḍasena": ['mw'],
    "daṇḍasthāna": ['mw'],
    "daṇḍatva": ['mw'],
    "daṇḍatāmrī": ['mw'],
    "daṇḍatāḍana": ['mw'],
    "daṇḍavadha": ['cae', 'mw'],
    "daṇḍavaladhi": ['mw'],
    "daṇḍavant": ['cae'],
    "daṇḍavat": ['cae', 'mw'],
    "daṇḍavidhi": ['cae', 'mw'],
    "daṇḍavikalpa": ['cae', 'mw'],
    "daṇḍaviṣaya": ['mw'],
    "daṇḍaviṣkambha": ['mw'],
    "daṇḍavratadhara": ['mw'],
    "daṇḍavyūha": ['cae', 'mw'],
    "daṇḍavācika": ['cae', 'mw'],
    "daṇḍavādin": ['mw'],
    "daṇḍavāgurā": ['cped'],
    "daṇḍavāhin": ['mw'],
    "daṇḍavākarā": ['cped'],
    "daṇḍavākurā": ['cped'],
    "daṇḍavārita": ['mw'],
    "daṇḍavāsika": ['bhs', 'mw'],
    "daṇḍavāsin": ['mw'],
    "daṇḍavīrya": ['mw'],
    "daṇḍavṛkṣaka": ['mw'],
    "daṇḍay": ['cae'],
    "daṇḍaya": ['ddsa', 'mw'],
    "daṇḍayoga": ['cae', 'mw'],
    "daṇḍayāma": ['mw'],
    "daṇḍayātrā": ['cae', 'ddsa', 'mw'],
    "daṇḍaśarman": ['mw'],
    "daṇḍaśatru": ['mw'],
    "daṇḍaśrī": ['mw'],
    "daṇḍaśura": ['mw'],
    "daṇḍaśūra": ['cae'],
    "daṇḍaḍhakkā": ['mw'],
    "daṇḍeśa": ['mw'],
    "daṇḍi": ['mw'],
    "daṇḍidatta": ['mw'],
    "daṇḍika": ['cae', 'ddsa', 'mw'],
    "daṇḍikā": ['mw'],
    "daṇḍiman": ['mw'],
    "daṇḍimat": ['mw'],
    "daṇḍimuṇḍa": ['mw'],
    "daṇḍin": ['bhs', 'cae', 'mw'],
    "daṇḍita": ['cped', 'mw'],
    "daṇḍodyama": ['cae', 'ddsa', 'mw'],
    "daṇḍopaghātam": ['mw'],
    "daṇḍopānaha": ['cae', 'mw'],
    "daṇḍotpala": ['mw'],
    "daṇḍya": ['cae', 'ddsa', 'mw'],
    "daṇḍā": ['mw'],
    "daṇḍādaṇḍi": ['mw'],
    "daṇḍādhipa": ['cae', 'ddsa', 'mw'],
    "daṇḍādhipati": ['cae', 'mw'],
    "daṇḍādāna": ['cped'],
    "daṇḍāghāta": ['ddsa', 'mw'],
    "daṇḍāhata": ['mw'],
    "daṇḍājina": ['mw'],
    "daṇḍākhya": ['mw'],
    "daṇḍālasikā": ['mw'],
    "daṇḍālu": ['mw'],
    "daṇḍāmitrā": ['mw'],
    "daṇḍānīka": ['cae', 'mw'],
    "daṇḍāpatānaka": ['mw'],
    "daṇḍāpayati": ['bhs'],
    "daṇḍāpūpa": ['mw'],
    "daṇḍāpūpanyāya": ['mw'],
    "daṇḍāpūpikā": ['mw'],
    "daṇḍāpūpāyita": ['mw'],
    "daṇḍāra": ['mw'],
    "daṇḍāraka": ['ddsa', 'mw'],
    "daṇḍārta": ['mw'],
    "daṇḍāsana": ['mw'],
    "daṇḍāstra": ['mw'],
    "daṇḍāvayava": ['ddsa', 'mw'],
    "daṇḍāy": ['cae'],
    "daṇḍāya": ['mw'],
    "daṇḍāyamāna": ['cae'],
    "daṇḍāśrama": ['mw'],
    "daṇḍāśramin": ['mw'],
    "daṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "daṣṭaka": ['bhs'],
    "daṣṭamātra": ['cae', 'mw'],
    "daṣṭavya": ['mw'],
    "daṭṭha": ['cped'],
    "daṭṭha(r)": ['cped'],
    "daṭṭhabba": ['cped'],
    "daṭṭhayya": ['cped'],
    "daṭṭheyya": ['cped'],
    "daṭṭhu": ['cped'],
    "daṭṭhuṁ": ['cped'],
    "de": ['ap90', 'mw'],
    "dedīpyamāna": ['ap90', 'mw'],
    "dedīyitavai": ['mw'],
    "deha": ['cae', 'cped', 'ddsa', 'mw'],
    "dehabaddha": ['mw'],
    "dehabandha": ['mw'],
    "dehabheda": ['mw'],
    "dehabhuj": ['mw'],
    "dehabhāj": ['mw'],
    "dehabhṛt": ['cae', 'mw'],
    "dehacara": ['mw'],
    "dehacaryā": ['mw'],
    "dehacatuṣṭayavyavasthālakṣaṇa": ['mw'],
    "dehacyuta": ['mw'],
    "dehada": ['mw'],
    "dehadharma": ['mw'],
    "dehadhi": ['mw'],
    "dehadhāraka": ['mw'],
    "dehadhāraṇa": ['cae', 'mw'],
    "dehadhārin": ['mw'],
    "dehadhātṛ": ['mw'],
    "dehadhṛk": ['mw'],
    "dehadāha": ['cae', 'mw'],
    "dehadīpa": ['mw'],
    "dehagata": ['mw'],
    "dehagrahaṇa": ['mw'],
    "dehaja": ['cae', 'mw'],
    "dehaka": ['bhs', 'cped'],
    "dehakara": ['cae', 'mw'],
    "dehakartṛ": ['cae', 'mw'],
    "dehakośa": ['mw'],
    "dehakṛt": ['cae', 'mw'],
    "dehakṣaya": ['mw'],
    "dehalakṣaṇa": ['mw'],
    "dehaliḥ": ['ap90'],
    "dehalā": ['ap90', 'bhs', 'mw'],
    "dehalī": ['cae', 'ddsa', 'mw'],
    "dehalīdīpanyāya": ['mw'],
    "dehalīmuktapuṣpa": ['mw'],
    "dehalīśastotra": ['mw'],
    "dehalīśastuti": ['mw'],
    "dehamadhya": ['mw'],
    "dehambhara": ['mw'],
    "dehambharavārttika": ['mw'],
    "dehamānin": ['mw'],
    "dehamātrāvaśeṣita": ['mw'],
    "dehapatana": ['mw'],
    "dehapāta": ['mw'],
    "deharakṣā": ['cae', 'mw'],
    "dehasaṃcāriṇī": ['mw'],
    "dehasiddhisādhana": ['mw'],
    "dehasthasvarodaya": ['mw'],
    "dehasukha": ['mw'],
    "dehasāra": ['mw'],
    "dehatantra": ['mw'],
    "dehatva": ['mw'],
    "dehatyāga": ['cae', 'mw'],
    "dehavant": ['cae'],
    "dehavarman": ['mw'],
    "dehavat": ['ap90', 'ddsa', 'mw'],
    "dehavimukti": ['mw'],
    "dehavisarjana": ['mw'],
    "dehavāyu": ['mw'],
    "dehavṛnta": ['mw'],
    "dehavṛtti": ['cae', 'mw'],
    "dehayātrā": ['cae', 'mw'],
    "dehaśaṅku": ['mw'],
    "dehaḥ": ['ap90'],
    "dehaṃbhara": ['ap90'],
    "deheśvara": ['ddsa', 'mw'],
    "dehi": ['ddsa'],
    "dehikā": ['mw'],
    "dehin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dehinī": ['mw'],
    "dehodbhava": ['mw'],
    "dehodbhūta": ['mw'],
    "dehotkampa": ['cae', 'mw'],
    "dehānta": ['mw'],
    "dehāntara": ['mw'],
    "dehāntaraprāpti": ['mw'],
    "dehāri": ['mw'],
    "dehāsava": ['mw'],
    "dehātmavāda": ['ddsa', 'mw'],
    "dehātmavādin": ['mw'],
    "dehāvaraṇa": ['mw'],
    "dehāvasāna": ['mw'],
    "dehī": ['ddsa', 'gra', 'mw'],
    "dekkhiya": ['bhs'],
    "delima": ['mw'],
    "delu": ['bhs'],
    "dema": ['cped'],
    "denta": ['cped'],
    "dentu": ['cped'],
    "desa": ['cped'],
    "desaka": ['cped'],
    "desanā": ['cped'],
    "desanāgāmi(n)": ['cped'],
    "desaya(t)": ['cped'],
    "desayanta": ['cped'],
    "desayati": ['cped'],
    "desayissāmi": ['cped'],
    "desayī": ['cped'],
    "desenta": ['cped'],
    "desesi": ['cped'],
    "desessaṁ": ['cped'],
    "desessāmi": ['cped'],
    "desesuṁ": ['cped'],
    "deseta(r)": ['cped'],
    "desetabba": ['cped'],
    "deseti": ['cped'],
    "desetuṁ": ['cped'],
    "desetvā": ['cped'],
    "desissāmi": ['cped'],
    "desita": ['cped'],
    "desitavatthuka": ['cped'],
    "desituṁ": ['cped'],
    "desiya": ['cped'],
    "desiyamāna": ['cped'],
    "dessa": ['cped'],
    "dessiya": ['cped'],
    "desāpetabba": ['cped'],
    "desāpeti": ['cped'],
    "desāpetvā": ['cped'],
    "desīyati": ['cped'],
    "deta(r)": ['cped'],
    "deti": ['cped'],
    "detu": ['cped'],
    "deuliya": ['mw'],
    "dev": ['ap90', 'mw'],
    "deva": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "devabala": ['mw'],
    "devabali": ['mw'],
    "devabalā": ['mw'],
    "devabandhu": ['gra', 'mw'],
    "devabhadra": ['mw'],
    "devabhakta": ['gra', 'mw'],
    "devabhakti": ['cae', 'mw'],
    "devabhavana": ['mw'],
    "devabhaṭṭa": ['mw'],
    "devabhiṣaj": ['cae', 'mw'],
    "devabhoga": ['cae', 'mw'],
    "devabhojya": ['mw'],
    "devabhrāj": ['mw'],
    "devabhāga": ['mw'],
    "devabhāṣyasnānavidhipaddhati": ['mw'],
    "devabhīti": ['mw'],
    "devabhū": ['mw'],
    "devabhūmi": ['mw'],
    "devabhūri": ['mw'],
    "devabhūta": ['mw'],
    "devabhūti": ['mw'],
    "devabhūya": ['mw'],
    "devabhūyaṃgata": ['mw'],
    "devabodha": ['mw'],
    "devabodhi": ['mw'],
    "devabodhisattva": ['mw'],
    "devabrahman": ['mw'],
    "devabrāhmaṇa": ['mw'],
    "devabrāhmaṇasātkṛ": ['mw'],
    "devabāhu": ['mw'],
    "devacakra": ['mw'],
    "devacandra": ['mw'],
    "devacarita": ['mw'],
    "devacaryopaśobhita": ['mw'],
    "devacaryā": ['mw'],
    "devacchanda": ['cae', 'ddsa', 'mw'],
    "devacchandaprāsāda": ['mw'],
    "devacchandas": ['mw'],
    "devacchandasa": ['mw'],
    "devacikitsaka": ['mw'],
    "devacitta": ['mw'],
    "devacūḍa": ['bhs'],
    "devadaivatya": ['cae', 'mw'],
    "devadamanikā": ['mw'],
    "devadamanī": ['mw'],
    "devadantin": ['mw'],
    "devadarśa": ['mw'],
    "devadarśana": ['cae', 'mw'],
    "devadarśanin": ['mw'],
    "devadarśin": ['cae', 'mw'],
    "devadarśī": ['mw'],
    "devadatta": ['bhs', 'cae', 'ddsa', 'mw'],
    "devadattacara": ['mw'],
    "devadattaka": ['mw'],
    "devadattamaya": ['mw'],
    "devadattarūpya": ['mw'],
    "devadattaśatha": ['mw'],
    "devadattikā": ['mw'],
    "devadattā": ['mw'],
    "devadattāgraja": ['mw'],
    "devadattīya": ['mw'],
    "devadeva": ['cae', 'cped', 'mw'],
    "devadeveśa": ['cae', 'mw'],
    "devadevī": ['mw'],
    "devadhammika": ['cped'],
    "devadhara": ['mw'],
    "devadharma": ['mw'],
    "devadharman": ['mw'],
    "devadhiṣṇya": ['mw'],
    "devadhāman": ['mw'],
    "devadhānya": ['mw'],
    "devadhānī": ['mw'],
    "devadhūpa": ['mw'],
    "devadinna": ['mw'],
    "devadiṇṇa": ['mw'],
    "devadriac": ['gra'],
    "devadroṇī": ['mw'],
    "devadryac": ['mw'],
    "devadryañc": ['cae'],
    "devadryaṃc": ['ap90'],
    "devadundubhi": ['bhs', 'cped', 'mw'],
    "devadurga": ['mw'],
    "devadyumna": ['mw'],
    "devadālikā": ['mw'],
    "devadālī": ['mw'],
    "devadānī": ['mw'],
    "devadāru": ['cae', 'mw'],
    "devadārumaya": ['mw'],
    "devadāruvanamāhātmya": ['mw'],
    "devadāsa": ['mw'],
    "devadāsī": ['mw'],
    "devadīpa": ['mw'],
    "devadūta": ['cae', 'cped', 'mw'],
    "devadūti": ['mw'],
    "devadūtī": ['mw'],
    "devagaharaka": ['cped'],
    "devagama": ['mw'],
    "devagandharva": ['mw'],
    "devagandhā": ['mw'],
    "devagarbha": ['bhs', 'cae', 'mw'],
    "devagarbhā": ['mw'],
    "devagarjana": ['mw'],
    "devagava": ['mw'],
    "devagavī": ['cae', 'mw'],
    "devagaṇa": ['cae', 'mw'],
    "devagaṇadeva": ['mw'],
    "devagaṇeśvara": ['mw'],
    "devagaṇikā": ['mw'],
    "devaghoṣa": ['mw'],
    "devagiri": ['cae', 'mw'],
    "devagirī": ['mw'],
    "devagopa": ['gra'],
    "devagopā": ['gra', 'mw'],
    "devagraha": ['mw'],
    "devagrantha": ['mw'],
    "devagranthi": ['mw'],
    "devaguhya": ['cae', 'mw'],
    "devaguhī": ['mw'],
    "devagupta": ['bhs', 'cae', 'mw'],
    "devaguru": ['bhs', 'cae', 'mw'],
    "devagāndhāra": ['mw'],
    "devagāndhārī": ['mw'],
    "devagāyana": ['mw'],
    "devagṛha": ['cae', 'mw'],
    "devahavis": ['cae', 'mw'],
    "devahavya": ['cae', 'mw'],
    "devahel̤ana": ['mw'],
    "devaheti": ['cae', 'mw'],
    "devaheḍana": ['gra', 'mw'],
    "devahita": ['cae', 'gra', 'mw'],
    "devahiti": ['cae', 'gra', 'mw'],
    "devahitārthāya": ['mw'],
    "devahiṃsaka": ['mw'],
    "devahotra": ['mw'],
    "devahrada": ['mw'],
    "devahū": ['cae', 'gra', 'mw'],
    "devahūti": ['cae', 'gra', 'mw'],
    "devahūya": ['gra', 'mw'],
    "devaiddha": ['gra'],
    "devainasa": ['ddsa', 'mw'],
    "devaja": ['cae', 'mw'],
    "devajagdha": ['mw'],
    "devajagdhaka": ['mw'],
    "devajana": ['cae', 'gra', 'mw'],
    "devajananī": ['cae', 'mw'],
    "devajanavid": ['mw'],
    "devajanavidyā": ['mw'],
    "devajapa": ['mw'],
    "devajaya": ['mw'],
    "devajigucchaka": ['cped'],
    "devajuṣṭa": ['cae', 'gra', 'mw'],
    "devajā": ['cae', 'gra', 'mw'],
    "devajāmi": ['gra', 'mw'],
    "devajāta": ['cae', 'gra', 'mw'],
    "devajūta": ['cae', 'gra', 'mw'],
    "devajūti": ['mw'],
    "devaka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "devakabhojaputrī": ['mw'],
    "devakalaśa": ['mw'],
    "devakalpa": ['cae', 'mw'],
    "devakamalapura": ['mw'],
    "devakanyakā": ['cae', 'ddsa', 'mw'],
    "devakanyā": ['cae', 'mw'],
    "devakardama": ['mw'],
    "devakarma": ['gra', 'mw'],
    "devakarmakṛt": ['mw'],
    "devakarman": ['cae', 'mw'],
    "devakavaca": ['mw'],
    "devakaññā": ['cped'],
    "devakaḍa": ['mw'],
    "devakhāta": ['cae', 'mw'],
    "devakhātabila": ['mw'],
    "devakhātaka": ['mw'],
    "devakhātatīrtha": ['mw'],
    "devakilbiṣa": ['cae', 'gra', 'mw'],
    "devakinandana": ['mw'],
    "devakirī": ['mw'],
    "devakośa": ['mw'],
    "devakrī": ['mw'],
    "devakula": ['cae', 'ddsa', 'mw'],
    "devakulika": ['bhs', 'mw'],
    "devakulikā": ['mw'],
    "devakulyā": ['mw'],
    "devakulāvāsa": ['mw'],
    "devakuru": ['mw'],
    "devakurumbā": ['mw'],
    "devakusuma": ['mw'],
    "devakuśa": ['bhs'],
    "devakuṇḍa": ['mw'],
    "devakya": ['mw'],
    "devakā": ['mw'],
    "devakāma": ['gra', 'mw'],
    "devakānta": ['mw'],
    "devakārya": ['cae', 'mw'],
    "devakātmajā": ['mw'],
    "devakāya": ['cped'],
    "devakāñcana": ['mw'],
    "devakāṣṭha": ['mw'],
    "devakī": ['ap90', 'mw'],
    "devakīmātṛ": ['mw'],
    "devakīnandana": ['cae', 'ddsa', 'mw'],
    "devakīputra": ['cae', 'mw'],
    "devakīrti": ['mw'],
    "devakīsūnu": ['cae', 'mw'],
    "devakīya": ['ap90', 'mw'],
    "devakūṭa": ['mw'],
    "devakṛta": ['cae', 'gra', 'mw'],
    "devakṛtya": ['cae', 'mw'],
    "devakṣatra": ['gra', 'mw'],
    "devakṣema": ['mw'],
    "devakṣetra": ['mw'],
    "devala": ['bhs', 'cae', 'ddsa', 'mw'],
    "devalaka": ['cae'],
    "devalakaḥ": ['ap90'],
    "devalakṣma": ['mw'],
    "devalasmṛti": ['mw'],
    "devalatā": ['mw'],
    "devalaḥ": ['ap90'],
    "devalekhā": ['mw'],
    "devalipi": ['bhs'],
    "devaliṅga": ['cae', 'ddsa', 'mw'],
    "devaloka": ['cae', 'cped', 'mw'],
    "devalokagamanīya": ['cped'],
    "devalokagāminiya": ['cped'],
    "devalokapāla": ['mw'],
    "devalokegata": ['mw'],
    "devalokābhilaṣita": ['bhs'],
    "devalāti": ['mw'],
    "devalāṅgulikā": ['mw'],
    "devamadhu": ['mw'],
    "devamakuṭa": ['bhs'],
    "devamalimluc": ['mw'],
    "devamanuṣya": ['cae', 'mw'],
    "devamata": ['mw'],
    "devamati": ['bhs', 'mw'],
    "devamatiprabha": ['bhs'],
    "devamaya": ['cae', 'mw'],
    "devamañjara": ['mw'],
    "devamaṇi": ['cae', 'mw'],
    "devamaṇḍala": ['mw'],
    "devamithuna": ['mw'],
    "devamitra": ['mw'],
    "devamitrā": ['bhs', 'mw'],
    "devamiśra": ['mw'],
    "devamuni": ['cae', 'mw'],
    "devamādana": ['gra', 'mw'],
    "devamālā": ['mw'],
    "devamāna": ['gra', 'mw'],
    "devamānaka": ['mw'],
    "devamārga": ['mw'],
    "devamāsa": ['mw'],
    "devamāta": ['mw'],
    "devamātṛ": ['cae', 'mw'],
    "devamātṛka": ['mw'],
    "devamāya": ['mw'],
    "devamāyā": ['mw'],
    "devamīḍha": ['mw'],
    "devamīḍhuṣa": ['mw'],
    "devan": ['ap90', 'mw'],
    "devana": ['cae', 'ddsa', 'gra', 'mw'],
    "devanadī": ['cae', 'ddsa', 'mw'],
    "devanakṣatra": ['mw'],
    "devanala": ['mw'],
    "devanandin": ['mw'],
    "devanandā": ['mw'],
    "devanaḥ": ['ap90'],
    "devanibandha": ['mw'],
    "devanid": ['cae', 'gra', 'mw'],
    "devanikāya": ['cae', 'cped', 'mw'],
    "devanindaka": ['mw'],
    "devanindā": ['mw'],
    "devanirmita": ['cae', 'mw'],
    "devanirmitā": ['mw'],
    "devanirmālya": ['mw'],
    "devaniśrayaṇī": ['mw'],
    "devaniśreṇī": ['mw'],
    "devanā": ['mw'],
    "devanābha": ['mw'],
    "devanāgarī": ['mw'],
    "devanāla": ['mw'],
    "devanāma": ['mw'],
    "devanāman": ['cae', 'mw'],
    "devanātha": ['cae', 'mw'],
    "devanāyaka": ['mw'],
    "devanāyakapañcāśat": ['mw'],
    "devanāyakastuti": ['mw'],
    "devanītha": ['mw'],
    "devapada": ['mw'],
    "devapallīpaṭṭana": ['mw'],
    "devapariṣad": ['mw'],
    "devaparṇa": ['mw'],
    "devapatha": ['mw'],
    "devapathatīrtha": ['mw'],
    "devapathīya": ['mw'],
    "devapati": ['cae', 'ddsa', 'mw'],
    "devapatimantrin": ['mw'],
    "devapatnī": ['cae', 'gra', 'mw'],
    "devapattana": ['mw'],
    "devapañcarātra": ['mw'],
    "devapaśu": ['cae', 'mw'],
    "devapaṇḍita": ['mw'],
    "devaprabha": ['bhs', 'mw'],
    "devaprabhā": ['mw'],
    "devaprakāśinī": ['mw'],
    "devaprastha": ['mw'],
    "devaprasāda": ['mw'],
    "devaprasūta": ['mw'],
    "devapratikṛti": ['mw'],
    "devapratimā": ['mw'],
    "devapratiṣṭhā": ['mw'],
    "devapratiṣṭhāprayoga": ['mw'],
    "devapratiṣṭhātattva": ['mw'],
    "devaprayāga": ['mw'],
    "devapraśna": ['mw'],
    "devapriya": ['cae', 'mw'],
    "devapsaras": ['gra', 'mw'],
    "devapur": ['cae', 'mw'],
    "devapura": ['mw'],
    "devapurohita": ['mw'],
    "devapurā": ['bhs', 'mw'],
    "devapurīmāhātmya": ['mw'],
    "devaputra": ['bhs', 'cae', 'gra', 'mw'],
    "devaputramāra": ['bhs', 'mw'],
    "devaputrikā": ['mw'],
    "devaputrī": ['mw'],
    "devaputta": ['cped'],
    "devapuṣpa": ['mw'],
    "devapāda": ['mw'],
    "devapādamūla": ['mw'],
    "devapāla": ['mw'],
    "devapālita": ['mw'],
    "devapāna": ['cae', 'gra', 'mw'],
    "devapātra": ['cae', 'mw'],
    "devapātrin": ['mw'],
    "devapāṇi": ['mw'],
    "devapīyu": ['mw'],
    "devapūjaka": ['mw'],
    "devapūjita": ['mw'],
    "devapūjya": ['mw'],
    "devapūjā": ['cae', 'mw'],
    "devapūjāvidhi": ['mw'],
    "devapūrva": ['cae', 'mw'],
    "devapūrvakam": ['cae', 'mw'],
    "devara": ['cae', 'ddsa', 'mw'],
    "devaraghnī": ['mw'],
    "devarahasya": ['mw'],
    "devaraktadaṃśī": ['mw'],
    "devarakṣita": ['mw'],
    "devarakṣitā": ['mw'],
    "devarata": ['cae', 'ddsa', 'mw'],
    "devaratha": ['cae', 'mw'],
    "devarathāhnya": ['mw'],
    "devarati": ['mw'],
    "devaravatī": ['mw'],
    "devaraḥ": ['ap90'],
    "devaretasa": ['mw'],
    "devarāj": ['cae', 'mw'],
    "devarāja": ['bhs', 'cae', 'cped', 'mw'],
    "devarāja(n)": ['cped'],
    "devarājagupta": ['bhs'],
    "devarājamahiṣīstotra": ['mw'],
    "devarājan": ['mw'],
    "devarājaprabandha": ['mw'],
    "devarājaprabha": ['bhs'],
    "devarājasamadyuti": ['mw'],
    "devarājayajvan": ['mw'],
    "devarājya": ['cae', 'mw'],
    "devarāma": ['mw'],
    "devarāta": ['cae', 'mw'],
    "devarāya": ['mw'],
    "devarāṣṭra": ['mw'],
    "devarūpin": ['cae', 'mw'],
    "devarūpā": ['mw'],
    "devar̥ṣi": ['ddsa'],
    "devarṣi": ['cae', 'mw'],
    "devarṣicarita": ['mw'],
    "devarṣipitṛvallabha": ['mw'],
    "devarṣitva": ['mw'],
    "devarṣivarya": ['mw'],
    "devasabha": ['mw'],
    "devasabhya": ['mw'],
    "devasabhā": ['mw'],
    "devasad": ['cae', 'mw'],
    "devasadana": ['mw'],
    "devasadda": ['cped'],
    "devasadman": ['cae', 'mw'],
    "devasaha": ['mw'],
    "devasahā": ['mw'],
    "devasakha": ['cae', 'mw'],
    "devasakhi": ['mw'],
    "devasarasa": ['mw'],
    "devasarṣapa": ['mw'],
    "devasattra": ['mw'],
    "devasattva": ['bhs', 'mw'],
    "devasatya": ['mw'],
    "devasava": ['mw'],
    "devasaṃdha": ['mw'],
    "devasaṃgītayonin": ['mw'],
    "devasaṃhitā": ['mw'],
    "devasaṃnidhi": ['mw'],
    "devasaṃsad": ['mw'],
    "devasaṃyukta": ['mw'],
    "devasena": ['cae', 'mw'],
    "devasenā": ['gra', 'mw'],
    "devasenāpati": ['mw'],
    "devasenāpriya": ['mw'],
    "devasiddhayātra": ['bhs'],
    "devasiddhi": ['mw'],
    "devasika": ['bhs'],
    "devasikaṁ": ['cped'],
    "devasiṃha": ['mw'],
    "devasmitā": ['mw'],
    "devasoma": ['mw'],
    "devasomaka": ['mw'],
    "devasopānā": ['bhs'],
    "devastava": ['mw'],
    "devasthali": ['mw'],
    "devasthāna": ['mw'],
    "devastrī": ['mw'],
    "devastut": ['gra', 'mw'],
    "devasumanas": ['bhs', 'mw'],
    "devasumati": ['gra', 'mw'],
    "devasunda": ['mw'],
    "devasuṣi": ['mw'],
    "devasva": ['cae', 'mw'],
    "devasvāmin": ['mw'],
    "devasvāpaharaṇa": ['mw'],
    "devasyatvaka": ['mw'],
    "devasāgaragaṇi": ['mw'],
    "devasākṣya": ['mw'],
    "devasāt": ['ap90'],
    "devasātbhū": ['mw'],
    "devasātkṛ": ['mw'],
    "devasāvarṇi": ['mw'],
    "devasāyujya": ['mw'],
    "devasū": ['mw'],
    "devasūda": ['mw'],
    "devasūkakṣetra": ['mw'],
    "devasūri": ['mw'],
    "devasṛṣṭa": ['cae', 'mw'],
    "devasṛṣṭā": ['mw'],
    "devata": ['bhs'],
    "devatalpa": ['mw'],
    "devatama": ['mw'],
    "devatara": ['mw'],
    "devataras": ['mw'],
    "devataratha": ['mw'],
    "devatarpaṇa": ['mw'],
    "devataru": ['mw'],
    "devataṭika": ['bhs'],
    "devatejyā": ['mw'],
    "devatopadeśana": ['mw'],
    "devatrā": ['cae', 'gra', 'mw'],
    "devatrāta": ['mw'],
    "devatta": ['cae', 'cped', 'gra', 'mw'],
    "devattana": ['cped'],
    "devatumula": ['cae', 'ddsa', 'mw'],
    "devatuposatha": ['cped'],
    "devatva": ['cae', 'gra', 'mw'],
    "devatya": ['ap90', 'cae', 'ddsa', 'mw'],
    "devatyā": ['mw'],
    "devatā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "devatābhyarcana": ['mw'],
    "devatābhyarcanapara": ['mw'],
    "devatābādha": ['mw'],
    "devatādarśana": ['mw'],
    "devatādhipa": ['mw'],
    "devatādhyāya": ['mw'],
    "devatādvaṃdva": ['mw'],
    "devatāgāra": ['cae', 'ddsa', 'mw'],
    "devatāgṛha": ['cae', 'mw'],
    "devatājit": ['mw'],
    "devatālaka": ['mw'],
    "devatālaya": ['mw'],
    "devatāmandira": ['cae', 'mw'],
    "devatāmaya": ['cae', 'ddsa', 'mw'],
    "devatāmaṇi": ['mw'],
    "devatāmithuna": ['mw'],
    "devatāmūrtiprakaraṇa": ['mw'],
    "devatānigama": ['mw'],
    "devatānukrama": ['mw'],
    "devatānukramaṇī": ['mw'],
    "devatānussati": ['cped'],
    "devatāpratimā": ['mw'],
    "devatāpratiṣṭhāvidhi": ['mw'],
    "devatāpraṇidhāna": ['mw'],
    "devatāpāramya": ['mw'],
    "devatāpūjana": ['mw'],
    "devatārcana": ['cae', 'mw'],
    "devatārcanakrama": ['mw'],
    "devatārcanavidhi": ['mw'],
    "devatārādhana": ['mw'],
    "devatāsahāyin": ['cae', 'mw'],
    "devatāsnāna": ['mw'],
    "devatāsthāpanavidhi": ['mw'],
    "devatāsvarūpavicāra": ['mw'],
    "devatāsūtra": ['bhs'],
    "devatāt": ['cae', 'ddsa', 'gra', 'mw'],
    "devatātas": ['mw'],
    "devatāti": ['cae', 'gra', 'mw'],
    "devatātman": ['mw'],
    "devatātmā": ['mw'],
    "devatātva": ['mw'],
    "devatātvanirṇaya": ['mw'],
    "devatāveśman": ['mw'],
    "devatāvādavicāra": ['mw'],
    "devatāvāripūjā": ['mw'],
    "devatāyatana": ['mw'],
    "devatāśeṣa": ['cae', 'mw'],
    "devatāśraya": ['mw'],
    "devatāḍa": ['mw'],
    "devatāḍaka": ['mw'],
    "devatī": ['bhs'],
    "devatīrtha": ['mw'],
    "devatīrthamaya": ['mw'],
    "devatīrthasvāmin": ['mw'],
    "devatūposatha": ['cped'],
    "devaukas": ['mw'],
    "devavacanā": ['bhs', 'mw'],
    "devavadha": ['cae', 'mw'],
    "devavadhū": ['cae', 'mw'],
    "devavaktra": ['mw'],
    "devavallabha": ['mw'],
    "devavanda": ['cae', 'gra', 'mw'],
    "devavant": ['cae'],
    "devavara": ['mw'],
    "devavardhaki": ['mw'],
    "devavardhana": ['mw'],
    "devavarman": ['mw'],
    "devavartman": ['mw'],
    "devavarya": ['mw'],
    "devavarṇinī": ['mw'],
    "devavarṣa": ['mw'],
    "devavat": ['gra', 'mw'],
    "devavatī": ['mw'],
    "devaveśman": ['mw'],
    "devavibhāga": ['mw'],
    "devavid": ['cae', 'mw'],
    "devavidyā": ['mw'],
    "devavijayagaṇi": ['mw'],
    "devavimalagaṇi": ['mw'],
    "devaviś": ['cae', 'mw'],
    "devaviśā": ['cae', 'mw'],
    "devavrata": ['cae', 'mw'],
    "devavratin": ['mw'],
    "devavyacas": ['gra', 'mw'],
    "devavāhana": ['cae', 'gra', 'mw'],
    "devavālāha": ['bhs'],
    "devavāta": ['gra', 'mw'],
    "devavāyu": ['mw'],
    "devavāṇī": ['mw'],
    "devavī": ['cae', 'gra', 'mw'],
    "devavīti": ['cae', 'gra', 'mw'],
    "devavṛkṣa": ['mw'],
    "devavṛtti": ['mw'],
    "devay": ['cae', 'gra'],
    "devaya": ['mw'],
    "devayaj": ['cae', 'ddsa', 'mw'],
    "devayajana": ['cae', 'mw'],
    "devayajanatva": ['mw'],
    "devayajanavat": ['mw'],
    "devayaji": ['mw'],
    "devayajya": ['cae', 'gra', 'mw'],
    "devayajyā": ['gra', 'mw'],
    "devayajña": ['cae', 'mw'],
    "devayat": ['ddsa'],
    "devayaśas": ['mw'],
    "devayaśasa": ['mw'],
    "devayaśasin": ['mw'],
    "devayaṣṭi": ['mw'],
    "devayoni": ['mw'],
    "devayoṣā": ['cae', 'mw'],
    "devayu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "devayuga": ['cae', 'mw'],
    "devayukta": ['cae', 'gra', 'mw'],
    "devayā": ['cae', 'gra', 'mw'],
    "devayājin": ['cae', 'mw'],
    "devayājñika": ['mw'],
    "devayāna": ['cae', 'gra', 'mw'],
    "devayāniya": ['cped'],
    "devayānī": ['ap90', 'mw'],
    "devayānīya": ['mw'],
    "devayātrin": ['mw'],
    "devayātrā": ['cae', 'ddsa', 'mw'],
    "devayātu": ['mw'],
    "devayāvan": ['gra', 'mw'],
    "devayū": ['cae'],
    "devaññatara": ['cped'],
    "devaśabda": ['mw'],
    "devaśakti": ['ddsa', 'mw'],
    "devaśarman": ['bhs', 'cae', 'mw'],
    "devaśas": ['gra', 'mw'],
    "devaśatabhāṣya": ['mw'],
    "devaśatru": ['cae', 'gra', 'mw'],
    "devaśekhara": ['mw'],
    "devaśeṣa": ['cae', 'mw'],
    "devaśilpa": ['mw'],
    "devaśilpin": ['mw'],
    "devaśiri": ['bhs'],
    "devaśiśu": ['mw'],
    "devaśiṣṭa": ['cae', 'gra', 'mw'],
    "devaśravas": ['gra', 'mw'],
    "devaśreṇī": ['mw'],
    "devaśreṣṭha": ['mw'],
    "devaśrut": ['cae', 'gra', 'mw'],
    "devaśruta": ['mw'],
    "devaśrī": ['bhs', 'mw'],
    "devaśrīgarbha": ['bhs', 'mw'],
    "devaśrū": ['mw'],
    "devaśuddha": ['bhs'],
    "devaśunī": ['cae', 'mw'],
    "devaśābaratantra": ['mw'],
    "devaśūra": ['mw'],
    "devaḍaha": ['bhs'],
    "devaṃgama": ['mw'],
    "devaṇṇabhaṭṭa": ['mw'],
    "devaṛṣabha": ['mw'],
    "devaṛṣi": ['mw'],
    "devaṭa": ['mw'],
    "devaṭaḥ": ['ap90'],
    "devaṭṭī": ['mw'],
    "deveddha": ['cae', 'ddsa', 'gra', 'mw'],
    "devej": ['mw'],
    "devejya": ['mw'],
    "devendra": ['cae', 'mw'],
    "devendrabuddhi": ['bhs', 'mw'],
    "devendracūḍa": ['bhs'],
    "devendragarbha": ['bhs'],
    "devendrakīrtideva": ['mw'],
    "devendrarāja": ['bhs'],
    "devendrasamaya": ['bhs', 'mw'],
    "devendrasūri": ['mw'],
    "devendravarman": ['mw'],
    "devendrāśrama": ['mw'],
    "deveśa": ['cae', 'mw'],
    "deveśatīrtha": ['mw'],
    "deveśaya": ['mw'],
    "deveśayaḥ": ['ap90'],
    "deveśvara": ['cae', 'mw'],
    "deveśvarapaṇḍita": ['mw'],
    "deveśī": ['mw'],
    "deveṣita": ['cae', 'gra', 'mw'],
    "deveṣu": ['cae', 'mw'],
    "deveṣṭa": ['mw'],
    "deveṣṭā": ['mw'],
    "devi": ['mw'],
    "devia": ['gra'],
    "devidāsa": ['mw'],
    "devika": ['ap90', 'mw'],
    "devikā": ['ddsa', 'mw'],
    "devila": ['mw'],
    "devin": ['cae', 'mw'],
    "devitama": ['mw'],
    "devitamā": ['mw'],
    "devitavya": ['mw'],
    "devitvā": ['mw'],
    "devitṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "deviya": ['mw'],
    "devodyāna": ['mw'],
    "devopāsaka": ['mw'],
    "devy": ['mw'],
    "devya": ['cae', 'gra', 'mw'],
    "devyaparādhakṣamāpaṇastotra": ['mw'],
    "devyaṃ": ['ap90'],
    "devyaṣṭaka": ['mw'],
    "devyaṣṭottara": ['mw'],
    "devyupaniṣad": ['cae', 'mw'],
    "devyāgamanatantra": ['mw'],
    "devyāryāśataka": ['mw'],
    "devyātharvaṇaśīrṣopaniṣad": ['mw'],
    "devyāvaraṇapūjā": ['mw'],
    "devyāyatana": ['ddsa', 'mw'],
    "devā": ['mw'],
    "devābharaṇa": ['bhs'],
    "devābhika": ['bhs'],
    "devābhimukha": ['mw'],
    "devābhīṣṭā": ['mw'],
    "devāc": ['gra', 'mw'],
    "devācārya": ['mw'],
    "devācāryadigvijaya": ['mw'],
    "devādhideva": ['mw'],
    "devādhipa": ['cae', 'mw'],
    "devādhipati": ['mw'],
    "devāgamastotra": ['mw'],
    "devāgamālaṃkṛti": ['mw'],
    "devāgāra": ['cae', 'mw'],
    "devāhvaya": ['mw'],
    "devāhāra": ['mw'],
    "devājīva": ['mw'],
    "devājīvin": ['mw'],
    "devākrīḍa": ['mw'],
    "devākṣara": ['mw'],
    "devālaya": ['mw'],
    "devālayalakṣaṇa": ['mw'],
    "devālayapratiṣṭhā": ['mw'],
    "devālayapratiṣṭhāvidhi": ['mw'],
    "devālayotsavādikrama": ['mw'],
    "devālaṃkṛta": ['bhs'],
    "devālā": ['mw'],
    "devānanda": ['mw'],
    "devānandā": ['mw'],
    "devāndhas": ['mw'],
    "devānna": ['cae', 'mw'],
    "devānta": ['mw'],
    "devāntaka": ['mw'],
    "devāntakavadha": ['mw'],
    "devānucara": ['mw'],
    "devānukrama": ['mw'],
    "devānuyāyin": ['mw'],
    "devānāmpriya": ['ddsa', 'mw'],
    "devānīka": ['cae', 'ddsa', 'mw'],
    "devāpi": ['gra', 'mw'],
    "devāraṇya": ['mw'],
    "devārcaka": ['mw'],
    "devārcana": ['cae', 'mw'],
    "devārcanakramapaddhati": ['mw'],
    "devārha": ['mw'],
    "devārhaṇa": ['mw'],
    "devārhā": ['mw'],
    "devāri": ['cae', 'mw'],
    "devāribalasūdana": ['mw'],
    "devāripa": ['mw'],
    "devārpaṇa": ['mw'],
    "devārya": ['mw'],
    "devārādhana": ['mw'],
    "devārādhanā": ['mw'],
    "devāsura": ['cae', 'mw'],
    "devāsuragaṇādhyakṣa": ['mw'],
    "devāsuragaṇāgraṇī": ['mw'],
    "devāsuragaṇāśraya": ['mw'],
    "devāsuraguru": ['mw'],
    "devāsuramaheśvara": ['mw'],
    "devāsuramahāmātra": ['mw'],
    "devāsuramahāśraya": ['mw'],
    "devāsuranamaskṛta": ['mw'],
    "devāsurapati": ['mw'],
    "devāsuravaraprada": ['mw'],
    "devāsuravinirmātṛ": ['mw'],
    "devāsureśvara": ['mw'],
    "devātideva": ['mw'],
    "devātitha": ['mw'],
    "devātithi": ['mw'],
    "devātman": ['cae', 'mw'],
    "devātmaśakti": ['mw'],
    "devātmā": ['mw'],
    "devāvant": ['cae'],
    "devāvasatha": ['mw'],
    "devāvat": ['gra', 'mw'],
    "devāvataraṇa": ['bhs', 'mw'],
    "devāvatāra": ['bhs', 'mw'],
    "devāvatārasūtra": ['bhs'],
    "devāvāsa": ['mw'],
    "devāvī": ['cae', 'gra', 'mw'],
    "devāvṛdh": ['cae', 'mw'],
    "devāvṛdha": ['mw'],
    "devāy": ['cae'],
    "devāya": ['mw'],
    "devāyant": ['cae'],
    "devāyatana": ['mw'],
    "devāyu": ['cae', 'mw'],
    "devāyudha": ['mw'],
    "devāyuṣa": ['mw'],
    "devāyū": ['cae', 'mw'],
    "devāñc": ['cae'],
    "devāñjana": ['mw'],
    "devāśva": ['cae', 'mw'],
    "devāṃśa": ['ddsa', 'mw'],
    "devāṅga": ['mw'],
    "devāṅgacaritra": ['mw'],
    "devāṅganā": ['cae', 'mw'],
    "devāṅkīpūjā": ['mw'],
    "devāṭa": ['mw'],
    "devāṭaḥ": ['ap90'],
    "devī": ['ap90', 'bhs', 'cped', 'ddsa', 'gra', 'mw'],
    "devībhavana": ['cae', 'mw'],
    "devībhedagiri": ['mw'],
    "devībhujaṃga": ['mw'],
    "devībhāgavatapurāṇa": ['mw'],
    "devībhāgavatasthiti": ['mw'],
    "devībhāva": ['mw'],
    "devībhū": ['cae'],
    "devīdatta": ['mw'],
    "devīdhāman": ['mw'],
    "devīdāsa": ['mw'],
    "devīgarbhagṛha": ['mw'],
    "devīgṛha": ['cae', 'mw'],
    "devīhṛdaya": ['mw'],
    "devīka": ['mw'],
    "devīkalpa": ['mw'],
    "devīkavaca": ['mw'],
    "devīkoṭa": ['mw'],
    "devīkrīḍā": ['mw'],
    "devīkālottara": ['mw'],
    "devīkṛti": ['mw'],
    "devīmahiman": ['mw'],
    "devīmahādeva": ['mw'],
    "devīmata": ['mw'],
    "devīmāhātmya": ['mw'],
    "devīmāhātmyamantravibhāgakrama": ['mw'],
    "devīmāhātmyapāṭhavidhi": ['mw'],
    "devīmānanirṇaya": ['mw'],
    "devīmānasapūjana": ['mw'],
    "devīmānasapūjāvidhi": ['mw'],
    "devīnavaratna": ['mw'],
    "devīnityapūjāvidhi": ['mw'],
    "devīnāmāvalī": ['mw'],
    "devīparapūjāvidhi": ['mw'],
    "devīparicaryā": ['mw'],
    "devīpañcaratna": ['mw'],
    "devīpañcaśatī": ['mw'],
    "devīpurāṇa": ['mw'],
    "devīpurāṇīya": ['mw'],
    "devīpādadvaya": ['mw'],
    "devīpūjanabhāskara": ['mw'],
    "devīpūjāpaddhati": ['mw'],
    "devīpūjāprakaraṇa": ['mw'],
    "devīpūjāvidhi": ['mw'],
    "devīrahasya": ['mw'],
    "devīrāpaka": ['mw'],
    "devīrāpasaka": ['mw'],
    "devīsahasranāman": ['mw'],
    "devīsahāya": ['mw'],
    "devīsiṃhadeva": ['mw'],
    "devīstotra": ['mw'],
    "devīstuti": ['mw'],
    "devīsvarūpastuti": ['mw'],
    "devīsūkta": ['mw'],
    "devītantra": ['mw'],
    "devītva": ['mw'],
    "devīyāmalatantra": ['mw'],
    "devīśataka": ['mw'],
    "devīśatanāmastotra": ['mw'],
    "devīṃdhiyaka": ['mw'],
    "devṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "devṛghnī": ['mw'],
    "devṛkāma": ['mw'],
    "deya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "deyadharma": ['bhs', 'mw'],
    "deyya": ['cped'],
    "deyyadhamma": ['cped'],
    "deśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "deśabha": ['mw'],
    "deśabhaṅga": ['ddsa', 'mw'],
    "deśabhramaṇa": ['mw'],
    "deśabhraṃśa": ['mw'],
    "deśabhāṣā": ['cae', 'mw'],
    "deśabhāṣāntara": ['cae', 'mw'],
    "deśabhāṣāvijñāna": ['mw'],
    "deśacyuti": ['ddsa', 'mw'],
    "deśadharma": ['cae', 'mw'],
    "deśadṛṣṭa": ['cae', 'mw'],
    "deśaja": ['mw'],
    "deśajña": ['mw'],
    "deśajāta": ['mw'],
    "deśaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "deśakapaṭu": ['mw'],
    "deśakaḥ": ['ap90'],
    "deśakaṇṭaka": ['mw'],
    "deśakāla": ['cae', 'ddsa', 'mw'],
    "deśakālajña": ['mw'],
    "deśakālavibhāga": ['mw'],
    "deśakālavid": ['mw'],
    "deśakālavirodhin": ['mw'],
    "deśakālavyatīta": ['mw'],
    "deśakālavyavasthita": ['mw'],
    "deśakārī": ['mw'],
    "deśamānika": ['mw'],
    "deśana": ['bhs'],
    "deśanatā": ['bhs'],
    "deśanirṇaya": ['mw'],
    "deśanā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "deśanāpāṭha": ['bhs'],
    "deśapālī": ['mw'],
    "deśarakṣin": ['mw'],
    "deśarājacarita": ['mw'],
    "deśarūpa": ['mw'],
    "deśasaukhya": ['mw'],
    "deśastha": ['mw'],
    "deśasvāmin": ['mw'],
    "deśavibhraṃśa": ['mw'],
    "deśavirodhin": ['mw'],
    "deśaviruddha": ['mw'],
    "deśavyavahāra": ['mw'],
    "deśavāsin": ['mw'],
    "deśavṛtta": ['mw'],
    "deśayati": ['bhs'],
    "deśayin": ['bhs'],
    "deśaḥ": ['ap90'],
    "deśika": ['ap90', 'cae', 'mw'],
    "deśikavijaya": ['mw'],
    "deśikopaniṣad": ['mw'],
    "deśin": ['cae', 'ddsa', 'mw'],
    "deśinī": ['ap90', 'mw'],
    "deśita": ['ap90', 'mw'],
    "deśopadeśa": ['mw'],
    "deśopasarga": ['mw'],
    "deśya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "deśyabhikṣu": ['mw'],
    "deśyanidarśana": ['mw'],
    "deśyanighaṇṭu": ['mw'],
    "deśācāra": ['mw'],
    "deśākhya": ['mw'],
    "deśākhyā": ['mw'],
    "deśākramaṇa": ['ddsa', 'mw'],
    "deśāntara": ['cae', 'mw'],
    "deśāntarabhāṇḍānayana": ['mw'],
    "deśāntaragamana": ['cae', 'mw'],
    "deśāntaramṛtakriyānirūpaṇa": ['mw'],
    "deśāntaraphala": ['mw'],
    "deśāntarastha": ['cae', 'mw'],
    "deśāntarin": ['mw'],
    "deśāntarita": ['mw'],
    "deśāpekṣā": ['mw'],
    "deśātithi": ['cae', 'mw'],
    "deśāvakāśika": ['mw'],
    "deśāvakāśikavrata": ['mw'],
    "deśāṭana": ['cae', 'mw'],
    "deśī": ['ap90', 'ddsa', 'mw'],
    "deśīkaṭṭari": ['mw'],
    "deśīkośa": ['cae', 'mw'],
    "deśīnāmamālā": ['cae', 'mw'],
    "deśīnṛtya": ['mw'],
    "deśīprakāśa": ['mw'],
    "deśītva": ['mw'],
    "deśītāla": ['mw'],
    "deśīvarāḍī": ['mw'],
    "deśīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "deśīyarājaśekharakośa": ['mw'],
    "deśīyavarāḍī": ['mw'],
    "deśīyaśabdasaṃgraha": ['mw'],
    "deśīśabdasaṃgraha": ['mw'],
    "deḍḍubha": ['cped'],
    "deḍḍubhaka": ['cped'],
    "deṅgapāla": ['mw'],
    "deṇṭikā": ['mw'],
    "deṣṇa": ['cae', 'gra', 'mw'],
    "deṣṇaṃ": ['ap90'],
    "deṣṇu": ['ap90', 'mw'],
    "deṣṭavya": ['ddsa', 'mw'],
    "deṣṭha": ['cae', 'gra', 'mw'],
    "deṣṭra": ['cae', 'gra', 'mw'],
    "deṣṭrī": ['gra', 'mw'],
    "deṣṭṛ": ['cae', 'mw'],
    "dha": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "dhagaddhagiti": ['mw'],
    "dhagiti": ['ddsa', 'mw'],
    "dhainava": ['gra', 'mw'],
    "dhainuka": ['mw'],
    "dhainukaṃ": ['ap90'],
    "dhairya": ['cae', 'ddsa', 'mw'],
    "dhairyadhara": ['mw'],
    "dhairyadhvaṃsa": ['mw'],
    "dhairyakalita": ['mw'],
    "dhairyamitra": ['mw'],
    "dhairyapāramitā": ['mw'],
    "dhairyatā": ['mw'],
    "dhairyavat": ['mw'],
    "dhairyavṛtti": ['mw'],
    "dhairyayukta": ['mw'],
    "dhairyaṃ": ['ap90'],
    "dhaivara": ['cae', 'mw'],
    "dhaivata": ['ddsa', 'mw'],
    "dhaivataḥ": ['ap90'],
    "dhaivatya": ['mw'],
    "dhaivatyaṃ": ['ap90'],
    "dhaiṣṭha": ['gra'],
    "dhaja": ['cped'],
    "dhajabaddha": ['cped'],
    "dhajabandha": ['cped'],
    "dhaji(n)": ['cped'],
    "dhajāhaṭa": ['cped'],
    "dhajālu": ['cped'],
    "dhak": ['ap90', 'ddsa', 'mw'],
    "dhakit": ['mw'],
    "dhakk": ['ap90', 'mw'],
    "dhakkhiṇaggi": ['cped'],
    "dhakkhiṇena": ['cped'],
    "dhakkhiṇā": ['cped'],
    "dhakāra": ['mw'],
    "dhakṣat": ['cae', 'mw'],
    "dhakṣu": ['cae', 'gra', 'mw'],
    "dhalaṇḍa": ['mw'],
    "dhalila": ['mw'],
    "dham": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "dhama": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhamadhama": ['mw'],
    "dhamadhamā": ['ap90', 'mw'],
    "dhamadhamāy": ['cae'],
    "dhamadhamāya": ['mw'],
    "dhamaka": ['mw'],
    "dhamakaḥ": ['ap90'],
    "dhamamāna": ['cped'],
    "dhamana": ['ap90', 'bhs', 'cae', 'mw'],
    "dhamani": ['cae', 'cped', 'gra', 'mw'],
    "dhamanisantha": ['cped'],
    "dhamanisanthatagatta": ['cped'],
    "dhamanisaṃtata": ['mw'],
    "dhamanisaṇṭhita": ['cped'],
    "dhamaniḥ": ['ap90'],
    "dhamanī": ['mw'],
    "dhamanīla": ['mw'],
    "dhamanīrajjusaṃtata": ['mw'],
    "dhamara": ['bhs', 'mw'],
    "dhamati": ['cped'],
    "dhamayati": ['cped'],
    "dhameti": ['cped'],
    "dhami": ['mw'],
    "dhamin": ['mw'],
    "dhamita": ['mw'],
    "dhamitra": ['mw'],
    "dhamiḥ": ['ap90'],
    "dhamma": ['cped'],
    "dhamma(d)dasa": ['cped'],
    "dhamma(n)": ['cped'],
    "dhamma(t)thera": ['cped'],
    "dhammabhisamaya": ['cped'],
    "dhammacakka": ['cped'],
    "dhammacakkappavattana": ['cped'],
    "dhammacakkhu": ['cped'],
    "dhammacariyā": ['cped'],
    "dhammacetiya": ['cped'],
    "dhammacintanā": ['cped'],
    "dhammacodaka": ['cped'],
    "dhammacāri(n)": ['cped'],
    "dhammadesanā": ['cped'],
    "dhammadessi(n)": ['cped'],
    "dhammadhara": ['cped'],
    "dhammadhipa": ['cped'],
    "dhammadhātu": ['cped'],
    "dhammadīpa": ['cped'],
    "dhammagarahi(n)": ['cped'],
    "dhammagaru": ['cped'],
    "dhammagutta": ['cped'],
    "dhammagārava": ['cped'],
    "dhammajīvi(n)": ['cped'],
    "dhammakamma": ['cped'],
    "dhammakaraka": ['cped'],
    "dhammakathika": ['cped'],
    "dhammakathā": ['cped'],
    "dhammakkhandha": ['cped'],
    "dhammakāya": ['cped'],
    "dhammala": ['mw'],
    "dhammalaḥ": ['ap90'],
    "dhammanetti": ['cped'],
    "dhammanijjhānakhanti": ['cped'],
    "dhammanisanti": ['cped'],
    "dhammanupassi(n)": ['cped'],
    "dhammanussati": ['cped'],
    "dhammanusāri(n)": ['cped'],
    "dhammapada": ['cped'],
    "dhammapariyatti": ['cped'],
    "dhammapariyāya": ['cped'],
    "dhammapaṭirūpaka": ['cped'],
    "dhammapaṭisambhidā": ['cped'],
    "dhammapaṭisaṁyutta": ['cped'],
    "dhammapīti": ['cped'],
    "dhammarāja": ['cped'],
    "dhammarāja(n)": ['cped'],
    "dhammasamuppāda": ['cped'],
    "dhammasandosa": ['cped'],
    "dhammasaṅgaha": ['cped'],
    "dhammasāri(n)": ['cped'],
    "dhammatta": ['cped'],
    "dhammatthenaka": ['cped'],
    "dhammatā": ['cped'],
    "dhammaveda": ['cped'],
    "dhammavicaya": ['cped'],
    "dhammavādi(n)": ['cped'],
    "dhammayoga": ['cped'],
    "dhammayāgi(n)": ['cped'],
    "dhammaññū": ['cped'],
    "dhammaṁ carati": ['cped'],
    "dhammaṭa": ['ddsa', 'mw'],
    "dhammaṭṭha": ['cped'],
    "dhammcudita": ['cped'],
    "dhammcuditaka": ['cped'],
    "dhammena": ['cped'],
    "dhammika": ['cped'],
    "dhammikā": ['ddsa', 'mw'],
    "dhammilla": ['cae', 'ddsa', 'mw'],
    "dhammillacaritra": ['mw'],
    "dhammiya": ['cped'],
    "dhammiyamāna": ['cped'],
    "dhammketu": ['cped'],
    "dhammādhipatteyya": ['cped'],
    "dhammādāsa": ['cped'],
    "dhammānuvatti(n)": ['cped'],
    "dhammārāma": ['cped'],
    "dhammāyatana": ['cped'],
    "dhammī": ['cped'],
    "dhammīkathā": ['cped'],
    "dhammūpahāra": ['cped'],
    "dhammūpasaṁhita": ['cped'],
    "dhamyamāna": ['mw'],
    "dhamyat": ['mw'],
    "dhamātra": ['mw'],
    "dhan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhana": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dhanabhakṣa": ['gra', 'mw'],
    "dhanacandra": ['mw'],
    "dhanacchū": ['mw'],
    "dhanacyuta": ['mw'],
    "dhanada": ['cae', 'mw'],
    "dhanadadeva": ['mw'],
    "dhanadarpa": ['mw'],
    "dhanadastotra": ['mw'],
    "dhanadatta": ['cae', 'mw'],
    "dhanadatīrtha": ['mw'],
    "dhanadaṇḍa": ['cae', 'mw'],
    "dhanadeva": ['ddsa', 'mw'],
    "dhanadeśvara": ['cae', 'ddsa', 'mw'],
    "dhanadeśvaratīrtha": ['mw'],
    "dhanadharma": ['mw'],
    "dhanadharman": ['mw'],
    "dhanadhāniya": ['cped'],
    "dhanadhānya": ['mw'],
    "dhanadhānyādhika": ['mw'],
    "dhanadhānī": ['mw'],
    "dhanadā": ['cae', 'gra', 'mw'],
    "dhanadākṣī": ['mw'],
    "dhanadāmantra": ['mw'],
    "dhanadānuja": ['ddsa', 'mw'],
    "dhanadāpūjāyantra": ['mw'],
    "dhanadāstotra": ['mw'],
    "dhanadāvāsa": ['mw'],
    "dhanadāya": ['mw'],
    "dhanadāyin": ['mw'],
    "dhanagarva": ['mw'],
    "dhanagarvita": ['mw'],
    "dhanagiri": ['mw'],
    "dhanagoptṛ": ['mw'],
    "dhanagupta": ['bhs', 'mw'],
    "dhanaguptatā": ['mw'],
    "dhanahara": ['bhs', 'mw'],
    "dhanaharin": ['mw'],
    "dhanaharī": ['mw'],
    "dhanahāraka": ['cped', 'mw'],
    "dhanahārin": ['mw'],
    "dhanahārya": ['cae', 'mw'],
    "dhanahīna": ['cae', 'mw'],
    "dhanahīnatā": ['mw'],
    "dhanahṛt": ['mw'],
    "dhanaiśvarya": ['cae', 'mw'],
    "dhanaiṣin": ['cae', 'mw'],
    "dhanajit": ['cae', 'gra', 'mw'],
    "dhanajāni": ['cped'],
    "dhanajāta": ['mw'],
    "dhanaka": ['mw'],
    "dhanakaḥ": ['ap90'],
    "dhanakeli": ['mw'],
    "dhanakkīta": ['cped'],
    "dhanakośa": ['cae', 'ddsa', 'mw'],
    "dhanakrītā": ['mw'],
    "dhanakrītī": ['mw'],
    "dhanakāma": ['mw'],
    "dhanakāmya": ['mw'],
    "dhanakṣaya": ['cae', 'mw'],
    "dhanalobha": ['cae', 'mw'],
    "dhanalobhin": ['mw'],
    "dhanalubdha": ['mw'],
    "dhanamada": ['cae', 'mw'],
    "dhanamitra": ['cae', 'mw'],
    "dhanamohana": ['mw'],
    "dhanamūla": ['mw'],
    "dhanamūlya": ['mw'],
    "dhanamūlyatā": ['mw'],
    "dhananetṛ": ['mw'],
    "dhananāśa": ['cae', 'ddsa', 'mw'],
    "dhanapara": ['mw'],
    "dhanapati": ['bhs', 'cae', 'mw'],
    "dhanapatigupta": ['bhs'],
    "dhanapiśācikā": ['mw'],
    "dhanapiśācī": ['mw'],
    "dhanapriya": ['mw'],
    "dhanapriyā": ['mw'],
    "dhanapāla": ['bhs', 'cae', 'mw'],
    "dhanapālaka": ['bhs'],
    "dhanarakṣa": ['cae', 'mw'],
    "dhanarakṣaka": ['mw'],
    "dhanarc": ['cae', 'gra'],
    "dhanarca": ['mw'],
    "dhanarci": ['cae', 'mw'],
    "dhanarūpa": ['mw'],
    "dhanarṇa": ['mw'],
    "dhanasammata": ['mw'],
    "dhanasampad": ['mw'],
    "dhanasampatti": ['mw'],
    "dhanasani": ['cae', 'mw'],
    "dhanasañcaya": ['ddsa'],
    "dhanasaṃcaya": ['cae', 'mw'],
    "dhanasaṃcayana": ['mw'],
    "dhanasaṃcayin": ['mw'],
    "dhanasaṃmata": ['bhs'],
    "dhanaspṛt": ['cae', 'gra', 'mw'],
    "dhanastha": ['mw'],
    "dhanasthāna": ['mw'],
    "dhanasthānādhikārin": ['mw'],
    "dhanasvāmin": ['cae', 'mw'],
    "dhanasyaka": ['mw'],
    "dhanasā": ['cae', 'gra', 'mw'],
    "dhanasādhana": ['mw'],
    "dhanasāti": ['cae', 'gra', 'mw'],
    "dhanasū": ['mw'],
    "dhanatama": ['mw'],
    "dhanatyaj": ['mw'],
    "dhanatṛpti": ['ddsa', 'mw'],
    "dhanatṛṣṇā": ['mw'],
    "dhanava": ['mw'],
    "dhanava(t)": ['cped'],
    "dhanavant": ['cae'],
    "dhanavarjita": ['cae', 'mw'],
    "dhanavarman": ['mw'],
    "dhanavat": ['ap90', 'mw'],
    "dhanavatī": ['mw'],
    "dhanavibhāga": ['mw'],
    "dhanaviparyaya": ['mw'],
    "dhanavyaya": ['cae', 'mw'],
    "dhanavṛddha": ['cae', 'mw'],
    "dhanavṛddhi": ['cae', 'mw'],
    "dhanayauvanaśālin": ['cae', 'mw'],
    "dhanañjaya": ['ddsa'],
    "dhanaśrī": ['bhs', 'mw'],
    "dhanaṃ": ['ap90'],
    "dhanaṃdadā": ['mw'],
    "dhanaṃjaya": ['cae', 'gra', 'mw'],
    "dhanaṃjayakośa": ['mw'],
    "dhanaṃjayanighaṇṭu": ['mw'],
    "dhanaṃjayanāmamālā": ['mw'],
    "dhanaṃjayasaṃgraha": ['mw'],
    "dhanaṃjayasena": ['mw'],
    "dhanaṃjayasūtra": ['bhs'],
    "dhanaṃjayavijaya": ['cae', 'mw'],
    "dhanaṃjayaḥ": ['ap90'],
    "dhandha": ['bhs', 'mw'],
    "dhandhaka": ['bhs'],
    "dhandhañña": ['cped'],
    "dhandhuka": ['mw'],
    "dhandhāyati": ['bhs'],
    "dhandhīkriyate": ['bhs'],
    "dhanecchā": ['ddsa', 'mw'],
    "dhaneya": ['mw'],
    "dhaneyaka": ['mw'],
    "dhaneyakaṃ": ['ap90'],
    "dhaneś": ['mw'],
    "dhaneśa": ['cae', 'mw'],
    "dhaneśatva": ['mw'],
    "dhaneśvara": ['bhs', 'cae', 'mw'],
    "dhaneśvarī": ['mw'],
    "dhania": ['gra'],
    "dhanika": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "dhanikatā": ['mw'],
    "dhanikā": ['mw'],
    "dhanin": ['ap90', 'cae', 'gra', 'mw'],
    "dhaniya": ['cped'],
    "dhaniṣṭha": ['ap90', 'cae', 'gra', 'mw'],
    "dhaniṣṭhā": ['mw'],
    "dhanopakṣaya": ['cae'],
    "dhanotpatti": ['mw'],
    "dhanoṣman": ['cae', 'mw'],
    "dhanta": ['cped'],
    "dhanu": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dhanuacyut": ['gra'],
    "dhanuan": ['gra'],
    "dhanudharā": ['bhs'],
    "dhanuggaha": ['cped'],
    "dhanugupta": ['mw'],
    "dhanuhastā": ['mw'],
    "dhanuka": ['cped'],
    "dhanukalāpa": ['cped'],
    "dhanuketakī": ['mw'],
    "dhanunāśa": ['bhs'],
    "dhanur": ['mw'],
    "dhanurbhṛt": ['cae', 'mw'],
    "dhanurdhara": ['cae', 'mw'],
    "dhanurdhārin": ['cae', 'mw'],
    "dhanurdruma": ['mw'],
    "dhanurdurga": ['cae', 'mw'],
    "dhanurdvitīya": ['mw'],
    "dhanurgraha": ['cae', 'ddsa', 'mw'],
    "dhanurgrāha": ['cae', 'mw'],
    "dhanurgrāhin": ['cae', 'mw'],
    "dhanurguṇa": ['mw'],
    "dhanurguṇā": ['mw'],
    "dhanurhasta": ['mw'],
    "dhanurjyā": ['cae', 'mw'],
    "dhanurjyātalaśabda": ['mw'],
    "dhanurlatā": ['cae', 'mw'],
    "dhanurmadhya": ['mw'],
    "dhanurmaha": ['mw'],
    "dhanurmakha": ['mw'],
    "dhanurmālā": ['mw'],
    "dhanurmārga": ['mw'],
    "dhanurmāsamāhātmya": ['mw'],
    "dhanurvakra": ['mw'],
    "dhanurvaktra": ['mw'],
    "dhanurveda": ['mw'],
    "dhanurvedacintāmaṇi": ['mw'],
    "dhanurvedapara": ['mw'],
    "dhanurvedaparāyaṇa": ['mw'],
    "dhanurvedaprakaraṇa": ['mw'],
    "dhanurvedasāra": ['mw'],
    "dhanurvedin": ['mw'],
    "dhanurvidyā": ['cae', 'mw'],
    "dhanurvidyādīpikā": ['mw'],
    "dhanurvidyārambhaprayoga": ['mw'],
    "dhanurvāta": ['mw'],
    "dhanurvṛkṣa": ['mw'],
    "dhanuryantra": ['mw'],
    "dhanuryaṣṭi": ['cae', 'mw'],
    "dhanuryogyā": ['mw'],
    "dhanuryāsa": ['mw'],
    "dhanurāja": ['mw'],
    "dhanurākāra": ['mw'],
    "dhanurākṛti": ['mw'],
    "dhanurārtnī": ['cae', 'mw'],
    "dhanurāsana": ['mw'],
    "dhanurāśi": ['mw'],
    "dhanus": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhanusata": ['cped'],
    "dhanustambha": ['mw'],
    "dhanutṛ": ['cae', 'gra', 'mw'],
    "dhanuśreṇī": ['mw'],
    "dhanuḥ": ['ap90', 'bhs', 'mw'],
    "dhanuḥkhaṇḍa": ['mw'],
    "dhanuḥkāṇḍa": ['mw'],
    "dhanuḥpaṭa": ['mw'],
    "dhanuḥsaṃstha": ['mw'],
    "dhanuḥstambha": ['mw'],
    "dhanuḥśata": ['cae', 'mw'],
    "dhanuḥśreṇī": ['mw'],
    "dhanuḥśākhā": ['mw'],
    "dhanuḥśālā": ['mw'],
    "dhanuṣ": ['mw'],
    "dhanuṣa": ['mw'],
    "dhanuṣka": ['cae', 'ddsa', 'mw'],
    "dhanuṣkalāpa": ['bhs'],
    "dhanuṣkalāpaka": ['bhs'],
    "dhanuṣkapāla": ['mw'],
    "dhanuṣkara": ['mw'],
    "dhanuṣkarī": ['mw'],
    "dhanuṣkarṣaṇa": ['mw'],
    "dhanuṣketakī": ['bhs'],
    "dhanuṣketu": ['bhs'],
    "dhanuṣkhaṇḍa": ['mw'],
    "dhanuṣkhātā": ['mw'],
    "dhanuṣkoṭi": ['cae', 'mw'],
    "dhanuṣkoṭī": ['cae', 'mw'],
    "dhanuṣkāra": ['cae', 'mw'],
    "dhanuṣkārika": ['bhs'],
    "dhanuṣkārin": ['bhs'],
    "dhanuṣkāṇḍa": ['cae', 'ddsa', 'mw'],
    "dhanuṣkṛt": ['cae', 'mw'],
    "dhanuṣmant": ['cae'],
    "dhanuṣmat": ['ap90', 'mw'],
    "dhanuṣmattā": ['mw'],
    "dhanuṣmatī": ['mw'],
    "dhanuṣpaṭa": ['mw'],
    "dhanuṣpāṇi": ['cae', 'mw'],
    "dhanuṣākṣa": ['mw'],
    "dhanv": ['cae', 'ddsa', 'gra', 'mw'],
    "dhanva": ['bhs', 'cae', 'ddsa', 'mw'],
    "dhanvacara": ['gra', 'mw'],
    "dhanvacyut": ['cae', 'gra', 'mw'],
    "dhanvadhi": ['mw'],
    "dhanvadurga": ['cae', 'ddsa', 'mw'],
    "dhanvaga": ['mw'],
    "dhanvaja": ['mw'],
    "dhanvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhanvana": ['ddsa', 'mw'],
    "dhanvantara": ['mw'],
    "dhanvantari": ['cae', 'ddsa', 'mw'],
    "dhanvantaridarpabhaṅga": ['mw'],
    "dhanvantarigrantha": ['mw'],
    "dhanvantarigrastā": ['mw'],
    "dhanvantariguṇāguṇayogaśata": ['mw'],
    "dhanvantarinighaṇṭu": ['mw'],
    "dhanvantaripañcaka": ['mw'],
    "dhanvantarisāranidhi": ['mw'],
    "dhanvantarivilāsa": ['mw'],
    "dhanvantariyajña": ['mw'],
    "dhanvantarīya": ['mw'],
    "dhanvanya": ['cae', 'mw'],
    "dhanvapati": ['mw'],
    "dhanvarṇas": ['gra', 'mw'],
    "dhanvataru": ['mw'],
    "dhanvayavāsa": ['mw'],
    "dhanvayavāsaka": ['mw'],
    "dhanvayāsa": ['mw'],
    "dhanvayāsaka": ['mw'],
    "dhanvaṃ": ['ap90'],
    "dhanvaṃtaraṃ": ['ap90'],
    "dhanvaṃtariḥ": ['ap90'],
    "dhanvaṅga": ['mw'],
    "dhanvibhāṣya": ['mw'],
    "dhanvin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhanvinaḥ": ['ap90'],
    "dhanvā": ['mw'],
    "dhanvācārya": ['mw'],
    "dhanvārti": ['cae'],
    "dhanvāsah": ['cae', 'gra', 'mw'],
    "dhanvāvin": ['cae', 'mw'],
    "dhanvāyana": ['cae', 'ddsa', 'mw'],
    "dhanvāyin": ['cae', 'mw'],
    "dhanya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhanyabhānu": ['bhs'],
    "dhanyaka": ['ddsa', 'mw'],
    "dhanyammanya": ['ddsa', 'mw'],
    "dhanyastotra": ['mw'],
    "dhanyatithi": ['mw'],
    "dhanyatva": ['mw'],
    "dhanyatā": ['cae', 'mw'],
    "dhanyavāda": ['mw'],
    "dhanyaṃmanya": ['ap90'],
    "dhanyodaya": ['ddsa', 'mw'],
    "dhanyā": ['mw'],
    "dhanyāka": ['mw'],
    "dhanyākara": ['bhs'],
    "dhanyākaṃ": ['ap90'],
    "dhanyāśī": ['mw'],
    "dhanyāṣṭaka": ['mw'],
    "dhanādhigoptṛ": ['mw'],
    "dhanādhikāra": ['mw'],
    "dhanādhikārin": ['mw'],
    "dhanādhikṛta": ['mw'],
    "dhanādhipa": ['cae', 'mw'],
    "dhanādhipati": ['cae', 'mw'],
    "dhanādhipatya": ['mw'],
    "dhanādhyakṣa": ['cae', 'mw'],
    "dhanādāna": ['cae', 'mw'],
    "dhanādānanibandhana": ['mw'],
    "dhanāgama": ['cae', 'ddsa', 'mw'],
    "dhanāndha": ['mw'],
    "dhanānvita": ['mw'],
    "dhanāpaha": ['bhs'],
    "dhanāpahāra": ['mw'],
    "dhanāpti": ['mw'],
    "dhanārcita": ['mw'],
    "dhanārgha": ['mw'],
    "dhanārjana": ['mw'],
    "dhanārthin": ['cae', 'ddsa', 'mw'],
    "dhanāya": ['ddsa', 'mw'],
    "dhanāyati": ['ap90', 'cped'],
    "dhanāyu": ['cae', 'mw'],
    "dhanāyus": ['mw'],
    "dhanāyā": ['mw'],
    "dhanāśrī": ['mw'],
    "dhanāśā": ['mw'],
    "dhanāḍhya": ['cae', 'mw'],
    "dhanāḍhyatā": ['mw'],
    "dhanī": ['ap90'],
    "dhanīkā": ['mw'],
    "dhanīrāma": ['mw'],
    "dhanīya": ['mw'],
    "dhanīyaka": ['mw'],
    "dhanīyakaṃ": ['ap90'],
    "dhanīyati": ['ap90'],
    "dhanū": ['ap90', 'ddsa', 'mw'],
    "dhara": ['ap90', 'cae', 'ddsa', 'mw'],
    "dharananda": ['bhs'],
    "dharapaṭṭa": ['mw'],
    "dharasaṃstha": ['mw'],
    "dharasena": ['mw'],
    "dharati": ['cped'],
    "dharayati": ['cped'],
    "dharaṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "dharaṇapriyā": ['mw'],
    "dharaṇi": ['cae', 'ddsa', 'mw'],
    "dharaṇibhuj": ['mw'],
    "dharaṇibhṛt": ['cae', 'mw'],
    "dharaṇidhara": ['cae', 'mw'],
    "dharaṇidāsa": ['mw'],
    "dharaṇigoṇiga": ['mw'],
    "dharaṇigrāma": ['mw'],
    "dharaṇija": ['mw'],
    "dharaṇikośa": ['mw'],
    "dharaṇimaṇḍa": ['mw'],
    "dharaṇipati": ['cae', 'mw'],
    "dharaṇistha": ['mw'],
    "dharaṇisuta": ['mw'],
    "dharaṇitala": ['mw'],
    "dharaṇitalataitila": ['mw'],
    "dharaṇitejas": ['bhs'],
    "dharaṇitejaśirī": ['bhs'],
    "dharaṇiḥ": ['ap90'],
    "dharaṇiṃdhara": ['bhs'],
    "dharaṇī": ['bhs', 'cped', 'ddsa', 'mw'],
    "dharaṇībandha": ['mw'],
    "dharaṇībhṛt": ['cae', 'mw'],
    "dharaṇīdhara": ['cae', 'mw'],
    "dharaṇīdhra": ['cae', 'mw'],
    "dharaṇīdhṛt": ['cae', 'mw'],
    "dharaṇīkanda": ['mw'],
    "dharaṇīkīlaka": ['mw'],
    "dharaṇīmaṇḍala": ['mw'],
    "dharaṇīnirghoṣasvara": ['bhs'],
    "dharaṇīnirnādaghoṣa": ['bhs'],
    "dharaṇīnārāyaṇastotra": ['mw'],
    "dharaṇīplava": ['mw'],
    "dharaṇīprekṣaṇīlipi": ['bhs'],
    "dharaṇīpūra": ['mw'],
    "dharaṇīruha": ['cae', 'mw'],
    "dharaṇīsura": ['mw'],
    "dharaṇīsurendrāyudha": ['bhs'],
    "dharaṇīsuta": ['mw'],
    "dharaṇīsutā": ['mw'],
    "dharaṇītala": ['mw'],
    "dharaṇītalaśrī": ['bhs', 'mw'],
    "dharaṇītejas": ['bhs'],
    "dharaṇīvarāha": ['mw'],
    "dharaṇīvarāhasaṃvāda": ['mw'],
    "dharaṇīvrata": ['mw'],
    "dharaṇīya": ['ap90', 'mw'],
    "dharaṇīśrīparvatateja": ['bhs'],
    "dharaṇīśubhakāya": ['bhs'],
    "dharaṇīśvara": ['mw'],
    "dharaṇīśvararāja": ['bhs', 'mw'],
    "dharaṇīṃdhara": ['bhs', 'mw'],
    "dharbaka": ['mw'],
    "dhareti": ['cped'],
    "dharimameya": ['mw'],
    "dhariman": ['ap90', 'cae', 'ddsa', 'mw'],
    "dharitrī": ['ap90', 'cae', 'ddsa', 'mw'],
    "dharitrībhṛt": ['mw'],
    "dharitrīdhara": ['mw'],
    "dharitrīputra": ['mw'],
    "dharitrīsutrāman": ['mw'],
    "dhariṇi": ['mw'],
    "dharkaṭa": ['mw'],
    "dharma": ['bhs', 'cae', 'ddsa', 'mw'],
    "dharmabala": ['mw'],
    "dharmabalaprabha": ['bhs'],
    "dharmabalaśrīkūṭa": ['bhs'],
    "dharmabhaginī": ['cae', 'mw'],
    "dharmabhagna": ['mw'],
    "dharmabhikṣuka": ['cae', 'mw'],
    "dharmabhrātṛ": ['mw'],
    "dharmabhāgin": ['cae', 'mw'],
    "dharmabhāskaraśrīmegha": ['bhs'],
    "dharmabhāṇaka": ['bhs', 'mw'],
    "dharmabhāṇin": ['bhs'],
    "dharmabhīru": ['mw'],
    "dharmabhīruka": ['mw'],
    "dharmabhṛt": ['cae', 'mw'],
    "dharmabhṛta": ['mw'],
    "dharmabindu": ['mw'],
    "dharmabuddhi": ['bhs', 'cae', 'mw'],
    "dharmabāhya": ['mw'],
    "dharmabāṇijika": ['mw'],
    "dharmacakra": ['bhs', 'mw'],
    "dharmacakrabhṛt": ['mw'],
    "dharmacakracandrodgataśrī": ['bhs'],
    "dharmacakrajvalanateja": ['bhs'],
    "dharmacakranirghoṣagaganameghapradīparāja": ['bhs'],
    "dharmacakranirmāṇaprabhā": ['bhs'],
    "dharmacakranirmāṇasamantapratibhāsanirghoṣa": ['bhs'],
    "dharmacakraprabhanirghoṣa": ['bhs'],
    "dharmacakraprabhanirghoṣarāja": ['bhs'],
    "dharmacakrapravartana": ['mw'],
    "dharmacakṣus": ['bhs', 'cae', 'mw'],
    "dharmacandra": ['mw'],
    "dharmacandraprabhurāja": ['bhs'],
    "dharmacandrasamantajñānāvabhāsarāja": ['bhs'],
    "dharmacara": ['mw'],
    "dharmacaraṇa": ['cae', 'mw'],
    "dharmacarita": ['bhs'],
    "dharmacaryā": ['bhs', 'mw'],
    "dharmacchala": ['mw'],
    "dharmacintaka": ['mw'],
    "dharmacintana": ['mw'],
    "dharmacinti": ['bhs'],
    "dharmacintika": ['bhs'],
    "dharmacintin": ['mw'],
    "dharmacintā": ['mw'],
    "dharmacārin": ['bhs', 'cae', 'mw'],
    "dharmacāriṇī": ['mw'],
    "dharmada": ['mw'],
    "dharmadakṣiṇā": ['mw'],
    "dharmadarśana": ['mw'],
    "dharmadarśin": ['mw'],
    "dharmadatta": ['cae', 'mw'],
    "dharmadeva": ['bhs', 'cae', 'mw'],
    "dharmadeśaka": ['bhs', 'mw'],
    "dharmadeśanā": ['bhs', 'mw'],
    "dharmadhanaśikharābhaskandha": ['bhs'],
    "dharmadhara": ['bhs', 'mw'],
    "dharmadhenu": ['mw'],
    "dharmadhurya": ['mw'],
    "dharmadhvaja": ['bhs', 'cae', 'mw'],
    "dharmadhvajin": ['cae'],
    "dharmadhāraya": ['mw'],
    "dharmadhāraṇī": ['bhs'],
    "dharmadhātrī": ['mw'],
    "dharmadhātu": ['bhs', 'mw'],
    "dharmadhātugaganapūrṇaratnaśikharaśrīpradīpa": ['bhs'],
    "dharmadhātugaganaśrīvairocana": ['bhs'],
    "dharmadhātujñānapradīpa": ['bhs'],
    "dharmadhātukusuma": ['bhs'],
    "dharmadhātunagarābhajñānapradīparāja": ['bhs'],
    "dharmadhātunayajñānagati": ['bhs'],
    "dharmadhātunayāvabhāsabuddhi": ['bhs'],
    "dharmadhātuniyata": ['bhs', 'mw'],
    "dharmadhātupadma": ['bhs'],
    "dharmadhātuparirakṣiṇī": ['bhs', 'mw'],
    "dharmadhātupratibhāsa": ['bhs'],
    "dharmadhātupratibhāsamaṇimakuṭa": ['bhs'],
    "dharmadhātupratibhāsaprabha": ['bhs'],
    "dharmadhātupratibhāsaśiri": ['bhs'],
    "dharmadhātupraṇidhisunirmitacandrarāja": ['bhs'],
    "dharmadhātupraṇidhitalanirbheda": ['bhs'],
    "dharmadhātusiṃhaprabha": ['bhs'],
    "dharmadhātusunirmitapraṇidhicandra": ['bhs'],
    "dharmadhātusvaraghoṣa": ['bhs'],
    "dharmadhātusvaraketu": ['bhs'],
    "dharmadhātutalabhedajñānābhijñārāja": ['bhs'],
    "dharmadhātuvibhaktipraveśa": ['bhs'],
    "dharmadhātuvidyotitaraśmi": ['bhs'],
    "dharmadhātuviṣayamaticandra": ['bhs'],
    "dharmadhātuvāgīśvara": ['bhs', 'mw'],
    "dharmadhātvarcivairocanasaṃbhavamati": ['bhs'],
    "dharmadhṛk": ['mw'],
    "dharmadhṛt": ['cae', 'mw'],
    "dharmadinnā": ['bhs', 'mw'],
    "dharmadogdhrī": ['mw'],
    "dharmadravī": ['mw'],
    "dharmadrohin": ['mw'],
    "dharmadroṇa": ['mw'],
    "dharmadruh": ['mw'],
    "dharmadrumaparvatateja": ['bhs'],
    "dharmadughā": ['mw'],
    "dharmadvaitanirṇaya": ['mw'],
    "dharmadveṣin": ['mw'],
    "dharmadvāra": ['mw'],
    "dharmadāna": ['mw'],
    "dharmadānapaddhati": ['mw'],
    "dharmadāra": ['cae', 'mw'],
    "dharmadāsa": ['mw'],
    "dharmadīpa": ['mw'],
    "dharmadīpikā": ['mw'],
    "dharmadṛś": ['mw'],
    "dharmadṛḍhābhedyasunilambha": ['mw'],
    "dharmadṛṣṭi": ['cae', 'mw'],
    "dharmagaganakāntasiṃhaprabha": ['bhs'],
    "dharmagaganābhyudgatarāja": ['bhs'],
    "dharmagaganābhyudgataśrīrājan": ['bhs'],
    "dharmagahanābhyudgatarāja": ['mw'],
    "dharmagaveṣa": ['mw'],
    "dharmagañja": ['mw'],
    "dharmaghaṭa": ['mw'],
    "dharmaghaṭavratakathā": ['mw'],
    "dharmaghna": ['cae', 'mw'],
    "dharmaghoṣa": ['mw'],
    "dharmagopa": ['mw'],
    "dharmagrāma": ['bhs'],
    "dharmagup": ['mw'],
    "dharmagupta": ['bhs', 'mw'],
    "dharmaguptacarita": ['mw'],
    "dharmagupti": ['bhs'],
    "dharmahantṛ": ['cae', 'mw'],
    "dharmahāni": ['cae', 'mw'],
    "dharmahīna": ['mw'],
    "dharmaja": ['cae', 'mw'],
    "dharmajanman": ['mw'],
    "dharmajijñāsā": ['mw'],
    "dharmajvalanārciḥsāgaraghoṣa": ['bhs'],
    "dharmajña": ['cae', 'mw'],
    "dharmajñatama": ['mw'],
    "dharmajñāna": ['cae', 'mw'],
    "dharmajñānasaṃbhavasamantapratibhāsagarbha": ['bhs'],
    "dharmajālavibuddhaśrīcandra": ['bhs'],
    "dharmajīvana": ['cae', 'mw'],
    "dharmaka": ['mw'],
    "dharmakarman": ['ddsa', 'mw'],
    "dharmakaropādhyāya": ['mw'],
    "dharmakathaka": ['mw'],
    "dharmakathika": ['bhs'],
    "dharmakathā": ['mw'],
    "dharmakañcuka": ['cae', 'mw'],
    "dharmakañcukapraveśin": ['mw'],
    "dharmaketu": ['bhs', 'mw'],
    "dharmakhaṇḍa": ['mw'],
    "dharmakośa": ['cae', 'mw'],
    "dharmakośavyākhyā": ['mw'],
    "dharmakoṣa": ['mw'],
    "dharmakriyā": ['cae', 'mw'],
    "dharmakusumaketudhvajamegha": ['bhs'],
    "dharmakāla": ['mw'],
    "dharmakāma": ['bhs', 'mw'],
    "dharmakāmyā": ['cae'],
    "dharmakāmārtha": ['cae', 'mw'],
    "dharmakāmārthasambandha": ['mw'],
    "dharmakāmārthasaṃbaddha": ['mw'],
    "dharmakāra": ['mw'],
    "dharmakāraṇa": ['mw'],
    "dharmakārya": ['cae', 'mw'],
    "dharmakāya": ['bhs', 'mw'],
    "dharmakāṅkṣiṇī": ['bhs', 'mw'],
    "dharmakāṇḍa": ['mw'],
    "dharmakīla": ['mw'],
    "dharmakīrti": ['bhs', 'mw'],
    "dharmakūpa": ['mw'],
    "dharmakūṭa": ['mw'],
    "dharmakṛcchra": ['mw'],
    "dharmakṛt": ['gra', 'mw'],
    "dharmakṛtya": ['cae', 'mw'],
    "dharmakṣetra": ['cae', 'mw'],
    "dharmalabdha": ['bhs'],
    "dharmalakṣaṇa": ['mw'],
    "dharmalopa": ['cae', 'mw'],
    "dharmamahāmātra": ['mw'],
    "dharmamati": ['bhs', 'mw'],
    "dharmamaticandrā": ['bhs'],
    "dharmamativinanditarāga": ['mw'],
    "dharmamativinanditarāja": ['bhs'],
    "dharmamatsara": ['mw'],
    "dharmamaya": ['ap90', 'cae', 'mw'],
    "dharmamaṇḍalapaṭalamegha": ['bhs'],
    "dharmamaṇḍalaprabhāsa": ['bhs'],
    "dharmamaṇḍalavibuddhaśrīcandra": ['bhs'],
    "dharmamaṇḍalaśrīśikharābhaprabha": ['bhs'],
    "dharmamegha": ['mw'],
    "dharmameghadhvajapradīpa": ['bhs'],
    "dharmameghadhyāna": ['mw'],
    "dharmameghanagarābhapradīparāja": ['bhs'],
    "dharmameghanirghoṣarāja": ['bhs'],
    "dharmameghavighuṣṭakīrtirāja": ['bhs'],
    "dharmameghā": ['bhs', 'mw'],
    "dharmameru": ['mw'],
    "dharmamitra": ['mw'],
    "dharmamudrā": ['bhs'],
    "dharmamukha": ['bhs'],
    "dharmamukhikā": ['bhs'],
    "dharmamārga": ['cae', 'mw'],
    "dharmamātra": ['mw'],
    "dharmamātratva": ['mw'],
    "dharmamīmāṃsā": ['mw'],
    "dharmamīmāṃsāparibhāṣā": ['mw'],
    "dharmamīmāṃsāsaṃgraha": ['mw'],
    "dharmamīmāṃsāsārasaṃgraha": ['mw'],
    "dharmamūla": ['mw'],
    "dharmamṛj": ['mw'],
    "dharman": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "dharmanada": ['mw'],
    "dharmanagaraprabhaśrī": ['bhs'],
    "dharmanandana": ['mw'],
    "dharmanandin": ['mw'],
    "dharmanayagambhīraśrīcandra": ['bhs'],
    "dharmanetra": ['mw'],
    "dharmanibandha": ['mw'],
    "dharmanibandhin": ['mw'],
    "dharmanitya": ['mw'],
    "dharmaniveśa": ['mw'],
    "dharmaniṣpatti": ['mw'],
    "dharmaniṣṭha": ['cae', 'mw'],
    "dharmanābha": ['mw'],
    "dharmanārāyaṇaketu": ['bhs'],
    "dharmanātha": ['ddsa', 'mw'],
    "dharmanāśā": ['mw'],
    "dharmapada": ['bhs'],
    "dharmapadmaphullagātra": ['bhs'],
    "dharmapadmapraphullitaśrīmegha": ['bhs'],
    "dharmapadmavairocanavibuddhaketu": ['bhs'],
    "dharmapadmaśrīkuśalā": ['bhs'],
    "dharmapara": ['cae', 'mw'],
    "dharmaparyāya": ['bhs', 'mw'],
    "dharmaparāyaṇa": ['cae', 'mw'],
    "dharmaparīkṣā": ['mw'],
    "dharmapatha": ['mw'],
    "dharmapathin": ['mw'],
    "dharmapati": ['cae', 'mw'],
    "dharmapatnī": ['cae', 'mw'],
    "dharmapattana": ['mw'],
    "dharmapattra": ['mw'],
    "dharmapañcaviṃśatikā": ['mw'],
    "dharmapaṭṭa": ['mw'],
    "dharmapaṭṭana": ['mw'],
    "dharmaplava": ['cae', 'mw'],
    "dharmaprabha": ['bhs'],
    "dharmaprabhāsa": ['bhs', 'mw'],
    "dharmapracāra": ['mw'],
    "dharmapradhāna": ['cae', 'mw'],
    "dharmapradīpa": ['mw'],
    "dharmapradīpavikramajñānasiṃha": ['bhs'],
    "dharmapradīpavyākhyāna": ['mw'],
    "dharmapradīpaśirimeru": ['bhs'],
    "dharmaprakāśa": ['mw'],
    "dharmapramāṇapariccheda": ['mw'],
    "dharmaprastha": ['mw'],
    "dharmapratirūpaka": ['cae', 'mw'],
    "dharmapravacana": ['mw'],
    "dharmapravaktṛ": ['cae', 'mw'],
    "dharmapravṛtti": ['mw'],
    "dharmapraśna": ['mw'],
    "dharmapraśnavyākhyā": ['mw'],
    "dharmaprekṣa": ['mw'],
    "dharmapriya": ['bhs', 'mw'],
    "dharmapura": ['mw'],
    "dharmapuraskāra": ['mw'],
    "dharmapurāṇa": ['mw'],
    "dharmaputra": ['cae', 'mw'],
    "dharmaputraka": ['mw'],
    "dharmapāla": ['bhs', 'mw'],
    "dharmapālasyajātakam": ['bhs'],
    "dharmapāśa": ['mw'],
    "dharmapāṭhaka": ['cae', 'mw'],
    "dharmapīḍā": ['mw'],
    "dharmapīṭha": ['mw'],
    "dharmapīṭhā": ['bhs', 'mw'],
    "dharmapūta": ['mw'],
    "dharmarahasya": ['mw'],
    "dharmarakṣitā": ['mw'],
    "dharmarasāyana": ['mw'],
    "dharmarata": ['cae', 'mw'],
    "dharmaratha": ['mw'],
    "dharmarathābhirūḍha": ['mw'],
    "dharmarati": ['bhs', 'cae', 'mw'],
    "dharmaratna": ['mw'],
    "dharmaratnakusumaśrīmegha": ['bhs'],
    "dharmaratnamañjūṣā": ['mw'],
    "dharmaratnākara": ['mw'],
    "dharmarodhin": ['mw'],
    "dharmaruci": ['bhs', 'cae', 'mw'],
    "dharmarāj": ['cae', 'mw'],
    "dharmarāja": ['bhs', 'cae', 'mw'],
    "dharmarājabhaṭṭa": ['mw'],
    "dharmarājadīkṣita": ['mw'],
    "dharmarājadīkṣitīya": ['mw'],
    "dharmarājan": ['cae', 'mw'],
    "dharmarājapurogama": ['mw'],
    "dharmarājaputra": ['mw'],
    "dharmarājatā": ['mw'],
    "dharmarājikā": ['bhs', 'mw'],
    "dharmarājya": ['bhs'],
    "dharmarājādhvarindra": ['mw'],
    "dharmarājādhvarivara": ['mw'],
    "dharmarātrī": ['mw'],
    "dharmasabhā": ['mw'],
    "dharmasahāya": ['mw'],
    "dharmasamaya": ['cae', 'mw'],
    "dharmasampradāyadīpikā": ['mw'],
    "dharmasamudra": ['bhs'],
    "dharmasamudragarbha": ['bhs'],
    "dharmasamudragarjana": ['bhs'],
    "dharmasamudrasaṃbhavaruta": ['bhs'],
    "dharmasamudravegaśirirāja": ['bhs'],
    "dharmasatyavrata": ['mw'],
    "dharmasatyavrateyu": ['mw'],
    "dharmasaṃcaya": ['cae', 'mw'],
    "dharmasaṃgara": ['mw'],
    "dharmasaṃgraha": ['mw'],
    "dharmasaṃgrahanivṛtti": ['mw'],
    "dharmasaṃgīti": ['bhs', 'mw'],
    "dharmasaṃhitā": ['cae', 'mw'],
    "dharmasaṃjña": ['mw'],
    "dharmasaṃjñatva": ['mw'],
    "dharmasaṃjñatā": ['mw'],
    "dharmasaṃjñā": ['cae'],
    "dharmasaṃkathā": ['mw'],
    "dharmasaṃsṛta": ['mw'],
    "dharmasaṃtānasū": ['mw'],
    "dharmasaṃyukta": ['cae', 'mw'],
    "dharmasaṃśraya": ['mw'],
    "dharmasaṅga": ['mw'],
    "dharmasena": ['mw'],
    "dharmasetu": ['mw'],
    "dharmasevana": ['cae', 'mw'],
    "dharmasindhu": ['mw'],
    "dharmasindhusāra": ['mw'],
    "dharmasiṃha": ['mw'],
    "dharmaskandha": ['bhs', 'mw'],
    "dharmasmāraka": ['mw'],
    "dharmasmṛti": ['mw'],
    "dharmastha": ['cae', 'mw'],
    "dharmasthala": ['mw'],
    "dharmasthavira": ['mw'],
    "dharmasthititā": ['mw'],
    "dharmasthūṇārāja": ['mw'],
    "dharmasubodhinī": ['mw'],
    "dharmasuta": ['mw'],
    "dharmasvabhāvamudrā": ['bhs'],
    "dharmasvarūpin": ['cae'],
    "dharmasvāmin": ['mw'],
    "dharmasādhana": ['mw'],
    "dharmasāgara": ['mw'],
    "dharmasāgaranigarjitaghoṣa": ['bhs'],
    "dharmasāgaranirdeśaghoṣa": ['bhs'],
    "dharmasāgaranirghoṣamati": ['bhs'],
    "dharmasāgaranirnādanirghoṣa": ['bhs'],
    "dharmasāgarapadma": ['bhs'],
    "dharmasāra": ['mw'],
    "dharmasārasamuccaya": ['mw'],
    "dharmasārathi": ['mw'],
    "dharmasāvarṇi": ['mw'],
    "dharmasāvarṇika": ['mw'],
    "dharmasāṃkathya": ['mw'],
    "dharmasū": ['cae', 'mw'],
    "dharmasūkta": ['mw'],
    "dharmasūryameghapradīpa": ['bhs'],
    "dharmasūryatejas": ['bhs'],
    "dharmasūtra": ['cae', 'mw'],
    "dharmasūtrakāra": ['mw'],
    "dharmasūtravyākhyā": ['mw'],
    "dharmatantra": ['mw'],
    "dharmatas": ['cae', 'mw'],
    "dharmatattva": ['mw'],
    "dharmatattvaprakāśa": ['mw'],
    "dharmatattvasaṃgraha": ['mw'],
    "dharmatattvatas": ['cae', 'mw'],
    "dharmatattvavid": ['mw'],
    "dharmatattvārthacintāmaṇi": ['mw'],
    "dharmatayā": ['mw'],
    "dharmataḥ": ['ap90', 'ddsa'],
    "dharmatrāta": ['bhs', 'mw'],
    "dharmatva": ['mw'],
    "dharmatvaṃ": ['ap90'],
    "dharmatyāga": ['mw'],
    "dharmatā": ['bhs', 'mw'],
    "dharmatābuddha": ['bhs'],
    "dharmatīrtha": ['mw'],
    "dharmavahikā": ['mw'],
    "dharmavaitaṃsika": ['mw'],
    "dharmavallabha": ['mw'],
    "dharmavant": ['cae'],
    "dharmavardhana": ['mw'],
    "dharmavarman": ['mw'],
    "dharmavartin": ['mw'],
    "dharmavasuprada": ['mw'],
    "dharmavat": ['ap90', 'gra', 'mw'],
    "dharmavatsala": ['mw'],
    "dharmavatī": ['mw'],
    "dharmaveṣṭi": ['bhs'],
    "dharmavicāra": ['mw'],
    "dharmavicārasaṃgraha": ['mw'],
    "dharmavicāraśāstra": ['mw'],
    "dharmavid": ['cae', 'mw'],
    "dharmavidharman": ['mw'],
    "dharmavidhi": ['cae', 'mw'],
    "dharmavidyā": ['mw'],
    "dharmavijaya": ['mw'],
    "dharmavijayagaṇi": ['mw'],
    "dharmavikurvitavegadhvajaśrī": ['bhs'],
    "dharmavimānanirghoṣarāja": ['bhs'],
    "dharmaviplava": ['mw'],
    "dharmavirodhavat": ['mw'],
    "dharmavivaraṇa": ['mw'],
    "dharmavivardhana": ['bhs', 'mw'],
    "dharmavivecana": ['mw'],
    "dharmaviveka": ['mw'],
    "dharmavivekavākya": ['mw'],
    "dharmavivṛti": ['mw'],
    "dharmavyatikrama": ['mw'],
    "dharmavyavasthā": ['mw'],
    "dharmavyādha": ['mw'],
    "dharmavācaspati": ['mw'],
    "dharmavāda": ['mw'],
    "dharmavādin": ['mw'],
    "dharmavāha": ['mw'],
    "dharmavāhana": ['mw'],
    "dharmavāhya": ['mw'],
    "dharmavāsara": ['mw'],
    "dharmavāṇijaka": ['mw'],
    "dharmavāṇijika": ['mw'],
    "dharmavāṇijyaka": ['mw'],
    "dharmavīra": ['mw'],
    "dharmavṛddha": ['cae', 'mw'],
    "dharmavṛtti": ['mw'],
    "dharmayajña": ['mw'],
    "dharmayaśas": ['bhs', 'mw'],
    "dharmayoga": ['bhs'],
    "dharmayogeśvara": ['mw'],
    "dharmayoni": ['mw'],
    "dharmayu": ['ap90', 'mw'],
    "dharmayuddha": ['mw'],
    "dharmayuga": ['mw'],
    "dharmayuj": ['mw'],
    "dharmayukta": ['cae', 'mw'],
    "dharmayyadīkṣita": ['mw'],
    "dharmaśarman": ['mw'],
    "dharmaśarmābhyudaya": ['mw'],
    "dharmaśarīra": ['bhs', 'mw'],
    "dharmaśikharadhvajamegha": ['bhs'],
    "dharmaśravaṇa": ['bhs', 'mw'],
    "dharmaśravaṇika": ['bhs'],
    "dharmaśreṣṭhin": ['mw'],
    "dharmaśrī": ['bhs'],
    "dharmaśuddhi": ['cae', 'mw'],
    "dharmaśālā": ['mw'],
    "dharmaśāsana": ['cae', 'ddsa', 'mw'],
    "dharmaśāstra": ['cae', 'mw'],
    "dharmaśāstradīpikā": ['mw'],
    "dharmaśāstrakārikā": ['mw'],
    "dharmaśāstranibandha": ['mw'],
    "dharmaśāstrasarvasva": ['mw'],
    "dharmaśāstrasaṃgraha": ['mw'],
    "dharmaśāstrasaṃgrahaśloka": ['mw'],
    "dharmaśāstrasudhānidhi": ['mw'],
    "dharmaśāstravacana": ['mw'],
    "dharmaśāstrin": ['mw'],
    "dharmaśāstroddhṛtavacana": ['mw'],
    "dharmaśāṭapraticchanna": ['mw'],
    "dharmaśīla": ['cae', 'mw'],
    "dharmaśūra": ['bhs'],
    "dharmaḥ": ['ap90', 'bhs'],
    "dharmaḥsamudra": ['bhs'],
    "dharmaṃdada": ['mw'],
    "dharmaṃdadā": ['bhs', 'mw'],
    "dharmaṇa": ['mw'],
    "dharmendra": ['cae', 'mw'],
    "dharmendrarāja": ['bhs'],
    "dharmendrarājaguṇaghoṣa": ['bhs'],
    "dharmepsu": ['cae', 'ddsa', 'mw'],
    "dharmesthita": ['mw'],
    "dharmeyu": ['mw'],
    "dharmeśa": ['cae', 'mw'],
    "dharmeśvara": ['bhs', 'cae', 'mw'],
    "dharmeśvaraliṅga": ['mw'],
    "dharmeśvararāja": ['bhs'],
    "dharmeśvaratīrtha": ['mw'],
    "dharmeṇa": ['mw'],
    "dharmi": ['bhs'],
    "dharmika": ['bhs', 'mw'],
    "dharmin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dharmita": ['bhs'],
    "dharmitva": ['ddsa', 'mw'],
    "dharmitā": ['cae', 'mw'],
    "dharmitāvaccheda": ['mw'],
    "dharmitāvacchedakapratyāsatti": ['mw'],
    "dharmitāvacchedakapratyāsattinirūpaṇa": ['mw'],
    "dharmitāvacchedakarahasya": ['mw'],
    "dharmitāvacchedakatāvāda": ['mw'],
    "dharmitāvacchedakatāvādārtha": ['mw'],
    "dharmitāvacchedakavāda": ['mw'],
    "dharmiṇī": ['mw'],
    "dharmiṣṭha": ['ap90', 'cae', 'ddsa', 'mw'],
    "dharmiṣṭhatā": ['mw'],
    "dharmoccaya": ['bhs', 'mw'],
    "dharmodgata": ['bhs'],
    "dharmodgatakīrti": ['bhs'],
    "dharmodgatanabheśvara": ['bhs'],
    "dharmolkā": ['bhs', 'mw'],
    "dharmolkājvalanaśrīcandra": ['bhs'],
    "dharmolkāratnavitānaghoṣa": ['bhs'],
    "dharmopadeśa": ['cae', 'mw'],
    "dharmopadeśaka": ['mw'],
    "dharmopadeśanā": ['mw'],
    "dharmopadha": ['mw'],
    "dharmopaghātaka": ['cae', 'mw'],
    "dharmopamā": ['cae', 'mw'],
    "dharmopeta": ['mw'],
    "dharmottamā": ['mw'],
    "dharmottara": ['bhs', 'ddsa', 'mw'],
    "dharmottarīya": ['mw'],
    "dharmya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dharmyavivāha": ['mw'],
    "dharmyākṣepa": ['mw'],
    "dharmyāmṛta": ['cae', 'mw'],
    "dharmā": ['bhs'],
    "dharmābhijanavat": ['mw'],
    "dharmābhimanas": ['mw'],
    "dharmābhimukha": ['mw'],
    "dharmābhimukhā": ['bhs', 'mw'],
    "dharmābhiṣekakriyā": ['cae', 'mw'],
    "dharmācārya": ['cae', 'mw'],
    "dharmācāryastuti": ['mw'],
    "dharmādeśaka": ['mw'],
    "dharmādharma": ['cae', 'mw'],
    "dharmādharmajña": ['mw'],
    "dharmādharmaparīkṣaṇa": ['mw'],
    "dharmādharmaparīkṣā": ['mw'],
    "dharmādharmaprabodhinī": ['mw'],
    "dharmādharmasenāhanana": ['mw'],
    "dharmādharmavyavasthā": ['mw'],
    "dharmādhikaraṇa": ['cae', 'mw'],
    "dharmādhikaraṇasthāna": ['cae', 'mw'],
    "dharmādhikāra": ['cae', 'mw'],
    "dharmādhikārakāraṇika": ['mw'],
    "dharmādhikārakāraṇin": ['mw'],
    "dharmādhikāraṇika": ['cae'],
    "dharmādhikārika": ['mw'],
    "dharmādhikārin": ['cae', 'mw'],
    "dharmādhikāripuruṣa": ['mw'],
    "dharmādhikṛta": ['cae', 'mw'],
    "dharmādhiṣṭhāna": ['cae', 'mw'],
    "dharmādhvabodha": ['mw'],
    "dharmādhvan": ['mw'],
    "dharmādhyakṣa": ['cae', 'mw'],
    "dharmāditya": ['mw'],
    "dharmādityajñānamaṇḍalapradīpa": ['bhs'],
    "dharmāgada": ['mw'],
    "dharmāgama": ['mw'],
    "dharmāha": ['mw'],
    "dharmāhṛta": ['mw'],
    "dharmākara": ['bhs', 'mw'],
    "dharmākaramati": ['bhs'],
    "dharmākhyāna": ['ddsa', 'mw'],
    "dharmākṣara": ['cae', 'mw'],
    "dharmākṣepa": ['mw'],
    "dharmāloka": ['bhs', 'mw'],
    "dharmālokamukha": ['bhs', 'mw'],
    "dharmālīka": ['mw'],
    "dharmāmbodhi": ['mw'],
    "dharmāmṛta": ['mw'],
    "dharmāmṛtamahodadhi": ['mw'],
    "dharmānala": ['mw'],
    "dharmāndhu": ['mw'],
    "dharmānudharma": ['bhs'],
    "dharmānukāṅkṣin": ['cae', 'mw'],
    "dharmānusmṛti": ['mw'],
    "dharmānusmṛtyupasthāna": ['mw'],
    "dharmānusāra": ['mw'],
    "dharmānuṣṭhāna": ['cae', 'mw'],
    "dharmānvaya": ['bhs', 'mw'],
    "dharmāpeta": ['mw'],
    "dharmāraṇya": ['cae', 'ddsa', 'mw'],
    "dharmāraṇyakhaṇḍa": ['mw'],
    "dharmāraṇyakulācāranirṇaya": ['mw'],
    "dharmāraṇyamāhātmya": ['mw'],
    "dharmārci": ['bhs'],
    "dharmārcimeghanagaraḥ": ['bhs'],
    "dharmārcimeru": ['bhs'],
    "dharmārcinagaramegha": ['bhs'],
    "dharmārciḥparvataketurāja": ['bhs'],
    "dharmārciḥsaṃtejorāja": ['bhs'],
    "dharmārtha": ['cae', 'mw'],
    "dharmārthadarśin": ['mw'],
    "dharmārthakāmamokṣa": ['mw'],
    "dharmārtham": ['mw'],
    "dharmārthamatitejorāja": ['bhs'],
    "dharmārthapratibaddhatā": ['mw'],
    "dharmārthayukta": ['mw'],
    "dharmārthika": ['mw'],
    "dharmārthīya": ['mw'],
    "dharmārṇava": ['mw'],
    "dharmāsana": ['bhs', 'cae', 'mw'],
    "dharmāsanagata": ['mw'],
    "dharmāsanaka": ['bhs'],
    "dharmāstikāya": ['mw'],
    "dharmāt": ['mw'],
    "dharmātikrama": ['cae', 'mw'],
    "dharmātmaja": ['mw'],
    "dharmātman": ['cae', 'mw'],
    "dharmātmatā": ['cae', 'mw'],
    "dharmāvabhāsasvara": ['bhs'],
    "dharmāvekṣitā": ['cae'],
    "dharmāviruddham": ['cae', 'mw'],
    "dharmāvāpti": ['mw'],
    "dharmāya": ['mw'],
    "dharmāyana": ['mw'],
    "dharmāyatana": ['bhs', 'mw'],
    "dharmāyatanika": ['mw'],
    "dharmāśoka": ['bhs', 'cae', 'mw'],
    "dharmāśokadatta": ['mw'],
    "dharmāśrita": ['cae', 'mw'],
    "dharmāṅga": ['mw'],
    "dharmāṅgā": ['mw'],
    "dharmī": ['bhs'],
    "dharmīputra": ['mw'],
    "dharmīputraḥ": ['ap90'],
    "dharmīyas": ['mw'],
    "dharoddhāra": ['mw'],
    "dharopastha": ['mw'],
    "dhartavya": ['mw'],
    "dhartra": ['cae', 'ddsa', 'mw'],
    "dhartraṃ": ['ap90'],
    "dharttūraḥ": ['ap90'],
    "dhartu": ['mw'],
    "dhartṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dharuṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dharuṇahvara": ['gra', 'mw'],
    "dharuṇī": ['mw'],
    "dharā": ['ap90', 'mw'],
    "dharābandha": ['mw'],
    "dharābhuj": ['cae', 'mw'],
    "dharābhṛt": ['cae', 'mw'],
    "dharādhara": ['cae', 'ddsa', 'mw'],
    "dharādharendra": ['mw'],
    "dharādharā": ['mw'],
    "dharādhava": ['mw'],
    "dharādhipa": ['cae', 'mw'],
    "dharādhārā": ['mw'],
    "dharākadamba": ['mw'],
    "dharāmara": ['ddsa', 'mw'],
    "dharāpati": ['cae', 'mw'],
    "dharāputra": ['mw'],
    "dharāsūnu": ['mw'],
    "dharātmaja": ['mw'],
    "dharāturāṣāh": ['mw'],
    "dharāśaya": ['cae', 'mw'],
    "dharīman": ['cae', 'gra', 'mw'],
    "dharītu": ['mw'],
    "dharīyas": ['mw'],
    "dharṇasa": ['ap90', 'cae', 'mw'],
    "dharṇasi": ['cae', 'ddsa', 'gra', 'mw'],
    "dharṇi": ['cae', 'gra', 'mw'],
    "dharṣa": ['mw'],
    "dharṣaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "dharṣakāriṇī": ['mw'],
    "dharṣavara": ['mw'],
    "dharṣaḥ": ['ap90'],
    "dharṣaṇa": ['cae', 'mw'],
    "dharṣaṇaṃ": ['ap90'],
    "dharṣaṇi": ['mw'],
    "dharṣaṇiḥ": ['ap90'],
    "dharṣaṇātman": ['mw'],
    "dharṣaṇī": ['mw'],
    "dharṣaṇīya": ['mw'],
    "dharṣika": ['bhs'],
    "dharṣin": ['ap90', 'cae', 'mw'],
    "dharṣita": ['ap90', 'mw'],
    "dharṣitā": ['mw'],
    "dharṣiṇī": ['mw'],
    "dhas": ['ap90'],
    "dhata": ['cped'],
    "dhatotseka": ['ddsa'],
    "dhattūra": ['cae', 'ddsa', 'mw'],
    "dhattūraka": ['mw'],
    "dhattūrakā": ['mw'],
    "dhattūraḥ": ['ap90'],
    "dhaumaka": ['mw'],
    "dhaumata": ['mw'],
    "dhaumatāyana": ['mw'],
    "dhaumatāyanaka": ['mw'],
    "dhaumra": ['cae', 'mw'],
    "dhaumraḥ": ['ap90'],
    "dhaumrāyaṇa": ['bhs', 'mw'],
    "dhaumya": ['cae', 'mw'],
    "dhaumyasmṛti": ['mw'],
    "dhaumyaśikṣā": ['mw'],
    "dhaumāyana": ['mw'],
    "dhaumīya": ['mw'],
    "dhaundhumāra": ['mw'],
    "dhaundhumāri": ['mw'],
    "dhaura": ['bhs', 'mw'],
    "dhaureya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhaureyaka": ['cae'],
    "dhauritaka": ['mw'],
    "dhauritakaṃ": ['ap90'],
    "dhaurjaṭa": ['cae', 'ddsa', 'mw'],
    "dhaurtaka": ['mw'],
    "dhaurtakaṃ": ['ap90'],
    "dhaurteya": ['mw'],
    "dhaurtika": ['mw'],
    "dhaurtya": ['cae', 'ddsa', 'mw'],
    "dhaurya": ['mw'],
    "dhauryaṃ": ['ap90'],
    "dhaurādityatīrtha": ['mw'],
    "dhauta": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhautabalī": ['mw'],
    "dhautadanta": ['mw'],
    "dhautaka": ['mw'],
    "dhautakauśeya": ['cae', 'mw'],
    "dhautakaṭa": ['mw'],
    "dhautakhaṇḍī": ['mw'],
    "dhautakośaja": ['mw'],
    "dhautakuṣṭha": ['mw'],
    "dhautamūla": ['mw'],
    "dhautamūlaka": ['mw'],
    "dhautapāpman": ['mw'],
    "dhautari": ['ap90'],
    "dhautarī": ['gra', 'mw'],
    "dhautaya": ['mw'],
    "dhautaśila": ['mw'],
    "dhauteya": ['mw'],
    "dhauteyaḥ": ['ap90'],
    "dhauti": ['ap90', 'cae', 'gra', 'mw'],
    "dhautodana": ['bhs'],
    "dhautāpāṅga": ['mw'],
    "dhautātman": ['mw'],
    "dhautāñjalī": ['mw'],
    "dhautāñjanī": ['mw'],
    "dhautī": ['mw'],
    "dhauvaki": ['mw'],
    "dhauṣya": ['mw'],
    "dhav": ['cae', 'ddsa', 'gra', 'mw'],
    "dhava": ['cae', 'cped', 'ddsa', 'mw'],
    "dhavala": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhavalacandra": ['mw'],
    "dhavalagiri": ['cae', 'mw'],
    "dhavalagṛha": ['mw'],
    "dhavalamukha": ['mw'],
    "dhavalamṛttikā": ['mw'],
    "dhavalanibandha": ['mw'],
    "dhavalapakṣa": ['mw'],
    "dhavalasmṛti": ['mw'],
    "dhavalatva": ['mw'],
    "dhavalatā": ['mw'],
    "dhavalay": ['cae'],
    "dhavalaya": ['ddsa', 'mw'],
    "dhavalayāvanāla": ['mw'],
    "dhavaletarataṇḍula": ['mw'],
    "dhavaliman": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhavalita": ['ap90', 'mw'],
    "dhavalotpala": ['mw'],
    "dhavalāy": ['cae'],
    "dhavalāya": ['ddsa', 'mw'],
    "dhavalāyita": ['mw'],
    "dhavalāṅka": ['mw'],
    "dhavalāṣṭaka": ['mw'],
    "dhavalī": ['ddsa', 'mw'],
    "dhavalībhūta": ['mw'],
    "dhavalīkṛta": ['mw'],
    "dhavanī": ['mw'],
    "dhavara": ['bhs', 'mw'],
    "dhavaḥ": ['ap90'],
    "dhavitavya": ['cae', 'mw'],
    "dhavitra": ['cae', 'ddsa', 'mw'],
    "dhavitradaṇḍa": ['mw'],
    "dhavitraṃ": ['ap90'],
    "dhavāṇaka": ['mw'],
    "dhavāṇakaḥ": ['ap90'],
    "dhavīyas": ['gra', 'mw'],
    "dhavīyaṃs": ['cae'],
    "dhaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhayadvat": ['mw'],
    "dhayantikā": ['mw'],
    "dhañoka": ['mw'],
    "dhañña": ['cped'],
    "dhaññakarana": ['cped'],
    "dhaññasamavāpaka": ['cped'],
    "dhaññāgāra": ['cped'],
    "dhaḍieva": ['mw'],
    "dhaṁsati": ['cped'],
    "dhaṁsayati": ['cped'],
    "dhaṁseti": ['cped'],
    "dhaṁsi(n)": ['cped'],
    "dhaṅka": ['cped'],
    "dhaṅkarūpa": ['cped'],
    "dhaṇ": ['ap90', 'mw'],
    "dhaṇapālaka": ['bhs'],
    "dhaṭa": ['cae', 'ddsa', 'mw'],
    "dhaṭaka": ['mw'],
    "dhaṭakaḥ": ['ap90'],
    "dhaṭaḥ": ['ap90'],
    "dhaṭika": ['bhs'],
    "dhaṭikā": ['ap90', 'mw'],
    "dhaṭin": ['ap90', 'mw'],
    "dhaṭotkaca": ['mw'],
    "dhaṭī": ['mw'],
    "dhaṭīdāna": ['mw'],
    "dhe": ['ap90', 'ddsa', 'mw'],
    "dhehi": ['ddsa'],
    "dhemātra": ['mw'],
    "dhena": ['mw'],
    "dhenaḥ": ['ap90'],
    "dhenikā": ['mw'],
    "dhenu": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dhenubhavyā": ['mw'],
    "dhenudakṣiṇa": ['mw'],
    "dhenudugdha": ['mw'],
    "dhenugoduha": ['mw'],
    "dhenuka": ['mw'],
    "dhenukadhvaṃsin": ['mw'],
    "dhenukara": ['mw'],
    "dhenukasūdana": ['mw'],
    "dhenukavadha": ['mw'],
    "dhenukaḥ": ['ap90'],
    "dhenukā": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhenukādugdha": ['mw'],
    "dhenukāri": ['mw'],
    "dhenukāśrama": ['mw'],
    "dhenumakṣikā": ['mw'],
    "dhenumant": ['cae'],
    "dhenumat": ['ddsa', 'gra', 'mw'],
    "dhenumatī": ['mw'],
    "dhenumbhavyā": ['mw'],
    "dhenupa": ['cped'],
    "dhenupaka": ['cped'],
    "dhenutva": ['mw'],
    "dhenuḥ": ['ap90'],
    "dhenuṣyita": ['mw'],
    "dhenuṣyā": ['ap90', 'mw'],
    "dhenuṣṭarī": ['ap90', 'mw'],
    "dhenvanaḍuha": ['cae', 'ddsa', 'mw'],
    "dhenā": ['cae', 'ddsa', 'gra', 'mw'],
    "dhenī": ['mw'],
    "dhenūka": ['mw'],
    "dheya": ['ap90', 'bhs', 'ddsa', 'gra', 'mw'],
    "dheyeśvara": ['mw'],
    "dheṣṭha": ['cae', 'gra', 'mw'],
    "dhi": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dhig": ['mw'],
    "dhigama": ['bhs'],
    "dhigdaṇḍa": ['cae', 'ddsa', 'mw'],
    "dhigvaṇa": ['cae', 'ddsa', 'mw'],
    "dhigvaṇaḥ": ['ap90'],
    "dhigvāda": ['mw'],
    "dhik": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhikka": ['mw'],
    "dhikkriyā": ['mw'],
    "dhikkāra": ['cae', 'mw'],
    "dhikkāraḥ": ['ap90'],
    "dhikkṛ": ['ap90', 'mw'],
    "dhikkṛta": ['ap90', 'ddsa', 'mw'],
    "dhikpāruṣya": ['mw'],
    "dhikṣ": ['ap90', 'mw'],
    "dhinv": ['ap90', 'mw'],
    "dhipsu": ['ap90', 'cae', 'mw'],
    "dhita": ['ddsa', 'mw'],
    "dhitavan": ['mw'],
    "dhiti": ['cae', 'cped', 'gra', 'mw'],
    "dhitima(t)": ['cped'],
    "dhitimanta": ['cped'],
    "dhitsya": ['mw'],
    "dhitāvan": ['cae', 'gra', 'mw'],
    "dhiya": ['mw'],
    "dhiyandhā": ['ddsa'],
    "dhiyasāna": ['gra', 'mw'],
    "dhiyañjinva": ['ddsa'],
    "dhiyaṃ": ['mw'],
    "dhiyaṃdhā": ['cae', 'gra', 'mw'],
    "dhiyaṃjinva": ['cae', 'gra', 'mw'],
    "dhiyājur": ['gra', 'mw'],
    "dhiyāmpati": ['mw'],
    "dhiyāvasu": ['cae', 'gra', 'mw'],
    "dhiyāy": ['gra'],
    "dhiyāya": ['mw'],
    "dhiyāyu": ['cae', 'gra', 'mw'],
    "dhiḥ": ['ap90'],
    "dhiṣ": ['ap90', 'mw'],
    "dhiṣa": ['mw'],
    "dhiṣaṇa": ['cae', 'ddsa', 'mw'],
    "dhiṣaṇaḥ": ['ap90'],
    "dhiṣaṇy": ['cae', 'gra'],
    "dhiṣaṇya": ['mw'],
    "dhiṣaṇā": ['ddsa', 'gra', 'mw'],
    "dhiṣe": ['ddsa'],
    "dhiṣā": ['cae', 'gra'],
    "dhiṣṇia": ['gra'],
    "dhiṣṇiya": ['mw'],
    "dhiṣṇya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhiṣṇyahoma": ['mw'],
    "dhiṣṇyapa": ['mw'],
    "dhiṣṇyavat": ['mw'],
    "dhiṣṇyaviharaṇa": ['mw'],
    "dhiṣṇyā": ['mw'],
    "dhiṣṇyādhipati": ['mw'],
    "dhiṣṇīya": ['mw'],
    "dhiṣṭhita": ['cae', 'mw'],
    "dhiṣṭhya": ['mw'],
    "dhiṣṭya": ['ddsa', 'mw'],
    "dhma": ['ddsa', 'mw'],
    "dhmā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhmākāra": ['mw'],
    "dhmākāraḥ": ['ap90'],
    "dhmāman": ['mw'],
    "dhmāna": ['cae', 'ddsa', 'mw'],
    "dhmānaṃ": ['ap90'],
    "dhmāpana": ['mw'],
    "dhmāpanaṃ": ['ap90'],
    "dhmāpita": ['ap90', 'mw'],
    "dhmāta": ['ap90', 'cae', 'mw'],
    "dhmātaka": ['bhs'],
    "dhmātavya": ['cae', 'ddsa', 'mw'],
    "dhmātṛ": ['cae', 'gra', 'mw'],
    "dhmāyamāna": ['mw'],
    "dhmāyat": ['mw'],
    "dhmāṃkṣ": ['ap90'],
    "dhmāṅkṣ": ['mw'],
    "dhmāṅkṣa": ['ddsa', 'mw'],
    "dhona": ['cped'],
    "dhopati": ['bhs'],
    "dhor": ['ap90', 'mw'],
    "dhorayha": ['cped'],
    "dhorayhasīla": ['cped'],
    "dhorayhavatā": ['cped'],
    "dhoraṇa": ['mw'],
    "dhoraṇaṃ": ['ap90'],
    "dhoraṇi": ['cae', 'mw'],
    "dhoraṇiḥ": ['ap90'],
    "dhoraṇī": ['cae', 'ddsa', 'mw'],
    "dhoreyya": ['cped'],
    "dhorita": ['mw'],
    "dhoritaka": ['mw'],
    "dhoritaṃ": ['ap90'],
    "dhota": ['cped'],
    "dhotapaccatthara": ['cped'],
    "dhotapādaka": ['cped'],
    "dhotra": ['mw'],
    "dhova": ['bhs'],
    "dhova(t)": ['cped'],
    "dhovaka": ['bhs'],
    "dhovana": ['bhs', 'cped'],
    "dhovanaka": ['bhs'],
    "dhovanta": ['cped'],
    "dhovanā": ['cped'],
    "dhovati": ['bhs', 'cped'],
    "dhovi": ['cped'],
    "dhovitabba": ['cped'],
    "dhovituṁ": ['cped'],
    "dhovitvā": ['cped'],
    "dhoviṁ": ['cped'],
    "dhovāpanika": ['bhs'],
    "dhovāpenta": ['cped'],
    "dhovāpesi": ['cped'],
    "dhovāpesuṁ": ['cped'],
    "dhovāpeti": ['cped'],
    "dhovāpita": ['cped'],
    "dhovīyati": ['cped'],
    "dhoyin": ['ddsa', 'mw'],
    "dhoyī": ['mw'],
    "dhoyīka": ['mw'],
    "dhoīkavi": ['mw'],
    "dhoḍa": ['mw'],
    "dhoḍaḥ": ['ap90'],
    "dhra": ['ap90', 'ddsa', 'mw'],
    "dhrai": ['ap90', 'mw'],
    "dhraj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhrajas": ['cae', 'gra', 'mw'],
    "dhrajati": ['gra', 'mw'],
    "dhraji": ['ap90', 'mw'],
    "dhrajīmant": ['cae'],
    "dhrajīmat": ['gra', 'mw'],
    "dhras": ['ap90', 'mw'],
    "dhraupada": ['mw'],
    "dhrauva": ['cae', 'mw'],
    "dhrauvaki": ['mw'],
    "dhrauvapadaṭīkā": ['mw'],
    "dhrauvya": ['cae', 'ddsa', 'mw'],
    "dhrauvyaṃ": ['ap90'],
    "dhrañj": ['mw'],
    "dhraṇ": ['ap90', 'mw'],
    "dhrek": ['ap90', 'mw'],
    "dhri": ['gra', 'mw'],
    "dhrij": ['ap90', 'mw'],
    "dhriyamāṇa": ['mw'],
    "dhriyati": ['bhs'],
    "dhru": ['ap90', 'gra', 'mw'],
    "dhrupadākhyanṛtya": ['mw'],
    "dhrut": ['gra', 'mw'],
    "dhruti": ['cae', 'ddsa', 'gra', 'mw'],
    "dhrutiḥ": ['ap90'],
    "dhruv": ['mw'],
    "dhruva": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "dhruvabhramaṇa": ['mw'],
    "dhruvabhramaṇayantra": ['mw'],
    "dhruvabhramaṇādhikāra": ['mw'],
    "dhruvabhāga": ['mw'],
    "dhruvacakra": ['mw'],
    "dhruvacarita": ['mw'],
    "dhruvacyut": ['cae', 'gra', 'mw'],
    "dhruvadevī": ['mw'],
    "dhruvagati": ['mw'],
    "dhruvagopa": ['mw'],
    "dhruvagītanṛtya": ['mw'],
    "dhruvaka": ['mw'],
    "dhruvakabhāga": ['mw'],
    "dhruvakaḥ": ['ap90'],
    "dhruvaketu": ['mw'],
    "dhruvakila": ['mw'],
    "dhruvakin": ['mw'],
    "dhruvakā": ['mw'],
    "dhruvakṣema": ['cae', 'gra', 'mw'],
    "dhruvakṣetra": ['mw'],
    "dhruvakṣit": ['cae', 'mw'],
    "dhruvakṣiti": ['cae', 'mw'],
    "dhruvalakṣaṇa": ['mw'],
    "dhruvam": ['mw'],
    "dhruvamaṇḍala": ['mw'],
    "dhruvamānasa": ['mw'],
    "dhruvanaḍi": ['mw'],
    "dhruvanaḍī": ['mw'],
    "dhruvanṛtya": ['mw'],
    "dhruvapada": ['mw'],
    "dhruvapaṭu": ['mw'],
    "dhruvapāla": ['mw'],
    "dhruvaratnā": ['mw'],
    "dhruvarāhu": ['mw'],
    "dhruvarāja": ['mw'],
    "dhruvas": ['gra'],
    "dhruvasad": ['cae', 'mw'],
    "dhruvasaṃdhi": ['mw'],
    "dhruvase": ['cae', 'mw'],
    "dhruvasena": ['mw'],
    "dhruvasiddhi": ['cae', 'mw'],
    "dhruvasthālī": ['mw'],
    "dhruvastuti": ['mw'],
    "dhruvasūkta": ['mw'],
    "dhruvatva": ['mw'],
    "dhruvatāraka": ['mw'],
    "dhruvatārā": ['mw'],
    "dhruvayaṣṭi": ['mw'],
    "dhruvayoni": ['mw'],
    "dhruvaśīla": ['ddsa', 'mw'],
    "dhruvi": ['ap90', 'cae', 'gra', 'mw'],
    "dhruvā": ['ddsa', 'mw'],
    "dhruvākṣara": ['mw'],
    "dhruvānanda": ['mw'],
    "dhruvānandamatavyākhyā": ['mw'],
    "dhruvāvarta": ['mw'],
    "dhruvāya": ['mw'],
    "dhruvāśva": ['mw'],
    "dhruvāḍaka": ['mw'],
    "dhrā": ['ap90', 'mw'],
    "dhrāgh": ['ap90', 'mw'],
    "dhrāj": ['cae', 'mw'],
    "dhrāja": ['cae', 'mw'],
    "dhrāji": ['cae', 'gra', 'mw'],
    "dhrājiḥ": ['ap90'],
    "dhrākh": ['ap90', 'mw'],
    "dhrākṣā": ['mw'],
    "dhrākṣāmat": ['mw'],
    "dhrāḍ": ['ap90', 'mw'],
    "dhrāḍi": ['mw'],
    "dhrāḍiḥ": ['ap90'],
    "dhrāṃkṣ": ['ap90'],
    "dhrāṅkṣ": ['mw'],
    "dhrūṇā": ['mw'],
    "dhu": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhuka": ['mw'],
    "dhukkā": ['mw'],
    "dhukā": ['mw'],
    "dhukṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhuma": ['cped'],
    "dhumadhumāya": ['mw'],
    "dhuna": ['ap90', 'cped', 'mw'],
    "dhunamāna": ['cped'],
    "dhunana": ['bhs', 'mw'],
    "dhunay": ['cae', 'gra'],
    "dhunaya": ['ddsa', 'mw'],
    "dhunayati": ['ap90'],
    "dhundhu": ['cae', 'ddsa', 'mw'],
    "dhundhuhan": ['mw'],
    "dhundhuka": ['mw'],
    "dhundhumat": ['mw'],
    "dhundhumāra": ['mw'],
    "dhundhumāratva": ['mw'],
    "dhundhumāropākhyāna": ['mw'],
    "dhundhuri": ['mw'],
    "dhundhurī": ['mw'],
    "dhuneti": ['cae', 'gra', 'mw'],
    "dhuni": ['cae', 'ddsa', 'gra', 'mw'],
    "dhunimant": ['cae'],
    "dhunimat": ['gra', 'mw'],
    "dhunivrata": ['cae', 'gra', 'mw'],
    "dhuniḥ": ['ap90'],
    "dhunvat": ['mw'],
    "dhunvāna": ['mw'],
    "dhunāna": ['mw'],
    "dhunāti": ['cped'],
    "dhunī": ['bhs', 'ddsa', 'mw'],
    "dhunīcumuri": ['gra', 'mw'],
    "dhunīnātha": ['mw'],
    "dhur": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhura": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "dhuradhorayha": ['cped'],
    "dhuradhoreyya": ['cped'],
    "dhurandhara": ['ddsa'],
    "dhurasamādhi": ['cped'],
    "dhurassaha": ['cped'],
    "dhurava(t)": ['cped'],
    "dhuraḥ": ['ap90'],
    "dhuraṃdhara": ['ap90', 'cae', 'mw'],
    "dhurdhūraka": ['bhs'],
    "dhuri": ['mw'],
    "dhurikā": ['mw'],
    "dhurv": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhurya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhuryatā": ['mw'],
    "dhuryavat": ['mw'],
    "dhuryavāha": ['mw'],
    "dhuryetara": ['mw'],
    "dhuryāsana": ['cae', 'mw'],
    "dhurā": ['ap90', 'cae', 'mw'],
    "dhurānikṣepaṇa": ['bhs', 'mw'],
    "dhurātuṇḍa": ['bhs'],
    "dhurāvaha": ['mw'],
    "dhurīya": ['mw'],
    "dhurīṇa": ['ap90', 'ddsa', 'mw'],
    "dhustura": ['mw'],
    "dhusturaḥ": ['ap90'],
    "dhustūra": ['cae', 'ddsa'],
    "dhustūraḥ": ['ap90'],
    "dhuta": ['ap90', 'bhs', 'cped', 'mw'],
    "dhutadhara": ['bhs'],
    "dhutadharma": ['bhs'],
    "dhutaguṇa": ['bhs', 'mw'],
    "dhutaguṇin": ['bhs'],
    "dhutapāpa": ['mw'],
    "dhutaṃguṇa": ['bhs'],
    "dhutaṅga": ['cped'],
    "dhutaṅgaguṇa": ['cped'],
    "dhutaṅgakilesa": ['cped'],
    "dhutaṇgavāda": ['cped'],
    "dhutta": ['cped'],
    "dhuttaka": ['cped'],
    "dhuttikā": ['cped'],
    "dhuttī": ['cped'],
    "dhuttūraka": ['bhs'],
    "dhuva": ['cped'],
    "dhuvabhatta": ['cped'],
    "dhuvabhattika": ['cped'],
    "dhuvacolā": ['cped'],
    "dhuvacoḷā": ['cped'],
    "dhuvaka": ['mw'],
    "dhuvakila": ['mw'],
    "dhuvakin": ['mw'],
    "dhuvakā": ['ap90', 'mw'],
    "dhuvana": ['ddsa', 'mw'],
    "dhuvanaḥ": ['ap90'],
    "dhuvati": ['cped'],
    "dhuvayāgu": ['cped'],
    "dhuvaṭṭhāniya": ['cped'],
    "dhuvitra": ['mw'],
    "dhuvitraṃ": ['ap90'],
    "dhuśulyā": ['mw'],
    "dhuḥ": ['ap90'],
    "dhuṃdhumāraḥ": ['ap90'],
    "dhuṅkṣā": ['cae', 'mw'],
    "dhvaj": ['ap90', 'gra', 'mw'],
    "dhvaja": ['cae', 'ddsa', 'gra', 'mw'],
    "dhvajabaddhaka": ['bhs'],
    "dhvajabhaṅga": ['mw'],
    "dhvajadhvaja": ['bhs'],
    "dhvajadruma": ['mw'],
    "dhvajagrīva": ['mw'],
    "dhvajagṛha": ['mw'],
    "dhvajahṛta": ['mw'],
    "dhvajaketu": ['bhs'],
    "dhvajamaparājita": ['bhs'],
    "dhvajanavamī": ['mw'],
    "dhvajapatākin": ['mw'],
    "dhvajapaṭa": ['cae', 'mw'],
    "dhvajapraharaṇa": ['mw'],
    "dhvajarucira": ['bhs'],
    "dhvajarājin": ['mw'],
    "dhvajasamucchraya": ['mw'],
    "dhvajavada": ['mw'],
    "dhvajavant": ['cae'],
    "dhvajavat": ['ap90', 'mw'],
    "dhvajavatī": ['bhs', 'mw'],
    "dhvajavṛkṣa": ['mw'],
    "dhvajayantra": ['mw'],
    "dhvajayaṣṭi": ['cae', 'mw'],
    "dhvajaḥ": ['ap90'],
    "dhvaji": ['mw'],
    "dhvajika": ['mw'],
    "dhvajikaḥ": ['ap90'],
    "dhvajin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhvajinyutsavasaṃketa": ['mw'],
    "dhvajinī": ['ddsa', 'mw'],
    "dhvajinīpati": ['mw'],
    "dhvajinīpāla": ['mw'],
    "dhvajocchrāya": ['mw'],
    "dhvajonnati": ['mw'],
    "dhvajottama": ['bhs'],
    "dhvajotthāna": ['mw'],
    "dhvajotthāpana": ['mw'],
    "dhvajotthāpanamantra": ['mw'],
    "dhvajāgra": ['bhs', 'mw'],
    "dhvajāgrakeyūra": ['bhs', 'mw'],
    "dhvajāgrakeyūrā": ['bhs'],
    "dhvajāgramaṇi": ['bhs'],
    "dhvajāgraniśrāvaṇī": ['bhs'],
    "dhvajāgraniśāmaṇi": ['mw'],
    "dhvajāgrasūtra": ['bhs'],
    "dhvajāgravatī": ['bhs', 'mw'],
    "dhvajāhṛta": ['cae', 'ddsa', 'mw'],
    "dhvajākāra": ['mw'],
    "dhvajāroha": ['mw'],
    "dhvajārohaṇa": ['mw'],
    "dhvajāropaṇa": ['mw'],
    "dhvajāṃśuka": ['mw'],
    "dhvajī": ['mw'],
    "dhvajīkaraṇa": ['mw'],
    "dhvajīkaraṇaṃ": ['ap90'],
    "dhvajīkṛ": ['ddsa', 'mw'],
    "dhvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhvana": ['cae', 'mw'],
    "dhvanamodin": ['mw'],
    "dhvanana": ['cae', 'ddsa', 'mw'],
    "dhvananaṃ": ['ap90'],
    "dhvanayat": ['mw'],
    "dhvanaḥ": ['ap90'],
    "dhvani": ['cae', 'ddsa', 'mw'],
    "dhvania": ['gra'],
    "dhvanibodhaka": ['mw'],
    "dhvanibodhana": ['mw'],
    "dhvanidhvaṃsa": ['mw'],
    "dhvanigraha": ['mw'],
    "dhvanigāthāpañjikā": ['mw'],
    "dhvanikāra": ['mw'],
    "dhvanikṛt": ['mw'],
    "dhvanimat": ['mw'],
    "dhvanimattā": ['mw'],
    "dhvaninālā": ['mw'],
    "dhvaninātha": ['mw'],
    "dhvanipradīpa": ['mw'],
    "dhvanisiddhāntasaṃgraha": ['mw'],
    "dhvanita": ['ap90', 'cae', 'mw'],
    "dhvanitva": ['mw'],
    "dhvanivikāra": ['mw'],
    "dhvaniviveka": ['mw'],
    "dhvaniḥ": ['ap90'],
    "dhvany": ['mw'],
    "dhvanya": ['gra', 'mw'],
    "dhvanyartha": ['mw'],
    "dhvanyācārya": ['mw'],
    "dhvanyālocana": ['mw'],
    "dhvanyāloka": ['mw'],
    "dhvanyātmaka": ['ddsa', 'mw'],
    "dhvaras": ['cae', 'gra', 'mw'],
    "dhvartavya": ['mw'],
    "dhvarya": ['mw'],
    "dhvarā": ['cae', 'mw'],
    "dhvas": ['cae', 'gra', 'mw'],
    "dhvasan": ['cae', 'mw'],
    "dhvasani": ['cae', 'gra', 'mw'],
    "dhvasanti": ['cae', 'gra', 'mw'],
    "dhvasira": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhvasman": ['cae', 'gra', 'mw'],
    "dhvasmanvant": ['cae'],
    "dhvasmanvat": ['gra', 'mw'],
    "dhvasra": ['cae', 'gra', 'mw'],
    "dhvasta": ['ap90', 'cae', 'mw'],
    "dhvastadhī": ['mw'],
    "dhvastakamala": ['mw'],
    "dhvastamūrdhaja": ['mw'],
    "dhvastapreman": ['mw'],
    "dhvastarajaḥsattvatamomala": ['mw'],
    "dhvasti": ['cae', 'mw'],
    "dhvastiḥ": ['ap90'],
    "dhvastākṣa": ['mw'],
    "dhvañj": ['mw'],
    "dhvaṃs": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhvaṃsa": ['cae', 'ddsa', 'mw'],
    "dhvaṃsaka": ['cae', 'mw'],
    "dhvaṃsakalākṛ": ['mw'],
    "dhvaṃsakārin": ['cae', 'mw'],
    "dhvaṃsana": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhvaṃsaḥ": ['ap90'],
    "dhvaṃsi": ['mw'],
    "dhvaṃsin": ['ap90', 'cae', 'mw'],
    "dhvaṃsita": ['ap90', 'mw'],
    "dhvaṃsiḥ": ['ap90'],
    "dhvaṃsī": ['mw'],
    "dhvaṇ": ['ap90', 'mw'],
    "dhvraṇ": ['mw'],
    "dhvākṣā": ['mw'],
    "dhvāna": ['cae', 'ddsa', 'mw'],
    "dhvānaḥ": ['ap90'],
    "dhvānita": ['mw'],
    "dhvānitadundubhi": ['mw'],
    "dhvānta": ['cae', 'ddsa', 'mw'],
    "dhvāntacitta": ['mw'],
    "dhvāntadīpikā": ['mw'],
    "dhvāntajāla": ['mw'],
    "dhvāntamaṇi": ['mw'],
    "dhvāntarāti": ['mw'],
    "dhvāntasaṃtati": ['mw'],
    "dhvāntaśātrava": ['mw'],
    "dhvāntonmeṣa": ['mw'],
    "dhvānāyana": ['mw'],
    "dhvāṃkṣ": ['ap90'],
    "dhvāṃkṣaḥ": ['ap90'],
    "dhvāṃtaṃ": ['ap90'],
    "dhvāṅkṣ": ['mw'],
    "dhvāṅkṣa": ['cae', 'ddsa', 'mw'],
    "dhvāṅkṣadantī": ['mw'],
    "dhvāṅkṣajambū": ['mw'],
    "dhvāṅkṣajaṅghā": ['mw'],
    "dhvāṅkṣamācī": ['mw'],
    "dhvāṅkṣanakhī": ['mw'],
    "dhvāṅkṣanāman": ['mw'],
    "dhvāṅkṣanāmnī": ['mw'],
    "dhvāṅkṣanāsikā": ['mw'],
    "dhvāṅkṣanāsā": ['mw'],
    "dhvāṅkṣanāśanī": ['mw'],
    "dhvāṅkṣapuṣṭa": ['mw'],
    "dhvāṅkṣatuṇḍaphala": ['mw'],
    "dhvāṅkṣatuṇḍā": ['mw'],
    "dhvāṅkṣatuṇḍī": ['mw'],
    "dhvāṅkṣatīrtha": ['mw'],
    "dhvāṅkṣavallī": ['mw'],
    "dhvāṅkṣikā": ['mw'],
    "dhvāṅkṣolikā": ['mw'],
    "dhvāṅkṣolī": ['mw'],
    "dhvāṅkṣā": ['mw'],
    "dhvāṅkṣādanī": ['mw'],
    "dhvāṅkṣārāti": ['mw'],
    "dhvāṅkṣī": ['mw'],
    "dhvṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhvṛt": ['mw'],
    "dhyai": ['ap90', 'ddsa', 'mw'],
    "dhyeya": ['cae', 'ddsa', 'mw'],
    "dhyuṣita": ['bhs', 'ddsa', 'mw'],
    "dhyuṣitāśva": ['mw'],
    "dhyā": ['ap90', 'cae', 'gra', 'mw'],
    "dhyāma": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "dhyāmaka": ['mw'],
    "dhyāmala": ['mw'],
    "dhyāmalīkṛ": ['mw'],
    "dhyāman": ['ap90'],
    "dhyāmīkaraṇa": ['bhs', 'mw'],
    "dhyāmīkaroti": ['bhs'],
    "dhyāmīkṛta": ['mw'],
    "dhyāna": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "dhyānabhaṅga": ['mw'],
    "dhyānabhūmi": ['bhs'],
    "dhyānabindūpaniṣad": ['mw'],
    "dhyānacakṣus": ['mw'],
    "dhyānaccheda": ['mw'],
    "dhyānadhīra": ['mw'],
    "dhyānadrāhyāyaṇī": ['bhs'],
    "dhyānadyuti": ['mw'],
    "dhyānadīpa": ['mw'],
    "dhyānadīpikā": ['mw'],
    "dhyānadṛṣṭi": ['mw'],
    "dhyānagamya": ['mw'],
    "dhyānagocara": ['bhs', 'mw'],
    "dhyānajapya": ['mw'],
    "dhyānalakṣaṇa": ['mw'],
    "dhyānamaya": ['mw'],
    "dhyānamudrā": ['mw'],
    "dhyānamātra": ['mw'],
    "dhyānanitya": ['mw'],
    "dhyānaniṣṭha": ['mw'],
    "dhyānapara": ['cae', 'mw'],
    "dhyānapaṭaha": ['cae'],
    "dhyānaphala": ['mw'],
    "dhyānapuṣṭa": ['mw'],
    "dhyānapāramitā": ['mw'],
    "dhyānapūta": ['mw'],
    "dhyānastha": ['mw'],
    "dhyānasthita": ['cae', 'mw'],
    "dhyānastimitalocana": ['mw'],
    "dhyānataraṃgaṭīkā": ['mw'],
    "dhyānatatpara": ['cae', 'mw'],
    "dhyānavallarī": ['mw'],
    "dhyānavat": ['mw'],
    "dhyānayoga": ['cae', 'mw'],
    "dhyānayogasara": ['mw'],
    "dhyānayogin": ['mw'],
    "dhyānaśataka": ['mw'],
    "dhyānaśīlā": ['mw'],
    "dhyāni": ['bhs', 'mw'],
    "dhyānibodhisattva": ['mw'],
    "dhyānibuddha": ['mw'],
    "dhyānika": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhyānin": ['mw'],
    "dhyānāgāra": ['mw'],
    "dhyānāhāra": ['bhs', 'mw'],
    "dhyānālaṃkāra": ['mw'],
    "dhyānāmbā": ['mw'],
    "dhyānāspada": ['mw'],
    "dhyānāvacara": ['mw'],
    "dhyānāśrayaṭīkā": ['mw'],
    "dhyānāṅga": ['bhs'],
    "dhyānīya": ['mw'],
    "dhyāpayati": ['bhs'],
    "dhyāta": ['ap90', 'mw'],
    "dhyātaka": ['bhs'],
    "dhyātamātra": ['mw'],
    "dhyātamātropagāmin": ['mw'],
    "dhyātamātropanata": ['mw'],
    "dhyātamātropasthita": ['mw'],
    "dhyātamātrāgata": ['ddsa', 'mw'],
    "dhyātavya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhyātopanata": ['ddsa'],
    "dhyātva": ['mw'],
    "dhyātṛ": ['cae', 'mw'],
    "dhyātṛdhyātavyatva": ['mw'],
    "dhyāyam": ['ddsa', 'mw'],
    "dhyāyamāna": ['mw'],
    "dhyāyat": ['mw'],
    "dhyāyati": ['bhs', 'mw'],
    "dhyāyi": ['bhs'],
    "dhyāyikā": ['bhs'],
    "dhyāyin": ['cae', 'ddsa', 'mw'],
    "dhyāṃkṣaḥ": ['ap90'],
    "dhā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhāka": ['mw'],
    "dhākaḥ": ['ap90'],
    "dhākā": ['mw'],
    "dhāma": ['cae', 'ddsa', 'mw'],
    "dhāmabhāj": ['mw'],
    "dhāmacchad": ['ddsa', 'mw'],
    "dhāmadhā": ['gra', 'mw'],
    "dhāmaka": ['mw'],
    "dhāmakaḥ": ['ap90'],
    "dhāmakeśin": ['mw'],
    "dhāmamānin": ['mw'],
    "dhāman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhāmanidhi": ['mw'],
    "dhāmanikā": ['ap90', 'mw'],
    "dhāmanī": ['mw'],
    "dhāmasac": ['gra', 'mw'],
    "dhāmasāc": ['gra', 'mw'],
    "dhāmavant": ['cae'],
    "dhāmavat": ['ddsa', 'mw'],
    "dhāmaśas": ['gra', 'mw'],
    "dhāmādhipa": ['ddsa', 'mw'],
    "dhāmārga": ['mw'],
    "dhāmārgava": ['mw'],
    "dhāna": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "dhānada": ['mw'],
    "dhānaka": ['cae', 'ddsa', 'mw'],
    "dhānakaṃ": ['ap90'],
    "dhānakā": ['mw'],
    "dhānapata": ['mw'],
    "dhānasī": ['mw'],
    "dhānayaḥ": ['ap90'],
    "dhānaśrī": ['mw'],
    "dhānaṃ": ['ap90'],
    "dhānaṃjayya": ['mw'],
    "dhāndhya": ['mw'],
    "dhāndhā": ['mw'],
    "dhāneya": ['mw'],
    "dhāneyaka": ['mw'],
    "dhānia": ['gra'],
    "dhānikā": ['mw'],
    "dhānin": ['mw'],
    "dhāniya": ['cped'],
    "dhāniākṛt": ['gra'],
    "dhānta": ['mw'],
    "dhānurdaṃḍikaḥ": ['ap90'],
    "dhānurdaṇḍika": ['mw'],
    "dhānurveda": ['mw'],
    "dhānuṣka": ['cae', 'ddsa', 'mw'],
    "dhānuṣkari": ['mw'],
    "dhānuṣkatā": ['mw'],
    "dhānuṣkā": ['mw'],
    "dhānuṣkārika": ['bhs'],
    "dhānuṣkārin": ['bhs'],
    "dhānuṣkārīka": ['bhs'],
    "dhānuṣya": ['mw'],
    "dhānuṣyaḥ": ['ap90'],
    "dhānva": ['cae', 'ddsa', 'mw'],
    "dhānvana": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhānvantara": ['mw'],
    "dhānvantarya": ['mw'],
    "dhānvantarīya": ['mw'],
    "dhānvapata": ['mw'],
    "dhānya": ['cae', 'ddsa', 'gra', 'mw'],
    "dhānyabīja": ['mw'],
    "dhānyacamasa": ['mw'],
    "dhānyacaura": ['cae', 'mw'],
    "dhānyacārin": ['mw'],
    "dhānyada": ['cae', 'mw'],
    "dhānyadhana": ['cae', 'mw'],
    "dhānyadhanatas": ['mw'],
    "dhānyadhanavat": ['mw'],
    "dhānyadhenu": ['mw'],
    "dhānyadrāhyāyaṇa": ['bhs'],
    "dhānyagava": ['mw'],
    "dhānyajīvin": ['mw'],
    "dhānyaka": ['cae', 'ddsa', 'mw'],
    "dhānyakalka": ['mw'],
    "dhānyakartana": ['mw'],
    "dhānyakaṭaka": ['bhs', 'mw'],
    "dhānyakhala": ['cae', 'mw'],
    "dhānyakośa": ['mw'],
    "dhānyakoṣa": ['mw'],
    "dhānyakoṣṭaka": ['mw'],
    "dhānyakūṭa": ['cae', 'mw'],
    "dhānyakṣetra": ['mw'],
    "dhānyamaya": ['cae', 'mw'],
    "dhānyamiśra": ['cae', 'mw'],
    "dhānyamiśrā": ['mw'],
    "dhānyamāna": ['mw'],
    "dhānyamātṛ": ['mw'],
    "dhānyamāya": ['mw'],
    "dhānyamāṣa": ['mw'],
    "dhānyaparigraha": ['bhs'],
    "dhānyaparvatadānavidhi": ['mw'],
    "dhānyapata": ['mw'],
    "dhānyapati": ['mw'],
    "dhānyapañcaka": ['cae', 'mw'],
    "dhānyapura": ['bhs'],
    "dhānyapāla": ['mw'],
    "dhānyapātra": ['mw'],
    "dhānyapūla": ['mw'],
    "dhānyaropaṇa": ['mw'],
    "dhānyarāja": ['mw'],
    "dhānyasaṃgraha": ['mw'],
    "dhānyasāra": ['mw'],
    "dhānyatilvila": ['mw'],
    "dhānyatvac": ['mw'],
    "dhānyatā": ['mw'],
    "dhānyavani": ['mw'],
    "dhānyavapana": ['mw'],
    "dhānyavardhana": ['mw'],
    "dhānyavat": ['cae', 'mw'],
    "dhānyavīja": ['mw'],
    "dhānyavīra": ['mw'],
    "dhānyaśailadāna": ['mw'],
    "dhānyaśreṣṭha": ['mw'],
    "dhānyaśīrṣaka": ['mw'],
    "dhānyaśūka": ['mw'],
    "dhānyaṃ": ['ap90'],
    "dhānyeya": ['mw'],
    "dhānyika": ['bhs'],
    "dhānyottama": ['mw'],
    "dhānyā": ['ap90'],
    "dhānyābhra": ['mw'],
    "dhānyābhraka": ['mw'],
    "dhānyācala": ['mw'],
    "dhānyāda": ['cae', 'mw'],
    "dhānyākṛt": ['gra', 'mw'],
    "dhānyāmla": ['mw'],
    "dhānyārdha": ['cae'],
    "dhānyārgha": ['mw'],
    "dhānyāri": ['mw'],
    "dhānyārtha": ['mw'],
    "dhānyāsthi": ['mw'],
    "dhānyāyana": ['mw'],
    "dhānyāṃśa": ['cae', 'ddsa', 'mw'],
    "dhānā": ['cae', 'ddsa', 'gra', 'mw'],
    "dhānābharjana": ['mw'],
    "dhānācūrṇa": ['mw'],
    "dhānāka": ['mw'],
    "dhānākā": ['mw'],
    "dhānākāḥ": ['ap90'],
    "dhānāmuṣṭi": ['mw'],
    "dhānāntarvat": ['mw'],
    "dhānāphalavratakathā": ['mw'],
    "dhānāpūpa": ['mw'],
    "dhānāruh": ['mw'],
    "dhānāsoma": ['mw'],
    "dhānāvat": ['gra', 'mw'],
    "dhānāḥ": ['ap90'],
    "dhānī": ['ap90', 'mw'],
    "dhāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhāraka": ['ap90', 'bhs', 'cae', 'mw'],
    "dhārakajātika": ['cped'],
    "dhārakuśalāntara": ['bhs'],
    "dhārakā": ['cae', 'mw'],
    "dhāralopaka": ['mw'],
    "dhārapūta": ['cae', 'ddsa', 'gra', 'mw'],
    "dhāravāka": ['gra', 'mw'],
    "dhāraya": ['mw'],
    "dhārayadvat": ['mw'],
    "dhārayat": ['ddsa', 'mw'],
    "dhārayati": ['bhs', 'cped'],
    "dhārayatkavi": ['cae', 'gra', 'mw'],
    "dhārayatkṣiti": ['cae', 'gra', 'mw'],
    "dhārayi": ['cped'],
    "dhārayitavya": ['cae', 'ddsa', 'mw'],
    "dhārayitrī": ['ap90', 'mw'],
    "dhārayitvā": ['cped'],
    "dhārayitṛ": ['cae', 'mw'],
    "dhārayiṁ": ['cped'],
    "dhārayiṣṇu": ['ap90', 'mw'],
    "dhārayiṣṇutā": ['ddsa', 'mw'],
    "dhārayu": ['cae', 'gra', 'mw'],
    "dhārayuṁ": ['cped'],
    "dhārayāṇa": ['mw'],
    "dhāraṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "dhāraṇaka": ['cae', 'mw'],
    "dhāraṇakaḥ": ['ap90'],
    "dhāraṇalakṣaṇa": ['mw'],
    "dhāraṇamātṛkā": ['mw'],
    "dhāraṇapātra": ['mw'],
    "dhāraṇayantra": ['mw'],
    "dhāraṇi": ['mw'],
    "dhāraṇita": ['bhs'],
    "dhāraṇā": ['ap90', 'ddsa', 'mw'],
    "dhāraṇādhyayana": ['mw'],
    "dhāraṇāmaya": ['mw'],
    "dhāraṇānvita": ['ddsa', 'mw'],
    "dhāraṇāpāraṇavrata": ['mw'],
    "dhāraṇātmaka": ['mw'],
    "dhāraṇāvat": ['mw'],
    "dhāraṇāyoga": ['mw'],
    "dhāraṇāyukta": ['mw'],
    "dhāraṇī": ['bhs', 'mw'],
    "dhāraṇīgarbha": ['bhs'],
    "dhāraṇīmati": ['bhs', 'mw'],
    "dhāraṇīmukhasarvajagatpraṇidhisaṃdhāraṇagarbha": ['bhs', 'mw'],
    "dhāraṇīrāja": ['mw'],
    "dhāraṇīya": ['mw'],
    "dhāraṇīyā": ['cped', 'mw'],
    "dhāraṇīśvararāja": ['bhs'],
    "dhārenta": ['cped'],
    "dhāresi": ['cped'],
    "dhāresuṁ": ['cped'],
    "dhāreta(r)": ['cped'],
    "dhāretabba": ['cped'],
    "dhāreti": ['cped'],
    "dhāretvā": ['cped'],
    "dhāreśvara": ['mw'],
    "dhāri": ['cae', 'ddsa', 'mw'],
    "dhārikā": ['ddsa', 'mw'],
    "dhārin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhārita": ['ap90', 'cped', 'mw'],
    "dhāritabba": ['cped'],
    "dhāriyamāna": ['cped'],
    "dhāriṇī": ['ap90', 'mw'],
    "dhārma": ['ap90', 'cae', 'mw'],
    "dhārmakathika": ['bhs'],
    "dhārmapata": ['mw'],
    "dhārmapattana": ['mw'],
    "dhārmarājikā": ['bhs'],
    "dhārmavidya": ['mw'],
    "dhārmaśravaṇika": ['bhs'],
    "dhārmi": ['bhs'],
    "dhārmika": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhārmikatva": ['mw'],
    "dhārmikatā": ['mw'],
    "dhārmikya": ['mw'],
    "dhārmikīkṣita": ['bhs'],
    "dhārmiṇa": ['mw'],
    "dhārmiṇaṃ": ['ap90'],
    "dhārmiṇeya": ['mw'],
    "dhārmuka": ['mw'],
    "dhārmya": ['bhs', 'mw'],
    "dhārmyāyaṇa": ['mw'],
    "dhārmī": ['bhs'],
    "dhāropa": ['cped'],
    "dhārormi": ['mw'],
    "dhāroṣṇa": ['mw'],
    "dhārta": ['mw'],
    "dhārtarājña": ['mw'],
    "dhārtarājñaka": ['mw'],
    "dhārtarājñī": ['mw'],
    "dhārtarāṣṭra": ['cae', 'ddsa', 'mw'],
    "dhārtarāṣṭrapadī": ['mw'],
    "dhārtarāṣṭraḥ": ['ap90'],
    "dhārtarāṣṭri": ['mw'],
    "dhārteya": ['mw'],
    "dhārteyī": ['mw'],
    "dhāru": ['cae', 'mw'],
    "dhārya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhāryamāṇa": ['mw'],
    "dhāryamāṇatva": ['mw'],
    "dhāryatva": ['mw'],
    "dhārā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dhārādhara": ['cae', 'ddsa', 'mw'],
    "dhārādharodyāna": ['mw'],
    "dhārādharāgama": ['mw'],
    "dhārādharātyaya": ['mw'],
    "dhārādhirūḍha": ['cae', 'ddsa', 'mw'],
    "dhārādhvani": ['mw'],
    "dhārādhvaṃsa": ['mw'],
    "dhārāghoṣa": ['mw'],
    "dhārāgra": ['mw'],
    "dhārāgraha": ['mw'],
    "dhārāgṛha": ['mw'],
    "dhārāgṛhatva": ['mw'],
    "dhārājala": ['ddsa', 'mw'],
    "dhārākadamba": ['ddsa', 'mw'],
    "dhārāla": ['ap90', 'mw'],
    "dhārāmbhas": ['mw'],
    "dhārānipāta": ['cae', 'ddsa', 'mw'],
    "dhārāntaracara": ['mw'],
    "dhārānuyāja": ['mw'],
    "dhārāpatha": ['mw'],
    "dhārāpayas": ['mw'],
    "dhārāphala": ['mw'],
    "dhārāpāta": ['cae', 'mw'],
    "dhārārāṅkura": ['ddsa'],
    "dhārāsalila": ['mw'],
    "dhārāsampāta": ['ddsa', 'mw'],
    "dhārāsaṃpāta": ['cae'],
    "dhārāsnuhī": ['mw'],
    "dhārāsāra": ['cae', 'ddsa', 'mw'],
    "dhārāsūra": ['mw'],
    "dhārāvani": ['mw'],
    "dhārāvara": ['cae', 'gra', 'mw'],
    "dhārāvarta": ['mw'],
    "dhārāvartena": ['mw'],
    "dhārāvarṣa": ['cae', 'mw'],
    "dhārāvat": ['mw'],
    "dhārāvatī": ['mw'],
    "dhārāviṣa": ['mw'],
    "dhārāvāsa": ['mw'],
    "dhārāya": ['mw'],
    "dhārāyantra": ['cae', 'mw'],
    "dhārāyantragṛha": ['mw'],
    "dhārāyāja": ['mw'],
    "dhārāñcala": ['ddsa', 'mw'],
    "dhārāśita": ['mw'],
    "dhārāśru": ['cae', 'ddsa', 'mw'],
    "dhārāṅga": ['mw'],
    "dhārāṅgura": ['cae'],
    "dhārāṅkura": ['mw'],
    "dhārāṭa": ['mw'],
    "dhārīyati": ['cped'],
    "dhārṣṇaka": ['mw'],
    "dhārṣṭa": ['mw'],
    "dhārṣṭadyumna": ['mw'],
    "dhārṣṭadyumni": ['mw'],
    "dhārṣṭaka": ['mw'],
    "dhārṣṭya": ['cae', 'ddsa', 'mw'],
    "dhārṣṭyabhūmi": ['mw'],
    "dhārṣṭyaṃ": ['ap90'],
    "dhāsas": ['ap90', 'mw'],
    "dhāsi": ['cae', 'ddsa', 'gra', 'mw'],
    "dhāsiḥ": ['ap90'],
    "dhāsyu": ['cae', 'mw'],
    "dhāta": ['cped'],
    "dhātaka": ['mw'],
    "dhātaki": ['mw'],
    "dhātakitīrtha": ['mw'],
    "dhātakī": ['mw'],
    "dhātakīkhaṇḍa": ['mw'],
    "dhātakīṣaṇḍa": ['mw'],
    "dhāti": ['cped'],
    "dhāticela": ['cped'],
    "dhātra": ['cae', 'ddsa', 'mw'],
    "dhātraṃ": ['ap90'],
    "dhātreyikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhātreyī": ['cae', 'mw'],
    "dhātri": ['mw'],
    "dhātrikā": ['mw'],
    "dhātrī": ['ap90', 'ddsa', 'mw'],
    "dhātrīdhara": ['mw'],
    "dhātrīmodaka": ['mw'],
    "dhātrīpattra": ['mw'],
    "dhātrīphala": ['mw'],
    "dhātrīputra": ['mw'],
    "dhātrīśvarī": ['mw'],
    "dhātu": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dhātubhṛt": ['mw'],
    "dhātucandrikā": ['mw'],
    "dhātucandrodaya": ['mw'],
    "dhātucintāmaṇi": ['mw'],
    "dhātucūrṇa": ['mw'],
    "dhātudrāvaka": ['mw'],
    "dhātudīpikā": ['mw'],
    "dhātugarbha": ['bhs', 'mw'],
    "dhātugarbhakumbha": ['mw'],
    "dhātugaṇa": ['mw'],
    "dhātughna": ['mw'],
    "dhātughoṣā": ['mw'],
    "dhātugrāhin": ['mw'],
    "dhātuhan": ['mw'],
    "dhātuja": ['mw'],
    "dhātuka": ['bhs', 'mw'],
    "dhātukalpa": ['mw'],
    "dhātukathā": ['mw'],
    "dhātukośa": ['mw'],
    "dhātukramamālā": ['mw'],
    "dhātukriyā": ['cae', 'mw'],
    "dhātukuśala": ['ddsa', 'mw'],
    "dhātukāsīsa": ['mw'],
    "dhātukāvya": ['mw'],
    "dhātukāya": ['bhs', 'mw'],
    "dhātukī": ['bhs'],
    "dhātukṣaya": ['mw'],
    "dhātukṣayakāsa": ['mw'],
    "dhātula": ['mw'],
    "dhātulakṣaṇa": ['mw'],
    "dhātumala": ['mw'],
    "dhātumant": ['cae'],
    "dhātumat": ['ap90', 'mw'],
    "dhātumattā": ['cae', 'mw'],
    "dhātumaya": ['ap90', 'cae', 'mw'],
    "dhātumañjarī": ['mw'],
    "dhātumākṣika": ['mw'],
    "dhātumālā": ['mw'],
    "dhātumāraṇa": ['mw'],
    "dhātumārin": ['mw'],
    "dhātumāriṇī": ['mw'],
    "dhātunidāna": ['mw'],
    "dhātunāśana": ['mw'],
    "dhātupa": ['mw'],
    "dhātuparyāyadīpikā": ['mw'],
    "dhātuparyāyamañjūṣā": ['mw'],
    "dhātupradīpa": ['mw'],
    "dhātupradīpikā": ['mw'],
    "dhātuprakaraṇa": ['mw'],
    "dhātuprakāśa": ['mw'],
    "dhātuprasakta": ['mw'],
    "dhātupratyayapañcaka": ['mw'],
    "dhātupratyayapañjikā": ['mw'],
    "dhātupriyā": ['bhs', 'mw'],
    "dhātupuṣpikā": ['mw'],
    "dhātupuṣpī": ['mw'],
    "dhātupārāyaṇa": ['mw'],
    "dhātupārāyaṇavṛtti": ['mw'],
    "dhātupārāyaṇīya": ['mw'],
    "dhātupāṭha": ['cae', 'mw'],
    "dhātupūjā": ['mw'],
    "dhāturahasya": ['mw'],
    "dhāturatnamañjari": ['mw'],
    "dhāturatnamañjarī": ['mw'],
    "dhāturatnamālā": ['mw'],
    "dhāturatnākara": ['mw'],
    "dhāturatnāvalī": ['mw'],
    "dhāturājaka": ['mw'],
    "dhāturāṣṭra": ['bhs'],
    "dhāturūpa": ['mw'],
    "dhāturūpādarśa": ['mw'],
    "dhāturūpāvalī": ['mw'],
    "dhātusambhava": ['mw'],
    "dhātusamāsa": ['mw'],
    "dhātusaṃgraha": ['mw'],
    "dhātustūpa": ['mw'],
    "dhātusādhana": ['mw'],
    "dhātusāmya": ['mw'],
    "dhātutantra": ['bhs'],
    "dhātutaraṃgiṇī": ['mw'],
    "dhātuvairin": ['mw'],
    "dhātuvallabha": ['mw'],
    "dhātuvigraha": ['bhs'],
    "dhātuvikāra": ['mw'],
    "dhātuviṣ": ['mw'],
    "dhātuviṣa": ['mw'],
    "dhātuvāda": ['cae', 'mw'],
    "dhātuvādin": ['cae', 'mw'],
    "dhātuvṛtti": ['cae', 'mw'],
    "dhātuśekhara": ['mw'],
    "dhātuśodhana": ['mw'],
    "dhātuḥ": ['ap90'],
    "dhātvartha": ['mw'],
    "dhātvavaropaṇa": ['mw'],
    "dhātvākara": ['cae', 'ddsa', 'mw'],
    "dhātvākarākhya": ['mw'],
    "dhātī": ['cped'],
    "dhātūpala": ['mw'],
    "dhātṛ": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "dhātṛbhavana": ['mw'],
    "dhātṛkā": ['mw'],
    "dhātṛputra": ['mw'],
    "dhātṛpuṣpikā": ['mw'],
    "dhātṛpuṣpī": ['mw'],
    "dhāv": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhāva": ['ap90', 'cae', 'cped', 'mw'],
    "dhāva(t)": ['cped'],
    "dhāvaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhāvalya": ['cae', 'ddsa', 'mw'],
    "dhāvalyaṃ": ['ap90'],
    "dhāvamāna": ['mw'],
    "dhāvana": ['bhs', 'cae', 'ddsa', 'mw'],
    "dhāvanaṃ": ['ap90'],
    "dhāvani": ['mw'],
    "dhāvanikā": ['mw'],
    "dhāvanta": ['cped'],
    "dhāvanī": ['mw'],
    "dhāvat": ['mw'],
    "dhāvati": ['cped'],
    "dhāvin": ['cae', 'ddsa', 'mw'],
    "dhāvita": ['ap90', 'bhs', 'mw'],
    "dhāvitṛ": ['cae', 'mw'],
    "dhāya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhāyas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhāyin": ['mw'],
    "dhāyine": ['mw'],
    "dhāyu": ['ap90', 'cae', 'gra', 'mw'],
    "dhāyya": ['mw'],
    "dhāyyaḥ": ['ap90'],
    "dhāyyā": ['cae', 'ddsa', 'mw'],
    "dhāḍunṛtya": ['mw'],
    "dhāṃdhā": ['ap90'],
    "dhāṇaka": ['mw'],
    "dhāṇakaḥ": ['ap90'],
    "dhāṇikā": ['gra', 'mw'],
    "dhāṇikī": ['mw'],
    "dhāṭī": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhāṭīpañcaka": ['mw'],
    "dhāṭīrahasya": ['mw'],
    "dhī": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dhīdā": ['ap90', 'mw'],
    "dhīharā": ['mw'],
    "dhījavana": ['gra', 'mw'],
    "dhījaḍa": ['mw'],
    "dhījū": ['gra', 'mw'],
    "dhīkarman": ['mw'],
    "dhīkoṭī": ['mw'],
    "dhīkṣ": ['ap90', 'mw'],
    "dhīlaṭiḥ": ['ap90'],
    "dhīlaṭī": ['mw'],
    "dhīmahi": ['ddsa'],
    "dhīmant": ['cae'],
    "dhīmaraṇa": ['mw'],
    "dhīmat": ['ap90', 'ddsa', 'mw'],
    "dhīna": ['mw'],
    "dhīndriya": ['mw'],
    "dhīr": ['mw'],
    "dhīra": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dhīrabhāva": ['cae', 'mw'],
    "dhīracetas": ['cae', 'ddsa', 'mw'],
    "dhīradhvani": ['mw'],
    "dhīragovindaśarman": ['mw'],
    "dhīralalita": ['mw'],
    "dhīralalitā": ['mw'],
    "dhīram": ['mw'],
    "dhīranāga": ['mw'],
    "dhīrapattrī": ['mw'],
    "dhīrapraśānta": ['cae', 'mw'],
    "dhīrapraśāntasvara": ['mw'],
    "dhīrarañjanikā": ['mw'],
    "dhīrasattva": ['cae', 'ddsa', 'mw'],
    "dhīraskandha": ['mw'],
    "dhīratva": ['mw'],
    "dhīratā": ['ap90', 'mw'],
    "dhīraya": ['ddsa', 'mw'],
    "dhīraśiva": ['mw'],
    "dhīraśānta": ['mw'],
    "dhīraṇa": ['cae', 'gra', 'mw'],
    "dhīrendra": ['mw'],
    "dhīreśamiśra": ['mw'],
    "dhīreśvara": ['mw'],
    "dhīria": ['gra'],
    "dhīroddhata": ['mw'],
    "dhīrodātta": ['mw'],
    "dhīroṣṇin": ['mw'],
    "dhīrya": ['cae', 'ddsa', 'gra', 'mw'],
    "dhīrā": ['ap90', 'mw'],
    "dhīrādhīrā": ['mw'],
    "dhīrāja": ['mw'],
    "dhīrāvī": ['mw'],
    "dhīrīkṛ": ['mw'],
    "dhīrūpasevanā": ['cped'],
    "dhīsaciva": ['ddsa', 'mw'],
    "dhīsakha": ['mw'],
    "dhīsaṃtati": ['mw'],
    "dhīta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhīta(r)": ['cped'],
    "dhītar": ['bhs'],
    "dhītarasa": ['mw'],
    "dhīti": ['cae', 'ddsa', 'gra', 'mw'],
    "dhītika": ['mw'],
    "dhītikā": ['cped'],
    "dhītiḥ": ['ap90'],
    "dhītokaka": ['mw'],
    "dhītumaraṇa": ['cped'],
    "dhītā": ['cae', 'cped', 'mw'],
    "dhītī": ['cped'],
    "dhītīkā": ['mw'],
    "dhīvan": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhīvant": ['cae'],
    "dhīvara": ['cae', 'ddsa', 'mw'],
    "dhīvarakaḥ": ['ap90'],
    "dhīvaraḥ": ['ap90'],
    "dhīvarī": ['mw'],
    "dhīvat": ['ddsa', 'gra', 'mw'],
    "dhīvibhrama": ['mw'],
    "dhīvṛddhida": ['mw'],
    "dhīśakti": ['mw'],
    "dhīśodhinī": ['mw'],
    "dhīḥ": ['ap90'],
    "dhū": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhūka": ['cae', 'mw'],
    "dhūkaḥ": ['ap90'],
    "dhūlakaṃ": ['ap90'],
    "dhūlana": ['cae', 'ddsa', 'mw'],
    "dhūlay": ['cae'],
    "dhūlaya": ['ddsa', 'mw'],
    "dhūli": ['cae', 'ddsa', 'mw'],
    "dhūlidhvaja": ['mw'],
    "dhūlidhūmra": ['mw'],
    "dhūliguccha": ['mw'],
    "dhūligucchaka": ['mw'],
    "dhūlihastaya": ['mw'],
    "dhūlikedāra": ['mw'],
    "dhūlikuṭṭima": ['mw'],
    "dhūlikā": ['ap90', 'mw'],
    "dhūlimaya": ['mw'],
    "dhūlimuṣṭi": ['mw'],
    "dhūlipaṭala": ['mw'],
    "dhūliprakṣepa": ['mw'],
    "dhūlipuṣpikā": ['mw'],
    "dhūlita": ['mw'],
    "dhūliḥ": ['ap90'],
    "dhūlī": ['cae'],
    "dhūlījaṅgha": ['mw'],
    "dhūlīkadamba": ['mw'],
    "dhūlīmaya": ['cae', 'ddsa', 'mw'],
    "dhūlīpatala": ['mw'],
    "dhūlīvarṣa": ['mw'],
    "dhūma": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dhūmadarśin": ['mw'],
    "dhūmadhvaja": ['cae', 'mw'],
    "dhūmadhūmra": ['mw'],
    "dhūmagandhi": ['gra', 'mw'],
    "dhūmagandhika": ['mw'],
    "dhūmaggi": ['cped'],
    "dhūmagraha": ['cae', 'mw'],
    "dhūmagāra": ['bhs'],
    "dhūmaja": ['mw'],
    "dhūmajāla": ['mw'],
    "dhūmaka": ['cae', 'mw'],
    "dhūmakapuṣpā": ['mw'],
    "dhūmaketana": ['cae', 'ddsa', 'mw'],
    "dhūmaketu": ['cae', 'gra', 'mw'],
    "dhūmakālika": ['bhs'],
    "dhūmakālikaṁ": ['cped'],
    "dhūmala": ['ap90', 'mw'],
    "dhūmalava": ['mw'],
    "dhūmalekhā": ['ddsa', 'mw'],
    "dhūmamahiṣī": ['mw'],
    "dhūmamaya": ['cae', 'mw'],
    "dhūmana": ['mw'],
    "dhūmanetra": ['bhs', 'mw'],
    "dhūmanetta": ['cped'],
    "dhūmanirgamana": ['mw'],
    "dhūmapa": ['mw'],
    "dhūmapallava": ['mw'],
    "dhūmapatha": ['cae', 'mw'],
    "dhūmaprabhā": ['mw'],
    "dhūmaprāśa": ['mw'],
    "dhūmapāna": ['mw'],
    "dhūmapānavidhi": ['mw'],
    "dhūmapāta": ['cae', 'mw'],
    "dhūmarakta": ['mw'],
    "dhūmarāji": ['mw'],
    "dhūmarī": ['mw'],
    "dhūmasa": ['mw'],
    "dhūmasaṃhati": ['mw'],
    "dhūmasī": ['mw'],
    "dhūmatā": ['mw'],
    "dhūmatānta": ['mw'],
    "dhūmavadgati": ['mw'],
    "dhūmavant": ['cae'],
    "dhūmavarcas": ['mw'],
    "dhūmavarti": ['mw'],
    "dhūmavartman": ['cae', 'mw'],
    "dhūmavarṇa": ['mw'],
    "dhūmavat": ['ap90', 'mw'],
    "dhūmavattva": ['mw'],
    "dhūmay": ['cae'],
    "dhūmaya": ['ddsa', 'mw'],
    "dhūmayati": ['ap90'],
    "dhūmayoni": ['mw'],
    "dhūmaśikhā": ['cae', 'mw'],
    "dhūmaḥ": ['ap90'],
    "dhūmikā": ['ap90', 'ddsa', 'mw'],
    "dhūmin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhūminī": ['mw'],
    "dhūmita": ['ap90', 'mw'],
    "dhūmitā": ['mw'],
    "dhūmodgama": ['cae', 'ddsa', 'mw'],
    "dhūmodgāra": ['cae', 'mw'],
    "dhūmopahata": ['mw'],
    "dhūmorṇā": ['mw'],
    "dhūmorṇāpati": ['mw'],
    "dhūmottha": ['mw'],
    "dhūmoṣṇayoni": ['mw'],
    "dhūmra": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhūmradhī": ['mw'],
    "dhūmragiri": ['mw'],
    "dhūmrajaṭila": ['mw'],
    "dhūmrajānu": ['mw'],
    "dhūmraka": ['mw'],
    "dhūmrakarṇa": ['mw'],
    "dhūmrakaḥ": ['ap90'],
    "dhūmraketu": ['mw'],
    "dhūmrakeśa": ['mw'],
    "dhūmralalāma": ['mw'],
    "dhūmralocana": ['mw'],
    "dhūmralohita": ['mw'],
    "dhūmramūlikā": ['mw'],
    "dhūmranīkāśa": ['mw'],
    "dhūmrapattrā": ['mw'],
    "dhūmrarohita": ['mw'],
    "dhūmraruc": ['mw'],
    "dhūmrasagotra": ['bhs'],
    "dhūmrasaṃraktalocana": ['mw'],
    "dhūmravarṇa": ['cae', 'ddsa', 'mw'],
    "dhūmravarṇaka": ['mw'],
    "dhūmravarṇā": ['mw'],
    "dhūmravarṇāmanu": ['mw'],
    "dhūmravidyā": ['mw'],
    "dhūmravṛttaphalā": ['mw'],
    "dhūmray": ['cae'],
    "dhūmraya": ['ddsa', 'mw'],
    "dhūmraśikha": ['mw'],
    "dhūmraśūka": ['mw'],
    "dhūmraśūla": ['mw'],
    "dhūmrikā": ['mw'],
    "dhūmriman": ['cae', 'mw'],
    "dhūmrorṇā": ['mw'],
    "dhūmrā": ['mw'],
    "dhūmrābha": ['mw'],
    "dhūmrāhvā": ['mw'],
    "dhūmrākṣa": ['cae', 'mw'],
    "dhūmrākṣi": ['mw'],
    "dhūmrānīka": ['mw'],
    "dhūmrāyaṇa": ['mw'],
    "dhūmrāśva": ['mw'],
    "dhūmrāṭa": ['mw'],
    "dhūmrīkṛ": ['ddsa', 'mw'],
    "dhūmyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhūmyāṭa": ['mw'],
    "dhūmā": ['mw'],
    "dhūmābha": ['mw'],
    "dhūmākāra": ['mw'],
    "dhūmākṣa": ['cae', 'mw'],
    "dhūmānubandha": ['cae', 'ddsa', 'mw'],
    "dhūmāvali": ['mw'],
    "dhūmāvatī": ['mw'],
    "dhūmāvatīdīpadānapūjā": ['mw'],
    "dhūmāvatīmantra": ['mw'],
    "dhūmāvatīmanu": ['mw'],
    "dhūmāvatīpaṭala": ['mw'],
    "dhūmāvatīpūjāpaddhati": ['mw'],
    "dhūmāy": ['cae'],
    "dhūmāya": ['ddsa', 'mw'],
    "dhūmāyana": ['mw'],
    "dhūmāyanaṃ": ['ap90'],
    "dhūmāyanā": ['cped'],
    "dhūmāyati": ['ap90', 'cped'],
    "dhūmāyita": ['cped', 'mw'],
    "dhūmāyitatta": ['cped'],
    "dhūmāyitvā": ['cped'],
    "dhūmāṅga": ['mw'],
    "dhūmīkā": ['mw'],
    "dhūna": ['ap90', 'mw'],
    "dhūnaka": ['mw'],
    "dhūnana": ['cae', 'ddsa', 'mw'],
    "dhūnanaḥ": ['ap90'],
    "dhūnay": ['cae'],
    "dhūnaya": ['ddsa', 'mw'],
    "dhūni": ['mw'],
    "dhūniḥ": ['ap90'],
    "dhūnvat": ['ddsa', 'mw'],
    "dhūp": ['ap90', 'gra', 'mw'],
    "dhūpa": ['cae', 'ddsa', 'mw'],
    "dhūpadhūpita": ['mw'],
    "dhūpadāna": ['mw'],
    "dhūpaka": ['cae', 'mw'],
    "dhūpakaḥ": ['ap90'],
    "dhūpakaṭacchuka": ['mw'],
    "dhūpana": ['cae', 'ddsa', 'mw'],
    "dhūpanadhūpita": ['mw'],
    "dhūpanaṃ": ['ap90'],
    "dhūpanetra": ['bhs', 'mw'],
    "dhūpanāguru": ['mw'],
    "dhūpanāṅga": ['mw'],
    "dhūpapātra": ['mw'],
    "dhūpatṛṇa": ['mw'],
    "dhūpavarti": ['ddsa', 'mw'],
    "dhūpavṛkṣa": ['mw'],
    "dhūpavṛkṣaka": ['mw'],
    "dhūpay": ['cae'],
    "dhūpaya": ['ddsa', 'mw'],
    "dhūpayitavya": ['mw'],
    "dhūpaḥ": ['ap90'],
    "dhūpi": ['cae', 'ddsa', 'mw'],
    "dhūpika": ['mw'],
    "dhūpikaḥ": ['ap90'],
    "dhūpin": ['cae', 'ddsa', 'mw'],
    "dhūpita": ['ap90', 'mw'],
    "dhūpoṣman": ['mw'],
    "dhūpya": ['mw'],
    "dhūpā": ['bhs'],
    "dhūpāguru": ['mw'],
    "dhūpārha": ['mw'],
    "dhūpāy": ['cae'],
    "dhūpāya": ['ddsa', 'mw'],
    "dhūpāyanā": ['cped'],
    "dhūpāyati": ['cped'],
    "dhūpāyita": ['cped', 'mw'],
    "dhūpāṅga": ['mw'],
    "dhūpāṅgada": ['mw'],
    "dhūr": ['ap90', 'mw'],
    "dhūrdhara": ['ddsa', 'mw'],
    "dhūrgata": ['cae', 'ddsa', 'mw'],
    "dhūrgṛhīta": ['mw'],
    "dhūrjaṭa": ['mw'],
    "dhūrjaṭi": ['cae', 'mw'],
    "dhūrjaṭin": ['cae'],
    "dhūrta": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhūrtacarita": ['cae', 'mw'],
    "dhūrtajantu": ['mw'],
    "dhūrtaka": ['cae', 'mw'],
    "dhūrtakaḥ": ['ap90'],
    "dhūrtakitava": ['ddsa', 'mw'],
    "dhūrtakṛt": ['mw'],
    "dhūrtalavaṇa": ['mw'],
    "dhūrtamaṇḍala": ['mw'],
    "dhūrtamānuṣā": ['mw'],
    "dhūrtanartaka": ['cae', 'mw'],
    "dhūrtaprahasana": ['mw'],
    "dhūrtapralāpa": ['mw'],
    "dhūrtaracanā": ['mw'],
    "dhūrtarāja": ['mw'],
    "dhūrtasamāgama": ['cae', 'mw'],
    "dhūrtasvāmibhāṣya": ['mw'],
    "dhūrtasvāmin": ['mw'],
    "dhūrtatva": ['mw'],
    "dhūrtatā": ['mw'],
    "dhūrtaviḍambana": ['mw'],
    "dhūrti": ['cae', 'ddsa', 'gra', 'mw'],
    "dhūrtila": ['mw'],
    "dhūrtā": ['mw'],
    "dhūruṣad": ['mw'],
    "dhūrv": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhūrvaha": ['mw'],
    "dhūrvan": ['cae', 'gra', 'mw'],
    "dhūrvat": ['mw'],
    "dhūrvoḍhṛ": ['cae', 'ddsa', 'mw'],
    "dhūrvā": ['mw'],
    "dhūrvī": ['ap90', 'mw'],
    "dhūrya": ['mw'],
    "dhūryuja": ['mw'],
    "dhūrṇa": ['mw'],
    "dhūrṇi": ['mw'],
    "dhūrṣad": ['cae', 'gra', 'mw'],
    "dhūrṣah": ['cae', 'mw'],
    "dhūrṣāh": ['mw'],
    "dhūs": ['mw'],
    "dhūsara": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhūsaracchadā": ['mw'],
    "dhūsaraka": ['mw'],
    "dhūsarapattrikā": ['mw'],
    "dhūsaratva": ['mw'],
    "dhūsariman": ['cae', 'ddsa', 'mw'],
    "dhūsarita": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhūsarā": ['mw'],
    "dhūsarī": ['mw'],
    "dhūstuṇḍa": ['ddsa'],
    "dhūstūra": ['mw'],
    "dhūstūraḥ": ['ap90'],
    "dhūta": ['ap90', 'mw'],
    "dhūtaguṇa": ['bhs', 'mw'],
    "dhūtakalmaṣa": ['mw'],
    "dhūtapāpa": ['mw'],
    "dhūtapāpaka": ['mw'],
    "dhūtapāpatīrtha": ['mw'],
    "dhūtapāpeśvaratīrtha": ['mw'],
    "dhūtapāpman": ['mw'],
    "dhūtapāpā": ['mw'],
    "dhūtarajas": ['bhs'],
    "dhūti": ['cae', 'ddsa', 'gra', 'mw'],
    "dhūtiḥ": ['ap90'],
    "dhūtkāra": ['mw'],
    "dhūtā": ['cae', 'mw'],
    "dhūś": ['ap90', 'mw'],
    "dhūḥ": ['ap90'],
    "dhūṇa": ['mw'],
    "dhūṣ": ['mw'],
    "dhūṣara": ['mw'],
    "dhṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhṛj": ['ap90', 'mw'],
    "dhṛk": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhṛt": ['ap90', 'ddsa', 'mw'],
    "dhṛta": ['ap90', 'cae', 'mw'],
    "dhṛtacāpa": ['mw'],
    "dhṛtadakṣa": ['gra', 'mw'],
    "dhṛtadaṇḍa": ['cae', 'mw'],
    "dhṛtadevā": ['mw'],
    "dhṛtadevī": ['mw'],
    "dhṛtadhanus": ['cae', 'mw'],
    "dhṛtadvaidhībhāva": ['cae', 'mw'],
    "dhṛtadīdhiti": ['mw'],
    "dhṛtagarbhā": ['mw'],
    "dhṛtahavya": ['mw'],
    "dhṛtaheti": ['mw'],
    "dhṛtaikaveṇi": ['mw'],
    "dhṛtaka": ['mw'],
    "dhṛtakanakamāla": ['ddsa', 'mw'],
    "dhṛtaketu": ['mw'],
    "dhṛtakleśa": ['mw'],
    "dhṛtakārmukeṣu": ['mw'],
    "dhṛtam": ['mw'],
    "dhṛtamatiteja": ['bhs'],
    "dhṛtamatī": ['mw'],
    "dhṛtaniścaya": ['cae', 'mw'],
    "dhṛtapaṭa": ['mw'],
    "dhṛtapraja": ['cae', 'mw'],
    "dhṛtapūrva": ['cae', 'mw'],
    "dhṛtarājan": ['mw'],
    "dhṛtarājya": ['bhs'],
    "dhṛtarāṣṭra": ['bhs', 'cae', 'mw'],
    "dhṛtarāṣṭragati": ['bhs'],
    "dhṛtarāṣṭraja": ['mw'],
    "dhṛtarāṣṭrānuja": ['mw'],
    "dhṛtarāṣṭrī": ['mw'],
    "dhṛtasaṃdhi": ['mw'],
    "dhṛtasaṃkalpa": ['cae', 'mw'],
    "dhṛtasiṃha": ['mw'],
    "dhṛtatāla": ['mw'],
    "dhṛtavarman": ['mw'],
    "dhṛtavat": ['mw'],
    "dhṛtavatī": ['mw'],
    "dhṛtavrata": ['cae', 'gra', 'mw'],
    "dhṛtaśarīra": ['cae', 'mw'],
    "dhṛtaśrī": ['mw'],
    "dhṛteṣudhi": ['mw'],
    "dhṛti": ['cae', 'ddsa', 'gra', 'mw'],
    "dhṛtigṛhīta": ['cae', 'mw'],
    "dhṛtimant": ['bhs', 'cae'],
    "dhṛtimat": ['ap90', 'ddsa', 'mw'],
    "dhṛtimattā": ['mw'],
    "dhṛtimatī": ['mw'],
    "dhṛtimaya": ['mw'],
    "dhṛtimuṣ": ['cae', 'mw'],
    "dhṛtimālin": ['mw'],
    "dhṛtipada": ['bhs'],
    "dhṛtiparipūrṇa": ['bhs', 'mw'],
    "dhṛtiparītātman": ['mw'],
    "dhṛtipuṣpa": ['cae'],
    "dhṛtisiṃha": ['mw'],
    "dhṛtiyoga": ['mw'],
    "dhṛtiḥ": ['ap90'],
    "dhṛtiṣeṇa": ['mw'],
    "dhṛtotseka": ['mw'],
    "dhṛtvan": ['ap90', 'mw'],
    "dhṛtvarī": ['ap90', 'mw'],
    "dhṛtvā": ['mw'],
    "dhṛtāmbhas": ['mw'],
    "dhṛtārcis": ['mw'],
    "dhṛtātapatra": ['mw'],
    "dhṛtātman": ['cae', 'ddsa', 'mw'],
    "dhṛñj": ['mw'],
    "dhṛṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhṛṣad": ['gra', 'mw'],
    "dhṛṣadvarṇa": ['gra', 'mw'],
    "dhṛṣadvin": ['cae', 'gra', 'mw'],
    "dhṛṣaj": ['cae', 'gra', 'mw'],
    "dhṛṣanmanas": ['gra', 'mw'],
    "dhṛṣant": ['cae'],
    "dhṛṣat": ['mw'],
    "dhṛṣatā": ['mw'],
    "dhṛṣita": ['ap90', 'cae', 'mw'],
    "dhṛṣitā": ['mw'],
    "dhṛṣu": ['ap90', 'mw'],
    "dhṛṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhṛṣāṇa": ['mw'],
    "dhṛṣṇa": ['mw'],
    "dhṛṣṇaj": ['ap90', 'mw'],
    "dhṛṣṇi": ['mw'],
    "dhṛṣṇiḥ": ['ap90'],
    "dhṛṣṇokta": ['mw'],
    "dhṛṣṇu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dhṛṣṇuka": ['mw'],
    "dhṛṣṇuojas": ['gra'],
    "dhṛṣṇutva": ['mw'],
    "dhṛṣṇuyā": ['cae', 'ddsa', 'mw'],
    "dhṛṣṇuṣeṇa": ['cae', 'gra', 'mw'],
    "dhṛṣṇvojas": ['cae', 'gra', 'mw'],
    "dhṛṣṭa": ['ap90', 'cae', 'mw'],
    "dhṛṣṭabuddhi": ['mw'],
    "dhṛṣṭadhī": ['mw'],
    "dhṛṣṭadyumna": ['cae', 'mw'],
    "dhṛṣṭaka": ['mw'],
    "dhṛṣṭakakathā": ['mw'],
    "dhṛṣṭaketu": ['cae', 'ddsa', 'mw'],
    "dhṛṣṭam": ['mw'],
    "dhṛṣṭamānin": ['mw'],
    "dhṛṣṭaparākrama": ['mw'],
    "dhṛṣṭaratha": ['mw'],
    "dhṛṣṭatama": ['mw'],
    "dhṛṣṭatva": ['mw'],
    "dhṛṣṭatā": ['mw'],
    "dhṛṣṭavādin": ['mw'],
    "dhṛṣṭaśarman": ['mw'],
    "dhṛṣṭi": ['ap90', 'cae', 'ddsa', 'mw'],
    "dhṛṣṭokta": ['mw'],
    "dhṛṣṭā": ['mw'],
    "dhṝ": ['mw'],
    "dibba": ['cped'],
    "dibbacakkhu": ['cped'],
    "dibbacakkhuka": ['cped'],
    "dibbasota": ['cped'],
    "dibbasotadhātu": ['cped'],
    "dibbati": ['cped'],
    "dibbaṁ cakkhu": ['cped'],
    "dibbā sotadhātu": ['cped'],
    "dibya": ['cped'],
    "dicchati": ['cped'],
    "didambhiṣu": ['mw'],
    "diddha": ['cped'],
    "diddhagada": ['cped'],
    "diddhagata": ['cped'],
    "diddibha": ['mw'],
    "diddā": ['ddsa', 'mw'],
    "diddākṣema": ['mw'],
    "diddāpura": ['mw'],
    "diddāpāla": ['mw'],
    "diddāsvāmin": ['mw'],
    "dideviṣu": ['mw'],
    "didhakṣ": ['mw'],
    "didhakṣu": ['mw'],
    "didhakṣā": ['cae', 'ddsa', 'mw'],
    "didhi": ['mw'],
    "didhikṣ": ['mw'],
    "didhiḥ": ['ap90'],
    "didhiṣu": ['cae', 'ddsa', 'gra', 'mw'],
    "didhiṣuḥ": ['ap90'],
    "didhiṣāyia": ['gra'],
    "didhiṣāyya": ['ap90', 'gra', 'mw'],
    "didhiṣūpapati": ['mw'],
    "didhiṣūpati": ['cae', 'mw'],
    "didhiṣūḥ": ['ap90'],
    "didhīrṣā": ['ap90', 'mw'],
    "didhīṣu": ['mw'],
    "didhīṣūḥ": ['ap90'],
    "diditsu": ['mw'],
    "didivi": ['mw'],
    "didyotiṣu": ['mw'],
    "didyu": ['cae', 'gra', 'mw'],
    "didyut": ['cae', 'ddsa', 'gra', 'mw'],
    "didyuḥ": ['ap90'],
    "didī": ['ddsa'],
    "didīvi": ['mw'],
    "didṛkṣeya": ['cae', 'gra', 'mw'],
    "didṛkṣeṇya": ['cae', 'gra', 'mw'],
    "didṛkṣita": ['mw'],
    "didṛkṣitṛ": ['mw'],
    "didṛkṣu": ['ddsa', 'gra', 'mw'],
    "didṛkṣuka": ['bhs'],
    "didṛkṣā": ['cae', 'ddsa', 'mw'],
    "didṛkṣāvat": ['mw'],
    "dig": ['mw'],
    "digadhipa": ['cae', 'ddsa', 'mw'],
    "digambara": ['cae', 'mw'],
    "digambaratva": ['ddsa', 'mw'],
    "digambarī": ['mw'],
    "diganta": ['cae', 'mw'],
    "digantara": ['cae', 'mw'],
    "digavasthāna": ['mw'],
    "digaṅganā": ['mw'],
    "digbandha": ['mw'],
    "digbheda": ['mw'],
    "digbhrama": ['mw'],
    "digbhāga": ['cae', 'ddsa', 'mw'],
    "digdaivata": ['mw'],
    "digdantin": ['mw'],
    "digdarśana": ['mw'],
    "digdarśin": ['mw'],
    "digdevatā": ['cae', 'mw'],
    "digdeśa": ['cae', 'mw'],
    "digdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "digdhahasta": ['mw'],
    "digdhahata": ['mw'],
    "digdhaphala": ['mw'],
    "digdhasahaśaya": ['mw'],
    "digdhaviddha": ['mw'],
    "digdhāṅga": ['mw'],
    "digdāha": ['cae', 'mw'],
    "diggaja": ['cae', 'ddsa', 'mw'],
    "diggrahaṇa": ['mw'],
    "digibha": ['mw'],
    "digjaya": ['cae', 'mw'],
    "digjyā": ['mw'],
    "diglābha": ['mw'],
    "digmaṇḍala": ['mw'],
    "dignāga": ['bhs', 'mw'],
    "diguṇa": ['cped'],
    "digvadhū": ['mw'],
    "digvairocanamakuṭa": ['bhs'],
    "digvakrasaṃstha": ['mw'],
    "digvalaya": ['mw'],
    "digvasana": ['cae', 'mw'],
    "digvastra": ['mw'],
    "digvibhāga": ['cae', 'mw'],
    "digvibhāvita": ['mw'],
    "digvidhāna": ['mw'],
    "digvidikstha": ['mw'],
    "digvijaya": ['cae', 'mw'],
    "digvijayakrama": ['mw'],
    "digvilokana": ['mw'],
    "digvilokita": ['bhs'],
    "digvirati": ['mw'],
    "digvrata": ['mw'],
    "digvyāghāraṇa": ['mw'],
    "digvyāpin": ['mw'],
    "digvāraṇa": ['mw'],
    "digvāsas": ['cae', 'mw'],
    "digyātrā": ['mw'],
    "digāgata": ['mw'],
    "digīśa": ['cae', 'mw'],
    "digīśvara": ['cae', 'mw'],
    "dih": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dihlā": ['mw'],
    "dija": ['cped'],
    "dik": ['mw'],
    "dikam": ['mw'],
    "dikcakra": ['cae', 'mw'],
    "dikcakravāla": ['cae', 'mw'],
    "dikchabda": ['cae', 'mw'],
    "dikka": ['cae', 'ddsa', 'mw'],
    "dikkanyā": ['ddsa', 'mw'],
    "dikkara": ['mw'],
    "dikkaravāsinī": ['mw'],
    "dikkarika": ['mw'],
    "dikkarikā": ['mw'],
    "dikkarin": ['cae', 'mw'],
    "dikkarī": ['mw'],
    "dikkaḥ": ['ap90'],
    "dikkumāra": ['mw'],
    "dikkuñjara": ['cae', 'mw'],
    "dikkāminī": ['mw'],
    "dikkāntā": ['mw'],
    "dikpatha": ['cae', 'mw'],
    "dikpati": ['cae', 'mw'],
    "dikpravibhāga": ['mw'],
    "dikprekṣaṇa": ['mw'],
    "dikpāla": ['cae', 'mw'],
    "dikpālastuti": ['mw'],
    "diksama": ['mw'],
    "diksrakti": ['mw'],
    "diksudṛś": ['mw'],
    "diksundarī": ['mw'],
    "diksvāmin": ['mw'],
    "diksādhanayantra": ['mw'],
    "diksāmya": ['mw'],
    "diktas": ['mw'],
    "diktaṭa": ['mw'],
    "diktulya": ['mw'],
    "diktulyatā": ['mw'],
    "dikśūla": ['mw'],
    "dikśūlalakṣaṇa": ['mw'],
    "dikṣiṣu": ['bhs'],
    "dilha": ['ddsa', 'mw'],
    "dilīpa": ['cae', 'ddsa', 'mw'],
    "dilīpasūnu": ['cae'],
    "dilīpaḥ": ['ap90'],
    "dilīra": ['mw'],
    "dilīraṃ": ['ap90'],
    "dimbh": ['mw'],
    "dimp": ['mw'],
    "dina": ['cae', 'ddsa', 'gra', 'mw'],
    "dinabala": ['mw'],
    "dinabandhu": ['mw'],
    "dinabhartṛ": ['cae', 'mw'],
    "dinacaryā": ['mw'],
    "dinacchidrā": ['mw'],
    "dinaduḥkhita": ['mw'],
    "dinagaṇa": ['mw'],
    "dinagaṇita": ['mw'],
    "dinagraha": ['mw'],
    "dinaika": ['mw'],
    "dinajyotis": ['mw'],
    "dinakara": ['cae', 'mw'],
    "dinakarabhaṭṭa": ['mw'],
    "dinakarabhaṭṭīya": ['mw'],
    "dinakaradeva": ['mw'],
    "dinakaratanaya": ['mw'],
    "dinakaraṭippanī": ['mw'],
    "dinakaroddyota": ['mw'],
    "dinakartavya": ['cae', 'mw'],
    "dinakartṛ": ['cae', 'mw'],
    "dinakarātmaja": ['mw'],
    "dinakarī": ['mw'],
    "dinakarīya": ['mw'],
    "dinakesara": ['mw'],
    "dinakeśava": ['mw'],
    "dinakārya": ['cae', 'mw'],
    "dinakṛddivasa": ['mw'],
    "dinakṛt": ['mw'],
    "dinakṛtsuta": ['mw'],
    "dinakṛtya": ['mw'],
    "dinakṣaya": ['cae', 'mw'],
    "dinamala": ['mw'],
    "dinamaṇi": ['cae', 'mw'],
    "dinamaṇisārathi": ['mw'],
    "dinammanyā": ['mw'],
    "dinamukha": ['cae', 'mw'],
    "dinamūrdhan": ['mw'],
    "dinanaktam": ['cae', 'mw'],
    "dinaniś": ['cae', 'mw'],
    "dinanātha": ['cae', 'mw'],
    "dinapa": ['mw'],
    "dinapati": ['cae', 'mw'],
    "dinaprabhā": ['mw'],
    "dinapraṇī": ['mw'],
    "dinapākin": ['mw'],
    "dinapāṭikā": ['mw'],
    "dinaratna": ['mw'],
    "dinarāja": ['mw'],
    "dinarāśi": ['mw'],
    "dinasaṃcaya": ['mw'],
    "dinaspṛś": ['mw'],
    "dinaugha": ['mw'],
    "dinavyāsadala": ['mw'],
    "dinavāra": ['mw'],
    "dinaḥ": ['ap90'],
    "dindima": ['cped', 'mw'],
    "dineśa": ['cae', 'ddsa', 'mw'],
    "dineśvara": ['cae', 'mw'],
    "dineśātmaja": ['mw'],
    "dinikā": ['ap90', 'mw'],
    "dinna": ['bhs', 'cped', 'mw'],
    "dinnapāṭikaṅkhi(n)": ['cped'],
    "dinnasūri": ['mw'],
    "dinnādāyī(n)": ['cped'],
    "dinnāgrāma": ['ddsa', 'mw'],
    "dinodaya": ['cae', 'ddsa', 'mw'],
    "dinopavāsin": ['mw'],
    "dinv": ['ap90', 'mw'],
    "dinādhinātha": ['cae', 'mw'],
    "dinādhīśa": ['cae', 'mw'],
    "dinādi": ['mw'],
    "dināgama": ['ddsa', 'mw'],
    "dinānta": ['cae', 'mw'],
    "dināntaka": ['mw'],
    "dinārambha": ['mw'],
    "dinārdha": ['cae', 'mw'],
    "dināstra": ['mw'],
    "dinātyaya": ['mw'],
    "dināvasāna": ['cae', 'mw'],
    "dināṃśa": ['mw'],
    "dināṃśaka": ['mw'],
    "dināṇḍa": ['mw'],
    "dinīkṛ": ['mw'],
    "dio": ['gra'],
    "diotana": ['gra'],
    "dip": ['mw'],
    "dipada": ['cped'],
    "dippati": ['cped'],
    "dipsu": ['cae', 'ddsa', 'gra', 'mw'],
    "dipādaka": ['cped'],
    "dir": ['gra', 'mw'],
    "diripaka": ['mw'],
    "diripakaḥ": ['ap90'],
    "disa": ['cped'],
    "disati": ['cped'],
    "disaṅgamika": ['cped'],
    "disaṅgamiya": ['cped'],
    "disaṅgata": ['cped'],
    "disodisaṁ": ['cped'],
    "dissamāna": ['cped'],
    "dissate": ['cped'],
    "dissati": ['cped'],
    "disvā": ['cped'],
    "disvāna": ['cped'],
    "disvānaṁ": ['cped'],
    "disā": ['cped'],
    "disādāha": ['cped'],
    "disāpāmokkha": ['cped'],
    "disāḍāha": ['cped'],
    "dita": ['ap90', 'ddsa', 'mw'],
    "diti": ['cae', 'ddsa', 'gra', 'mw'],
    "ditija": ['cae', 'ddsa', 'mw'],
    "ditijārāti": ['mw'],
    "ditinandana": ['mw'],
    "ditisuta": ['mw'],
    "ditisutaguru": ['mw'],
    "dititanaya": ['mw'],
    "ditiḥ": ['ap90'],
    "ditsita": ['mw'],
    "ditsu": ['ap90', 'gra', 'mw'],
    "ditsya": ['mw'],
    "ditsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "ditta": ['cped'],
    "ditya": ['mw'],
    "dityauhī": ['mw'],
    "dityavah": ['cae', 'ddsa', 'mw'],
    "dityaḥ": ['ap90'],
    "div": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "diva": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "divadarśa": ['mw'],
    "divakṣas": ['gra', 'mw'],
    "divan": ['ap90', 'mw'],
    "divaratha": ['mw'],
    "divas": ['mw'],
    "divasa": ['cae', 'cped', 'ddsa', 'mw'],
    "divasabhartṛ": ['mw'],
    "divasacara": ['cae', 'mw'],
    "divasacarā": ['bhs'],
    "divasacchidra": ['mw'],
    "divasakara": ['cae', 'ddsa', 'mw'],
    "divasakriyā": ['mw'],
    "divasakṛt": ['cae', 'mw'],
    "divasakṣaya": ['cae', 'mw'],
    "divasam": ['bhs'],
    "divasamudrā": ['mw'],
    "divasamukha": ['cae', 'mw'],
    "divasanirīkṣaka": ['bhs', 'mw'],
    "divasanātha": ['cae', 'mw'],
    "divasatithi": ['mw'],
    "divasavigama": ['mw'],
    "divasavyāpāra": ['mw'],
    "divasavāra": ['mw'],
    "divasaḥ": ['ap90'],
    "divasaṁ": ['cped'],
    "divaseśvara": ['cae', 'ddsa', 'mw'],
    "divaspati": ['cae', 'ddsa', 'mw'],
    "divaspṛthivyau": ['mw'],
    "divaspṛthivī": ['cae'],
    "divaspṛś": ['ddsa', 'mw'],
    "divastambhana": ['mw'],
    "divasāntara": ['mw'],
    "divasānudivasam": ['bhs'],
    "divasātyaya": ['mw'],
    "divasāvasāna": ['mw'],
    "divasīkṛ": ['cae', 'ddsa', 'mw'],
    "divaukas": ['cae', 'ddsa', 'mw'],
    "divaukasa": ['bhs', 'mw'],
    "divaukaḥpati": ['mw'],
    "divaḍḍha": ['cped'],
    "divaḥśyenī": ['mw'],
    "divaṃ": ['ap90'],
    "divaṃgama": ['cae', 'mw'],
    "divaṅgama": ['ddsa'],
    "divi": ['mw'],
    "divia": ['gra'],
    "divicara": ['cae', 'mw'],
    "divicārin": ['cae', 'mw'],
    "dividhuvaka": ['mw'],
    "divigamana": ['mw'],
    "divigamanaratna": ['mw'],
    "divigata": ['ddsa', 'mw'],
    "divija": ['cae', 'mw'],
    "divijā": ['cae', 'gra', 'mw'],
    "divijāta": ['mw'],
    "divikṣaya": ['cae', 'gra', 'mw'],
    "divikṣit": ['cae', 'gra', 'mw'],
    "divira": ['ddsa', 'mw'],
    "divirakiśora": ['mw'],
    "diviratha": ['mw'],
    "divisad": ['mw'],
    "divispṛś": ['cae', 'ddsa', 'gra', 'mw'],
    "divispṛśant": ['cae'],
    "divispṛśat": ['mw'],
    "divit": ['cae', 'gra', 'mw'],
    "divitmant": ['cae'],
    "divitmat": ['gra', 'mw'],
    "divitmatā": ['mw'],
    "diviya": ['cped'],
    "diviyaj": ['gra', 'mw'],
    "diviyoni": ['gra', 'mw'],
    "diviśrit": ['mw'],
    "diviḥ": ['ap90'],
    "diviṃ": ['bhs'],
    "diviṣad": ['cae', 'ddsa', 'mw'],
    "diviṣadadhvan": ['mw'],
    "diviṣṭambha": ['mw'],
    "diviṣṭha": ['cae', 'mw'],
    "diviṣṭi": ['cae', 'gra', 'mw'],
    "divo": ['mw'],
    "divodbhava": ['mw'],
    "divodbhavā": ['mw'],
    "divoduh": ['mw'],
    "divodāsa": ['cae', 'ddsa', 'gra', 'mw'],
    "divodāseśvaraliṅga": ['mw'],
    "divodāsopākhyāna": ['mw'],
    "divojā": ['cae', 'gra', 'mw'],
    "divokas": ['mw'],
    "divolkā": ['mw'],
    "divoruc": ['gra', 'mw'],
    "divya": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "divyacakṣus": ['cae', 'mw'],
    "divyadarśana": ['cae', 'mw'],
    "divyadarśin": ['cae', 'mw'],
    "divyadeha": ['mw'],
    "divyadevī": ['mw'],
    "divyadharmin": ['mw'],
    "divyadohada": ['mw'],
    "divyadṛś": ['cae', 'mw'],
    "divyadṛṣṭi": ['mw'],
    "divyagandha": ['mw'],
    "divyagandhā": ['mw'],
    "divyagāyana": ['mw'],
    "divyajñāna": ['cae', 'mw'],
    "divyaka": ['mw'],
    "divyakaṭa": ['mw'],
    "divyakriyā": ['ddsa', 'mw'],
    "divyakuṇḍa": ['mw'],
    "divyakālinī": ['mw'],
    "divyakānana": ['mw'],
    "divyakānanadarśana": ['mw'],
    "divyakārin": ['mw'],
    "divyalatā": ['mw'],
    "divyamantra": ['mw'],
    "divyamāna": ['mw'],
    "divyamānuṣa": ['mw'],
    "divyanadī": ['mw'],
    "divyanārī": ['cae', 'mw'],
    "divyapañcāmṛta": ['mw'],
    "divyaprabhāva": ['mw'],
    "divyaprajñāna": ['mw'],
    "divyaprajñānaśālin": ['mw'],
    "divyapraśna": ['mw'],
    "divyapuruṣa": ['mw'],
    "divyapuṣpa": ['mw'],
    "divyapuṣpikā": ['mw'],
    "divyapuṣpā": ['mw'],
    "divyapāṭala": ['mw'],
    "divyarasa": ['mw'],
    "divyarasendrasāra": ['mw'],
    "divyaratha": ['mw'],
    "divyaratna": ['mw'],
    "divyarūpa": ['cae', 'mw'],
    "divyarūpin": ['cae', 'mw'],
    "divyasaṃgraha": ['mw'],
    "divyasaṃkāśa": ['cae', 'mw'],
    "divyasraganulepin": ['mw'],
    "divyastrī": ['cae', 'mw'],
    "divyasānu": ['mw'],
    "divyasāra": ['mw'],
    "divyasūri": ['mw'],
    "divyasūricarita": ['mw'],
    "divyasūriprabhāvadīpikā": ['mw'],
    "divyatattva": ['mw'],
    "divyatejas": ['mw'],
    "divyatumbī": ['mw'],
    "divyatva": ['mw'],
    "divyatā": ['cae', 'mw'],
    "divyaugha": ['mw'],
    "divyauṣadha": ['cae', 'mw'],
    "divyauṣadhi": ['mw'],
    "divyavarmabhṛt": ['cae', 'mw'],
    "divyavastra": ['mw'],
    "divyavijñānavant": ['cae'],
    "divyavijñānavat": ['mw'],
    "divyavākya": ['mw'],
    "divyayamunā": ['mw'],
    "divyaśrotra": ['mw'],
    "divyelaka": ['mw'],
    "divyodaka": ['mw'],
    "divyonmāda": ['mw'],
    "divyopapāduka": ['mw'],
    "divyā": ['mw'],
    "divyādivya": ['mw'],
    "divyādivyā": ['mw'],
    "divyākṛti": ['cae', 'ddsa', 'mw'],
    "divyānnada": ['bhs'],
    "divyāstra": ['cae'],
    "divyāvadāna": ['bhs', 'mw'],
    "divyāṃśu": ['mw'],
    "divyāṅganā": ['mw'],
    "divā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "divābhīta": ['ddsa', 'mw'],
    "divābhīti": ['mw'],
    "divābhūta": ['mw'],
    "divācara": ['cae', 'mw'],
    "divācārin": ['cae', 'mw'],
    "divādi": ['ddsa', 'mw'],
    "divādivassa": ['cped'],
    "divāgaṇa": ['mw'],
    "divākara": ['cae', 'ddsa', 'mw'],
    "divākaramitra": ['mw'],
    "divākarasuta": ['mw'],
    "divākarasutā": ['mw'],
    "divākaravaralocana": ['mw'],
    "divākaravatsa": ['mw'],
    "divākaroddyota": ['mw'],
    "divākīrti": ['cae', 'mw'],
    "divākīrtya": ['cae', 'mw'],
    "divākṛta": ['mw'],
    "divāmadhya": ['mw'],
    "divāmaithunin": ['mw'],
    "divāmanya": ['mw'],
    "divāmaṇi": ['mw'],
    "divānaktam": ['cae', 'ddsa', 'mw'],
    "divāndha": ['cae', 'ddsa', 'mw'],
    "divāndhakī": ['mw'],
    "divāndhā": ['mw'],
    "divānidrā": ['mw'],
    "divāniśam": ['cae', 'mw'],
    "divāpati": ['mw'],
    "divāpradīpa": ['mw'],
    "divāpuṣṭa": ['mw'],
    "divārattiṁ": ['cped'],
    "divārka": ['mw'],
    "divārātram": ['cae', 'ddsa', 'mw'],
    "divāsaṃcara": ['mw'],
    "divāsaṃketa": ['cae', 'mw'],
    "divāseyyā": ['cped'],
    "divāsoppa": ['cped'],
    "divāsthāna": ['mw'],
    "divāsupta": ['mw'],
    "divāsvapana": ['mw'],
    "divāsvapna": ['mw'],
    "divāsvāpa": ['mw'],
    "divāsvāpā": ['mw'],
    "divātana": ['ap90', 'cae', 'ddsa', 'mw'],
    "divātara": ['gra', 'mw'],
    "divātaraṁ": ['cped'],
    "divātithi": ['ddsa', 'mw'],
    "divāvasu": ['gra', 'mw'],
    "divāvasāna": ['mw'],
    "divāvihāra": ['bhs', 'cped', 'mw'],
    "divāśaya": ['mw'],
    "divāśayatā": ['mw'],
    "divāśayyā": ['mw'],
    "divī": ['mw'],
    "divīśa": ['mw'],
    "diya": ['gra', 'mw'],
    "diyaḍḍha": ['cped'],
    "diyyamāna": ['cped'],
    "diyyati": ['cped'],
    "diś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "diśa": ['bhs'],
    "diśabhedajñānaprabhaketumati": ['bhs'],
    "diśadeśaāmukhajaga": ['bhs'],
    "diśam": ['mw'],
    "diśas": ['mw'],
    "diśasaṃbhava": ['bhs'],
    "diśati": ['bhs'],
    "diśatā": ['bhs'],
    "diśi": ['bhs'],
    "diśo": ['mw'],
    "diśobhāga": ['mw'],
    "diśobhāj": ['ap90', 'ddsa', 'mw'],
    "diśodaṇḍa": ['mw'],
    "diśodāha": ['bhs', 'mw'],
    "diśoyāyin": ['mw'],
    "diśya": ['ap90', 'cae', 'ddsa', 'mw'],
    "diśyā": ['mw'],
    "diśā": ['ap90', 'cae', 'mw'],
    "diśācakṣus": ['mw'],
    "diśāgaja": ['mw'],
    "diśāna": ['mw'],
    "diśāpāla": ['mw'],
    "diśāṃpati": ['bhs'],
    "diṃp": ['ap90'],
    "diṃḍiḥ": ['ap90'],
    "diṅ": ['mw'],
    "diṅka": ['mw'],
    "diṅmaṇḍala": ['cae', 'mw'],
    "diṅmoha": ['mw'],
    "diṅmukha": ['cae', 'mw'],
    "diṅmukhamaṇḍala": ['mw'],
    "diṅmārga": ['mw'],
    "diṅmātaṅga": ['mw'],
    "diṅmātra": ['cae', 'mw'],
    "diṅmūḍha": ['mw'],
    "diṅnāga": ['bhs', 'cae', 'ddsa', 'mw'],
    "diṅnātha": ['cae', 'mw'],
    "diṇḍi": ['mw'],
    "diṇḍin": ['mw'],
    "diṇḍīra": ['mw'],
    "diṇḍīya": ['mw'],
    "diṇṇa": ['mw'],
    "diṣṇu": ['mw'],
    "diṣṇuḥ": ['ap90'],
    "diṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "diṣṭabhuj": ['mw'],
    "diṣṭabhāva": ['mw'],
    "diṣṭadṛś": ['mw'],
    "diṣṭagamana": ['mw'],
    "diṣṭakārin": ['mw'],
    "diṣṭapara": ['mw'],
    "diṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "diṣṭivṛddhi": ['ddsa', 'mw'],
    "diṣṭiḥ": ['ap90'],
    "diṣṭyā": ['ap90'],
    "diṣṭānta": ['cae', 'mw'],
    "diṭṭha": ['cped'],
    "diṭṭhadhamma": ['cped'],
    "diṭṭhadhammanibbāna": ['cped'],
    "diṭṭhadhammasukha": ['cped'],
    "diṭṭhadhammika": ['cped'],
    "diṭṭhadhammābhinibbuta": ['cped'],
    "diṭṭhapubba": ['cped'],
    "diṭṭhe (va) dhamme": ['cped'],
    "diṭṭheyya": ['cped'],
    "diṭṭhi": ['cped'],
    "diṭṭhigata": ['cped'],
    "diṭṭhinijjhānakkhanti": ['cped'],
    "diṭṭhinipātta": ['cped'],
    "diṭṭhipatta": ['cped'],
    "diṭṭhiyā": ['cped'],
    "diṭṭhiyāyaka": ['cped'],
    "diṭṭhupādāna": ['cped'],
    "diṭṭhā": ['cped'],
    "diṭṭhānugati": ['cped'],
    "diṭṭhānusaya": ['cped'],
    "diṭṭhāvikamma": ['cped'],
    "diṭṭhūpādāna": ['cped'],
    "do": ['ap90', 'mw'],
    "dodha": ['mw'],
    "dodhaka": ['cae', 'ddsa', 'mw'],
    "dodhakavṛtta": ['mw'],
    "dodhakaśokaṭīkā": ['mw'],
    "dodhat": ['gra', 'mw'],
    "dodhataḥ": ['ddsa'],
    "dodhūyamāna": ['mw'],
    "dodulyamāna": ['mw'],
    "doga": ['mw'],
    "dogdhavya": ['ddsa', 'mw'],
    "dogdhos": ['mw'],
    "dogdhra": ['cae', 'mw'],
    "dogdhrī": ['ap90', 'mw'],
    "dogdhukāma": ['mw'],
    "dogdhṛ": ['ap90', 'cae', 'mw'],
    "dogha": ['ap90', 'cae', 'gra', 'mw'],
    "doghaḥ": ['ap90'],
    "doha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dohada": ['cae', 'ddsa', 'mw'],
    "dohadaduḥkhaśīlatā": ['mw'],
    "dohadalakṣaṇa": ['mw'],
    "dohadaprakāra": ['mw'],
    "dohadavatī": ['ap90', 'mw'],
    "dohadaḥ": ['ap90'],
    "dohadin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dohadānvitā": ['mw'],
    "dohaja": ['mw'],
    "dohaka": ['mw'],
    "dohakāma": ['mw'],
    "dohala": ['cae', 'cped', 'ddsa', 'mw'],
    "dohalaka": ['bhs'],
    "dohalavatī": ['mw'],
    "dohalaḥ": ['ap90'],
    "dohalin": ['mw'],
    "dohalī": ['ap90'],
    "dohana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dohanī": ['mw'],
    "dohanīya": ['mw'],
    "dohas": ['cae', 'ddsa', 'gra', 'mw'],
    "dohati": ['cped'],
    "dohaḍikā": ['mw'],
    "dohaḥ": ['ap90'],
    "dohaḷa": ['cped'],
    "dohin": ['mw'],
    "dohita": ['ap90', 'mw'],
    "dohya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dohā": ['mw'],
    "dohādohīya": ['mw'],
    "dohāpanaya": ['mw'],
    "dohāpeti": ['cped'],
    "dohīyas": ['mw'],
    "dola": ['cae', 'ddsa', 'mw'],
    "dolamaṇḍapa": ['mw'],
    "dolaparvata": ['mw'],
    "dolayāna": ['mw'],
    "dolayātrā": ['mw'],
    "dolaḥ": ['ap90'],
    "dolikā": ['ap90', 'mw'],
    "dolita": ['mw'],
    "dolotsava": ['cae', 'ddsa'],
    "dolā": ['ap90', 'mw'],
    "dolācalacittavṛtti": ['mw'],
    "dolādhirūḍha": ['mw'],
    "dolādolotsava": ['mw'],
    "dolādri": ['mw'],
    "dolāghara": ['cae', 'mw'],
    "dolāgharaka": ['cae', 'mw'],
    "dolākuladhī": ['mw'],
    "dolālola": ['mw'],
    "dolāndolana": ['mw'],
    "dolārohaṇapaddhati": ['mw'],
    "dolārūḍha": ['cae', 'mw'],
    "dolāy": ['cae'],
    "dolāya": ['ddsa', 'mw'],
    "dolāyamāna": ['ap90', 'mw'],
    "dolāyamānamati": ['mw'],
    "dolāyantra": ['mw'],
    "dolāyate": ['ap90'],
    "dolāyita": ['ap90', 'mw'],
    "dolāyitaśravaṇakuṇḍala": ['mw'],
    "dolāyuddha": ['ddsa', 'mw'],
    "dolāyātrā": ['mw'],
    "dolāyātrāviveka": ['mw'],
    "doman": ['mw'],
    "domanassa": ['cped'],
    "domanassavedaniya": ['cped'],
    "domanassaṭṭhāniya": ['cped'],
    "domanassindriya": ['cped'],
    "dor": ['mw'],
    "doraka": ['mw'],
    "dorakaṃ": ['ap90'],
    "doraḥ": ['ap90'],
    "dorbāhava": ['mw'],
    "dordaṇḍa": ['cae', 'mw'],
    "dorgaḍu": ['mw'],
    "dorgraha": ['mw'],
    "dorjyā": ['mw'],
    "dorlatikā": ['mw'],
    "dorlatikābhīma": ['mw'],
    "dorlatikādarśanīya": ['mw'],
    "dormadhya": ['mw'],
    "dormūla": ['ddsa', 'mw'],
    "dornikartana": ['mw'],
    "dorviṣāda": ['mw'],
    "dorāndolana": ['mw'],
    "dos": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dosa": ['cped'],
    "dosagaru": ['cped'],
    "dosagati": ['cped'],
    "dosaggi": ['cped'],
    "dosagāmi(n)": ['cped'],
    "dosahetuka": ['cped'],
    "dosaneyya": ['cped'],
    "dosantara": ['cped'],
    "dosanīya": ['cped'],
    "dosapakata": ['cped'],
    "dosinapuṇṇamāsī": ['cped'],
    "dosinā": ['cped'],
    "dosināpunnamāsī": ['cped'],
    "dostha": ['mw'],
    "dosārita": ['cped'],
    "dovacassa": ['cped'],
    "dovacassatā": ['cped'],
    "dovārika": ['cped'],
    "dovāriya": ['cped'],
    "doḍī": ['mw'],
    "doḍḍayācārya": ['mw'],
    "doḥ": ['mw'],
    "doḥsahasrabhṛt": ['mw'],
    "doḥśekhara": ['mw'],
    "doḥśiñjinī": ['mw'],
    "doḥśālin": ['cae', 'ddsa', 'mw'],
    "doḷasa": ['cped'],
    "doḷasaka": ['cped'],
    "doṇa": ['cped'],
    "doṇapāka": ['cped'],
    "doṇī": ['cped'],
    "doṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "doṣabalapravṛtta": ['mw'],
    "doṣabhakti": ['mw'],
    "doṣabheda": ['mw'],
    "doṣabhedīya": ['mw'],
    "doṣabhāj": ['mw'],
    "doṣabhīti": ['mw'],
    "doṣadvaya": ['mw'],
    "doṣadūṣita": ['mw'],
    "doṣadūṣitatva": ['mw'],
    "doṣadṛṣṭi": ['mw'],
    "doṣaghna": ['mw'],
    "doṣagrasta": ['mw'],
    "doṣagrāhin": ['mw'],
    "doṣaguṇa": ['cae', 'mw'],
    "doṣaguṇin": ['mw'],
    "doṣaguṇitva": ['mw'],
    "doṣaguṇīkaraṇa": ['mw'],
    "doṣahara": ['mw'],
    "doṣaikadṛś": ['mw'],
    "doṣajitkāra": ['mw'],
    "doṣajña": ['cae', 'mw'],
    "doṣakalpana": ['mw'],
    "doṣakara": ['ddsa', 'mw'],
    "doṣakaḥ": ['ap90'],
    "doṣakārin": ['mw'],
    "doṣakṛt": ['mw'],
    "doṣala": ['ap90', 'cae', 'ddsa', 'mw'],
    "doṣamaya": ['cae', 'mw'],
    "doṣan": ['ap90', 'cae', 'ddsa', 'mw'],
    "doṣanirghāta": ['mw'],
    "doṣaparihāra": ['mw'],
    "doṣaphala": ['ddsa', 'mw'],
    "doṣaprasaṅga": ['mw'],
    "doṣas": ['ap90', 'cae', 'ddsa', 'mw'],
    "doṣasthāna": ['mw'],
    "doṣatas": ['mw'],
    "doṣatobrū": ['mw'],
    "doṣatraya": ['mw'],
    "doṣatrayaghṇa": ['mw'],
    "doṣatrayahara": ['mw'],
    "doṣatva": ['mw'],
    "doṣavant": ['cae'],
    "doṣavat": ['cae', 'ddsa', 'mw'],
    "doṣaśamana": ['mw'],
    "doṣaḥ": ['ap90'],
    "doṣaṇa": ['mw'],
    "doṣaṇaṃ": ['ap90'],
    "doṣaṇiśriṣ": ['mw'],
    "doṣaṇya": ['cae', 'gra', 'mw'],
    "doṣika": ['ap90', 'mw'],
    "doṣin": ['ap90', 'ddsa', 'mw'],
    "doṣmat": ['ddsa', 'mw'],
    "doṣocchrāya": ['mw'],
    "doṣodaka": ['mw'],
    "doṣoddhāra": ['mw'],
    "doṣollāsa": ['mw'],
    "doṣopacaya": ['mw'],
    "doṣā": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "doṣābhūta": ['mw'],
    "doṣākara": ['cae', 'ddsa', 'mw'],
    "doṣākleśī": ['mw'],
    "doṣākṣara": ['cae', 'ddsa', 'mw'],
    "doṣām": ['mw'],
    "doṣāmanya": ['mw'],
    "doṣānta": ['mw'],
    "doṣānudarśin": ['cae', 'mw'],
    "doṣānuvāda": ['mw'],
    "doṣāpatti": ['mw'],
    "doṣāramaṇa": ['ddsa', 'mw'],
    "doṣāropa": ['mw'],
    "doṣāsya": ['mw'],
    "doṣātana": ['ap90', 'cae', 'ddsa', 'mw'],
    "doṣātilaka": ['mw'],
    "doṣāvastar": ['ddsa'],
    "doṣāvastṛ": ['cae', 'gra', 'mw'],
    "doṣāy": ['cae'],
    "doṣāya": ['ddsa', 'mw'],
    "dra": ['mw'],
    "drabuddha": ['bhs', 'mw'],
    "dradhas": ['cae', 'ddsa', 'mw'],
    "dradula": ['bhs'],
    "dragaḍa": ['mw'],
    "draha": ['mw'],
    "drahaḥ": ['ap90'],
    "drahya": ['mw'],
    "drahyat": ['cae', 'gra', 'mw'],
    "drai": ['ap90', 'mw'],
    "drakaṭa": ['mw'],
    "drakaṭaḥ": ['ap90'],
    "drakṣaṇaṃ": ['ap90'],
    "dram": ['ap90', 'cae', 'ddsa', 'mw'],
    "drama": ['bhs'],
    "dramila": ['cae', 'mw'],
    "dramita": ['mw'],
    "dramiḍa": ['bhs', 'mw'],
    "dramiḍabhāṣya": ['mw'],
    "dramiṭa": ['mw'],
    "dramma": ['ddsa', 'mw'],
    "drammaṃ": ['ap90'],
    "drapsa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "drapsavant": ['cae'],
    "drapsavat": ['mw'],
    "drapsin": ['cae', 'gra', 'mw'],
    "drapsya": ['mw'],
    "draughaṇa": ['mw'],
    "drauhika": ['mw'],
    "drauhiṇya": ['bhs'],
    "drauhya": ['mw'],
    "drauhyava": ['mw'],
    "draupada": ['mw'],
    "draupadeya": ['cae', 'mw'],
    "draupadeyaḥ": ['ap90'],
    "draupadija": ['mw'],
    "draupadāditya": ['mw'],
    "draupadāyani": ['mw'],
    "draupadī": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "draupadīharaṇa": ['mw'],
    "draupadīpariṇayacampū": ['mw'],
    "draupadīpramātha": ['mw'],
    "draupadīsvayaṃvara": ['mw'],
    "draupadīvastrāharaṇa": ['mw'],
    "drauṇa": ['mw'],
    "drauṇeya": ['mw'],
    "drauṇi": ['cae', 'mw'],
    "drauṇika": ['ap90', 'mw'],
    "drauṇāyana": ['mw'],
    "drauṇāyanaḥ": ['ap90'],
    "drauṇāyani": ['mw'],
    "drauṇī": ['ap90', 'mw'],
    "drava": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "dravaccakra": ['gra', 'mw'],
    "dravadaśva": ['gra', 'mw'],
    "dravadravya": ['mw'],
    "dravaja": ['mw'],
    "dravaka": ['ap90', 'mw'],
    "dravamaya": ['cae', 'mw'],
    "dravamāṇa": ['mw'],
    "dravamūrti": ['mw'],
    "dravantī": ['mw'],
    "dravaprāya": ['mw'],
    "dravara": ['cae', 'ddsa', 'gra', 'mw'],
    "dravarasā": ['mw'],
    "dravarāga": ['mw'],
    "dravasveda": ['mw'],
    "dravasya": ['mw'],
    "dravasyati": ['ap90'],
    "dravat": ['cae', 'ddsa', 'gra', 'mw'],
    "dravatpattrī": ['mw'],
    "dravatpāṇi": ['gra', 'mw'],
    "dravatva": ['mw'],
    "dravatvaka": ['mw'],
    "dravatya": ['mw'],
    "dravatā": ['cae', 'ddsa', 'mw'],
    "dravavasu": ['mw'],
    "dravay": ['cae'],
    "dravaya": ['ddsa', 'mw'],
    "dravaṃtī": ['ap90'],
    "dravaṇa": ['cae', 'mw'],
    "dravetara": ['mw'],
    "dravi": ['cae', 'gra', 'mw'],
    "dravitnu": ['cae', 'ddsa', 'gra', 'mw'],
    "dravitṛ": ['cae', 'gra', 'mw'],
    "draviḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "draviḍabhāṣya": ['mw'],
    "draviḍadeśa": ['mw'],
    "draviḍadeśīya": ['mw'],
    "draviḍagauḍaka": ['mw'],
    "draviḍaśiśu": ['mw'],
    "draviḍaḥ": ['ap90'],
    "draviḍopaniṣacchekhara": ['mw'],
    "draviḍopaniṣad": ['mw'],
    "draviḍopaniṣatsāra": ['mw'],
    "draviḍopaniṣatsāraratnāvalīvyākhyā": ['mw'],
    "draviḍopaniṣattātparyaratnāvali": ['mw'],
    "draviḍācārya": ['mw'],
    "draviḍī": ['mw'],
    "draviṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "draviṇaka": ['mw'],
    "draviṇanāśana": ['mw'],
    "draviṇapati": ['mw'],
    "draviṇarāśi": ['ddsa', 'mw'],
    "draviṇas": ['cae', 'gra', 'mw'],
    "draviṇasvat": ['gra', 'mw'],
    "draviṇasyu": ['ap90', 'cae', 'gra', 'mw'],
    "draviṇavat": ['mw'],
    "draviṇaṃ": ['ap90'],
    "draviṇendrātmaja": ['mw'],
    "draviṇeśvara": ['cae', 'mw'],
    "draviṇo": ['mw'],
    "draviṇoda": ['cae', 'ddsa', 'gra', 'mw'],
    "draviṇodas": ['cae', 'gra', 'mw'],
    "draviṇodaya": ['mw'],
    "draviṇodā": ['cae', 'gra', 'mw'],
    "draviṇovid": ['cae', 'gra', 'mw'],
    "draviṇādhipati": ['cae', 'mw'],
    "draviṇāgama": ['mw'],
    "draviṇīya": ['mw'],
    "dravottara": ['mw'],
    "dravya": ['cae', 'ddsa', 'mw'],
    "dravyabhāṣā": ['mw'],
    "dravyabhāṣāṭīkā": ['mw'],
    "dravyadevatā": ['mw'],
    "dravyadvaita": ['mw'],
    "dravyadātṛ": ['cae'],
    "dravyadīpaka": ['mw'],
    "dravyagarvita": ['cae', 'mw'],
    "dravyagaṇa": ['mw'],
    "dravyaguṇa": ['mw'],
    "dravyaguṇadīpikā": ['mw'],
    "dravyaguṇaparyāya": ['mw'],
    "dravyaguṇasaṃgraha": ['mw'],
    "dravyaguṇavicāra": ['mw'],
    "dravyaguṇaviveka": ['mw'],
    "dravyaguṇaśataślokī": ['mw'],
    "dravyaguṇādarśanighaṇṭu": ['mw'],
    "dravyaguṇādhirāja": ['mw'],
    "dravyaguṇākara": ['mw'],
    "dravyahasta": ['cae', 'mw'],
    "dravyajāta": ['cae', 'mw'],
    "dravyaka": ['bhs', 'mw'],
    "dravyakaḥ": ['ap90'],
    "dravyakiraṇāvalī": ['mw'],
    "dravyakṛśa": ['mw'],
    "dravyalakṣaṇa": ['mw'],
    "dravyamaya": ['ap90', 'cae', 'mw'],
    "dravyamātra": ['mw'],
    "dravyanirūpaṇa": ['mw'],
    "dravyaniścaya": ['mw'],
    "dravyapadārtha": ['mw'],
    "dravyaparigraha": ['mw'],
    "dravyapatākā": ['mw'],
    "dravyaprakalpana": ['mw'],
    "dravyaprakarṣa": ['mw'],
    "dravyaprakāśikā": ['mw'],
    "dravyaprakṛti": ['mw'],
    "dravyaprayojana": ['mw'],
    "dravyapūjā": ['mw'],
    "dravyaratnāvali": ['mw'],
    "dravyasamuccaya": ['mw'],
    "dravyasamuddeśa": ['mw'],
    "dravyasaṃcaya": ['mw'],
    "dravyasaṃgraha": ['mw'],
    "dravyasaṃskāra": ['mw'],
    "dravyasiddhi": ['mw'],
    "dravyasārasaṃgraha": ['mw'],
    "dravyatas": ['mw'],
    "dravyatva": ['mw'],
    "dravyatvajātimānavicāra": ['mw'],
    "dravyaugha": ['mw'],
    "dravyavant": ['cae'],
    "dravyavardhana": ['mw'],
    "dravyavat": ['ap90', 'mw'],
    "dravyavattva": ['mw'],
    "dravyavācaka": ['mw'],
    "dravyavādin": ['mw'],
    "dravyavṛddhi": ['cae', 'mw'],
    "dravyayajña": ['cae', 'mw'],
    "dravyaśabda": ['mw'],
    "dravyaśaktimat": ['mw'],
    "dravyaśodhanavidhāna": ['mw'],
    "dravyaśuddhi": ['cae', 'mw'],
    "dravyaśuddhidīpikā": ['mw'],
    "dravyaṃ": ['ap90'],
    "dravyādarśa": ['mw'],
    "dravyāgama": ['ddsa'],
    "dravyāmbara": ['bhs'],
    "dravyāntara": ['mw'],
    "dravyārjana": ['cae', 'mw'],
    "dravyātmaka": ['mw'],
    "dravyātmakāryasiddhi": ['mw'],
    "dravyāśrita": ['cae', 'mw'],
    "dravādhāra": ['mw'],
    "dravī": ['cae', 'mw'],
    "dravībhāva": ['mw'],
    "dravībhū": ['ddsa', 'mw'],
    "dravīkaraṇa": ['mw'],
    "dravīkaroti": ['bhs'],
    "dravīkṛ": ['mw'],
    "draḍhay": ['cae'],
    "draḍhaya": ['ddsa', 'mw'],
    "draḍhayati": ['ap90'],
    "draḍhika": ['ddsa', 'mw'],
    "draḍhiman": ['ap90', 'cae', 'ddsa', 'mw'],
    "draḍhiṣṭha": ['cae', 'mw'],
    "draḍhīyas": ['mw'],
    "draḍhīyaṃs": ['cae'],
    "draṅga": ['bhs', 'cae', 'ddsa', 'mw'],
    "draṅgā": ['mw'],
    "draṅkṣaṇa": ['mw'],
    "draṣṭavya": ['ap90', 'cae', 'ddsa', 'mw'],
    "draṣṭu": ['mw'],
    "draṣṭukāma": ['cae', 'mw'],
    "draṣṭumanas": ['mw'],
    "draṣṭuśakya": ['mw'],
    "draṣṭṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "draṣṭṛtva": ['mw'],
    "drek": ['ap90', 'mw'],
    "drekka": ['mw'],
    "drekkāṇa": ['mw'],
    "drekā": ['cae', 'mw'],
    "dreśya": ['mw'],
    "dreṣkāṇa": ['mw'],
    "dreṣkāṇādhyāya": ['mw'],
    "drimila": ['mw'],
    "drogdhavya": ['ddsa', 'mw'],
    "drogdhṛ": ['ap90', 'cae', 'mw'],
    "drogha": ['cae', 'gra', 'mw'],
    "droghamitra": ['gra', 'mw'],
    "droghavāc": ['gra', 'mw'],
    "droghaḥ": ['ap90'],
    "droha": ['cae', 'ddsa', 'mw'],
    "drohabhāva": ['cae', 'mw'],
    "drohabuddhi": ['mw'],
    "drohacintana": ['mw'],
    "drohapara": ['mw'],
    "drohavacana": ['mw'],
    "drohavṛtti": ['mw'],
    "drohaḥ": ['ap90'],
    "drohin": ['ap90', 'cae', 'ddsa', 'mw'],
    "drohita": ['ap90', 'mw'],
    "drohiṇya": ['bhs'],
    "drohāṭa": ['mw'],
    "dromiṇa": ['mw'],
    "droṇa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "droṇacit": ['mw'],
    "droṇaciti": ['mw'],
    "droṇadugdhā": ['mw'],
    "droṇadughā": ['mw'],
    "droṇagandhikā": ['mw'],
    "droṇaghā": ['mw'],
    "droṇagrāmaka": ['bhs'],
    "droṇaka": ['mw'],
    "droṇakalaśa": ['cae', 'ddsa', 'mw'],
    "droṇakāka": ['bhs', 'mw'],
    "droṇakākala": ['mw'],
    "droṇakṣīrā": ['mw'],
    "droṇamaya": ['mw'],
    "droṇamegha": ['cae', 'mw'],
    "droṇampaca": ['mw'],
    "droṇamukha": ['bhs', 'mw'],
    "droṇamukhya": ['bhs'],
    "droṇamānā": ['mw'],
    "droṇapadī": ['mw'],
    "droṇaparvan": ['mw'],
    "droṇaparṇī": ['mw'],
    "droṇapuṣpa": ['mw'],
    "droṇapuṣpī": ['mw'],
    "droṇaripu": ['mw'],
    "droṇasiṃha": ['mw'],
    "droṇastūpa": ['mw'],
    "droṇasāc": ['gra', 'mw'],
    "droṇavastuka": ['bhs'],
    "droṇavṛṣṭi": ['mw'],
    "droṇaśarmapada": ['mw'],
    "droṇaḥ": ['ap90'],
    "droṇeya": ['mw'],
    "droṇi": ['mw'],
    "droṇia": ['gra'],
    "droṇikā": ['ap90', 'ddsa', 'mw'],
    "droṇiḥ": ['ap90'],
    "droṇodana": ['bhs', 'mw'],
    "droṇya": ['cae', 'gra', 'mw'],
    "droṇyaśva": ['gra', 'mw'],
    "droṇyāmaya": ['mw'],
    "droṇā": ['mw'],
    "droṇācārya": ['mw'],
    "droṇāhāva": ['gra', 'mw'],
    "droṇāsa": ['mw'],
    "droṇī": ['bhs', 'mw'],
    "droṇīaśva": ['gra'],
    "droṇīdala": ['mw'],
    "droṇīja": ['mw'],
    "droṇīlavaṇa": ['mw'],
    "droṇīmukha": ['mw'],
    "droṇīpadī": ['mw'],
    "dru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "druanna": ['gra'],
    "drugdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "drugha": ['mw'],
    "drughaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "drughnī": ['cae', 'mw'],
    "druh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "druha": ['mw'],
    "druhaḥ": ['ap90'],
    "druhaṃtara": ['gra', 'mw'],
    "druhaṇa": ['mw'],
    "druhaṇaḥ": ['ap90'],
    "druhiṇa": ['cae', 'ddsa', 'mw'],
    "druhu": ['cae', 'mw'],
    "druhvan": ['cae', 'gra', 'mw'],
    "druhya": ['mw'],
    "druhyu": ['cae', 'gra', 'mw'],
    "druhī": ['mw'],
    "drukilima": ['mw'],
    "druma": ['bhs', 'cae', 'ddsa', 'mw'],
    "drumacchedaprāyaścitta": ['mw'],
    "drumachāyā": ['bhs'],
    "drumada": ['mw'],
    "drumadhvaja": ['bhs'],
    "drumakhaṇḍa": ['mw'],
    "drumakiṃnaraprabha": ['bhs', 'mw'],
    "drumakiṃnararāja": ['mw'],
    "drumakiṃnararājaparipṛcchā": ['bhs', 'mw'],
    "drumakulya": ['mw'],
    "drumakuśa": ['bhs'],
    "drumala": ['mw'],
    "drumamaya": ['mw'],
    "drumameruśrī": ['bhs'],
    "drumanakha": ['mw'],
    "drumaparvata": ['bhs'],
    "drumaparvatateja": ['bhs'],
    "drumara": ['mw'],
    "drumaratnaśākhāprabha": ['bhs', 'mw'],
    "drumasena": ['mw'],
    "drumat": ['mw'],
    "drumavalka": ['mw'],
    "drumavant": ['cae'],
    "drumavat": ['mw'],
    "drumavyādhi": ['mw'],
    "drumavāsin": ['mw'],
    "drumaśreṣṭha": ['mw'],
    "drumaśīrṣa": ['mw'],
    "drumaḥ": ['ap90'],
    "drumaṣaṇḍa": ['mw'],
    "drumbhūlī": ['mw'],
    "drumeśvara": ['mw'],
    "drumila": ['mw'],
    "drumiṇī": ['ap90', 'mw'],
    "drumm": ['mw'],
    "drumotpala": ['mw'],
    "drumā": ['mw'],
    "drumābjaketu": ['mw'],
    "drumāgra": ['cae', 'mw'],
    "drumākṣa": ['mw'],
    "drumālaya": ['mw'],
    "drumāmaya": ['cae', 'mw'],
    "drumāri": ['mw'],
    "drumāvatī": ['bhs'],
    "drumāy": ['cae'],
    "drumāya": ['ddsa', 'mw'],
    "drumāśraya": ['mw'],
    "drunaha": ['mw'],
    "drunakha": ['mw'],
    "drupada": ['cae', 'ddsa', 'gra', 'mw'],
    "drupadaputra": ['mw'],
    "drupadaḥ": ['ap90'],
    "drupadā": ['mw'],
    "drupadāditya": ['mw'],
    "drupadātmajā": ['mw'],
    "drupadī": ['mw'],
    "drupāda": ['mw'],
    "drusallaka": ['mw'],
    "druta": ['ap90', 'cae', 'ddsa', 'mw'],
    "drutabodha": ['mw'],
    "drutabodhikā": ['mw'],
    "drutacaurya": ['mw'],
    "drutagati": ['ddsa', 'mw'],
    "drutam": ['mw'],
    "drutamadhyā": ['mw'],
    "drutameru": ['mw'],
    "drutapada": ['cae', 'mw'],
    "drutapadam": ['mw'],
    "drutatara": ['mw'],
    "drutataragati": ['mw'],
    "drutataram": ['mw'],
    "drutatva": ['cae', 'mw'],
    "drutavarāhakula": ['mw'],
    "drutavikrama": ['mw'],
    "drutavilambita": ['cae', 'mw'],
    "drutavāhana": ['mw'],
    "drutayāna": ['mw'],
    "druti": ['cae', 'ddsa', 'mw'],
    "drutiḥ": ['ap90'],
    "druvaya": ['cae', 'mw'],
    "druvayaḥ": ['ap90'],
    "druḍ": ['ap90', 'mw'],
    "druṇ": ['ap90', 'mw'],
    "druṇa": ['mw'],
    "druṇaha": ['mw'],
    "druṇasa": ['mw'],
    "druṇaḥ": ['ap90'],
    "druṇiḥ": ['ap90'],
    "druṇā": ['ap90', 'mw'],
    "druṇī": ['mw'],
    "druṣad": ['gra', 'mw'],
    "druṣadvan": ['gra', 'mw'],
    "drvanna": ['gra', 'mw'],
    "drā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "drāgbhṛtaka": ['mw'],
    "drāgh": ['ap90', 'gra', 'mw'],
    "drāghay": ['cae'],
    "drāghaya": ['ddsa'],
    "drāghayati": ['ap90'],
    "drāghiman": ['ap90', 'cae', 'ddsa', 'mw'],
    "drāghimavat": ['mw'],
    "drāghita": ['mw'],
    "drāghiṣṭha": ['ap90', 'cae', 'gra', 'mw'],
    "drāghman": ['cae', 'gra', 'mw'],
    "drāghmā": ['mw'],
    "drāghīyas": ['ap90', 'gra', 'mw'],
    "drāghīyaṃs": ['cae'],
    "drāh": ['ap90', 'mw'],
    "drāhyāyaṇa": ['mw'],
    "drāhyāyaṇagṛhya": ['mw'],
    "drāhyāyaṇaka": ['mw'],
    "drāhyāyaṇasūtra": ['mw'],
    "drāhyāyaṇi": ['mw'],
    "drāhyāyaṇīya": ['mw'],
    "drāk": ['ap90', 'cae', 'ddsa', 'mw'],
    "drākh": ['ap90', 'mw'],
    "drākkendra": ['mw'],
    "drākpratimaṇḍala": ['mw'],
    "drākṣa": ['ddsa', 'mw'],
    "drākṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "drākṣāghṛta": ['mw'],
    "drākṣālatikā": ['bhs'],
    "drākṣālatā": ['mw'],
    "drākṣāmat": ['mw'],
    "drākṣāprastha": ['mw'],
    "drākṣārasa": ['mw'],
    "drākṣāriṣṭa": ['mw'],
    "drākṣārāmeśvara": ['mw'],
    "drākṣāsava": ['mw'],
    "drākṣāvalayabhūmi": ['mw'],
    "drākṣāvana": ['mw'],
    "drākṣāvāruṇī": ['mw'],
    "drāmila": ['mw'],
    "drāmilaḥ": ['ap90'],
    "drāmiḍa": ['bhs'],
    "drāmiḍī": ['mw'],
    "drāpa": ['mw'],
    "drāpaḥ": ['ap90'],
    "drāpi": ['cae', 'gra', 'mw'],
    "drāva": ['bhs', 'mw'],
    "drāvaka": ['ap90', 'mw'],
    "drāvakanda": ['mw'],
    "drāvakara": ['mw'],
    "drāvayatsakha": ['cae', 'ddsa', 'gra', 'mw'],
    "drāvayitnu": ['cae', 'ddsa', 'gra', 'mw'],
    "drāvayitṛ": ['ddsa'],
    "drāvayāṇa": ['mw'],
    "drāvaḥ": ['ap90'],
    "drāvaṇa": ['cae', 'ddsa', 'mw'],
    "drāvaṇabāṇa": ['mw'],
    "drāvaṇaṃ": ['ap90'],
    "drāvikā": ['ap90', 'mw'],
    "drāvila": ['mw'],
    "drāvin": ['mw'],
    "drāvita": ['ap90', 'mw'],
    "drāviḍa": ['cae', 'ddsa', 'mw'],
    "drāviḍabhūtika": ['mw'],
    "drāviḍagauḍaka": ['mw'],
    "drāviḍajāti": ['mw'],
    "drāviḍaka": ['mw'],
    "drāviḍakaḥ": ['ap90'],
    "drāviḍalipi": ['bhs', 'mw'],
    "drāviḍavedapārāyaṇapramāṇa": ['mw'],
    "drāviḍaḥ": ['ap90'],
    "drāviḍī": ['mw'],
    "drāviṇodasa": ['mw'],
    "drāvya": ['ap90', 'mw'],
    "drāḍ": ['ap90', 'mw'],
    "drāṃkṣ": ['ap90'],
    "drāṅgavadha": ['mw'],
    "drāṅkṣ": ['mw'],
    "drāṇa": ['ap90', 'mw'],
    "drū": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "drūghaṇa": ['mw'],
    "drūghaṇaḥ": ['ap90'],
    "drūḍ": ['mw'],
    "drūḥ": ['ap90'],
    "drūṇa": ['mw'],
    "drūṇaḥ": ['ap90'],
    "du": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "du(g)guṇa": ['cped'],
    "du-osārita": ['cped'],
    "dua": ['gra'],
    "dubbalaka": ['cped'],
    "dubballa": ['cped'],
    "dubbalya": ['cped'],
    "dubbalīkarana": ['cped'],
    "dubbha": ['cped'],
    "dubbhati": ['cped'],
    "dubbhida": ['cped'],
    "dubbinodaya": ['cped'],
    "dubbisodha": ['cped'],
    "dubbiññapaya": ['cped'],
    "dubbuddhi(n)": ['cped'],
    "dubbuṭṭhika": ['cped'],
    "dubhatomukha": ['cped'],
    "dubhaya": ['cped'],
    "dubhayaṁ": ['cped'],
    "duccaja": ['cped'],
    "duccajja": ['cped'],
    "duccara": ['cped'],
    "duccarita": ['cped'],
    "ducchaka": ['mw'],
    "ducchana": ['bhs'],
    "ducchunā": ['cae', 'ddsa', 'mw'],
    "ducchunāy": ['cae'],
    "ducchunāya": ['mw'],
    "duccintitacinti(n)": ['cped'],
    "duccola": ['cped'],
    "duccoḷa": ['cped'],
    "duchunā": ['gra'],
    "duchunāy": ['gra'],
    "duda": ['mw'],
    "dudda": ['mw'],
    "duddada": ['cped'],
    "duddama": ['cped'],
    "duddamaya": ['cped'],
    "duddamiya": ['cped'],
    "duddasa": ['cped'],
    "duddasika": ['cped'],
    "duddassika": ['cped'],
    "duddhakhīra": ['cped'],
    "duddhara": ['mw'],
    "duddikkha": ['cped'],
    "duddiṭṭha": ['cped'],
    "duddiṭṭharūpa": ['cped'],
    "duddiṭṭhi": ['cped'],
    "duddiṭṭhi(n)": ['cped'],
    "duddādin": ['mw'],
    "dudh": ['ap90', 'cae', 'gra', 'mw'],
    "dudhi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dudhita": ['ap90', 'mw'],
    "dudhra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dudhrakṛt": ['cae', 'gra', 'mw'],
    "dudhravāc": ['gra', 'mw'],
    "dudhrukṣu": ['ddsa', 'mw'],
    "dudhukṣu": ['ddsa', 'mw'],
    "dudikkha": ['cped'],
    "dudrukṣu": ['mw'],
    "dudruma": ['mw'],
    "dudrumaḥ": ['ap90'],
    "duduha": ['mw'],
    "dudyūṣu": ['mw'],
    "dugdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "dugdhabandhaka": ['mw'],
    "dugdhabhṛt": ['mw'],
    "dugdhabījā": ['mw'],
    "dugdhacaru": ['mw'],
    "dugdhada": ['ddsa', 'mw'],
    "dugdhadoha": ['cae', 'mw'],
    "dugdhakūpikā": ['mw'],
    "dugdhamukha": ['mw'],
    "dugdhapadī": ['mw'],
    "dugdhapeyā": ['mw'],
    "dugdhaphena": ['mw'],
    "dugdhaphenī": ['mw'],
    "dugdhapoṣya": ['mw'],
    "dugdhapucchī": ['mw'],
    "dugdhapācana": ['mw'],
    "dugdhapātra": ['mw'],
    "dugdhapāyin": ['mw'],
    "dugdhapāṣāṇa": ['mw'],
    "dugdhasamudra": ['mw'],
    "dugdhasindhu": ['cae', 'mw'],
    "dugdhasrotas": ['cae', 'mw'],
    "dugdhatumbī": ['mw'],
    "dugdhatva": ['mw'],
    "dugdhatā": ['mw'],
    "dugdhatālīya": ['mw'],
    "dugdhavaṭī": ['mw'],
    "dugdhikā": ['mw'],
    "dugdhin": ['mw'],
    "dugdhinikā": ['mw'],
    "dugdhodadhi": ['mw'],
    "dugdhābdhi": ['mw'],
    "dugdhābdhitanayā": ['mw'],
    "dugdhāgra": ['mw'],
    "dugdhākṣa": ['mw'],
    "dugdhāmbudhi": ['mw'],
    "dugdhāmra": ['mw'],
    "dugdhāśman": ['mw'],
    "dugdhī": ['mw'],
    "dugga": ['cped'],
    "duggaha": ['cped'],
    "duggahīta": ['cped'],
    "duggata": ['cped'],
    "duggati": ['cped'],
    "duggatigamana": ['cped'],
    "duggatigāmin(n)": ['cped'],
    "dugh": ['gra'],
    "dugha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dughā": ['mw'],
    "duguṇa": ['bhs'],
    "dugūla": ['mw'],
    "duh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "duha": ['cae', 'mw'],
    "duhara": ['cped'],
    "duhati": ['cped'],
    "duhatṛ": ['bhs'],
    "duhitika": ['cped'],
    "duhitrī": ['bhs'],
    "duhituḥpati": ['mw'],
    "duhitāmātṛ": ['cae', 'ddsa', 'mw'],
    "duhitṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "duhitṛkā": ['bhs'],
    "duhitṛmat": ['mw'],
    "duhitṛpati": ['mw'],
    "duhitṛtva": ['mw'],
    "duhya": ['mw'],
    "duhyu": ['mw'],
    "duhāpeti": ['cped'],
    "duibandhu": ['gra'],
    "dujivha": ['cped'],
    "dujjaha": ['cped'],
    "dujjaya": ['cped'],
    "dujjivha": ['cped'],
    "dujjivīta": ['cped'],
    "dujjāna": ['cped'],
    "dujjāta": ['cped'],
    "duka": ['bhs', 'cped'],
    "dukanipāta": ['cped'],
    "dukathā": ['cped'],
    "dukha": ['bhs'],
    "dukhita": ['cped'],
    "dukhya": ['bhs'],
    "dukkara": ['cped'],
    "dukkarakārikā": ['cped'],
    "dukkaratara": ['cped'],
    "dukkata": ['cped'],
    "dukkaṭa": ['cped'],
    "dukkha": ['cped'],
    "dukkhabhikiṇṇa": ['cped'],
    "dukkhadhivaha": ['cped'],
    "dukkhadhivāha": ['cped'],
    "dukkhadukkha": ['cped'],
    "dukkhadukkhatā": ['cped'],
    "dukkhakkhanda": ['cped'],
    "dukkhama": ['cped'],
    "dukkhanirodha": ['cped'],
    "dukkhanirodhagāmi(n)": ['cped'],
    "dukkhapaṭikkūla": ['cped'],
    "dukkhappaṭikkūla": ['cped'],
    "dukkhasamudaya": ['cped'],
    "dukkhatta": ['cped'],
    "dukkhatā": ['cped'],
    "dukkhavedanīya": ['cped'],
    "dukkhavepakka": ['cped'],
    "dukkhavinaya": ['cped'],
    "dukkhaṁ": ['cped'],
    "dukkhetta": ['cped'],
    "dukkhi(n)": ['cped'],
    "dukkhindriya": ['cped'],
    "dukkhita": ['cped'],
    "dukkhotiṇṇa": ['cped'],
    "dukkhudaya": ['cped'],
    "dukkhuddaya": ['cped'],
    "dukkhudraya": ['cped'],
    "dukkhupasamana": ['cped'],
    "dukkhāvaha": ['cped'],
    "dukkhāvakkanta": ['cped'],
    "dukura": ['bhs'],
    "dukūla": ['cae', 'ddsa', 'mw'],
    "dukūlaka": ['bhs'],
    "dukūlapaṭṭa": ['mw'],
    "dukūlasandāna": ['cped'],
    "dukūlavat": ['mw'],
    "dukūlaṃ": ['ap90'],
    "dul": ['ap90', 'cae', 'ddsa', 'mw'],
    "dulayate": ['mw'],
    "duli": ['mw'],
    "duliduha": ['mw'],
    "duliḥ": ['ap90'],
    "dull": ['bhs'],
    "dullabha": ['bhs', 'cped'],
    "dullabhatara": ['cped'],
    "dullala": ['mw'],
    "duloka": ['mw'],
    "dulā": ['mw'],
    "dulārabhaṭṭācārya": ['mw'],
    "dulī": ['mw'],
    "duma": ['cped'],
    "dumatī": ['mw'],
    "dumavhaya": ['cped'],
    "dumbaka": ['mw'],
    "dumela": ['bhs', 'mw'],
    "dummadumāka": ['mw'],
    "dummana": ['cped'],
    "dummedhi(n)": ['cped'],
    "dumāsika": ['cped'],
    "dumāsikaṁ": ['cped'],
    "dumūlaka": ['cped'],
    "dundama": ['mw'],
    "dundu": ['mw'],
    "dundubha": ['cae', 'ddsa', 'mw'],
    "dundubhi": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "dundubhidarpahan": ['mw'],
    "dundubhigrīva": ['mw'],
    "dundubhika": ['mw'],
    "dundubhikā": ['bhs'],
    "dundubhinirhrāda": ['mw'],
    "dundubhisvana": ['mw'],
    "dundubhisvara": ['bhs', 'mw'],
    "dundubhisvaranirghoṣa": ['bhs', 'mw'],
    "dundubhisvararāja": ['bhs', 'mw'],
    "dundubhivadha": ['mw'],
    "dundubhivimocanīya": ['mw'],
    "dundubhya": ['mw'],
    "dundubhyāghāta": ['cae', 'mw'],
    "dundubhī": ['mw'],
    "dundubhīśvara": ['mw'],
    "dundumāra": ['mw'],
    "dundumāya": ['mw'],
    "dundunābha": ['mw'],
    "dunnaya": ['cped'],
    "dunniggaha": ['cped'],
    "dunnihata": ['cped'],
    "dunnikkhama": ['cped'],
    "dunnikkhasa": ['cped'],
    "dunnikkhitta": ['cped'],
    "dunnissārita": ['cped'],
    "dunnisārita": ['cped'],
    "dunnivattha": ['cped'],
    "dunnivāraya": ['cped'],
    "dunnīta": ['cped'],
    "dunvat": ['mw'],
    "dupadendra": ['bhs'],
    "dupaṇṇa": ['cped'],
    "dupaṭṭa": ['cped'],
    "dupaṭṭhāka": ['cped'],
    "duphāra": ['mw'],
    "duppadhaṁsiya": ['cped'],
    "duppadālaya": ['cped'],
    "duppadāliya": ['cped'],
    "duppajaha": ['cped'],
    "duppamuñca": ['cped'],
    "duppariyogāha": ['cped'],
    "duppasaha": ['cped'],
    "duppatimantiya": ['cped'],
    "duppaṭimantiya": ['cped'],
    "duppaṭinissaggi(n)": ['cped'],
    "duppaṭivijjha": ['cped'],
    "duppaṭivinodaya": ['cped'],
    "duppaṭivinodiya": ['cped'],
    "duputta": ['cped'],
    "dur": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dura": ['bhs', 'cae', 'gra', 'mw'],
    "durabhi": ['mw'],
    "durabhibhava": ['mw'],
    "durabhigraha": ['mw'],
    "durabhigrahā": ['mw'],
    "durabhimoca": ['bhs'],
    "durabhimānin": ['mw'],
    "durabhiprāya": ['mw'],
    "durabhirakṣa": ['mw'],
    "durabhirakṣatā": ['mw'],
    "durabhirama": ['cped'],
    "durabhisambhava": ['cped', 'mw'],
    "durabhisaṃbhava": ['bhs'],
    "durabhisaṃbhuṇa": ['bhs'],
    "durabhisaṃbodha": ['bhs'],
    "durabhisaṃdhi": ['mw'],
    "durabhisaṅga": ['cae'],
    "duraccaya": ['cped'],
    "duradabhna": ['mw'],
    "duradhiga": ['cae', 'mw'],
    "duradhigama": ['cae', 'cped', 'mw'],
    "duradhimoca": ['bhs'],
    "duradhivāsa": ['cped'],
    "duradhiṣṭhita": ['mw'],
    "duradhva": ['mw'],
    "duradhyavasāya": ['mw'],
    "duradhyaya": ['mw'],
    "duradhyayayana": ['mw'],
    "duradhyeya": ['mw'],
    "duradhyeyatva": ['mw'],
    "duradhīta": ['mw'],
    "duradhīyāna": ['mw'],
    "duradhīśvara": ['mw'],
    "duradmanī": ['mw'],
    "duradṛṣṭa": ['mw'],
    "durahna": ['mw'],
    "durakkhāta": ['cped'],
    "durakṣa": ['cae', 'mw'],
    "durakṣara": ['mw'],
    "durannaya": ['cped'],
    "duranta": ['cae', 'ddsa', 'mw'],
    "durantabhāva": ['mw'],
    "durantacintā": ['mw'],
    "durantadeva": ['mw'],
    "durantaka": ['mw'],
    "durantakṛcchra": ['mw'],
    "durantakṛt": ['mw'],
    "durantamoha": ['mw'],
    "durantaparyanta": ['mw'],
    "durantavīrya": ['mw'],
    "durantaśakti": ['mw'],
    "duranubodha": ['bhs', 'cped', 'mw'],
    "duranuga": ['mw'],
    "duranujñāta": ['mw'],
    "duranuneya": ['mw'],
    "duranuneyatā": ['mw'],
    "duranupālana": ['mw'],
    "duranurakkhiya": ['cped'],
    "duranusamprāpya": ['mw'],
    "duranuvartya": ['mw'],
    "duranuṣṭheya": ['mw'],
    "duranuṣṭhita": ['mw'],
    "duranvaya": ['mw'],
    "duranveṣya": ['mw'],
    "duranūcāna": ['mw'],
    "durapacāra": ['mw'],
    "durapavāda": ['mw'],
    "durapāsa": ['mw'],
    "durasy": ['cae'],
    "durasya": ['mw'],
    "durasyu": ['mw'],
    "duratikkama": ['cped'],
    "duratikrama": ['cae', 'ddsa', 'mw'],
    "duratikramaṇīya": ['mw'],
    "durativatta": ['cped'],
    "duratyaya": ['cae', 'mw'],
    "duratyayānukramaṇa": ['mw'],
    "duratyetu": ['gra', 'mw'],
    "duravabodha": ['cae', 'mw'],
    "duravabodhatā": ['mw'],
    "duravacchada": ['mw'],
    "duravadhāraka": ['mw'],
    "duravadhāraṇa": ['mw'],
    "duravadhārya": ['mw'],
    "duravagama": ['mw'],
    "duravagraha": ['mw'],
    "duravagrahagrāha": ['mw'],
    "duravagrahagrāhya": ['mw'],
    "duravagāha": ['cae', 'mw'],
    "duravalepa": ['mw'],
    "duravaroha": ['mw'],
    "duravasita": ['mw'],
    "duravastha": ['mw'],
    "duravasthita": ['mw'],
    "duravasthā": ['mw'],
    "duravatāra": ['mw'],
    "duravavada": ['mw'],
    "duravekṣita": ['mw'],
    "duravāpa": ['cae', 'mw'],
    "duraḥprabhṛti": ['mw'],
    "durbaddha": ['mw'],
    "durbala": ['cae', 'ddsa', 'mw'],
    "durbalaka": ['bhs'],
    "durbalatā": ['mw'],
    "durbalendriya": ['cae', 'mw'],
    "durbali": ['mw'],
    "durbalika": ['mw'],
    "durbalita": ['mw'],
    "durbalā": ['mw'],
    "durbalāgni": ['mw'],
    "durbalāgnitā": ['mw'],
    "durbalāyāsa": ['mw'],
    "durbalī": ['mw'],
    "durbalībhāva": ['mw'],
    "durbalībhū": ['mw'],
    "durbalīyas": ['mw'],
    "durbandha": ['mw'],
    "durbhaga": ['cae', 'mw'],
    "durbhagatva": ['mw'],
    "durbhagna": ['mw'],
    "durbhagā": ['mw'],
    "durbhakātyāyana": ['bhs'],
    "durbhakṣa": ['bhs', 'ddsa', 'mw'],
    "durbhakṣya": ['mw'],
    "durbhara": ['cae', 'mw'],
    "durbharatā": ['bhs'],
    "durbhartṛ": ['cae', 'mw'],
    "durbhaṅga": ['mw'],
    "durbhaṇa": ['mw'],
    "durbhaṇatva": ['mw'],
    "durbheda": ['cae', 'mw'],
    "durbhedya": ['cae', 'mw'],
    "durbhida": ['cae', 'mw'],
    "durbhikṣa": ['cae', 'mw'],
    "durbhikṣatva": ['mw'],
    "durbhikṣavyasanin": ['mw'],
    "durbhikṣaśamana": ['mw'],
    "durbhiṣajya": ['mw'],
    "durbhogā": ['mw'],
    "durbhrātṛ": ['cae', 'mw'],
    "durbhukta": ['bhs'],
    "durbhāgya": ['cae', 'mw'],
    "durbhāryā": ['cae', 'mw'],
    "durbhāvanā": ['mw'],
    "durbhāvya": ['mw'],
    "durbhāṣa": ['cae', 'mw'],
    "durbhāṣin": ['cae', 'mw'],
    "durbhāṣita": ['cae', 'mw'],
    "durbhūta": ['cae', 'mw'],
    "durbhṛti": ['cae', 'gra', 'mw'],
    "durbodha": ['cae', 'mw'],
    "durbodhapadabhañjikā": ['mw'],
    "durbodhapadabhañjinī": ['mw'],
    "durbodhya": ['cae', 'mw'],
    "durbrāhmaṇa": ['cae', 'mw'],
    "durbuda": ['bhs'],
    "durbuddhi": ['cae', 'mw'],
    "durbudha": ['mw'],
    "durbāla": ['mw'],
    "durbīriṇa": ['mw'],
    "durdagdha": ['mw'],
    "durdaiva": ['cae', 'mw'],
    "durdaivavat": ['mw'],
    "durdama": ['cae', 'ddsa', 'mw'],
    "durdamana": ['mw'],
    "durdamya": ['cae', 'mw'],
    "durdara": ['mw'],
    "durdarśa": ['cae', 'mw'],
    "durdarśana": ['cae', 'mw'],
    "durdarśatā": ['mw'],
    "durdarśatāya": ['mw'],
    "durdatta": ['bhs', 'mw'],
    "durdaśā": ['cae', 'mw'],
    "durdeśa": ['cae', 'mw'],
    "durdeśaja": ['mw'],
    "durdhara": ['cae', 'ddsa', 'gra', 'mw'],
    "durdharma": ['mw'],
    "durdhartu": ['cae', 'gra', 'mw'],
    "durdharuṭa": ['mw'],
    "durdharā": ['mw'],
    "durdharāyogādhyāya": ['mw'],
    "durdharītu": ['cae', 'gra', 'mw'],
    "durdharṣa": ['bhs', 'cae', 'mw'],
    "durdharṣakumārabhūta": ['mw'],
    "durdharṣatva": ['mw'],
    "durdharṣatā": ['mw'],
    "durdharṣaṇa": ['mw'],
    "durdharṣā": ['mw'],
    "durdhita": ['cae', 'gra', 'mw'],
    "durdhur": ['cae', 'gra', 'mw'],
    "durdhurūṭa": ['mw'],
    "durdhyāna": ['mw'],
    "durdhā": ['cae', 'gra', 'mw'],
    "durdhārya": ['cae', 'mw'],
    "durdhāva": ['mw'],
    "durdhī": ['cae', 'mw'],
    "durdina": ['bhs', 'cae', 'mw'],
    "durdinagrastabhāskara": ['mw'],
    "durdināya": ['mw'],
    "durdivasa": ['cae', 'mw'],
    "durdohā": ['mw'],
    "durdolī": ['mw'],
    "durdritā": ['mw'],
    "durdruma": ['mw'],
    "durduhā": ['cae', 'ddsa', 'mw'],
    "durdurūṭa": ['mw'],
    "durdyūta": ['cae', 'mw'],
    "durdyūtadevin": ['mw'],
    "durdyūtavedin": ['mw'],
    "durdānta": ['cae', 'mw'],
    "durdāru": ['mw'],
    "durdūrānta": ['mw'],
    "durdṛś": ['cae', 'mw'],
    "durdṛśa": ['cae', 'mw'],
    "durdṛśīka": ['gra', 'mw'],
    "durdṛṣṭa": ['mw'],
    "dureva": ['cae', 'gra', 'mw'],
    "durga": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "durgadatta": ['mw'],
    "durgadeśa": ['ddsa', 'mw'],
    "durgaghna": ['mw'],
    "durgaghnā": ['mw'],
    "durgaghāta": ['ddsa', 'mw'],
    "durgagupta": ['mw'],
    "durgaha": ['cae', 'ddsa', 'gra', 'mw'],
    "durgakarman": ['mw'],
    "durgakāraka": ['mw'],
    "durgala": ['mw'],
    "durgalaṅghana": ['mw'],
    "durgama": ['cae', 'ddsa', 'mw'],
    "durgamamārganirgama": ['mw'],
    "durgamanīya": ['cae', 'mw'],
    "durgamya": ['cae', 'mw'],
    "durgamārga": ['mw'],
    "durgamāśubodhinī": ['mw'],
    "durgandha": ['bhs', 'cae', 'ddsa', 'mw'],
    "durgandhakāra": ['mw'],
    "durgandharasa": ['mw'],
    "durgandhatā": ['cae', 'mw'],
    "durgandhi": ['cae', 'mw'],
    "durgandhita": ['bhs'],
    "durganivāsin": ['mw'],
    "durganāga": ['mw'],
    "durgapadaprabodha": ['mw'],
    "durgapati": ['cae', 'ddsa', 'mw'],
    "durgapiśāca": ['mw'],
    "durgapura": ['mw'],
    "durgapuṣpī": ['mw'],
    "durgapāla": ['cae', 'mw'],
    "durgasaha": ['mw'],
    "durgasampad": ['mw'],
    "durgasaṃcara": ['mw'],
    "durgasaṃcāra": ['mw'],
    "durgasena": ['cae', 'mw'],
    "durgasiṃha": ['cae', 'ddsa', 'mw'],
    "durgasiṃhī": ['mw'],
    "durgata": ['cae', 'ddsa', 'mw'],
    "durgataraṇī": ['mw'],
    "durgatariṇī": ['mw'],
    "durgatatā": ['mw'],
    "durgati": ['bhs', 'cae', 'ddsa', 'mw'],
    "durgatināśinī": ['mw'],
    "durgatā": ['mw'],
    "durgavyasana": ['mw'],
    "durgavākyaprabodha": ['mw'],
    "durgavāsa": ['mw'],
    "durgavṛtti": ['mw'],
    "durgaya": ['mw'],
    "durgaśaila": ['mw'],
    "durgaṭīkā": ['mw'],
    "durghaṭa": ['mw'],
    "durghaṭaghātana": ['mw'],
    "durghaṭakāvya": ['mw'],
    "durghaṭatva": ['mw'],
    "durghaṭavṛtti": ['mw'],
    "durghaṭodghāṭa": ['mw'],
    "durghaṭārthaprakāśikā": ['mw'],
    "durghoṣa": ['mw'],
    "durgi": ['mw'],
    "durgilā": ['mw'],
    "durgotsava": ['mw'],
    "durgotsavatattva": ['mw'],
    "durgottāriṇī": ['bhs'],
    "durgoṣṭhī": ['mw'],
    "durgraha": ['cae', 'mw'],
    "durgrāhya": ['cae', 'mw'],
    "durgrāhyahṛdaya": ['mw'],
    "durgrāhyatva": ['mw'],
    "durgā": ['mw'],
    "durgābhaktitaraṃgiṇī": ['mw'],
    "durgācārya": ['cae', 'ddsa', 'mw'],
    "durgādatta": ['cae', 'mw'],
    "durgādha": ['cae', 'mw'],
    "durgādhatva": ['mw'],
    "durgādhikārin": ['mw'],
    "durgādhyakṣa": ['mw'],
    "durgādāsa": ['cae', 'mw'],
    "durgāha": ['mw'],
    "durgāhlāda": ['mw'],
    "durgāhya": ['cae', 'mw'],
    "durgāhyatva": ['mw'],
    "durgākavaca": ['mw'],
    "durgākramaṇa": ['mw'],
    "durgākuṇḍa": ['mw'],
    "durgāmahattva": ['mw'],
    "durgāmāhātmya": ['mw'],
    "durgāmṛtarahasya": ['mw'],
    "durgānavamī": ['mw'],
    "durgāntarātithi": ['mw'],
    "durgāpañcāṅga": ['mw'],
    "durgāpūjā": ['cae', 'mw'],
    "durgārcanamāhātmya": ['mw'],
    "durgārohaṇa": ['mw'],
    "durgārāma": ['mw'],
    "durgāsaṃdehabhedikā": ['mw'],
    "durgāstava": ['mw'],
    "durgāstotra": ['mw'],
    "durgāstuti": ['mw'],
    "durgāsāvitrī": ['mw'],
    "durgātattva": ['mw'],
    "durgāvallabha": ['mw'],
    "durgāvarodha": ['mw'],
    "durgāvatī": ['mw'],
    "durgāvilāsa": ['mw'],
    "durgāyantra": ['mw'],
    "durgāśrayaṇa": ['mw'],
    "durgāḍha": ['cae', 'ddsa', 'mw'],
    "durgāṣṭamī": ['mw'],
    "durgṛbhi": ['cae', 'gra', 'mw'],
    "durgṛbhiśvan": ['gra', 'mw'],
    "durgṛbhīy": ['gra'],
    "durgṛbhīya": ['mw'],
    "durhala": ['mw'],
    "durhali": ['mw'],
    "durhanu": ['mw'],
    "durhanā": ['mw'],
    "durhaṇu": ['cae', 'gra'],
    "durhaṇā": ['cae', 'gra', 'mw'],
    "durhaṇāvat": ['gra', 'mw'],
    "durhaṇāy": ['cae', 'gra'],
    "durhaṇāya": ['mw'],
    "durhaṇāyu": ['cae', 'ddsa', 'gra', 'mw'],
    "durhita": ['cae', 'gra', 'mw'],
    "durhuta": ['mw'],
    "durhārd": ['mw'],
    "durhārda": ['cae'],
    "durhṛd": ['cae', 'mw'],
    "durhṛdaya": ['mw'],
    "durhṛta": ['mw'],
    "durhṛṇāy": ['cae'],
    "durhṛṇāya": ['mw'],
    "durhṛṇāyu": ['cae', 'gra', 'mw'],
    "durhṛṣīka": ['mw'],
    "duri": ['mw'],
    "duria": ['gra'],
    "durita": ['cae', 'ddsa', 'gra', 'mw'],
    "duritadamanī": ['mw'],
    "duritakṣaya": ['mw'],
    "duriti": ['cae', 'mw'],
    "duritāri": ['mw'],
    "duritārṇava": ['mw'],
    "duritātman": ['ddsa', 'mw'],
    "duriṣṭa": ['mw'],
    "duriṣṭakṛt": ['mw'],
    "duriṣṭi": ['cae', 'mw'],
    "durjala": ['cae', 'mw'],
    "durjana": ['cae', 'ddsa', 'mw'],
    "durjanamalla": ['mw'],
    "durjanamukhacapeṭikā": ['mw'],
    "durjanamukhamahācapeṭikā": ['mw'],
    "durjanamukhapadmapādukā": ['mw'],
    "durjananindā": ['mw'],
    "durjanatva": ['mw'],
    "durjanatā": ['mw'],
    "durjanāya": ['ddsa', 'mw'],
    "durjanīkṛ": ['cae', 'ddsa', 'mw'],
    "durjara": ['mw'],
    "durjaya": ['bhs', 'cae', 'ddsa', 'mw'],
    "durjayacandra": ['bhs'],
    "durjayanta": ['mw'],
    "durjayā": ['bhs', 'mw'],
    "durjeya": ['cae', 'mw'],
    "durjñeya": ['cae', 'mw'],
    "durjñāna": ['cae', 'mw'],
    "durjñānatva": ['mw'],
    "durjāta": ['cae', 'mw'],
    "durjāti": ['cae', 'mw'],
    "durjātīya": ['cae', 'mw'],
    "durjīva": ['cae', 'mw'],
    "durlabha": ['cae', 'ddsa', 'mw'],
    "durlabhadarśana": ['cae', 'mw'],
    "durlabhaka": ['mw'],
    "durlabhakasvāmin": ['mw'],
    "durlabharāja": ['mw'],
    "durlabhatva": ['mw'],
    "durlabhatā": ['mw'],
    "durlabhavardhana": ['mw'],
    "durlabhā": ['mw'],
    "durlakṣaṇa": ['mw'],
    "durlakṣya": ['cae', 'ddsa', 'mw'],
    "durlalita": ['cae', 'ddsa', 'mw'],
    "durlambha": ['bhs'],
    "durlaṅghana": ['cae', 'mw'],
    "durlaṅghanaśakti": ['mw'],
    "durlaṅghita": ['bhs'],
    "durlaṅghya": ['cae', 'mw'],
    "durlaṅghyatā": ['mw'],
    "durlekhya": ['mw'],
    "durlikhita": ['bhs', 'mw'],
    "durlipi": ['mw'],
    "durlābha": ['mw'],
    "durmada": ['cae', 'gra', 'mw'],
    "durmadavīramānin": ['mw'],
    "durmadin": ['mw'],
    "durmadāndha": ['mw'],
    "durmaitra": ['cae', 'mw'],
    "durmakha": ['gra', 'mw'],
    "durmallikā": ['mw'],
    "durmallī": ['mw'],
    "durmanas": ['cae', 'mw'],
    "durmanaska": ['cae', 'mw'],
    "durmanaskatā": ['mw'],
    "durmanastā": ['mw'],
    "durmanasvin": ['bhs'],
    "durmanman": ['cae', 'gra', 'mw'],
    "durmantra": ['cae', 'mw'],
    "durmantrin": ['cae', 'mw'],
    "durmantrita": ['cae', 'mw'],
    "durmantu": ['cae', 'gra', 'mw'],
    "durmanuṣya": ['cae', 'ddsa', 'mw'],
    "durmanāy": ['cae'],
    "durmanāya": ['ddsa', 'mw'],
    "durmara": ['cae', 'mw'],
    "durmaratva": ['cae', 'mw'],
    "durmaraṇa": ['cae', 'mw'],
    "durmaryāda": ['mw'],
    "durmaryādatā": ['mw'],
    "durmarā": ['mw'],
    "durmarāyu": ['mw'],
    "durmarṣa": ['cae', 'gra', 'mw'],
    "durmarṣaṇa": ['cae', 'mw'],
    "durmarṣita": ['mw'],
    "durmatakhaṇḍana": ['mw'],
    "durmati": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "durmatīkṛta": ['mw'],
    "durmaṅgala": ['gra', 'mw'],
    "durmaṅku": ['bhs', 'mw'],
    "durmedha": ['cae', 'mw'],
    "durmedhas": ['cae', 'mw'],
    "durmedhastva": ['mw'],
    "durmedhāvin": ['cae', 'mw'],
    "durmilikā": ['mw'],
    "durmilā": ['mw'],
    "durmitra": ['cae', 'gra', 'mw'],
    "durmitriya": ['mw'],
    "durmitrā": ['mw'],
    "durmoca": ['mw'],
    "durmocahastagrāha": ['cae', 'mw'],
    "durmohā": ['mw'],
    "durmuhūrta": ['mw'],
    "durmukha": ['bhs', 'cae', 'mw'],
    "durmukhācārya": ['mw'],
    "durmātsarya": ['mw'],
    "durmāyin": ['mw'],
    "durmāyu": ['gra', 'mw'],
    "durmūlya": ['mw'],
    "durnarendra": ['mw'],
    "durnaya": ['cae', 'ddsa', 'mw'],
    "durnigraha": ['cae', 'mw'],
    "durnimita": ['mw'],
    "durnimitta": ['cae', 'mw'],
    "durnirīkṣa": ['cae', 'mw'],
    "durnirīkṣaṇa": ['cae', 'mw'],
    "durnirīkṣya": ['cae', 'mw'],
    "durnivartya": ['mw'],
    "durnivedya": ['mw'],
    "durnivedyatva": ['mw'],
    "durnivāra": ['cae', 'mw'],
    "durnivāratva": ['mw'],
    "durnivārya": ['cae', 'mw'],
    "durnivṛtta": ['mw'],
    "durniyantu": ['gra', 'mw'],
    "durniḥsaraṇa": ['mw'],
    "durniṣedha": ['mw'],
    "durniṣkramaṇa": ['mw'],
    "durniṣprapatana": ['mw'],
    "durnyasta": ['cae', 'mw'],
    "durnāmaka": ['mw'],
    "durnāman": ['mw'],
    "durnāmikā": ['mw'],
    "durnāmāri": ['mw'],
    "durnīta": ['cae', 'mw'],
    "durnītabhāva": ['mw'],
    "durnīti": ['mw'],
    "durnṛpa": ['mw'],
    "durodara": ['cae', 'ddsa', 'mw'],
    "durodaraḥ": ['ap90'],
    "duroka": ['gra'],
    "durokam": ['cae', 'mw'],
    "durokaśocis": ['gra', 'mw'],
    "duropagama": ['bhs'],
    "duropaya": ['cped'],
    "duroṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "duroṇasad": ['cae', 'gra', 'mw'],
    "duroṇayu": ['gra', 'mw'],
    "duroṣa": ['gra', 'mw'],
    "duroṣas": ['gra', 'mw'],
    "duru": ['mw'],
    "durubbaha": ['cped'],
    "duruccheda": ['mw'],
    "durucchedya": ['mw'],
    "durudarka": ['mw'],
    "durudaya": ['mw'],
    "durudgītha": ['cae'],
    "durudharā": ['mw'],
    "durudvaha": ['cae', 'mw'],
    "durudāhara": ['mw'],
    "durukta": ['cae', 'ddsa', 'gra', 'mw'],
    "durukti": ['cae', 'mw'],
    "duruktokta": ['mw'],
    "durupacāra": ['cae', 'mw'],
    "durupadeśa": ['mw'],
    "durupadiṣṭa": ['mw'],
    "durupakrama": ['mw'],
    "durupalakṣa": ['mw'],
    "durupapāda": ['mw'],
    "durupasada": ['cae', 'mw'],
    "durupasarpin": ['cae', 'mw'],
    "durupasaṅkama": ['cped'],
    "durupasthāna": ['mw'],
    "durupayukta": ['mw'],
    "durupeta": ['cped'],
    "durupāpa": ['mw'],
    "durupāya": ['mw'],
    "duruta": ['mw'],
    "durutsaha": ['cae', 'mw'],
    "durutsāha": ['mw'],
    "duruttara": ['cae', 'mw'],
    "duruḥpha": ['mw'],
    "durv": ['ap90', 'mw'],
    "durvaca": ['cae', 'ddsa', 'mw'],
    "durvacaka": ['mw'],
    "durvacakayoga": ['mw'],
    "durvacana": ['cae', 'mw'],
    "durvacas": ['cae', 'mw'],
    "durvacastva": ['mw'],
    "durvacatva": ['mw'],
    "durvadaka": ['mw'],
    "durvaha": ['cae', 'mw'],
    "durvahaka": ['mw'],
    "durvaira": ['mw'],
    "durvala": ['mw'],
    "durvartu": ['cae', 'gra', 'mw'],
    "durvarāha": ['mw'],
    "durvarṇa": ['cae', 'mw'],
    "durvarṇaka": ['mw'],
    "durvarṇīkaraṇa": ['bhs'],
    "durvasa": ['cae', 'mw'],
    "durvasati": ['cae', 'mw'],
    "durvañca": ['mw'],
    "durvaṇij": ['mw'],
    "durveda": ['mw'],
    "durvibhāga": ['mw'],
    "durvibhāva": ['cae', 'mw'],
    "durvibhāvana": ['cae', 'mw'],
    "durvibhāvya": ['cae', 'mw'],
    "durvibhāṣa": ['mw'],
    "durviceṣṭa": ['mw'],
    "durvicintita": ['mw'],
    "durvicintya": ['mw'],
    "durvicāra": ['mw'],
    "durvicāratva": ['mw'],
    "durvida": ['mw'],
    "durvidagdha": ['cae', 'mw'],
    "durvidatra": ['gra', 'mw'],
    "durvidha": ['mw'],
    "durvidhi": ['cae', 'mw'],
    "durvidvas": ['gra', 'mw'],
    "durvidvaṃs": ['cae'],
    "durvidya": ['cae', 'mw'],
    "durvigāha": ['cae', 'mw'],
    "durvigāhya": ['cae'],
    "durvijñeya": ['cae', 'mw'],
    "durvijñāna": ['cae', 'mw'],
    "durvikalpa": ['mw'],
    "durvikatthana": ['mw'],
    "durvilasita": ['cae', 'mw'],
    "durvimarśa": ['mw'],
    "durvimocana": ['mw'],
    "durvinaya": ['cae', 'mw'],
    "durvinīta": ['cae', 'mw'],
    "durvipāka": ['cae', 'mw'],
    "durvirecya": ['mw'],
    "durvirocana": ['mw'],
    "durvitarka": ['mw'],
    "durvitarkya": ['mw'],
    "durvivaktṛ": ['mw'],
    "durvivecana": ['mw'],
    "durvivāha": ['cae', 'mw'],
    "durviśa": ['mw'],
    "durviṣa": ['mw'],
    "durviṣaha": ['cae', 'mw'],
    "durviṣahya": ['cae'],
    "durvrajita": ['mw'],
    "durvrata": ['mw'],
    "durvyasana": ['cae', 'mw'],
    "durvyavahāra": ['mw'],
    "durvyavahṛti": ['mw'],
    "durvyavasita": ['mw'],
    "durvyavasthāpaka": ['mw'],
    "durvyāhṛta": ['mw'],
    "durvāc": ['cae', 'mw'],
    "durvācakayoga": ['mw'],
    "durvācika": ['mw'],
    "durvācya": ['cae', 'mw'],
    "durvāda": ['cae', 'mw'],
    "durvāgbhāva": ['mw'],
    "durvāhita": ['mw'],
    "durvākya": ['mw'],
    "durvāla": ['cae', 'mw'],
    "durvānta": ['cae', 'mw'],
    "durvāra": ['cae', 'mw'],
    "durvāratva": ['mw'],
    "durvāraṇa": ['cae', 'mw'],
    "durvāraṇīya": ['mw'],
    "durvāri": ['mw'],
    "durvārita": ['mw'],
    "durvārttā": ['cae', 'mw'],
    "durvārya": ['cae', 'mw'],
    "durvāryatva": ['mw'],
    "durvāsa": ['mw'],
    "durvāsanā": ['mw'],
    "durvāsapurāṇa": ['mw'],
    "durvāsas": ['cae', 'gra', 'mw'],
    "durvāsaupapurāṇa": ['mw'],
    "durvāsaupākhyāna": ['mw'],
    "durvāseśvara": ['mw'],
    "durvāsodarpabhaṅga": ['mw'],
    "durvāsodviśatī": ['mw'],
    "durvāsomahiman": ['mw'],
    "durvāsomatatantra": ['mw'],
    "durvāsopaniṣad": ['mw'],
    "durvāsovākya": ['mw'],
    "durvāta": ['mw'],
    "durvātāya": ['mw'],
    "durvṛtta": ['cae', 'mw'],
    "durvṛtti": ['cae', 'mw'],
    "durvṛṣala": ['mw'],
    "durvṛṣṭi": ['mw'],
    "durya": ['cae', 'ddsa', 'gra', 'mw'],
    "duryavanam": ['mw'],
    "duryaśas": ['cae', 'ddsa', 'mw'],
    "duryodha": ['mw'],
    "duryodhana": ['bhs', 'cae', 'mw'],
    "duryodhanarakṣābandhana": ['mw'],
    "duryodhanatā": ['mw'],
    "duryodhanavīryajñānamudrā": ['mw'],
    "duryodhanavīryavegarāja": ['bhs'],
    "duryodhanāsana": ['mw'],
    "duryodhanāvaraja": ['mw'],
    "duryoga": ['cae', 'mw'],
    "duryoni": ['cae', 'mw'],
    "duryoṇa": ['cae', 'gra', 'mw'],
    "duryuga": ['cae', 'mw'],
    "duryuj": ['cae', 'gra', 'mw'],
    "duryāman": ['mw'],
    "durābhaṭṭha": ['cped'],
    "durābādha": ['mw'],
    "durācara": ['cae', 'mw'],
    "durācarita": ['mw'],
    "durācāra": ['cae', 'mw'],
    "durācārin": ['mw'],
    "durādeya": ['mw'],
    "durādhana": ['mw'],
    "durādhara": ['cae', 'mw'],
    "durādharṣa": ['cae', 'gra', 'mw'],
    "durādharṣā": ['mw'],
    "durādhi": ['mw'],
    "durādhāra": ['mw'],
    "durādhī": ['cae', 'gra', 'mw'],
    "durādāna": ['mw'],
    "durādṛṣṭi": ['mw'],
    "durāgama": ['cae', 'mw'],
    "durāgata": ['bhs', 'cped', 'mw'],
    "durāgraha": ['mw'],
    "durāhara": ['mw'],
    "durāhā": ['mw'],
    "durājñeya": ['bhs'],
    "durājāna": ['cped'],
    "durāka": ['mw'],
    "durākhyāta": ['bhs'],
    "durākrama": ['mw'],
    "durākramaṇa": ['mw'],
    "durākranda": ['mw'],
    "durākrośam": ['mw'],
    "durākrāma": ['mw'],
    "durākrānta": ['mw'],
    "durākāra": ['bhs'],
    "durākṛti": ['cae', 'ddsa', 'mw'],
    "durālabha": ['cae', 'mw'],
    "durālakṣya": ['cae', 'mw'],
    "durālamba": ['cae', 'mw'],
    "durālambha": ['cae', 'mw'],
    "durālambhā": ['mw'],
    "durāloka": ['cae', 'mw'],
    "durālāpa": ['mw'],
    "durāmnāya": ['mw'],
    "durāmoda": ['mw'],
    "durānama": ['mw'],
    "durāneya": ['mw'],
    "durānuga": ['bhs'],
    "durāpa": ['cae', 'mw'],
    "durāpana": ['cae', 'gra', 'mw'],
    "durāpādana": ['mw'],
    "durāpūra": ['mw'],
    "durārakṣa": ['mw'],
    "durārakṣya": ['mw'],
    "durārihan": ['mw'],
    "durāroha": ['bhs', 'cae', 'mw'],
    "durārohatā": ['mw'],
    "durārohaṇīya": ['mw'],
    "durārohā": ['mw'],
    "durāropa": ['mw'],
    "durāruha": ['cae', 'mw'],
    "durāruhā": ['mw'],
    "durārādha": ['mw'],
    "durārādhya": ['cae', 'mw'],
    "durārūḍha": ['mw'],
    "durāsa": ['mw'],
    "durāsada": ['cae', 'cped', 'mw'],
    "durāsaha": ['cae', 'mw'],
    "durāseva": ['mw'],
    "durāsita": ['mw'],
    "durātman": ['cae', 'mw'],
    "durātmatā": ['mw'],
    "durātmavant": ['cae'],
    "durātmavat": ['mw'],
    "durāvagāha": ['bhs'],
    "durāvaha": ['cae', 'mw'],
    "durāvara": ['mw'],
    "durāvarta": ['mw'],
    "durāvia": ['gra'],
    "durāvya": ['gra'],
    "durāvāra": ['cae', 'mw'],
    "durāvāsa": ['cped'],
    "durāvāsin": ['mw'],
    "durāvī": ['mw'],
    "durāyya": ['mw'],
    "durāśa": ['mw'],
    "durāśaya": ['cae', 'ddsa', 'mw'],
    "durāśaṃsin": ['mw'],
    "durāśir": ['cae', 'gra', 'mw'],
    "durāśis": ['cae', 'mw'],
    "durāśraya": ['mw'],
    "durāśā": ['cae', 'mw'],
    "durāḍhya": ['mw'],
    "durāḍhyambhava": ['mw'],
    "durāḍhyaṃkara": ['mw'],
    "durīha": ['cae', 'mw'],
    "durīkṣa": ['ddsa', 'mw'],
    "durīkṣatā": ['mw'],
    "durīśa": ['mw'],
    "durīṣaṇā": ['mw'],
    "durūha": ['cae', 'ddsa', 'mw'],
    "durūhatva": ['mw'],
    "durūpa": ['bhs'],
    "durūpasaṅkama": ['cped'],
    "durūpeta": ['cped'],
    "durṇaya": ['mw'],
    "durṇaśa": ['cae', 'mw'],
    "durṇaṣṭa": ['mw'],
    "durṇihitaiṣin": ['mw'],
    "durṇāmacātana": ['mw'],
    "durṇāmahan": ['mw'],
    "durṇāman": ['cae', 'gra', 'mw'],
    "durṇīta": ['mw'],
    "durṇīti": ['mw'],
    "dus": ['ap90', 'cae', 'gra', 'mw'],
    "duspṛṣṭa": ['mw'],
    "dussa": ['cped'],
    "dussacālanī": ['cped'],
    "dussaddhāpaya": ['cped'],
    "dussaka": ['cped'],
    "dussamuṭṭhāpaya": ['cped'],
    "dussamādaha": ['cped'],
    "dussani": ['ddsa', 'mw'],
    "dussanīya": ['cped'],
    "dussapallaṭṭhikā": ['cped'],
    "dussapata": ['cped'],
    "dussapaṭṭa": ['cped'],
    "dussatha": ['mw'],
    "dussati": ['cped'],
    "dussavaṭṭi": ['cped'],
    "dussaveṇi": ['cped'],
    "dussaṁhara": ['cped'],
    "dussi": ['cped'],
    "dussīlya": ['cped'],
    "dustapa": ['mw'],
    "dustara": ['cae', 'ddsa', 'mw'],
    "dustaraṇa": ['cae', 'mw'],
    "dustarka": ['mw'],
    "dustarkamūla": ['mw'],
    "dustarkya": ['mw'],
    "dustha": ['cae', 'ddsa', 'mw'],
    "dusthita": ['cae', 'mw'],
    "dustithi": ['mw'],
    "dustoṣa": ['mw'],
    "dustyaja": ['cae'],
    "dustyajya": ['mw'],
    "dustyājya": ['mw'],
    "dustāra": ['mw'],
    "dustīrtha": ['mw'],
    "dustīrṇa": ['mw'],
    "dus˚": ['ddsa'],
    "dut": ['mw'],
    "duta": ['mw'],
    "dutiya": ['cped'],
    "dutiyaka": ['cped'],
    "dutiyakaṁ": ['cped'],
    "dutiyakulika": ['cped'],
    "dutiyaṁ": ['cped'],
    "dutiyya": ['cped'],
    "dutiyās": ['bhs'],
    "duttakkita": ['cped'],
    "duttappaya": ['cped'],
    "duttara": ['cped'],
    "dutthotthadavīra": ['mw'],
    "duttitikkha": ['cped'],
    "dutīlakṣaṇa": ['mw'],
    "dutīprakāśa": ['mw'],
    "dutīya": ['cped'],
    "duvagga": ['cped'],
    "duvanya": ['gra'],
    "duvanyasad": ['gra', 'mw'],
    "duvas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "duvasana": ['ap90', 'gra', 'mw'],
    "duvaskṛ": ['mw'],
    "duvassa": ['cped'],
    "duvasvan": ['ap90'],
    "duvasvant": ['cae'],
    "duvasvat": ['mw'],
    "duvasy": ['cae', 'gra'],
    "duvasya": ['ddsa', 'mw'],
    "duvasyati": ['ap90'],
    "duvasyu": ['cae', 'gra', 'mw'],
    "duvasyāt": ['ddsa'],
    "duvaṅgula": ['cped'],
    "duve": ['bhs'],
    "duvidha": ['cped'],
    "duvidhena": ['cped'],
    "duvijātā": ['cped'],
    "duvinodaya": ['cped'],
    "duviññapaya": ['cped'],
    "duvo": ['mw'],
    "duvodhā": ['mw'],
    "duvoyu": ['ap90', 'cae', 'gra', 'mw'],
    "duvoyā": ['cae', 'gra', 'mw'],
    "duvāra": ['bhs', 'cped'],
    "duvārika": ['bhs'],
    "duvūpasamaya": ['cped'],
    "duyamana": ['bhs'],
    "duādaśan": ['gra'],
    "duādaśāra": ['gra'],
    "duś": ['mw'],
    "duścakṣas": ['mw'],
    "duścar": ['mw'],
    "duścara": ['cae', 'ddsa', 'mw'],
    "duścaracārin": ['mw'],
    "duścaraka": ['bhs'],
    "duścaratva": ['mw'],
    "duścarita": ['cae', 'mw'],
    "duścarmaka": ['mw'],
    "duścarman": ['cae', 'mw'],
    "duścetas": ['cae'],
    "duśceṣṭita": ['mw'],
    "duśceṣṭā": ['cae', 'mw'],
    "duśchada": ['mw'],
    "duśchardita": ['bhs'],
    "duśchid": ['mw'],
    "duśchinna": ['mw'],
    "duśchāya": ['bhs', 'mw'],
    "duścikitsa": ['mw'],
    "duścikitsita": ['mw'],
    "duścikitsya": ['mw'],
    "duścikitsyatva": ['mw'],
    "duścikitsā": ['mw'],
    "duścikya": ['mw'],
    "duścintin": ['mw'],
    "duścintita": ['mw'],
    "duścintitacintin": ['bhs'],
    "duścintya": ['mw'],
    "duścit": ['cae', 'mw'],
    "duścitta": ['cae', 'mw'],
    "duścyavana": ['cae', 'gra', 'mw'],
    "duścyāva": ['mw'],
    "duścyāvana": ['mw'],
    "duścārin": ['cae', 'mw'],
    "duścāritra": ['cae', 'mw'],
    "duḍi": ['mw'],
    "duḍiḥ": ['ap90'],
    "duḥ": ['mw'],
    "duḥk": ['bhs'],
    "duḥkh": ['ap90'],
    "duḥkha": ['ap90', 'cae', 'ddsa', 'mw'],
    "duḥkhabahula": ['mw'],
    "duḥkhabheṣaja": ['mw'],
    "duḥkhabhāgin": ['cae', 'mw'],
    "duḥkhabhāj": ['cae', 'mw'],
    "duḥkhabhūyiṣṭha": ['mw'],
    "duḥkhabodha": ['mw'],
    "duḥkhacchedya": ['mw'],
    "duḥkhacchinna": ['mw'],
    "duḥkhacārin": ['mw'],
    "duḥkhadagdha": ['mw'],
    "duḥkhadohyā": ['mw'],
    "duḥkhaduḥkha": ['mw'],
    "duḥkhaduḥkhatā": ['mw'],
    "duḥkhaduḥkhena": ['cae'],
    "duḥkhaduḥkhin": ['mw'],
    "duḥkhagata": ['mw'],
    "duḥkhagraha": ['cae', 'mw'],
    "duḥkhahan": ['cae', 'mw'],
    "duḥkhajāta": ['mw'],
    "duḥkhajīvin": ['cae', 'mw'],
    "duḥkhaka": ['bhs'],
    "duḥkhakara": ['cae', 'ddsa', 'mw'],
    "duḥkhakārin": ['mw'],
    "duḥkhalabdhikā": ['mw'],
    "duḥkhalavya": ['mw'],
    "duḥkhaloka": ['mw'],
    "duḥkham": ['mw'],
    "duḥkhamaraṇa": ['cae', 'mw'],
    "duḥkhamaya": ['mw'],
    "duḥkhamayatva": ['mw'],
    "duḥkhamoha": ['ddsa', 'mw'],
    "duḥkhamokṣa": ['mw'],
    "duḥkhamukta": ['bhs'],
    "duḥkhana": ['bhs'],
    "duḥkhanivaha": ['mw'],
    "duḥkhaparītātman": ['mw'],
    "duḥkhaparītāṅga": ['mw'],
    "duḥkhapratīkāra": ['mw'],
    "duḥkhaprāya": ['cae', 'mw'],
    "duḥkhapātra": ['mw'],
    "duḥkhasamāyukta": ['mw'],
    "duḥkhasaṃcāra": ['mw'],
    "duḥkhasaṃsparśa": ['mw'],
    "duḥkhasaṃsthiti": ['mw'],
    "duḥkhasaṃvardhita": ['mw'],
    "duḥkhasaṃyoga": ['mw'],
    "duḥkhasparśa": ['mw'],
    "duḥkhasāgara": ['mw'],
    "duḥkhatara": ['mw'],
    "duḥkhati": ['bhs'],
    "duḥkhatā": ['bhs', 'cae', 'mw'],
    "duḥkhavasati": ['mw'],
    "duḥkhavega": ['mw'],
    "duḥkhavyābhāṣita": ['mw'],
    "duḥkhavāsa": ['mw'],
    "duḥkhay": ['cae'],
    "duḥkhaya": ['ddsa', 'mw'],
    "duḥkhayantra": ['ddsa', 'mw'],
    "duḥkhayitrṛ": ['ddsa'],
    "duḥkhayoga": ['cae', 'mw'],
    "duḥkhayoni": ['cae', 'mw'],
    "duḥkhaśokaparitrāṇa": ['mw'],
    "duḥkhaśokasamanvita": ['mw'],
    "duḥkhaśokavat": ['mw'],
    "duḥkhaśīla": ['cae', 'mw'],
    "duḥkhaśīlatva": ['mw'],
    "duḥkheta": ['mw'],
    "duḥkhilatā": ['bhs'],
    "duḥkhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "duḥkhita": ['ap90', 'cae', 'ddsa', 'mw'],
    "duḥkhitacitta": ['mw'],
    "duḥkhitaka": ['bhs'],
    "duḥkhitva": ['mw'],
    "duḥkhitā": ['cae', 'ddsa', 'mw'],
    "duḥkhocchedya": ['mw'],
    "duḥkhodarka": ['mw'],
    "duḥkhopacarya": ['cae', 'mw'],
    "duḥkhopaghāta": ['ddsa', 'mw'],
    "duḥkhopahatacetas": ['mw'],
    "duḥkhopeta": ['mw'],
    "duḥkhottara": ['cae', 'mw'],
    "duḥkhya": ['mw'],
    "duḥkhābhijña": ['cae', 'mw'],
    "duḥkhācāra": ['mw'],
    "duḥkhākara": ['ddsa', 'mw'],
    "duḥkhākula": ['cae', 'ddsa', 'mw'],
    "duḥkhākṛ": ['ddsa', 'mw'],
    "duḥkhālaya": ['cae'],
    "duḥkhālīḍha": ['mw'],
    "duḥkhānarha": ['mw'],
    "duḥkhānta": ['mw'],
    "duḥkhānvita": ['mw'],
    "duḥkhāpayati": ['bhs'],
    "duḥkhārta": ['cae', 'ddsa', 'mw'],
    "duḥkhāsikā": ['mw'],
    "duḥkhātmaka": ['mw'],
    "duḥkhātmakatva": ['mw'],
    "duḥkhātīta": ['mw'],
    "duḥkhāy": ['cae'],
    "duḥkhāya": ['ddsa', 'mw'],
    "duḥkhāyate": ['ap90'],
    "duḥkhīy": ['cae'],
    "duḥkhīya": ['ddsa', 'mw'],
    "duḥkhīyati": ['ap90'],
    "duḥkṛta": ['ddsa'],
    "duḥp": ['bhs'],
    "duḥprasaha": ['cae'],
    "duḥsaha": ['cae', 'mw'],
    "duḥsahatva": ['mw'],
    "duḥsahā": ['mw'],
    "duḥsahāya": ['mw'],
    "duḥsaktha": ['mw'],
    "duḥsakthi": ['mw'],
    "duḥsama": ['mw'],
    "duḥsamartha": ['mw'],
    "duḥsamatikrama": ['mw'],
    "duḥsampāda": ['mw'],
    "duḥsampādatva": ['mw'],
    "duḥsampādya": ['mw'],
    "duḥsampādyatva": ['mw'],
    "duḥsamīkṣya": ['mw'],
    "duḥsandhāna": ['ddsa'],
    "duḥsarpa": ['mw'],
    "duḥsattva": ['mw'],
    "duḥsattvavat": ['mw'],
    "duḥsaṃcintya": ['mw'],
    "duḥsaṃcāra": ['mw'],
    "duḥsaṃdheya": ['mw'],
    "duḥsaṃdhāna": ['mw'],
    "duḥsaṃlakṣya": ['ddsa', 'mw'],
    "duḥsaṃrakṣya": ['mw'],
    "duḥsaṃskāra": ['mw'],
    "duḥsaṃsthita": ['mw'],
    "duḥsaṅga": ['mw'],
    "duḥsevya": ['mw'],
    "duḥsmara": ['mw'],
    "duḥsnāna": ['mw'],
    "duḥsparśa": ['cae', 'mw'],
    "duḥsparśā": ['mw'],
    "duḥsphoṭa": ['mw'],
    "duḥspṛśa": ['cae', 'mw'],
    "duḥspṛṣṭa": ['mw'],
    "duḥstha": ['cae', 'ddsa', 'mw'],
    "duḥstham": ['mw'],
    "duḥstheya": ['mw'],
    "duḥsthita": ['cae', 'mw'],
    "duḥsthiti": ['cae', 'mw'],
    "duḥstrī": ['mw'],
    "duḥsvana": ['mw'],
    "duḥsvapna": ['cae', 'mw'],
    "duḥsvapnadarśana": ['mw'],
    "duḥsvapnanāśa": ['mw'],
    "duḥsvapnanāśana": ['mw'],
    "duḥsvapnanāśin": ['mw'],
    "duḥsvapnapratibodhana": ['mw'],
    "duḥsvapnaśānti": ['mw'],
    "duḥsvapnopaśānti": ['mw'],
    "duḥsādhin": ['mw'],
    "duḥsādhya": ['cae', 'mw'],
    "duḥsākṣin": ['mw'],
    "duḥśaka": ['mw'],
    "duḥśakatva": ['mw'],
    "duḥśakta": ['mw'],
    "duḥśakti": ['mw'],
    "duḥśala": ['cae', 'ddsa', 'mw'],
    "duḥśalā": ['mw'],
    "duḥśasta": ['mw'],
    "duḥśaṃsa": ['cae', 'gra', 'mw'],
    "duḥśeva": ['cae', 'gra', 'mw'],
    "duḥśikṣita": ['cae', 'mw'],
    "duḥśiṣya": ['cae', 'mw'],
    "duḥśodha": ['mw'],
    "duḥśoṣa": ['mw'],
    "duḥśraddadha": ['bhs'],
    "duḥśraddadheya": ['bhs'],
    "duḥśrava": ['mw'],
    "duḥśravatva": ['mw'],
    "duḥśruta": ['mw'],
    "duḥśākam": ['mw'],
    "duḥśāsa": ['mw'],
    "duḥśāsana": ['cae', 'mw'],
    "duḥśāsu": ['gra'],
    "duḥśāsus": ['cae', 'gra', 'mw'],
    "duḥśīla": ['cae', 'mw'],
    "duḥśīlacitta": ['mw'],
    "duḥśīlatā": ['mw'],
    "duḥśīlā": ['mw'],
    "duḥśīma": ['gra', 'mw'],
    "duḥśīrtatanu": ['mw'],
    "duḥśṛta": ['mw'],
    "duḥśṛṅgī": ['mw'],
    "duḥṣaha": ['gra', 'mw'],
    "duḥṣama": ['ddsa', 'mw'],
    "duḥṣamam": ['mw'],
    "duḥṣamasuṣamā": ['mw'],
    "duḥṣamā": ['mw'],
    "duḥṣanta": ['ddsa', 'mw'],
    "duḥṣparśa": ['mw'],
    "duḥṣupta": ['mw'],
    "duḥṣvanta": ['mw'],
    "duḥṣvapnya": ['cae', 'mw'],
    "duḥṣṭhu": ['mw'],
    "duḥṣṭuta": ['mw'],
    "duḥṣṭuti": ['cae', 'mw'],
    "duṃdamaḥ": ['ap90'],
    "duṃdubhaḥ": ['ap90'],
    "duṃdubhikaḥ": ['ap90'],
    "duṃdubhiḥ": ['ap90'],
    "duṃdumā": ['ap90'],
    "duṃdumāraḥ": ['ap90'],
    "duṃdumāyate": ['ap90'],
    "duṃdumāyitaṃ": ['ap90'],
    "duṃduḥ": ['ap90'],
    "duṃḍubhaḥ": ['ap90'],
    "duṃḍuka": ['ap90'],
    "duṇḍhā": ['mw'],
    "duṇḍubha": ['mw'],
    "duṇḍubhi": ['mw'],
    "duṇḍuka": ['mw'],
    "duṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "duṣkalevara": ['mw'],
    "duṣkara": ['bhs', 'cae', 'ddsa', 'mw'],
    "duṣkaracaryā": ['mw'],
    "duṣkaraka": ['bhs'],
    "duṣkarakarman": ['mw'],
    "duṣkarakārin": ['mw'],
    "duṣkarakāritā": ['mw'],
    "duṣkarasādhana": ['mw'],
    "duṣkaraṇa": ['mw'],
    "duṣkarman": ['cae', 'ddsa', 'mw'],
    "duṣkarmasūdana": ['mw'],
    "duṣkarṇa": ['mw'],
    "duṣkha": ['bhs', 'mw'],
    "duṣkhadira": ['mw'],
    "duṣkrama": ['mw'],
    "duṣkramatā": ['mw'],
    "duṣkriyā": ['mw'],
    "duṣkrīta": ['mw'],
    "duṣkuha": ['mw'],
    "duṣkuhaka": ['bhs', 'mw'],
    "duṣkula": ['cae', 'mw'],
    "duṣkulatā": ['mw'],
    "duṣkulīna": ['mw'],
    "duṣkāla": ['mw'],
    "duṣkāyasthakula": ['mw'],
    "duṣkīrti": ['mw'],
    "duṣkṛt": ['cae', 'gra', 'mw'],
    "duṣkṛta": ['bhs', 'cae', 'gra', 'mw'],
    "duṣkṛtabahiṣkṛta": ['mw'],
    "duṣkṛtakarman": ['cae', 'ddsa', 'mw'],
    "duṣkṛtakārin": ['cae'],
    "duṣkṛti": ['cae', 'ddsa', 'mw'],
    "duṣkṛtin": ['cae', 'mw'],
    "duṣkṛtātman": ['mw'],
    "duṣkṛṣṭa": ['mw'],
    "duṣmanta": ['cae', 'ddsa', 'mw'],
    "duṣpaca": ['mw'],
    "duṣpad": ['gra'],
    "duṣpada": ['mw'],
    "duṣparigraha": ['ddsa', 'mw'],
    "duṣparihantu": ['cae', 'gra', 'mw'],
    "duṣparimṛṣṭa": ['mw'],
    "duṣpariṇāma": ['mw'],
    "duṣparājaya": ['mw'],
    "duṣparīkṣya": ['mw'],
    "duṣparśa": ['mw'],
    "duṣpatana": ['mw'],
    "duṣpattra": ['mw'],
    "duṣpeṣaṇa": ['mw'],
    "duṣpoṣa": ['mw'],
    "duṣpoṣata": ['bhs'],
    "duṣpoṣatā": ['mw'],
    "duṣprabhañjana": ['mw'],
    "duṣprabodha": ['mw'],
    "duṣprada": ['mw'],
    "duṣpradharṣa": ['bhs', 'cae', 'mw'],
    "duṣpradharṣaṇa": ['mw'],
    "duṣpradharṣaṇī": ['mw'],
    "duṣpradharṣiṇī": ['mw'],
    "duṣpradharṣā": ['mw'],
    "duṣpradhṛṣya": ['mw'],
    "duṣpraharṣa": ['mw'],
    "duṣpraja": ['mw'],
    "duṣprajas": ['mw'],
    "duṣprajña": ['mw'],
    "duṣprajñatva": ['mw'],
    "duṣprajñāna": ['mw'],
    "duṣprakampa": ['mw'],
    "duṣprakampya": ['mw'],
    "duṣprakriyā": ['mw'],
    "duṣprakāśa": ['mw'],
    "duṣprakṛti": ['mw'],
    "duṣpralambha": ['mw'],
    "duṣpramaya": ['mw'],
    "duṣprapadana": ['mw'],
    "duṣprasaha": ['bhs', 'cae', 'mw'],
    "duṣprasaṃstara": ['bhs'],
    "duṣprasāda": ['cae', 'mw'],
    "duṣprasādana": ['cae', 'mw'],
    "duṣprasādhana": ['mw'],
    "duṣprasādhya": ['mw'],
    "duṣprasāha": ['mw'],
    "duṣprasū": ['mw'],
    "duṣpratara": ['mw'],
    "duṣpratigraha": ['mw'],
    "duṣprativedha": ['bhs'],
    "duṣprativāraṇa": ['mw'],
    "duṣprativīkṣaṇīya": ['mw'],
    "duṣprativīkṣya": ['mw'],
    "duṣpratyabhijña": ['mw'],
    "duṣpratītikara": ['mw'],
    "duṣpraveśa": ['mw'],
    "duṣpraveśā": ['mw'],
    "duṣpravāda": ['mw'],
    "duṣpravṛtti": ['mw'],
    "duṣprayukta": ['cae', 'mw'],
    "duṣpraṇīta": ['cae', 'mw'],
    "duṣprekṣa": ['cae', 'mw'],
    "duṣprekṣaṇīya": ['cae', 'mw'],
    "duṣprekṣita": ['bhs', 'mw'],
    "duṣprekṣya": ['cae', 'mw'],
    "duṣprāpa": ['cae', 'mw'],
    "duṣprāpaṇa": ['cae', 'mw'],
    "duṣprāpta": ['mw'],
    "duṣprāpya": ['mw'],
    "duṣprāvī": ['gra', 'mw'],
    "duṣprīti": ['mw'],
    "duṣpuruṣa": ['mw'],
    "duṣputra": ['mw'],
    "duṣpāna": ['mw'],
    "duṣpāra": ['cae', 'mw'],
    "duṣpārṣṇigraha": ['mw'],
    "duṣpārṣṇigrāha": ['mw'],
    "duṣpīta": ['mw'],
    "duṣpūra": ['cae', 'mw'],
    "duṣvanta": ['mw'],
    "duṣvapnia": ['gra'],
    "duṣvapnya": ['gra', 'mw'],
    "duṣya": ['bhs'],
    "duṣyanta": ['ddsa', 'mw'],
    "duṣyati": ['bhs'],
    "duṣyaṃtaḥ": ['ap90'],
    "duṣ˚": ['ddsa'],
    "duṣṭa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "duṣṭabaṭuka": ['cae', 'mw'],
    "duṣṭabhāva": ['cae', 'mw'],
    "duṣṭabhāvatā": ['mw'],
    "duṣṭabuddhi": ['mw'],
    "duṣṭacaritra": ['cae', 'mw'],
    "duṣṭacetas": ['cae', 'mw'],
    "duṣṭacārin": ['cae', 'mw'],
    "duṣṭadamana": ['mw'],
    "duṣṭadamanakāvya": ['mw'],
    "duṣṭadhī": ['mw'],
    "duṣṭadurjana": ['mw'],
    "duṣṭagaja": ['mw'],
    "duṣṭahṛdaya": ['mw'],
    "duṣṭalāṅgala": ['mw'],
    "duṣṭamati": ['mw'],
    "duṣṭamānasa": ['mw'],
    "duṣṭanu": ['cae', 'mw'],
    "duṣṭanāśinī": ['mw'],
    "duṣṭara": ['cae', 'gra', 'mw'],
    "duṣṭarajodarśanaśānti": ['mw'],
    "duṣṭaratarītu": ['mw'],
    "duṣṭarītu": ['cae', 'gra'],
    "duṣṭatva": ['mw'],
    "duṣṭatā": ['mw'],
    "duṣṭavraṇa": ['mw'],
    "duṣṭavāc": ['cae', 'mw'],
    "duṣṭavānara": ['mw'],
    "duṣṭavṛṣa": ['mw'],
    "duṣṭayoniprāptivicāra": ['mw'],
    "duṣṭaśoṇita": ['cae'],
    "duṣṭhu": ['ap90', 'mw'],
    "duṣṭhula": ['bhs'],
    "duṣṭi": ['cae', 'ddsa', 'mw'],
    "duṣṭiḥ": ['ap90'],
    "duṣṭuta": ['mw'],
    "duṣṭuti": ['cae', 'ddsa', 'gra'],
    "duṣṭā": ['mw'],
    "duṣṭāntarātman": ['cae', 'mw'],
    "duṣṭānvita": ['mw'],
    "duṣṭātman": ['cae', 'ddsa', 'mw'],
    "duṣṭātura": ['mw'],
    "duṣṭīya": ['mw'],
    "duṭṭha": ['cped'],
    "duṭṭhagahaṇika": ['cped'],
    "duṭṭhulla": ['cped'],
    "duṭṭhullabhāṇi(n)": ['cped'],
    "duṭṭhullagāhi(n)": ['cped'],
    "duṭṭhāruka": ['cped'],
    "duṭṭhārukā": ['cped'],
    "dva": ['cae', 'ddsa', 'gra', 'mw'],
    "dvai": ['mw'],
    "dvaibhāvya": ['mw'],
    "dvaidatti": ['mw'],
    "dvaidha": ['ap90', 'cae', 'ddsa', 'mw'],
    "dvaidham": ['mw'],
    "dvaidhasūtra": ['mw'],
    "dvaidhaṃkāram": ['mw'],
    "dvaidhya": ['mw'],
    "dvaidhyaṃ": ['ap90'],
    "dvaidhī": ['mw'],
    "dvaidhībhāva": ['cae', 'ddsa', 'mw'],
    "dvaidhībhāvaḥ": ['ap90'],
    "dvaidhībhū": ['ap90', 'cae', 'ddsa', 'mw'],
    "dvaidhībhūta": ['mw'],
    "dvaidhīkaraṇa": ['mw'],
    "dvaidhīkṛ": ['ap90'],
    "dvaidhīkṛta": ['ap90', 'mw'],
    "dvaigata": ['mw'],
    "dvaiguṇika": ['mw'],
    "dvaiguṇikaḥ": ['ap90'],
    "dvaiguṇya": ['cae', 'ddsa', 'mw'],
    "dvaiguṇyaṃ": ['ap90'],
    "dvaihāyana": ['mw'],
    "dvaihāyanaṃ": ['ap90'],
    "dvaijāta": ['cae', 'ddsa', 'mw'],
    "dvaikulijika": ['mw'],
    "dvailiṅgya": ['mw'],
    "dvaimatya": ['mw'],
    "dvaimitri": ['mw'],
    "dvaimāsya": ['cae', 'mw'],
    "dvaimātura": ['ap90', 'cae', 'ddsa', 'mw'],
    "dvaimātṛka": ['ap90', 'mw'],
    "dvaipa": ['ap90', 'cae', 'ddsa', 'mw'],
    "dvaipada": ['ddsa', 'mw'],
    "dvaipadaśas": ['mw'],
    "dvaipadika": ['mw'],
    "dvaipaka": ['mw'],
    "dvaipakṣa": ['mw'],
    "dvaipakṣaṃ": ['ap90'],
    "dvaipakṣya": ['mw'],
    "dvaiparāka": ['mw'],
    "dvaipya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dvaipyabhaimāyana": ['mw'],
    "dvaipārāyaṇika": ['mw'],
    "dvaipāyana": ['cae', 'ddsa', 'mw'],
    "dvaipāyanaḥ": ['ap90'],
    "dvairatha": ['cae', 'mw'],
    "dvairathaṃ": ['ap90'],
    "dvairājya": ['cae', 'mw'],
    "dvairājyaṃ": ['ap90'],
    "dvairātrika": ['mw'],
    "dvairūpya": ['mw'],
    "dvaisamika": ['ap90', 'mw'],
    "dvaisaṃdhya": ['mw'],
    "dvaita": ['cae', 'ddsa', 'mw'],
    "dvaitabhāna": ['cae'],
    "dvaitabhūṣaṇa": ['mw'],
    "dvaitabhṛta": ['mw'],
    "dvaitanirṇaya": ['mw'],
    "dvaitanirṇayaphakkikā": ['mw'],
    "dvaitanirṇayasiddhāntasaṃgraha": ['mw'],
    "dvaitanirṇayaśivapūjāsaṃgraha": ['mw'],
    "dvaitanirṇayaṭīkā": ['mw'],
    "dvaitapariśiṣṭa": ['mw'],
    "dvaitasiddhi": ['mw'],
    "dvaitasiddhāntasaṃgraha": ['mw'],
    "dvaitavaitathyopaniṣad": ['mw'],
    "dvaitavana": ['mw'],
    "dvaitaviveka": ['mw'],
    "dvaitavāda": ['cae', 'mw'],
    "dvaitavādin": ['mw'],
    "dvaitaṃ": ['ap90'],
    "dvaitin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dvaitādvaitamārga": ['mw'],
    "dvaitādvaitamārgaparibhraṣṭa": ['mw'],
    "dvaitīyaka": ['bhs', 'mw'],
    "dvaitīyīka": ['ap90', 'mw'],
    "dvaitīyīkatā": ['mw'],
    "dvaivacana": ['mw'],
    "dvaivarṣika": ['mw'],
    "dvaividhya": ['cae', 'mw'],
    "dvaividhyaṃ": ['ap90'],
    "dvaivārṣika": ['ap90'],
    "dvaiyahakālya": ['mw'],
    "dvaiyahnika": ['mw'],
    "dvaiyogya": ['mw'],
    "dvaiyāhāvaka": ['mw'],
    "dvaiśāṇa": ['mw'],
    "dvaiṣaṇīyā": ['mw'],
    "dvaka": ['cae', 'gra', 'mw'],
    "dvandva": ['ddsa'],
    "dvandvacara": ['ddsa'],
    "dvandvin": ['ddsa'],
    "dvandvībhū": ['ddsa'],
    "dvar": ['gra'],
    "dvara": ['cae', 'gra', 'mw'],
    "dvaras": ['gra'],
    "dvari": ['cae', 'gra', 'mw'],
    "dvarin": ['cae', 'gra', 'mw'],
    "dvatricaturam": ['ddsa'],
    "dvattikkhattuṁ": ['cped'],
    "dvattiṁsa": ['cped'],
    "dvattiṁsati": ['cped'],
    "dvattiṁsaṁ": ['cped'],
    "dvattiṁsā": ['cped'],
    "dvay": ['gra'],
    "dvaya": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dvayabhāratī": ['mw'],
    "dvayadvayasamāpatti": ['mw'],
    "dvayagāmi(n)": ['cped'],
    "dvayahīna": ['ddsa', 'mw'],
    "dvayakāri(n)": ['cped'],
    "dvayam": ['mw'],
    "dvayamati": ['bhs'],
    "dvayas": ['gra', 'mw'],
    "dvayasa": ['ap90', 'ddsa', 'mw'],
    "dvayasata": ['mw'],
    "dvayat": ['mw'],
    "dvayatā": ['cped'],
    "dvayavādin": ['mw'],
    "dvayaṁdvayasamāpatti": ['cped'],
    "dvayena": ['cped'],
    "dvayin": ['mw'],
    "dvayopaniṣad": ['mw'],
    "dvayu": ['cae', 'gra', 'mw'],
    "dvayāgni": ['mw'],
    "dvayātiga": ['mw'],
    "dvayātmaka": ['mw'],
    "dvayāvin": ['cae', 'ddsa', 'gra', 'mw'],
    "dvayī": ['mw'],
    "dvaṃda": ['mw'],
    "dvaṃdaḥ": ['ap90'],
    "dvaṃdva": ['cae', 'mw'],
    "dvaṃdvabhinna": ['mw'],
    "dvaṃdvabhāva": ['cae', 'mw'],
    "dvaṃdvabhūta": ['mw'],
    "dvaṃdvacara": ['mw'],
    "dvaṃdvacārin": ['mw'],
    "dvaṃdvaduḥkha": ['mw'],
    "dvaṃdvaja": ['mw'],
    "dvaṃdvalakṣaṇavāda": ['mw'],
    "dvaṃdvam": ['mw'],
    "dvaṃdvamoha": ['mw'],
    "dvaṃdvasahiṣṇutva": ['mw'],
    "dvaṃdvasahiṣṇutā": ['mw'],
    "dvaṃdvasamprahāra": ['mw'],
    "dvaṃdvavicāra": ['mw'],
    "dvaṃdvayodhin": ['mw'],
    "dvaṃdvayuddha": ['mw'],
    "dvaṃdvayuddhavarṇana": ['mw'],
    "dvaṃdvaśas": ['cae', 'mw'],
    "dvaṃdvaśaḥ": ['ap90'],
    "dvaṃdvaṃ": ['ap90'],
    "dvaṃdve": ['mw'],
    "dvaṃdvena": ['mw'],
    "dvaṃdvin": ['ap90', 'cae', 'mw'],
    "dvaṃdvādikośa": ['mw'],
    "dvaṃdvālāpa": ['mw'],
    "dvaṃdvārāma": ['mw'],
    "dvaṃdvātīta": ['mw'],
    "dvaṃdvī": ['cae'],
    "dvaṃdvībhū": ['mw'],
    "dvaṃdvībhūta": ['ap90'],
    "dvaṅgula": ['cped'],
    "dvaṅgulakappa": ['cped'],
    "dvaṅgulapañña": ['cped'],
    "dvaṅgulipañña": ['cped'],
    "dvaṭṭhi": ['cped'],
    "dve": ['bhs', 'cped'],
    "dvecattālīsa": ['cped'],
    "dvecattārīsa": ['cped'],
    "dvecattāḷīsa": ['cped'],
    "dvecatu(r)": ['cped'],
    "dvecaturaśīti": ['bhs'],
    "dvedhikajāta": ['cped'],
    "dvedhā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "dvedhākriyā": ['ddsa', 'mw'],
    "dvedhākāram": ['mw'],
    "dvedhākṛta": ['mw'],
    "dvedhī": ['mw'],
    "dvedhīkṛta": ['mw'],
    "dvehika": ['bhs'],
    "dvejjha": ['cped'],
    "dvemāsa": ['cped'],
    "dvemāsika": ['bhs'],
    "dvenavuti": ['cped'],
    "dvepaññāsa": ['cped'],
    "dvepaṇṇāsa": ['cped'],
    "dvesata": ['mw'],
    "dvesattati": ['cped'],
    "dvevassahassāyuka": ['cped'],
    "dvevassatāyuka": ['cped'],
    "dvevācika": ['cped'],
    "dvevācikaṁ": ['cped'],
    "dvevīsati(ṁ)": ['cped'],
    "dveṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "dveṣakalpa": ['mw'],
    "dveṣaparimocana": ['mw'],
    "dveṣaparimuktā": ['bhs', 'mw'],
    "dveṣas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dveṣastha": ['cae', 'ddsa', 'mw'],
    "dveṣaḥ": ['ap90'],
    "dveṣaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "dveṣaṇīya": ['cae', 'mw'],
    "dveṣin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dveṣoyavana": ['mw'],
    "dveṣoyut": ['gra', 'mw'],
    "dveṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dveṣyapāpaka": ['mw'],
    "dveṣyatva": ['mw'],
    "dveṣyatā": ['cae', 'mw'],
    "dveṣṭos": ['mw'],
    "dveṣṭum": ['mw'],
    "dveṣṭṛ": ['cae', 'mw'],
    "dvi": ['ap90', 'bhs', 'cae', 'cped', 'gra', 'mw'],
    "dvi(r)": ['cped'],
    "dvibandhu": ['gra', 'mw'],
    "dvibarhajman": ['gra', 'mw'],
    "dvibarhas": ['gra', 'mw'],
    "dvibarhās": ['mw'],
    "dvibhallaka": ['mw'],
    "dvibhauma": ['mw'],
    "dvibhuja": ['cae', 'mw'],
    "dvibhujarāmadhyāna": ['mw'],
    "dvibhādra": ['mw'],
    "dvibhāga": ['cae', 'mw'],
    "dvibhāgadhana": ['mw'],
    "dvibhārya": ['mw'],
    "dvibhāryāgni": ['mw'],
    "dvibhāta": ['mw'],
    "dvibhātatva": ['mw'],
    "dvibhāva": ['mw'],
    "dvibhūma": ['mw'],
    "dvibindu": ['mw'],
    "dvibāhu": ['cae', 'mw'],
    "dvibāhuka": ['mw'],
    "dvibāṇī": ['mw'],
    "dvicakra": ['mw'],
    "dvicandra": ['mw'],
    "dvicaraṇa": ['mw'],
    "dvicatu(r)": ['cped'],
    "dvicaturaśraka": ['ddsa', 'mw'],
    "dvicaturaṅgagāmi(n)": ['cped'],
    "dvicatvāri": ['mw'],
    "dvicatvāriṃśa": ['mw'],
    "dvicatvāriṃśat": ['mw'],
    "dvicatvāriṃśika": ['mw'],
    "dvicchinna": ['mw'],
    "dvicātvāriṃśika": ['mw'],
    "dvicūḍa": ['mw'],
    "dvidaivasika": ['bhs'],
    "dvidaivatyā": ['mw'],
    "dvidala": ['mw'],
    "dvidalā": ['mw'],
    "dvidanta": ['mw'],
    "dvidat": ['mw'],
    "dvidatta": ['mw'],
    "dvidaśa": ['mw'],
    "dvidaṇḍi": ['mw'],
    "dvidaṇḍin": ['bhs', 'mw'],
    "dvideha": ['mw'],
    "dvidevata": ['mw'],
    "dvidevatya": ['mw'],
    "dvidevatyapātra": ['mw'],
    "dvidha": ['ap90', 'cae', 'ddsa', 'mw'],
    "dvidhā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dvidhābhāvam": ['mw'],
    "dvidhābhū": ['mw'],
    "dvidhābhūtākṛti": ['cae', 'mw'],
    "dvidhāgam": ['mw'],
    "dvidhāgati": ['mw'],
    "dvidhākaraṇa": ['mw'],
    "dvidhākāra": ['ddsa', 'mw'],
    "dvidhākāram": ['mw'],
    "dvidhākṛ": ['mw'],
    "dvidhālekhya": ['mw'],
    "dvidhāpatha": ['cped'],
    "dvidhāra": ['gra', 'mw'],
    "dvidhāsthita": ['cae', 'mw'],
    "dvidhātmaka": ['mw'],
    "dvidhātu": ['mw'],
    "dvidhūrvaha": ['mw'],
    "dvidiva": ['mw'],
    "dvidroṇa": ['cae', 'mw'],
    "dvidugamavaratarahanutta": ['cped'],
    "dvidāmnī": ['mw'],
    "dvigarta": ['mw'],
    "dvigat": ['mw'],
    "dvigata": ['mw'],
    "dvigava": ['mw'],
    "dvigotra": ['ddsa', 'mw'],
    "dvigu": ['cae', 'mw'],
    "dviguṇa": ['cae', 'cped', 'mw'],
    "dviguṇatara": ['mw'],
    "dviguṇataram": ['mw'],
    "dviguṇatva": ['mw'],
    "dviguṇatā": ['mw'],
    "dviguṇay": ['cae'],
    "dviguṇaya": ['ddsa', 'mw'],
    "dviguṇita": ['mw'],
    "dviguṇā": ['mw'],
    "dviguṇākarṇa": ['mw'],
    "dviguṇāya": ['ddsa', 'mw'],
    "dviguṇībhū": ['mw'],
    "dviguṇīkṛ": ['cae', 'ddsa', 'mw'],
    "dvigūḍha": ['mw'],
    "dvihalya": ['mw'],
    "dvihan": ['mw'],
    "dvihasta": ['mw'],
    "dvihavis": ['mw'],
    "dvihiṃkāra": ['mw'],
    "dvihotṛ": ['mw'],
    "dvihāyana": ['cae', 'ddsa', 'mw'],
    "dvihāyanī": ['mw'],
    "dvihīna": ['mw'],
    "dvihūtavat": ['mw'],
    "dvihṛdayā": ['mw'],
    "dvija": ['cae', 'cped', 'ddsa', 'mw'],
    "dvijabandhu": ['mw'],
    "dvijabruva": ['mw'],
    "dvijacchattra": ['mw'],
    "dvijadeva": ['mw'],
    "dvijadevadeva": ['mw'],
    "dvijadharmin": ['cae'],
    "dvijadāsa": ['mw'],
    "dvijajetṛ": ['mw'],
    "dvijakalpalatā": ['mw'],
    "dvijaketu": ['mw'],
    "dvijakutsita": ['mw'],
    "dvijaliṅgin": ['cae', 'mw'],
    "dvijamalla": ['mw'],
    "dvijamaya": ['ddsa', 'mw'],
    "dvijamukhya": ['mw'],
    "dvijanayana": ['mw'],
    "dvijaniṣevita": ['mw'],
    "dvijanman": ['cae', 'gra', 'mw'],
    "dvijapati": ['mw'],
    "dvijaprapā": ['mw'],
    "dvijapriya": ['mw'],
    "dvijaropaṇī": ['mw'],
    "dvijarāja": ['mw'],
    "dvijarājodaya": ['mw'],
    "dvijarṣabha": ['cae', 'mw'],
    "dvijarṣi": ['cae', 'mw'],
    "dvijasattama": ['cae', 'mw'],
    "dvijasevaka": ['mw'],
    "dvijasevā": ['mw'],
    "dvijasneha": ['mw'],
    "dvijatva": ['mw'],
    "dvijavara": ['cae', 'mw'],
    "dvijavarya": ['mw'],
    "dvijavatsala": ['cae'],
    "dvijavraṇa": ['mw'],
    "dvijavāhana": ['mw'],
    "dvijaśapta": ['mw'],
    "dvijaśreṣṭha": ['cae', 'mw'],
    "dvijendra": ['cae', 'ddsa', 'mw'],
    "dvijendraka": ['mw'],
    "dvijeśa": ['mw'],
    "dvijeśvara": ['cae', 'mw'],
    "dvijihva": ['cae', 'ddsa', 'mw'],
    "dvijihvatva": ['mw'],
    "dvijihvatā": ['mw'],
    "dvijihvika": ['bhs'],
    "dvijivha": ['cped'],
    "dvijjha": ['cped'],
    "dvijopāsaka": ['mw'],
    "dvijottama": ['cae', 'mw'],
    "dvijyā": ['mw'],
    "dvijyāmārga": ['mw'],
    "dvijā": ['cae', 'gra', 'mw'],
    "dvijādi": ['cae'],
    "dvijāgrya": ['cae', 'mw'],
    "dvijāgryārcā": ['cae'],
    "dvijālaya": ['mw'],
    "dvijāmbā": ['mw'],
    "dvijāni": ['cae', 'gra', 'mw'],
    "dvijāti": ['cae', 'cped', 'ddsa', 'mw'],
    "dvijātimukhya": ['mw'],
    "dvijātipravara": ['mw'],
    "dvijātirājan": ['bhs'],
    "dvijātisāt": ['mw'],
    "dvijātisātkṛ": ['ddsa'],
    "dvijātīya": ['mw'],
    "dvijāya": ['mw'],
    "dvijāyanī": ['mw'],
    "dvijāṅgikā": ['mw'],
    "dvijāṅgī": ['mw'],
    "dvijībhū": ['mw'],
    "dvika": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "dvikakud": ['mw'],
    "dvikakāra": ['mw'],
    "dvikapāla": ['mw'],
    "dvikapṛṣṭha": ['mw'],
    "dvikara": ['mw'],
    "dvikaraṇī": ['mw'],
    "dvikarmaka": ['cae', 'ddsa', 'mw'],
    "dvikarmavāda": ['mw'],
    "dvikauḍavika": ['mw'],
    "dvikhaṇḍikā": ['mw'],
    "dvikhura": ['mw'],
    "dvikhurin": ['mw'],
    "dvikhārīka": ['mw'],
    "dvikkhattuṁ": ['cped'],
    "dvikoṇa": ['mw'],
    "dvikrama": ['mw'],
    "dvikubja": ['mw'],
    "dvikulija": ['mw'],
    "dvikulijika": ['mw'],
    "dvikulijīna": ['mw'],
    "dvikuṭika": ['cped'],
    "dvikālam": ['mw'],
    "dvikārṣāpaṇa": ['mw'],
    "dvikārṣāpaṇika": ['mw'],
    "dvikāṇḍa": ['mw'],
    "dvikūbara": ['mw'],
    "dvilakṣa": ['cae', 'ddsa', 'mw'],
    "dvilakṣaṇa": ['cae', 'mw'],
    "dvilaya": ['cae', 'mw'],
    "dvimantha": ['mw'],
    "dvimaya": ['mw'],
    "dvimodakikā": ['mw'],
    "dvimukha": ['cae', 'mw'],
    "dvimukhoraga": ['mw'],
    "dvimukhā": ['mw'],
    "dvimukhāhi": ['mw'],
    "dvimuni": ['mw'],
    "dvimusali": ['mw'],
    "dvimārga": ['mw'],
    "dvimārgī": ['mw'],
    "dvimāsa": ['cped'],
    "dvimāsādi": ['cae'],
    "dvimātra": ['cae', 'mw'],
    "dvimātrā": ['mw'],
    "dvimātṛ": ['gra', 'mw'],
    "dvimātṛja": ['mw'],
    "dvimāṣya": ['mw'],
    "dvimīḍha": ['mw'],
    "dvimūlaka": ['cped'],
    "dvimūlika": ['cped'],
    "dvimūrdha": ['mw'],
    "dvimūrdhan": ['cae', 'mw'],
    "dvinagnaka": ['mw'],
    "dvinaiṣkika": ['mw'],
    "dvinavakṛtvas": ['mw'],
    "dvinavata": ['mw'],
    "dvinavati": ['mw'],
    "dvinavatitama": ['mw'],
    "dvinayanī": ['mw'],
    "dvinetra": ['mw'],
    "dvinetrabhedin": ['ddsa', 'mw'],
    "dvinidhana": ['mw'],
    "dviniṣka": ['mw'],
    "dvināman": ['mw'],
    "dvinārāśaṃsa": ['mw'],
    "dvipa": ['cae', 'ddsa', 'mw'],
    "dvipad": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dvipada": ['cae', 'cped', 'ddsa', 'mw'],
    "dvipadaka": ['bhs'],
    "dvipadapati": ['mw'],
    "dvipadarāśi": ['mw'],
    "dvipadikā": ['cae', 'ddsa', 'mw'],
    "dvipadā": ['mw'],
    "dvipadābhyāsa": ['mw'],
    "dvipadāna": ['ddsa', 'mw'],
    "dvipadāntara": ['mw'],
    "dvipadī": ['ddsa', 'mw'],
    "dvipadīkhaṇḍa": ['cae'],
    "dvipakṣa": ['mw'],
    "dvipamada": ['mw'],
    "dvipapati": ['ddsa', 'mw'],
    "dvipari": ['bhs', 'mw'],
    "dviparājavikrama": ['mw'],
    "dviparāka": ['mw'],
    "dviparārdhika": ['mw'],
    "dviparṇa": ['mw'],
    "dviparṇī": ['mw'],
    "dvipatha": ['mw'],
    "dvipathā": ['mw'],
    "dvipatnīka": ['mw'],
    "dvipattraka": ['mw'],
    "dvipauruṣa": ['mw'],
    "dvipañcadvayasāṅgula": ['mw'],
    "dvipañcamūla": ['mw'],
    "dvipañcaviṃśa": ['ddsa', 'mw'],
    "dvipañcāśa": ['mw'],
    "dvipañcāśat": ['mw'],
    "dvipañcāśattama": ['mw'],
    "dvipaśu": ['mw'],
    "dvipaśutva": ['mw'],
    "dvipaṇya": ['mw'],
    "dvipendra": ['cae', 'mw'],
    "dvipendradāna": ['mw'],
    "dvipeśvara": ['cae', 'mw'],
    "dvipitṛ": ['mw'],
    "dvipitṛka": ['mw'],
    "dviporisa": ['cped'],
    "dviporisaṁ": ['cped'],
    "dvipraiṣa": ['mw'],
    "dviprasūtā": ['bhs'],
    "dvipratihāra": ['mw'],
    "dvipratika": ['mw'],
    "dvipratiṣṭha": ['mw'],
    "dvipravrājinī": ['ddsa', 'mw'],
    "dvipravācana": ['mw'],
    "dvipuruṣa": ['mw'],
    "dvipuruṣam": ['mw'],
    "dvipuruṣā": ['mw'],
    "dvipuṭa": ['bhs', 'mw'],
    "dvipuṭī": ['mw'],
    "dvipād": ['mw'],
    "dvipāda": ['cae', 'ddsa', 'mw'],
    "dvipādaka": ['bhs', 'cped', 'mw'],
    "dvipādikā": ['mw'],
    "dvipādya": ['mw'],
    "dvipāri": ['cae', 'ddsa', 'mw'],
    "dvipāsya": ['mw'],
    "dvipātra": ['mw'],
    "dvipātrika": ['mw'],
    "dvipātrīṇa": ['mw'],
    "dvipāttva": ['mw'],
    "dvipāttā": ['mw'],
    "dvipāyin": ['ddsa', 'mw'],
    "dvipāyya": ['mw'],
    "dvipṛṣṭha": ['mw'],
    "dvir": ['mw'],
    "dvira": ['mw'],
    "dvirabhyasta": ['mw'],
    "dvirabhyāsākūpara": ['mw'],
    "dvirada": ['cae', 'mw'],
    "dviradagāmin": ['mw'],
    "dviradakarāgra": ['mw'],
    "dviradamaya": ['mw'],
    "dviradapati": ['mw'],
    "dviradarata": ['mw'],
    "dviradāntaka": ['mw'],
    "dviradārāti": ['mw'],
    "dviradāsya": ['mw'],
    "dviradāśana": ['mw'],
    "dviranugāna": ['mw'],
    "dvirasana": ['mw'],
    "dviraśana": ['mw'],
    "dviraṃsaka": ['mw'],
    "dvirbhāva": ['ddsa', 'mw'],
    "dvirepha": ['cae', 'mw'],
    "dvirephacaya": ['mw'],
    "dvirephagaṇasammitā": ['mw'],
    "dvirephagaṇasaṃkulā": ['mw'],
    "dvirephamālā": ['mw'],
    "dvirephavṛnda": ['mw'],
    "dviretas": ['mw'],
    "dviriḍa": ['mw'],
    "dvirnagna": ['mw'],
    "dviroṣṭhya": ['mw'],
    "dviroṣṭhyatva": ['mw'],
    "dviruccārita": ['cae', 'mw'],
    "dvirudātta": ['mw'],
    "dvirukta": ['cae', 'ddsa', 'mw'],
    "dvirukti": ['cae', 'mw'],
    "dviruktikośa": ['mw'],
    "dviruktiprakriyā": ['mw'],
    "dviruttarapadasaṃdhilipi": ['bhs'],
    "dvirvacana": ['cae', 'mw'],
    "dvirvyūha": ['mw'],
    "dvirāgamana": ['mw'],
    "dvirāgamanaprakaraṇa": ['mw'],
    "dvirāja": ['mw'],
    "dvirāmuṣyāyaṇa": ['mw'],
    "dvirāpa": ['mw'],
    "dvirātra": ['cae', 'mw'],
    "dvirātrīṇa": ['mw'],
    "dvirāvaṭṭa": ['cped'],
    "dvirāṣāḍha": ['mw'],
    "dvirūpa": ['cae', 'ddsa', 'mw'],
    "dvirūpakośa": ['mw'],
    "dvirūpatā": ['mw'],
    "dvirūḍhā": ['mw'],
    "dvis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dvisahasra": ['cae', 'mw'],
    "dvisahasrākṣa": ['mw'],
    "dvisahassa": ['cped'],
    "dvisahassakkhattuṁ": ['cped'],
    "dvisama": ['mw'],
    "dvisamacaturaśra": ['mw'],
    "dvisamatribhuja": ['mw'],
    "dvisamuṭṭhānika": ['cped'],
    "dvisamīna": ['mw'],
    "dvisaptadhā": ['mw'],
    "dvisaptan": ['mw'],
    "dvisaptasaṃkhyāka": ['mw'],
    "dvisaptata": ['mw'],
    "dvisaptati": ['ddsa', 'mw'],
    "dvisaptatitama": ['mw'],
    "dvisattvalakṣaṇa": ['mw'],
    "dvisauvarṇika": ['mw'],
    "dvisaṃdhi": ['mw'],
    "dvisaṃdhya": ['mw'],
    "dvisaṃstha": ['mw'],
    "dvisaṃsthita": ['mw'],
    "dvisaṃvatsarīṇa": ['mw'],
    "dvisrakti": ['mw'],
    "dvistanā": ['mw'],
    "dvistanī": ['mw'],
    "dvisthūṇa": ['mw'],
    "dvistvala": ['bhs'],
    "dvistāvā": ['mw'],
    "dvisuvarṇa": ['mw'],
    "dvisvabhāva": ['mw'],
    "dvisvara": ['mw'],
    "dvisāhasra": ['bhs', 'mw'],
    "dvisāhasrika": ['bhs'],
    "dvisāptatika": ['mw'],
    "dvisāṃvatsarika": ['mw'],
    "dvisītya": ['mw'],
    "dvisūrya": ['mw'],
    "dvita": ['cae', 'ddsa', 'gra', 'mw'],
    "dvitavana": ['mw'],
    "dvitaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dvitiya": ['bhs'],
    "dvitra": ['cae', 'ddsa', 'mw'],
    "dvitrayastriṃśat": ['mw'],
    "dvitri": ['mw'],
    "dvitricaturabhāga": ['cae'],
    "dvitricaturam": ['mw'],
    "dvitricaturbhāga": ['mw'],
    "dvitricatuṣpañcaka": ['mw'],
    "dvitridivasanivāsa": ['mw'],
    "dvitris": ['mw'],
    "dvitriveṇu": ['mw'],
    "dvittikkhattuṁ": ['cped'],
    "dvittā": ['cped'],
    "dvitva": ['cae', 'ddsa', 'mw'],
    "dvitvatva": ['mw'],
    "dvitvaṃ": ['ap90'],
    "dvitā": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dvitāla": ['cped'],
    "dvitālaṁ": ['cped'],
    "dvitīya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dvitīyabhāga": ['cae'],
    "dvitīyacakravartilakṣaṇa": ['mw'],
    "dvitīyacakravartilakṣaṇadīdhitiṭīkā": ['mw'],
    "dvitīyacakravartilakṣaṇaprakāśa": ['mw'],
    "dvitīyacakravartilakṣaṇarahasya": ['mw'],
    "dvitīyacakravartilakṣaṇānugama": ['mw'],
    "dvitīyaka": ['ap90', 'mw'],
    "dvitīyakam": ['bhs'],
    "dvitīyakuladhāraka": ['mw'],
    "dvitīyam": ['mw'],
    "dvitīyamiśralakṣaṇa": ['mw'],
    "dvitīyamiśralakṣaṇaprakāśa": ['mw'],
    "dvitīyamiśralakṣaṇavivecana": ['mw'],
    "dvitīyamiśralakṣaṇānugama": ['mw'],
    "dvitīyapragalbhalakṣaṇa": ['mw'],
    "dvitīyapragalbhalakṣaṇānugama": ['mw'],
    "dvitīyasvalakṣaṇa": ['mw'],
    "dvitīyasvalakṣaṇadīdhitiṭīkā": ['mw'],
    "dvitīyasvalakṣaṇarahasya": ['mw'],
    "dvitīyasvalakṣaṇaṭīkā": ['mw'],
    "dvitīyasvalakṣaṇāloka": ['mw'],
    "dvitīyasvalakṣaṇānugama": ['mw'],
    "dvitīyasvara": ['mw'],
    "dvitīyatantra": ['mw'],
    "dvitīyatriphalā": ['mw'],
    "dvitīyatva": ['mw'],
    "dvitīyatā": ['mw'],
    "dvitīyatāla": ['mw'],
    "dvitīyavat": ['mw'],
    "dvitīyavayas": ['mw'],
    "dvitīyika": ['mw'],
    "dvitīyin": ['ap90', 'mw'],
    "dvitīyā": ['bhs', 'mw'],
    "dvitīyābhā": ['mw'],
    "dvitīyācandra": ['cae', 'mw'],
    "dvitīyādivyutpattivāda": ['mw'],
    "dvitīyākalpa": ['mw'],
    "dvitīyākṛ": ['ap90', 'mw'],
    "dvitīyākṛta": ['ap90'],
    "dvitīyārcanacandrikā": ['mw'],
    "dvitīyārcanakalpalatā": ['mw'],
    "dvitīyātantra": ['mw'],
    "dvitīyāṃśa": ['cae'],
    "dvitīyūka": ['mw'],
    "dvivacana": ['cae', 'mw'],
    "dvivacanānta": ['mw'],
    "dvivacas": ['mw'],
    "dvivaistika": ['mw'],
    "dvivajraka": ['mw'],
    "dvivaktra": ['cae', 'mw'],
    "dvivartani": ['gra'],
    "dvivarṇa": ['cae', 'mw'],
    "dvivarṇaratha": ['mw'],
    "dvivarṣa": ['cae', 'mw'],
    "dvivarṣaka": ['cae', 'mw'],
    "dvivarṣā": ['mw'],
    "dvivarṣīṇa": ['mw'],
    "dvivastra": ['mw'],
    "dviveda": ['mw'],
    "dvivedagaṅga": ['mw'],
    "dvivedin": ['mw'],
    "dvivesarā": ['mw'],
    "dvivida": ['mw'],
    "dvividha": ['cae', 'mw'],
    "dvividhā": ['mw'],
    "dvividāri": ['mw'],
    "dvivista": ['mw'],
    "dvivivāhin": ['mw'],
    "dvivivāhitāsapiṇḍīkaraṇa": ['mw'],
    "dviviṃśatikīna": ['mw'],
    "dvivrata": ['mw'],
    "dvivraṇīya": ['mw'],
    "dvivyāma": ['mw'],
    "dvivyāyāma": ['mw'],
    "dvivācin": ['mw'],
    "dvivāhikā": ['mw'],
    "dvivārṣika": ['cae', 'mw'],
    "dvivṛntāya": ['mw'],
    "dvivṛṣa": ['mw'],
    "dviyaja": ['mw'],
    "dviyajatva": ['mw'],
    "dviyajus": ['mw'],
    "dviyajñopavītin": ['mw'],
    "dviyama": ['mw'],
    "dviyamunam": ['mw'],
    "dviyodha": ['mw'],
    "dviyodhī": ['mw'],
    "dviyojanasatika": ['cped'],
    "dviyāmī": ['mw'],
    "dviśapha": ['cae', 'mw'],
    "dviśarīra": ['mw'],
    "dviśas": ['ap90', 'cae', 'mw'],
    "dviśata": ['cae', 'ddsa', 'mw'],
    "dviśataka": ['mw'],
    "dviśatatama": ['mw'],
    "dviśatikā": ['mw'],
    "dviśatottarasāhasra": ['mw'],
    "dviśatya": ['mw'],
    "dviśatī": ['mw'],
    "dviśaurpika": ['mw'],
    "dviśavas": ['cae', 'gra', 'mw'],
    "dviśikha": ['mw'],
    "dviśiras": ['cae', 'mw'],
    "dviśiraska": ['mw'],
    "dviśruti": ['mw'],
    "dviśukla": ['mw'],
    "dviśuklavat": ['mw'],
    "dviśākha": ['mw'],
    "dviśākhaka": ['mw'],
    "dviśāla": ['mw'],
    "dviśāṇa": ['mw'],
    "dviśāṇika": ['mw'],
    "dviśāṇya": ['mw'],
    "dviśīrṣa": ['mw'],
    "dviśīrṣaka": ['mw'],
    "dviśūla": ['mw'],
    "dviśūrpa": ['mw'],
    "dviśṛṅga": ['cae', 'mw'],
    "dviśṛṅgikā": ['mw'],
    "dviśṛṅgin": ['mw'],
    "dvi˚": ['ddsa'],
    "dviḍha": ['mw'],
    "dviḥ": ['mw'],
    "dviḥsama": ['cae', 'ddsa', 'mw'],
    "dviḥsvara": ['mw'],
    "dviṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dviṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "dviṣadanna": ['cae'],
    "dviṣadā": ['mw'],
    "dviṣadāyus": ['cae'],
    "dviṣant": ['cae'],
    "dviṣat": ['ap90', 'ddsa', 'mw'],
    "dviṣatva": ['mw'],
    "dviṣatā": ['mw'],
    "dviṣatītāpa": ['mw'],
    "dviṣaḥ": ['ap90'],
    "dviṣaṃdhi": ['mw'],
    "dviṣaṃhita": ['mw'],
    "dviṣaṃtapa": ['mw'],
    "dviṣaṇḍika": ['mw'],
    "dviṣaṣ": ['mw'],
    "dviṣaṣṭa": ['mw'],
    "dviṣaṣṭi": ['mw'],
    "dviṣaṣṭitama": ['mw'],
    "dviṣaṣṭivākya": ['mw'],
    "dviṣeṇia": ['gra'],
    "dviṣpakva": ['mw'],
    "dviṣā": ['mw'],
    "dviṣāhasra": ['mw'],
    "dviṣāṣṭika": ['mw'],
    "dviṣūkta": ['mw'],
    "dviṣṭa": ['ap90', 'cae', 'mw'],
    "dviṣṭamām": ['mw'],
    "dviṣṭarām": ['mw'],
    "dviṣṭatva": ['ddsa', 'mw'],
    "dviṣṭha": ['mw'],
    "dviṣṭhatā": ['mw'],
    "dviṭ": ['mw'],
    "dviṭha": ['mw'],
    "dviṭsevin": ['cae', 'ddsa', 'mw'],
    "dviṭsevā": ['mw'],
    "dvy": ['mw'],
    "dvyabhiyoga": ['cae', 'mw'],
    "dvyadhika": ['cae', 'mw'],
    "dvyagni": ['mw'],
    "dvyagra": ['mw'],
    "dvyaha": ['cae', 'mw'],
    "dvyahakāla": ['mw'],
    "dvyaham": ['mw'],
    "dvyahan": ['mw'],
    "dvyahatarṣam": ['mw'],
    "dvyahavṛtta": ['cae', 'mw'],
    "dvyahe": ['mw'],
    "dvyahika": ['bhs'],
    "dvyahāt": ['mw'],
    "dvyahātyāsam": ['mw'],
    "dvyahīna": ['mw'],
    "dvyahīnatva": ['mw'],
    "dvyakṣa": ['cae', 'mw'],
    "dvyakṣara": ['cae', 'mw'],
    "dvyakṣaranāmamālā": ['mw'],
    "dvyantara": ['mw'],
    "dvyanya": ['mw'],
    "dvyanīka": ['mw'],
    "dvyardha": ['cae', 'mw'],
    "dvyartha": ['cae', 'mw'],
    "dvyarthakośa": ['mw'],
    "dvyavara": ['mw'],
    "dvyañjala": ['mw'],
    "dvyaśīta": ['mw'],
    "dvyaśīti": ['mw'],
    "dvyaśītitama": ['mw'],
    "dvyaṃśa": ['cae', 'ddsa', 'mw'],
    "dvyaṃśī": ['mw'],
    "dvyaṅga": ['mw'],
    "dvyaṅgula": ['mw'],
    "dvyaṅgulaprajñā": ['bhs'],
    "dvyaṅgulaśṛṅga": ['mw'],
    "dvyaṇuka": ['cae', 'mw'],
    "dvyaṇukodara": ['mw'],
    "dvyaṇukīya": ['mw'],
    "dvyaṣṭa": ['mw'],
    "dvyaṣṭasahasra": ['mw'],
    "dvyaṣṭasāhasra": ['mw'],
    "dvyekāntara": ['cae', 'mw'],
    "dvyoga": ['mw'],
    "dvyopaśa": ['mw'],
    "dvyudāsa": ['mw'],
    "dvyudātta": ['mw'],
    "dvyuktha": ['ddsa', 'mw'],
    "dvyuraṇa": ['cae', 'mw'],
    "dvyācita": ['mw'],
    "dvyācitika": ['mw'],
    "dvyācitīna": ['mw'],
    "dvyādhāna": ['mw'],
    "dvyāhika": ['mw'],
    "dvyāhāva": ['mw'],
    "dvyākṣāyaṇa": ['mw'],
    "dvyāmnāta": ['mw'],
    "dvyāmuṣyāyaṇa": ['mw'],
    "dvyāmuṣyāyaṇaka": ['mw'],
    "dvyārṣeya": ['mw'],
    "dvyāsya": ['cae', 'ddsa', 'mw'],
    "dvyātmaka": ['mw'],
    "dvyāyuṣa": ['mw'],
    "dvyāśrayakośavṛtti": ['mw'],
    "dvyāḍhaka": ['mw'],
    "dvyāḍhakika": ['mw'],
    "dvyāḍhakīna": ['mw'],
    "dvyṛca": ['mw'],
    "dvā": ['cae', 'ddsa', 'mw'],
    "dvācatvāriṃśa": ['mw'],
    "dvācatvāriṃśat": ['ddsa', 'mw'],
    "dvācatvāriṃśati": ['mw'],
    "dvādasa": ['cped'],
    "dvādasaka": ['cped'],
    "dvādasaki(n)": ['cped'],
    "dvādasama": ['cped'],
    "dvādasamāsika": ['cped'],
    "dvādasamāsiya": ['cped'],
    "dvādasanahuta": ['cped'],
    "dvādasaporisa": ['cped'],
    "dvādasapurisa": ['cped'],
    "dvādasavassa": ['cped'],
    "dvādasayojana": ['cped'],
    "dvādaśa": ['cae', 'ddsa', 'gra', 'mw'],
    "dvādaśabhavana": ['mw'],
    "dvādaśabhuja": ['mw'],
    "dvādaśabhāva": ['mw'],
    "dvādaśabhāvaphala": ['mw'],
    "dvādaśabhāvavicāra": ['mw'],
    "dvādaśadhā": ['cae', 'mw'],
    "dvādaśagava": ['mw'],
    "dvādaśagopālanirṇayabhakti": ['mw'],
    "dvādaśagṛhīta": ['mw'],
    "dvādaśajyotirliṅgastotra": ['mw'],
    "dvādaśaka": ['cae', 'ddsa', 'mw'],
    "dvādaśakapāla": ['mw'],
    "dvādaśakara": ['mw'],
    "dvādaśalakṣaṇī": ['mw'],
    "dvādaśaliṅgastavana": ['mw'],
    "dvādaśaliṅgastotra": ['mw'],
    "dvādaśaliṅgodbhava": ['mw'],
    "dvādaśalocana": ['mw'],
    "dvādaśama": ['mw'],
    "dvādaśamahāsiddhāntanirūpaṇa": ['mw'],
    "dvādaśamahāvākya": ['mw'],
    "dvādaśamahāvākyanirṇaya": ['mw'],
    "dvādaśamahāvākyavivaraṇa": ['mw'],
    "dvādaśamahāvākyāvalī": ['mw'],
    "dvādaśamañjarikā": ['mw'],
    "dvādaśamañjarī": ['mw'],
    "dvādaśamāsadeyadānaratnākara": ['mw'],
    "dvādaśamāsika": ['mw'],
    "dvādaśamātra": ['mw'],
    "dvādaśamūla": ['mw'],
    "dvādaśan": ['cae', 'ddsa', 'gra', 'mw'],
    "dvādaśanidhana": ['mw'],
    "dvādaśanāmapañjara": ['mw'],
    "dvādaśapada": ['ddsa', 'mw'],
    "dvādaśapattra": ['mw'],
    "dvādaśapattraka": ['mw'],
    "dvādaśapañjarikāstotra": ['mw'],
    "dvādaśapuṣkara": ['mw'],
    "dvādaśarca": ['mw'],
    "dvādaśarātra": ['cae', 'mw'],
    "dvādaśarāśiphala": ['mw'],
    "dvādaśasaṃskāra": ['mw'],
    "dvādaśasiddhānta": ['mw'],
    "dvādaśastotra": ['mw'],
    "dvādaśasāhasra": ['cae', 'mw'],
    "dvādaśatva": ['mw'],
    "dvādaśatā": ['mw'],
    "dvādaśavarga": ['bhs', 'mw'],
    "dvādaśavargika": ['bhs'],
    "dvādaśavargīya": ['bhs'],
    "dvādaśavargīyā": ['mw'],
    "dvādaśavatsarī": ['mw'],
    "dvādaśavidha": ['cae', 'mw'],
    "dvādaśavidhaputramīmāṃsā": ['mw'],
    "dvādaśavārṣika": ['cae', 'mw'],
    "dvādaśavārṣikavrata": ['mw'],
    "dvādaśayoga": ['mw'],
    "dvādaśayātrātattva": ['mw'],
    "dvādaśaśata": ['cae', 'mw'],
    "dvādaśaśatadakṣiṇa": ['mw'],
    "dvādaśaśatatama": ['mw'],
    "dvādaśika": ['mw'],
    "dvādaśin": ['mw'],
    "dvādaśodyāma": ['mw'],
    "dvādaśyudyāpana": ['mw'],
    "dvādaśābda": ['cae', 'ddsa', 'mw'],
    "dvādaśābdānantarāvalokanavidhi": ['mw'],
    "dvādaśādhyāyī": ['mw'],
    "dvādaśāditya": ['mw'],
    "dvādaśādityastava": ['mw'],
    "dvādaśādityatīrtha": ['mw'],
    "dvādaśādityāśrama": ['mw'],
    "dvādaśāha": ['cae', 'mw'],
    "dvādaśāhahautra": ['mw'],
    "dvādaśāhamahāvrataprayoga": ['mw'],
    "dvādaśāhamaitrāvaruṇaprayoga": ['mw'],
    "dvādaśāhaprayoga": ['mw'],
    "dvādaśāhaprayogapaddhati": ['mw'],
    "dvādaśāhaprayogavṛtti": ['mw'],
    "dvādaśāhapraśna": ['mw'],
    "dvādaśāhika": ['mw'],
    "dvādaśāhāṇḍabilā": ['mw'],
    "dvādaśāhīya": ['mw'],
    "dvādaśākhya": ['mw'],
    "dvādaśākāra": ['mw'],
    "dvādaśākṛti": ['gra', 'mw'],
    "dvādaśākṣa": ['mw'],
    "dvādaśākṣara": ['mw'],
    "dvādaśākṣaramantra": ['mw'],
    "dvādaśākṣaramālā": ['mw'],
    "dvādaśākṣaravidyā": ['mw'],
    "dvādaśāntaprakaraṇa": ['mw'],
    "dvādaśānyika": ['mw'],
    "dvādaśāra": ['cae', 'gra', 'mw'],
    "dvādaśāratni": ['mw'],
    "dvādaśārcis": ['mw'],
    "dvādaśārka": ['mw'],
    "dvādaśāsra": ['mw'],
    "dvādaśāsri": ['mw'],
    "dvādaśātmaka": ['mw'],
    "dvādaśātman": ['mw'],
    "dvādaśāvarta": ['mw'],
    "dvādaśāyoga": ['mw'],
    "dvādaśāyus": ['mw'],
    "dvādaśāṃśa": ['mw'],
    "dvādaśāṃśu": ['mw'],
    "dvādaśāṅgula": ['mw'],
    "dvādaśāṅgulasāriṇī": ['mw'],
    "dvādaśāṅgī": ['mw'],
    "dvādaśī": ['mw'],
    "dvādaśīmāhātmya": ['mw'],
    "dvādaśītīrtha": ['mw'],
    "dvādaśīvrata": ['mw'],
    "dvādhiṭṭhita": ['cped'],
    "dvāgārika": ['cped'],
    "dvāja": ['ap90', 'mw'],
    "dvākkhāta": ['cped'],
    "dvākāra": ['cped'],
    "dvālopika": ['cped'],
    "dvāmuṣyāyaṇaḥ": ['ap90'],
    "dvānavata": ['mw'],
    "dvānavati": ['mw'],
    "dvāpara": ['cae', 'ddsa', 'mw'],
    "dvāparacchandas": ['mw'],
    "dvāparastoma": ['mw'],
    "dvāparaḥ": ['ap90'],
    "dvāpañcāśa": ['cae', 'ddsa', 'mw'],
    "dvāpañcāśadakṣara": ['mw'],
    "dvāpañcāśat": ['cae', 'mw'],
    "dvār": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dvāra": ['cae', 'cped', 'ddsa', 'mw'],
    "dvārabalibhuj": ['mw'],
    "dvārabandhāvaraṇa": ['mw'],
    "dvārabhatta": ['cped'],
    "dvārabāhu": ['cae', 'mw'],
    "dvārabāhā": ['cped'],
    "dvāradarśin": ['mw'],
    "dvāradāru": ['mw'],
    "dvāradātu": ['mw'],
    "dvārajapasūkta": ['mw'],
    "dvāraka": ['cae', 'ddsa', 'mw'],
    "dvārakapāṭa": ['mw'],
    "dvārakaṇṭaka": ['mw'],
    "dvārakeśa": ['mw'],
    "dvārakosa": ['cped'],
    "dvārakośa": ['bhs'],
    "dvārakoṣṭaka": ['mw'],
    "dvārakoṣṭha": ['bhs'],
    "dvārakoṣṭhaka": ['bhs'],
    "dvārakā": ['ap90', 'mw'],
    "dvārakādāsa": ['mw'],
    "dvārakāmāhātmya": ['mw'],
    "dvārakānātha": ['mw'],
    "dvārakānāthayajvan": ['mw'],
    "dvārakāpraveśa": ['mw'],
    "dvārakārambha": ['mw'],
    "dvāralakṣaṇapaṭala": ['mw'],
    "dvāramahimavarṇana": ['mw'],
    "dvāramukha": ['cae', 'mw'],
    "dvāranāyaka": ['mw'],
    "dvārapa": ['cae', 'mw'],
    "dvārapakṣa": ['cae', 'mw'],
    "dvārapakṣaka": ['cae', 'mw'],
    "dvārapati": ['cae', 'mw'],
    "dvārapaṭṭa": ['mw'],
    "dvāraphalaka": ['cae', 'mw'],
    "dvārapidhāna": ['cae', 'mw'],
    "dvārapiṇḍī": ['mw'],
    "dvārapāla": ['cae', 'mw'],
    "dvārapālaka": ['mw'],
    "dvārapālamantra": ['mw'],
    "dvārapālika": ['mw'],
    "dvārapālikā": ['mw'],
    "dvārapālinī": ['bhs'],
    "dvārapālī": ['bhs'],
    "dvārarakṣaka": ['cae', 'mw'],
    "dvārarakṣin": ['cae', 'mw'],
    "dvārastambha": ['mw'],
    "dvārastha": ['cae', 'mw'],
    "dvārasthita": ['mw'],
    "dvārasthūṇā": ['mw'],
    "dvārasvaraprabhūtakośa": ['bhs'],
    "dvārasālā": ['cped'],
    "dvāratva": ['mw'],
    "dvāratā": ['ddsa', 'mw'],
    "dvāravartman": ['mw'],
    "dvāravat": ['mw'],
    "dvāravatī": ['ap90', 'bhs', 'cae', 'mw'],
    "dvāravatīmāhātmya": ['mw'],
    "dvāravatīnirmāṇa": ['mw'],
    "dvāravaṃśa": ['mw'],
    "dvāravṛtta": ['mw'],
    "dvārayantra": ['mw'],
    "dvārayātrāvidhi": ['mw'],
    "dvāraśobhā": ['cae', 'mw'],
    "dvāraśākhā": ['mw'],
    "dvāraśākhī": ['bhs'],
    "dvāraṃ": ['ap90'],
    "dvārbāhu": ['cae', 'mw'],
    "dvārika": ['cae', 'ddsa', 'mw'],
    "dvārikaḥ": ['ap90'],
    "dvārikā": ['ap90'],
    "dvārin": ['cae', 'mw'],
    "dvārvat": ['mw'],
    "dvārvatī": ['mw'],
    "dvārya": ['cae', 'ddsa', 'mw'],
    "dvāryā": ['mw'],
    "dvārābhimānin": ['mw'],
    "dvārādhipa": ['ddsa', 'mw'],
    "dvārādhyakṣa": ['mw'],
    "dvārāpidhāna": ['mw'],
    "dvārārari": ['mw'],
    "dvārāvatī": ['mw'],
    "dvārāvatīmāhātmya": ['mw'],
    "dvārī": ['mw'],
    "dvārīkṛ": ['cae', 'ddsa', 'mw'],
    "dvāsaptata": ['mw'],
    "dvāsaptati": ['cae', 'ddsa', 'mw'],
    "dvāsaptatīṣṭaka": ['mw'],
    "dvāsattati": ['cped'],
    "dvāsaṭṭhi": ['cped'],
    "dvāstha": ['cae'],
    "dvāsīti": ['cped'],
    "dvātriṃśa": ['cae', 'mw'],
    "dvātriṃśacchālabhañjikā": ['mw'],
    "dvātriṃśadakṣara": ['mw'],
    "dvātriṃśadakṣarin": ['mw'],
    "dvātriṃśadaparādhastotra": ['mw'],
    "dvātriṃśadara": ['mw'],
    "dvātriṃśadrātra": ['mw'],
    "dvātriṃśadupaniṣad": ['mw'],
    "dvātriṃśallakṣaṇika": ['cae', 'mw'],
    "dvātriṃśallakṣaṇikṣaṇopeta": ['cae'],
    "dvātriṃśallakṣaṇopeta": ['mw'],
    "dvātriṃśat": ['cae', 'mw'],
    "dvātriṃśata": ['bhs'],
    "dvātriṃśati": ['mw'],
    "dvātriṃśatikā": ['mw'],
    "dvātriṃśatkarmapaddhati": ['mw'],
    "dvātriṃśatkā": ['mw'],
    "dvātriṃśatpattra": ['mw'],
    "dvātriṃśikā": ['mw'],
    "dvātriṃśāra": ['mw'],
    "dvāviṃśa": ['cae', 'ddsa', 'mw'],
    "dvāviṃśati": ['cae', 'ddsa', 'mw'],
    "dvāviṃśatidhā": ['cae', 'mw'],
    "dvāviṃśatirātra": ['mw'],
    "dvāviṃśatitama": ['mw'],
    "dvāviṃśatiśata": ['mw'],
    "dvāviṃśatiśatama": ['mw'],
    "dvāviṃśatyakṣara": ['mw'],
    "dvāvāṭṭa": ['cped'],
    "dvāvīsa": ['cped'],
    "dvāvīsatima": ['cped'],
    "dvāḥ": ['mw'],
    "dvāḥstha": ['cae', 'ddsa', 'mw'],
    "dvāḥsthita": ['mw'],
    "dvāṃdvika": ['mw'],
    "dvāṣaṣṭa": ['cae', 'mw'],
    "dvāṣaṣṭi": ['mw'],
    "dvāṣaṣṭitama": ['mw'],
    "dvīha": ['cped'],
    "dvīhapaṭicchanna": ['cped'],
    "dvīhatīha": ['cped'],
    "dvīhika": ['bhs', 'cped'],
    "dvīhitika": ['cped'],
    "dvīndriya": ['mw'],
    "dvīndriyagrāhya": ['mw'],
    "dvīpa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "dvīpacchandira": ['mw'],
    "dvīpaja": ['mw'],
    "dvīpaka": ['bhs'],
    "dvīpakarpūraja": ['mw'],
    "dvīpakarpūraka": ['mw'],
    "dvīpakharjurī": ['mw'],
    "dvīpakumāra": ['mw'],
    "dvīparāja": ['mw'],
    "dvīpasambhava": ['mw'],
    "dvīpasambhavā": ['mw'],
    "dvīpavat": ['ap90', 'mw'],
    "dvīpavatī": ['mw'],
    "dvīpavyavasthā": ['mw'],
    "dvīpaśatru": ['mw'],
    "dvīpaśreṣṭha": ['mw'],
    "dvīpaḥ": ['ap90'],
    "dvīpeśa": ['mw'],
    "dvīpi": ['mw'],
    "dvīpicarman": ['cae'],
    "dvīpika": ['bhs'],
    "dvīpikarṇi": ['ddsa', 'mw'],
    "dvīpikā": ['mw'],
    "dvīpin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dvīpinakha": ['mw'],
    "dvīpinī": ['ddsa', 'mw'],
    "dvīpiśatru": ['mw'],
    "dvīpya": ['cae', 'ddsa', 'mw'],
    "dvīpyaḥ": ['ap90'],
    "dvīpyā": ['mw'],
    "dvīpāntaravacā": ['mw'],
    "dvīrāvatīka": ['mw'],
    "dvīḍa": ['mw'],
    "dvṛ": ['ap90', 'mw'],
    "dvṛca": ['ddsa'],
    "dya": ['mw'],
    "dyai": ['ap90', 'mw'],
    "dyau": ['mw'],
    "dyaukāmi": ['mw'],
    "dyauloka": ['mw'],
    "dyaurdā": ['mw'],
    "dyaurloka": ['cae'],
    "dyausaṃśita": ['mw'],
    "dyauta": ['mw'],
    "dyauttra": ['mw'],
    "dyautāna": ['mw'],
    "dyauṣpitṛ": ['mw'],
    "dyavidyavī": ['ap90'],
    "dyo": ['ap90', 'ddsa', 'gra', 'mw'],
    "dyobhūmi": ['mw'],
    "dyobhūmī": ['mw'],
    "dyodruma": ['mw'],
    "dyokāra": ['mw'],
    "dyota": ['cae', 'ddsa', 'mw'],
    "dyotaka": ['ap90', 'cae', 'mw'],
    "dyotakatva": ['mw'],
    "dyotamāna": ['ddsa'],
    "dyotana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dyotanaka": ['mw'],
    "dyotani": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dyotanikā": ['ap90', 'ddsa', 'mw'],
    "dyotaḥ": ['ap90'],
    "dyotin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dyotiriṅgaṇa": ['mw'],
    "dyotis": ['ap90', 'ddsa', 'mw'],
    "dyotita": ['ap90', 'mw'],
    "dyotitaprabha": ['mw'],
    "dyotiṣpatha": ['ddsa', 'mw'],
    "dyotman": ['gra', 'mw'],
    "dyotya": ['cae', 'ddsa', 'mw'],
    "dyotā": ['mw'],
    "dyoṣad": ['mw'],
    "dyu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dyubhakta": ['cae', 'gra', 'mw'],
    "dyucara": ['cae', 'mw'],
    "dyucārin": ['mw'],
    "dyudala": ['mw'],
    "dyudantin": ['mw'],
    "dyudhuni": ['mw'],
    "dyudhāman": ['mw'],
    "dyuga": ['mw'],
    "dyugat": ['cae', 'gra', 'mw'],
    "dyugaṇa": ['mw'],
    "dyujana": ['mw'],
    "dyujaya": ['mw'],
    "dyujyā": ['mw'],
    "dyujīvā": ['mw'],
    "dyuka": ['mw'],
    "dyukarṇārdha": ['mw'],
    "dyukaḥ": ['ap90'],
    "dyukāma": ['mw'],
    "dyukāri": ['mw'],
    "dyukṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dyukṣavacas": ['gra', 'mw'],
    "dyuloka": ['mw'],
    "dyumadgāman": ['mw'],
    "dyumaithuna": ['mw'],
    "dyumant": ['cae'],
    "dyumaryāda": ['mw'],
    "dyumaryādatva": ['mw'],
    "dyumaryādavat": ['mw'],
    "dyumaryādavattva": ['mw'],
    "dyumat": ['ap90', 'gra', 'mw'],
    "dyumatsena": ['cae', 'mw'],
    "dyumaurvi": ['mw'],
    "dyumaya": ['mw'],
    "dyumayī": ['mw'],
    "dyumaṇi": ['cae', 'mw'],
    "dyumna": ['cae', 'ddsa', 'gra', 'mw'],
    "dyumnahūti": ['gra', 'mw'],
    "dyumnasāti": ['gra', 'mw'],
    "dyumnavant": ['cae'],
    "dyumnavardhana": ['gra', 'mw'],
    "dyumnavat": ['gra', 'mw'],
    "dyumnaśravas": ['gra', 'mw'],
    "dyumnaṃ": ['ap90'],
    "dyumni": ['mw'],
    "dyumnin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dyumnodā": ['mw'],
    "dyumnāsah": ['gra', 'mw'],
    "dyumnīka": ['mw'],
    "dyumārga": ['ddsa', 'mw'],
    "dyuna": ['mw'],
    "dyunadī": ['mw'],
    "dyunadīsaṃgama": ['mw'],
    "dyunivāsa": ['mw'],
    "dyunivāsībhūya": ['mw'],
    "dyuniś": ['cae', 'ddsa', 'mw'],
    "dyuniśa": ['cae', 'mw'],
    "dyupatha": ['cae', 'mw'],
    "dyupati": ['cae', 'mw'],
    "dyupiṇḍa": ['mw'],
    "dyupuraṃdhri": ['mw'],
    "dyuratna": ['mw'],
    "dyurātra": ['mw'],
    "dyurātravṛtta": ['mw'],
    "dyurāśi": ['mw'],
    "dyus": ['mw'],
    "dyusad": ['mw'],
    "dyusadman": ['mw'],
    "dyusambhava": ['mw'],
    "dyusaras": ['mw'],
    "dyusarit": ['cae', 'mw'],
    "dyusindhu": ['mw'],
    "dyustha": ['mw'],
    "dyustrī": ['cae', 'mw'],
    "dyut": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dyuta": ['mw'],
    "dyutadyāman": ['gra', 'mw'],
    "dyutaru": ['mw'],
    "dyutat": ['mw'],
    "dyutay": ['cae'],
    "dyutaya": ['ddsa'],
    "dyuti": ['cae', 'ddsa', 'mw'],
    "dyutidhara": ['mw'],
    "dyutikara": ['mw'],
    "dyutilā": ['mw'],
    "dyutimat": ['mw'],
    "dyutimati": ['mw'],
    "dyutimatī": ['mw'],
    "dyutita": ['ap90', 'mw'],
    "dyutiḥ": ['ap90'],
    "dyutiṃdhara": ['bhs'],
    "dyutta": ['mw'],
    "dyutāna": ['mw'],
    "dyuvadhū": ['cae', 'mw'],
    "dyuvan": ['mw'],
    "dyuvanī": ['mw'],
    "dyuyoṣit": ['cae', 'ddsa', 'mw'],
    "dyuṣad": ['cae', 'mw'],
    "dyāmpāta": ['mw'],
    "dyāvan": ['mw'],
    "dyāvā": ['cae', 'ddsa', 'mw'],
    "dyāvābhūmi": ['cae', 'ddsa', 'gra'],
    "dyāvābhūmī": ['mw'],
    "dyāvākṣam": ['cae', 'gra'],
    "dyāvākṣame": ['mw'],
    "dyāvākṣāmā": ['mw'],
    "dyāvāpṛthivī": ['cae', 'gra', 'mw'],
    "dyāvāpṛthivīvat": ['mw'],
    "dyāvāpṛthivīya": ['ddsa', 'mw'],
    "dyū": ['cae', 'ddsa', 'mw'],
    "dyūna": ['ap90', 'cae', 'ddsa', 'mw'],
    "dyūta": ['cae', 'ddsa', 'mw'],
    "dyūtabhūmi": ['mw'],
    "dyūtabīja": ['mw'],
    "dyūtadharma": ['cae', 'mw'],
    "dyūtadāsa": ['cae', 'mw'],
    "dyūtadāsī": ['mw'],
    "dyūtajita": ['cae', 'mw'],
    "dyūtakara": ['cae', 'mw'],
    "dyūtakaramaṇḍalī": ['mw'],
    "dyūtakiṃkarī": ['mw'],
    "dyūtakrīḍā": ['mw'],
    "dyūtakāra": ['cae', 'mw'],
    "dyūtakāraka": ['mw'],
    "dyūtakṛt": ['cae', 'mw'],
    "dyūtalekhaka": ['cae', 'mw'],
    "dyūtamaṇḍala": ['mw'],
    "dyūtapalāyita": ['cae', 'mw'],
    "dyūtapaurṇimī": ['mw'],
    "dyūtaphalaka": ['mw'],
    "dyūtapratipad": ['mw'],
    "dyūtapriya": ['mw'],
    "dyūtapūrṇimā": ['mw'],
    "dyūtasabhā": ['mw'],
    "dyūtasadana": ['cae', 'mw'],
    "dyūtasamāhvayaprakaraṇa": ['mw'],
    "dyūtasamāja": ['cae', 'mw'],
    "dyūtatā": ['mw'],
    "dyūtavaitaṃsika": ['mw'],
    "dyūtavartman": ['mw'],
    "dyūtaviśeṣa": ['mw'],
    "dyūtavṛtti": ['cae', 'mw'],
    "dyūtaśālā": ['cae', 'mw'],
    "dyūtaḥ": ['ap90'],
    "dyūtia": ['gra'],
    "dyūtvā": ['mw'],
    "dyūtya": ['gra', 'mw'],
    "dyūtādhikārin": ['mw'],
    "dyūtādhyakṣa": ['mw'],
    "dā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dāanaokas": ['gra'],
    "dābha": ['cae', 'gra', 'mw'],
    "dābhia": ['gra'],
    "dābhya": ['gra', 'mw'],
    "dāda": ['cae', 'ddsa', 'mw'],
    "dādada": ['mw'],
    "dādaḥ": ['ap90'],
    "dādhika": ['ap90', 'mw'],
    "dādhikra": ['mw'],
    "dādhikā": ['mw'],
    "dādhittha": ['mw'],
    "dādhreyaka": ['mw'],
    "dādhīca": ['mw'],
    "dādhṛvi": ['cae', 'gra', 'mw'],
    "dādhṛṣi": ['cae', 'gra', 'mw'],
    "dādin": ['mw'],
    "dādā": ['mw'],
    "dādābhāi": ['mw'],
    "dādākhyabhaṭṭa": ['mw'],
    "dādū": ['mw'],
    "dādūpanthin": ['mw'],
    "dāgavyāyani": ['mw'],
    "dāgha": ['bhs'],
    "dāghaḥ": ['ap90'],
    "dāha": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "dāhadā": ['mw'],
    "dāhaharaṇa": ['mw'],
    "dāhajvara": ['cae', 'ddsa', 'mw'],
    "dāhaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "dāhakāṣṭha": ['mw'],
    "dāhamaya": ['mw'],
    "dāhamayatva": ['mw'],
    "dāhana": ['cae', 'ddsa', 'mw'],
    "dāhanaṃ": ['ap90'],
    "dāhani": ['bhs'],
    "dāhanāguru": ['mw'],
    "dāhanī": ['mw'],
    "dāhasara": ['mw'],
    "dāhasaras": ['mw'],
    "dāhasthala": ['mw'],
    "dāhavadānya": ['mw'],
    "dāhavadānyatā": ['mw'],
    "dāhavat": ['mw'],
    "dāhaḥ": ['ap90'],
    "dāhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dāhuka": ['ap90', 'cae', 'ddsa', 'mw'],
    "dāhya": ['ap90', 'cae', 'ddsa'],
    "dāhādhikāra": ['mw'],
    "dāhāguru": ['mw'],
    "dāhātmaka": ['cae', 'ddsa', 'mw'],
    "dāhātman": ['mw'],
    "dāka": ['ap90', 'mw'],
    "dākaḥ": ['ap90'],
    "dākṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "dākṣaka": ['mw'],
    "dākṣasyāyana": ['mw'],
    "dākṣeya": ['mw'],
    "dākṣeyaḥ": ['ap90'],
    "dākṣeyī": ['mw'],
    "dākṣi": ['mw'],
    "dākṣigrāma": ['mw'],
    "dākṣigrāmīya": ['mw'],
    "dākṣihrada": ['mw'],
    "dākṣikanthiya": ['mw'],
    "dākṣikanthā": ['mw'],
    "dākṣikarṣa": ['mw'],
    "dākṣikarṣuka": ['mw'],
    "dākṣikarṣū": ['mw'],
    "dākṣikūla": ['mw'],
    "dākṣinagara": ['mw'],
    "dākṣinagarīya": ['mw'],
    "dākṣipalada": ['mw'],
    "dākṣiḥ": ['ap90'],
    "dākṣiṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "dākṣiṇahoma": ['mw'],
    "dākṣiṇaśāla": ['mw'],
    "dākṣiṇeya": ['bhs', 'mw'],
    "dākṣiṇika": ['ap90', 'mw'],
    "dākṣiṇya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dākṣiṇyalipi": ['bhs'],
    "dākṣiṇyasampanna": ['mw'],
    "dākṣiṇyatā": ['mw'],
    "dākṣiṇyavaddara": ['mw'],
    "dākṣiṇyavant": ['cae'],
    "dākṣiṇyavat": ['mw'],
    "dākṣiṇā": ['mw'],
    "dākṣiṇāgnika": ['mw'],
    "dākṣiṇāja": ['mw'],
    "dākṣiṇāpathaka": ['mw'],
    "dākṣiṇārdhika": ['mw'],
    "dākṣiṇātya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dākṣiṇātyaka": ['mw'],
    "dākṣiṇīya": ['mw'],
    "dākṣya": ['cae', 'ddsa', 'mw'],
    "dākṣyaṃ": ['ap90'],
    "dākṣāyaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "dākṣāyaṇabhakta": ['mw'],
    "dākṣāyaṇahasta": ['mw'],
    "dākṣāyaṇayajña": ['mw'],
    "dākṣāyaṇayajñika": ['mw'],
    "dākṣāyaṇayajñin": ['mw'],
    "dākṣāyaṇin": ['ap90', 'ddsa', 'mw'],
    "dākṣāyaṇya": ['mw'],
    "dākṣāyaṇyagnipraveśa": ['mw'],
    "dākṣāyaṇyaḥ": ['ap90'],
    "dākṣāyaṇī": ['ap90', 'mw'],
    "dākṣāyaṇīpa": ['mw'],
    "dākṣāyaṇīpati": ['mw'],
    "dākṣāyaṇīramaṇa": ['mw'],
    "dākṣāyiṇī": ['mw'],
    "dākṣāyya": ['mw'],
    "dākṣāyyaḥ": ['ap90'],
    "dākṣī": ['ap90', 'mw'],
    "dākṣīputra": ['mw'],
    "dāla": ['cae', 'mw'],
    "dālabhya": ['mw'],
    "dālaka": ['mw'],
    "dālaki": ['mw'],
    "dālana": ['bhs', 'ddsa', 'mw'],
    "dālanaṃ": ['ap90'],
    "dālava": ['mw'],
    "dālayati": ['cped'],
    "dālayitvā": ['cped'],
    "dālaṃ": ['ap90'],
    "dālbha": ['mw'],
    "dālbhi": ['mw'],
    "dālbhya": ['cae', 'mw'],
    "dālbhyaghoṣa": ['mw'],
    "dālbhyaka": ['mw'],
    "dālbhyapariśiṣṭa": ['mw'],
    "dālbhyāyana": ['mw'],
    "dāleti": ['cped'],
    "dāli": ['ddsa'],
    "dāliddiya": ['cped'],
    "dālikā": ['mw'],
    "dālima": ['cae', 'ddsa', 'mw'],
    "dālimaphala": ['mw'],
    "dālimaḥ": ['ap90'],
    "dālmi": ['mw'],
    "dālmiḥ": ['ap90'],
    "dālā": ['mw'],
    "dālāvana": ['bhs'],
    "dālī": ['mw'],
    "dāma": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "dāmacandra": ['mw'],
    "dāmacarita": ['mw'],
    "dāmadaśa": ['mw'],
    "dāmagranthi": ['mw'],
    "dāmajātaśrī": ['mw'],
    "dāmaka": ['bhs'],
    "dāmakaṇṭha": ['mw'],
    "dāmalih": ['mw'],
    "dāmalihya": ['mw'],
    "dāmalipta": ['ddsa', 'mw'],
    "dāman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dāmana": ['mw'],
    "dāmanaparvan": ['mw'],
    "dāmani": ['mw'],
    "dāmanvat": ['gra', 'mw'],
    "dāmanī": ['ap90', 'mw'],
    "dāmanīya": ['mw'],
    "dāmasiṃha": ['mw'],
    "dāmatūṣa": ['mw'],
    "dāmbha": ['mw'],
    "dāmbhika": ['cae', 'ddsa', 'mw'],
    "dāmbhola": ['mw'],
    "dāminī": ['ap90'],
    "dāmoda": ['mw'],
    "dāmodara": ['bhs', 'cae', 'ddsa', 'mw'],
    "dāmodarabhūti": ['mw'],
    "dāmodaradatta": ['mw'],
    "dāmodaradeva": ['mw'],
    "dāmodaragupta": ['cae', 'mw'],
    "dāmodaramiśra": ['cae', 'mw'],
    "dāmodarapaddhati": ['mw'],
    "dāmodaratantra": ['mw'],
    "dāmodarāraṇya": ['mw'],
    "dāmodarīya": ['ddsa', 'mw'],
    "dāmoṣṇīṣa": ['mw'],
    "dāmoṣṇīṣi": ['mw'],
    "dāmoṣṇīṣya": ['mw'],
    "dāmpatya": ['ddsa', 'mw'],
    "dāmā": ['ap90', 'cped', 'gra', 'mw'],
    "dāmāñcala": ['mw'],
    "dāmāñcana": ['mw'],
    "dān": ['ap90', 'mw'],
    "dāna": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dānaapnas": ['gra'],
    "dānabhinna": ['mw'],
    "dānabhāgavata": ['mw'],
    "dānacandrikā": ['mw'],
    "dānacyuta": ['mw'],
    "dānadarpaṇa": ['mw'],
    "dānadharma": ['cae', 'ddsa', 'mw'],
    "dānadharmakathana": ['mw'],
    "dānadharmavidhi": ['mw'],
    "dānadharmādhyāya": ['mw'],
    "dānadinakara": ['mw'],
    "dānahemādri": ['mw'],
    "dānahīna": ['mw'],
    "dānaka": ['mw'],
    "dānakalpataru": ['mw'],
    "dānakamalākara": ['mw'],
    "dānakaumudī": ['mw'],
    "dānakaustubha": ['mw'],
    "dānakaṃ": ['ap90'],
    "dānakelikaumudī": ['mw'],
    "dānakhaṇḍa": ['mw'],
    "dānakriyākaumudī": ['mw'],
    "dānakusumāñjali": ['mw'],
    "dānakā": ['mw'],
    "dānakāma": ['cae', 'mw'],
    "dānamanohara": ['mw'],
    "dānamaya": ['mw'],
    "dānamayūkha": ['mw'],
    "dānamañjarī": ['mw'],
    "dānapaddhati": ['mw'],
    "dānapara": ['cae', 'mw'],
    "dānaparatā": ['mw'],
    "dānaparibhāṣā": ['mw'],
    "dānapati": ['cae', 'cped', 'mw'],
    "dānapattra": ['mw'],
    "dānapaṭṭaka": ['mw'],
    "dānapradīpa": ['mw'],
    "dānapraguru": ['bhs'],
    "dānaprakaraṇa": ['mw'],
    "dānaprakāśa": ['mw'],
    "dānapratibhū": ['cae', 'mw'],
    "dānaprātibhāvya": ['mw'],
    "dānapāramitā": ['mw'],
    "dānapārijāta": ['mw'],
    "dānapātra": ['mw'],
    "dānasaṃvanana": ['mw'],
    "dānastuti": ['cae', 'mw'],
    "dānasāgara": ['mw'],
    "dānatas": ['mw'],
    "dānaukas": ['cae', 'gra', 'mw'],
    "dānava": ['cae', 'ddsa', 'gra', 'mw'],
    "dānavagupta": ['bhs'],
    "dānavaguru": ['mw'],
    "dānavajra": ['mw'],
    "dānavakula": ['bhs'],
    "dānavant": ['cae'],
    "dānavapati": ['ddsa', 'mw'],
    "dānavapriyā": ['mw'],
    "dānavapūjita": ['mw'],
    "dānavarman": ['mw'],
    "dānavat": ['ddsa', 'gra', 'mw'],
    "dānavavairin": ['mw'],
    "dānavaśīkṛ": ['ddsa', 'mw'],
    "dānavaḥ": ['ap90'],
    "dānavendra": ['mw'],
    "dānaveya": ['mw'],
    "dānaveyaḥ": ['ap90'],
    "dānavidhi": ['mw'],
    "dānaviśodhana": ['mw'],
    "dānavrata": ['mw'],
    "dānavyatyāsa": ['mw'],
    "dānavār": ['ddsa', 'mw'],
    "dānavāri": ['mw'],
    "dānavī": ['mw'],
    "dānavīra": ['cae', 'mw'],
    "dānayogya": ['mw'],
    "dānaśauṇḍa": ['mw'],
    "dānaśālin": ['mw'],
    "dānaśālā": ['mw'],
    "dānaśīla": ['cae', 'mw'],
    "dānaśūra": ['bhs', 'cae', 'mw'],
    "dānaṃ": ['ap90'],
    "dānaṃdadā": ['bhs', 'mw'],
    "dāni": ['bhs', 'cped'],
    "dānika": ['mw'],
    "dānin": ['ap90', 'cae', 'mw'],
    "dānoddyota": ['mw'],
    "dānta": ['cae', 'ddsa', 'mw'],
    "dāntabhadra": ['mw'],
    "dāntadeva": ['mw'],
    "dāntaka": ['bhs', 'mw'],
    "dāntasena": ['mw'],
    "dānti": ['mw'],
    "dāntika": ['mw'],
    "dāntvā": ['mw'],
    "dāntā": ['mw'],
    "dānu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dānucitra": ['cae', 'gra', 'mw'],
    "dānuda": ['gra', 'mw'],
    "dānumat": ['gra', 'mw'],
    "dānupinva": ['gra', 'mw'],
    "dānādhikāra": ['mw'],
    "dānāpnas": ['ddsa', 'gra', 'mw'],
    "dānīya": ['ap90', 'mw'],
    "dāpana": ['ap90', 'mw'],
    "dāpanaṃ": ['ap90'],
    "dāpanīya": ['cae', 'ddsa', 'mw'],
    "dāpayati": ['cped'],
    "dāpayitavya": ['cae', 'mw'],
    "dāpayitvā": ['mw'],
    "dāpenta": ['cped'],
    "dāpesi": ['cped'],
    "dāpeti": ['cped'],
    "dāpetvā": ['cped'],
    "dāpita": ['ap90', 'mw'],
    "dāpya": ['cae', 'mw'],
    "dāra": ['cae', 'cped', 'ddsa', 'mw'],
    "dārabalibhuj": ['mw'],
    "dārabharaṇa": ['cped'],
    "dārada": ['mw'],
    "dāradaḥ": ['ap90'],
    "dāragava": ['mw'],
    "dāragrahaṇa": ['mw'],
    "dāragupti": ['mw'],
    "dāraka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "dārakarman": ['cae', 'ddsa', 'mw'],
    "dārakriyā": ['cae', 'mw'],
    "dārakācārya": ['mw'],
    "dāralakṣaṇa": ['mw'],
    "dāraparigraha": ['cae', 'ddsa', 'mw'],
    "dāraparigrahin": ['mw'],
    "dārarakṣitaka": ['mw'],
    "dārasambandha": ['mw'],
    "dārasaṃgraha": ['cae', 'mw'],
    "dārasaṅgraha": ['ddsa'],
    "dārasuta": ['mw'],
    "dāratyāgin": ['cae', 'mw'],
    "dārava": ['ap90', 'cae', 'ddsa', 'mw'],
    "dāravīya": ['mw'],
    "dāraḥ": ['ap90'],
    "dāraṇa": ['cae', 'ddsa', 'mw'],
    "dāraṇaṃ": ['ap90'],
    "dāraṇī": ['mw'],
    "dārbha": ['ap90', 'cae', 'ddsa', 'mw'],
    "dārbhi": ['mw'],
    "dārbhia": ['gra'],
    "dārbhya": ['gra', 'mw'],
    "dārbhyūṣa": ['mw'],
    "dārbhāyaṇa": ['mw'],
    "dārdura": ['cae', 'ddsa', 'mw'],
    "dārduraka": ['cae', 'mw'],
    "dārduraḥ": ['ap90'],
    "dārdurika": ['mw'],
    "dārghasattra": ['mw'],
    "dāri": ['cae', 'mw'],
    "dāridra": ['mw'],
    "dāridrya": ['ddsa', 'mw'],
    "dāridryaṃ": ['ap90'],
    "dārika": ['bhs'],
    "dārikā": ['ap90', 'cped', 'ddsa', 'mw'],
    "dārikādāna": ['mw'],
    "dārila": ['mw'],
    "dārin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dārita": ['ap90', 'mw'],
    "dāriḥ": ['ap90'],
    "dārodara": ['mw'],
    "dāropasaṃgraha": ['mw'],
    "dārteya": ['mw'],
    "dāru": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dārubrahmarasa": ['mw'],
    "dāruciti": ['mw'],
    "dārudhītalikā": ['cped'],
    "dārugaha": ['cped'],
    "dārugandhā": ['mw'],
    "dārugarbhā": ['mw'],
    "dāruharidrā": ['mw'],
    "dāruhasta": ['mw'],
    "dāruhastaka": ['mw'],
    "dāruja": ['cae', 'mw'],
    "dāruka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "dārukaccha": ['mw'],
    "dārukacchaka": ['mw'],
    "dārukadalī": ['mw'],
    "dārukapillaka": ['cped'],
    "dārukarman": ['ddsa', 'mw'],
    "dārukarṇin": ['bhs', 'mw'],
    "dārukaḥ": ['ap90'],
    "dārukeśvaratīrtha": ['mw'],
    "dāruki": ['mw'],
    "dārukā": ['mw'],
    "dārukāvana": ['mw'],
    "dārukṛtya": ['mw'],
    "dārumatsyāhvaya": ['mw'],
    "dārumaya": ['cae', 'mw'],
    "dārumuca": ['mw'],
    "dārumukhyāhva": ['mw'],
    "dārumukhyāhvaya": ['mw'],
    "dārumāsaka": ['cped'],
    "dārumūkhā": ['mw'],
    "dāruniśā": ['mw'],
    "dāruparvata": ['ddsa', 'mw'],
    "dārupattika": ['cped'],
    "dārupattrī": ['mw'],
    "dāruphala": ['mw'],
    "dāruphalaka": ['mw'],
    "dāruputrikā": ['mw'],
    "dāruputrī": ['mw'],
    "dārupātra": ['cae', 'mw'],
    "dārupītā": ['mw'],
    "dārusitā": ['mw'],
    "dārustrī": ['mw'],
    "dārutīrtha": ['mw'],
    "dāruvaha": ['mw'],
    "dāruvarman": ['mw'],
    "dāruyantra": ['mw'],
    "dāruśailamaya": ['mw'],
    "dāruṇa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "dāruṇaka": ['mw'],
    "dāruṇakarman": ['mw'],
    "dāruṇatā": ['ddsa', 'mw'],
    "dāruṇavapus": ['mw'],
    "dāruṇya": ['cae', 'ddsa', 'mw'],
    "dāruṇyaṃ": ['ap90'],
    "dāruṇā": ['cae'],
    "dāruṇādhyāpaka": ['mw'],
    "dāruṇākṛti": ['mw'],
    "dāruṇātman": ['cae', 'mw'],
    "dāruṇāya": ['mw'],
    "dāruṣaṭka": ['mw'],
    "dārva": ['ap90', 'cae', 'ddsa', 'mw'],
    "dārvaka": ['mw'],
    "dārvan": ['mw'],
    "dārvaṇḍa": ['mw'],
    "dārvaṭa": ['mw'],
    "dārvaṭaṃ": ['ap90'],
    "dārvihomika": ['mw'],
    "dārvikā": ['mw'],
    "dārvipattrikā": ['mw'],
    "dārvāghāta": ['mw'],
    "dārvāghāṭa": ['cae', 'ddsa', 'mw'],
    "dārvāhāra": ['mw'],
    "dārvāyasmaya": ['bhs'],
    "dārvī": ['mw'],
    "dārvīhaumika": ['mw'],
    "dārvīkvāthodbhava": ['mw'],
    "dārābharaṇa": ['cped'],
    "dārādhigamana": ['cae', 'mw'],
    "dārādhīna": ['mw'],
    "dārāṇukramaṇa": ['mw'],
    "dārī": ['ap90', 'mw'],
    "dārśa": ['cae', 'ddsa', 'mw'],
    "dārśanika": ['mw'],
    "dārśanikaḥ": ['ap90'],
    "dārśapaurṇamāsika": ['mw'],
    "dārśika": ['cae', 'mw'],
    "dārśya": ['mw'],
    "dārḍhacyuta": ['mw'],
    "dārḍhajayanti": ['mw'],
    "dārḍhya": ['cae', 'ddsa', 'mw'],
    "dārḍhyaṃ": ['ap90'],
    "dārṣada": ['ap90', 'mw'],
    "dārṣadvata": ['mw'],
    "dārṣṭiviṣayika": ['mw'],
    "dārṣṭānta": ['mw'],
    "dārṣṭāntika": ['ddsa', 'mw'],
    "dārṣṭāṃta": ['ap90'],
    "dās": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dāsa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dāsabhārya": ['mw'],
    "dāsabhāva": ['cae', 'mw'],
    "dāsadāsī": ['cae', 'mw'],
    "dāsadāsījana": ['mw'],
    "dāsajana": ['cae', 'ddsa', 'mw'],
    "dāsajīvana": ['cae', 'mw'],
    "dāsaka": ['bhs', 'mw'],
    "dāsakammakarā": ['cped'],
    "dāsakaputta": ['cped'],
    "dāsakarmakara": ['mw'],
    "dāsaketu": ['mw'],
    "dāsakāyana": ['mw'],
    "dāsameya": ['mw'],
    "dāsamithuna": ['mw'],
    "dāsamitra": ['mw'],
    "dāsamitri": ['mw'],
    "dāsamitribhakta": ['mw'],
    "dāsamitrika": ['mw'],
    "dāsamitrāyaṇa": ['mw'],
    "dāsamitrāyaṇabhakta": ['mw'],
    "dāsamīya": ['mw'],
    "dāsanandinī": ['mw'],
    "dāsanu": ['mw'],
    "dāsanīya": ['mw'],
    "dāsapatnī": ['gra', 'mw'],
    "dāsaporisa": ['cped'],
    "dāsapravarga": ['gra', 'mw'],
    "dāsasarasa": ['mw'],
    "dāsasyakula": ['mw'],
    "dāsatva": ['mw'],
    "dāsatā": ['cae', 'mw'],
    "dāsavarga": ['mw'],
    "dāsavat": ['cae'],
    "dāsaveśa": ['gra', 'mw'],
    "dāsaviya": ['cped'],
    "dāsavya": ['cped'],
    "dāsaśarman": ['mw'],
    "dāsaśiras": ['mw'],
    "dāsaḥ": ['ap90'],
    "dāsera": ['mw'],
    "dāseraka": ['cae', 'ddsa', 'mw'],
    "dāseraki": ['mw'],
    "dāserakī": ['mw'],
    "dāseraḥ": ['ap90'],
    "dāseya": ['mw'],
    "dāseyaḥ": ['ap90'],
    "dāsi": ['cped'],
    "dāsidāsa": ['cped'],
    "dāsikā": ['ap90', 'mw'],
    "dāsinikā": ['bhs'],
    "dāsiputta": ['cped'],
    "dāsitā": ['bhs'],
    "dāsra": ['mw'],
    "dāsraṃ": ['ap90'],
    "dāsvant": ['cae'],
    "dāsvat": ['gra', 'mw'],
    "dāsya": ['cae', 'ddsa', 'mw'],
    "dāsyaṃ": ['ap90'],
    "dāsyāḥputra": ['mw'],
    "dāsyāḥsuta": ['mw'],
    "dāsānudāsa": ['mw'],
    "dāsāya": ['mw'],
    "dāsāyana": ['mw'],
    "dāsī": ['ap90', 'cped', 'ddsa', 'mw'],
    "dāsībhāva": ['cae', 'mw'],
    "dāsībhū": ['mw'],
    "dāsībrāhmaṇa": ['mw'],
    "dāsīdānavidhi": ['mw'],
    "dāsīdāsa": ['cped', 'ddsa', 'mw'],
    "dāsījana": ['mw'],
    "dāsīkṛ": ['ddsa', 'mw'],
    "dāsīmāṇavaka": ['mw'],
    "dāsīputra": ['mw'],
    "dāsīsabha": ['mw'],
    "dāsīsuta": ['mw'],
    "dāsītva": ['cae', 'mw'],
    "dāsīśrotriya": ['mw'],
    "dāta": ['ap90', 'mw'],
    "dāta(r)": ['cped'],
    "dātabba": ['cped'],
    "dātavai": ['cae'],
    "dātave": ['cae', 'cped'],
    "dātavya": ['ap90', 'cae', 'ddsa', 'mw'],
    "dāti": ['cae', 'gra', 'mw'],
    "dātivāra": ['cae', 'gra', 'mw'],
    "dātiḥ": ['ap90'],
    "dātra": ['cae', 'ddsa', 'gra', 'mw'],
    "dātraṃ": ['ap90'],
    "dātreya": ['mw'],
    "dātrākarṇa": ['mw'],
    "dātta": ['mw'],
    "dātteya": ['mw'],
    "dāttāmitrī": ['mw'],
    "dāttāmitrīya": ['mw'],
    "dātu": ['cae', 'gra', 'mw'],
    "dātukāma": ['ddsa'],
    "dātuye": ['cped'],
    "dātuṁ": ['cped'],
    "dātva": ['mw'],
    "dātvaḥ": ['ap90'],
    "dātyauha": ['cae', 'mw'],
    "dātyūha": ['cae', 'ddsa', 'mw'],
    "dātyūhaka": ['mw'],
    "dātyūhaḥ": ['ap90'],
    "dātṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dātṛnirūpaṇa": ['mw'],
    "dātṛpratīcchaka": ['cae', 'mw'],
    "dātṛpura": ['mw'],
    "dātṛtva": ['mw'],
    "dātṛtā": ['ddsa', 'mw'],
    "dāva": ['cae', 'cped', 'ddsa', 'mw'],
    "dāvadahana": ['cae'],
    "dāvadahanajvālākalāpāya": ['mw'],
    "dāvalatā": ['mw'],
    "dāvan": ['cae', 'gra', 'mw'],
    "dāvane": ['cae'],
    "dāvapa": ['mw'],
    "dāvaparīta": ['mw'],
    "dāvarī": ['mw'],
    "dāvasu": ['mw'],
    "dāvasunidhana": ['mw'],
    "dāvat": ['mw'],
    "dāvavivarjita": ['mw'],
    "dāvaḥ": ['ap90'],
    "dāvika": ['mw'],
    "dāvikākūla": ['mw'],
    "dāvita": ['ap90'],
    "dāvāgni": ['cae', 'mw'],
    "dāvānala": ['cae'],
    "dāvānila": ['mw'],
    "dāy": ['mw'],
    "dāya": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dāyabandhu": ['mw'],
    "dāyabhāga": ['cae', 'mw'],
    "dāyabhāgatattva": ['mw'],
    "dāyabhāgaṭīkā": ['mw'],
    "dāyahara": ['cae', 'mw'],
    "dāyajja": ['cped'],
    "dāyaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "dāyakramasaṃgraha": ['mw'],
    "dāyakāla": ['ddsa', 'mw'],
    "dāyanirṇaya": ['mw'],
    "dāyapāla": ['cped'],
    "dāyarahasya": ['mw'],
    "dāyatattva": ['mw'],
    "dāyatattvakṛt": ['mw'],
    "dāyavibhāga": ['mw'],
    "dāyavira": ['mw'],
    "dāyaḥ": ['ap90'],
    "dāyika": ['bhs'],
    "dāyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dāyita": ['mw'],
    "dāyāda": ['cae', 'cped', 'ddsa', 'mw'],
    "dāyādaka": ['cped'],
    "dāyādava": ['mw'],
    "dāyādavat": ['mw'],
    "dāyādhikārakramasaṃgraha": ['mw'],
    "dāyādikā": ['cped'],
    "dāyādya": ['cae', 'ddsa', 'mw'],
    "dāyādyatā": ['mw'],
    "dāyāpavartana": ['mw'],
    "dāyārha": ['mw'],
    "dāyīkṛ": ['ddsa', 'mw'],
    "dāś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dāśa": ['cae', 'ddsa', 'mw'],
    "dāśagrāmika": ['mw'],
    "dāśaka": ['mw'],
    "dāśakaputra": ['mw'],
    "dāśakaṇṭha": ['mw'],
    "dāśamūlika": ['mw'],
    "dāśanandinī": ['mw'],
    "dāśapati": ['ddsa', 'mw'],
    "dāśaphalī": ['mw'],
    "dāśapura": ['mw'],
    "dāśaratha": ['cae', 'mw'],
    "dāśarathaḥ": ['ap90'],
    "dāśarathi": ['cae', 'ddsa', 'mw'],
    "dāśarathītantra": ['mw'],
    "dāśarma": ['mw'],
    "dāśarājña": ['cae', 'ddsa', 'gra', 'mw'],
    "dāśarātrika": ['mw'],
    "dāśarūpya": ['mw'],
    "dāśarūpyaka": ['mw'],
    "dāśaspati": ['mw'],
    "dāśaspatipatya": ['mw'],
    "dāśat": ['mw'],
    "dāśataya": ['cae', 'ddsa', 'mw'],
    "dāśatayī": ['mw'],
    "dāśatva": ['mw'],
    "dāśaudanika": ['mw'],
    "dāśaudanikī": ['mw'],
    "dāśavāja": ['mw'],
    "dāśaḥ": ['ap90'],
    "dāśera": ['mw'],
    "dāśeraka": ['cae', 'ddsa', 'mw'],
    "dāśerakaḥ": ['ap90'],
    "dāśeraḥ": ['ap90'],
    "dāśeya": ['mw'],
    "dāśeyaḥ": ['ap90'],
    "dāśeyī": ['mw'],
    "dāśivas": ['cae', 'mw'],
    "dāśu": ['gra', 'mw'],
    "dāśuadhvara": ['gra'],
    "dāśuas": ['gra'],
    "dāśura": ['mw'],
    "dāśuri": ['cae', 'gra', 'mw'],
    "dāśuṣe": ['ddsa'],
    "dāśva": ['ap90', 'mw'],
    "dāśvadhvara": ['gra', 'mw'],
    "dāśvas": ['cae', 'gra', 'mw'],
    "dāśārha": ['cae', 'ddsa', 'mw'],
    "dāśārhaka": ['mw'],
    "dāśārhāḥ": ['ap90'],
    "dāśārhī": ['mw'],
    "dāśārṇa": ['mw'],
    "dāśārṇaka": ['ddsa', 'mw'],
    "dāśārṇarāja": ['mw'],
    "dāśārṇeśa": ['mw'],
    "dāśāśvamedha": ['mw'],
    "dāśī": ['mw'],
    "dāḍaka": ['mw'],
    "dāḍakaḥ": ['ap90'],
    "dāḍhikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "dāḍhā": ['ap90', 'mw'],
    "dāḍima": ['cae', 'cped', 'ddsa', 'mw'],
    "dāḍimabhakṣaṇa": ['mw'],
    "dāḍimabhaṭṭa": ['mw'],
    "dāḍimapattraka": ['mw'],
    "dāḍimaphala": ['mw'],
    "dāḍimapriya": ['mw'],
    "dāḍimapuṣpa": ['cae', 'mw'],
    "dāḍimaḥ": ['ap90'],
    "dāḍimba": ['mw'],
    "dāḍimīsāra": ['mw'],
    "dāḍimīvat": ['mw'],
    "dāḍiṃbaḥ": ['ap90'],
    "dāḍī": ['mw'],
    "dāḷiddiya": ['cped'],
    "dāṃbhika": ['ap90'],
    "dāṃpatya": ['cae'],
    "dāṃpatyaṃ": ['ap90'],
    "dāṃta": ['ap90'],
    "dāṃtika": ['ap90'],
    "dāṃtiḥ": ['ap90'],
    "dāṃḍa": ['ap90'],
    "dāṃḍikaḥ": ['ap90'],
    "dāṃḍājinika": ['ap90'],
    "dāṇḍa": ['mw'],
    "dāṇḍagrāhika": ['mw'],
    "dāṇḍaki": ['mw'],
    "dāṇḍakya": ['mw'],
    "dāṇḍakīya": ['mw'],
    "dāṇḍamāthika": ['mw'],
    "dāṇḍapātā": ['mw'],
    "dāṇḍapāyana": ['mw'],
    "dāṇḍapāśika": ['mw'],
    "dāṇḍapāṇika": ['mw'],
    "dāṇḍika": ['cae', 'mw'],
    "dāṇḍikya": ['mw'],
    "dāṇḍin": ['mw'],
    "dāṇḍināyana": ['mw'],
    "dāṇḍā": ['mw'],
    "dāṇḍājinika": ['mw'],
    "dāṇḍājinikatā": ['bhs'],
    "dāṇḍāyana": ['mw'],
    "dāṇḍāyanasthalaka": ['mw'],
    "dāṇḍāyanasthalī": ['mw'],
    "dāṭha": ['bhs', 'cped'],
    "dāṭhabala": ['cped'],
    "dāṭhi(n)": ['cped'],
    "dāṭhikā": ['cped'],
    "dāṭhin": ['bhs'],
    "dāṭhā": ['cped'],
    "dāṭhābali(n)": ['cped'],
    "dī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dīda": ['mw'],
    "dīdhi": ['cae', 'ddsa'],
    "dīdhiti": ['cae', 'ddsa', 'gra', 'mw'],
    "dīdhitimat": ['ap90', 'mw'],
    "dīdhitimāthurī": ['mw'],
    "dīdhitiprakāśa": ['mw'],
    "dīdhitipratyakṣaṭīkā": ['mw'],
    "dīdhitiraudrī": ['mw'],
    "dīdhitivyākhyā": ['mw'],
    "dīdhitiḥ": ['ap90'],
    "dīdhyat": ['cae'],
    "dīdhyāna": ['cae', 'ddsa'],
    "dīdhī": ['ap90', 'mw'],
    "dīdi": ['cae', 'ddsa', 'mw'],
    "dīdiagni": ['gra'],
    "dīditi": ['cae', 'gra', 'mw'],
    "dīdivas": ['cae'],
    "dīdivi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dīdyagni": ['gra', 'mw'],
    "dīdyuṣ": ['cae'],
    "dīdī": ['mw'],
    "dīgha": ['cped'],
    "dīghalomaka": ['cped'],
    "dīghanikāya": ['cped'],
    "dīghapiṭṭhika": ['cped'],
    "dīgharattassa": ['cped'],
    "dīgharattaṁ": ['cped'],
    "dīgharattāya": ['cped'],
    "dīghaso": ['cped'],
    "dīghato": ['cped'],
    "dīghatta": ['cped'],
    "dīghaṁ": ['cped'],
    "dīghaṅguli": ['cped'],
    "dīghānusayi(n)": ['cped'],
    "dīghānusayita": ['cped'],
    "dīghāyuka": ['cped'],
    "dīkṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "dīkṣaka": ['mw'],
    "dīkṣakaḥ": ['ap90'],
    "dīkṣate": ['bhs'],
    "dīkṣayitṛ": ['mw'],
    "dīkṣaṇa": ['cae', 'ddsa', 'mw'],
    "dīkṣaṇaṃ": ['ap90'],
    "dīkṣaṇā": ['mw'],
    "dīkṣaṇīya": ['cae', 'mw'],
    "dīkṣaṇīyā": ['mw'],
    "dīkṣin": ['mw'],
    "dīkṣita": ['ap90', 'cae', 'ddsa', 'mw'],
    "dīkṣitabālakṛṣṇa": ['mw'],
    "dīkṣitadhuṇḍhirāja": ['mw'],
    "dīkṣitasāmarāja": ['mw'],
    "dīkṣitatva": ['mw'],
    "dīkṣitavasana": ['mw'],
    "dīkṣitavimita": ['mw'],
    "dīkṣitavrata": ['mw'],
    "dīkṣitavāda": ['mw'],
    "dīkṣitayajñadatta": ['mw'],
    "dīkṣitāvedana": ['mw'],
    "dīkṣitāyanī": ['mw'],
    "dīkṣitīya": ['mw'],
    "dīkṣitṛ": ['ap90', 'mw'],
    "dīkṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "dīkṣāguru": ['ddsa', 'mw'],
    "dīkṣākaraṇa": ['mw'],
    "dīkṣākramaratna": ['mw'],
    "dīkṣākārin": ['mw'],
    "dīkṣāmahotsava": ['mw'],
    "dīkṣāmaya": ['mw'],
    "dīkṣāmāsādivicāra": ['mw'],
    "dīkṣānta": ['mw'],
    "dīkṣāpaddhati": ['mw'],
    "dīkṣāpati": ['cae', 'mw'],
    "dīkṣāpattra": ['mw'],
    "dīkṣāphala": ['mw'],
    "dīkṣāprakaraṇa": ['mw'],
    "dīkṣāpāla": ['cae', 'mw'],
    "dīkṣāratna": ['mw'],
    "dīkṣāsaṃskāra": ['mw'],
    "dīkṣāsetu": ['mw'],
    "dīkṣāsūkta": ['mw'],
    "dīkṣātattva": ['mw'],
    "dīkṣāvidhi": ['mw'],
    "dīkṣāvidhāna": ['mw'],
    "dīkṣāvinoda": ['mw'],
    "dīkṣāviveka": ['mw'],
    "dīkṣāṅgasvastivācana": ['mw'],
    "dīna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dīnacetana": ['cae', 'mw'],
    "dīnacintāmaṇi": ['mw'],
    "dīnacitta": ['cae', 'mw'],
    "dīnadakṣa": ['gra', 'mw'],
    "dīnadhī": ['mw'],
    "dīnadāsa": ['mw'],
    "dīnadīna": ['mw'],
    "dīnaka": ['ap90', 'ddsa', 'mw'],
    "dīnakam": ['mw'],
    "dīnalocana": ['mw'],
    "dīnam": ['mw'],
    "dīnamana": ['cped'],
    "dīnamanas": ['cae', 'mw'],
    "dīnamukha": ['mw'],
    "dīnamānasa": ['cae', 'mw'],
    "dīnanātha": ['mw'],
    "dīnanāthasūri": ['mw'],
    "dīnarūpa": ['cae', 'mw'],
    "dīnasattva": ['cae', 'mw'],
    "dīnasādhaka": ['mw'],
    "dīnatā": ['gra', 'mw'],
    "dīnavadana": ['mw'],
    "dīnavarṇa": ['mw'],
    "dīnavatsala": ['mw'],
    "dīnnāra": ['mw'],
    "dīnā": ['mw'],
    "dīnākrandanastotra": ['mw'],
    "dīnānukampana": ['mw'],
    "dīnāra": ['ddsa', 'mw'],
    "dīnāraka": ['mw'],
    "dīnāraḥ": ['ap90'],
    "dīnārikā": ['mw'],
    "dīnāsya": ['ddsa', 'mw'],
    "dīp": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dīpa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "dīpabhājana": ['mw'],
    "dīpada": ['cae', 'mw'],
    "dīpadhvaja": ['mw'],
    "dīpadāna": ['mw'],
    "dīpadānapaddhati": ['mw'],
    "dīpadānaratna": ['mw'],
    "dīpadānavidhi": ['mw'],
    "dīpaka": ['ap90', 'cae', 'mw'],
    "dīpakalikā": ['ddsa', 'mw'],
    "dīpakamālā": ['mw'],
    "dīpakarpūraja": ['mw'],
    "dīpakavyākaraṇa": ['mw'],
    "dīpakhorī": ['mw'],
    "dīpakiṭṭa": ['mw'],
    "dīpakāra": ['bhs'],
    "dīpakūpī": ['mw'],
    "dīpamallī": ['mw'],
    "dīpamāhātmya": ['mw'],
    "dīpamālikotsava": ['mw'],
    "dīpamālikā": ['cae', 'mw'],
    "dīpamālā": ['cae', 'mw'],
    "dīpana": ['ap90', 'cae', 'ddsa', 'mw'],
    "dīpanī": ['mw'],
    "dīpanīya": ['ap90', 'mw'],
    "dīpaprakāśa": ['mw'],
    "dīpapuṣpa": ['mw'],
    "dīpapādapa": ['ddsa', 'mw'],
    "dīpapūjā": ['mw'],
    "dīpapūjāvidhāna": ['mw'],
    "dīpasaha": ['bhs'],
    "dīpastambhadevatāpūjā": ['mw'],
    "dīpasāra": ['mw'],
    "dīpavarti": ['mw'],
    "dīpavat": ['mw'],
    "dīpavatī": ['bhs', 'mw'],
    "dīpavidhi": ['mw'],
    "dīpavidhāna": ['mw'],
    "dīpavyākaraṇa": ['mw'],
    "dīpavṛkṣa": ['mw'],
    "dīpayat": ['mw'],
    "dīpayati": ['cped'],
    "dīpaśatru": ['mw'],
    "dīpaśikhopaniṣad": ['mw'],
    "dīpaśikhā": ['mw'],
    "dīpaśrāddhavidhi": ['mw'],
    "dīpaśrī": ['bhs'],
    "dīpaśṛṅkhalā": ['mw'],
    "dīpaḥ": ['ap90'],
    "dīpaṃkara": ['bhs', 'mw'],
    "dīpaṃkarajñāna": ['mw'],
    "dīpenta": ['cped'],
    "dīpeti": ['cped'],
    "dīpi(n)": ['cped'],
    "dīpikā": ['ap90', 'cped', 'ddsa', 'mw'],
    "dīpikādhāriṇī": ['mw'],
    "dīpikāprakāśa": ['mw'],
    "dīpikāprakāśikā": ['mw'],
    "dīpikātaila": ['mw'],
    "dīpikāvivaraṇa": ['mw'],
    "dīpikāvyākhyā": ['mw'],
    "dīpikāṭīkā": ['mw'],
    "dīpin": ['ap90', 'cae', 'ddsa', 'mw'],
    "dīpinī": ['mw'],
    "dīpita": ['ap90', 'mw'],
    "dīpitṛ": ['mw'],
    "dīpocchiṣṭa": ['mw'],
    "dīpotsava": ['mw'],
    "dīpra": ['ap90', 'cae', 'ddsa', 'mw'],
    "dīpta": ['ap90', 'cae', 'mw'],
    "dīptabhānu": ['bhs'],
    "dīptajihvā": ['mw'],
    "dīptaka": ['mw'],
    "dīptakaḥ": ['ap90'],
    "dīptaketu": ['mw'],
    "dīptakiraṇa": ['cae', 'ddsa', 'mw'],
    "dīptakīrti": ['mw'],
    "dīptalocana": ['mw'],
    "dīptaloha": ['mw'],
    "dīptanayana": ['mw'],
    "dīptaphala": ['mw'],
    "dīptapiṅgala": ['mw'],
    "dīptapuṣpā": ['mw'],
    "dīptarasa": ['mw'],
    "dīptarasatva": ['mw'],
    "dīptaroman": ['mw'],
    "dīptarūpin": ['mw'],
    "dīptasvāmin": ['mw'],
    "dīptatapas": ['mw'],
    "dīptateja": ['bhs'],
    "dīptatejas": ['mw'],
    "dīptatva": ['mw'],
    "dīptaujas": ['cae', 'ddsa', 'mw'],
    "dīptavarṇa": ['mw'],
    "dīptavīrya": ['bhs', 'cae', 'mw'],
    "dīptaśakti": ['mw'],
    "dīptaśikha": ['mw'],
    "dīpti": ['cae', 'ddsa', 'mw'],
    "dīptika": ['mw'],
    "dīptikara": ['mw'],
    "dīptiketu": ['mw'],
    "dīptikeśvaratīrtha": ['mw'],
    "dīptimat": ['ap90', 'ddsa', 'mw'],
    "dīptimatī": ['mw'],
    "dīptiḥ": ['ap90'],
    "dīptoda": ['mw'],
    "dīptopala": ['mw'],
    "dīptāgni": ['mw'],
    "dīptāgnitā": ['mw'],
    "dīptāgra": ['mw'],
    "dīptākṣa": ['cae', 'mw'],
    "dīptāsya": ['mw'],
    "dīptātman": ['mw'],
    "dīptāṃśu": ['ddsa', 'mw'],
    "dīptāṅga": ['mw'],
    "dīpya": ['ap90', 'mw'],
    "dīpyaka": ['mw'],
    "dīpā": ['bhs'],
    "dīpālikakalpa": ['mw'],
    "dīpāloka": ['cae', 'ddsa', 'mw'],
    "dīpālī": ['mw'],
    "dīpānvitā": ['mw'],
    "dīpārādhana": ['mw'],
    "dīpāsura": ['mw'],
    "dīpāvali": ['cae', 'mw'],
    "dīpāvalīprayoga": ['mw'],
    "dīpāvatī": ['bhs'],
    "dīpāṅkura": ['mw'],
    "dīrgha": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "dīrghabhuja": ['mw'],
    "dīrghabāhu": ['cae', 'mw'],
    "dīrghabāhugarvita": ['mw'],
    "dīrghabāhurgarvita": ['bhs'],
    "dīrghabījā": ['mw'],
    "dīrghacaturaśra": ['mw'],
    "dīrghacañcu": ['mw'],
    "dīrghacchada": ['mw'],
    "dīrghacārāyaṇa": ['bhs'],
    "dīrghadanta": ['mw'],
    "dīrghadarśana": ['mw'],
    "dīrghadarśin": ['cae', 'mw'],
    "dīrghadarśitva": ['mw'],
    "dīrghadarśitā": ['cae', 'mw'],
    "dīrghadarśivas": ['mw'],
    "dīrghadaṇḍa": ['mw'],
    "dīrghadaṇḍaka": ['mw'],
    "dīrghadaṇḍī": ['mw'],
    "dīrghadru": ['mw'],
    "dīrghadruma": ['mw'],
    "dīrghadveṣin": ['mw'],
    "dīrghadṛśvan": ['mw'],
    "dīrghadṛṣṭi": ['mw'],
    "dīrghagati": ['mw'],
    "dīrghaghāṭika": ['mw'],
    "dīrghagranthi": ['mw'],
    "dīrghagrīva": ['mw'],
    "dīrghagāmin": ['mw'],
    "dīrghajaṅgala": ['mw'],
    "dīrghajaṅgha": ['mw'],
    "dīrghajihva": ['cae', 'mw'],
    "dīrghajihvia": ['gra'],
    "dīrghajihvya": ['gra', 'mw'],
    "dīrghajihvā": ['mw'],
    "dīrghajihvī": ['mw'],
    "dīrghajānuka": ['mw'],
    "dīrghajīraka": ['mw'],
    "dīrghajīvantī": ['mw'],
    "dīrghajīvin": ['cae', 'mw'],
    "dīrghaka": ['bhs'],
    "dīrghakandaka": ['mw'],
    "dīrghakandikā": ['mw'],
    "dīrghakarṇa": ['cae', 'ddsa', 'mw'],
    "dīrghakarṣaṇa": ['mw'],
    "dīrghakaṃdharā": ['mw'],
    "dīrghakaṇā": ['mw'],
    "dīrghakaṇṭa": ['mw'],
    "dīrghakaṇṭaka": ['mw'],
    "dīrghakaṇṭha": ['mw'],
    "dīrghakaṇṭhaka": ['mw'],
    "dīrghakeśa": ['mw'],
    "dīrghakośikā": ['mw'],
    "dīrghakośā": ['mw'],
    "dīrghakośī": ['mw'],
    "dīrghakāla": ['mw'],
    "dīrghakālajīvin": ['mw'],
    "dīrghakālam": ['cae'],
    "dīrghakātyāyanī": ['bhs'],
    "dīrghakāya": ['mw'],
    "dīrghakāṇḍa": ['mw'],
    "dīrghakāṇḍā": ['mw'],
    "dīrghakāṣṭha": ['mw'],
    "dīrghakīla": ['mw'],
    "dīrghakīlaka": ['mw'],
    "dīrghakūraka": ['mw'],
    "dīrghakūrca": ['mw'],
    "dīrghalatādruma": ['mw'],
    "dīrghalocana": ['cae', 'mw'],
    "dīrghalohitayaṣṭikā": ['mw'],
    "dīrgham": ['mw'],
    "dīrghamukha": ['cae', 'mw'],
    "dīrghamukhī": ['mw'],
    "dīrghamāruta": ['mw'],
    "dīrghamūla": ['mw'],
    "dīrghamūlaka": ['mw'],
    "dīrghamūlikā": ['mw'],
    "dīrghamūlā": ['mw'],
    "dīrghamūlī": ['mw'],
    "dīrghanakha": ['bhs', 'mw'],
    "dīrghanakhī": ['mw'],
    "dīrghanidrā": ['mw'],
    "dīrghanirvaṃśa": ['mw'],
    "dīrghaniśvasya": ['mw'],
    "dīrghaniśvāsa": ['mw'],
    "dīrghaniḥśvāsa": ['cae'],
    "dīrghanāda": ['mw'],
    "dīrghanāla": ['mw'],
    "dīrghanītha": ['gra', 'mw'],
    "dīrghapad": ['mw'],
    "dīrghapakṣa": ['mw'],
    "dīrghapallava": ['mw'],
    "dīrghaparvan": ['mw'],
    "dīrghaparṇa": ['mw'],
    "dīrghaparṇī": ['mw'],
    "dīrghapattra": ['mw'],
    "dīrghapattraka": ['mw'],
    "dīrghapattrikā": ['mw'],
    "dīrghapattrā": ['mw'],
    "dīrghapattrī": ['mw'],
    "dīrghapavana": ['mw'],
    "dīrghapaṭolikā": ['mw'],
    "dīrghaphala": ['mw'],
    "dīrghaphalaka": ['mw'],
    "dīrghaphalā": ['mw'],
    "dīrghaprajña": ['mw'],
    "dīrghaprasadman": ['gra', 'mw'],
    "dīrghaprayajyu": ['cae', 'gra', 'mw'],
    "dīrghaprayatna": ['mw'],
    "dīrghaprekṣin": ['mw'],
    "dīrghaprāṇa": ['mw'],
    "dīrghapuṣpa": ['mw'],
    "dīrghapād": ['mw'],
    "dīrghapāda": ['mw'],
    "dīrghapādapa": ['mw'],
    "dīrghapādyā": ['mw'],
    "dīrghapāṭha": ['mw'],
    "dīrghapṛṣṭha": ['mw'],
    "dīrgharada": ['mw'],
    "dīrgharasana": ['mw'],
    "dīrgharata": ['mw'],
    "dīrgharaṅgā": ['mw'],
    "dīrgharogin": ['mw'],
    "dīrgharohiṣaka": ['mw'],
    "dīrgharoma": ['mw'],
    "dīrgharoman": ['mw'],
    "dīrgharoṣa": ['cae', 'mw'],
    "dīrgharoṣatā": ['mw'],
    "dīrgharoṣaṇa": ['mw'],
    "dīrgharāgā": ['mw'],
    "dīrgharātra": ['bhs'],
    "dīrgharātram": ['mw'],
    "dīrgharātrika": ['mw'],
    "dīrgharāva": ['cae', 'mw'],
    "dīrgharūpa": ['mw'],
    "dīrghasaktha": ['mw'],
    "dīrghasakthi": ['mw'],
    "dīrghasasya": ['mw'],
    "dīrghasattra": ['cae', 'mw'],
    "dīrghasaṃdhya": ['cae', 'mw'],
    "dīrghasaṃdhyatva": ['mw'],
    "dīrghaskandha": ['mw'],
    "dīrghasurata": ['mw'],
    "dīrghasvara": ['mw'],
    "dīrghasūtra": ['cae', 'mw'],
    "dīrghasūtratva": ['mw'],
    "dīrghasūtratā": ['mw'],
    "dīrghasūtrin": ['cae', 'mw'],
    "dīrghasūtritā": ['mw'],
    "dīrghatama": ['mw'],
    "dīrghatamas": ['cae', 'gra', 'mw'],
    "dīrghatamasorka": ['mw'],
    "dīrghatamasovrata": ['mw'],
    "dīrghatantu": ['gra', 'mw'],
    "dīrghatanu": ['mw'],
    "dīrghatanvī": ['mw'],
    "dīrghatapas": ['mw'],
    "dīrghatapaākhyāna": ['mw'],
    "dīrghatapaḥsvargagamana": ['mw'],
    "dīrghatara": ['mw'],
    "dīrghataru": ['mw'],
    "dīrghatimiṣā": ['mw'],
    "dīrghatuṇḍa": ['mw'],
    "dīrghatuṇḍā": ['mw'],
    "dīrghatva": ['mw'],
    "dīrghatā": ['mw'],
    "dīrghatīkṣṇamukha": ['cae', 'mw'],
    "dīrghatṛṇa": ['mw'],
    "dīrghavacchikā": ['mw'],
    "dīrghavaktra": ['mw'],
    "dīrghavarchikā": ['mw'],
    "dīrghavartman": ['mw'],
    "dīrghavarṇa": ['mw'],
    "dīrghavarṣābhū": ['mw'],
    "dīrghavat": ['mw'],
    "dīrghavaṃśa": ['mw'],
    "dīrghaveṇu": ['mw'],
    "dīrghaviśvavedasakaivalyadīpikā": ['mw'],
    "dīrghavyādhi": ['mw'],
    "dīrghavālā": ['mw'],
    "dīrghavārṣika": ['bhs'],
    "dīrghavṛkṣa": ['mw'],
    "dīrghavṛnta": ['mw'],
    "dīrghavṛntaka": ['mw'],
    "dīrghavṛntikā": ['mw'],
    "dīrghavṛntā": ['mw'],
    "dīrghavṛttaphalā": ['mw'],
    "dīrghaya": ['mw'],
    "dīrghayajña": ['mw'],
    "dīrghayaśas": ['cae', 'gra', 'mw'],
    "dīrghayāma": ['mw'],
    "dīrghayātha": ['gra', 'mw'],
    "dīrghaśakti": ['bhs'],
    "dīrghaśara": ['mw'],
    "dīrghaśimbika": ['mw'],
    "dīrghaśira": ['mw'],
    "dīrghaśmaśru": ['mw'],
    "dīrghaśravas": ['cae', 'gra', 'mw'],
    "dīrghaśrut": ['cae', 'gra', 'mw'],
    "dīrghaśākha": ['mw'],
    "dīrghaśākhikā": ['mw'],
    "dīrghaśūka": ['mw'],
    "dīrghaśūkaka": ['mw'],
    "dīrghaśṛṅga": ['mw'],
    "dīrghervāru": ['mw'],
    "dīrghika": ['bhs'],
    "dīrghikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "dīrghocchvāsam": ['cae', 'ddsa', 'mw'],
    "dīrghotkaṇṭhamanas": ['mw'],
    "dīrghya": ['bhs'],
    "dīrghā": ['mw'],
    "dīrghābhiniṣṭhānānta": ['mw'],
    "dīrghādhva": ['mw'],
    "dīrghādhvaga": ['mw'],
    "dīrghādhī": ['cae', 'ddsa', 'gra', 'mw'],
    "dīrghāgama": ['bhs', 'mw'],
    "dīrghāhan": ['mw'],
    "dīrghākāra": ['mw'],
    "dīrghākṣa": ['cae', 'ddsa', 'mw'],
    "dīrghālarka": ['mw'],
    "dīrghāmaya": ['mw'],
    "dīrghānala": ['mw'],
    "dīrghānuparivartin": ['mw'],
    "dīrghāpekṣin": ['mw'],
    "dīrghāpsas": ['gra', 'mw'],
    "dīrghāpāṅga": ['cae', 'mw'],
    "dīrghāraṇya": ['mw'],
    "dīrghāsya": ['mw'],
    "dīrghāyu": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "dīrghāyudha": ['mw'],
    "dīrghāyuka": ['bhs'],
    "dīrghāyus": ['cae', 'gra', 'mw'],
    "dīrghāyutva": ['gra', 'mw'],
    "dīrghāyuśocis": ['gra', 'mw'],
    "dīrghāyuṣka": ['mw'],
    "dīrghāyuṣya": ['cae', 'mw'],
    "dīrghāyuṣṭva": ['cae', 'mw'],
    "dīrghāṃhri": ['mw'],
    "dīrghāṅghri": ['mw'],
    "dīrghāṅgulitā": ['mw'],
    "dīrghāṅgī": ['mw'],
    "dīrghāṅkagrāma": ['mw'],
    "dīrghī": ['mw'],
    "dīrghībhāva": ['mw'],
    "dīrghībhū": ['ap90', 'mw'],
    "dīrghībhūta": ['mw'],
    "dīrghīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "dīrita": ['bhs'],
    "dīrṇa": ['ap90', 'mw'],
    "dīrṇāṅga": ['mw'],
    "dīti": ['cae', 'gra', 'mw'],
    "dītiḥ": ['ap90'],
    "dīv": ['cae', 'gra', 'mw'],
    "dīvana": ['ddsa', 'mw'],
    "dīvi": ['mw'],
    "dīvyat": ['mw'],
    "dīyamāna": ['cped'],
    "dīyati": ['cped'],
    "dīyittha": ['cped'],
    "dīḥ": ['ap90'],
    "dū": ['ap90', 'cae', 'gra', 'mw'],
    "dūbha": ['cped'],
    "dūda": ['mw'],
    "dūhara": ['cped'],
    "dūhati": ['cped'],
    "dūkūla": ['bhs'],
    "dūlikā": ['ap90', 'mw'],
    "dūlāla": ['mw'],
    "dūlālipattra": ['mw'],
    "dūlālīya": ['mw'],
    "dūlāsa": ['mw'],
    "dūlī": ['mw'],
    "dūl̤abha": ['mw'],
    "dūna": ['ap90', 'cae', 'ddsa', 'mw'],
    "dūpaṭṭhāka": ['cped'],
    "dūpra": ['mw'],
    "dūr": ['mw'],
    "dūra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dūrabandhu": ['mw'],
    "dūrabheda": ['mw'],
    "dūrabhinna": ['mw'],
    "dūrabhāj": ['mw'],
    "dūrabhāva": ['cae', 'mw'],
    "dūracara": ['mw'],
    "dūrada": ['ddsa', 'mw'],
    "dūradarśana": ['cae', 'ddsa', 'mw'],
    "dūradarśin": ['cae', 'mw'],
    "dūradṛś": ['mw'],
    "dūradṛṣṭi": ['mw'],
    "dūraga": ['cae', 'ddsa', 'mw'],
    "dūragamana": ['mw'],
    "dūragata": ['cae', 'mw'],
    "dūragrahaṇa": ['mw'],
    "dūragā": ['mw'],
    "dūragāmin": ['mw'],
    "dūragṛha": ['mw'],
    "dūraja": ['mw'],
    "dūraka": ['gra'],
    "dūrakam": ['cae'],
    "dūrakantana": ['cped'],
    "dūrake": ['cae'],
    "dūrakhātodaka": ['mw'],
    "dūrakta": ['mw'],
    "dūrakārya": ['mw'],
    "dūrakṣya": ['cae', 'ddsa', 'mw'],
    "dūram": ['mw'],
    "dūrama": ['cped'],
    "dūrambhaviṣṇu": ['mw'],
    "dūrambhāvuka": ['mw'],
    "dūramūla": ['mw'],
    "dūrapatha": ['cae', 'mw'],
    "dūraprasārin": ['mw'],
    "dūrapāra": ['ddsa', 'mw'],
    "dūrapārā": ['mw'],
    "dūrapāta": ['mw'],
    "dūrapātana": ['mw'],
    "dūrapātin": ['cae', 'mw'],
    "dūrapātitva": ['mw'],
    "dūrapātitā": ['mw'],
    "dūrapātra": ['mw'],
    "dūrasaṃstha": ['cae', 'mw'],
    "dūrasaṃsthāna": ['mw'],
    "dūrastha": ['cae', 'mw'],
    "dūrasthatva": ['mw'],
    "dūrasthita": ['cae', 'mw'],
    "dūrasthāyin": ['mw'],
    "dūrasvarga": ['mw'],
    "dūrasūrya": ['cae', 'mw'],
    "dūratara": ['cped', 'ddsa'],
    "dūratare": ['mw'],
    "dūratareṇa": ['mw'],
    "dūratas": ['cae', 'ddsa', 'mw'],
    "dūrataḥ": ['ap90'],
    "dūrato": ['cped'],
    "dūratobhū": ['mw'],
    "dūratva": ['cae', 'ddsa', 'mw'],
    "dūratā": ['mw'],
    "dūraupabda": ['gra'],
    "dūraupaśabdas": ['mw'],
    "dūravartin": ['cae', 'mw'],
    "dūravastraka": ['mw'],
    "dūravedha": ['bhs', 'mw'],
    "dūravedhin": ['mw'],
    "dūravibhinna": ['mw'],
    "dūravidāritānana": ['mw'],
    "dūravilambin": ['cae', 'mw'],
    "dūravāsin": ['mw'],
    "dūray": ['cae'],
    "dūraya": ['mw'],
    "dūrayanta": ['gra'],
    "dūrayartha": ['gra'],
    "dūrayupabda": ['gra'],
    "dūrayādhī": ['gra'],
    "dūrayādiś": ['gra'],
    "dūrayāyin": ['mw'],
    "dūraādhī": ['cae', 'ddsa', 'gra', 'mw'],
    "dūraādiś": ['gra', 'mw'],
    "dūraśravas": ['mw'],
    "dūraśravaṇa": ['mw'],
    "dūraśūnya": ['mw'],
    "dūraṁ": ['cped'],
    "dūraṃgama": ['cae', 'mw'],
    "dūraṃgamā": ['bhs'],
    "dūraṃgata": ['mw'],
    "dūraṃkaraṇa": ['mw'],
    "dūraṅgama": ['cped'],
    "dūre": ['cped', 'mw'],
    "dūreamitra": ['mw'],
    "dūreanta": ['cae', 'ddsa', 'gra', 'mw'],
    "dūreartha": ['gra', 'mw'],
    "dūrebhā": ['cae', 'mw'],
    "dūrebhās": ['gra'],
    "dūrebāndhava": ['mw'],
    "dūrecara": ['cae', 'ddsa', 'mw'],
    "dūredevata": ['mw'],
    "dūredṛś": ['cae', 'gra', 'mw'],
    "dūregavyūti": ['mw'],
    "dūreheti": ['mw'],
    "dūrejanāntanilaya": ['mw'],
    "dūrepaśyā": ['mw'],
    "dūrepānīyagocara": ['mw'],
    "dūrepāti(n)": ['cped'],
    "dūreritekṣaṇa": ['mw'],
    "dūretya": ['ap90', 'mw'],
    "dūrevadha": ['cae', 'mw'],
    "dūreyama": ['mw'],
    "dūreśravas": ['mw'],
    "dūreśruta": ['mw'],
    "dūreṇa": ['mw'],
    "dūreṣupātin": ['mw'],
    "dūrodāracaritra": ['ddsa'],
    "dūroha": ['cae', 'ddsa', 'mw'],
    "dūrohaṇa": ['cae', 'mw'],
    "dūrohaṇīya": ['mw'],
    "dūronnamita": ['mw'],
    "dūrotsārita": ['cae', 'mw'],
    "dūrotsāritatva": ['mw'],
    "dūrva": ['cae', 'mw'],
    "dūrveṣṭakā": ['mw'],
    "dūrvā": ['ap90', 'ddsa', 'gra', 'mw'],
    "dūrvācatvara": ['cae'],
    "dūrvāgaṇapativrata": ['mw'],
    "dūrvāgaṇapativratakathā": ['mw'],
    "dūrvākāṇḍa": ['mw'],
    "dūrvākṣī": ['mw'],
    "dūrvāloṣṭa": ['mw'],
    "dūrvāsoma": ['mw'],
    "dūrvāvana": ['mw'],
    "dūrvāvat": ['ddsa', 'mw'],
    "dūrvāvaṇa": ['mw'],
    "dūrvāvihāyakavrata": ['mw'],
    "dūrvāvrata": ['mw'],
    "dūrvāvratakathā": ['mw'],
    "dūrvāṣṭamī": ['mw'],
    "dūrya": ['mw'],
    "dūryaṃ": ['ap90'],
    "dūrā": ['cped', 'mw'],
    "dūrādha": ['mw'],
    "dūrādhirohin": ['mw'],
    "dūrāgata": ['ddsa', 'mw'],
    "dūrākṛṣṭa": ['cae'],
    "dūrāloka": ['cae', 'mw'],
    "dūrāntara": ['mw'],
    "dūrāntarita": ['mw'],
    "dūrāpaṇika": ['mw'],
    "dūrāpeta": ['mw'],
    "dūrāpetatva": ['mw'],
    "dūrāplāva": ['mw'],
    "dūrāpāta": ['mw'],
    "dūrāpātin": ['mw'],
    "dūrārohabuddhi": ['bhs'],
    "dūrārohin": ['cae', 'mw'],
    "dūrārtha": ['mw'],
    "dūrārūḍha": ['cae', 'mw'],
    "dūrāt": ['mw'],
    "dūrāvasthita": ['mw'],
    "dūrī": ['mw'],
    "dūrībhū": ['mw'],
    "dūrībhūta": ['mw'],
    "dūrīkaraṇa": ['mw'],
    "dūrīkṛ": ['cae', 'ddsa', 'mw'],
    "dūrīkṛta": ['mw'],
    "dūrśa": ['cae', 'mw'],
    "dūrūpa": ['mw'],
    "dūrūḍha": ['mw'],
    "dūrūḍhatva": ['mw'],
    "dūsa": ['mw'],
    "dūsaka": ['cped'],
    "dūsanīya": ['cped'],
    "dūsayati": ['cped'],
    "dūsesi": ['cped'],
    "dūsesuṁ": ['cped'],
    "dūseti": ['cped'],
    "dūsi(n)": ['cped'],
    "dūsita": ['cped'],
    "dūta": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "dūtaghnī": ['mw'],
    "dūtaka": ['cae', 'cped', 'mw'],
    "dūtakarman": ['cae', 'mw'],
    "dūtalakṣaṇa": ['mw'],
    "dūtamocana": ['mw'],
    "dūtamukha": ['mw'],
    "dūtaparīkṣā": ['mw'],
    "dūtasampreṣaṇa": ['mw'],
    "dūtatva": ['cae', 'mw'],
    "dūtavat": ['mw'],
    "dūtavākya": ['mw'],
    "dūtavākyaprabandha": ['mw'],
    "dūtaya": ['mw'],
    "dūtaḥ": ['ap90'],
    "dūtenūpasamapadā": ['cped'],
    "dūteyya": ['cped'],
    "dūti": ['mw'],
    "dūtia": ['gra'],
    "dūtikā": ['ap90', 'ddsa', 'mw'],
    "dūtitva": ['mw'],
    "dūtopasampadā": ['cped'],
    "dūtya": ['cae', 'ddsa', 'gra', 'mw'],
    "dūtyaṃ": ['ap90'],
    "dūtyupahāsa": ['mw'],
    "dūtāṅgada": ['mw'],
    "dūtī": ['bhs', 'ddsa', 'gra', 'mw'],
    "dūtūpasampadā": ['cped'],
    "dūyana": ['mw'],
    "dūśya": ['mw'],
    "dūśyaṃ": ['ap90'],
    "dūḍabha": ['cae', 'gra', 'mw'],
    "dūḍhya": ['mw'],
    "dūḍhī": ['cae', 'ddsa', 'gra', 'mw'],
    "dūḍāś": ['gra', 'mw'],
    "dūḍāśa": ['cae', 'mw'],
    "dūṇaśa": ['cae', 'gra', 'mw'],
    "dūṇāśa": ['cae', 'gra', 'mw'],
    "dūṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "dūṣaka": ['ap90', 'cae', 'mw'],
    "dūṣay": ['cae'],
    "dūṣaya": ['ddsa', 'mw'],
    "dūṣayat": ['mw'],
    "dūṣayitnu": ['mw'],
    "dūṣayitṛ": ['ap90', 'mw'],
    "dūṣayāṇa": ['mw'],
    "dūṣaṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "dūṣaṇatā": ['mw'],
    "dūṣaṇatāvādin": ['mw'],
    "dūṣaṇoddhāra": ['mw'],
    "dūṣaṇā": ['mw'],
    "dūṣaṇāri": ['mw'],
    "dūṣaṇāvaha": ['mw'],
    "dūṣaṇīya": ['ap90', 'mw'],
    "dūṣi": ['cae', 'ddsa', 'mw'],
    "dūṣika": ['bhs'],
    "dūṣikā": ['ap90', 'mw'],
    "dūṣin": ['cae', 'ddsa', 'mw'],
    "dūṣita": ['ap90', 'mw'],
    "dūṣitatva": ['mw'],
    "dūṣitā": ['mw'],
    "dūṣiḥ": ['ap90'],
    "dūṣya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "dūṣyagandhin": ['cae'],
    "dūṣyat": ['mw'],
    "dūṣyate": ['bhs'],
    "dūṣyayukta": ['mw'],
    "dūṣyudara": ['mw'],
    "dūṣyudarin": ['mw'],
    "dūṣyā": ['mw'],
    "dūṣāri": ['mw'],
    "dūṣī": ['cae', 'ddsa', 'mw'],
    "dūṣīkā": ['ap90', 'cae'],
    "dūṣīviṣa": ['mw'],
    "dṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dṛbdha": ['ap90', 'mw'],
    "dṛbdhi": ['cae', 'mw'],
    "dṛbdhiḥ": ['ap90'],
    "dṛbh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dṛbhīka": ['cae', 'gra', 'mw'],
    "dṛdhra": ['cae', 'gra', 'mw'],
    "dṛdhraṃ": ['ap90'],
    "dṛg": ['mw'],
    "dṛgadhyakṣa": ['mw'],
    "dṛganta": ['cae', 'ddsa', 'mw'],
    "dṛgañcala": ['mw'],
    "dṛgbhakti": ['mw'],
    "dṛgbhū": ['mw'],
    "dṛgdṛśyaprakaraṇa": ['mw'],
    "dṛgdṛśyaviveka": ['mw'],
    "dṛggati": ['mw'],
    "dṛggatijyā": ['mw'],
    "dṛggatijīvā": ['mw'],
    "dṛggocara": ['cae', 'mw'],
    "dṛggola": ['mw'],
    "dṛggolavarṇana": ['mw'],
    "dṛgjala": ['mw'],
    "dṛgjyā": ['mw'],
    "dṛglambana": ['mw'],
    "dṛgrudh": ['cae', 'mw'],
    "dṛgruj": ['mw'],
    "dṛgvihīna": ['mw'],
    "dṛgviṣa": ['mw'],
    "dṛgvṛtta": ['mw'],
    "dṛgāyudha": ['mw'],
    "dṛh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dṛk": ['mw'],
    "dṛka": ['mw'],
    "dṛkaṃ": ['ap90'],
    "dṛkcchada": ['mw'],
    "dṛkchattra": ['mw'],
    "dṛkchat‍tra": ['ddsa'],
    "dṛkkarman": ['mw'],
    "dṛkkarṇa": ['mw'],
    "dṛkkrodha": ['mw'],
    "dṛkkāṇa": ['mw'],
    "dṛkkṣatra": ['mw'],
    "dṛkkṣaya": ['mw'],
    "dṛkkṣepa": ['mw'],
    "dṛkpatha": ['cae', 'mw'],
    "dṛkpathamgam": ['mw'],
    "dṛkpathami": ['mw'],
    "dṛkprasādā": ['mw'],
    "dṛkpriyā": ['mw'],
    "dṛkpāta": ['cae', 'mw'],
    "dṛksaṃgama": ['mw'],
    "dṛksaṅgama": ['ddsa'],
    "dṛktulya": ['mw'],
    "dṛktulyatā": ['mw'],
    "dṛkāṇa": ['mw'],
    "dṛkśakti": ['mw'],
    "dṛkśravas": ['mw'],
    "dṛkśruti": ['mw'],
    "dṛkṣa": ['ddsa', 'mw'],
    "dṛl̤ha": ['mw'],
    "dṛmbhū": ['mw'],
    "dṛmicaṇḍeśvara": ['mw'],
    "dṛmp": ['mw'],
    "dṛmph": ['mw'],
    "dṛmphū": ['mw'],
    "dṛn": ['mw'],
    "dṛnbhū": ['mw'],
    "dṛnbhūḥ": ['ap90'],
    "dṛnphū": ['mw'],
    "dṛnphūḥ": ['ap90'],
    "dṛp": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dṛph": ['mw'],
    "dṛpra": ['ap90', 'mw'],
    "dṛpta": ['ap90', 'mw'],
    "dṛptabālāki": ['mw'],
    "dṛpti": ['mw'],
    "dṛptātman": ['mw'],
    "dṛpyat": ['mw'],
    "dṛta": ['ap90', 'mw'],
    "dṛti": ['cae', 'ddsa', 'gra', 'mw'],
    "dṛtidhāraka": ['mw'],
    "dṛtihari": ['mw'],
    "dṛtihāra": ['mw'],
    "dṛtikuṇḍatapaścit": ['mw'],
    "dṛtivātavata": ['mw'],
    "dṛtiḥ": ['ap90'],
    "dṛtyaṃ": ['ap90'],
    "dṛtā": ['mw'],
    "dṛvan": ['cae', 'mw'],
    "dṛś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dṛśa": ['ddsa', 'mw'],
    "dṛśad": ['ap90', 'mw'],
    "dṛśadvati": ['mw'],
    "dṛśam": ['mw'],
    "dṛśati": ['cae', 'gra', 'mw'],
    "dṛśatiḥ": ['ap90'],
    "dṛśenia": ['gra'],
    "dṛśenya": ['cae', 'gra', 'mw'],
    "dṛśi": ['cae', 'ddsa', 'gra', 'mw'],
    "dṛśia": ['gra'],
    "dṛśimat": ['ddsa', 'mw'],
    "dṛśiḥ": ['ap90'],
    "dṛśna": ['mw'],
    "dṛśopama": ['mw'],
    "dṛśvan": ['ap90', 'ddsa', 'mw'],
    "dṛśvantva": ['mw'],
    "dṛśya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dṛśyajāti": ['mw'],
    "dṛśyapura": ['mw'],
    "dṛśyasthāpita": ['mw'],
    "dṛśyati": ['bhs'],
    "dṛśyatva": ['mw'],
    "dṛśyatā": ['mw'],
    "dṛśyaśravya": ['mw'],
    "dṛśyaśravyatva": ['mw'],
    "dṛśyetara": ['mw'],
    "dṛśyetaratā": ['mw'],
    "dṛśyādṛśya": ['mw'],
    "dṛśyādṛśyā": ['mw'],
    "dṛśā": ['ap90', 'mw'],
    "dṛśākāṅkṣya": ['mw'],
    "dṛśālu": ['mw'],
    "dṛśāna": ['mw'],
    "dṛśānaḥ": ['ap90'],
    "dṛśāsphutamālā": ['mw'],
    "dṛśīka": ['ap90', 'cae', 'gra', 'mw'],
    "dṛśīku": ['mw'],
    "dṛśīkā": ['cae', 'ddsa', 'gra', 'mw'],
    "dṛḍaka": ['mw'],
    "dṛḍha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dṛḍhabaddha": ['mw'],
    "dṛḍhabala": ['bhs', 'mw'],
    "dṛḍhabandhanabaddha": ['mw'],
    "dṛḍhabandhinī": ['mw'],
    "dṛḍhabhakti": ['mw'],
    "dṛḍhabhaktika": ['mw'],
    "dṛḍhabhaktimat": ['mw'],
    "dṛḍhabhaktitā": ['mw'],
    "dṛḍhabuddhi": ['mw'],
    "dṛḍhabāhu": ['bhs'],
    "dṛḍhabīja": ['mw'],
    "dṛḍhacchada": ['mw'],
    "dṛḍhacyuta": ['mw'],
    "dṛḍhadasyu": ['ddsa', 'mw'],
    "dṛḍhadaṃśaka": ['mw'],
    "dṛḍhadeva": ['bhs'],
    "dṛḍhadhana": ['bhs', 'mw'],
    "dṛḍhadhanu": ['bhs'],
    "dṛḍhadhanus": ['mw'],
    "dṛḍhadhanvan": ['cae', 'mw'],
    "dṛḍhadhanvin": ['cae', 'mw'],
    "dṛḍhadhur": ['mw'],
    "dṛḍhadhṛti": ['mw'],
    "dṛḍhadvāra": ['mw'],
    "dṛḍhagranthi": ['mw'],
    "dṛḍhagrāhin": ['mw'],
    "dṛḍhagātrikā": ['mw'],
    "dṛḍhahanu": ['bhs', 'mw'],
    "dṛḍhahasta": ['mw'],
    "dṛḍhajñāna": ['mw'],
    "dṛḍhakaṇṭaka": ['mw'],
    "dṛḍhakaṇṭakā": ['mw'],
    "dṛḍhakrodha": ['mw'],
    "dṛḍhakuṭṭaka": ['mw'],
    "dṛḍhakārin": ['cae', 'mw'],
    "dṛḍhakāṇḍa": ['mw'],
    "dṛḍhakāṇḍā": ['mw'],
    "dṛḍhakṣatra": ['mw'],
    "dṛḍhakṣurā": ['mw'],
    "dṛḍhalatā": ['mw'],
    "dṛḍhaloman": ['mw'],
    "dṛḍham": ['mw'],
    "dṛḍhamanyu": ['mw'],
    "dṛḍhamati": ['bhs', 'cae', 'mw'],
    "dṛḍhamuṣṭi": ['cae', 'mw'],
    "dṛḍhamuṣṭitā": ['mw'],
    "dṛḍhamūla": ['bhs', 'mw'],
    "dṛḍhanemi": ['mw'],
    "dṛḍhanetra": ['mw'],
    "dṛḍhaniścaya": ['cae', 'mw'],
    "dṛḍhaniṣkramaṇa": ['bhs'],
    "dṛḍhanābha": ['mw'],
    "dṛḍhanāman": ['bhs'],
    "dṛḍhanīra": ['mw'],
    "dṛḍhapattra": ['mw'],
    "dṛḍhapattrī": ['mw'],
    "dṛḍhaphala": ['mw'],
    "dṛḍhaprabha": ['bhs'],
    "dṛḍhapraharaṇataraka": ['bhs'],
    "dṛḍhaprahāra": ['mw'],
    "dṛḍhaprahārin": ['mw'],
    "dṛḍhaprahāritā": ['bhs', 'mw'],
    "dṛḍhapralamba": ['bhs'],
    "dṛḍhapraroha": ['mw'],
    "dṛḍhapratijña": ['mw'],
    "dṛḍhapratyaya": ['mw'],
    "dṛḍhapāda": ['mw'],
    "dṛḍhapādā": ['mw'],
    "dṛḍhapādī": ['mw'],
    "dṛḍharatha": ['mw'],
    "dṛḍharaṅgā": ['mw'],
    "dṛḍharuci": ['mw'],
    "dṛḍhasamādhāna": ['mw'],
    "dṛḍhasauhṛda": ['mw'],
    "dṛḍhasaṃdha": ['mw'],
    "dṛḍhasaṃdhi": ['bhs', 'mw'],
    "dṛḍhasena": ['mw'],
    "dṛḍhaskandha": ['mw'],
    "dṛḍhasthūṇa": ['mw'],
    "dṛḍhasyu": ['mw'],
    "dṛḍhasūtrikā": ['mw'],
    "dṛḍhatara": ['mw'],
    "dṛḍhataru": ['mw'],
    "dṛḍhatarīkṛ": ['ddsa', 'mw'],
    "dṛḍhatoraṇārgala": ['mw'],
    "dṛḍhatva": ['mw'],
    "dṛḍhatvac": ['mw'],
    "dṛḍhatā": ['cae', 'ddsa', 'mw'],
    "dṛḍhatṛṇa": ['mw'],
    "dṛḍhatṛṇā": ['mw'],
    "dṛḍhavairin": ['mw'],
    "dṛḍhavajra": ['mw'],
    "dṛḍhavalka": ['mw'],
    "dṛḍhavalkala": ['mw'],
    "dṛḍhavalkā": ['mw'],
    "dṛḍhavapus": ['ddsa', 'mw'],
    "dṛḍhavarman": ['mw'],
    "dṛḍhavedhana": ['mw'],
    "dṛḍhavikrama": ['bhs', 'mw'],
    "dṛḍhavrata": ['cae', 'mw'],
    "dṛḍhavya": ['mw'],
    "dṛḍhavādaparākrama": ['mw'],
    "dṛḍhavīrya": ['bhs'],
    "dṛḍhavīryatā": ['bhs'],
    "dṛḍhavṛkṣa": ['mw'],
    "dṛḍhay": ['cae'],
    "dṛḍhaya": ['ddsa', 'mw'],
    "dṛḍhayati": ['ap90'],
    "dṛḍhaśakti": ['bhs'],
    "dṛḍhaśaktika": ['mw'],
    "dṛḍhekṣurā": ['mw'],
    "dṛḍheyu": ['mw'],
    "dṛḍheṣudhi": ['mw'],
    "dṛḍhiṣṭha": ['mw'],
    "dṛḍhā": ['bhs', 'mw'],
    "dṛḍhākṣa": ['mw'],
    "dṛḍhānutāpa": ['mw'],
    "dṛḍhāyu": ['cae', 'mw'],
    "dṛḍhāyudha": ['cae', 'ddsa', 'mw'],
    "dṛḍhāyus": ['cae', 'mw'],
    "dṛḍhāśva": ['mw'],
    "dṛḍhāṅga": ['mw'],
    "dṛḍhī": ['mw'],
    "dṛḍhībhū": ['mw'],
    "dṛḍhīkaraṇa": ['cae', 'ddsa', 'mw'],
    "dṛḍhīkaraṇaṃ": ['ap90'],
    "dṛḍhīkāra": ['mw'],
    "dṛḍhīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "dṛḍu": ['mw'],
    "dṛṃh": ['ap90', 'ddsa', 'gra', 'mw'],
    "dṛṃha": ['mw'],
    "dṛṃhaṇa": ['cae', 'mw'],
    "dṛṃhaṇaṃ": ['ap90'],
    "dṛṃhita": ['ap90', 'cae', 'mw'],
    "dṛṃhitṛ": ['cae', 'gra', 'mw'],
    "dṛṃp": ['ap90'],
    "dṛṃph": ['ap90'],
    "dṛṃphū": ['ap90'],
    "dṛṅ": ['mw'],
    "dṛṅmaṇḍala": ['mw'],
    "dṛṅnīraja": ['mw'],
    "dṛṣac": ['mw'],
    "dṛṣacchārada": ['mw'],
    "dṛṣad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "dṛṣada": ['mw'],
    "dṛṣadaka": ['mw'],
    "dṛṣadaśman": ['ddsa', 'mw'],
    "dṛṣadi": ['mw'],
    "dṛṣadimāṣaka": ['mw'],
    "dṛṣadolūkhala": ['cae', 'mw'],
    "dṛṣadupala": ['cae', 'mw'],
    "dṛṣadvant": ['cae'],
    "dṛṣadvat": ['ap90', 'mw'],
    "dṛṣadvatī": ['ddsa', 'gra', 'mw'],
    "dṛṣadya": ['mw'],
    "dṛṣan": ['mw'],
    "dṛṣannau": ['ddsa', 'mw'],
    "dṛṣat": ['mw'],
    "dṛṣatkaṇa": ['cae', 'ddsa', 'mw'],
    "dṛṣatputra": ['mw'],
    "dṛṣatsāra": ['mw'],
    "dṛṣyā": ['mw'],
    "dṛṣṭa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "dṛṣṭabhakti": ['mw'],
    "dṛṣṭacara": ['mw'],
    "dṛṣṭadharma": ['bhs', 'mw'],
    "dṛṣṭadharman": ['mw'],
    "dṛṣṭadharmika": ['bhs', 'mw'],
    "dṛṣṭadoṣa": ['cae', 'mw'],
    "dṛṣṭadraṣṭavya": ['mw'],
    "dṛṣṭaduḥkha": ['mw'],
    "dṛṣṭahāni": ['mw'],
    "dṛṣṭakarman": ['mw'],
    "dṛṣṭakaṣṭa": ['mw'],
    "dṛṣṭakūṭa": ['mw'],
    "dṛṣṭamātra": ['cae', 'mw'],
    "dṛṣṭanaṣṭa": ['mw'],
    "dṛṣṭanaṣṭatā": ['mw'],
    "dṛṣṭapratyaya": ['mw'],
    "dṛṣṭapuṣpā": ['mw'],
    "dṛṣṭapūrva": ['cae', 'mw'],
    "dṛṣṭapūrvin": ['mw'],
    "dṛṣṭarajas": ['mw'],
    "dṛṣṭarajaskā": ['mw'],
    "dṛṣṭaratha": ['mw'],
    "dṛṣṭarūpā": ['mw'],
    "dṛṣṭasāra": ['cae', 'mw'],
    "dṛṣṭatas": ['mw'],
    "dṛṣṭatva": ['mw'],
    "dṛṣṭavat": ['mw'],
    "dṛṣṭavyatikara": ['mw'],
    "dṛṣṭavīria": ['gra'],
    "dṛṣṭavīrya": ['cae', 'gra', 'mw'],
    "dṛṣṭaśakti": ['bhs'],
    "dṛṣṭaśarman": ['mw'],
    "dṛṣṭaśruta": ['cae', 'mw'],
    "dṛṣṭi": ['bhs', 'cae', 'ddsa', 'mw'],
    "dṛṣṭibandha": ['mw'],
    "dṛṣṭibandhu": ['mw'],
    "dṛṣṭibāṇa": ['mw'],
    "dṛṣṭidoṣa": ['mw'],
    "dṛṣṭidāna": ['mw'],
    "dṛṣṭigata": ['bhs', 'mw'],
    "dṛṣṭigocara": ['cae', 'mw'],
    "dṛṣṭiguru": ['mw'],
    "dṛṣṭiguṇa": ['mw'],
    "dṛṣṭika": ['bhs', 'mw'],
    "dṛṣṭikṛt": ['mw'],
    "dṛṣṭikṛta": ['bhs', 'mw'],
    "dṛṣṭikṣama": ['cae', 'mw'],
    "dṛṣṭikṣepa": ['cae', 'ddsa', 'mw'],
    "dṛṣṭimant": ['cae'],
    "dṛṣṭimat": ['mw'],
    "dṛṣṭimaṇḍala": ['mw'],
    "dṛṣṭimārga": ['mw'],
    "dṛṣṭin": ['ap90', 'mw'],
    "dṛṣṭinipāta": ['mw'],
    "dṛṣṭipa": ['mw'],
    "dṛṣṭiparāmarśa": ['bhs'],
    "dṛṣṭipatha": ['cae', 'mw'],
    "dṛṣṭipathin": ['mw'],
    "dṛṣṭiphala": ['mw'],
    "dṛṣṭiphalabhāvādhyāya": ['mw'],
    "dṛṣṭiprapāta": ['mw'],
    "dṛṣṭiprasāda": ['cae', 'mw'],
    "dṛṣṭipāta": ['cae', 'mw'],
    "dṛṣṭipūta": ['cae', 'mw'],
    "dṛṣṭipūtanā": ['mw'],
    "dṛṣṭiroga": ['mw'],
    "dṛṣṭirāga": ['cae', 'mw'],
    "dṛṣṭisambheda": ['mw'],
    "dṛṣṭisaṃbheda": ['cae'],
    "dṛṣṭivibhrama": ['mw'],
    "dṛṣṭividyā": ['mw'],
    "dṛṣṭivikṣepa": ['cae', 'mw'],
    "dṛṣṭiviṣa": ['bhs', 'mw'],
    "dṛṣṭivāda": ['mw'],
    "dṛṣṭiḥ": ['ap90'],
    "dṛṣṭotsāha": ['ddsa'],
    "dṛṣṭvā": ['mw'],
    "dṛṣṭvāya": ['mw'],
    "dṛṣṭyagocara": ['ddsa'],
    "dṛṣṭā": ['bhs'],
    "dṛṣṭādṛṣṭa": ['ddsa', 'mw'],
    "dṛṣṭānta": ['bhs', 'cae', 'mw'],
    "dṛṣṭāntaka": ['bhs'],
    "dṛṣṭāntakalikā": ['mw'],
    "dṛṣṭāntatas": ['mw'],
    "dṛṣṭāntavat": ['mw'],
    "dṛṣṭāntaya": ['mw'],
    "dṛṣṭāntaśataka": ['mw'],
    "dṛṣṭāntita": ['mw'],
    "dṛṣṭāriṣṭa": ['mw'],
    "dṛṣṭārtha": ['cae', 'mw'],
    "dṛṣṭārthatattvajña": ['mw'],
    "dṛṣṭī": ['bhs'],
    "dṝ": ['ap90', 'mw'],
    "e": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ed": ['cae', 'ddsa', 'mw'],
    "edh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "edha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "edhamāna": ['ap90', 'mw'],
    "edhamānadviṣ": ['gra', 'mw'],
    "edhanīya": ['mw'],
    "edhas": ['ap90', 'cae', 'ddsa', 'mw'],
    "edhati": ['cped'],
    "edhatu": ['ap90', 'cae', 'gra', 'mw'],
    "edhavant": ['cae'],
    "edhavat": ['mw'],
    "edhaḥ": ['ap90'],
    "edhi": ['ddsa'],
    "edhini": ['mw'],
    "edhita": ['ap90', 'mw'],
    "edhittha": ['cped'],
    "edhitṛ": ['mw'],
    "edhodaka": ['cae', 'ddsa', 'mw'],
    "edhā": ['ap90', 'mw'],
    "edidhiṣuḥpati": ['mw'],
    "edidhiṣuḥpatiḥ": ['ap90'],
    "edisa": ['cped'],
    "edisaka": ['cped'],
    "edānīm": ['bhs'],
    "edṛśa": ['bhs'],
    "edṛśaka": ['bhs'],
    "eha": ['ap90', 'bhs', 'cae', 'mw'],
    "ehas": ['ap90', 'cae', 'gra', 'mw'],
    "ehi": ['cped', 'ddsa', 'mw'],
    "ehibhadantika": ['cped'],
    "ehibhikkhu": ['cped'],
    "ehibhikkhunī": ['cped'],
    "ehibhikṣukā": ['bhs', 'mw'],
    "ehibhikṣuṇīvāda": ['bhs'],
    "ehidvitīyā": ['mw'],
    "ehikaṭā": ['mw'],
    "ehimāya": ['ap90', 'gra', 'mw'],
    "ehipassika": ['cped'],
    "ehipaśyika": ['bhs'],
    "ehisi": ['cped'],
    "ehisvāgatavādi": ['cped'],
    "ehisvāgatavādin": ['bhs', 'cped'],
    "ehisāgatavādi": ['cped'],
    "ehisāgatavādin": ['cped'],
    "ehivat": ['mw'],
    "ej": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "eja": ['cped'],
    "ejaka": ['ap90'],
    "ejana": ['mw'],
    "ejanaṃ": ['ap90'],
    "ejant": ['cae'],
    "ejat": ['mw'],
    "ejathu": ['cae', 'mw'],
    "ejathuḥ": ['ap90'],
    "ejatka": ['ap90', 'mw'],
    "ejaya": ['cae', 'gra', 'mw'],
    "eji": ['ap90', 'mw'],
    "ejita": ['ap90'],
    "ejitavya": ['mw'],
    "ejitṛ": ['mw'],
    "ejya": ['cae', 'mw'],
    "ejā": ['cped'],
    "ejānuga": ['cped'],
    "eka": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "eka-m-eka": ['cped'],
    "eka-m-ekaṁ": ['cped'],
    "ekabhakta": ['cae', 'mw'],
    "ekabhakti": ['cae', 'mw'],
    "ekabhaktika": ['mw'],
    "ekabhakṣa": ['mw'],
    "ekabhattika": ['cped'],
    "ekabhoga": ['mw'],
    "ekabhogya": ['mw'],
    "ekabhojana": ['mw'],
    "ekabhojin": ['mw'],
    "ekabhāga": ['mw'],
    "ekabhāva": ['cae', 'mw'],
    "ekabhāvin": ['cae', 'mw'],
    "ekabhūmika": ['mw'],
    "ekabhūta": ['cae', 'mw'],
    "ekabhūya": ['mw'],
    "ekabhūyas": ['mw'],
    "ekabuddhi": ['cae', 'mw'],
    "ekabīji": ['cped'],
    "ekabījin": ['cped'],
    "ekacakra": ['cae', 'ddsa', 'gra', 'mw'],
    "ekacakravartitā": ['mw'],
    "ekacakrā": ['mw'],
    "ekacakṣus": ['mw'],
    "ekacandrā": ['mw'],
    "ekacara": ['cae', 'cped', 'mw'],
    "ekacaraṇa": ['mw'],
    "ekacariyā": ['cped'],
    "ekacatvāriṃśa": ['mw'],
    "ekacatvāriṃśat": ['mw'],
    "ekacca": ['cped'],
    "ekacca-asassatika": ['cped'],
    "ekacca-sassatika": ['cped'],
    "ekacchannā": ['mw'],
    "ekacchatra": ['cae'],
    "ekacchattra": ['mw'],
    "ekacchāya": ['mw'],
    "ekacchāyāpraviṣṭa": ['mw'],
    "ekacchāyāśrita": ['mw'],
    "ekaccika": ['cped'],
    "ekacciya": ['cped'],
    "ekacetas": ['mw'],
    "ekachattra": ['bhs'],
    "ekachiggala": ['cped'],
    "ekachiggaḷa": ['cped'],
    "ekacinmaya": ['mw'],
    "ekacintana": ['mw'],
    "ekaciti": ['mw'],
    "ekacitika": ['mw'],
    "ekacitta": ['cae', 'mw'],
    "ekacittatā": ['mw'],
    "ekacittībhū": ['mw'],
    "ekacitīka": ['mw'],
    "ekacitīkatva": ['mw'],
    "ekacodana": ['mw'],
    "ekacāri": ['cped'],
    "ekacārin": ['cped', 'mw'],
    "ekacāriṇī": ['mw'],
    "ekacīraka": ['bhs'],
    "ekacūrṇi": ['mw'],
    "ekadanta": ['mw'],
    "ekadaṃṣṭra": ['mw'],
    "ekadaṇḍin": ['mw'],
    "ekadaṇḍisaṃnyāsavidhi": ['mw'],
    "ekadeha": ['mw'],
    "ekadehau": ['mw'],
    "ekadesa": ['cped'],
    "ekadeva": ['mw'],
    "ekadevata": ['mw'],
    "ekadevatya": ['mw'],
    "ekadeśa": ['cae', 'mw'],
    "ekadeśakālaka": ['bhs'],
    "ekadeśastha": ['mw'],
    "ekadeśatva": ['mw'],
    "ekadeśavibhāvita": ['mw'],
    "ekadeśavikāra": ['mw'],
    "ekadeśavikṛta": ['mw'],
    "ekadeśavivartin": ['mw'],
    "ekadeśin": ['mw'],
    "ekadhana": ['cae', 'mw'],
    "ekadhanavid": ['mw'],
    "ekadhanin": ['mw'],
    "ekadhanā": ['mw'],
    "ekadharma": ['cae', 'mw'],
    "ekadharmin": ['cae', 'mw'],
    "ekadhenu": ['gra', 'mw'],
    "ekadhippāya": ['cped'],
    "ekadhiṣṇya": ['mw'],
    "ekadhura": ['mw'],
    "ekadhurāvaha": ['mw'],
    "ekadhurīṇa": ['mw'],
    "ekadhyam": ['bhs'],
    "ekadhā": ['ap90', 'cae', 'mw'],
    "ekadhābhūya": ['mw'],
    "ekadhāra": ['mw'],
    "ekadhāraka": ['bhs', 'mw'],
    "ekadhātu": ['mw'],
    "ekadhītikā": ['cped'],
    "ekadiś": ['mw'],
    "ekadravya": ['mw'],
    "ekadugdha": ['mw'],
    "ekadukāye": ['bhs'],
    "ekaduḥkha": ['cae', 'mw'],
    "ekaduḥkhasukha": ['mw'],
    "ekadvāra": ['mw'],
    "ekadvīhikā": ['cped'],
    "ekadyū": ['gra', 'mw'],
    "ekadā": ['ap90', 'cae', 'cped', 'mw'],
    "ekadīkṣa": ['mw'],
    "ekadṛś": ['mw'],
    "ekadṛśya": ['mw'],
    "ekadṛṣṭi": ['mw'],
    "ekaga": ['mw'],
    "ekagarbha": ['mw'],
    "ekagga": ['cped'],
    "ekaggacitta": ['cped'],
    "ekaggatā": ['cped'],
    "ekaghana": ['bhs', 'cped'],
    "ekagrantha": ['mw'],
    "ekagrāma": ['cae', 'mw'],
    "ekagrāmīya": ['mw'],
    "ekagrāmīṇa": ['mw'],
    "ekagu": ['mw'],
    "ekaguru": ['mw'],
    "ekaguruka": ['mw'],
    "ekaguṇaṁ": ['cped'],
    "ekagārika": ['cped'],
    "ekahalya": ['mw'],
    "ekahasta": ['mw'],
    "ekahaṃsa": ['mw'],
    "ekahelayā": ['mw'],
    "ekahelā": ['mw'],
    "ekahārya": ['mw'],
    "ekahāyana": ['cae', 'ddsa', 'mw'],
    "ekahāyanī": ['mw'],
    "ekaika": ['cae', 'ddsa', 'mw'],
    "ekaikam": ['mw'],
    "ekaikatara": ['mw'],
    "ekaikatra": ['mw'],
    "ekaikavat": ['mw'],
    "ekaikavṛtti": ['mw'],
    "ekaikaśas": ['cae', 'mw'],
    "ekaikaśya": ['mw'],
    "ekaikaśyena": ['mw'],
    "ekaiśvarya": ['cae', 'ddsa', 'mw'],
    "ekaiṣikā": ['mw'],
    "ekaja": ['cae', 'cped', 'gra', 'mw'],
    "ekajanman": ['mw'],
    "ekajanmika": ['bhs'],
    "ekajaṭa": ['mw'],
    "ekajaṭā": ['bhs', 'mw'],
    "ekajaṭī": ['bhs'],
    "ekajjhaṁ": ['cped'],
    "ekajyotis": ['mw'],
    "ekajyā": ['mw'],
    "ekajāla": ['cped'],
    "ekajāta": ['cae', 'mw'],
    "ekajāti": ['cae', 'mw'],
    "ekajātipratibaddha": ['bhs'],
    "ekajātīya": ['mw'],
    "ekajīvavāda": ['mw'],
    "ekaka": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ekakakṣa": ['bhs'],
    "ekakalpa": ['mw'],
    "ekakamma": ['cped'],
    "ekakapāla": ['mw'],
    "ekakara": ['mw'],
    "ekakarmakāraka": ['mw'],
    "ekakarman": ['mw'],
    "ekakaśata": ['mw'],
    "ekakaṇṭaka": ['mw'],
    "ekakaṇṭha": ['mw'],
    "ekakhura": ['cae', 'mw'],
    "ekakrama": ['cae'],
    "ekakriya": ['mw'],
    "ekakriyāvidhi": ['cae', 'mw'],
    "ekakuṇḍala": ['mw'],
    "ekakuṣṭha": ['mw'],
    "ekakuṭika": ['cped'],
    "ekakāla": ['cae', 'mw'],
    "ekakālam": ['cae', 'mw'],
    "ekakālikam": ['cae', 'mw'],
    "ekakālin": ['mw'],
    "ekakāntarājan": ['bhs'],
    "ekakārya": ['mw'],
    "ekakṛṣṭa": ['mw'],
    "ekakṣīra": ['mw'],
    "ekala": ['ap90', 'cae', 'ddsa', 'mw'],
    "ekalakṣyatā": ['mw'],
    "ekalavya": ['mw'],
    "ekalavyā": ['mw'],
    "ekaliṅga": ['mw'],
    "ekalocana": ['cae'],
    "ekaloka": ['mw'],
    "ekalū": ['mw'],
    "ekamana": ['cped'],
    "ekamanas": ['cae', 'mw'],
    "ekamantaṁ": ['cped'],
    "ekamante": ['bhs', 'cped'],
    "ekamati": ['cae', 'mw'],
    "ekamaya": ['cae', 'mw'],
    "ekamaṁsakhala": ['cped'],
    "ekameka": ['bhs'],
    "ekamukha": ['cae', 'mw'],
    "ekamātra": ['mw'],
    "ekamāṣaka": ['cae'],
    "ekamūla": ['cae', 'mw'],
    "ekamūlaka": ['cped'],
    "ekamūlika": ['cped'],
    "ekamūlā": ['mw'],
    "ekamūrdhan": ['mw'],
    "ekamūrti": ['mw'],
    "ekanakṣatra": ['mw'],
    "ekanavata": ['mw'],
    "ekanavati": ['mw'],
    "ekanavatitama": ['mw'],
    "ekanavuta": ['cped'],
    "ekanavutikappa": ['cped'],
    "ekanayana": ['mw'],
    "ekanaṭa": ['mw'],
    "ekanemi": ['mw'],
    "ekanetra": ['mw'],
    "ekanetraka": ['mw'],
    "ekanibha": ['mw'],
    "ekanipāta": ['mw'],
    "ekaniścaya": ['mw'],
    "ekantarīka": ['cped'],
    "ekantarīkaṁ": ['cped'],
    "ekantarīyā": ['cped'],
    "ekantaṁ": ['cped'],
    "ekantaṁgata": ['cped'],
    "ekantaṁgatalomi": ['cped'],
    "ekantaṁgatalomin": ['cped'],
    "ekantaṁgatalomī": ['cped'],
    "ekantaṁkusalāyatika": ['cped'],
    "ekantika": ['cped'],
    "ekanāmatā": ['bhs'],
    "ekanātha": ['mw'],
    "ekanāthī": ['mw'],
    "ekanāyaka": ['mw'],
    "ekanīḍa": ['mw'],
    "ekapad": ['cae', 'gra', 'mw'],
    "ekapada": ['cae', 'cped', 'mw'],
    "ekapadam": ['mw'],
    "ekapadastha": ['mw'],
    "ekapadavat": ['mw'],
    "ekapade": ['mw'],
    "ekapadi": ['mw'],
    "ekapadika": ['mw'],
    "ekapadikā": ['bhs'],
    "ekapadā": ['mw'],
    "ekapadī": ['cae', 'mw'],
    "ekapakṣa": ['mw'],
    "ekapakṣe": ['mw'],
    "ekapakṣībhāva": ['mw'],
    "ekapakṣībhū": ['mw'],
    "ekapalādhika": ['cae', 'mw'],
    "ekapalāsika": ['cped'],
    "ekapalāśa": ['mw'],
    "ekapalāśīya": ['mw'],
    "ekapara": ['cae', 'gra', 'mw'],
    "ekapari": ['mw'],
    "ekapariyākata": ['cped'],
    "ekaparvataka": ['mw'],
    "ekaparṇikā": ['mw'],
    "ekaparṇā": ['mw'],
    "ekapassayika": ['cped'],
    "ekapati": ['mw'],
    "ekapatika": ['mw'],
    "ekapatikā": ['ddsa'],
    "ekapatitva": ['mw'],
    "ekapatni": ['cae'],
    "ekapatnitā": ['mw'],
    "ekapatnī": ['cae', 'mw'],
    "ekapatnīka": ['mw'],
    "ekapattra": ['mw'],
    "ekapattrikā": ['mw'],
    "ekapañcāśa": ['mw'],
    "ekapañcāśat": ['cae', 'mw'],
    "ekapañcāśattama": ['mw'],
    "ekapaśuka": ['mw'],
    "ekaphala": ['cae'],
    "ekaphalā": ['mw'],
    "ekapiṅga": ['mw'],
    "ekapiṅgala": ['mw'],
    "ekapiṅgalācala": ['mw'],
    "ekapiṇḍa": ['mw'],
    "ekapiṇḍayati": ['bhs'],
    "ekaprabhutva": ['mw'],
    "ekapradāna": ['mw'],
    "ekaprahārika": ['cae', 'mw'],
    "ekaprakhya": ['mw'],
    "ekaprakāra": ['mw'],
    "ekaprastha": ['mw'],
    "ekaprasūtā": ['bhs'],
    "ekapratihāra": ['mw'],
    "ekaprayatna": ['mw'],
    "ekaprādeśa": ['mw'],
    "ekaprāṇabhāva": ['mw'],
    "ekaprāṇayoga": ['mw'],
    "ekapuroḍāśa": ['mw'],
    "ekapuruṣa": ['cae', 'mw'],
    "ekaputra": ['mw'],
    "ekaputraka": ['mw'],
    "ekapuṇḍarīka": ['bhs', 'mw'],
    "ekapuṣkala": ['mw'],
    "ekapuṣpā": ['mw'],
    "ekapuṭa": ['bhs'],
    "ekapād": ['cae'],
    "ekapāda": ['cae', 'mw'],
    "ekapādaka": ['mw'],
    "ekapādikā": ['mw'],
    "ekapākopajīvin": ['mw'],
    "ekapārthiva": ['cae', 'mw'],
    "ekapāta": ['mw'],
    "ekapātin": ['cae', 'mw'],
    "ekapātra": ['mw'],
    "ekapāṇa": ['mw'],
    "ekapāṭalā": ['mw'],
    "ekapīta": ['cae', 'mw'],
    "ekapṛthaktva": ['mw'],
    "ekarada": ['mw'],
    "ekaraja": ['mw'],
    "ekarakṣa": ['bhs'],
    "ekarasa": ['cae', 'mw'],
    "ekaratha": ['mw'],
    "ekarca": ['cae', 'mw'],
    "ekarikthin": ['cae', 'mw'],
    "ekartu": ['mw'],
    "ekarudra": ['mw'],
    "ekarukkhika": ['cped'],
    "ekarāj": ['cae', 'gra', 'mw'],
    "ekarāja": ['cae', 'mw'],
    "ekarājñī": ['mw'],
    "ekarātra": ['cae', 'mw'],
    "ekarātrika": ['cae', 'mw'],
    "ekarātrīṇa": ['mw'],
    "ekarāśi": ['mw'],
    "ekarāśibhūta": ['mw'],
    "ekarāśigata": ['mw'],
    "ekarūpa": ['cae', 'gra', 'mw'],
    "ekarūpatas": ['mw'],
    "ekarūpatā": ['cae', 'mw'],
    "ekarūpya": ['mw'],
    "ekarṣi": ['cae', 'mw'],
    "ekasabha": ['mw'],
    "ekasahasra": ['cae', 'mw'],
    "ekasampratyaya": ['mw'],
    "ekasaptata": ['cae', 'mw'],
    "ekasaptati": ['cae', 'mw'],
    "ekasaptatiguṇa": ['cae', 'mw'],
    "ekasaptatika": ['mw'],
    "ekasaptatitama": ['mw'],
    "ekasarga": ['mw'],
    "ekasata": ['cped'],
    "ekasattati": ['cped'],
    "ekasatī": ['mw'],
    "ekasaṃvatsara": ['mw'],
    "ekasaṃśraya": ['cae', 'ddsa', 'mw'],
    "ekasaṭṭhi": ['cped'],
    "ekaseyya": ['cped'],
    "ekasphyā": ['mw'],
    "ekastambha": ['cae', 'mw'],
    "ekastha": ['cae', 'mw'],
    "ekasthāna": ['cae', 'mw'],
    "ekasthāne": ['mw'],
    "ekasthānāśraya": ['mw'],
    "ekastoma": ['mw'],
    "ekasākṣika": ['mw'],
    "ekasāla": ['mw'],
    "ekasālaka": ['cped'],
    "ekasāra": ['cae'],
    "ekasārthaprayāta": ['mw'],
    "ekasārīrika": ['cped'],
    "ekasūnu": ['mw'],
    "ekasūtra": ['mw'],
    "ekasṛka": ['mw'],
    "ekata": ['cae', 'mw'],
    "ekatama": ['ap90', 'cae', 'mw'],
    "ekatantrikā": ['mw'],
    "ekatantrī": ['mw'],
    "ekatara": ['ap90', 'cae', 'mw'],
    "ekatas": ['ap90', 'cae', 'mw'],
    "ekatatpara": ['ddsa', 'mw'],
    "ekataya": ['cae', 'mw'],
    "ekatejana": ['mw'],
    "ekatimsā": ['cped'],
    "ekatiya": ['cped'],
    "ekatiṁsa": ['cped'],
    "ekato": ['cped', 'mw'],
    "ekato-upasampanna": ['cped'],
    "ekatodant": ['cae'],
    "ekatodat": ['mw'],
    "ekatodhāra": ['cped'],
    "ekatokāja": ['cped'],
    "ekatomukha": ['mw'],
    "ekatopakkhika": ['cped'],
    "ekatovaṇṭikamālā": ['cped'],
    "ekatra": ['ap90', 'cae', 'mw'],
    "ekatrika": ['mw'],
    "ekatriṃśa": ['cae', 'mw'],
    "ekatriṃśadakṣara": ['mw'],
    "ekatriṃśaka": ['mw'],
    "ekatriṃśat": ['cae', 'mw'],
    "ekatta": ['cped'],
    "ekattakāya": ['cped'],
    "ekattanirata": ['cped'],
    "ekattasaññi": ['cped'],
    "ekattasaññin": ['cped'],
    "ekattavāsa": ['cped'],
    "ekattha": ['cped'],
    "ekattimsā": ['cped'],
    "ekattiṁsa": ['cped'],
    "ekatumba": ['mw'],
    "ekatva": ['cae', 'mw'],
    "ekatya": ['bhs'],
    "ekatyaśāśvatika": ['bhs'],
    "ekatā": ['ap90', 'cae', 'mw'],
    "ekatāla": ['mw'],
    "ekatālikā": ['mw'],
    "ekatālī": ['mw'],
    "ekatāna": ['mw'],
    "ekatīrthin": ['mw'],
    "ekatīrthya": ['mw'],
    "ekatṛṃśa": ['mw'],
    "ekaugha": ['mw'],
    "ekaughabhūta": ['mw'],
    "ekavacana": ['cae', 'mw'],
    "ekavacanodāhāra": ['bhs'],
    "ekavadbhāva": ['mw'],
    "ekavaktra": ['mw'],
    "ekavaktraka": ['mw'],
    "ekavaktrā": ['mw'],
    "ekavaraka": ['cped'],
    "ekavartanin": ['mw'],
    "ekavartman": ['mw'],
    "ekavarṇa": ['cae', 'mw'],
    "ekavarṇaka": ['mw'],
    "ekavarṇasamīkaraṇa": ['mw'],
    "ekavarṇī": ['mw'],
    "ekavarṣikā": ['mw'],
    "ekavasana": ['cae'],
    "ekavassa": ['cped'],
    "ekavassaṁ": ['cped'],
    "ekavastra": ['cae', 'mw'],
    "ekavastrasnānavidhi": ['mw'],
    "ekavastratā": ['mw'],
    "ekavat": ['mw'],
    "ekavatthuka": ['cped'],
    "ekaveda": ['cae', 'mw'],
    "ekaveśman": ['cae', 'mw'],
    "ekaveṇi": ['cae', 'mw'],
    "ekaveṇī": ['cae', 'mw'],
    "ekavibhakti": ['mw'],
    "ekavidha": ['cae', 'mw'],
    "ekavihāri": ['cped'],
    "ekavihārin": ['cped'],
    "ekavilocana": ['mw'],
    "ekaviṃśa": ['cae', 'mw'],
    "ekaviṃśaka": ['cae', 'mw'],
    "ekaviṃśasaṃpad": ['mw'],
    "ekaviṃśastoma": ['mw'],
    "ekaviṃśat": ['cae', 'mw'],
    "ekaviṃśati": ['mw'],
    "ekaviṃśaticchadi": ['mw'],
    "ekaviṃśatidhā": ['mw'],
    "ekaviṃśatitama": ['mw'],
    "ekaviṃśatividha": ['mw'],
    "ekaviṃśatka": ['mw'],
    "ekaviṃśavat": ['mw'],
    "ekaviṃśinī": ['mw'],
    "ekaviṣayin": ['mw'],
    "ekavrata": ['cae', 'mw'],
    "ekavrātya": ['mw'],
    "ekavyavasāyin": ['mw'],
    "ekavyākhyāna": ['mw'],
    "ekavyāvahārika": ['mw'],
    "ekavyūha": ['bhs', 'mw'],
    "ekavācaka": ['mw'],
    "ekavācika": ['cped'],
    "ekavāda": ['mw'],
    "ekavādyā": ['mw'],
    "ekavākya": ['mw'],
    "ekavākyatā": ['mw'],
    "ekavāram": ['mw'],
    "ekavāre": ['mw'],
    "ekavāsa": ['mw'],
    "ekavāsas": ['mw'],
    "ekavīcika": ['bhs'],
    "ekavīra": ['cae', 'gra', 'mw'],
    "ekavīrakalpa": ['mw'],
    "ekavīrya": ['mw'],
    "ekavīrā": ['mw'],
    "ekavīsa": ['cped'],
    "ekavīsaṁ": ['cped'],
    "ekavṛka": ['mw'],
    "ekavṛkṣa": ['mw'],
    "ekavṛkṣīya": ['mw'],
    "ekavṛnda": ['mw'],
    "ekavṛt": ['mw'],
    "ekavṛtta": ['mw'],
    "ekavṛṣa": ['mw'],
    "ekayajña": ['mw'],
    "ekayakāra": ['mw'],
    "ekayama": ['mw'],
    "ekayaṣṭi": ['cae', 'ddsa', 'mw'],
    "ekayaṣṭikā": ['cae', 'mw'],
    "ekayoga": ['mw'],
    "ekayoni": ['cae', 'mw'],
    "ekayāna": ['bhs'],
    "ekayāvan": ['mw'],
    "ekayūpa": ['mw'],
    "ekaśalākā": ['mw'],
    "ekaśapha": ['cae', 'mw'],
    "ekaśarīra": ['mw'],
    "ekaśarīrin": ['mw'],
    "ekaśarīrānvaya": ['mw'],
    "ekaśarīrārambha": ['mw'],
    "ekaśarīrāvayava": ['mw'],
    "ekaśarīrāvayavatva": ['mw'],
    "ekaśas": ['ap90', 'cae', 'mw'],
    "ekaśata": ['cae', 'ddsa', 'gra', 'mw'],
    "ekaśatadhā": ['mw'],
    "ekaśatatama": ['cae', 'mw'],
    "ekaśatavidha": ['mw'],
    "ekaśepa": ['mw'],
    "ekaśeṣa": ['cae', 'mw'],
    "ekaśilā": ['mw'],
    "ekaśitipad": ['mw'],
    "ekaśnuṣṭi": ['mw'],
    "ekaśrutadhara": ['mw'],
    "ekaśruti": ['cae', 'mw'],
    "ekaśrutimūlatva": ['mw'],
    "ekaśrutyupadeśa": ['mw'],
    "ekaśruṣṭi": ['mw'],
    "ekaśulka": ['mw'],
    "ekaśuṅga": ['mw'],
    "ekaśākha": ['mw'],
    "ekaśākhīya": ['mw'],
    "ekaśālika": ['mw'],
    "ekaśālā": ['mw'],
    "ekaśāyin": ['mw'],
    "ekaśīla": ['mw'],
    "ekaśīrṣan": ['mw'],
    "ekaśīrṣā": ['bhs'],
    "ekaśūla": ['mw'],
    "ekaśṛṅga": ['bhs', 'mw'],
    "ekaśṛṅgā": ['mw'],
    "ekaṁsa": ['cped'],
    "ekaṁsabhavita": ['cped'],
    "ekaṁsavacana": ['cped'],
    "ekaṁsavyākaraṇiya": ['cped'],
    "ekaṁsavāda": ['cped'],
    "ekaṁsena": ['cped'],
    "ekaṁsika": ['cped'],
    "ekaṅga": ['cped'],
    "ekaṅgadassi": ['cped'],
    "ekaṅgadassin": ['cped'],
    "ekaṅgahīna": ['cped'],
    "ekaṛtu": ['mw'],
    "ekaṛṣi": ['mw'],
    "ekaṣaṣṭa": ['cae', 'mw'],
    "ekaṣaṣṭi": ['cae', 'mw'],
    "ekaṣaṣṭitama": ['mw'],
    "ekaṭṭha": ['cped'],
    "ekeka": ['cped'],
    "ekekṣaṇa": ['mw'],
    "ekendriya": ['mw'],
    "ekeṣa": ['gra', 'mw'],
    "ekeṣṭaka": ['mw'],
    "ekeṣṭakā": ['mw'],
    "ekin": ['cae', 'mw'],
    "ekindriya": ['cped'],
    "ekoccaya": ['ddsa', 'mw'],
    "ekodaka": ['cae', 'cped', 'ddsa', 'mw'],
    "ekodakībhhūta": ['cped'],
    "ekoddiṣṭa": ['cae', 'ddsa', 'mw'],
    "ekoddiṣṭaśrāddhapaddhati": ['mw'],
    "ekodi": ['cped'],
    "ekodibhāva": ['cped'],
    "ekodibhāvita": ['cped'],
    "ekodibhūta": ['cped'],
    "ekodihoti": ['cped'],
    "ekodikaroti": ['cped'],
    "ekodikatabba": ['cped'],
    "ekodikātabba": ['cped'],
    "ekodāhāra": ['bhs'],
    "ekodātta": ['mw'],
    "ekokti": ['mw'],
    "ekolmuka": ['mw'],
    "ekona": ['cae', 'ddsa', 'mw'],
    "ekonaviṃśati": ['mw'],
    "ekonnata": ['mw'],
    "ekoti": ['mw'],
    "ekotibhāva": ['bhs', 'mw'],
    "ekotibhūta": ['bhs'],
    "ekotsava": ['bhs'],
    "ekottara": ['bhs', 'cae', 'ddsa', 'mw'],
    "ekottarika": ['bhs'],
    "ekottarikā": ['mw'],
    "ekottarikāgama": ['mw'],
    "ekotībhāva": ['bhs'],
    "ekotīkaroti": ['bhs'],
    "ekuddesa": ['cped'],
    "ekuttarika": ['cped'],
    "ekuttariya": ['cped'],
    "ekā": ['mw'],
    "ekābdā": ['mw'],
    "ekāc": ['ddsa'],
    "ekādasa": ['cped'],
    "ekādasaka": ['cped'],
    "ekādasama": ['cped'],
    "ekādaśa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ekādaśacchadi": ['mw'],
    "ekādaśadhā": ['mw'],
    "ekādaśadvāra": ['cae', 'mw'],
    "ekādaśaguṇa": ['cae'],
    "ekādaśaka": ['ap90', 'mw'],
    "ekādaśakapāla": ['mw'],
    "ekādaśakṛtvas": ['mw'],
    "ekādaśama": ['cae', 'mw'],
    "ekādaśamārikā": ['mw'],
    "ekādaśan": ['ap90', 'cae', 'gra', 'mw'],
    "ekādaśarca": ['mw'],
    "ekādaśarātra": ['mw'],
    "ekādaśarāśika": ['mw'],
    "ekādaśaskandhārthanirūpaṇakārikā": ['mw'],
    "ekādaśatva": ['mw'],
    "ekādaśavarṣa": ['mw'],
    "ekādaśavidha": ['mw'],
    "ekādaśaviṣṇugaṇaśrāddha": ['mw'],
    "ekādaśavyūha": ['mw'],
    "ekādaśikā": ['bhs'],
    "ekādaśin": ['ap90', 'cae', 'mw'],
    "ekādaśinī": ['mw'],
    "ekādaśottama": ['mw'],
    "ekādaśā": ['bhs'],
    "ekādaśāha": ['mw'],
    "ekādaśākṣa": ['mw'],
    "ekādaśākṣara": ['mw'],
    "ekādaśāratni": ['mw'],
    "ekādaśī": ['bhs', 'mw'],
    "ekādaśīvrata": ['mw'],
    "ekādeśa": ['mw'],
    "ekādhika": ['cae', 'ddsa'],
    "ekādhipati": ['mw'],
    "ekādhyāyin": ['mw'],
    "ekāgni": ['ddsa', 'mw'],
    "ekāgnika": ['mw'],
    "ekāgnikāṇḍa": ['mw'],
    "ekāgra": ['cae', 'mw'],
    "ekāgracitta": ['mw'],
    "ekāgradhī": ['mw'],
    "ekāgradṛṣṭi": ['mw'],
    "ekāgram": ['mw'],
    "ekāgramanas": ['mw'],
    "ekāgramati": ['bhs', 'mw'],
    "ekāgratas": ['mw'],
    "ekāgratva": ['mw'],
    "ekāgratā": ['mw'],
    "ekāgrya": ['mw'],
    "ekāha": ['cae', 'ddsa', 'mw'],
    "ekāhadhanin": ['mw'],
    "ekāhagama": ['mw'],
    "ekāham": ['mw'],
    "ekāhan": ['cae', 'mw'],
    "ekāhatya": ['bhs'],
    "ekāhaṁ": ['cped'],
    "ekāhena": ['cped'],
    "ekāhenamata": ['cped'],
    "ekāhika": ['bhs', 'cped'],
    "ekāhnā": ['mw'],
    "ekāhāra": ['ddsa', 'mw'],
    "ekāhārya": ['mw'],
    "ekāhātāna": ['mw'],
    "ekāki": ['cped'],
    "ekākika": ['cped'],
    "ekākin": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "ekākiya": ['cped'],
    "ekākāra": ['bhs'],
    "ekākṣa": ['cae', 'ddsa', 'mw'],
    "ekākṣara": ['cae', 'mw'],
    "ekākṣaragaṇapatistotra": ['mw'],
    "ekākṣarakośa": ['mw'],
    "ekākṣaramālikā": ['mw'],
    "ekākṣaranighaṇṭa": ['mw'],
    "ekākṣaranāmamālā": ['mw'],
    "ekākṣarābhidhānakośa": ['mw'],
    "ekākṣarībhāva": ['mw'],
    "ekākṣipiṅgalin": ['mw'],
    "ekālopika": ['cped'],
    "ekālāpaka": ['bhs', 'mw'],
    "ekāmracandrikā": ['mw'],
    "ekāmranātha": ['mw'],
    "ekāmrapurāṇa": ['mw'],
    "ekāmravanamāhātmya": ['mw'],
    "ekāmravaṇa": ['mw'],
    "ekānartha": ['cae', 'ddsa', 'mw'],
    "ekānavā": ['bhs'],
    "ekānaṃśā": ['ddsa', 'mw'],
    "ekānekasvarūpa": ['mw'],
    "ekānna": ['mw'],
    "ekānnabhojin": ['mw'],
    "ekānnanaktabhojana": ['mw'],
    "ekānnapañcāśadrātra": ['mw'],
    "ekānnaviṃsa": ['mw'],
    "ekānnaviṃsatidhā": ['mw'],
    "ekānnādin": ['cae', 'ddsa', 'mw'],
    "ekānta": ['cae', 'ddsa', 'mw'],
    "ekāntabhāva": ['mw'],
    "ekāntabhīru": ['cae'],
    "ekāntabhūta": ['mw'],
    "ekāntaduḥkha": ['mw'],
    "ekāntaduḥṣamā": ['mw'],
    "ekāntagrahaṇa": ['mw'],
    "ekāntagrāhin": ['mw'],
    "ekāntahita": ['cae'],
    "ekāntaka": ['bhs'],
    "ekāntakaruṇa": ['ddsa', 'mw'],
    "ekāntam": ['mw'],
    "ekāntamati": ['mw'],
    "ekāntara": ['cae', 'ddsa', 'mw'],
    "ekāntarahasya": ['mw'],
    "ekāntaraurava": ['bhs'],
    "ekāntarin": ['mw'],
    "ekāntaritin": ['mw'],
    "ekāntarāj": ['mw'],
    "ekāntarājan": ['bhs'],
    "ekāntasthita": ['mw'],
    "ekāntasuṣamā": ['mw'],
    "ekāntasādhya": ['cae'],
    "ekāntatas": ['mw'],
    "ekāntatva": ['mw'],
    "ekāntatā": ['mw'],
    "ekāntavidhvaṃsin": ['ddsa'],
    "ekāntavihārin": ['mw'],
    "ekāntaśīla": ['cae', 'mw'],
    "ekānte": ['mw'],
    "ekāntena": ['mw'],
    "ekāntika": ['mw'],
    "ekāntin": ['cae', 'mw'],
    "ekāntitva": ['mw'],
    "ekāntāt": ['mw'],
    "ekāntīkaroti": ['bhs'],
    "ekānudiṣṭa": ['cae', 'ddsa', 'mw'],
    "ekānugāna": ['mw'],
    "ekānvaya": ['cae', 'ddsa', 'mw'],
    "ekānṛca": ['mw'],
    "ekāpacaya": ['ddsa', 'mw'],
    "ekāpāya": ['cae', 'ddsa', 'mw'],
    "ekāra": ['cae', 'ddsa', 'mw'],
    "ekārakṣa": ['bhs'],
    "ekāratni": ['mw'],
    "ekārtha": ['cae', 'ddsa', 'mw'],
    "ekārthadarśin": ['bhs'],
    "ekārthadīpaka": ['mw'],
    "ekārthanāmamālā": ['mw'],
    "ekārthasamupeta": ['mw'],
    "ekārthatva": ['mw'],
    "ekārthatā": ['mw'],
    "ekārthībhāva": ['mw'],
    "ekārāma": ['bhs', 'ddsa', 'mw'],
    "ekārāmatā": ['cped', 'mw'],
    "ekārṇava": ['mw'],
    "ekārṣeya": ['mw'],
    "ekāsana": ['cped'],
    "ekāsanabhojana": ['cped'],
    "ekāsani": ['cped'],
    "ekāsanika": ['bhs', 'cped', 'mw'],
    "ekāsanin": ['cped'],
    "ekāsya": ['mw'],
    "ekātapatra": ['cae', 'ddsa', 'mw'],
    "ekātman": ['cae', 'mw'],
    "ekātmanībhūtvā": ['bhs'],
    "ekātmapakṣa": ['mw'],
    "ekātmapakṣavāda": ['mw'],
    "ekātmatā": ['mw'],
    "ekātmya": ['mw'],
    "ekāvacāraka": ['bhs'],
    "ekāvali": ['cae', 'ddsa', 'mw'],
    "ekāvalikā": ['bhs'],
    "ekāvaliprakāśa": ['mw'],
    "ekāvalitarala": ['mw'],
    "ekāvalī": ['cae', 'mw'],
    "ekāvalīprakāśa": ['mw'],
    "ekāvalītarala": ['mw'],
    "ekāvama": ['mw'],
    "ekāvarta": ['mw'],
    "ekāvayava": ['mw'],
    "ekāvāñc": ['mw'],
    "ekāyana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ekāyanagata": ['mw'],
    "ekāyanībhāva": ['mw'],
    "ekāyanībhū": ['mw'],
    "ekāyu": ['gra', 'mw'],
    "ekāñjali": ['ddsa', 'mw'],
    "ekāśin": ['mw'],
    "ekāśrama": ['mw'],
    "ekāśraya": ['mw'],
    "ekāśrayaguṇa": ['mw'],
    "ekāśrita": ['mw'],
    "ekāśritaguṇa": ['mw'],
    "ekāśīta": ['mw'],
    "ekāśīti": ['mw'],
    "ekāśītitama": ['mw'],
    "ekāṃsam": ['bhs'],
    "ekāṃsīkṛta": ['bhs'],
    "ekāṃśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "ekāṃśena": ['bhs'],
    "ekāṃśika": ['bhs'],
    "ekāṃśīkṛta": ['bhs'],
    "ekāṅga": ['cae', 'ddsa', 'mw'],
    "ekāṅgagraha": ['mw'],
    "ekāṅgarūpaka": ['cae', 'mw'],
    "ekāṅgau": ['mw'],
    "ekāṅgī": ['mw'],
    "ekāṇḍa": ['mw'],
    "ekāṣṭakā": ['mw'],
    "ekāṣṭhīla": ['mw'],
    "ekāṣṭhīlā": ['mw'],
    "ekāṣṭī": ['mw'],
    "ekī": ['mw'],
    "ekībhāva": ['cae', 'cped', 'mw'],
    "ekībhāvastotra": ['mw'],
    "ekībhāvaḥ": ['ap90'],
    "ekībhāvin": ['mw'],
    "ekībhū": ['ap90', 'mw'],
    "ekībhūta": ['bhs'],
    "ekīkaraṇa": ['mw'],
    "ekīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "ekīya": ['ap90', 'mw'],
    "ekūnapaññāsa": ['cped'],
    "ekūnapaññāsaṁ": ['cped'],
    "ekūnapaṇṇāsa": ['cped'],
    "ekūnatiṁsa": ['cped'],
    "ekūnatiṁsaṁ": ['cped'],
    "ekūnatiṁsaṁkkhattuṁ": ['cped'],
    "ekūnavīsa": ['cped'],
    "ekūnavīsati": ['cped'],
    "ekūnavīsatima": ['cped'],
    "ekūnavīsaṁ": ['cped'],
    "ekṣ": ['mw'],
    "ekṣya": ['mw'],
    "ela": ['bhs', 'mw'],
    "elabhadra": ['bhs'],
    "elada": ['bhs', 'mw'],
    "elagalavāca": ['cped'],
    "elaka": ['bhs', 'mw'],
    "elakapādaka": ['cped'],
    "elakaḥ": ['ap90'],
    "elamela": ['bhs'],
    "elamūga": ['cped'],
    "elapatra": ['bhs'],
    "elatā": ['bhs'],
    "elavarṇa": ['bhs'],
    "elavila": ['mw'],
    "elavilaḥ": ['ap90'],
    "elavālu": ['ap90', 'mw'],
    "elavāluka": ['mw'],
    "elaṃgaḥ": ['ap90'],
    "elaṅga": ['mw'],
    "elaṇḍa": ['cped'],
    "elu": ['bhs', 'mw'],
    "eluda": ['bhs'],
    "eluka": ['bhs', 'mw'],
    "elukaṃ": ['ap90'],
    "elvavāluka": ['mw'],
    "elvālu": ['mw'],
    "elvāluka": ['mw'],
    "elā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "elāgandhika": ['mw'],
    "elāka": ['mw'],
    "elākapura": ['mw'],
    "elāna": ['mw'],
    "elāparṇī": ['mw'],
    "elāpattra": ['bhs', 'mw'],
    "elāphala": ['mw'],
    "elāpura": ['mw'],
    "elārasālaka": ['mw'],
    "elāvali": ['mw'],
    "elāvāluka": ['mw'],
    "elāya": ['mw'],
    "elāyati": ['ap90'],
    "elīkā": ['ap90', 'mw'],
    "elūka": ['bhs'],
    "em": ['bhs', 'cped'],
    "ema": ['ap90', 'cae', 'ddsa', 'mw'],
    "eman": ['gra', 'mw'],
    "eminā": ['bhs'],
    "emuṣam": ['mw'],
    "emūṣa": ['mw'],
    "ena": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "enap": ['ddsa'],
    "enas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "enasvant": ['cae'],
    "enasvat": ['ap90', 'gra', 'mw'],
    "enasvin": ['cae', 'mw'],
    "enasya": ['ap90', 'mw'],
    "endh": ['mw'],
    "eno": ['mw'],
    "enomuc": ['mw'],
    "env": ['mw'],
    "enā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "enī": ['ap90', 'ddsa', 'gra', 'mw'],
    "enījaṅgha": ['cped'],
    "er": ['mw'],
    "eragu": ['cped'],
    "eraka": ['bhs', 'cae', 'mw'],
    "erakakṣa": ['bhs'],
    "erakavattika": ['cped'],
    "erakā": ['ap90', 'mw'],
    "erakī": ['mw'],
    "eramattaka": ['mw'],
    "eravaṇa": ['bhs'],
    "erayati": ['cped'],
    "erayita": ['cped'],
    "eraṃgaḥ": ['ap90'],
    "eraṃḍakaḥ": ['ap90'],
    "eraṃḍaḥ": ['ap90'],
    "eraṅga": ['mw'],
    "eraṇdakatela": ['cped'],
    "eraṇdatela": ['cped'],
    "eraṇḍa": ['cae', 'ddsa', 'mw'],
    "eraṇḍaka": ['mw'],
    "eraṇḍapalla": ['mw'],
    "eraṇḍapattraka": ['mw'],
    "eraṇḍapattrikā": ['mw'],
    "eraṇḍaphalā": ['mw'],
    "eraṇḍataila": ['mw'],
    "eraṇḍā": ['mw'],
    "eraṇḍītīrtha": ['mw'],
    "ereti": ['cped'],
    "erire": ['ddsa'],
    "erita": ['bhs', 'cped'],
    "eru": ['ap90', 'mw'],
    "ervāru": ['ddsa', 'mw'],
    "ervāruka": ['mw'],
    "ervāruḥ": ['ap90'],
    "erā": ['mw'],
    "esa": ['cped'],
    "esana": ['cped'],
    "esanā": ['cped'],
    "esanī": ['cped'],
    "esat": ['cped'],
    "esati": ['cped'],
    "esi": ['cped'],
    "esikaṭṭhāyiṭṭhita": ['cped'],
    "esikā": ['cped'],
    "esitvā": ['cped'],
    "essanti": ['cped'],
    "essati": ['cped'],
    "essāmi": ['cped'],
    "esāna": ['cped'],
    "eta": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "etad": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "etadagra": ['bhs'],
    "etadanta": ['cae', 'ddsa', 'mw'],
    "etadantika": ['cped'],
    "etadartham": ['cae', 'mw'],
    "etadatirikta": ['mw'],
    "etadatthiya": ['cped'],
    "etadavadhi": ['mw'],
    "etadavastha": ['cae', 'mw'],
    "etaddevatya": ['mw'],
    "etaddvitīya": ['mw'],
    "etaddā": ['mw'],
    "etadohi": ['cped'],
    "etadupaniṣad": ['mw'],
    "etadvat": ['mw'],
    "etadvaśa": ['cae'],
    "etadvid": ['cae'],
    "etadyoni": ['cae', 'mw'],
    "etadādi": ['mw'],
    "etadātmya": ['mw'],
    "etadīya": ['ap90', 'mw'],
    "etageha": ['cped'],
    "etagva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "etaj": ['mw'],
    "etajja": ['mw'],
    "etaka": ['mw'],
    "etan": ['mw'],
    "etana": ['mw'],
    "etanaḥ": ['ap90'],
    "etanmaya": ['cae', 'mw'],
    "etannimittam": ['cae'],
    "etannāmaka": ['cae', 'ddsa'],
    "etaparama": ['cped'],
    "etaparamaṁ": ['cped'],
    "etarahesi": ['bhs'],
    "etarahi": ['bhs', 'cped'],
    "etarhi": ['ap90', 'cae', 'ddsa', 'mw'],
    "etarhiṃ": ['bhs'],
    "etarī": ['gra'],
    "etase": ['cped'],
    "etat": ['mw'],
    "etatkāla": ['cae', 'ddsa'],
    "etatkālam": ['mw'],
    "etatkālīna": ['mw'],
    "etatkṣaṇe": ['mw'],
    "etatkṣaṇāt": ['mw'],
    "etatpara": ['mw'],
    "etatprabhṛti": ['mw'],
    "etatprathama": ['mw'],
    "etatsama": ['mw'],
    "etatsamīpa": ['mw'],
    "etattulya": ['cae', 'mw'],
    "etattṛtīya": ['mw'],
    "etavai": ['cae'],
    "etave": ['cae', 'cped', 'ddsa'],
    "etaśa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "etaśas": ['ap90', 'mw'],
    "etena upāyena": ['cped'],
    "etha": ['cped'],
    "eti": ['bhs', 'cae', 'cped', 'gra', 'mw'],
    "etivat": ['mw'],
    "etiḥ": ['ap90'],
    "etta": ['bhs', 'cped'],
    "ettaka": ['bhs', 'cped'],
    "ettakaṁ": ['cped'],
    "ettakena": ['cped'],
    "ettha": ['bhs', 'cped'],
    "etthantare": ['cped'],
    "etthaṃ": ['bhs'],
    "ettiya": ['bhs'],
    "etto": ['bhs', 'cped'],
    "ettāvat": ['bhs'],
    "ettāvatā": ['cped'],
    "etu": ['gra'],
    "etya": ['mw'],
    "etā": ['mw'],
    "etādisa": ['cped'],
    "etādisikā": ['cped'],
    "etādṛkṣa": ['cae', 'ddsa', 'mw'],
    "etādṛś": ['ap90', 'cae', 'gra', 'mw'],
    "etādṛśa": ['cae', 'mw'],
    "etādṛśaka": ['bhs'],
    "etāva": ['cped'],
    "etāvac": ['mw'],
    "etāvacchas": ['mw'],
    "etāvad": ['mw'],
    "etāvaddhā": ['mw'],
    "etāvadāvāsa": ['mw'],
    "etāvan": ['mw'],
    "etāvanmātra": ['cae', 'mw'],
    "etāvant": ['cae'],
    "etāvat": ['ap90', 'cped', 'ddsa', 'gra', 'mw'],
    "etāvataparama": ['cped'],
    "etāvataparamaṁ": ['cped'],
    "etāvatitha": ['mw'],
    "etāvattva": ['mw'],
    "etāvattvaṃ": ['ap90'],
    "etṛ": ['ap90', 'cae', 'gra', 'mw'],
    "eva": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "evadassi": ['cped'],
    "evadassin": ['cped'],
    "evala": ['bhs'],
    "evam": ['cae', 'ddsa', 'gra', 'mw'],
    "evam eva": ['cped'],
    "evamabhyanūkta": ['mw'],
    "evamarthīya": ['mw'],
    "evamavastha": ['ddsa', 'mw'],
    "evambhūta": ['mw'],
    "evambhūtavat": ['mw'],
    "evampariṇāma": ['ddsa', 'mw'],
    "evamprabhāva": ['mw'],
    "evamprakāra": ['mw'],
    "evampratyaya": ['mw'],
    "evampravāda": ['mw'],
    "evamprāya": ['mw'],
    "evampūrva": ['mw'],
    "evamācāra": ['mw'],
    "evamādi": ['cae', 'mw'],
    "evamādya": ['mw'],
    "evamākṛti": ['mw'],
    "evamātmaka": ['mw'],
    "evarūpa": ['bhs', 'cae', 'cped'],
    "evata": ['bhs'],
    "evathā": ['gra', 'mw'],
    "evayā": ['cae', 'gra', 'mw'],
    "evayāmarut": ['cae', 'gra', 'mw'],
    "evayāvan": ['cae', 'gra', 'mw'],
    "evaṁ": ['cped'],
    "evaṁbhāvi": ['cped'],
    "evaṁbhāvin": ['cped'],
    "evaṁdiṭṭhi": ['cped'],
    "evaṁdiṭṭhika": ['cped'],
    "evaṁdiṭṭhin": ['cped'],
    "evaṁgata": ['cped'],
    "evaṁgatika": ['cped'],
    "evaṁjacca": ['cped'],
    "evaṁkāri": ['cped'],
    "evaṁkārin": ['cped'],
    "evaṁrūpa": ['cped'],
    "evaṁsaddha": ['cped'],
    "evaṁsaññi": ['cped'],
    "evaṁsaññin": ['cped'],
    "evaṁvihitaka": ['cped'],
    "evaṁvihāri": ['cped'],
    "evaṁvihārin": ['cped'],
    "evaṁvādi": ['cped'],
    "evaṁvādin": ['cped'],
    "evaṃ": ['ap90'],
    "evaṃbhūta": ['cae'],
    "evaṃdarśana": ['bhs'],
    "evaṃdarśin": ['cae'],
    "evaṃdravya": ['mw'],
    "evaṃdṛṣṭi": ['bhs'],
    "evaṃgata": ['cae', 'mw'],
    "evaṃgate": ['mw'],
    "evaṃgotra": ['mw'],
    "evaṃguṇa": ['cae', 'mw'],
    "evaṃguṇajātīya": ['mw'],
    "evaṃguṇasaṃpanna": ['mw'],
    "evaṃguṇopeta": ['cae', 'mw'],
    "evaṃjāti": ['mw'],
    "evaṃjātīya": ['mw'],
    "evaṃkara": ['bhs'],
    "evaṃkarman": ['cae', 'mw'],
    "evaṃkratu": ['mw'],
    "evaṃkāla": ['mw'],
    "evaṃkāram": ['mw'],
    "evaṃkārya": ['mw'],
    "evaṃkḷpta": ['mw'],
    "evaṃnyaṅga": ['mw'],
    "evaṃnyāya": ['mw'],
    "evaṃnāman": ['mw'],
    "evaṃprakāra": ['cae'],
    "evaṃprāya": ['cae'],
    "evaṃpūrva": ['cae'],
    "evaṃrūpa": ['ddsa', 'mw'],
    "evaṃsamṛddha": ['mw'],
    "evaṃsaṃjñaka": ['mw'],
    "evaṃsaṃsthitika": ['mw'],
    "evaṃtarkin": ['cae', 'mw'],
    "evaṃvid": ['cae', 'mw'],
    "evaṃvidha": ['cae', 'mw'],
    "evaṃvidhi": ['bhs'],
    "evaṃvidus": ['mw'],
    "evaṃvidvas": ['cae', 'mw'],
    "evaṃviśeṣaṇa": ['mw'],
    "evaṃviṣaya": ['mw'],
    "evaṃvrata": ['mw'],
    "evaṃvādin": ['ddsa'],
    "evaṃvīrya": ['mw'],
    "evaṃvṛtta": ['cae', 'mw'],
    "evaṃvṛtti": ['mw'],
    "evaṃyuktam": ['mw'],
    "evaṃśīla": ['mw'],
    "evaṅkarman": ['ddsa'],
    "evā": ['cae'],
    "evācāra": ['cped'],
    "evāra": ['gra', 'mw'],
    "evāvada": ['ap90', 'gra', 'mw'],
    "evāṣa": ['cae', 'mw'],
    "eyaṃ": ['bhs'],
    "eḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "eḍagaja": ['mw'],
    "eḍaka": ['cae', 'mw'],
    "eḍakamūka": ['bhs'],
    "eḍakarajas": ['bhs'],
    "eḍakaḥ": ['ap90'],
    "eḍakīya": ['mw'],
    "eḍameḍa": ['bhs'],
    "eḍamūka": ['bhs', 'mw'],
    "eḍikākṣī": ['mw'],
    "eḍoka": ['mw'],
    "eḍuka": ['mw'],
    "eḍukaḥ": ['ap90'],
    "eḍākṣipuṣpa": ['bhs'],
    "eḍī": ['mw'],
    "eḍūka": ['mw'],
    "eḥ": ['ap90'],
    "eḷagalāgumba": ['cped'],
    "eḷaka": ['cped'],
    "eḷaka-m-antaraṁ": ['cped'],
    "eḷakacamma": ['cped'],
    "eḷakaloma": ['cped'],
    "eḷakasamāna": ['cped'],
    "eḷakasaṁvāsa": ['cped'],
    "eḷakā": ['cped'],
    "eḷakī": ['cped'],
    "eḷamūga": ['cped'],
    "eṅ": ['ddsa'],
    "eṇa": ['cae', 'ddsa', 'mw'],
    "eṇabhṛt": ['mw'],
    "eṇadṛś": ['mw'],
    "eṇajaṅgha": ['mw'],
    "eṇaka": ['mw'],
    "eṇamada": ['mw'],
    "eṇanetra": ['mw'],
    "eṇanetrā": ['cae'],
    "eṇatilaka": ['ddsa', 'mw'],
    "eṇavilocana": ['mw'],
    "eṇaśiras": ['mw'],
    "eṇaḥ": ['ap90'],
    "eṇekṣaṇa": ['mw'],
    "eṇeyyajaṅgha": ['cped'],
    "eṇeyyaka": ['cped'],
    "eṇi": ['bhs'],
    "eṇikā": ['mw'],
    "eṇājina": ['mw'],
    "eṇākṣa": ['mw'],
    "eṇākṣī": ['cae'],
    "eṇāṅka": ['mw'],
    "eṇāṅkamaṇi": ['ddsa', 'mw'],
    "eṇī": ['ap90', 'bhs', 'ddsa', 'mw'],
    "eṇīdāha": ['mw'],
    "eṇīdṛś": ['cae', 'mw'],
    "eṇīka": ['mw'],
    "eṇīkīya": ['mw'],
    "eṇīnayana": ['mw'],
    "eṇīpacana": ['mw'],
    "eṇīpacanīya": ['mw'],
    "eṇīpada": ['mw'],
    "eṇīpadī": ['mw'],
    "eṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "eṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "eṣaiṣia": ['gra'],
    "eṣaiṣya": ['gra', 'mw'],
    "eṣaka": ['bhs'],
    "eṣakā": ['mw'],
    "eṣati": ['bhs'],
    "eṣavīra": ['mw'],
    "eṣaṇa": ['ap90', 'cae', 'gra', 'mw'],
    "eṣaṇikā": ['ap90', 'mw'],
    "eṣaṇin": ['ap90', 'mw'],
    "eṣaṇā": ['mw'],
    "eṣaṇāsamiti": ['mw'],
    "eṣaṇī": ['mw'],
    "eṣaṇīya": ['ap90', 'mw'],
    "eṣikā": ['bhs', 'mw'],
    "eṣin": ['ap90', 'cae', 'mw'],
    "eṣiriṣū": ['bhs'],
    "eṣitavya": ['mw'],
    "eṣitṛ": ['ap90', 'mw'],
    "eṣya": ['ap90', 'cae', 'mw'],
    "eṣyat": ['ap90', 'mw'],
    "eṣyatkālīya": ['mw'],
    "eṣā": ['mw'],
    "eṣṭa": ['cae', 'mw'],
    "eṣṭavai": ['mw'],
    "eṣṭavya": ['cae', 'mw'],
    "eṣṭi": ['cae', 'gra', 'mw'],
    "eṣṭiḥ": ['ap90'],
    "eṣṭṛ": ['cae', 'mw'],
    "eṭh": ['ap90', 'mw'],
    "ga": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gabbha": ['cped'],
    "gabbhakaraṇa": ['cped'],
    "gabbhapātana": ['cped'],
    "gabbhaseyyā": ['cped'],
    "gabbhavokkanti": ['cped'],
    "gabbhaṁ gaṇhāti": ['cped'],
    "gabbhi(n)": ['cped'],
    "gabbhinī": ['cped'],
    "gabdikā": ['mw'],
    "gabh": ['gra'],
    "gabha": ['cae', 'ddsa', 'mw'],
    "gabhastala": ['cae', 'ddsa', 'mw'],
    "gabhasti": ['cae', 'ddsa', 'gra', 'mw'],
    "gabhastihasta": ['mw'],
    "gabhastimant": ['cae'],
    "gabhastimat": ['ap90', 'mw'],
    "gabhastimālin": ['mw'],
    "gabhastinemi": ['mw'],
    "gabhastipāṇi": ['mw'],
    "gabhastipūta": ['gra', 'mw'],
    "gabhastivāra": ['mw'],
    "gabhastiḥ": ['ap90'],
    "gabhastī": ['mw'],
    "gabhastīśvara": ['mw'],
    "gabhaḥ": ['ap90'],
    "gabhira": ['bhs'],
    "gabhiṣak": ['mw'],
    "gabholika": ['mw'],
    "gabholikaḥ": ['ap90'],
    "gabhvara": ['mw'],
    "gabhīkā": ['mw'],
    "gabhīra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gabhīravepas": ['gra', 'mw'],
    "gabhīrikā": ['ap90', 'mw'],
    "gabm, gambha": ['ddsa'],
    "gaccha": ['cped', 'ddsa', 'mw'],
    "gaccha(t)": ['cped'],
    "gacchamāna": ['cped'],
    "gacchamānaka": ['bhs'],
    "gacchanta": ['cped'],
    "gacchantaka": ['bhs'],
    "gacchanti": ['cped'],
    "gacchasi": ['cped'],
    "gacchat": ['mw'],
    "gacchati": ['bhs', 'cped'],
    "gacchaḥ": ['ap90'],
    "gacchaṁ": ['cped'],
    "gacchi": ['cped'],
    "gacchisi": ['cped'],
    "gacchissam": ['cped'],
    "gacchissanti": ['cped'],
    "gacchissati": ['cped'],
    "gacchissāmi": ['cped'],
    "gacchiṁsu": ['cped'],
    "gacchāmi": ['cped'],
    "gad": ['ap90', 'cae', 'ddsa', 'mw'],
    "gada": ['cae', 'ddsa', 'gra', 'mw'],
    "gadana": ['cae', 'ddsa', 'mw'],
    "gadanigraha": ['mw'],
    "gadasiṃha": ['mw'],
    "gadavarman": ['mw'],
    "gadayitnu": ['ap90', 'mw'],
    "gadaḥ": ['ap90'],
    "gaddhabādhipubba": ['cped'],
    "gadduhana": ['cped'],
    "gaddulabhaddha": ['cped'],
    "gaddūhana": ['cped'],
    "gadga": ['mw'],
    "gadgada": ['ap90', 'cae', 'ddsa', 'mw'],
    "gadgadabhāṣaṇa": ['mw'],
    "gadgadabhāṣin": ['mw'],
    "gadgadadhvani": ['mw'],
    "gadgadagala": ['mw'],
    "gadgadaka": ['mw'],
    "gadgadapada": ['mw'],
    "gadgadaruddha": ['mw'],
    "gadgadasvara": ['bhs', 'mw'],
    "gadgadatva": ['mw'],
    "gadgadatā": ['mw'],
    "gadgadavāc": ['mw'],
    "gadgadavākya": ['mw'],
    "gadgadayati": ['ap90'],
    "gadgadaśabda": ['mw'],
    "gadgadikā": ['ddsa', 'mw'],
    "gadgadita": ['ap90', 'mw'],
    "gadgadya": ['mw'],
    "gadh": ['ap90', 'ddsa', 'gra', 'mw'],
    "gadha": ['cae'],
    "gadhia": ['gra'],
    "gadhita": ['cped', 'mw'],
    "gadhitacitta": ['cped'],
    "gadhya": ['ap90', 'gra', 'mw'],
    "gadhā": ['mw'],
    "gadi": ['mw'],
    "gadin": ['ap90', 'cae', 'ddsa', 'mw'],
    "gadisiṃha": ['mw'],
    "gadita": ['ap90', 'mw'],
    "gadrabha": ['cped'],
    "gadya": ['ap90', 'cae', 'ddsa', 'mw'],
    "gadyapadyamaya": ['mw'],
    "gadyarāmāyaṇakāvya": ['mw'],
    "gadyālaka": ['mw'],
    "gadyāna": ['mw'],
    "gadyānaka": ['mw'],
    "gadyāṇa": ['ddsa', 'mw'],
    "gadyāṇaka": ['mw'],
    "gadyāṇakaḥ": ['ap90'],
    "gadā": ['ap90', 'cae', 'ddsa', 'mw'],
    "gadābhṛt": ['cae', 'ddsa', 'mw'],
    "gadādhara": ['cae', 'ddsa', 'mw'],
    "gadādharabhaṭṭa": ['mw'],
    "gadāgada": ['mw'],
    "gadāgraja": ['mw'],
    "gadāgrapāṇi": ['mw'],
    "gadāgraṇī": ['mw'],
    "gadāhasta": ['mw'],
    "gadāhva": ['mw'],
    "gadāhvaya": ['mw'],
    "gadākhya": ['mw'],
    "gadāmbara": ['mw'],
    "gadāntaka": ['mw'],
    "gadāparvan": ['mw'],
    "gadāpāṇi": ['mw'],
    "gadārāti": ['mw'],
    "gadāvasāna": ['mw'],
    "gadāya": ['mw'],
    "gadāyuddha": ['mw'],
    "gadāyuddhaparvan": ['mw'],
    "gadāyudha": ['mw'],
    "gagala": ['mw'],
    "gagana": ['cae', 'cped', 'mw'],
    "gaganabhramaṇa": ['mw'],
    "gaganabuddhi": ['bhs'],
    "gaganacara": ['mw'],
    "gaganacitta": ['bhs'],
    "gaganacārin": ['mw'],
    "gaganadhvaja": ['mw'],
    "gaganaga": ['mw'],
    "gaganagarbha": ['bhs'],
    "gaganagati": ['ddsa', 'mw'],
    "gaganagañja": ['bhs', 'mw'],
    "gaganagañjasūtra": ['bhs'],
    "gaganaghoṣa": ['bhs'],
    "gaganakośānāvaraṇajñānagarbha": ['bhs'],
    "gaganakusuma": ['mw'],
    "gaganakāntarāja": ['bhs'],
    "gaganalih": ['mw'],
    "gaganameghaśrī": ['bhs'],
    "gaganamūrdhan": ['mw'],
    "gagananagara": ['mw'],
    "gagananetra": ['bhs'],
    "gagananirghoṣasvara": ['bhs'],
    "gaganaparidhāna": ['mw'],
    "gaganapradīpaabhirāmaśrī": ['bhs'],
    "gaganaprajña": ['bhs'],
    "gaganapratiṣṭha": ['cae'],
    "gaganapriya": ['mw'],
    "gaganapuṣpa": ['mw'],
    "gaganaromantha": ['mw'],
    "gaganaromanthāyita": ['mw'],
    "gaganasad": ['mw'],
    "gaganasindhu": ['mw'],
    "gaganasiṃha": ['mw'],
    "gaganasparśana": ['mw'],
    "gaganaspṛś": ['cae', 'mw'],
    "gaganastha": ['mw'],
    "gaganasthita": ['mw'],
    "gaganatala": ['cae', 'mw'],
    "gaganavallabha": ['mw'],
    "gaganavihārin": ['cae', 'mw'],
    "gaganaśrī": ['bhs'],
    "gaganaṃ": ['ap90'],
    "gaganecara": ['mw'],
    "gaganojjvala": ['cae'],
    "gaganolmuka": ['mw'],
    "gaganādhivāsin": ['mw'],
    "gaganādhvaga": ['mw'],
    "gaganāgra": ['mw'],
    "gaganālaya": ['bhs'],
    "gaganāmbu": ['mw'],
    "gaganānanda": ['mw'],
    "gaganāpagā": ['ddsa', 'mw'],
    "gaganāravinda": ['mw'],
    "gaganāyas": ['mw'],
    "gaganāyasa": ['mw'],
    "gaganāṅgana": ['cae'],
    "gaganāṅganā": ['cae', 'mw'],
    "gaganāṅgaṇa": ['mw'],
    "gagaṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "gagaṇagāmin": ['bhs'],
    "gagaṇaprekṣiṇīlipi": ['bhs'],
    "gagaṇaṃ": ['ap90'],
    "gaggh": ['ap90', 'mw'],
    "gagghati": ['cped'],
    "gagnu": ['mw'],
    "gah": ['ap90', 'gra', 'mw'],
    "gaha": ['bhs', 'cped', 'mw'],
    "gahaka": ['cped'],
    "gahakāra": ['cped'],
    "gahakāraka": ['cped'],
    "gahakūṭa": ['cped'],
    "gahana": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "gahananissita": ['cped'],
    "gahanatva": ['mw'],
    "gahanatā": ['bhs'],
    "gahanavat": ['mw'],
    "gahaneṣṭha": ['mw'],
    "gahanā": ['mw'],
    "gahanāya": ['mw'],
    "gahanīkṛ": ['ddsa'],
    "gahanīkṛta": ['mw'],
    "gahapata": ['cped'],
    "gahapataggi": ['cped'],
    "gahapati": ['cped'],
    "gahapaticīvara": ['cped'],
    "gahapatika": ['cped'],
    "gahapatikula": ['cped'],
    "gahapatimahāsala": ['cped'],
    "gahapatinecayika": ['cped'],
    "gahapatiratana": ['cped'],
    "gahapatāggi": ['cped'],
    "gahapatānī": ['cped'],
    "gahastha": ['bhs'],
    "gahavibhava": ['cped'],
    "gahaṇa": ['cped'],
    "gahaṇī": ['cped'],
    "gahaṭṭha": ['cped'],
    "gahaṭṭhaka": ['cped'],
    "gahaṭṭhā": ['cped'],
    "gahessanti": ['cped'],
    "gahessati": ['cped'],
    "gahessaṁ": ['cped'],
    "gahessāmi": ['cped'],
    "gaheta(r)": ['cped'],
    "gahetabba": ['cped'],
    "gahetuṁ": ['cped'],
    "gahetvā": ['cped'],
    "gahetvāna": ['cped'],
    "gahi": ['mw'],
    "gahissati": ['cped'],
    "gahita": ['cped'],
    "gahman": ['ap90', 'mw'],
    "gahvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "gahvareṣṭha": ['cae', 'mw'],
    "gahvarita": ['ap90', 'mw'],
    "gahvarā": ['mw'],
    "gahvarī": ['mw'],
    "gahvarībhūta": ['mw'],
    "gahvaṃ": ['ap90'],
    "gahya": ['mw'],
    "gahādi": ['mw'],
    "gahāya": ['cped'],
    "gahīta": ['cped'],
    "gahīya": ['ap90', 'mw'],
    "gai": ['ap90', 'ddsa', 'mw'],
    "gailānya": ['bhs'],
    "gaira": ['ap90', 'mw'],
    "gairakaṃvūla": ['mw'],
    "gaireya": ['ap90', 'mw'],
    "gairika": ['ap90', 'cae', 'ddsa', 'mw'],
    "gairikadhātu": ['mw'],
    "gairikaṃvūla": ['mw'],
    "gairikā": ['mw'],
    "gairikācala": ['mw'],
    "gairikākhya": ['mw'],
    "gairikākṣa": ['mw'],
    "gairikāñjana": ['mw'],
    "gairikṣita": ['gra', 'mw'],
    "gairāyaṇa": ['mw'],
    "gairī": ['mw'],
    "gairīyaka": ['mw'],
    "gaiṣṭi": ['mw'],
    "gaj": ['ap90', 'mw'],
    "gaja": ['cae', 'cped', 'ddsa', 'mw'],
    "gajabandhana": ['mw'],
    "gajabandhanī": ['mw'],
    "gajabandhinī": ['mw'],
    "gajabhakṣaka": ['mw'],
    "gajabhakṣyā": ['mw'],
    "gajabhakṣā": ['mw'],
    "gajabhujaṃgama": ['mw'],
    "gajacarman": ['mw'],
    "gajacchāyā": ['ddsa', 'mw'],
    "gajacirbhaṭā": ['mw'],
    "gajacirbhiṭa": ['mw'],
    "gajacirbhiṭā": ['mw'],
    "gajadaghna": ['mw'],
    "gajadaityabhid": ['mw'],
    "gajadanta": ['cae', 'ddsa', 'mw'],
    "gajadantamaya": ['mw'],
    "gajadantaphalā": ['mw'],
    "gajadeva": ['bhs'],
    "gajadvayasa": ['mw'],
    "gajadāna": ['mw'],
    "gajagati": ['mw'],
    "gajagāminī": ['mw'],
    "gajajhampa": ['mw'],
    "gajakanda": ['mw'],
    "gajakanyā": ['mw'],
    "gajakarṇa": ['bhs', 'mw'],
    "gajakarṇī": ['mw'],
    "gajakūrmāśin": ['mw'],
    "gajakṛṣṇā": ['mw'],
    "gajalīla": ['mw'],
    "gajamada": ['cae', 'mw'],
    "gajamalla": ['mw'],
    "gajamauktika": ['mw'],
    "gajamaṇḍalikā": ['mw'],
    "gajamaṇḍana": ['mw'],
    "gajamocana": ['mw'],
    "gajamoṭana": ['mw'],
    "gajamukha": ['mw'],
    "gajamuktā": ['mw'],
    "gajamācala": ['mw'],
    "gajamāna": ['cae', 'mw'],
    "gajamātra": ['mw'],
    "gajanakra": ['mw'],
    "gajanavī": ['mw'],
    "gajanimīlikā": ['mw'],
    "gajanimīlita": ['mw'],
    "gajanāsā": ['mw'],
    "gajapati": ['bhs', 'mw'],
    "gajapippalī": ['mw'],
    "gajaprameha": ['bhs'],
    "gajaprayantṛ": ['mw'],
    "gajapriyā": ['mw'],
    "gajapura": ['cae', 'mw'],
    "gajapuṃgava": ['cae', 'mw'],
    "gajapuṣpamaya": ['mw'],
    "gajapuṣpī": ['mw'],
    "gajapuṭa": ['mw'],
    "gajapādapa": ['mw'],
    "gajapūrva": ['mw'],
    "gajarathapura": ['mw'],
    "gajareva": ['mw'],
    "gajarāja": ['mw'],
    "gajarājamuktā": ['mw'],
    "gajasiṃha": ['mw'],
    "gajasiṃhacaritra": ['mw'],
    "gajaskandha": ['mw'],
    "gajasnāna": ['mw'],
    "gajasthāna": ['mw'],
    "gajasukumāracaritra": ['mw'],
    "gajasāhvaya": ['cae', 'ddsa', 'mw'],
    "gajaturaṃgavilasita": ['mw'],
    "gajatva": ['mw'],
    "gajatā": ['ap90', 'mw'],
    "gajavadana": ['mw'],
    "gajavadhū": ['cae', 'mw'],
    "gajavallabhā": ['mw'],
    "gajavara": ['mw'],
    "gajavat": ['ap90', 'mw'],
    "gajavikāśī": ['mw'],
    "gajavilasitā": ['mw'],
    "gajavraja": ['mw'],
    "gajavāja": ['mw'],
    "gajavīthi": ['mw'],
    "gajavīthī": ['mw'],
    "gajayodhin": ['mw'],
    "gajayānavid": ['mw'],
    "gajayūtha": ['cae', 'mw'],
    "gajayūthapa": ['cae'],
    "gajaśikṣā": ['mw'],
    "gajaśiras": ['mw'],
    "gajaśvasana": ['bhs'],
    "gajaśāstra": ['mw'],
    "gajaśīrṣa": ['bhs', 'mw'],
    "gajaḍhakkā": ['mw'],
    "gajaḥ": ['ap90'],
    "gajekṣaṇa": ['mw'],
    "gajendra": ['cae', 'ddsa', 'mw'],
    "gajendrakarṇa": ['mw'],
    "gajendramokṣaṇa": ['mw'],
    "gajendranātha": ['mw'],
    "gajendravikrama": ['mw'],
    "gajeṣṭā": ['mw'],
    "gajin": ['mw'],
    "gajjati": ['cped'],
    "gajjayitvā": ['cped'],
    "gajjita": ['cped'],
    "gajjita(r)": ['cped'],
    "gajodara": ['mw'],
    "gajomānikula": ['bhs'],
    "gajoṣaṇā": ['mw'],
    "gajā": ['mw'],
    "gajādana": ['mw'],
    "gajādhipati": ['mw'],
    "gajādhyakṣa": ['ddsa', 'mw'],
    "gajādināmā": ['mw'],
    "gajāgraṇī": ['mw'],
    "gajāhva": ['mw'],
    "gajāhvaya": ['cae', 'ddsa', 'mw'],
    "gajāhvā": ['mw'],
    "gajājīva": ['mw'],
    "gajākhya": ['mw'],
    "gajālāna": ['mw'],
    "gajānana": ['mw'],
    "gajānīka": ['mw'],
    "gajāpasada": ['mw'],
    "gajāri": ['mw'],
    "gajāroha": ['mw'],
    "gajārūḍha": ['mw'],
    "gajāsuhṛd": ['mw'],
    "gajāsura": ['mw'],
    "gajāsuradveṣin": ['mw'],
    "gajāsya": ['mw'],
    "gajāyurveda": ['mw'],
    "gajāśana": ['mw'],
    "gajāśanā": ['mw'],
    "gajāśva": ['bhs'],
    "gajāṇḍa": ['mw'],
    "gajī": ['mw'],
    "gajībhū": ['ddsa'],
    "gajībhūta": ['mw'],
    "gakāra": ['mw'],
    "gal": ['ap90', 'cae', 'ddsa', 'mw'],
    "gala": ['cae', 'ddsa', 'mw'],
    "galacarman": ['mw'],
    "galadvāra": ['mw'],
    "galagaṇḍa": ['mw'],
    "galagaṇḍhi(n)": ['cped'],
    "galagaṇḍin": ['mw'],
    "galaggāha": ['cped'],
    "galagolī": ['mw'],
    "galagoḍikā": ['mw'],
    "galagoḍī": ['mw'],
    "galagraha": ['mw'],
    "galagranihi": ['mw'],
    "galaguhā": ['cae'],
    "galahasta": ['cae', 'mw'],
    "galahastaya": ['mw'],
    "galahastita": ['mw'],
    "galaka": ['cped', 'mw'],
    "galakambala": ['mw'],
    "galakaḥ": ['ap90'],
    "galamekhalā": ['mw'],
    "galamocikā": ['mw'],
    "galamoṭana": ['mw'],
    "galana": ['mw'],
    "galanaṃ": ['ap90'],
    "galantikā": ['mw'],
    "galantī": ['mw'],
    "galanīya": ['mw'],
    "galappavedhaka": ['cped'],
    "galarandhra": ['mw'],
    "galastanī": ['mw'],
    "galati": ['cped'],
    "galatkuṣṭha": ['mw'],
    "galaugha": ['mw'],
    "galavidradhi": ['mw'],
    "galavrata": ['mw'],
    "galavārtta": ['mw'],
    "galaśuṇḍikā": ['mw'],
    "galaśuṇḍī": ['mw'],
    "galaśālūka": ['mw'],
    "galaḍā": ['mw'],
    "galaḥ": ['ap90'],
    "galaṃtikā": ['ap90'],
    "galbh": ['ap90', 'mw'],
    "galbha": ['ap90', 'mw'],
    "galbhāya": ['mw'],
    "galda": ['cae', 'mw'],
    "galdaḥ": ['ap90'],
    "galdā": ['gra', 'mw'],
    "gale": ['mw'],
    "galecopaka": ['mw'],
    "galegaṃḍaḥ": ['ap90'],
    "galegaṇḍa": ['mw'],
    "galestanī": ['mw'],
    "galeti": ['cped'],
    "galh": ['ap90', 'mw'],
    "gali": ['mw'],
    "galita": ['ap90', 'bhs', 'cae', 'mw'],
    "galitadanta": ['mw'],
    "galitaka": ['cae', 'ddsa', 'mw'],
    "galitakaḥ": ['ap90'],
    "galitakuṣṭha": ['mw'],
    "galitanakha": ['mw'],
    "galitanakhadanta": ['mw'],
    "galitanayana": ['mw'],
    "galitapradīpa": ['mw'],
    "galitapradīpikā": ['mw'],
    "galiḥ": ['ap90'],
    "galla": ['cae', 'ddsa', 'mw'],
    "gallacāturī": ['mw'],
    "gallaka": ['mw'],
    "gallakaḥ": ['ap90'],
    "gallakī": ['mw'],
    "gallamasūrī": ['mw'],
    "gallapūraṇa": ['cae', 'mw'],
    "gallarkaḥ": ['ap90'],
    "gallavādya": ['mw'],
    "gallaḥ": ['ap90'],
    "gallikā": ['mw'],
    "gallopadhānīya": ['mw'],
    "gallī": ['bhs'],
    "galodbhava": ['mw'],
    "galoḍya": ['mw'],
    "galunta": ['mw'],
    "galv": ['mw'],
    "galva": ['mw'],
    "galvarka": ['cae', 'ddsa', 'mw'],
    "galvarkaḥ": ['ap90'],
    "galyā": ['ap90', 'mw'],
    "galā": ['mw'],
    "galānika": ['mw'],
    "galānila": ['mw'],
    "galānilaḥ": ['ap90'],
    "galāvala": ['mw'],
    "galāvila": ['mw'],
    "galāṅkura": ['mw'],
    "galū": ['mw'],
    "galūna": ['ddsa', 'mw'],
    "galūnasa": ['mw'],
    "gam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gamadhyai": ['cae', 'ddsa', 'mw'],
    "gamaka": ['ap90', 'cae', 'mw'],
    "gamakatva": ['mw'],
    "gamakatā": ['mw'],
    "gamakāritva": ['mw'],
    "gamana": ['cae', 'cped', 'ddsa', 'mw'],
    "gamanavat": ['mw'],
    "gamanaṃ": ['ap90'],
    "gamanikā": ['mw'],
    "gamantra": ['bhs'],
    "gamanābādha": ['mw'],
    "gamanāgamana": ['mw'],
    "gamanārha": ['mw'],
    "gamanīya": ['ap90', 'cae', 'cped', 'mw'],
    "gamatha": ['mw'],
    "gamathaḥ": ['ap90'],
    "gamayati": ['cped'],
    "gamayitavya": ['mw'],
    "gamayitṛ": ['mw'],
    "gamb": ['mw'],
    "gambhan": ['cae', 'ddsa', 'mw'],
    "gambhara": ['gra', 'mw'],
    "gambhiṣṭha": ['cae', 'mw'],
    "gambhārikā": ['mw'],
    "gambhārī": ['mw'],
    "gambhīra": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "gambhīrabuddhi": ['bhs', 'mw'],
    "gambhīracetas": ['gra', 'mw'],
    "gambhīradharmaguṇarājaśrī": ['bhs'],
    "gambhīradharmaśrīsamudraprabha": ['bhs'],
    "gambhīradhvani": ['mw'],
    "gambhīradhīra": ['mw'],
    "gambhīragati": ['mw'],
    "gambhīraghoṣasvaranādita": ['bhs'],
    "gambhīraka": ['mw'],
    "gambhīrakukṣitā": ['mw'],
    "gambhīranirghoṣa": ['bhs', 'mw'],
    "gambhīranābhitā": ['mw'],
    "gambhīranāda": ['mw'],
    "gambhīrapakṣa": ['bhs', 'mw'],
    "gambhīrapañña": ['cped'],
    "gambhīrapāṇilekhatā": ['mw'],
    "gambhīrasattvasvaranābhi": ['mw'],
    "gambhīrasvāmin": ['mw'],
    "gambhīrasīta": ['cped'],
    "gambhīratva": ['mw'],
    "gambhīratā": ['mw'],
    "gambhīravedha": ['mw'],
    "gambhīravedin": ['mw'],
    "gambhīravepas": ['gra', 'mw'],
    "gambhīraśaṃsa": ['cae', 'gra', 'mw'],
    "gambhīraśīla": ['mw'],
    "gambhīreśvara": ['bhs'],
    "gambhīrikā": ['mw'],
    "gambhīrobhāsa": ['cped'],
    "gambhīrā": ['mw'],
    "gambhīrārtha": ['ddsa', 'mw'],
    "gambhīrāvabhāsa": ['cped'],
    "gameti": ['cped'],
    "gami": ['mw'],
    "gami(n)": ['cped'],
    "gamika": ['bhs', 'cped', 'mw'],
    "gamikacitta": ['cped'],
    "gamikābhisankhāra": ['cped'],
    "gamin": ['ap90', 'cae', 'ddsa', 'mw'],
    "gamina": ['cped'],
    "gamissami": ['cped'],
    "gamissanti": ['cped'],
    "gamissasi": ['cped'],
    "gamissati": ['cped'],
    "gamissaṁ": ['cped'],
    "gamissāma": ['cped'],
    "gamita": ['mw'],
    "gamittha": ['cped'],
    "gamiya": ['cped'],
    "gamiyacitta": ['cped'],
    "gamiyābhisankhāra": ['cped'],
    "gamiṣṇu": ['cae', 'ddsa', 'mw'],
    "gamiṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "gamma": ['cped'],
    "gamya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "gamyamāna": ['mw'],
    "gamyate": ['bhs'],
    "gamyatva": ['mw'],
    "gamyatā": ['mw'],
    "gamyādi": ['mw'],
    "gamāgama": ['cae', 'ddsa', 'mw'],
    "gamāgamakārin": ['mw'],
    "gamātra": ['bhs', 'mw'],
    "ganabhandiya": ['cped'],
    "gandh": ['mw'],
    "gandha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "gandhabahala": ['mw'],
    "gandhabahula": ['mw'],
    "gandhabahulā": ['mw'],
    "gandhabandhu": ['mw'],
    "gandhabba": ['cped'],
    "gandhabbahatthaka": ['cped'],
    "gandhabbakāyika": ['cped'],
    "gandhabbi": ['cped'],
    "gandhabhadrā": ['mw'],
    "gandhabhāṇḍa": ['mw'],
    "gandhabījā": ['mw'],
    "gandhacelikā": ['mw'],
    "gandhadalā": ['mw'],
    "gandhadhārin": ['mw'],
    "gandhadhūli": ['mw'],
    "gandhadhūmabhava": ['mw'],
    "gandhadhūmaja": ['mw'],
    "gandhadravya": ['mw'],
    "gandhadvipa": ['cae', 'mw'],
    "gandhadvirada": ['cae', 'mw'],
    "gandhadvāra": ['mw'],
    "gandhadāru": ['mw'],
    "gandhaga": ['mw'],
    "gandhagaja": ['cae', 'mw'],
    "gandhagandha": ['cped'],
    "gandhagandhi(n)": ['cped'],
    "gandhaghrāṇa": ['mw'],
    "gandhagrāhaka": ['mw'],
    "gandhagrāhin": ['mw'],
    "gandhaguṇa": ['cae', 'mw'],
    "gandhahasta": ['bhs'],
    "gandhahastimahātarka": ['mw'],
    "gandhahastin": ['bhs', 'mw'],
    "gandhahārikā": ['mw'],
    "gandhaja": ['mw'],
    "gandhajala": ['mw'],
    "gandhajaṭilā": ['mw'],
    "gandhajñā": ['mw'],
    "gandhajāta": ['mw'],
    "gandhaka": ['cae', 'ddsa', 'mw'],
    "gandhakandaka": ['mw'],
    "gandhakapeṣikā": ['mw'],
    "gandhakelikā": ['mw'],
    "gandhakheḍa": ['mw'],
    "gandhakheḍaka": ['mw'],
    "gandhakokilā": ['mw'],
    "gandhakusumā": ['mw'],
    "gandhakuṭī": ['bhs', 'mw'],
    "gandhakālikā": ['mw'],
    "gandhakālī": ['mw'],
    "gandhakāraka": ['mw'],
    "gandhakārikā": ['mw'],
    "gandhakārī": ['mw'],
    "gandhakāṣṭha": ['mw'],
    "gandhakīya": ['mw'],
    "gandhakūṭī": ['mw'],
    "gandhalatā": ['mw'],
    "gandhalipta": ['mw'],
    "gandhalolupā": ['mw'],
    "gandhalubdha": ['mw'],
    "gandhamadana": ['bhs', 'mw'],
    "gandhamaithuna": ['mw'],
    "gandhamaya": ['mw'],
    "gandhamañjarī": ['mw'],
    "gandhameghavyūhadhvajā": ['bhs'],
    "gandhamoca": ['mw'],
    "gandhamodana": ['mw'],
    "gandhamohinī": ['mw'],
    "gandhamokṣa": ['mw'],
    "gandhamuṇḍa": ['mw'],
    "gandhamāda": ['mw'],
    "gandhamādana": ['bhs', 'cae', 'mw'],
    "gandhamādanavarṣa": ['mw'],
    "gandhamādanī": ['mw'],
    "gandhamādinī": ['mw'],
    "gandhamālatī": ['mw'],
    "gandhamālin": ['mw'],
    "gandhamālinī": ['mw'],
    "gandhamālya": ['cae', 'mw'],
    "gandhamālyaloka": ['mw'],
    "gandhamārjāra": ['mw'],
    "gandhamātṛ": ['mw'],
    "gandhamāṃsī": ['mw'],
    "gandhamūla": ['mw'],
    "gandhamūlaka": ['mw'],
    "gandhamūlikā": ['mw'],
    "gandhamūlā": ['mw'],
    "gandhamūlī": ['mw'],
    "gandhamūṣika": ['mw'],
    "gandhamūṣikā": ['mw'],
    "gandhamūṣī": ['mw'],
    "gandhamṛga": ['mw'],
    "gandhamṛgāṇḍajā": ['mw'],
    "gandhana": ['cae', 'ddsa', 'mw'],
    "gandhanakula": ['mw'],
    "gandhanilayā": ['mw'],
    "gandhaniśā": ['mw'],
    "gandhanākulī": ['mw'],
    "gandhanālikā": ['mw'],
    "gandhanālī": ['mw'],
    "gandhanāman": ['mw'],
    "gandhanāḍī": ['mw'],
    "gandhapa": ['mw'],
    "gandhapalāśikā": ['mw'],
    "gandhapalāśī": ['mw'],
    "gandhaparṇa": ['mw'],
    "gandhapattra": ['mw'],
    "gandhapattrikā": ['mw'],
    "gandhapattrā": ['mw'],
    "gandhapattrī": ['mw'],
    "gandhaphala": ['mw'],
    "gandhaphalā": ['mw'],
    "gandhaphalī": ['mw'],
    "gandhapiśācikā": ['mw'],
    "gandhapiṅgalā": ['mw'],
    "gandhaprabha": ['bhs'],
    "gandhaprabhāsa": ['bhs', 'mw'],
    "gandhapradīpa": ['bhs'],
    "gandhapradīpameghaśiri": ['bhs'],
    "gandhapura": ['bhs'],
    "gandhapuṣpa": ['mw'],
    "gandhapuṣpadhūpadīpa": ['mw'],
    "gandhapuṣpā": ['mw'],
    "gandhapālin": ['mw'],
    "gandhapāna": ['mw'],
    "gandhapāṣāṇa": ['mw'],
    "gandhapāṣāṇavat": ['mw'],
    "gandhapītā": ['mw'],
    "gandhapūtanā": ['mw'],
    "gandharasa": ['mw'],
    "gandharasāṅgaka": ['mw'],
    "gandharatā": ['mw'],
    "gandharva": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "gandharvadattā": ['mw'],
    "gandharvagraha": ['mw'],
    "gandharvagīta": ['bhs'],
    "gandharvagṛhīta": ['mw'],
    "gandharvahasta": ['mw'],
    "gandharvahastaka": ['mw'],
    "gandharvakanyā": ['bhs', 'mw'],
    "gandharvakhaṇḍa": ['ddsa', 'mw'],
    "gandharvakāyika": ['bhs'],
    "gandharvakāyuprabharāja": ['bhs'],
    "gandharvalipi": ['bhs'],
    "gandharvaloka": ['cae', 'mw'],
    "gandharvamādana": ['bhs'],
    "gandharvanagara": ['mw'],
    "gandharvapada": ['mw'],
    "gandharvapatnī": ['mw'],
    "gandharvapratyupasthita": ['mw'],
    "gandharvapura": ['mw'],
    "gandharvartu": ['mw'],
    "gandharvarāja": ['bhs', 'cae', 'mw'],
    "gandharvataila": ['mw'],
    "gandharvatva": ['mw'],
    "gandharvaveda": ['mw'],
    "gandharvavidyā": ['mw'],
    "gandharvavivāha": ['mw'],
    "gandharveṣṭhā": ['mw'],
    "gandharvika": ['bhs'],
    "gandharvopādhyāya": ['mw'],
    "gandharvā": ['mw'],
    "gandharvāpsaras": ['mw'],
    "gandharvī": ['ddsa', 'gra', 'mw'],
    "gandharāja": ['mw'],
    "gandharājī": ['mw'],
    "gandhasevaka": ['mw'],
    "gandhasoma": ['mw'],
    "gandhasragdāmavat": ['mw'],
    "gandhasugandhā": ['bhs'],
    "gandhasukhī": ['mw'],
    "gandhasāra": ['cae', 'mw'],
    "gandhasāraṇa": ['mw'],
    "gandhasūyī": ['mw'],
    "gandhataila": ['mw'],
    "gandhatailaka": ['bhs'],
    "gandhataṇḍula": ['mw'],
    "gandhatoya": ['mw'],
    "gandhatvac": ['mw'],
    "gandhatūrya": ['mw'],
    "gandhatṛṇa": ['mw'],
    "gandhautu": ['mw'],
    "gandhavadhū": ['mw'],
    "gandhavaha": ['cae', 'mw'],
    "gandhavahaśmaśāna": ['mw'],
    "gandhavahā": ['mw'],
    "gandhavajrā": ['mw'],
    "gandhavajrī": ['mw'],
    "gandhavalkala": ['mw'],
    "gandhavallarī": ['mw'],
    "gandhavallī": ['mw'],
    "gandhavant": ['cae'],
    "gandhavat": ['ddsa', 'mw'],
    "gandhavatī": ['bhs', 'mw'],
    "gandhavaṇij": ['mw'],
    "gandhavaṭikā": ['mw'],
    "gandhavihvala": ['mw'],
    "gandhavyākula": ['mw'],
    "gandhavāha": ['cae', 'mw'],
    "gandhavāhā": ['mw'],
    "gandhavṛkṣaka": ['mw'],
    "gandhayukti": ['cae', 'mw'],
    "gandhayuktijña": ['mw'],
    "gandhayuktivid": ['mw'],
    "gandhayuti": ['mw'],
    "gandhayātana": ['cped'],
    "gandhaśaila": ['mw'],
    "gandhaśaṭī": ['mw'],
    "gandhaśekhara": ['mw'],
    "gandhaśuṇḍinī": ['mw'],
    "gandhaśāka": ['mw'],
    "gandhaśāli": ['mw'],
    "gandhebha": ['ddsa', 'mw'],
    "gandhecchā": ['mw'],
    "gandhendriya": ['mw'],
    "gandheśa": ['mw'],
    "gandhi": ['cae', 'ddsa', 'gra', 'mw'],
    "gandhika": ['bhs', 'cae', 'mw'],
    "gandhikā": ['mw'],
    "gandhikāpaṇa": ['mw'],
    "gandhin": ['cae', 'mw'],
    "gandhinikā": ['bhs'],
    "gandhinī": ['mw'],
    "gandhiparṇa": ['mw'],
    "gandhivṛtta": ['mw'],
    "gandhoda": ['mw'],
    "gandhodaka": ['mw'],
    "gandhoddāma": ['cae', 'mw'],
    "gandhohana": ['cped'],
    "gandholi": ['mw'],
    "gandholī": ['mw'],
    "gandhopajīvin": ['mw'],
    "gandhopala": ['mw'],
    "gandhotkaṭa": ['mw'],
    "gandhottama": ['bhs', 'mw'],
    "gandhottamā": ['mw'],
    "gandhotu": ['mw'],
    "gandhoṣṇīṣa": ['mw'],
    "gandhya": ['mw'],
    "gandhā": ['bhs', 'mw'],
    "gandhādhika": ['mw'],
    "gandhāhvā": ['mw'],
    "gandhājīva": ['mw'],
    "gandhākhu": ['mw'],
    "gandhālaṃkāraruciraśubhagarbhā": ['bhs'],
    "gandhālepa": ['cped'],
    "gandhālu": ['mw'],
    "gandhālā": ['mw'],
    "gandhālī": ['mw'],
    "gandhālīgarbha": ['mw'],
    "gandhāmbhas": ['mw'],
    "gandhāmbu": ['mw'],
    "gandhāmlā": ['mw'],
    "gandhāpakarṣaṇa": ['mw'],
    "gandhāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "gandhārcimeghaśrīrāja": ['bhs'],
    "gandhārciravabhāsarāja": ['bhs'],
    "gandhārciḥprabhāsvarā": ['bhs'],
    "gandhāri": ['cae', 'gra', 'mw'],
    "gandhārī": ['bhs', 'cped', 'mw'],
    "gandhātu": ['cped'],
    "gandhāśman": ['mw'],
    "gandhāḍhya": ['cae', 'ddsa', 'mw'],
    "gandhāḍhyā": ['mw'],
    "gandhāṣṭaka": ['mw'],
    "gandhūhana": ['cped'],
    "gandhūpahāra": ['cped'],
    "gandikā": ['mw'],
    "ganmut": ['mw'],
    "ganta(r)": ['cped'],
    "gantabba": ['cped'],
    "gantavai": ['mw'],
    "gantave": ['cae', 'cped', 'ddsa', 'mw'],
    "gantavya": ['cae', 'ddsa', 'mw'],
    "gantha": ['cped'],
    "ganthati": ['cped'],
    "ganthayati": ['cped'],
    "gantheti": ['cped'],
    "ganthetvā": ['cped'],
    "ganthita": ['cped'],
    "ganthitva": ['cped'],
    "ganthitāganthita": ['cped'],
    "ganthāpeti": ['cped'],
    "gantra": ['bhs'],
    "gantrikā": ['mw'],
    "gantrī": ['mw'],
    "gantrīratha": ['mw'],
    "gantu": ['cae', 'gra', 'mw'],
    "gantukāma": ['cae', 'ddsa', 'mw'],
    "gantuṁ": ['cped'],
    "gantva": ['mw'],
    "gantvā": ['cped'],
    "gantvāna": ['cped'],
    "gantṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "ganāspati": ['gra'],
    "gar": ['gra'],
    "gara": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "garabha": ['mw'],
    "garabhaḥ": ['ap90'],
    "garada": ['cae', 'mw'],
    "garadattaka": ['bhs'],
    "garadruma": ['mw'],
    "garadāna": ['mw'],
    "garaghna": ['mw'],
    "garaghnī": ['mw'],
    "garagir": ['mw'],
    "garagīrṇa": ['mw'],
    "garagīrṇin": ['mw'],
    "garahamāna": ['cped'],
    "garahan": ['mw'],
    "garahanta": ['cped'],
    "garahati": ['bhs', 'cped'],
    "garaheti": ['cped'],
    "garahi": ['cped'],
    "garahita": ['cped'],
    "garahitabba": ['cped'],
    "garahitta": ['cped'],
    "garahiya": ['cped'],
    "garahā": ['cped'],
    "garala": ['cae', 'ddsa', 'mw'],
    "garalavrata": ['mw'],
    "garalaḥ": ['ap90'],
    "garalin": ['ap90', 'mw'],
    "garalliḥ": ['ap90'],
    "garalāri": ['mw'],
    "garalāya": ['ddsa'],
    "garavrata": ['mw'],
    "garayati": ['cped'],
    "garaṇa": ['mw'],
    "garaṇavat": ['mw'],
    "garaṇaṃ": ['ap90'],
    "garb": ['mw'],
    "garbha": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "garbhabharman": ['mw'],
    "garbhabhartṛdruh": ['cae', 'mw'],
    "garbhabhavana": ['cae', 'mw'],
    "garbhabhāra": ['mw'],
    "garbhacalana": ['mw'],
    "garbhacchidra": ['mw'],
    "garbhaceṭa": ['mw'],
    "garbhacyuta": ['mw'],
    "garbhacyuti": ['mw'],
    "garbhada": ['mw'],
    "garbhadha": ['cae', 'mw'],
    "garbhadharā": ['cae', 'mw'],
    "garbhadhi": ['cae', 'gra', 'mw'],
    "garbhadhvaṃsa": ['mw'],
    "garbhadhāna": ['mw'],
    "garbhadhāraṇa": ['cae', 'mw'],
    "garbhadhāraṇā": ['mw'],
    "garbhadhārita": ['mw'],
    "garbhadhṛta": ['mw'],
    "garbhadhṛti": ['mw'],
    "garbhadivasa": ['mw'],
    "garbhadruh": ['mw'],
    "garbhadruti": ['mw'],
    "garbhadrāvaṇa": ['mw'],
    "garbhadvādaśa": ['mw'],
    "garbhadā": ['mw'],
    "garbhadāsa": ['cae', 'mw'],
    "garbhadāsī": ['mw'],
    "garbhadātrī": ['mw'],
    "garbhagata": ['cae', 'mw'],
    "garbhageha": ['cae', 'mw'],
    "garbhaghātinī": ['mw'],
    "garbhagraha": ['cae', 'mw'],
    "garbhagrahaṇa": ['mw'],
    "garbhagrahārtava": ['mw'],
    "garbhagrāhikā": ['mw'],
    "garbhagurvī": ['mw'],
    "garbhagṛha": ['cae', 'mw'],
    "garbhahantṛ": ['mw'],
    "garbhaikādaśa": ['ddsa', 'mw'],
    "garbhaka": ['cae', 'mw'],
    "garbhakara": ['mw'],
    "garbhakaraṇa": ['mw'],
    "garbhakartṛ": ['mw'],
    "garbhakaḥ": ['ap90'],
    "garbhakleśa": ['mw'],
    "garbhakośa": ['mw'],
    "garbhakoṣa": ['mw'],
    "garbhakāla": ['cae', 'mw'],
    "garbhakāma": ['mw'],
    "garbhakāra": ['mw'],
    "garbhakārin": ['mw'],
    "garbhakṣaya": ['mw'],
    "garbhalakṣaṇa": ['mw'],
    "garbhalambhana": ['mw'],
    "garbhamaṇḍapa": ['mw'],
    "garbhamocana": ['mw'],
    "garbhamokṣa": ['mw'],
    "garbhamās": ['mw'],
    "garbhamāsa": ['mw'],
    "garbhamṛt": ['mw'],
    "garbhanidhāna": ['mw'],
    "garbhanirharaṇa": ['mw'],
    "garbhaniṣkṛti": ['mw'],
    "garbhanud": ['mw'],
    "garbhanābhināḍī": ['mw'],
    "garbhanāḍī": ['mw'],
    "garbhaparisrava": ['mw'],
    "garbhapoṣaṇa": ['mw'],
    "garbhaprāvaraṇa": ['mw'],
    "garbhapuroḍāśa": ['mw'],
    "garbhapākin": ['mw'],
    "garbhapāta": ['mw'],
    "garbhapātaka": ['mw'],
    "garbhapātana": ['mw'],
    "garbhapātinī": ['mw'],
    "garbharakṣaṇa": ['mw'],
    "garbharakṣā": ['mw'],
    "garbharandhi": ['mw'],
    "garbharasa": ['gra', 'mw'],
    "garbharūpa": ['mw'],
    "garbharūpaka": ['mw'],
    "garbhasamaya": ['mw'],
    "garbhasambhava": ['mw'],
    "garbhasambhavā": ['mw'],
    "garbhasambhūti": ['mw'],
    "garbhasamplava": ['mw'],
    "garbhasaṃdhi": ['mw'],
    "garbhasaṃkarita": ['mw'],
    "garbhasaṃkramaṇa": ['mw'],
    "garbhasaṃskāra": ['mw'],
    "garbhasaṃsravaṇa": ['mw'],
    "garbhasrāva": ['cae', 'mw'],
    "garbhasrāvin": ['mw'],
    "garbhastha": ['cae', 'mw'],
    "garbhasthāna": ['mw'],
    "garbhasubhaga": ['mw'],
    "garbhasūtra": ['mw'],
    "garbhatva": ['gra', 'mw'],
    "garbhatā": ['cae', 'mw'],
    "garbhavadha": ['mw'],
    "garbhavadhaprāyaścitta": ['mw'],
    "garbhavartman": ['mw'],
    "garbhavasati": ['cae', 'mw'],
    "garbhavatī": ['ap90', 'cae', 'mw'],
    "garbhavedana": ['mw'],
    "garbhavedanā": ['mw'],
    "garbhavedinī": ['mw'],
    "garbhaveśman": ['cae', 'mw'],
    "garbhavicyuti": ['mw'],
    "garbhavipatti": ['mw'],
    "garbhavyākaraṇa": ['mw'],
    "garbhavyāpad": ['mw'],
    "garbhavyūha": ['mw'],
    "garbhavāsa": ['mw'],
    "garbhavāsakleśa": ['mw'],
    "garbhayamaka": ['mw'],
    "garbhayoṣā": ['mw'],
    "garbhayutā": ['mw'],
    "garbhaśayyā": ['mw'],
    "garbhaśaṅku": ['mw'],
    "garbhaśrīkāntamiśra": ['mw'],
    "garbhaśātana": ['mw'],
    "garbhaḥ": ['ap90'],
    "garbhaṃḍaḥ": ['ap90'],
    "garbhaṇḍa": ['mw'],
    "garbhetṛpta": ['ap90', 'mw'],
    "garbheśvara": ['cae', 'ddsa', 'mw'],
    "garbheśvaratva": ['mw'],
    "garbheśvaratā": ['mw'],
    "garbhin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "garbhita": ['ap90', 'mw'],
    "garbhitatva": ['mw'],
    "garbhitatā": ['mw'],
    "garbhiṇyavekṣaṇa": ['mw'],
    "garbhiṇī": ['ap90', 'mw'],
    "garbhiṇītva": ['mw'],
    "garbhiṇīvyākaraṇa": ['mw'],
    "garbholika": ['bhs'],
    "garbhopaghāta": ['mw'],
    "garbhopaghātinī": ['mw'],
    "garbhopaniṣad": ['mw'],
    "garbhotpatti": ['mw'],
    "garbhotpāda": ['mw'],
    "garbhya": ['mw'],
    "garbhāda": ['mw'],
    "garbhādhāna": ['cae', 'mw'],
    "garbhādi": ['mw'],
    "garbhāgāra": ['ddsa', 'mw'],
    "garbhāgārajvara": ['mw'],
    "garbhāhāriṇī": ['bhs'],
    "garbhāri": ['mw'],
    "garbhāspandana": ['mw'],
    "garbhāsrāva": ['mw'],
    "garbhāvakrānti": ['mw'],
    "garbhāvataraṇa": ['mw'],
    "garbhāvatāraṇa": ['mw'],
    "garbhāśaya": ['mw'],
    "garbhāśaṅkā": ['mw'],
    "garbhāṅka": ['mw'],
    "garbhāṣṭama": ['cae', 'mw'],
    "garbhīkaraṇa": ['mw'],
    "gard": ['ap90', 'cae', 'ddsa', 'mw'],
    "garda": ['cae', 'ddsa', 'mw'],
    "gardabh": ['mw'],
    "gardabha": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "gardabhagada": ['mw'],
    "gardabhaka": ['mw'],
    "gardabhakaḥ": ['ap90'],
    "gardabhakātyāyanī": ['bhs'],
    "gardabhakṣīra": ['mw'],
    "gardabhanādin": ['mw'],
    "gardabhapuṣpa": ['mw'],
    "gardabharatha": ['mw'],
    "gardabharūpa": ['mw'],
    "gardabhavallī": ['mw'],
    "gardabhaya": ['mw'],
    "gardabhaśāka": ['mw'],
    "gardabhaśākhī": ['mw'],
    "gardabhaḥ": ['ap90'],
    "gardabhejyā": ['mw'],
    "gardabhi": ['mw'],
    "gardabhikā": ['mw'],
    "gardabhila": ['mw'],
    "gardabhilla": ['mw'],
    "gardabhākṣa": ['mw'],
    "gardabhāṇḍa": ['mw'],
    "gardabhāṇḍaka": ['mw'],
    "gardabhāṇḍīya": ['mw'],
    "gardabhī": ['mw'],
    "gardabhīmukha": ['mw'],
    "gardabhīvidyā": ['mw'],
    "gardabhīvipīta": ['mw'],
    "gardayitnu": ['mw'],
    "gardh": ['ap90'],
    "gardha": ['cae', 'ddsa', 'mw'],
    "gardhana": ['ap90', 'mw'],
    "gardhanā": ['mw'],
    "gardhaḥ": ['ap90'],
    "gardhin": ['ap90', 'cae', 'mw'],
    "gardhita": ['mw'],
    "gardula": ['bhs'],
    "garga": ['cae', 'ddsa', 'mw'],
    "gargabhaginī": ['mw'],
    "gargabhagiṇī": ['mw'],
    "gargabhārgavikā": ['mw'],
    "gargabhūmi": ['mw'],
    "gargakula": ['mw'],
    "gargamaya": ['mw'],
    "gargara": ['cae', 'ddsa', 'gra', 'mw'],
    "gargaraka": ['mw'],
    "gargaraḥ": ['ap90'],
    "gargarikā": ['mw'],
    "gargarā": ['mw'],
    "gargarī": ['bhs', 'mw'],
    "gargarūpya": ['mw'],
    "gargasaṃhitā": ['mw'],
    "gargasrotas": ['mw'],
    "gargatara": ['mw'],
    "gargatrirātra": ['mw'],
    "gargatryaha": ['mw'],
    "gargavāhana": ['mw'],
    "gargavāhaṇa": ['mw'],
    "gargaśiras": ['mw'],
    "gargaḥ": ['ap90'],
    "gargā": ['bhs', 'mw'],
    "gargādi": ['mw'],
    "gargāṭa": ['mw'],
    "gargāṭaḥ": ['ap90'],
    "gargī": ['mw'],
    "garh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "garhaṇa": ['cae', 'ddsa', 'mw'],
    "garhaṇaṃ": ['ap90'],
    "garhaṇā": ['mw'],
    "garhaṇīya": ['mw'],
    "garhin": ['cae', 'mw'],
    "garhita": ['ap90', 'cae', 'mw'],
    "garhitam": ['mw'],
    "garhitavya": ['mw'],
    "garhitānnāśana": ['cae', 'mw'],
    "garhya": ['ap90', 'cae', 'mw'],
    "garhyavādin": ['mw'],
    "garhyāṇaka": ['mw'],
    "garhā": ['ap90', 'cae', 'mw'],
    "garikā": ['mw'],
    "gariman": ['ap90', 'cae', 'ddsa', 'mw'],
    "garita": ['ap90', 'mw'],
    "gariṣṭha": ['ap90', 'cae', 'mw'],
    "garj": ['ap90', 'cae', 'ddsa', 'mw'],
    "garja": ['cae', 'ddsa', 'mw'],
    "garjaka": ['mw'],
    "garjana": ['mw'],
    "garjanaṃ": ['ap90'],
    "garjanī": ['bhs'],
    "garjanīya": ['mw'],
    "garjara": ['mw'],
    "garjaḥ": ['ap90'],
    "garji": ['mw'],
    "garjita": ['ap90', 'cae', 'ddsa', 'mw'],
    "garjitarava": ['mw'],
    "garjitāsaha": ['mw'],
    "garjya": ['mw'],
    "garjā": ['ap90', 'mw'],
    "garjāphala": ['mw'],
    "garmoṭikā": ['mw'],
    "garmud": ['mw'],
    "garmut": ['ap90', 'cae', 'ddsa', 'mw'],
    "garmuṭikā": ['mw'],
    "garmūcchada": ['mw'],
    "garmūṭikā": ['mw'],
    "garmūṭī": ['mw'],
    "garta": ['cae', 'ddsa', 'gra', 'mw'],
    "gartakī": ['mw'],
    "gartamit": ['cae', 'mw'],
    "gartanvat": ['mw'],
    "gartapatya": ['mw'],
    "gartasad": ['cae', 'gra', 'mw'],
    "gartaḥ": ['ap90'],
    "garteśa": ['mw'],
    "garteṣṭhā": ['mw'],
    "gartikā": ['ap90', 'mw'],
    "gartin": ['mw'],
    "gartodaka": ['mw'],
    "gartya": ['mw'],
    "gartā": ['mw'],
    "gartākukkuṭa": ['mw'],
    "gartāruh": ['cae', 'gra', 'mw'],
    "gartāśraya": ['cae', 'ddsa', 'mw'],
    "gartīya": ['mw'],
    "garu": ['cped', 'mw'],
    "garubhaṇda": ['cped'],
    "garubhārā": ['cped'],
    "garud": ['mw'],
    "garudhamma": ['cped'],
    "garudyodhin": ['mw'],
    "garugaru": ['cped'],
    "garuka": ['cped'],
    "garukaraṇa": ['cped'],
    "garukariyamāna": ['cped'],
    "garukariṁsu": ['cped'],
    "garukaronta": ['cped'],
    "garukaroti": ['cped'],
    "garukarīyati": ['cped'],
    "garukata": ['cped'],
    "garukatvā": ['cped'],
    "garukāra": ['cped'],
    "garukātabba": ['cped'],
    "garula": ['mw'],
    "garulaḥ": ['ap90'],
    "garut": ['ap90', 'cae', 'ddsa', 'mw'],
    "garutara": ['cped'],
    "garutmant": ['cae'],
    "garutmat": ['ap90', 'gra', 'mw'],
    "garuvacana": ['cped'],
    "garuḍa": ['bhs', 'cae', 'ddsa', 'mw'],
    "garuḍadhvaja": ['mw'],
    "garuḍaketu": ['mw'],
    "garuḍalipi": ['bhs'],
    "garuḍamāṇikya": ['mw'],
    "garuḍamāṇikyamaya": ['mw'],
    "garuḍapakṣa": ['mw'],
    "garuḍapurāṇa": ['mw'],
    "garuḍaruta": ['mw'],
    "garuḍavega": ['mw'],
    "garuḍavegā": ['mw'],
    "garuḍaḥ": ['ap90'],
    "garuḍeśa": ['mw'],
    "garuḍeśāna": ['mw'],
    "garuḍodbhava": ['mw'],
    "garuḍodgīrṇa": ['mw'],
    "garuḍopaniṣad": ['mw'],
    "garuḍottīrṇa": ['mw'],
    "garuḍāditya": ['mw'],
    "garuḍāgraja": ['mw'],
    "garuḍārdha": ['mw'],
    "garuḍāya": ['ddsa'],
    "garuḍāśman": ['mw'],
    "garuḍāṅka": ['mw'],
    "garuḍāṅkita": ['mw'],
    "garuḍī": ['mw'],
    "garuṭṭhānīka": ['cped'],
    "garuṭṭhānīya": ['cped'],
    "garv": ['ap90', 'mw'],
    "garva": ['ddsa', 'mw'],
    "garvagir": ['cae'],
    "garvara": ['mw'],
    "garvarī": ['mw'],
    "garvaya": ['mw'],
    "garvaḥ": ['ap90'],
    "garvi": ['mw'],
    "garvita": ['ap90', 'cae', 'mw'],
    "garviṣṭha": ['mw'],
    "garvāya": ['ddsa', 'mw'],
    "garvāṭa": ['mw'],
    "garvāṭaḥ": ['ap90'],
    "garā": ['mw'],
    "garādhikā": ['mw'],
    "garāgarī": ['mw'],
    "garātmaka": ['mw'],
    "garāṣikā": ['mw'],
    "garī": ['mw'],
    "garīyas": ['ap90', 'mw'],
    "garīyasa": ['mw'],
    "garīyastara": ['mw'],
    "garīyastva": ['cae', 'mw'],
    "garīyaṃs": ['cae'],
    "gat": ['mw'],
    "gata": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "gatabhartṛkā": ['mw'],
    "gatabhī": ['mw'],
    "gatacetana": ['mw'],
    "gatacetas": ['mw'],
    "gataddhī(n)": ['cped'],
    "gatadina": ['mw'],
    "gatadinam": ['mw'],
    "gatadivasa": ['mw'],
    "gatadivasam": ['mw'],
    "gatajvara": ['mw'],
    "gatajīva": ['cae', 'ddsa', 'mw'],
    "gatajīvita": ['cae', 'mw'],
    "gataka": ['bhs', 'mw'],
    "gatakalmaṣa": ['mw'],
    "gatakaṃ": ['ap90'],
    "gataklama": ['cae', 'mw'],
    "gatakāla": ['mw'],
    "gatakīrti": ['mw'],
    "gatalajja": ['mw'],
    "gatalakṣmīka": ['mw'],
    "gatamanas": ['mw'],
    "gatamanaska": ['mw'],
    "gatamātra": ['cae', 'mw'],
    "gatamāya": ['mw'],
    "gatanidhana": ['mw'],
    "gatanāsika": ['mw'],
    "gatapaccāgata": ['cped'],
    "gatapaṭiyāgata": ['cped'],
    "gatapraja": ['mw'],
    "gatapratyāgata": ['cae', 'mw'],
    "gatapratyāgatikā": ['bhs'],
    "gataprāya": ['cae', 'mw'],
    "gataprāṇa": ['cae', 'mw'],
    "gatapubba": ['cped'],
    "gatapuṇya": ['mw'],
    "gatapāpa": ['mw'],
    "gatapāra": ['cae', 'mw'],
    "gatapūrva": ['cae'],
    "gatarasa": ['cae', 'mw'],
    "gataroga": ['mw'],
    "gatarātri": ['mw'],
    "gatasannaka": ['mw'],
    "gatasattva": ['mw'],
    "gatasauhṛda": ['mw'],
    "gatasaṃdeha": ['cae', 'mw'],
    "gatasaṃkalpa": ['mw'],
    "gatasaṅga": ['cae', 'mw'],
    "gataspṛha": ['mw'],
    "gatasvārtha": ['mw'],
    "gatasādhvasa": ['mw'],
    "gatasāra": ['cae', 'mw'],
    "gatatoyada": ['mw'],
    "gatatrapa": ['mw'],
    "gatatta": ['cped'],
    "gataujas": ['mw'],
    "gatavaira": ['mw'],
    "gatavarṣa": ['mw'],
    "gatavat": ['mw'],
    "gatavayas": ['mw'],
    "gatavayaska": ['mw'],
    "gatavibhava": ['mw'],
    "gatavitta": ['mw'],
    "gatavyatha": ['cae', 'mw'],
    "gatayauvana": ['cae'],
    "gatayauvayas": ['cae'],
    "gataśaiśava": ['mw'],
    "gataśrī": ['mw'],
    "gataśrīka": ['mw'],
    "gathita": ['cped'],
    "gathitacitta": ['cped'],
    "gati": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "gatibhaṅga": ['cae', 'ddsa', 'mw'],
    "gatibheda": ['cae', 'mw'],
    "gaticandranetranayana": ['bhs'],
    "gatigata": ['bhs', 'cped'],
    "gatihīna": ['mw'],
    "gatika": ['bhs', 'mw'],
    "gatikaṃ": ['ap90'],
    "gatikā": ['bhs'],
    "gatilā": ['ap90', 'mw'],
    "gatima": ['bhs'],
    "gatima(t)": ['cped'],
    "gatimant": ['cae'],
    "gatimanto": ['cped'],
    "gatimat": ['ap90', 'mw'],
    "gatimā": ['cped'],
    "gatipatha": ['cae'],
    "gatipravara": ['bhs'],
    "gatitālin": ['mw'],
    "gatiśakti": ['mw'],
    "gatiḥ": ['ap90'],
    "gatiṃgata": ['bhs'],
    "gatiṃgatvā": ['bhs'],
    "gatodaka": ['cae', 'mw'],
    "gatodvega": ['mw'],
    "gatotsāha": ['mw'],
    "gatta": ['cped'],
    "gatvan": ['cae', 'gra', 'mw'],
    "gatvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "gatvā": ['mw'],
    "gatvāya": ['mw'],
    "gatvī": ['mw'],
    "gaty": ['mw'],
    "gatyanusāra": ['mw'],
    "gatyartha": ['ddsa'],
    "gatyāgati": ['mw'],
    "gatyūna": ['mw'],
    "gatādhi": ['mw'],
    "gatādhvan": ['cae', 'mw'],
    "gatādhvā": ['mw'],
    "gatāgata": ['cae', 'cped', 'ddsa', 'mw'],
    "gatāgati": ['cae', 'mw'],
    "gatākṣa": ['mw'],
    "gatālīka": ['mw'],
    "gatānta": ['mw'],
    "gatānugata": ['mw'],
    "gatānugatika": ['cae', 'mw'],
    "gatārtavā": ['mw'],
    "gatārtha": ['mw'],
    "gatāsu": ['cae', 'gra', 'mw'],
    "gatāyus": ['cae', 'mw'],
    "gatāyāta": ['mw'],
    "gatī": ['cped', 'mw'],
    "gatīka": ['bhs', 'mw'],
    "gaubhila": ['mw'],
    "gaubhileya": ['mw'],
    "gaubhṛta": ['mw'],
    "gaudanteya": ['mw'],
    "gaudapariṇaddhi": ['mw'],
    "gaudeya": ['mw'],
    "gaudhenuka": ['mw'],
    "gaudhera": ['mw'],
    "gaudheraka": ['mw'],
    "gaudherakāyaṇi": ['mw'],
    "gaudheya": ['mw'],
    "gaudhili": ['mw'],
    "gaudhāra": ['mw'],
    "gaudhāśanika": ['mw'],
    "gaudhūma": ['mw'],
    "gaudhūmra": ['mw'],
    "gaudhūmīnaṃ": ['ap90'],
    "gaudānika": ['mw'],
    "gaudāyana": ['mw'],
    "gauggulava": ['mw'],
    "gauhalavya": ['mw'],
    "gauhalavyāyanī": ['mw'],
    "gauhileya": ['mw'],
    "gauhya": ['mw'],
    "gauhyaka": ['mw'],
    "gaukakṣa": ['mw'],
    "gaukakṣya": ['mw'],
    "gaukakṣyā": ['mw'],
    "gaukakṣyāpati": ['mw'],
    "gaukakṣyāputra": ['mw'],
    "gaukakṣyāyaṇa": ['mw'],
    "gaukakṣyāyaṇi": ['mw'],
    "gaukakṣyāyaṇī": ['mw'],
    "gaukakṣī": ['mw'],
    "gaukakṣīpati": ['mw'],
    "gaukakṣīputra": ['mw'],
    "gaulakṣaṇika": ['mw'],
    "gaulakṣaṇikaḥ": ['ap90'],
    "gaulanda": ['mw'],
    "gaulgulava": ['mw'],
    "gaulgulavī": ['mw'],
    "gaulgulavīputra": ['mw'],
    "gaulika": ['bhs', 'mw'],
    "gaulmika": ['bhs', 'mw'],
    "gaulmikaḥ": ['ap90'],
    "gaulomana": ['mw'],
    "gaulunda": ['mw'],
    "gaulundya": ['mw'],
    "gaulya": ['mw'],
    "gaulyaṃ": ['ap90'],
    "gaulā": ['mw'],
    "gaulāṅkāyana": ['mw'],
    "gaumata": ['mw'],
    "gaumathika": ['mw'],
    "gaumatāyana": ['mw'],
    "gaumatāyanaka": ['mw'],
    "gaumatī": ['mw'],
    "gaumaya": ['mw'],
    "gaumaṭhika": ['mw'],
    "gaumāyana": ['mw'],
    "gaunarda": ['mw'],
    "gaunardaḥ": ['ap90'],
    "gaupa": ['mw'],
    "gaupanya": ['mw'],
    "gaupatya": ['mw'],
    "gaupavana": ['mw'],
    "gaupeya": ['mw'],
    "gauphila": ['mw'],
    "gauphilaka": ['mw'],
    "gauphileya": ['mw'],
    "gaupika": ['mw'],
    "gaupikaḥ": ['ap90'],
    "gaupteya": ['mw'],
    "gaupteyaḥ": ['ap90'],
    "gaupuccha": ['ap90', 'mw'],
    "gaupucchika": ['ap90', 'mw'],
    "gaupālapaśupālikā": ['mw'],
    "gaupāleya": ['mw'],
    "gaupāli": ['mw'],
    "gaupālika": ['mw'],
    "gaupālāyana": ['mw'],
    "gaupāyana": ['mw'],
    "gaura": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "gauracandra": ['mw'],
    "gauragaṇoddeśa": ['mw'],
    "gauragotama": ['mw'],
    "gauragrīva": ['mw'],
    "gauragrīvi": ['mw'],
    "gauragrīvīya": ['mw'],
    "gaurajīraka": ['mw'],
    "gauraka": ['mw'],
    "gaurakhara": ['bhs', 'mw'],
    "gauraki": ['mw'],
    "gaurakṛṣṇa": ['mw'],
    "gaurakṣya": ['mw'],
    "gaurakṣyaṃ": ['ap90'],
    "gauralalāma": ['mw'],
    "gauramantra": ['mw'],
    "gauramukha": ['cae', 'mw'],
    "gauramukhā": ['mw'],
    "gauramṛga": ['cae', 'mw'],
    "gaurapṛṣṭha": ['mw'],
    "gaurasaktha": ['mw'],
    "gaurasarṣapa": ['cae', 'ddsa', 'mw'],
    "gaurasuvarṇa": ['mw'],
    "gauratha": ['mw'],
    "gauratittiri": ['mw'],
    "gauratva": ['mw'],
    "gauratvac": ['mw'],
    "gaurava": ['cae', 'ddsa', 'mw'],
    "gauravajāta": ['mw'],
    "gauravallī": ['mw'],
    "gauravalāghavavicāra": ['mw'],
    "gauravatā": ['bhs'],
    "gauravavat": ['mw'],
    "gauravaṃ": ['ap90'],
    "gauraverita": ['mw'],
    "gauravita": ['ap90', 'mw'],
    "gauravya": ['mw'],
    "gauravāhana": ['mw'],
    "gauravāsana": ['mw'],
    "gauraśiras": ['mw'],
    "gauraśāka": ['mw'],
    "gauraśāli": ['mw'],
    "gauri": ['mw'],
    "gaurijeya": ['mw'],
    "gaurika": ['mw'],
    "gaurikā": ['ap90', 'mw'],
    "gaurila": ['mw'],
    "gaurilaḥ": ['ap90'],
    "gauriman": ['mw'],
    "gaurimat": ['mw'],
    "gaurimatī": ['mw'],
    "gaurita": ['mw'],
    "gauriva": ['mw'],
    "gaurivāyana": ['mw'],
    "gaurivīta": ['mw'],
    "gaurivīti": ['gra', 'mw'],
    "gauriśravas": ['mw'],
    "gauriṣaktha": ['mw'],
    "gaurjara": ['mw'],
    "gaurutalpika": ['mw'],
    "gaurutalpikaḥ": ['ap90'],
    "gauryaśman": ['mw'],
    "gaurā": ['mw'],
    "gaurādi": ['mw'],
    "gaurāhika": ['mw'],
    "gaurājājī": ['mw'],
    "gaurārdraka": ['mw'],
    "gaurāsya": ['mw'],
    "gaurātreya": ['mw'],
    "gaurāśva": ['mw'],
    "gaurāṅga": ['mw'],
    "gaurāṅgamallīka": ['mw'],
    "gaurāṅgī": ['mw'],
    "gaurāṭikā": ['mw'],
    "gaurī": ['ap90', 'bhs', 'ddsa', 'mw'],
    "gaurībhartṛ": ['cae', 'mw'],
    "gaurīcarita": ['mw'],
    "gaurīcaturthī": ['mw'],
    "gaurīguru": ['cae', 'mw'],
    "gaurīgāyatrikā": ['mw'],
    "gaurīgāyatrī": ['mw'],
    "gaurīja": ['mw'],
    "gaurījātaka": ['mw'],
    "gaurīkalpa": ['mw'],
    "gaurīkānta": ['mw'],
    "gaurīkāntasārvabhauma": ['mw'],
    "gaurīkṛta": ['mw'],
    "gaurīlalita": ['mw'],
    "gaurīmantra": ['mw'],
    "gaurīmuṇḍa": ['mw'],
    "gaurīnātha": ['cae', 'mw'],
    "gaurīpati": ['cae', 'mw'],
    "gaurīpaṭṭa": ['mw'],
    "gaurīputra": ['mw'],
    "gaurīpuṣpa": ['mw'],
    "gaurīpāṣāṇa": ['mw'],
    "gaurīpūjā": ['cae', 'mw'],
    "gaurītīrtha": ['mw'],
    "gaurīvara": ['mw'],
    "gaurīvita": ['mw'],
    "gaurīviti": ['mw'],
    "gaurīvivāha": ['mw'],
    "gaurīvrata": ['cae', 'mw'],
    "gaurīśa": ['cae', 'mw'],
    "gausahasrika": ['ap90', 'mw'],
    "gautama": ['bhs', 'cae', 'ddsa', 'mw'],
    "gautamaka": ['bhs', 'mw'],
    "gautamanyagrodha": ['mw'],
    "gautamapṛcchā": ['mw'],
    "gautamasa": ['mw'],
    "gautamasambhavā": ['mw'],
    "gautamasaras": ['mw'],
    "gautamasvāmin": ['mw'],
    "gautamavana": ['mw'],
    "gautamaḥ": ['ap90'],
    "gautameśa": ['mw'],
    "gautameśvaratīrtha": ['mw'],
    "gautami": ['mw'],
    "gautaminandana": ['mw'],
    "gautamāraṇya": ['cae', 'mw'],
    "gautamārdhika": ['mw'],
    "gautamāśrama": ['mw'],
    "gautamī": ['ap90', 'bhs', 'ddsa', 'mw'],
    "gautamīputra": ['mw'],
    "gautamīsuta": ['mw'],
    "gautamītantra": ['mw'],
    "gautamīya": ['mw'],
    "gauvindīya": ['bhs'],
    "gauvāsanika": ['mw'],
    "gauñjika": ['mw'],
    "gauśakaṭika": ['mw'],
    "gauśatika": ['ap90', 'mw'],
    "gauśla": ['mw'],
    "gauśra": ['mw'],
    "gauśrāyaṇi": ['mw'],
    "gauśṛṅga": ['mw'],
    "gauḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "gauḍabhṛtyapura": ['mw'],
    "gauḍadeśa": ['mw'],
    "gauḍadeśīya": ['mw'],
    "gauḍagrantha": ['mw'],
    "gauḍaka": ['mw'],
    "gauḍakamṛga": ['bhs', 'mw'],
    "gauḍamālava": ['mw'],
    "gauḍanibandha": ['mw'],
    "gauḍapura": ['mw'],
    "gauḍapāda": ['mw'],
    "gauḍasāraṅgī": ['mw'],
    "gauḍatithitattva": ['mw'],
    "gauḍavyavahāranirṇaya": ['mw'],
    "gauḍaśuddhitattva": ['mw'],
    "gauḍaḥ": ['ap90'],
    "gauḍeśvarācārya": ['mw'],
    "gauḍika": ['ap90', 'mw'],
    "gauḍorvīkulapraśasti": ['mw'],
    "gauḍābhinanda": ['mw'],
    "gauḍābhinandana": ['mw'],
    "gauḍī": ['mw'],
    "gauḍīya": ['mw'],
    "gauṃjikaḥ": ['ap90'],
    "gauṅgava": ['mw'],
    "gauṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "gauṇapakṣa": ['mw'],
    "gauṇasādhyavasānā": ['mw'],
    "gauṇasāropā": ['mw'],
    "gauṇatva": ['mw'],
    "gauṇika": ['ap90', 'cae', 'mw'],
    "gauṇya": ['mw'],
    "gauṇyaṃ": ['ap90'],
    "gauṇāyana": ['bhs'],
    "gauṇḍakirī": ['mw'],
    "gauṣūkta": ['mw'],
    "gauṣūkti": ['mw'],
    "gauṣṭha": ['mw'],
    "gauṣṭhika": ['bhs', 'ddsa', 'mw'],
    "gauṣṭhīna": ['mw'],
    "gauṣṭhīnaṃ": ['ap90'],
    "gav": ['mw'],
    "gava": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "gavacī": ['mw'],
    "gavadika": ['mw'],
    "gavagra": ['gra'],
    "gavaiḍaka": ['mw'],
    "gavajana": ['gra'],
    "gavala": ['cae', 'mw'],
    "gavalaḥ": ['ap90'],
    "gavalgaṇa": ['mw'],
    "gavarāja": ['mw'],
    "gavarṇas": ['gra'],
    "gavassa": ['cped'],
    "gavassā": ['cped'],
    "gavaya": ['cae', 'ddsa', 'gra', 'mw'],
    "gavayaśīrṣa": ['bhs'],
    "gavayaḥ": ['ap90'],
    "gavayī": ['mw'],
    "gavedhu": ['mw'],
    "gavedhuka": ['mw'],
    "gavedhukā": ['mw'],
    "gavedhukāsaktu": ['mw'],
    "gavendra": ['mw'],
    "gaveraṇi": ['mw'],
    "gaveruka": ['mw'],
    "gaverukaṃ": ['ap90'],
    "gavesanta": ['cped'],
    "gavesati": ['cped'],
    "gavesi(n)": ['cped'],
    "gavesissanti": ['cped'],
    "gavesissati": ['cped'],
    "gavesituṁ": ['cped'],
    "gaveśa": ['mw'],
    "gaveśakā": ['mw'],
    "gaveśvara": ['mw'],
    "gaveḍu": ['mw'],
    "gaveḍukā": ['mw'],
    "gaveḍuḥ": ['ap90'],
    "gaveṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "gaveṣa": ['ap90', 'mw'],
    "gaveṣaka": ['bhs'],
    "gaveṣaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "gaveṣaṇaṃ": ['ap90'],
    "gaveṣaṇā": ['bhs', 'mw'],
    "gaveṣaṇīya": ['mw'],
    "gaveṣin": ['cae', 'mw'],
    "gaveṣita": ['ap90', 'mw'],
    "gaveṣṭhin": ['mw'],
    "gavi": ['mw'],
    "gavia": ['gra'],
    "gavijāta": ['mw'],
    "gavinī": ['ap90', 'mw'],
    "gavipphala": ['cped'],
    "gaviputra": ['mw'],
    "gaviṣ": ['ap90', 'cae', 'gra', 'mw'],
    "gaviṣa": ['cae', 'gra', 'mw'],
    "gaviṣṭha": ['ddsa', 'mw'],
    "gaviṣṭhaḥ": ['ap90'],
    "gaviṣṭhi": ['ap90'],
    "gaviṣṭhila": ['mw'],
    "gaviṣṭhira": ['gra', 'mw'],
    "gaviṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "gavodgha": ['mw'],
    "gavopaśa": ['gra'],
    "gavy": ['cae', 'gra'],
    "gavya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gavyadṛḍha": ['bhs', 'mw'],
    "gavyat": ['mw'],
    "gavyaya": ['ap90', 'cae', 'gra', 'mw'],
    "gavyayu": ['ap90', 'cae', 'gra', 'mw'],
    "gavyu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gavyā": ['ap90', 'gra', 'mw'],
    "gavyūta": ['mw'],
    "gavyūtaṃ": ['ap90'],
    "gavyūti": ['cae', 'ddsa', 'gra', 'mw'],
    "gavā": ['bhs'],
    "gavācī": ['mw'],
    "gavādana": ['mw'],
    "gavādanī": ['mw'],
    "gavādevagupta": ['bhs'],
    "gavādi": ['mw'],
    "gavāghātana": ['cped'],
    "gavāgra": ['mw'],
    "gavāhnika": ['mw'],
    "gavākṛti": ['mw'],
    "gavākṣa": ['cae', 'ddsa', 'mw'],
    "gavākṣajāla": ['mw'],
    "gavākṣaka": ['mw'],
    "gavākṣin": ['mw'],
    "gavākṣita": ['mw'],
    "gavālambha": ['mw'],
    "gavālūka": ['mw'],
    "gavālūkaḥ": ['ap90'],
    "gavām": ['mw'],
    "gavāmaya": ['mw'],
    "gavāmayana": ['ddsa', 'mw'],
    "gavāmmedha": ['mw'],
    "gavāmpati": ['mw'],
    "gavāmṛta": ['mw'],
    "gavānṛta": ['cae', 'ddsa', 'mw'],
    "gavāpati": ['cae'],
    "gavārha": ['mw'],
    "gavārtham": ['mw'],
    "gavārthe": ['mw'],
    "gavāssa": ['cped'],
    "gavāssā": ['cped'],
    "gavāsthi": ['mw'],
    "gavāvika": ['mw'],
    "gavāyus": ['mw'],
    "gavāyuta": ['mw'],
    "gavāñc": ['mw'],
    "gavāśana": ['ddsa', 'mw'],
    "gavāśir": ['gra', 'mw'],
    "gavāśva": ['mw'],
    "gavāṃpati": ['bhs'],
    "gavāṃpatiḥ": ['ap90'],
    "gavī": ['ddsa', 'mw'],
    "gavīdhu": ['mw'],
    "gavīdhuka": ['mw'],
    "gavīdhukayavāgū": ['mw'],
    "gavīdhukā": ['mw'],
    "gavīdhumat": ['cae', 'ddsa', 'mw'],
    "gavīnikā": ['cae', 'mw'],
    "gavīnī": ['cae', 'mw'],
    "gavīśa": ['mw'],
    "gavīśvara": ['mw'],
    "gavīḍā": ['mw'],
    "gavṛjīka": ['gra'],
    "gaya": ['cae', 'ddsa', 'gra', 'mw'],
    "gayadāsa": ['mw'],
    "gayasiṃha": ['mw'],
    "gayasiṃharājacaritra": ['mw'],
    "gayasphāna": ['cae', 'gra', 'mw'],
    "gayasphāti": ['mw'],
    "gayasphāyana": ['mw'],
    "gayasādhana": ['gra', 'mw'],
    "gayaśiras": ['mw'],
    "gayaḥ": ['ap90'],
    "gayha": ['cped'],
    "gayhaka": ['cped'],
    "gayhakaṁ": ['cped'],
    "gayhamāna": ['cped'],
    "gayhati": ['cped'],
    "gayin": ['mw'],
    "gayā": ['ddsa', 'mw'],
    "gayādāsa": ['mw'],
    "gayākāśyapa": ['bhs', 'mw'],
    "gayākūpa": ['ddsa', 'mw'],
    "gayāmāhātmya": ['mw'],
    "gayāsadīna": ['mw'],
    "gayātīrtha": ['mw'],
    "gayāśikhara": ['mw'],
    "gayāśiras": ['mw'],
    "gayāśīrṣa": ['bhs', 'mw'],
    "gayāśīrṣaparvata": ['mw'],
    "gañchasi": ['cped'],
    "gañchi": ['cped'],
    "gañchisi": ['cped'],
    "gañchissaṁ": ['cped'],
    "gañj": ['mw'],
    "gañja": ['bhs', 'cae', 'ddsa', 'mw'],
    "gañjana": ['cae', 'mw'],
    "gañjavara": ['mw'],
    "gañjikā": ['mw'],
    "gañjā": ['ddsa', 'mw'],
    "gañjājikā": ['mw'],
    "gañjākinī": ['mw'],
    "gaḍ": ['ap90', 'mw'],
    "gaḍa": ['mw'],
    "gaḍadeśaja": ['mw'],
    "gaḍaka": ['mw'],
    "gaḍalavaṇa": ['mw'],
    "gaḍayanta": ['mw'],
    "gaḍayaṃtaḥ": ['ap90'],
    "gaḍayitnu": ['mw'],
    "gaḍaḥ": ['ap90'],
    "gaḍera": ['mw'],
    "gaḍeraka": ['mw'],
    "gaḍeraḥ": ['ap90'],
    "gaḍhādeśa": ['mw'],
    "gaḍi": ['cae', 'ddsa', 'mw'],
    "gaḍika": ['mw'],
    "gaḍita": ['bhs'],
    "gaḍiḥ": ['ap90'],
    "gaḍola": ['mw'],
    "gaḍolaḥ": ['ap90'],
    "gaḍottha": ['mw'],
    "gaḍu": ['ap90', 'cae', 'ddsa', 'mw'],
    "gaḍuka": ['mw'],
    "gaḍukaḥ": ['ap90'],
    "gaḍukaṇṭha": ['mw'],
    "gaḍula": ['mw'],
    "gaḍura": ['ap90', 'mw'],
    "gaḍuśiras": ['mw'],
    "gaḍvādi": ['mw'],
    "gaḍā": ['bhs', 'mw'],
    "gaḍākhya": ['mw'],
    "gaḍḍakaḥ": ['ap90'],
    "gaḍḍaraḥ": ['ap90'],
    "gaḍḍarikā": ['ap90'],
    "gaḍḍuka": ['mw'],
    "gaḍḍālikā": ['mw'],
    "gaḍḍālikāpravāheṇa": ['mw'],
    "gaḍḍārikā": ['mw'],
    "gaḍḍūka": ['mw'],
    "gaḷa": ['cped'],
    "gaḷagaḷāyanta": ['cped'],
    "gaḷagaḷāyati": ['cped'],
    "gaḷati": ['cped'],
    "gaḷayati": ['cped'],
    "gaṃbhārikā": ['ap90'],
    "gaṃbhīra": ['ap90'],
    "gaṃbhīraka": ['ap90'],
    "gaṃbhīrā": ['ap90'],
    "gaṃdh": ['ap90'],
    "gaṃdhakaḥ": ['ap90'],
    "gaṃdhanaṃ": ['ap90'],
    "gaṃdharvaḥ": ['ap90'],
    "gaṃdhavat": ['ap90'],
    "gaṃdhaḥ": ['ap90'],
    "gaṃdhi": ['ap90'],
    "gaṃdhika": ['ap90'],
    "gaṃdhin": ['ap90'],
    "gaṃdholī": ['ap90'],
    "gaṃdhālu": ['ap90'],
    "gaṃdhālī": ['ap90'],
    "gaṃdhāraḥ": ['ap90'],
    "gaṃgolaḥ": ['ap90'],
    "gaṃgā": ['ap90'],
    "gaṃgākā": ['ap90'],
    "gaṃgībhūta": ['ap90'],
    "gaṃhman": ['mw'],
    "gaṃj": ['ap90'],
    "gaṃjana": ['ap90'],
    "gaṃjaḥ": ['ap90'],
    "gaṃjikā": ['ap90'],
    "gaṃtavya": ['ap90'],
    "gaṃtrī": ['ap90'],
    "gaṃtuḥ": ['ap90'],
    "gaṃtṛ": ['ap90'],
    "gaṃḍakaḥ": ['ap90'],
    "gaṃḍakā": ['ap90'],
    "gaṃḍakī": ['ap90'],
    "gaṃḍalin": ['ap90'],
    "gaṃḍaḥ": ['ap90'],
    "gaṃḍikā": ['ap90'],
    "gaṃḍinī": ['ap90'],
    "gaṃḍiḥ": ['ap90'],
    "gaṃḍolaḥ": ['ap90'],
    "gaṃḍuḥ": ['ap90'],
    "gaṃḍālī": ['ap90'],
    "gaṃḍīraḥ": ['ap90'],
    "gaṃḍūla": ['ap90'],
    "gaṃḍūḥ": ['ap90'],
    "gaṃḍūṣaḥ": ['ap90'],
    "gaṅga": ['bhs', 'mw'],
    "gaṅgadatta": ['mw'],
    "gaṅgadevībhaginī": ['bhs'],
    "gaṅgadāsa": ['mw'],
    "gaṅgakā": ['mw'],
    "gaṅgama": ['mw'],
    "gaṅgapāla": ['bhs'],
    "gaṅgapālaka": ['bhs'],
    "gaṅgarasthā": ['bhs'],
    "gaṅgeyaka": ['bhs'],
    "gaṅgeśa": ['mw'],
    "gaṅgeśvara": ['mw'],
    "gaṅgeśvaraliṅga": ['mw'],
    "gaṅgeṣṭi": ['mw'],
    "gaṅgika": ['bhs'],
    "gaṅgikā": ['mw'],
    "gaṅgodaka": ['mw'],
    "gaṅgodbheda": ['mw'],
    "gaṅguka": ['mw'],
    "gaṅgā": ['cae', 'ddsa', 'gra', 'mw'],
    "gaṅgābhṛt": ['mw'],
    "gaṅgācampū": ['mw'],
    "gaṅgācillī": ['mw'],
    "gaṅgādevā": ['bhs'],
    "gaṅgādevī": ['mw'],
    "gaṅgādhara": ['ddsa', 'mw'],
    "gaṅgādharabhaṭṭa": ['mw'],
    "gaṅgādharacūrṇa": ['mw'],
    "gaṅgādharamādhava": ['mw'],
    "gaṅgādharapura": ['mw'],
    "gaṅgādhararasa": ['mw'],
    "gaṅgādhāra": ['mw'],
    "gaṅgāditya": ['mw'],
    "gaṅgādvāra": ['mw'],
    "gaṅgādvāramāhātmya": ['mw'],
    "gaṅgādāsa": ['mw'],
    "gaṅgāhrada": ['mw'],
    "gaṅgāja": ['mw'],
    "gaṅgājala": ['mw'],
    "gaṅgākā": ['mw'],
    "gaṅgākṣetra": ['mw'],
    "gaṅgālaharī": ['mw'],
    "gaṅgāmadhya": ['mw'],
    "gaṅgāmaha": ['mw'],
    "gaṅgāmahādvāra": ['mw'],
    "gaṅgāmbhas": ['mw'],
    "gaṅgāmbu": ['mw'],
    "gaṅgāmāhātmya": ['mw'],
    "gaṅgānāgarāja": ['mw'],
    "gaṅgānāgarājan": ['bhs'],
    "gaṅgānātha": ['mw'],
    "gaṅgāpattrī": ['mw'],
    "gaṅgāpurībhaṭṭāraka": ['mw'],
    "gaṅgāputra": ['mw'],
    "gaṅgāpāra": ['mw'],
    "gaṅgārāma": ['mw'],
    "gaṅgāsaptamī": ['mw'],
    "gaṅgāsaras": ['mw'],
    "gaṅgāsnāna": ['mw'],
    "gaṅgāstotra": ['mw'],
    "gaṅgāstuti": ['mw'],
    "gaṅgāsuta": ['mw'],
    "gaṅgāsāgara": ['mw'],
    "gaṅgāsūnu": ['mw'],
    "gaṅgātīra": ['mw'],
    "gaṅgātīrtha": ['mw'],
    "gaṅgāvataraṇa": ['mw'],
    "gaṅgāvataraṇacampūprabandha": ['mw'],
    "gaṅgāvillāsa": ['mw'],
    "gaṅgāvāhatīrtha": ['mw'],
    "gaṅgāvākyāvalī": ['mw'],
    "gaṅgāvāsin": ['mw'],
    "gaṅgāyamune": ['mw'],
    "gaṅgāyātrā": ['mw'],
    "gaṅgāśoṇa": ['mw'],
    "gaṅgāṣṭaka": ['mw'],
    "gaṅgāṭeya": ['mw'],
    "gaṅgī": ['mw'],
    "gaṅgībhūta": ['mw'],
    "gaṅgūya": ['mw'],
    "gaṇ": ['ap90', 'mw'],
    "gaṇa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "gaṇabandhandhika": ['cped'],
    "gaṇabhartṛ": ['mw'],
    "gaṇabhogya": ['mw'],
    "gaṇabhojana": ['bhs', 'cped', 'mw'],
    "gaṇabhṛt": ['mw'],
    "gaṇacakra": ['ddsa', 'mw'],
    "gaṇacakraka": ['mw'],
    "gaṇacchandas": ['cae', 'mw'],
    "gaṇadeva": ['mw'],
    "gaṇadevatā": ['mw'],
    "gaṇadhara": ['mw'],
    "gaṇadhātuparibhāṣā": ['mw'],
    "gaṇadravya": ['mw'],
    "gaṇadvīpa": ['mw'],
    "gaṇadāsa": ['cae', 'mw'],
    "gaṇadīkṣin": ['ddsa', 'mw'],
    "gaṇadīkṣā": ['mw'],
    "gaṇadīkṣāprabhu": ['mw'],
    "gaṇaguṇa": ['bhs'],
    "gaṇagāri": ['mw'],
    "gaṇahoma": ['mw'],
    "gaṇahāsa": ['mw'],
    "gaṇahāsaka": ['mw'],
    "gaṇaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "gaṇakamahāmatta": ['cped'],
    "gaṇakamahāmattā": ['cped'],
    "gaṇakamahāmātra": ['mw'],
    "gaṇakarman": ['mw'],
    "gaṇakarṇikā": ['mw'],
    "gaṇaki": ['cped'],
    "gaṇakumāra": ['mw'],
    "gaṇakāma": ['mw'],
    "gaṇakāra": ['mw'],
    "gaṇakāri": ['mw'],
    "gaṇakāritā": ['mw'],
    "gaṇakī": ['mw'],
    "gaṇakṛtvas": ['mw'],
    "gaṇamaggena": ['cped'],
    "gaṇamukhya": ['mw'],
    "gaṇana": ['cae', 'cped', 'ddsa', 'mw'],
    "gaṇanaṃ": ['ap90'],
    "gaṇangaṇaūpāhanā": ['cped'],
    "gaṇangaṇūpāhanā": ['cped'],
    "gaṇanā": ['cped', 'mw'],
    "gaṇanāgati": ['bhs', 'mw'],
    "gaṇanāmahāmātra": ['mw'],
    "gaṇanāpati": ['mw'],
    "gaṇanāpattrikā": ['mw'],
    "gaṇanāsamatikrānta": ['bhs'],
    "gaṇanātha": ['cae', 'ddsa', 'mw'],
    "gaṇanāvartalipi": ['bhs', 'mw'],
    "gaṇanāyaka": ['cae', 'mw'],
    "gaṇanāyikā": ['mw'],
    "gaṇanīya": ['ap90', 'mw'],
    "gaṇapa": ['cae', 'mw'],
    "gaṇaparvata": ['mw'],
    "gaṇapati": ['cae', 'gra', 'mw'],
    "gaṇapatibhaṭṭa": ['mw'],
    "gaṇapatihṛdayā": ['mw'],
    "gaṇapatikhaṇḍa": ['mw'],
    "gaṇapatināga": ['mw'],
    "gaṇapatinātha": ['mw'],
    "gaṇapatipūjana": ['mw'],
    "gaṇapatipūrvatāpanīyopaniṣad": ['mw'],
    "gaṇapatipūrvatāpinī": ['mw'],
    "gaṇapatistavarāja": ['mw'],
    "gaṇapatistotra": ['mw'],
    "gaṇapatyupaniṣad": ['mw'],
    "gaṇapatyārādhana": ['mw'],
    "gaṇapramukha": ['mw'],
    "gaṇapuraṇa": ['mw'],
    "gaṇapuṃgava": ['mw'],
    "gaṇapāda": ['mw'],
    "gaṇapāṭha": ['cae', 'mw'],
    "gaṇapīṭhaka": ['mw'],
    "gaṇapūjya": ['mw'],
    "gaṇapūra": ['cped'],
    "gaṇapūraka": ['cped'],
    "gaṇapūrva": ['mw'],
    "gaṇaratna": ['mw'],
    "gaṇaratnakāra": ['mw'],
    "gaṇaratnamahodadhi": ['mw'],
    "gaṇarājya": ['mw'],
    "gaṇarātra": ['mw'],
    "gaṇarūpa": ['mw'],
    "gaṇarūpaka": ['mw'],
    "gaṇarūpin": ['mw'],
    "gaṇatitha": ['mw'],
    "gaṇatrikā": ['mw'],
    "gaṇatva": ['mw'],
    "gaṇatā": ['ap90', 'mw'],
    "gaṇavara": ['mw'],
    "gaṇavassika": ['cped'],
    "gaṇavat": ['mw'],
    "gaṇavatī": ['mw'],
    "gaṇavatīsuta": ['mw'],
    "gaṇavyākhyāna": ['mw'],
    "gaṇavyūha": ['mw'],
    "gaṇavācaka": ['bhs'],
    "gaṇavṛtta": ['cae', 'ddsa', 'mw'],
    "gaṇay": ['cae'],
    "gaṇaya": ['ddsa'],
    "gaṇaya(t)": ['cped'],
    "gaṇayajña": ['mw'],
    "gaṇayitrikā": ['mw'],
    "gaṇayāga": ['mw'],
    "gaṇaśas": ['ap90', 'cae', 'ddsa', 'mw'],
    "gaṇaśri": ['gra'],
    "gaṇaśrī": ['cae', 'mw'],
    "gaṇaḥ": ['ap90'],
    "gaṇdamattikā": ['cped'],
    "gaṇdupāda": ['cped'],
    "gaṇendra": ['bhs', 'mw'],
    "gaṇendrarāja": ['bhs'],
    "gaṇeru": ['mw'],
    "gaṇeruka": ['mw'],
    "gaṇerukā": ['ap90', 'mw'],
    "gaṇeruḥ": ['ap90'],
    "gaṇesi": ['cped'],
    "gaṇetabba": ['cped'],
    "gaṇetuṁ": ['cped'],
    "gaṇetvā": ['cped'],
    "gaṇeya": ['ap90', 'mw'],
    "gaṇeyu": ['mw'],
    "gaṇeśa": ['cae', 'ddsa', 'mw'],
    "gaṇeśabhujaṃgaprayātastotra": ['mw'],
    "gaṇeśabhūṣaṇa": ['mw'],
    "gaṇeśacaturthī": ['mw'],
    "gaṇeśagītā": ['mw'],
    "gaṇeśakhaṇḍa": ['mw'],
    "gaṇeśakumbha": ['mw'],
    "gaṇeśakusuma": ['mw'],
    "gaṇeśamiśra": ['mw'],
    "gaṇeśapurāṇa": ['mw'],
    "gaṇeśapūjā": ['mw'],
    "gaṇeśasahasranāman": ['mw'],
    "gaṇeśastavarāja": ['mw'],
    "gaṇeśastuti": ['mw'],
    "gaṇeśatāpinī": ['mw'],
    "gaṇeśavimarśinī": ['mw'],
    "gaṇeśayāmala": ['mw'],
    "gaṇeśopapurāṇa": ['mw'],
    "gaṇeśvara": ['bhs', 'mw'],
    "gaṇeśāna": ['mw'],
    "gaṇha": ['cped'],
    "gaṇhanta": ['cped'],
    "gaṇhati": ['cped'],
    "gaṇhayati": ['cped'],
    "gaṇhiya": ['cped'],
    "gaṇhiṁ": ['cped'],
    "gaṇhiṁsu": ['cped'],
    "gaṇhāpeti": ['cped'],
    "gaṇhāti": ['cped'],
    "gaṇi": ['mw'],
    "gaṇia": ['gra'],
    "gaṇibhuta": ['cped'],
    "gaṇika": ['bhs'],
    "gaṇikā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "gaṇikādārikā": ['cae'],
    "gaṇikānna": ['cae', 'mw'],
    "gaṇikāpravahana": ['cae'],
    "gaṇikāpāda": ['mw'],
    "gaṇikārikā": ['mw'],
    "gaṇikārī": ['mw'],
    "gaṇima": ['mw'],
    "gaṇimat": ['mw'],
    "gaṇin": ['ap90', 'bhs', 'cae', 'mw'],
    "gaṇipiṭaka": ['mw'],
    "gaṇistharāja": ['mw'],
    "gaṇita": ['ap90', 'cae', 'cped', 'mw'],
    "gaṇitabba": ['cped'],
    "gaṇitakaumudī": ['mw'],
    "gaṇitalatā": ['mw'],
    "gaṇitamālatī": ['mw'],
    "gaṇitanāmamālā": ['mw'],
    "gaṇitapañcaviṃśatikā": ['mw'],
    "gaṇitapāśa": ['mw'],
    "gaṇitasāra": ['mw'],
    "gaṇitatattvacintāmaṇi": ['mw'],
    "gaṇitavya": ['mw'],
    "gaṇitaśāstra": ['mw'],
    "gaṇitin": ['ap90', 'mw'],
    "gaṇitra": ['bhs', 'mw'],
    "gaṇitrikā": ['mw'],
    "gaṇitā": ['mw'],
    "gaṇitādevītīrtha": ['mw'],
    "gaṇitādhyāya": ['mw'],
    "gaṇitāmṛtasāgarī": ['mw'],
    "gaṇiḥ": ['ap90'],
    "gaṇotsāha": ['mw'],
    "gaṇthikāphalaka": ['cped'],
    "gaṇya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gaṇā": ['mw'],
    "gaṇābhyantara": ['cae', 'mw'],
    "gaṇācala": ['mw'],
    "gaṇācārya": ['mw'],
    "gaṇādhipa": ['mw'],
    "gaṇādhipati": ['ddsa', 'mw'],
    "gaṇādhipatya": ['mw'],
    "gaṇādhyakṣa": ['mw'],
    "gaṇādhīśa": ['mw'],
    "gaṇāgraṇī": ['mw'],
    "gaṇānna": ['cae', 'mw'],
    "gaṇāpeti": ['cped'],
    "gaṇārāma": ['cped'],
    "gaṇāvarā": ['mw'],
    "gaṇī(n)": ['cped'],
    "gaṇībhūta": ['ap90', 'mw'],
    "gaṇḍ": ['mw'],
    "gaṇḍa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "gaṇḍabhitti": ['mw'],
    "gaṇḍadeśa": ['mw'],
    "gaṇḍadūrvā": ['mw'],
    "gaṇḍagopāla": ['mw'],
    "gaṇḍagopālikā": ['mw'],
    "gaṇḍagrāma": ['mw'],
    "gaṇḍagrāmaka": ['bhs'],
    "gaṇḍagātra": ['mw'],
    "gaṇḍaka": ['bhs', 'mw'],
    "gaṇḍakaraṭa": ['mw'],
    "gaṇḍakaṇḍu": ['mw'],
    "gaṇḍakusuma": ['mw'],
    "gaṇḍakā": ['mw'],
    "gaṇḍakālī": ['mw'],
    "gaṇḍakārī": ['mw'],
    "gaṇḍakāṣa": ['mw'],
    "gaṇḍakī": ['mw'],
    "gaṇḍakūpa": ['mw'],
    "gaṇḍalavaṇa": ['mw'],
    "gaṇḍalekhā": ['cae', 'mw'],
    "gaṇḍalin": ['mw'],
    "gaṇḍamāla": ['cae', 'mw'],
    "gaṇḍamālaka": ['mw'],
    "gaṇḍamālikā": ['mw'],
    "gaṇḍamālin": ['cae', 'mw'],
    "gaṇḍamālā": ['cae', 'mw'],
    "gaṇḍamālī": ['mw'],
    "gaṇḍamūrkha": ['mw'],
    "gaṇḍaphalaka": ['mw'],
    "gaṇḍapradeśa": ['mw'],
    "gaṇḍapāda": ['mw'],
    "gaṇḍapālī": ['cae', 'mw'],
    "gaṇḍasthala": ['cae', 'mw'],
    "gaṇḍasthalī": ['mw'],
    "gaṇḍasāhvayā": ['mw'],
    "gaṇḍavyūha": ['bhs', 'mw'],
    "gaṇḍayanta": ['mw'],
    "gaṇḍaśaila": ['mw'],
    "gaṇḍaśilā": ['mw'],
    "gaṇḍi": ['bhs', 'mw'],
    "gaṇḍikā": ['bhs', 'cped', 'mw'],
    "gaṇḍikākārayoga": ['mw'],
    "gaṇḍilaka": ['mw'],
    "gaṇḍinī": ['mw'],
    "gaṇḍira": ['mw'],
    "gaṇḍiya": ['cped'],
    "gaṇḍola": ['mw'],
    "gaṇḍolaka": ['mw'],
    "gaṇḍolakapāda": ['mw'],
    "gaṇḍolapāda": ['mw'],
    "gaṇḍopadhāna": ['ddsa', 'mw'],
    "gaṇḍopadhānīya": ['mw'],
    "gaṇḍopala": ['mw'],
    "gaṇḍu": ['cae', 'ddsa', 'mw'],
    "gaṇḍuka": ['mw'],
    "gaṇḍula": ['mw'],
    "gaṇḍuppāda": ['cped'],
    "gaṇḍut": ['mw'],
    "gaṇḍā": ['mw'],
    "gaṇḍālī": ['mw'],
    "gaṇḍānta": ['mw'],
    "gaṇḍāri": ['mw'],
    "gaṇḍāśman": ['mw'],
    "gaṇḍāṅga": ['mw'],
    "gaṇḍī": ['bhs'],
    "gaṇḍīkādhāna": ['cped'],
    "gaṇḍīra": ['mw'],
    "gaṇḍīraka": ['bhs'],
    "gaṇḍīrī": ['mw'],
    "gaṇḍū": ['mw'],
    "gaṇḍūpada": ['ddsa', 'mw'],
    "gaṇḍūpadabhava": ['mw'],
    "gaṇḍūpadodbhava": ['mw'],
    "gaṇḍūpadī": ['mw'],
    "gaṇḍūśika": ['bhs'],
    "gaṇḍūṣa": ['cae', 'ddsa', 'mw'],
    "gaṇḍūṣaya": ['mw'],
    "gaṇḍūṣīkṛ": ['mw'],
    "gaṇṭhi": ['cped'],
    "gaṇṭhikā": ['cped'],
    "gdha": ['mw'],
    "gdhi": ['mw'],
    "gdhiḥ": ['ap90'],
    "gedha": ['cped'],
    "gedhi": ['cped'],
    "gedhi(n)": ['cped'],
    "gedhikata": ['cped'],
    "gedhitacitta": ['cped'],
    "geha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "gehabhū": ['mw'],
    "gehadāha": ['cae', 'mw'],
    "gehanakula": ['mw'],
    "gehanissita": ['cped'],
    "gehapati": ['mw'],
    "gehapārāvata": ['cae', 'mw'],
    "gehasita": ['cped'],
    "gehaṃ": ['ap90'],
    "gehe": ['mw'],
    "gehedhṛṣṭa": ['mw'],
    "gehedāhin": ['mw'],
    "gehedṛpta": ['mw'],
    "gehekṣveḍin": ['mw'],
    "gehemehin": ['mw'],
    "gehenardin": ['mw'],
    "gehevijitin": ['mw'],
    "gehevyāḍa": ['mw'],
    "geheśūra": ['mw'],
    "gehia": ['gra'],
    "gehin": ['ap90'],
    "gehinī": ['ap90', 'mw'],
    "gehiṇī": ['mw'],
    "gehopavana": ['mw'],
    "gehya": ['ap90', 'cae', 'gra', 'mw'],
    "gehānuprapādam": ['mw'],
    "gehānuprapātam": ['mw'],
    "gehānupraveśam": ['mw'],
    "gehānupraveśanīya": ['mw'],
    "gehāvaskandam": ['mw'],
    "gehī": ['mw'],
    "gehīy": ['cae'],
    "gehīya": ['ddsa', 'mw'],
    "gela": ['bhs', 'mw'],
    "gelañña": ['cped'],
    "gelu": ['bhs', 'mw'],
    "genduka": ['mw'],
    "gep": ['ap90', 'mw'],
    "gerukaparikamma": ['cped'],
    "gev": ['ap90', 'mw'],
    "geya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "geyajña": ['mw'],
    "geyapada": ['mw'],
    "geyarājan": ['bhs', 'mw'],
    "geyya": ['cped'],
    "geṃdukaḥ": ['ap90'],
    "geṃḍukaḥ": ['ap90'],
    "geṇḍu": ['mw'],
    "geṇḍuka": ['cae', 'ddsa', 'mw'],
    "geṇḍūka": ['mw'],
    "geṣ": ['ap90', 'mw'],
    "geṣa": ['mw'],
    "geṣṇa": ['cae', 'ddsa', 'mw'],
    "geṣṇaḥ": ['ap90'],
    "geṣṇu": ['mw'],
    "geṣṇuḥ": ['ap90'],
    "gha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ghaggh": ['ap90', 'mw'],
    "ghagh": ['mw'],
    "ghakāra": ['mw'],
    "ghala": ['mw'],
    "ghamaghamārava": ['mw'],
    "ghamb": ['mw'],
    "ghamma": ['cped'],
    "ghammapareta": ['cped'],
    "ghammābhitatta": ['cped'],
    "ghana": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ghanabhitti": ['mw'],
    "ghanacaya": ['mw'],
    "ghanacchada": ['mw'],
    "ghanadhvani": ['mw'],
    "ghanadhātu": ['mw'],
    "ghanadruma": ['mw'],
    "ghanadundubhisvana": ['mw'],
    "ghanagarjita": ['mw'],
    "ghanaghana": ['mw'],
    "ghanaghanaugha": ['mw'],
    "ghanagolaka": ['mw'],
    "ghanahastasaṃkhyā": ['mw'],
    "ghanaja": ['mw'],
    "ghanajambāla": ['mw'],
    "ghanajvālā": ['mw'],
    "ghanakapha": ['mw'],
    "ghanakapīvat": ['mw'],
    "ghanakāla": ['cae', 'ddsa', 'mw'],
    "ghanakṣama": ['mw'],
    "ghanam": ['mw'],
    "ghanamud": ['mw'],
    "ghanamūla": ['mw'],
    "ghananābhi": ['mw'],
    "ghananīhāra": ['mw'],
    "ghanapada": ['mw'],
    "ghanapadavī": ['cae', 'mw'],
    "ghanapallava": ['mw'],
    "ghanapattra": ['mw'],
    "ghanapayodhara": ['mw'],
    "ghanaphala": ['mw'],
    "ghanapriyā": ['mw'],
    "ghanapāṣaṇḍa": ['mw'],
    "ghanarasa": ['mw'],
    "ghanarava": ['mw'],
    "ghanaruc": ['mw'],
    "ghanarucirakalāpa": ['mw'],
    "ghanarūpā": ['mw'],
    "ghanasamaya": ['cae', 'mw'],
    "ghanasaṃdhi": ['bhs'],
    "ghanasaṃvṛtti": ['mw'],
    "ghanasiktha": ['mw'],
    "ghanaskandha": ['mw'],
    "ghanasvana": ['mw'],
    "ghanasāra": ['cae', 'mw'],
    "ghanasārabhāva": ['mw'],
    "ghanatimira": ['cae', 'mw'],
    "ghanatola": ['mw'],
    "ghanatoya": ['mw'],
    "ghanatva": ['mw'],
    "ghanatvac": ['mw'],
    "ghanatā": ['cae', 'mw'],
    "ghanatāla": ['mw'],
    "ghanatāmasa": ['cae'],
    "ghanaugha": ['mw'],
    "ghanavallikā": ['mw'],
    "ghanavallī": ['mw'],
    "ghanavara": ['mw'],
    "ghanavartman": ['mw'],
    "ghanavyapāya": ['mw'],
    "ghanavyūha": ['bhs', 'mw'],
    "ghanavāc": ['mw'],
    "ghanavāhana": ['mw'],
    "ghanavāri": ['mw'],
    "ghanavāsa": ['mw'],
    "ghanavāta": ['mw'],
    "ghanavīthi": ['cae', 'mw'],
    "ghanaśabda": ['mw'],
    "ghanaśyāma": ['mw'],
    "ghanaśṛṅgī": ['mw'],
    "ghanetara": ['mw'],
    "ghaneśvarī": ['mw'],
    "ghanoda": ['mw'],
    "ghanodadhi": ['mw'],
    "ghanodaya": ['mw'],
    "ghanopala": ['mw'],
    "ghanoparuddha": ['mw'],
    "ghanorū": ['ddsa', 'mw'],
    "ghanottama": ['mw'],
    "ghanottara": ['mw'],
    "ghanā": ['mw'],
    "ghanābhoga": ['mw'],
    "ghanāgama": ['ddsa', 'mw'],
    "ghanāghana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ghanāghanā": ['mw'],
    "ghanājñāna": ['mw'],
    "ghanākara": ['mw'],
    "ghanāmala": ['mw'],
    "ghanāmaya": ['mw'],
    "ghanāmbu": ['mw'],
    "ghanānta": ['cae', 'mw'],
    "ghanārava": ['mw'],
    "ghanāruddha": ['mw'],
    "ghanāruṇa": ['mw'],
    "ghanārāva": ['mw'],
    "ghanāsaha": ['mw'],
    "ghanāsthika": ['ddsa', 'mw'],
    "ghanātyaya": ['cae', 'mw'],
    "ghanāvaruddha": ['mw'],
    "ghanāya": ['ddsa', 'mw'],
    "ghanāñjanī": ['mw'],
    "ghanāśraya": ['mw'],
    "ghanī": ['mw'],
    "ghanībhāva": ['mw'],
    "ghanībhū": ['ap90'],
    "ghanībhūta": ['mw'],
    "ghanīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghanīkṛta": ['mw'],
    "ghanīya": ['mw'],
    "ghanīyati": ['ap90'],
    "ghar": ['ap90', 'gra', 'mw'],
    "ghara": ['bhs', 'cped'],
    "gharabandhana": ['cped'],
    "gharadinnakābādha": ['cped'],
    "gharaka": ['bhs'],
    "gharamesi(n)": ['cped'],
    "gharati": ['bhs'],
    "gharaḥ": ['ap90'],
    "gharaṇī": ['bhs', 'cped', 'mw'],
    "gharaṭṭa": ['cae', 'ddsa', 'mw'],
    "gharaṭṭaka": ['cae', 'mw'],
    "gharaṭṭaḥ": ['ap90'],
    "gharaṭṭikā": ['mw'],
    "gharb": ['ap90', 'mw'],
    "ghargaraka": ['mw'],
    "gharghara": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghargharadhvani": ['mw'],
    "ghargharaka": ['mw'],
    "ghargharikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghargharita": ['mw'],
    "ghargharitaṃ": ['ap90'],
    "ghargharya": ['mw'],
    "ghargharā": ['ap90', 'mw'],
    "ghargharārava": ['mw'],
    "ghargharī": ['mw'],
    "gharghaṭa": ['mw'],
    "gharghurghā": ['mw'],
    "ghariṇī": ['bhs', 'mw'],
    "ghariṇīstūpa": ['mw'],
    "gharma": ['cae', 'ddsa', 'gra', 'mw'],
    "gharmabhānu": ['mw'],
    "gharmabindu": ['mw'],
    "gharmacarcikā": ['mw'],
    "gharmaccheda": ['cae', 'mw'],
    "gharmada": ['mw'],
    "gharmadugha": ['mw'],
    "gharmaduh": ['mw'],
    "gharmadyuti": ['cae', 'mw'],
    "gharmadīdhiti": ['cae', 'mw'],
    "gharmaga": ['mw'],
    "gharmajala": ['cae', 'mw'],
    "gharmakāla": ['cae', 'ddsa', 'mw'],
    "gharmamāsa": ['mw'],
    "gharmapayas": ['mw'],
    "gharmapāvan": ['mw'],
    "gharmaraśmi": ['cae', 'mw'],
    "gharmarbhānu": ['cae'],
    "gharmarocana": ['mw'],
    "gharmasad": ['gra', 'mw'],
    "gharmastubh": ['cae', 'gra', 'mw'],
    "gharmasvaras": ['gra', 'mw'],
    "gharmasveda": ['gra', 'mw'],
    "gharmasūkta": ['mw'],
    "gharmatanu": ['mw'],
    "gharmatanū": ['mw'],
    "gharmatapta": ['mw'],
    "gharmatoya": ['cae', 'mw'],
    "gharmatva": ['mw'],
    "gharmavant": ['cae'],
    "gharmavat": ['mw'],
    "gharmavicarcikā": ['mw'],
    "gharmavāri": ['cae', 'mw'],
    "gharmaśiras": ['mw'],
    "gharmaḥ": ['ap90'],
    "gharmetarāṃśu": ['mw'],
    "gharmeṣṭakā": ['ddsa', 'mw'],
    "gharmieṣṭhā": ['gra'],
    "gharmin": ['cae', 'gra', 'mw'],
    "gharmita": ['cae', 'ddsa', 'mw'],
    "gharmocchiṣṭa": ['mw'],
    "gharmodaka": ['cae', 'mw'],
    "gharmya": ['cae', 'ddsa', 'mw'],
    "gharmyeṣṭhā": ['gra', 'mw'],
    "gharmāmbhas": ['cae', 'mw'],
    "gharmāmbu": ['cae', 'mw'],
    "gharmānta": ['cae', 'ddsa', 'mw'],
    "gharmāntakāmukī": ['mw'],
    "gharmārta": ['cae', 'mw'],
    "gharmāṃśu": ['cae', 'ddsa', 'mw'],
    "gharmūṭī": ['mw'],
    "gharā": ['bhs', 'cped'],
    "gharāvāsa": ['cped'],
    "gharūpacāra": ['cped'],
    "gharṣa": ['cae', 'ddsa', 'mw'],
    "gharṣaka": ['ap90', 'mw'],
    "gharṣaḥ": ['ap90'],
    "gharṣaṇa": ['ap90', 'cae', 'mw'],
    "gharṣaṇāla": ['mw'],
    "gharṣaṇī": ['mw'],
    "gharṣaṇīya": ['mw'],
    "gharṣin": ['mw'],
    "gharṣita": ['ap90', 'mw'],
    "ghas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ghasa": ['cae', 'ddsa', 'mw'],
    "ghasa(t)": ['cped'],
    "ghasana": ['cae', 'mw'],
    "ghasati": ['cped'],
    "ghasaḥ": ['ap90'],
    "ghasi": ['cae', 'mw'],
    "ghasiḥ": ['ap90'],
    "ghasmara": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghasmarī": ['bhs'],
    "ghasra": ['ap90', 'mw'],
    "ghasvara": ['cae', 'mw'],
    "ghasāna": ['cped'],
    "ghatana": ['mw'],
    "ghatikataha": ['cped'],
    "ghatvā": ['cped'],
    "ghaura": ['ddsa', 'mw'],
    "ghauṣaka": ['mw'],
    "ghauṣasthalaka": ['mw'],
    "ghauṣeya": ['mw'],
    "ghaṁsanta": ['cped'],
    "ghaṁsati": ['cped'],
    "ghaṁsenta": ['cped'],
    "ghaṁseti": ['cped'],
    "ghaṁsāpeti": ['cped'],
    "ghaṁsīyati": ['cped'],
    "ghaṃb": ['ap90'],
    "ghaṃs": ['mw'],
    "ghaṃḍaḥ": ['ap90'],
    "ghaṃṣ": ['ap90', 'mw'],
    "ghaṃṭ": ['ap90'],
    "ghaṃṭa": ['ap90'],
    "ghaṃṭikā": ['ap90'],
    "ghaṃṭin": ['ap90'],
    "ghaṃṭuḥ": ['ap90'],
    "ghaṃṭā": ['ap90'],
    "ghaṇ": ['ap90', 'mw'],
    "ghaṇḍa": ['mw'],
    "ghaṇṭ": ['mw'],
    "ghaṇṭa": ['bhs', 'mw'],
    "ghaṇṭaka": ['mw'],
    "ghaṇṭeśvara": ['mw'],
    "ghaṇṭi": ['mw'],
    "ghaṇṭika": ['cae', 'ddsa', 'mw'],
    "ghaṇṭikoṇa": ['mw'],
    "ghaṇṭikā": ['bhs', 'mw'],
    "ghaṇṭin": ['cae', 'mw'],
    "ghaṇṭinībīja": ['mw'],
    "ghaṇṭodara": ['mw'],
    "ghaṇṭu": ['mw'],
    "ghaṇṭā": ['cae', 'ddsa', 'mw'],
    "ghaṇṭābha": ['mw'],
    "ghaṇṭābīja": ['mw'],
    "ghaṇṭāka": ['bhs', 'mw'],
    "ghaṇṭākarṇa": ['cae', 'mw'],
    "ghaṇṭākarṇeśvara": ['mw'],
    "ghaṇṭākarṇī": ['mw'],
    "ghaṇṭāli": ['mw'],
    "ghaṇṭāmaṇḍapa": ['mw'],
    "ghaṇṭāmudrā": ['mw'],
    "ghaṇṭāmukha": ['mw'],
    "ghaṇṭānāda": ['mw'],
    "ghaṇṭāpatha": ['cae', 'mw'],
    "ghaṇṭāpathatva": ['mw'],
    "ghaṇṭāpāṭali": ['mw'],
    "ghaṇṭārava": ['cae', 'mw'],
    "ghaṇṭāravā": ['mw'],
    "ghaṇṭārāva": ['cae', 'mw'],
    "ghaṇṭāsvana": ['mw'],
    "ghaṇṭātāḍa": ['cae', 'mw'],
    "ghaṇṭātāḍana": ['mw'],
    "ghaṇṭāvant": ['cae'],
    "ghaṇṭāvat": ['mw'],
    "ghaṇṭāvādya": ['mw'],
    "ghaṇṭāśabda": ['mw'],
    "ghaṇṭāśabdapāṇi": ['mw'],
    "ghaṇṭī": ['mw'],
    "ghaṭ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ghaṭa": ['cae', 'cped', 'ddsa', 'mw'],
    "ghaṭa(t)": ['cped'],
    "ghaṭabhava": ['mw'],
    "ghaṭabhedanaka": ['bhs', 'mw'],
    "ghaṭadāsī": ['mw'],
    "ghaṭaghātinī": ['mw'],
    "ghaṭagraha": ['mw'],
    "ghaṭajanman": ['mw'],
    "ghaṭajānu": ['mw'],
    "ghaṭajānuka": ['mw'],
    "ghaṭaka": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "ghaṭakarkaṭatāla": ['mw'],
    "ghaṭakarpara": ['cae', 'mw'],
    "ghaṭakarparakulakavṛtti": ['mw'],
    "ghaṭakañcuki": ['mw'],
    "ghaṭakāra": ['cae', 'mw'],
    "ghaṭakṛt": ['cae', 'mw'],
    "ghaṭana": ['cae', 'ddsa', 'mw'],
    "ghaṭanaṃ": ['ap90'],
    "ghaṭanā": ['mw'],
    "ghaṭaprakṣayaṇa": ['mw'],
    "ghaṭapuccha": ['mw'],
    "ghaṭarāja": ['mw'],
    "ghaṭasthāpana": ['mw'],
    "ghaṭasṛñjaya": ['mw'],
    "ghaṭatantra": ['mw'],
    "ghaṭati": ['cped'],
    "ghaṭayati": ['cped'],
    "ghaṭayitavya": ['ddsa', 'mw'],
    "ghaṭayoni": ['mw'],
    "ghaṭaśodhanakāraka": ['mw'],
    "ghaṭaśrotra": ['mw'],
    "ghaṭaḥ": ['ap90'],
    "ghaṭeti": ['cped'],
    "ghaṭeśvara": ['mw'],
    "ghaṭi": ['bhs', 'cped', 'mw'],
    "ghaṭighaṭa": ['mw'],
    "ghaṭighaṭaḥ": ['ap90'],
    "ghaṭika": ['mw'],
    "ghaṭikalagna": ['mw'],
    "ghaṭikaḥ": ['ap90'],
    "ghaṭikā": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "ghaṭikālavaṇa": ['mw'],
    "ghaṭikāmaṇḍala": ['mw'],
    "ghaṭikāra": ['bhs'],
    "ghaṭikāyantra": ['mw'],
    "ghaṭila": ['mw'],
    "ghaṭin": ['ap90', 'mw'],
    "ghaṭita": ['ap90', 'cped', 'mw'],
    "ghaṭitabba": ['cped'],
    "ghaṭitatva": ['mw'],
    "ghaṭiyantra": ['mw'],
    "ghaṭiṃdhama": ['ap90', 'mw'],
    "ghaṭiṃdhaya": ['ap90', 'mw'],
    "ghaṭodara": ['mw'],
    "ghaṭodbhava": ['mw'],
    "ghaṭodhnī": ['mw'],
    "ghaṭotkaca": ['cae', 'ddsa', 'mw'],
    "ghaṭotkacaḥ": ['ap90'],
    "ghaṭotkacāntaka": ['mw'],
    "ghaṭā": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "ghaṭābha": ['mw'],
    "ghaṭābhidhā": ['mw'],
    "ghaṭādi": ['ddsa'],
    "ghaṭāhvayā": ['mw'],
    "ghaṭāla": ['mw'],
    "ghaṭālābu": ['mw'],
    "ghaṭārgalayantra": ['mw'],
    "ghaṭāvasthā": ['mw'],
    "ghaṭāśiras": ['bhs'],
    "ghaṭāṭopa": ['mw'],
    "ghaṭī": ['ap90', 'ddsa', 'mw'],
    "ghaṭīghaṭa": ['mw'],
    "ghaṭīgraha": ['mw'],
    "ghaṭīkara": ['mw'],
    "ghaṭīkā": ['mw'],
    "ghaṭīkāra": ['mw'],
    "ghaṭīkārī": ['mw'],
    "ghaṭīmāla": ['mw'],
    "ghaṭīyantra": ['cae', 'mw'],
    "ghaṭīyantraka": ['mw'],
    "ghaṭṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghaṭṭa": ['bhs', 'cae', 'ddsa', 'mw'],
    "ghaṭṭagā": ['mw'],
    "ghaṭṭajīvin": ['cae', 'mw'],
    "ghaṭṭakuṭīprabhātāyita": ['mw'],
    "ghaṭṭana": ['cae', 'ddsa', 'mw'],
    "ghaṭṭanaṃ": ['ap90'],
    "ghaṭṭanā": ['ap90', 'mw'],
    "ghaṭṭayanta": ['cped'],
    "ghaṭṭayati": ['cped'],
    "ghaṭṭaḥ": ['ap90'],
    "ghaṭṭenta": ['cped'],
    "ghaṭṭesi": ['cped'],
    "ghaṭṭetabba": ['cped'],
    "ghaṭṭeti": ['cped'],
    "ghaṭṭetvā": ['cped'],
    "ghaṭṭita": ['ap90', 'bhs', 'cped', 'mw'],
    "ghaṭṭitā": ['mw'],
    "ghaṭṭitṛ": ['mw'],
    "ghaṭṭā": ['mw'],
    "ghaṭṭānanda": ['mw'],
    "ghaṭṭāpenta": ['cped'],
    "ghaṭṭī": ['mw'],
    "ghed": ['cae', 'ddsa'],
    "gheñculikā": ['mw'],
    "gheñculī": ['mw'],
    "ghiṇṇ": ['mw'],
    "ghna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ghnat": ['ddsa', 'mw'],
    "ghnu": ['mw'],
    "ghnya": ['mw'],
    "ghnī": ['ddsa', 'mw'],
    "ghol": ['mw'],
    "ghola": ['cae', 'ddsa', 'mw'],
    "gholaya": ['ddsa'],
    "gholaḥ": ['ap90'],
    "gholi": ['mw'],
    "gholikā": ['mw'],
    "gholī": ['mw'],
    "ghonasa": ['mw'],
    "ghonasaḥ": ['ap90'],
    "ghora": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ghoracakṣas": ['gra', 'mw'],
    "ghoracakṣus": ['gra'],
    "ghoracaṇḍī": ['bhs'],
    "ghoradarśana": ['cae', 'mw'],
    "ghoraghoratara": ['mw'],
    "ghoraghuṣya": ['mw'],
    "ghorahṛdaya": ['mw'],
    "ghoraka": ['mw'],
    "ghoram": ['mw'],
    "ghorapuṣpa": ['mw'],
    "ghorarāsana": ['mw'],
    "ghorarāsin": ['mw'],
    "ghorarūpa": ['cae', 'mw'],
    "ghorarūpin": ['mw'],
    "ghorarūpā": ['mw'],
    "ghorarūpī": ['bhs'],
    "ghorasaṃkāśa": ['mw'],
    "ghorasaṃsparśa": ['mw'],
    "ghorasvara": ['mw'],
    "ghoratara": ['mw'],
    "ghoratva": ['mw'],
    "ghoratā": ['cae', 'ddsa', 'mw'],
    "ghoravarpas": ['cae', 'gra', 'mw'],
    "ghoravisa": ['cped'],
    "ghoravāluka": ['mw'],
    "ghoravāśana": ['mw'],
    "ghoravāśin": ['mw'],
    "ghoravāśinī": ['mw'],
    "ghorikā": ['mw'],
    "ghorita": ['mw'],
    "ghorā": ['mw'],
    "ghorādhyāpaka": ['mw'],
    "ghorākāra": ['cae', 'ddsa', 'mw'],
    "ghorākṛti": ['cae', 'mw'],
    "ghorātighora": ['mw'],
    "ghorāśaya": ['mw'],
    "ghorī": ['bhs', 'mw'],
    "ghosa": ['cped'],
    "ghosappamāṇa": ['cped'],
    "ghosita": ['cped'],
    "ghotkāra": ['mw'],
    "ghoḍa": ['mw'],
    "ghoḍeśvaratīrtha": ['mw'],
    "ghoḍācolin": ['mw'],
    "ghoṃghaḥ": ['ap90'],
    "ghoṃṭā": ['ap90'],
    "ghoṅgha": ['mw'],
    "ghoṇaka": ['mw'],
    "ghoṇasa": ['mw'],
    "ghoṇasaḥ": ['ap90'],
    "ghoṇika": ['mw'],
    "ghoṇin": ['ap90', 'mw'],
    "ghoṇā": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghoṇāntabhedana": ['mw'],
    "ghoṇṭā": ['mw'],
    "ghoṇṭāphala": ['mw'],
    "ghoṇṭī": ['mw'],
    "ghoṣa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ghoṣabuddha": ['mw'],
    "ghoṣad": ['mw'],
    "ghoṣadatta": ['bhs'],
    "ghoṣaka": ['ddsa', 'mw'],
    "ghoṣakaḥ": ['ap90'],
    "ghoṣakoṭi": ['mw'],
    "ghoṣakākṛti": ['mw'],
    "ghoṣakṛt": ['mw'],
    "ghoṣamati": ['bhs', 'mw'],
    "ghoṣasthalī": ['mw'],
    "ghoṣavadādi": ['mw'],
    "ghoṣavant": ['cae'],
    "ghoṣavarṇa": ['mw'],
    "ghoṣavasu": ['mw'],
    "ghoṣavat": ['ap90', 'ddsa', 'mw'],
    "ghoṣavatī": ['mw'],
    "ghoṣavṛddha": ['mw'],
    "ghoṣayitnu": ['ap90', 'mw'],
    "ghoṣayātrā": ['mw'],
    "ghoṣayātrāparvan": ['mw'],
    "ghoṣaśrī": ['bhs'],
    "ghoṣaḥ": ['ap90'],
    "ghoṣaṇa": ['cae', 'ddsa', 'mw'],
    "ghoṣaṇasthāna": ['cae'],
    "ghoṣaṇaṃ": ['ap90'],
    "ghoṣaṇā": ['mw'],
    "ghoṣaṇīya": ['mw'],
    "ghoṣeśvara": ['bhs'],
    "ghoṣi": ['cae', 'ddsa', 'gra', 'mw'],
    "ghoṣila": ['bhs', 'mw'],
    "ghoṣilārāma": ['bhs'],
    "ghoṣin": ['cae', 'mw'],
    "ghoṣita": ['mw'],
    "ghoṣiṇī": ['mw'],
    "ghoṣā": ['gra', 'mw'],
    "ghoṣādi": ['mw'],
    "ghoṣādī": ['mw'],
    "ghoṣānana": ['bhs'],
    "ghoṣānuga": ['bhs'],
    "ghoṣātakī": ['mw'],
    "ghoṣṭṛ": ['cae', 'mw'],
    "ghoṣṭṛtva": ['mw'],
    "ghoṣṭṭa": ['ddsa'],
    "ghoṭa": ['cae', 'ddsa', 'mw'],
    "ghoṭagala": ['mw'],
    "ghoṭaka": ['cae', 'mw'],
    "ghoṭakamukha": ['mw'],
    "ghoṭakamukhī": ['mw'],
    "ghoṭakamṛga": ['bhs'],
    "ghoṭakāri": ['mw'],
    "ghoṭaḥ": ['ap90'],
    "ghoṭikā": ['mw'],
    "ghoṭī": ['ap90'],
    "ghraṃs": ['cae', 'ddsa', 'mw'],
    "ghraṃsa": ['cae', 'gra', 'mw'],
    "ghraṃsaḥ": ['ap90'],
    "ghreya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghrā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ghrāta": ['ap90', 'mw'],
    "ghrātavya": ['ap90', 'ddsa', 'mw'],
    "ghrāti": ['cae', 'mw'],
    "ghrātiḥ": ['ap90'],
    "ghrātṛ": ['cae', 'mw'],
    "ghrāṃ": ['mw'],
    "ghrāṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghrāṇabila": ['mw'],
    "ghrāṇacakṣus": ['mw'],
    "ghrāṇaduḥkhadā": ['mw'],
    "ghrāṇaja": ['mw'],
    "ghrāṇapuṭaka": ['mw'],
    "ghrāṇapāka": ['mw'],
    "ghrāṇaskanda": ['mw'],
    "ghrāṇatarpaṇa": ['mw'],
    "ghrāṇaśravas": ['mw'],
    "ghrāṇendriya": ['mw'],
    "ghrāṇā": ['mw'],
    "ghu": ['ap90', 'ddsa', 'mw'],
    "ghughu": ['mw'],
    "ghughukṛt": ['mw'],
    "ghughulārava": ['mw'],
    "ghuka": ['mw'],
    "ghulaghulārava": ['mw'],
    "ghulaghulāravaḥ": ['ap90'],
    "ghulañca": ['mw'],
    "ghum": ['mw'],
    "ghumaghumā": ['mw'],
    "ghumaghumākāra": ['mw'],
    "ghumaghumārava": ['mw'],
    "ghumaghumāya": ['ddsa', 'mw'],
    "ghur": ['ap90', 'mw'],
    "ghuraghurā": ['mw'],
    "ghuraghurāghoṣa": ['mw'],
    "ghuraghurārāva": ['mw'],
    "ghuraghurāy": ['cae'],
    "ghuraghurāya": ['ddsa', 'mw'],
    "ghuraghurāyate": ['ap90'],
    "ghuraṇa": ['mw'],
    "ghuraṇaḥ": ['ap90'],
    "ghurghura": ['mw'],
    "ghurghuraka": ['mw'],
    "ghurghurakaḥ": ['ap90'],
    "ghurghuratā": ['mw'],
    "ghurghuraḥ": ['ap90'],
    "ghurghurikā": ['mw'],
    "ghurghuruka": ['mw'],
    "ghurghurā": ['mw'],
    "ghurghurāya": ['mw'],
    "ghurghurāyate": ['ap90'],
    "ghurghurī": ['ap90', 'mw'],
    "ghurikā": ['mw'],
    "ghurughurupassāsi(n)": ['cped'],
    "ghurughurā": ['mw'],
    "ghurughurāghoranirghoṣa": ['mw'],
    "ghurughurāghoṣa": ['mw'],
    "ghurī": ['ap90'],
    "ghusṛṇa": ['mw'],
    "ghusṛṇaṃ": ['ap90'],
    "ghutkāra": ['mw'],
    "ghutkāravat": ['ddsa'],
    "ghuśmeśa": ['mw'],
    "ghuḍ": ['ap90', 'mw'],
    "ghuḥ": ['ap90'],
    "ghuṃḍaḥ": ['ap90'],
    "ghuṃṭaḥ": ['ap90'],
    "ghuṃṭikaṃ": ['ap90'],
    "ghuṅghuma": ['mw'],
    "ghuṇ": ['ap90', 'mw'],
    "ghuṇa": ['cae', 'ddsa', 'mw'],
    "ghuṇaghuṇāyate": ['bhs'],
    "ghuṇajarjara": ['mw'],
    "ghuṇakīṭaka": ['cae', 'mw'],
    "ghuṇakṣata": ['mw'],
    "ghuṇapriyā": ['mw'],
    "ghuṇavallabhā": ['mw'],
    "ghuṇaḥ": ['ap90'],
    "ghuṇi": ['mw'],
    "ghuṇākṣara": ['cae', 'mw'],
    "ghuṇākṣaranyāya": ['mw'],
    "ghuṇākṣaravat": ['mw'],
    "ghuṇḍa": ['mw'],
    "ghuṇṇ": ['mw'],
    "ghuṇṭa": ['mw'],
    "ghuṇṭaka": ['mw'],
    "ghuṇṭika": ['mw'],
    "ghuṇṭikā": ['mw'],
    "ghuṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ghuṣa": ['ap90', 'mw'],
    "ghuṣita": ['ap90', 'mw'],
    "ghuṣya": ['mw'],
    "ghuṣṭa": ['mw'],
    "ghuṣṭasvara": ['ddsa'],
    "ghuṣṭra": ['mw'],
    "ghuṣṭraṃ": ['ap90'],
    "ghuṣṭānna": ['cae', 'mw'],
    "ghuṭ": ['ap90', 'ddsa', 'mw'],
    "ghuṭa": ['mw'],
    "ghuṭaḥ": ['ap90'],
    "ghuṭi": ['mw'],
    "ghuṭika": ['mw'],
    "ghuṭikā": ['mw'],
    "ghuṭī": ['mw'],
    "ghuṭṭi": ['mw'],
    "ghā": ['mw'],
    "ghānya": ['mw'],
    "ghāra": ['mw'],
    "ghāraḥ": ['ap90'],
    "ghārikā": ['mw'],
    "ghārteya": ['mw'],
    "ghārtika": ['ddsa', 'mw'],
    "ghārtikaḥ": ['ap90'],
    "ghārī": ['mw'],
    "ghāsa": ['cae', 'cped', 'ddsa', 'mw'],
    "ghāsacchāda": ['cped'],
    "ghāsacchādaparama": ['cped'],
    "ghāsahāraka": ['cped'],
    "ghāsaka": ['mw'],
    "ghāsakunda": ['mw'],
    "ghāsakundika": ['mw'],
    "ghāsakūṭa": ['mw'],
    "ghāsasthāna": ['mw'],
    "ghāsaḥ": ['ap90'],
    "ghāseajra": ['mw'],
    "ghāsesana": ['cped'],
    "ghāsesanā": ['cped'],
    "ghāsi": ['cae', 'gra', 'mw'],
    "ghāsiḥ": ['ap90'],
    "ghāta": ['cae', 'cped', 'ddsa', 'mw'],
    "ghātacandra": ['mw'],
    "ghātaka": ['ap90', 'cae', 'cped', 'mw'],
    "ghātakara": ['mw'],
    "ghātakṛcchra": ['mw'],
    "ghātana": ['ap90', 'cae', 'mw'],
    "ghātanakṣatra": ['mw'],
    "ghātanasthāna": ['mw'],
    "ghātanī": ['bhs', 'mw'],
    "ghātasthāna": ['mw'],
    "ghātatithi": ['mw'],
    "ghātavāra": ['mw'],
    "ghātay": ['cae'],
    "ghātaya": ['ddsa', 'mw'],
    "ghātayati": ['cped'],
    "ghātaye": ['cped'],
    "ghātayeyya": ['cped'],
    "ghātayi": ['cped'],
    "ghātaḥ": ['ap90'],
    "ghātenta": ['cped'],
    "ghātessāmi": ['cped'],
    "ghāteta(r)": ['cped'],
    "ghāteti": ['cped'],
    "ghātetuṁ": ['cped'],
    "ghātetāya": ['cped'],
    "ghāti": ['cped', 'mw'],
    "ghātikā": ['bhs'],
    "ghātin": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghātinī": ['mw'],
    "ghātipakṣin": ['mw'],
    "ghātitva": ['mw'],
    "ghātivihaga": ['mw'],
    "ghātiḥ": ['ap90'],
    "ghātuka": ['ap90', 'cae', 'mw'],
    "ghātvā": ['cped'],
    "ghātya": ['ap90', 'cae', 'mw'],
    "ghātyā": ['bhs'],
    "ghātāpeti": ['cped'],
    "ghātīkā": ['cped'],
    "ghāya(t)": ['cped'],
    "ghāyati": ['cped'],
    "ghāyita": ['cped'],
    "ghāyitvā": ['cped'],
    "ghāṃṭikaḥ": ['ap90'],
    "ghāṇa": ['cped'],
    "ghāṇadhatu": ['cped'],
    "ghāṇaviññeyya": ['cped'],
    "ghāṇindriya": ['cped'],
    "ghāṇāyatana": ['cped'],
    "ghāṇṭika": ['mw'],
    "ghāṭa": ['mw'],
    "ghāṭaka": ['bhs', 'mw'],
    "ghāṭakarkarī": ['mw'],
    "ghāṭala": ['mw'],
    "ghāṭalikā": ['mw'],
    "ghāṭarī": ['mw'],
    "ghāṭaḥ": ['ap90'],
    "ghāṭika": ['mw'],
    "ghāṭikā": ['bhs', 'mw'],
    "ghāṭin": ['bhs'],
    "ghāṭā": ['mw'],
    "ghāṭāla": ['mw'],
    "ghūka": ['cae', 'ddsa', 'mw'],
    "ghūkaḥ": ['ap90'],
    "ghūkāri": ['mw'],
    "ghūkāvāsa": ['mw'],
    "ghūr": ['ap90', 'mw'],
    "ghūrṇ": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghūrṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghūrṇana": ['cae', 'mw'],
    "ghūrṇanaṃ": ['ap90'],
    "ghūrṇanā": ['mw'],
    "ghūrṇavāyu": ['mw'],
    "ghūrṇi": ['mw'],
    "ghūrṇikā": ['cae', 'mw'],
    "ghūrṇiḥ": ['ap90'],
    "ghūrṇāyamāna": ['mw'],
    "ghūtkāra": ['cae', 'ddsa', 'mw'],
    "ghūtkāraḥ": ['ap90'],
    "ghṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghṛta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ghṛtaanna": ['gra'],
    "ghṛtabhājana": ['mw'],
    "ghṛtabhṛṣṭa": ['mw'],
    "ghṛtacyutā": ['mw'],
    "ghṛtadhenu": ['mw'],
    "ghṛtadhārā": ['mw'],
    "ghṛtaduh": ['gra', 'mw'],
    "ghṛtadānapaddhati": ['mw'],
    "ghṛtadīdhiti": ['mw'],
    "ghṛtaghaṭa": ['cae', 'mw'],
    "ghṛtahasta": ['gra', 'mw'],
    "ghṛtahetu": ['mw'],
    "ghṛtahoma": ['mw'],
    "ghṛtahrada": ['mw'],
    "ghṛtakambala": ['mw'],
    "ghṛtakarañja": ['mw'],
    "ghṛtakauśika": ['mw'],
    "ghṛtakeśa": ['gra', 'mw'],
    "ghṛtakulyā": ['mw'],
    "ghṛtakumbha": ['cae', 'mw'],
    "ghṛtakumārikā": ['mw'],
    "ghṛtakumārī": ['mw'],
    "ghṛtakuṇḍika": ['bhs'],
    "ghṛtakīrti": ['ddsa', 'mw'],
    "ghṛtakṣaudravat": ['mw'],
    "ghṛtalekhanī": ['mw'],
    "ghṛtalekhinī": ['mw'],
    "ghṛtalolīkṛta": ['mw'],
    "ghṛtamadhumaya": ['mw'],
    "ghṛtamaya": ['mw'],
    "ghṛtamaṇḍa": ['mw'],
    "ghṛtamaṇḍalikā": ['mw'],
    "ghṛtamaṇḍoda": ['mw'],
    "ghṛtamaṇḍā": ['mw'],
    "ghṛtaminva": ['mw'],
    "ghṛtanidhāyam": ['mw'],
    "ghṛtanirṇij": ['cae', 'gra', 'mw'],
    "ghṛtapa": ['mw'],
    "ghṛtapad": ['gra'],
    "ghṛtapadī": ['mw'],
    "ghṛtapakva": ['mw'],
    "ghṛtapakvā": ['mw'],
    "ghṛtaparṇa": ['mw'],
    "ghṛtaparṇaka": ['mw'],
    "ghṛtapaśu": ['cae', 'mw'],
    "ghṛtapluta": ['mw'],
    "ghṛtaprasatta": ['gra', 'mw'],
    "ghṛtapratīka": ['cae', 'gra', 'mw'],
    "ghṛtaprayas": ['gra', 'mw'],
    "ghṛtapruṣ": ['cae', 'gra', 'mw'],
    "ghṛtaprāśa": ['cae', 'mw'],
    "ghṛtaprāśana": ['mw'],
    "ghṛtaprī": ['mw'],
    "ghṛtapāka": ['mw'],
    "ghṛtapātrastanavatī": ['mw'],
    "ghṛtapāvan": ['mw'],
    "ghṛtapīta": ['mw'],
    "ghṛtapū": ['gra', 'mw'],
    "ghṛtapūra": ['mw'],
    "ghṛtapūrṇa": ['mw'],
    "ghṛtapūrṇaka": ['mw'],
    "ghṛtapṛc": ['gra', 'mw'],
    "ghṛtapṛkta": ['mw'],
    "ghṛtapṛṣṭha": ['cae', 'gra', 'mw'],
    "ghṛtarauḍhīya": ['mw'],
    "ghṛtasad": ['mw'],
    "ghṛtasamudra": ['mw'],
    "ghṛtasnu": ['cae', 'gra', 'mw'],
    "ghṛtasnā": ['cae', 'gra', 'mw'],
    "ghṛtaspṛś": ['mw'],
    "ghṛtasthalā": ['mw'],
    "ghṛtasto": ['mw'],
    "ghṛtastoka": ['mw'],
    "ghṛtastomya": ['mw'],
    "ghṛtastomīya": ['mw'],
    "ghṛtastuti": ['mw'],
    "ghṛtastū": ['mw'],
    "ghṛtatva": ['mw'],
    "ghṛtaudana": ['ddsa', 'mw'],
    "ghṛtavant": ['cae'],
    "ghṛtavara": ['mw'],
    "ghṛtavaradvīpa": ['mw'],
    "ghṛtavartani": ['cae', 'gra', 'mw'],
    "ghṛtavarti": ['mw'],
    "ghṛtavat": ['ap90', 'gra', 'mw'],
    "ghṛtavatsa": ['mw'],
    "ghṛtavatī": ['mw'],
    "ghṛtavikrayin": ['mw'],
    "ghṛtavrata": ['mw'],
    "ghṛtavṛddha": ['mw'],
    "ghṛtayoni": ['gra', 'mw'],
    "ghṛtayājyā": ['mw'],
    "ghṛtaścunnidhana": ['mw'],
    "ghṛtaścut": ['cae', 'gra', 'mw'],
    "ghṛtaścyunnidhana": ['mw'],
    "ghṛtaścyut": ['mw'],
    "ghṛtaśrī": ['gra', 'mw'],
    "ghṛtelī": ['ap90', 'mw'],
    "ghṛteyu": ['mw'],
    "ghṛteṣṭakā": ['ddsa', 'mw'],
    "ghṛtin": ['ap90', 'mw'],
    "ghṛtoda": ['mw'],
    "ghṛtodaṅka": ['mw'],
    "ghṛtya": ['cae', 'ddsa', 'mw'],
    "ghṛtā": ['mw'],
    "ghṛtābdhi": ['mw'],
    "ghṛtāc": ['gra'],
    "ghṛtācala": ['mw'],
    "ghṛtāci": ['mw'],
    "ghṛtācī": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghṛtācīgarbhasambhavā": ['mw'],
    "ghṛtādi": ['mw'],
    "ghṛtāhavana": ['cae', 'gra', 'mw'],
    "ghṛtāhuta": ['cae', 'mw'],
    "ghṛtāhuti": ['cae', 'mw'],
    "ghṛtāhva": ['mw'],
    "ghṛtāhvaya": ['mw'],
    "ghṛtākta": ['cae', 'ddsa', 'mw'],
    "ghṛtānna": ['cae', 'ddsa', 'gra', 'mw'],
    "ghṛtānuṣikta": ['mw'],
    "ghṛtānvakta": ['mw'],
    "ghṛtārcis": ['mw'],
    "ghṛtāsuti": ['cae', 'gra', 'mw'],
    "ghṛtāvani": ['mw'],
    "ghṛtāvṛdh": ['gra', 'mw'],
    "ghṛṅ": ['mw'],
    "ghṛṅkarikra": ['mw'],
    "ghṛṇ": ['ap90', 'mw'],
    "ghṛṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "ghṛṇaḥ": ['ap90'],
    "ghṛṇi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ghṛṇin": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghṛṇita": ['mw'],
    "ghṛṇitva": ['cae', 'ddsa', 'mw'],
    "ghṛṇā": ['ap90', 'gra', 'mw'],
    "ghṛṇācakṣus": ['mw'],
    "ghṛṇālu": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghṛṇārcis": ['mw'],
    "ghṛṇāvat": ['mw'],
    "ghṛṇāvāsa": ['mw'],
    "ghṛṇīvant": ['cae'],
    "ghṛṇīvat": ['gra', 'mw'],
    "ghṛṇṇ": ['mw'],
    "ghṛṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "ghṛṣu": ['cae', 'ddsa', 'gra', 'mw'],
    "ghṛṣvi": ['cae', 'gra', 'mw'],
    "ghṛṣvirādhas": ['cae', 'gra', 'mw'],
    "ghṛṣviḥ": ['ap90'],
    "ghṛṣṭa": ['ap90', 'mw'],
    "ghṛṣṭhilā": ['mw'],
    "ghṛṣṭi": ['mw'],
    "ghṛṣṭinetra": ['mw'],
    "ghṛṣṭiḥ": ['ap90'],
    "gida": ['mw'],
    "giddha": ['cped'],
    "giddhilobha": ['cped'],
    "giddhilobhi(n)": ['cped'],
    "giddhimāna": ['cped'],
    "gidhra": ['mw'],
    "giha": ['cped'],
    "gihi(d)dhaja": ['cped'],
    "gihi(n)": ['cped'],
    "gihibandhana": ['cped'],
    "gihigata": ['cped'],
    "gihiliṅga": ['cped'],
    "gihinivattha": ['cped'],
    "gihinivattham": ['cped'],
    "gihinī": ['cped'],
    "gihipatirūpakara": ['cped'],
    "gihipāruta": ['cped'],
    "gihipārutam": ['cped'],
    "gihisaṁyojana": ['cped'],
    "gihivikata": ['cped'],
    "gihivikaṭa": ['cped'],
    "gihivyañjana": ['cped'],
    "gihī": ['cped'],
    "gihīgata": ['cped'],
    "gihīsaṁyojana": ['cped'],
    "gijjha": ['cped'],
    "gijjhita": ['cped'],
    "gil": ['ap90', 'ddsa'],
    "gila": ['ap90', 'mw'],
    "gila(t)": ['cped'],
    "gilabaḷisa": ['cped'],
    "gilagila": ['mw'],
    "gilagrāha": ['mw'],
    "gilana": ['mw'],
    "gilanaṃ": ['ap90'],
    "gilanta": ['cped'],
    "gilat": ['mw'],
    "gilati": ['cped'],
    "gili": ['mw'],
    "gilita": ['ap90', 'mw'],
    "gilituṁ": ['cped'],
    "gilitvā": ['cped'],
    "gillapeṭṭa": ['bhs'],
    "giloḍya": ['mw'],
    "gilāna": ['bhs', 'cped'],
    "gilānaka": ['cped'],
    "gilānapaccaya": ['cped'],
    "gilānapucchaka": ['cped'],
    "gilānapucchikā": ['cped'],
    "gilānasālā": ['cped'],
    "gilānatiritta": ['cped'],
    "gilānupuṭṭhāka": ['cped'],
    "gilānālaya": ['cped'],
    "gilāyana": ['cped'],
    "gilāyu": ['mw'],
    "gilāyuḥ": ['ap90'],
    "gilī": ['cped'],
    "gimha": ['cped'],
    "gimhika": ['cped'],
    "gimhāna": ['cped'],
    "ginduka": ['mw'],
    "gini": ['cped'],
    "gir": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gira": ['cae', 'ddsa', 'mw'],
    "girapura": ['mw'],
    "giraukas": ['gra', 'mw'],
    "giraṇa": ['mw'],
    "giri": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "giriaggasamajja": ['cped'],
    "giribbaja": ['cped'],
    "giribhid": ['mw'],
    "giribhraj": ['gra', 'mw'],
    "giribhū": ['mw'],
    "giribudhna": ['mw'],
    "giribāndhava": ['mw'],
    "giricakravartin": ['mw'],
    "giricara": ['cae', 'mw'],
    "giricārin": ['mw'],
    "giridhara": ['mw'],
    "giridhvaja": ['mw'],
    "giridhātu": ['cae', 'mw'],
    "giriduhitṛ": ['mw'],
    "giridurga": ['cae', 'mw'],
    "giridvāra": ['mw'],
    "girigabbhara": ['cped'],
    "girigairikadhātu": ['mw'],
    "girigavhara": ['cped'],
    "girigaṅgā": ['mw'],
    "giriguhā": ['cped', 'mw'],
    "giriguḍa": ['mw'],
    "girihvā": ['mw'],
    "girija": ['cae', 'mw'],
    "girijvara": ['mw'],
    "girijvarasamudbhava": ['mw'],
    "girijā": ['cae', 'gra', 'mw'],
    "girijādevī": ['mw'],
    "girijādhava": ['mw'],
    "girijākumāra": ['mw'],
    "girijāla": ['mw'],
    "girijāmala": ['mw'],
    "girijāmāhātmya": ['mw'],
    "girijāpati": ['mw'],
    "girijāpriya": ['mw'],
    "girijāputra": ['mw'],
    "girika": ['bhs', 'mw'],
    "girikacchapa": ['mw'],
    "girikadalī": ['mw'],
    "girikadamba": ['mw'],
    "girikadambaka": ['mw'],
    "girikandara": ['mw'],
    "girikarṇikā": ['mw'],
    "girikarṇā": ['mw'],
    "girikarṇī": ['mw'],
    "girikaḥ": ['ap90'],
    "girikaṇṭaka": ['mw'],
    "girikuhara": ['ddsa', 'mw'],
    "girikā": ['mw'],
    "girikānana": ['cae', 'mw'],
    "girikāṇa": ['mw'],
    "girikūṭa": ['bhs', 'mw'],
    "girikṣipa": ['mw'],
    "girikṣit": ['cae', 'gra', 'mw'],
    "girilakṣmaṇa": ['mw'],
    "girimallikā": ['mw'],
    "girimaṇḍa": ['bhs'],
    "girimeda": ['mw'],
    "girimuddha(n)": ['cped'],
    "girimāla": ['mw'],
    "girimālaka": ['mw'],
    "girimāna": ['mw'],
    "girimātra": ['mw'],
    "girimṛd": ['mw'],
    "girimṛdbhava": ['mw'],
    "girinaddha": ['mw'],
    "girinadikā": ['mw'],
    "girinadyādi": ['mw'],
    "girinadī": ['cae', 'mw'],
    "girinagara": ['mw'],
    "girinakha": ['mw'],
    "girinandinī": ['mw'],
    "girinimba": ['mw'],
    "girinimnagā": ['mw'],
    "girinitamba": ['mw'],
    "giripara": ['mw'],
    "giripati": ['cae', 'mw'],
    "giripradīpa": ['bhs'],
    "giriprapāta": ['mw'],
    "giriprastha": ['cae', 'mw'],
    "giripriyā": ['mw'],
    "giripura": ['mw'],
    "giripuṣpaka": ['mw'],
    "giripīlu": ['mw'],
    "giripṛṣṭha": ['cae', 'mw'],
    "girirajaghoṣa": ['mw'],
    "girirajaghoṣeśvara": ['mw'],
    "girirakṣa": ['mw'],
    "girirakṣas": ['mw'],
    "girirāj": ['cae', 'mw'],
    "girirāja": ['bhs'],
    "girirājaghoṣa": ['bhs'],
    "girirājaghoṣeśvara": ['bhs'],
    "girirājakumāra": ['mw'],
    "girirūpa": ['mw'],
    "girisambhava": ['mw'],
    "girisarpa": ['mw'],
    "girisena": ['mw'],
    "girisravā": ['mw'],
    "giristanī": ['mw'],
    "girisuta": ['mw'],
    "girisutā": ['mw'],
    "girisutākānta": ['mw'],
    "girisānu": ['mw'],
    "girisāra": ['mw'],
    "girisāracandana": ['bhs'],
    "girisāramaya": ['mw'],
    "girita": ['ap90', 'mw'],
    "giritra": ['cae', 'mw'],
    "girivalgusamāgama": ['bhs'],
    "girivara": ['cae'],
    "girivartikā": ['mw'],
    "girivraja": ['mw'],
    "girivāsin": ['mw'],
    "giriyagrasamāja": ['bhs'],
    "giriyaka": ['mw'],
    "giriyakaḥ": ['ap90'],
    "giriyāka": ['mw'],
    "giriśa": ['cae', 'mw'],
    "giriśanta": ['mw'],
    "giriśarman": ['mw'],
    "giriśaya": ['mw'],
    "giriśaḥ": ['ap90'],
    "giriśikhara": ['mw'],
    "giriśā": ['mw'],
    "giriśālinī": ['mw'],
    "giriśāyikā": ['mw'],
    "giriśṛṅga": ['mw'],
    "giriṇaddha": ['mw'],
    "giriṇadī": ['cae', 'mw'],
    "giriṇakha": ['mw'],
    "giriṇitamba": ['mw'],
    "giriṣad": ['mw'],
    "giriṣṭhaa": ['gra'],
    "giriṣṭhā": ['cae', 'gra', 'mw'],
    "girvan": ['cae', 'gra', 'mw'],
    "girvavah": ['gra', 'mw'],
    "girvaṇas": ['cae', 'ddsa', 'gra', 'mw'],
    "girvaṇasyu": ['cae', 'gra', 'mw'],
    "girvāhas": ['gra', 'mw'],
    "giryagrasamāja": ['bhs'],
    "giryāhvā": ['mw'],
    "girā": ['ap90', 'bhs', 'cped', 'mw'],
    "girāvṛdh": ['gra', 'mw'],
    "girīkṛ": ['mw'],
    "girīndra": ['ddsa', 'mw'],
    "girīśa": ['cae', 'mw'],
    "girīśā": ['mw'],
    "gita": ['cped'],
    "giñjakāvasatha": ['cped'],
    "giḷati": ['cped'],
    "giṃdukaḥ": ['ap90'],
    "giṣṇu": ['mw'],
    "giṣṇuḥ": ['ap90'],
    "gla": ['mw'],
    "glah": ['ap90', 'cae', 'ddsa', 'mw'],
    "glaha": ['cae', 'ddsa', 'mw'],
    "glahana": ['cae', 'mw'],
    "glahaḥ": ['ap90'],
    "glahā": ['mw'],
    "glai": ['ap90', 'ddsa', 'mw'],
    "glap": ['cae', 'ddsa', 'mw'],
    "glapana": ['cae', 'ddsa', 'mw'],
    "glapanaṃ": ['ap90'],
    "glapaya": ['ddsa'],
    "glapita": ['mw'],
    "glapsa": ['cae', 'ddsa', 'mw'],
    "glas": ['ap90', 'mw'],
    "glasta": ['mw'],
    "glau": ['ap90', 'cae', 'ddsa', 'mw'],
    "glauas": ['mw'],
    "glaubhū": ['mw'],
    "glaucukāyana": ['mw'],
    "glaucukāyanaka": ['mw'],
    "glaukṛ": ['mw'],
    "glep": ['ap90', 'mw'],
    "glepana": ['mw'],
    "glev": ['ap90', 'mw'],
    "gleya": ['mw'],
    "gleṣ": ['ap90', 'mw'],
    "gluc": ['ap90', 'mw'],
    "glucuka": ['mw'],
    "glucukāyani": ['mw'],
    "gluntha": ['mw'],
    "gluñc": ['mw'],
    "gluṃc": ['ap90'],
    "glā": ['cae', 'gra', 'mw'],
    "glāna": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "glānaka": ['bhs'],
    "glānamanas": ['mw'],
    "glānapratyaya": ['mw'],
    "glāni": ['mw'],
    "glāniḥ": ['ap90'],
    "glānya": ['bhs', 'mw'],
    "glānīya": ['mw'],
    "glāpita": ['mw'],
    "glāsnu": ['ap90', 'cae', 'mw'],
    "glātu": ['mw'],
    "glātṛ": ['mw'],
    "glāva": ['mw'],
    "glāvin": ['cae', 'mw'],
    "glāyaka": ['mw'],
    "gman": ['cae', 'ddsa', 'gra', 'mw'],
    "gmat": ['ddsa'],
    "gmā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gnā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gnās": ['mw'],
    "gnāspati": ['cae', 'ddsa', 'gra', 'mw'],
    "gnāspatnī": ['cae', 'gra', 'mw'],
    "gnāvat": ['gra', 'mw'],
    "go": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "goagra": ['cae', 'ddsa', 'gra', 'mw'],
    "goajana": ['gra', 'mw'],
    "goapaśa": ['mw'],
    "goargha": ['mw'],
    "goarṇas": ['cae', 'gra', 'mw'],
    "goaśva": ['mw'],
    "goaśvīya": ['mw'],
    "gobaka": ['mw'],
    "gobala": ['mw'],
    "goballava": ['mw'],
    "gobalīvardanyāyena": ['mw'],
    "gobandhu": ['cae', 'gra', 'mw'],
    "gobhaga": ['mw'],
    "gobhartṛ": ['mw'],
    "gobhaṇḍīra": ['mw'],
    "gobhaṭṭa": ['mw'],
    "gobhila": ['cae', 'ddsa', 'mw'],
    "gobhilīya": ['mw'],
    "gobhuj": ['cae', 'ddsa', 'mw'],
    "gobhāj": ['cae', 'gra', 'mw'],
    "gobhānu": ['mw'],
    "gobhṛt": ['cae', 'mw'],
    "gobrāhmaṇa": ['cae', 'mw'],
    "gobrāhmaṇamanuṣya": ['mw'],
    "gobījakānana": ['cae'],
    "gobījakāñcana": ['mw'],
    "gocandana": ['cae', 'mw'],
    "gocandanā": ['mw'],
    "gocapalā": ['mw'],
    "gocara": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "gocaragata": ['mw'],
    "gocaragāma": ['cped'],
    "gocarapariśuddha": ['bhs'],
    "gocarapariśuddhisūtra": ['bhs'],
    "gocaraphala": ['mw'],
    "gocaraprakaraṇa": ['mw'],
    "gocarapīḍā": ['mw'],
    "gocaratva": ['mw'],
    "gocaratā": ['mw'],
    "gocaraya": ['mw'],
    "gocarika": ['bhs', 'mw'],
    "gocarin": ['bhs'],
    "gocariya": ['cped'],
    "gocarmamātra": ['mw'],
    "gocarman": ['mw'],
    "gocaryā": ['ddsa', 'mw'],
    "gocarādhyāya": ['mw'],
    "gocarāntaragata": ['mw'],
    "gocarī": ['bhs'],
    "gocarīkṛ": ['ddsa'],
    "gocarīkṛta": ['mw'],
    "gocchā": ['mw'],
    "gocchāla": ['mw'],
    "gociti": ['mw'],
    "gocāraka": ['mw'],
    "gocāraṇa": ['mw'],
    "gocārin": ['mw'],
    "goda": ['cae', 'ddsa', 'mw'],
    "godama": ['mw'],
    "godamaka": ['cped'],
    "godamma": ['cped'],
    "godanta": ['mw'],
    "godantamaṇi": ['mw'],
    "godari": ['gra', 'mw'],
    "godatra": ['gra'],
    "godattra": ['mw'],
    "godha": ['bhs', 'cae', 'ddsa', 'mw'],
    "godhana": ['cae', 'mw'],
    "godhara": ['mw'],
    "godharaṇī": ['cped'],
    "godharma": ['mw'],
    "godhenu": ['mw'],
    "godhera": ['mw'],
    "godheraka": ['mw'],
    "godheraḥ": ['ap90'],
    "godhi": ['mw'],
    "godhikā": ['ap90', 'ddsa', 'mw'],
    "godhikātmaja": ['mw'],
    "godhinī": ['mw'],
    "godhiḥ": ['ap90'],
    "godhuma": ['cped', 'mw'],
    "godhā": ['ap90', 'gra', 'mw'],
    "godhājātaka": ['bhs'],
    "godhāpadikā": ['mw'],
    "godhāpadī": ['mw'],
    "godhāra": ['mw'],
    "godhāskandha": ['mw'],
    "godhāsāman": ['mw'],
    "godhāvatī": ['mw'],
    "godhāvīṇākā": ['mw'],
    "godhāya": ['mw'],
    "godhāyas": ['gra', 'mw'],
    "godhāśana": ['mw'],
    "godhūli": ['mw'],
    "godhūlikā": ['mw'],
    "godhūma": ['cae', 'cped', 'ddsa', 'mw'],
    "godhūmacūrṇa": ['mw'],
    "godhūmaja": ['mw'],
    "godhūmaka": ['mw'],
    "godhūmasambhava": ['mw'],
    "godhūmasaṃcayamaya": ['mw'],
    "godhūmī": ['mw'],
    "godoha": ['bhs', 'cae', 'mw'],
    "godohaka": ['mw'],
    "godoham": ['mw'],
    "godohana": ['mw'],
    "godohanī": ['mw'],
    "godohikā": ['mw'],
    "godrava": ['mw'],
    "godugdha": ['mw'],
    "godugdhadā": ['mw'],
    "godugdhā": ['mw'],
    "goduh": ['cae', 'ddsa', 'gra', 'mw'],
    "goduha": ['mw'],
    "godā": ['cae', 'gra', 'mw'],
    "godāna": ['cae', 'mw'],
    "godānamaṅgala": ['mw'],
    "godānavidhi": ['mw'],
    "godānavrata": ['mw'],
    "godānika": ['mw'],
    "godānīya": ['bhs', 'mw'],
    "godāraṇa": ['mw'],
    "godāvarī": ['cae', 'ddsa', 'mw'],
    "godāvarīmāhātmya": ['mw'],
    "godāvarīsaṃgama": ['mw'],
    "godāvarītīrtha": ['mw'],
    "godāya": ['mw'],
    "gogamana": ['mw'],
    "gogati": ['mw'],
    "gogaṇa": ['mw'],
    "goghaṁsīka": ['cped'],
    "goghna": ['cae', 'gra', 'mw'],
    "goghnata": ['mw'],
    "goghāsa": ['mw'],
    "goghāta": ['mw'],
    "goghātaka": ['bhs', 'cped', 'mw'],
    "goghātin": ['mw'],
    "goghṛta": ['mw'],
    "gogoṣṭha": ['mw'],
    "gograha": ['mw'],
    "gograhatīrtha": ['mw'],
    "gogranthi": ['mw'],
    "gogrāsa": ['mw'],
    "gogṛṣṭi": ['mw'],
    "goha": ['cae', 'ddsa', 'gra', 'mw'],
    "gohan": ['cae', 'gra', 'mw'],
    "gohana": ['gra', 'mw'],
    "gohanaṃ": ['ap90'],
    "gohantṛ": ['cae', 'mw'],
    "gohanuka": ['cped'],
    "gohara": ['mw'],
    "goharaṇa": ['mw'],
    "goharītakī": ['mw'],
    "gohata": ['cped'],
    "gohatyā": ['cae', 'ddsa', 'mw'],
    "gohaḥ": ['ap90'],
    "gohi": ['mw'],
    "gohila": ['mw'],
    "gohilla": ['mw'],
    "gohira": ['mw'],
    "gohiraṃ": ['ap90'],
    "gohiraṇya": ['mw'],
    "gohita": ['mw'],
    "gohiṃsā": ['mw'],
    "gohya": ['mw'],
    "gohāliyā": ['mw'],
    "gojala": ['mw'],
    "gojara": ['mw'],
    "gojavāja": ['mw'],
    "goji": ['mw'],
    "gojihvikā": ['mw'],
    "gojihvā": ['mw'],
    "gojika": ['mw'],
    "gojikā": ['mw'],
    "gojikāya": ['mw'],
    "gojit": ['gra', 'mw'],
    "gojā": ['cae', 'gra', 'mw'],
    "gojāgarika": ['mw'],
    "gojāparṇī": ['mw'],
    "gojāta": ['cae', 'ddsa', 'gra', 'mw'],
    "gojī": ['mw'],
    "gojīra": ['gra', 'mw'],
    "gojīva": ['mw'],
    "gokakṣa": ['mw'],
    "gokarman": ['mw'],
    "gokarṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "gokarṇaliṅga": ['mw'],
    "gokarṇaśithila": ['mw'],
    "gokarṇeśa": ['mw'],
    "gokarṇeśaliṅga": ['mw'],
    "gokarṇeśvara": ['mw'],
    "gokarṇā": ['mw'],
    "gokarṇī": ['mw'],
    "gokaṇṭa": ['mw'],
    "gokaṇṭaka": ['bhs', 'mw'],
    "gokha": ['mw'],
    "gokhala": ['mw'],
    "gokhalu": ['mw'],
    "gokhalya": ['mw'],
    "gokhapiṅgali": ['mw'],
    "gokhura": ['mw'],
    "gokhuri": ['mw'],
    "gokila": ['mw'],
    "gokirāṭikā": ['mw'],
    "gokirāṭī": ['mw'],
    "gokula": ['cae', 'cped', 'mw'],
    "gokulajit": ['mw'],
    "gokulanātha": ['mw'],
    "gokulastha": ['mw'],
    "gokuleśa": ['mw'],
    "gokulika": ['mw'],
    "gokulodbhavā": ['mw'],
    "gokulāṣṭaka": ['mw'],
    "gokuñjara": ['mw'],
    "gokuṇika": ['mw'],
    "gokā": ['mw'],
    "gokāma": ['cae', 'gra', 'mw'],
    "gokāmukha": ['mw'],
    "gokāmyā": ['cae', 'mw'],
    "gokāṇā": ['cped'],
    "gokīla": ['mw'],
    "gokṛ": ['mw'],
    "gokṛcchra": ['mw'],
    "gokṛta": ['mw'],
    "gokṣoḍaka": ['mw'],
    "gokṣura": ['mw'],
    "gokṣuradugdhā": ['mw'],
    "gokṣuraka": ['mw'],
    "gokṣveḍa": ['mw'],
    "gokṣīra": ['cae', 'mw'],
    "gola": ['bhs', 'cae', 'ddsa', 'mw'],
    "golagola": ['mw'],
    "golagrāma": ['mw'],
    "golaka": ['bhs', 'cae', 'mw'],
    "golakaḥ": ['ap90'],
    "golakkhaṇa": ['cped'],
    "golakrīḍā": ['mw'],
    "golakṣaṇa": ['mw'],
    "golapuñja": ['mw'],
    "golattikā": ['mw'],
    "golava": ['mw'],
    "golavaṇa": ['mw'],
    "golayantra": ['mw'],
    "golaḥ": ['ap90'],
    "golhāṭa": ['mw'],
    "goliha": ['mw'],
    "golika": ['bhs'],
    "golikā": ['mw'],
    "golla": ['mw'],
    "goloka": ['mw'],
    "golokavarṇana": ['mw'],
    "golomakam": ['bhs'],
    "goloman": ['mw'],
    "golomi": ['cped'],
    "golomika": ['cped'],
    "golomikā": ['mw'],
    "golomī": ['mw'],
    "golunda": ['mw'],
    "golā": ['mw'],
    "golādhyāya": ['mw'],
    "golāmamāmuda": ['mw'],
    "golāsa": ['mw'],
    "golāsana": ['mw'],
    "golāsaḥ": ['ap90'],
    "golāvalī": ['mw'],
    "golāṅgula": ['mw'],
    "golāṅgulaparivartana": ['bhs', 'mw'],
    "golāṅgulī": ['mw'],
    "golāṅgūla": ['cae', 'ddsa', 'mw'],
    "golāṅka": ['mw'],
    "golīgulaparivartana": ['mw'],
    "golīḍha": ['mw'],
    "goma(t)": ['cped'],
    "gomacarcikā": ['mw'],
    "gomadhyamadhya": ['mw'],
    "gomagha": ['gra', 'mw'],
    "gomahiṣadā": ['mw'],
    "gomakṣikā": ['mw'],
    "gomanda": ['mw'],
    "gomant": ['cae'],
    "gomanta": ['mw'],
    "gomardana": ['bhs'],
    "gomat": ['ap90', 'ddsa', 'gra', 'mw'],
    "gomata": ['mw'],
    "gomatallikā": ['mw'],
    "gomatha": ['mw'],
    "gomati": ['mw'],
    "gomatsya": ['mw'],
    "gomatya": ['mw'],
    "gomatī": ['mw'],
    "gomatīputra": ['mw'],
    "gomatīsāra": ['mw'],
    "gomatītīrtha": ['mw'],
    "gomaya": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "gomayabhakkha": ['cped'],
    "gomayacchattra": ['mw'],
    "gomayacchattrikā": ['mw'],
    "gomayakārṣī": ['bhs', 'mw'],
    "gomayamaya": ['mw'],
    "gomayapriya": ['mw'],
    "gomayapāyasīyanyāyavat": ['mw'],
    "gomayodbhava": ['mw'],
    "gomayotthā": ['mw'],
    "gomayāmbhas": ['mw'],
    "gomayāya": ['ddsa', 'mw'],
    "gomaṇiṃda": ['mw'],
    "gomaṇḍala": ['cped', 'mw'],
    "gomaṇḍalaparibbūḷha": ['cped'],
    "gombhas": ['mw'],
    "gombu": ['mw'],
    "gomeda": ['mw'],
    "gomedaka": ['mw'],
    "gomedasaṃnibha": ['mw'],
    "gomedha": ['cae', 'mw'],
    "gomika": ['cped'],
    "gomimukhya": ['bhs'],
    "gomin": ['ap90', 'cae', 'mw'],
    "gomithuna": ['cae', 'ddsa', 'mw'],
    "gomitra": ['mw'],
    "gomiṣaṇḍa": ['bhs'],
    "gomukha": ['cae', 'mw'],
    "gomukhavyāghra": ['mw'],
    "gomukhyā": ['mw'],
    "gomukhī": ['bhs', 'mw'],
    "gomuṇḍa": ['mw'],
    "gomātṛ": ['cae', 'gra', 'mw'],
    "gomāyu": ['cae', 'ddsa', 'gra', 'mw'],
    "gomāyubhakṣa": ['mw'],
    "gomāyukeśvara": ['mw'],
    "gomīna": ['mw'],
    "gomūtra": ['cae', 'mw'],
    "gomūtrajāti": ['mw'],
    "gomūtraka": ['mw'],
    "gomūtrikā": ['mw'],
    "gomūtrikābandha": ['mw'],
    "gomūtrin": ['mw'],
    "gomūḍha": ['mw'],
    "gomṛga": ['cae', 'mw'],
    "gomṛgakākacaryā": ['mw'],
    "gomṛgendra": ['mw'],
    "gonaka": ['cped'],
    "gonanda": ['cae', 'mw'],
    "gonandā": ['mw'],
    "gonandī": ['mw'],
    "gonarda": ['cae', 'mw'],
    "gonardīya": ['mw'],
    "gonasa": ['mw'],
    "gonasaka": ['bhs'],
    "gonasā": ['cae', 'mw'],
    "gonasī": ['mw'],
    "gonaṅgula": ['bhs', 'cped'],
    "gonihāra": ['mw'],
    "gonikā": ['bhs'],
    "gonioghas": ['gra'],
    "gonisādikā": ['cped'],
    "gonisādiniviṭṭha": ['cped'],
    "goniṣkramaṇa": ['mw'],
    "goniṣkramaṇatīrtha": ['mw'],
    "goniṣyanda": ['mw'],
    "goniṣādikā": ['bhs'],
    "gonyoghas": ['gra', 'mw'],
    "gonāda": ['mw'],
    "gonāga": ['mw'],
    "gonāgonīśvaratīrtha": ['mw'],
    "gonāma": ['mw'],
    "gonāman": ['mw'],
    "gonāmika": ['mw'],
    "gonāsa": ['mw'],
    "gonāsā": ['cae', 'mw'],
    "gonātha": ['mw'],
    "gonāya": ['mw'],
    "gonāśana": ['mw'],
    "gonāḍīca": ['mw'],
    "gonāḍīka": ['mw'],
    "gonṛ": ['mw'],
    "goopaśa": ['gra', 'mw'],
    "gopa": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "gopabhadra": ['mw'],
    "gopabhadrikā": ['mw'],
    "gopabhadrā": ['mw'],
    "gopabhaṭṭa": ['mw'],
    "gopada": ['cped', 'mw'],
    "gopadala": ['mw'],
    "gopadanta": ['mw'],
    "gopadatta": ['mw'],
    "gopaghaṇḍā": ['mw'],
    "gopaghaṇṭa": ['mw'],
    "gopaghoṇṭā": ['mw'],
    "gopagiri": ['bhs'],
    "gopajalā": ['mw'],
    "gopajīvin": ['mw'],
    "gopaka": ['bhs', 'cped', 'mw'],
    "gopakanyakā": ['mw'],
    "gopakanyā": ['mw'],
    "gopakarkaṭikā": ['mw'],
    "gopakhuma": ['cped'],
    "gopakṣanetratā": ['mw'],
    "gopakṣma": ['bhs'],
    "gopana": ['cae', 'ddsa', 'mw'],
    "gopanagara": ['mw'],
    "gopananda": ['mw'],
    "gopanaṃ": ['ap90'],
    "gopanā": ['mw'],
    "gopanīya": ['ap90', 'cae', 'mw'],
    "gopanīyatva": ['mw'],
    "gopanīyatā": ['mw'],
    "goparasa": ['mw'],
    "goparvata": ['mw'],
    "goparāṣṭra": ['mw'],
    "goparīṇas": ['gra', 'mw'],
    "gopasū": ['cped'],
    "gopat": ['mw'],
    "gopatha": ['cae', 'ddsa', 'mw'],
    "gopathabrāhmaṇa": ['mw'],
    "gopati": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "gopaticāpa": ['mw'],
    "gopatidhvaja": ['mw'],
    "gopatva": ['mw'],
    "gopatā": ['mw'],
    "gopavadhū": ['mw'],
    "gopavadhūṭī": ['mw'],
    "gopavallī": ['mw'],
    "gopavana": ['gra', 'mw'],
    "gopavanādi": ['mw'],
    "gopaveṣa": ['ddsa', 'mw'],
    "gopay": ['cae'],
    "gopaya": ['ddsa', 'mw'],
    "gopaya(t)": ['cped'],
    "gopayati": ['cped'],
    "gopayatia": ['gra'],
    "gopayatya": ['gra', 'mw'],
    "gopayitavya": ['ddsa', 'mw'],
    "gopaśu": ['mw'],
    "gopaḥ": ['ap90'],
    "gopekṣanetra": ['bhs'],
    "gopendra": ['cae', 'ddsa', 'mw'],
    "gopenta": ['cped'],
    "gopetabba": ['cped'],
    "gopeti": ['cped'],
    "gopetu(m)": ['cped'],
    "gopeśa": ['cae', 'mw'],
    "gopeśvara": ['mw'],
    "gopeśvaratīrtha": ['mw'],
    "gophala": ['cped'],
    "gophaṇikā": ['mw'],
    "gophaṇā": ['mw'],
    "gophila": ['mw'],
    "gopika": ['mw'],
    "gopikā": ['bhs', 'mw'],
    "gopikāsaras": ['mw'],
    "gopila": ['mw'],
    "gopin": ['ap90'],
    "gopinī": ['mw'],
    "gopita": ['cped', 'mw'],
    "gopita(r)": ['cped'],
    "gopitaka": ['bhs'],
    "gopitta": ['ddsa', 'mw'],
    "gopitṛ": ['mw'],
    "gopiṣṭha": ['cae', 'mw'],
    "gopiṭaka": ['bhs', 'mw'],
    "gopotalikā": ['mw'],
    "gopoṣa": ['mw'],
    "goppha": ['cped'],
    "gopphaka": ['cped'],
    "gopracāra": ['ddsa', 'mw'],
    "gopradāna": ['mw'],
    "gopradānika": ['mw'],
    "goprakāṇḍa": ['mw'],
    "goprapadanīya": ['mw'],
    "gopratāra": ['mw'],
    "gopraveśasamaya": ['mw'],
    "goprekṣaka": ['mw'],
    "gopreraka": ['mw'],
    "goptavya": ['ddsa', 'mw'],
    "goptṛ": ['ap90', 'cae', 'mw'],
    "goptṛmat": ['mw'],
    "gopuccha": ['cae', 'mw'],
    "gopucchaka": ['mw'],
    "gopucchāgra": ['mw'],
    "gopucchākṛti": ['mw'],
    "gopura": ['cae', 'mw'],
    "gopuraka": ['mw'],
    "gopurogava": ['mw'],
    "gopurā": ['mw'],
    "gopurīṣa": ['mw'],
    "goputra": ['mw'],
    "gopuṭika": ['mw'],
    "gopuṭā": ['mw'],
    "gopya": ['ap90', 'mw'],
    "gopyaka": ['mw'],
    "gopyakaḥ": ['ap90'],
    "gopā": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "gopācala": ['mw'],
    "gopādhyakṣa": ['mw'],
    "gopāditya": ['mw'],
    "gopādri": ['mw'],
    "gopāgrahāra": ['ddsa', 'mw'],
    "gopājihva": ['gra', 'mw'],
    "gopāla": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "gopālabhaṭṭa": ['mw'],
    "gopālacakravartin": ['mw'],
    "gopālacampū": ['mw'],
    "gopāladeva": ['mw'],
    "gopāladhānīpūlāsa": ['mw'],
    "gopāladāraka": ['cae'],
    "gopāladāsa": ['mw'],
    "gopālagiri": ['mw'],
    "gopālaka": ['bhs', 'cae', 'cped', 'mw'],
    "gopālakakṣa": ['mw'],
    "gopālakalpa": ['mw'],
    "gopālakarkaṭī": ['mw'],
    "gopālakelicandrikā": ['mw'],
    "gopālakeśava": ['mw'],
    "gopālamaṭha": ['mw'],
    "gopālamiśra": ['mw'],
    "gopālaprasāda": ['mw'],
    "gopālapura": ['mw'],
    "gopālarahasya": ['mw'],
    "gopālasahasranāmabhūṣaṇā": ['mw'],
    "gopālasarasvatī": ['mw'],
    "gopālasāhi": ['mw'],
    "gopālatāpanīyopaniṣad": ['mw'],
    "gopālatāpinī": ['mw'],
    "gopālatīrtha": ['mw'],
    "gopālava": ['mw'],
    "gopālavarman": ['mw'],
    "gopālayogin": ['mw'],
    "gopāli": ['mw'],
    "gopālikā": ['cped', 'mw'],
    "gopālita": ['mw'],
    "gopālottaratāpinī": ['mw'],
    "gopālācārya": ['mw'],
    "gopālārcanacandrikā": ['mw'],
    "gopālī": ['bhs', 'mw'],
    "gopānasī": ['bhs', 'cped', 'mw'],
    "gopānasīvaṅka": ['cped'],
    "gopāputra": ['mw'],
    "gopāreśvaratīrtha": ['mw'],
    "gopāsala": ['mw'],
    "gopāvant": ['cae'],
    "gopāvat": ['gra', 'mw'],
    "gopāy": ['cae', 'gra'],
    "gopāya": ['ddsa', 'mw'],
    "gopāyaka": ['ap90', 'mw'],
    "gopāyana": ['ddsa', 'mw'],
    "gopāyanaṃ": ['ap90'],
    "gopāyita": ['ap90', 'mw'],
    "gopāyitavya": ['mw'],
    "gopāyitṛ": ['ap90', 'mw'],
    "gopāśadāraka": ['mw'],
    "gopāṣṭamī": ['mw'],
    "gopī": ['bhs', 'cped', 'mw'],
    "gopīcandana": ['mw'],
    "gopīcandanopaniṣad": ['mw'],
    "gopīnātha": ['mw'],
    "gopīnāthasaptaśatī": ['mw'],
    "gopīpremāmṛta": ['mw'],
    "gopīramaṇa": ['mw'],
    "gopīrasavivaraṇa": ['mw'],
    "gopīta": ['mw'],
    "gopītakaṁ": ['cped'],
    "gopītha": ['cae', 'gra', 'mw'],
    "gopīthia": ['gra'],
    "gopīthya": ['gra', 'mw'],
    "gopītilaka": ['mw'],
    "gor": ['mw'],
    "gorabhasa": ['gra', 'mw'],
    "gorajas": ['bhs', 'mw'],
    "gorakkha": ['cped'],
    "gorakṣ": ['mw'],
    "gorakṣa": ['mw'],
    "gorakṣadugdhā": ['mw'],
    "gorakṣadāsa": ['mw'],
    "gorakṣajambū": ['mw'],
    "gorakṣaka": ['cae', 'mw'],
    "gorakṣakalpa": ['mw'],
    "gorakṣakarkaṭī": ['mw'],
    "gorakṣanātha": ['mw'],
    "gorakṣapura": ['mw'],
    "gorakṣasahasranāman": ['mw'],
    "gorakṣataṇḍula": ['mw'],
    "gorakṣatumbī": ['mw'],
    "gorakṣaśataka": ['mw'],
    "gorakṣaṇa": ['mw'],
    "gorakṣya": ['mw'],
    "gorakṣyāṭṭa": ['mw'],
    "gorakṣā": ['cae', 'mw'],
    "gorakṣāsana": ['mw'],
    "gorakṣī": ['mw'],
    "gorambha": ['mw'],
    "gorasa": ['cae', 'cped', 'mw'],
    "gorasaja": ['mw'],
    "goratha": ['mw'],
    "gorathaka": ['mw'],
    "gorava": ['mw'],
    "goravaka": ['cped'],
    "goraṅku": ['mw'],
    "goraṇa": ['mw'],
    "goraṇaṃ": ['ap90'],
    "goraṭa": ['mw'],
    "gorda": ['mw'],
    "gordaḥ": ['ap90'],
    "gordha": ['mw'],
    "gorikā": ['mw'],
    "goroca": ['mw'],
    "gorocanā": ['cae', 'mw'],
    "gorudha": ['gra', 'mw'],
    "goruta": ['mw'],
    "gorvara": ['mw'],
    "gorāja": ['mw'],
    "gorāsya": ['mw'],
    "gorāṭikā": ['mw'],
    "gorāṭī": ['mw'],
    "gorūpa": ['mw'],
    "gosa": ['mw'],
    "gosadṛkṣa": ['mw'],
    "gosagṛha": ['mw'],
    "gosahasra": ['mw'],
    "gosahasrī": ['mw'],
    "gosakhi": ['gra', 'mw'],
    "gosambhava": ['mw'],
    "gosambhavā": ['mw'],
    "gosamita": ['cped'],
    "gosamādhi": ['mw'],
    "gosani": ['mw'],
    "gosarga": ['mw'],
    "gosarpa": ['mw'],
    "gosattra": ['mw'],
    "gosava": ['cae', 'mw'],
    "gosaśaśa": ['mw'],
    "gosaḥ": ['ap90'],
    "gosaṃdāya": ['mw'],
    "gosaṃkhya": ['mw'],
    "gosaṃkhyātṛ": ['mw'],
    "gosaṅga": ['mw'],
    "gose": ['mw'],
    "gosevā": ['mw'],
    "gosphuraṇa": ['mw'],
    "gostana": ['cae', 'ddsa', 'mw'],
    "gostanākāra": ['mw'],
    "gostanī": ['mw'],
    "gostanīsava": ['mw'],
    "gosthāna": ['mw'],
    "gosthānaka": ['mw'],
    "gostoma": ['mw'],
    "gosvāmin": ['cae', 'mw'],
    "gosvāmisthāna": ['mw'],
    "gosāda": ['mw'],
    "gosādi": ['mw'],
    "gosālikāputra": ['bhs'],
    "gosāraka": ['bhs'],
    "gosārathi": ['mw'],
    "gosāvitrī": ['mw'],
    "gosīla": ['cped'],
    "gosūkta": ['mw'],
    "gosūtrikā": ['mw'],
    "gotallaja": ['mw'],
    "gotama": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "gotamagaura": ['mw'],
    "gotamapṛcchā": ['mw'],
    "gotamastoma": ['mw'],
    "gotamasvāmin": ['mw'],
    "gotamaḥ": ['ap90'],
    "gotameśvaratīrtha": ['mw'],
    "gotamānvaya": ['mw'],
    "gotamī": ['ap90', 'bhs', 'cped', 'mw'],
    "gotamīputra": ['mw'],
    "gotara": ['mw'],
    "gotaraṇi": ['bhs', 'mw'],
    "gotarpaṇa": ['mw'],
    "gotarā": ['mw'],
    "gotra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "gotrabhid": ['cae', 'gra', 'mw'],
    "gotrabhāj": ['mw'],
    "gotrabhū": ['bhs', 'cped'],
    "gotrabhūmi": ['bhs', 'mw'],
    "gotradevatā": ['mw'],
    "gotraja": ['cae', 'mw'],
    "gotraka": ['bhs', 'ddsa', 'mw'],
    "gotrakartṛ": ['mw'],
    "gotrakārin": ['mw'],
    "gotrakīlā": ['mw'],
    "gotrakṣānti": ['bhs', 'mw'],
    "gotram": ['mw'],
    "gotramaya": ['mw'],
    "gotranāman": ['cae', 'mw'],
    "gotranāmābhijānatas": ['cae'],
    "gotrapaṭa": ['mw'],
    "gotrapravaradīpa": ['mw'],
    "gotrapravaramañjarī": ['mw'],
    "gotrapravaranirṇaya": ['mw'],
    "gotrariktha": ['cae', 'mw'],
    "gotrarikthāṃśa": ['mw'],
    "gotrasthiti": ['mw'],
    "gotravardhana": ['mw'],
    "gotravat": ['mw'],
    "gotravrata": ['mw'],
    "gotravṛkṣa": ['mw'],
    "gotreśa": ['mw'],
    "gotreṇa": ['mw'],
    "gotrika": ['mw'],
    "gotrin": ['cae', 'mw'],
    "gotritva": ['mw'],
    "gotroccāra": ['mw'],
    "gotrā": ['mw'],
    "gotrābhidhāyam": ['mw'],
    "gotrādi": ['mw'],
    "gotrākhyā": ['cae', 'ddsa', 'mw'],
    "gotrānta": ['mw'],
    "gotrāntarīya": ['bhs'],
    "gotta": ['cped'],
    "gottapaṭisarī(n": ['cped'],
    "gotulya": ['mw'],
    "gotva": ['cae', 'ddsa', 'mw'],
    "gotvac": ['mw'],
    "gotvagja": ['mw'],
    "gotā": ['mw'],
    "gotīrtha": ['mw'],
    "gotīrthaka": ['mw'],
    "govadha": ['cae', 'mw'],
    "govaidya": ['mw'],
    "govaidyaka": ['mw'],
    "govandanī": ['mw'],
    "govapus": ['gra', 'mw'],
    "govara": ['mw'],
    "govardhana": ['bhs', 'cae', 'mw'],
    "govardhanadhara": ['mw'],
    "govardhanamāhātmya": ['mw'],
    "govardhanasaptaśatī": ['mw'],
    "govardhanācārya": ['mw'],
    "govardhanānanda": ['mw'],
    "govardhanīya": ['mw'],
    "govata": ['cped'],
    "govatika": ['cped'],
    "govatsa": ['mw'],
    "govatsadvādaśīvrata": ['mw'],
    "govatsaka": ['mw'],
    "govatsalatīrtha": ['mw'],
    "govatsādin": ['mw'],
    "govatsāri": ['mw'],
    "govatta": ['cped'],
    "govattika": ['cped'],
    "govaya": ['mw'],
    "govaśā": ['mw'],
    "goveṣa": ['mw'],
    "govid": ['cae', 'gra', 'mw'],
    "govidhā": ['mw'],
    "govikantana": ['cped'],
    "govikarta": ['mw'],
    "govikarttṛ": ['mw'],
    "govinata": ['cae', 'mw'],
    "govinda": ['bhs', 'cae', 'mw'],
    "govindabhagavatpādācārya": ['mw'],
    "govindabhaṭṭa": ['mw'],
    "govindacanda": ['mw'],
    "govindacandra": ['mw'],
    "govindadatta": ['mw'],
    "govindadeva": ['mw'],
    "govindadvādaśī": ['mw'],
    "govindadīkṣita": ['mw'],
    "govindagira": ['mw'],
    "govindakūṭa": ['mw'],
    "govindamānasollāsa": ['mw'],
    "govindanātha": ['mw'],
    "govindanāyaka": ['mw'],
    "govindaprakāśa": ['mw'],
    "govindapāla": ['mw'],
    "govindarāja": ['mw'],
    "govindarāma": ['mw'],
    "govindarāya": ['mw'],
    "govindasiṃha": ['mw'],
    "govindasvāmin": ['mw'],
    "govindasūri": ['mw'],
    "govindasūtra": ['bhs'],
    "govindavṛndāvana": ['mw'],
    "govindinī": ['mw'],
    "govindiya": ['bhs'],
    "govindu": ['gra', 'mw'],
    "govindānanda": ['mw'],
    "govindārcanasudhā": ['mw'],
    "govindārṇava": ['mw'],
    "govindāṣṭaka": ['mw'],
    "govindīyaṃsūtraṃ": ['bhs'],
    "govisarga": ['mw'],
    "govitata": ['mw'],
    "goviṣ": ['mw'],
    "goviṣāṇa": ['mw'],
    "goviṣāṇika": ['mw'],
    "goviṣṭhā": ['mw'],
    "govraja": ['cae', 'mw'],
    "govrata": ['mw'],
    "govratika": ['bhs'],
    "govratin": ['mw'],
    "govyaccha": ['mw'],
    "govyādhi": ['mw'],
    "govyāghra": ['mw'],
    "govāhin": ['mw'],
    "govāla": ['cae', 'mw'],
    "govālin": ['mw'],
    "govāsa": ['mw'],
    "govāsana": ['mw'],
    "govāṇija": ['mw'],
    "govāṭa": ['mw'],
    "govīrya": ['mw'],
    "govīthī": ['mw'],
    "govṛnda": ['mw'],
    "govṛndāraka": ['cae', 'mw'],
    "govṛṣa": ['cae', 'mw'],
    "govṛṣabha": ['mw'],
    "govṛṣabhāṅka": ['mw'],
    "govṛṣadhvaja": ['mw'],
    "govṛṣaṇa": ['cae', 'mw'],
    "goyajña": ['cae', 'mw'],
    "goyoga": ['bhs'],
    "goyuga": ['mw'],
    "goyukta": ['cae', 'mw'],
    "goyuta": ['mw'],
    "goyāna": ['cae', 'ddsa', 'mw'],
    "goyūti": ['mw'],
    "goāyus": ['mw'],
    "gośakaṭa": ['mw'],
    "gośakṛdrasa": ['cae', 'mw'],
    "gośakṛt": ['cae', 'mw'],
    "gośalīputra": ['bhs'],
    "gośapha": ['mw'],
    "gośarya": ['gra', 'mw'],
    "gośata": ['mw'],
    "gośatin": ['mw'],
    "gośe": ['mw'],
    "gośila": ['mw'],
    "gośru": ['mw'],
    "gośruti": ['mw'],
    "gośrīta": ['gra', 'mw'],
    "gośva": ['cae', 'mw'],
    "gośāla": ['mw'],
    "gośāli": ['mw'],
    "gośālā": ['cae', 'mw'],
    "gośīrṣa": ['bhs', 'cae', 'mw'],
    "gośīrṣacandana": ['mw'],
    "gośīrṣaka": ['mw'],
    "gośṛṅga": ['cae', 'mw'],
    "gośṛṅgavratin": ['bhs', 'mw'],
    "gośṛṅgī": ['bhs'],
    "goḍa": ['mw'],
    "goḍakagrāma": ['mw'],
    "goḍimba": ['mw'],
    "goḍu": ['mw'],
    "goḍumba": ['mw'],
    "goḍumbikā": ['mw'],
    "goḍumbā": ['mw'],
    "goḍuṃbaḥ": ['ap90'],
    "goṃḍaḥ": ['ap90'],
    "goṇa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "goṇaka": ['cped'],
    "goṇakatthata": ['cped'],
    "goṇasaka": ['bhs'],
    "goṇasika": ['bhs'],
    "goṇi": ['bhs'],
    "goṇikā": ['bhs', 'mw'],
    "goṇikāputra": ['mw'],
    "goṇā": ['mw'],
    "goṇāśman": ['mw'],
    "goṇī": ['ap90', 'mw'],
    "goṇīpatha": ['mw'],
    "goṇītarī": ['mw'],
    "goṇḍa": ['cae', 'ddsa', 'mw'],
    "goṇḍakirī": ['mw'],
    "goṇḍavana": ['mw'],
    "goṇḍavāra": ['mw'],
    "goṇḍākrī": ['mw'],
    "goṛjīka": ['gra', 'mw'],
    "goṣ": ['mw'],
    "goṣad": ['mw'],
    "goṣada": ['mw'],
    "goṣadaka": ['mw'],
    "goṣadādi": ['mw'],
    "goṣaka": ['mw'],
    "goṣakhi": ['gra', 'mw'],
    "goṣan": ['cae', 'gra', 'mw'],
    "goṣatama": ['mw'],
    "goṣaḍgava": ['mw'],
    "goṣaṇi": ['cae', 'gra', 'mw'],
    "goṣedhā": ['mw'],
    "goṣpada": ['cae', 'ddsa', 'mw'],
    "goṣpadamātra": ['mw'],
    "goṣpadapram": ['mw'],
    "goṣpadapūram": ['mw'],
    "goṣpadatrirātravrata": ['mw'],
    "goṣpadatṛtīyāvrata": ['mw'],
    "goṣpadaṃ": ['ap90'],
    "goṣu": ['mw'],
    "goṣucara": ['mw'],
    "goṣuyudh": ['gra', 'mw'],
    "goṣā": ['cae', 'gra', 'mw'],
    "goṣādī": ['mw'],
    "goṣāti": ['cae', 'gra', 'mw'],
    "goṣūkta": ['mw'],
    "goṣūktin": ['mw'],
    "goṣṭa": ['mw'],
    "goṣṭh": ['ap90'],
    "goṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "goṣṭhacara": ['mw'],
    "goṣṭhagata": ['mw'],
    "goṣṭhagocara": ['mw'],
    "goṣṭhaja": ['mw'],
    "goṣṭhakarman": ['mw'],
    "goṣṭhakukkuṭa": ['mw'],
    "goṣṭhapati": ['mw'],
    "goṣṭhaśva": ['mw'],
    "goṣṭhaḥ": ['ap90'],
    "goṣṭhe": ['mw'],
    "goṣṭhekṣveḍin": ['mw'],
    "goṣṭhepaṇḍita": ['mw'],
    "goṣṭhepaṭu": ['mw'],
    "goṣṭhepragalbha": ['mw'],
    "goṣṭhevijitin": ['mw'],
    "goṣṭheśaya": ['ddsa', 'mw'],
    "goṣṭheśūra": ['mw'],
    "goṣṭhi": ['mw'],
    "goṣṭhika": ['bhs', 'ddsa', 'mw'],
    "goṣṭhiḥ": ['ap90'],
    "goṣṭhodumbara": ['mw'],
    "goṣṭhya": ['cae', 'mw'],
    "goṣṭhā": ['mw'],
    "goṣṭhādhyakṣa": ['mw'],
    "goṣṭhāgāra": ['mw'],
    "goṣṭhāna": ['mw'],
    "goṣṭhāṣṭamī": ['mw'],
    "goṣṭhī": ['ddsa', 'mw'],
    "goṣṭhībandha": ['mw'],
    "goṣṭhīna": ['mw'],
    "goṣṭhīpati": ['mw'],
    "goṣṭhīyāna": ['cae', 'mw'],
    "goṣṭhīśrāddha": ['mw'],
    "goṣṭhīśālā": ['mw'],
    "goṣṭoma": ['mw'],
    "goṭṭha": ['cped'],
    "go’śva": ['ddsa'],
    "gra": ['mw'],
    "grabh": ['cae', 'ddsa', 'gra', 'mw'],
    "grabha": ['cae', 'ddsa', 'gra', 'mw'],
    "grabhaṇa": ['gra', 'mw'],
    "grabhaṇavat": ['gra', 'mw'],
    "grabhītṛ": ['cae', 'mw'],
    "grah": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "graha": ['cae', 'ddsa', 'gra', 'mw'],
    "grahabhakti": ['mw'],
    "grahabhojana": ['mw'],
    "grahabhītijit": ['mw'],
    "grahacaritavid": ['mw'],
    "grahacintaka": ['mw'],
    "grahadaśā": ['mw'],
    "grahadhāra": ['mw'],
    "grahadruma": ['mw'],
    "grahadāya": ['mw'],
    "grahadīpikā": ['mw'],
    "grahagaṇa": ['mw'],
    "grahagaṇita": ['mw'],
    "grahagocara": ['mw'],
    "grahagrasta": ['ddsa', 'mw'],
    "grahagrāmaṇī": ['mw'],
    "grahaka": ['mw'],
    "grahakallola": ['mw'],
    "grahakautuka": ['mw'],
    "grahakaḥ": ['ap90'],
    "grahakośa": ['bhs'],
    "grahakoṣṭhaka": ['mw'],
    "grahakuṇḍalikā": ['mw'],
    "grahakāṇḍa": ['mw'],
    "grahakṣetrin": ['mw'],
    "grahalāghava": ['mw'],
    "grahamarda": ['mw'],
    "grahamardana": ['mw'],
    "grahamaya": ['mw'],
    "grahamuṣ": ['mw'],
    "grahamātṛkā": ['mw'],
    "grahanemi": ['mw'],
    "grahanigraha": ['mw'],
    "grahanāyaka": ['mw'],
    "grahanāśa": ['mw'],
    "grahanāśana": ['mw'],
    "grahapati": ['mw'],
    "grahapuṣa": ['mw'],
    "grahapīḍana": ['ddsa', 'mw'],
    "grahapīḍā": ['mw'],
    "grahapūjā": ['mw'],
    "graharāja": ['mw'],
    "grahasamāgama": ['cae', 'mw'],
    "grahasthitivarṇana": ['mw'],
    "grahasvara": ['mw'],
    "grahasāraṇī": ['mw'],
    "grahatilaka": ['mw'],
    "grahatva": ['mw'],
    "grahatā": ['mw'],
    "grahavarman": ['mw'],
    "grahavarṣa": ['cae', 'mw'],
    "grahavarṣaphala": ['mw'],
    "grahavicārin": ['mw'],
    "grahavimarda": ['mw'],
    "grahavinoda": ['mw'],
    "grahavipra": ['mw'],
    "grahayajña": ['mw'],
    "grahayajñatattva": ['mw'],
    "grahayoga": ['cae', 'mw'],
    "grahayuddha": ['cae', 'mw'],
    "grahayuti": ['cae', 'mw'],
    "grahayāga": ['mw'],
    "grahayāgatattva": ['mw'],
    "grahayālu": ['mw'],
    "grahayāmalatantra": ['mw'],
    "grahayāyya": ['mw'],
    "grahaśānti": ['mw'],
    "grahaśṛṅgāṭaka": ['mw'],
    "grahaḥ": ['ap90'],
    "grahaṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "grahaṇacatura": ['ddsa'],
    "grahaṇagata": ['mw'],
    "grahaṇaka": ['ap90', 'mw'],
    "grahaṇapañcāṅga": ['mw'],
    "grahaṇaphala": ['mw'],
    "grahaṇasambhavādhikāra": ['mw'],
    "grahaṇavat": ['mw'],
    "grahaṇaṃ": ['ap90'],
    "grahaṇi": ['mw'],
    "grahaṇiroga": ['mw'],
    "grahaṇiḥ": ['ap90'],
    "grahaṇānta": ['cae', 'mw'],
    "grahaṇāntam": ['mw'],
    "grahaṇāntika": ['cae', 'mw'],
    "grahaṇī": ['bhs', 'mw'],
    "grahaṇīdoṣa": ['mw'],
    "grahaṇīgada": ['mw'],
    "grahaṇīhara": ['mw'],
    "grahaṇīkapāṭa": ['mw'],
    "grahaṇīpradoṣa": ['mw'],
    "grahaṇīroga": ['mw'],
    "grahaṇīrogin": ['mw'],
    "grahaṇīruj": ['mw'],
    "grahaṇīya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "grahaṇīyatva": ['mw'],
    "grahaṇīyatā": ['mw'],
    "graheśa": ['mw'],
    "graheṣṭaka": ['mw'],
    "grahi": ['cae', 'mw'],
    "grahika": ['bhs'],
    "grahikā": ['mw'],
    "grahila": ['ap90', 'cae', 'ddsa', 'mw'],
    "grahiṣṇu": ['mw'],
    "grahoktha": ['ddsa', 'mw'],
    "grahya": ['mw'],
    "grahādhipati": ['mw'],
    "grahādhiṣṭhāpana": ['mw'],
    "grahādhyāya": ['mw'],
    "grahādhāra": ['mw'],
    "grahādhīna": ['mw'],
    "grahādi": ['mw'],
    "grahāgama": ['mw'],
    "grahāgamakutūhala": ['mw'],
    "grahāgresara": ['mw'],
    "grahāhvaya": ['mw'],
    "grahāluñcana": ['mw'],
    "grahāmaya": ['mw'],
    "grahāntarukthya": ['mw'],
    "grahāpahā": ['mw'],
    "grahārāmakutūhala": ['mw'],
    "grahāvamardana": ['mw'],
    "grahāvarta": ['mw'],
    "grahāya": ['bhs', 'mw'],
    "grahāśin": ['mw'],
    "grahāśraya": ['mw'],
    "grahītavya": ['ap90', 'cae', 'ddsa', 'mw'],
    "grahītṛ": ['ap90', 'cae', 'mw'],
    "graiva": ['ap90', 'cae', 'ddsa', 'mw'],
    "graiveya": ['ddsa', 'mw'],
    "graiveyaka": ['cae', 'mw'],
    "graiveyakaṃ": ['ap90'],
    "graivya": ['cae', 'mw'],
    "graivākṣa": ['mw'],
    "graiṣma": ['ap90', 'cae', 'ddsa', 'mw'],
    "graiṣmaka": ['ap90', 'mw'],
    "graiṣmika": ['bhs', 'cae', 'mw'],
    "graiṣmikadhānya": ['mw'],
    "graiṣmāyaṇa": ['mw'],
    "graiṣmī": ['mw'],
    "granth": ['gra', 'mw'],
    "grantha": ['bhs', 'cae', 'ddsa', 'mw'],
    "granthadhāraṇī": ['bhs'],
    "granthakaraṇa": ['mw'],
    "granthakartṛ": ['mw'],
    "granthakuṭī": ['mw'],
    "granthakāra": ['cae', 'mw'],
    "granthakūṭī": ['mw'],
    "granthakṛt": ['cae', 'mw'],
    "granthana": ['cae', 'mw'],
    "granthanā": ['mw'],
    "granthaparṇī": ['mw'],
    "granthasaṃdhi": ['mw'],
    "granthavistara": ['mw'],
    "granthavistāra": ['mw'],
    "granthi": ['cae', 'ddsa', 'gra', 'mw'],
    "granthibandham": ['mw'],
    "granthibandhana": ['mw'],
    "granthibarhin": ['mw'],
    "granthibheda": ['cae', 'mw'],
    "granthibhedaka": ['mw'],
    "granthicchedaka": ['cae', 'mw'],
    "granthidala": ['mw'],
    "granthidalā": ['mw'],
    "granthidūrvā": ['mw'],
    "granthihara": ['mw'],
    "granthika": ['cae', 'mw'],
    "granthila": ['cae', 'ddsa', 'mw'],
    "granthilā": ['mw'],
    "granthilībhū": ['mw'],
    "granthimant": ['cae'],
    "granthimat": ['mw'],
    "granthimatphala": ['mw'],
    "granthimocaka": ['bhs', 'mw'],
    "granthimūla": ['mw'],
    "granthimūlā": ['mw'],
    "granthin": ['cae', 'ddsa', 'gra', 'mw'],
    "granthinikā": ['mw'],
    "granthiparṇa": ['mw'],
    "granthiparṇaka": ['ddsa', 'mw'],
    "granthiparṇamaya": ['mw'],
    "granthiparṇā": ['mw'],
    "granthiparṇī": ['mw'],
    "granthipattra": ['mw'],
    "granthiphala": ['mw'],
    "granthita": ['bhs', 'mw'],
    "granthitva": ['mw'],
    "granthivajraka": ['mw'],
    "granthivīsarpa": ['mw'],
    "granthivīsarpin": ['mw'],
    "granthiśamana": ['ddsa'],
    "granthāvṛtti": ['mw'],
    "granthībhū": ['mw'],
    "granthīka": ['mw'],
    "grapsa": ['cae', 'ddsa', 'mw'],
    "gras": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "grasana": ['bhs', 'cae', 'ddsa', 'mw'],
    "grasanaṃ": ['ap90'],
    "grasanī": ['bhs'],
    "grasatī": ['bhs', 'mw'],
    "grasiṣṇu": ['ap90', 'cae', 'mw'],
    "grasiṣṭha": ['cae', 'gra', 'mw'],
    "grasta": ['ap90', 'mw'],
    "grastatva": ['mw'],
    "grasti": ['mw'],
    "grastiḥ": ['ap90'],
    "grastodaya": ['mw'],
    "grastāsta": ['mw'],
    "grastṛ": ['cae', 'mw'],
    "grasya": ['mw'],
    "grath": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "grathana": ['cae', 'ddsa', 'mw'],
    "grathanaṃ": ['ap90'],
    "grathanā": ['mw'],
    "grathanīya": ['mw'],
    "grathila": ['mw'],
    "grathin": ['cae', 'ddsa', 'gra', 'mw'],
    "grathita": ['ap90', 'bhs', 'mw'],
    "grathitavya": ['mw'],
    "grathna": ['cae', 'mw'],
    "grathnaḥ": ['ap90'],
    "grathya": ['mw'],
    "graṃth": ['ap90'],
    "graṃthanaṃ": ['ap90'],
    "graṃthaḥ": ['ap90'],
    "graṃthikaḥ": ['ap90'],
    "graṃthila": ['ap90'],
    "graṃthimat": ['ap90'],
    "graṃthin": ['ap90'],
    "graṃthita": ['ap90'],
    "graṃthiḥ": ['ap90'],
    "gredha": ['bhs'],
    "gri": ['mw'],
    "gruc": ['ap90', 'mw'],
    "grumuṣṭi": ['mw'],
    "grābha": ['cae', 'ddsa', 'gra', 'mw'],
    "grāha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "grāhaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "grāhakakṛkara": ['mw'],
    "grāhakatva": ['cae', 'mw'],
    "grāhakatvaṃ": ['ap90'],
    "grāhakavihaṃga": ['mw'],
    "grāham": ['mw'],
    "grāhamelaka": ['mw'],
    "grāhavat": ['mw'],
    "grāhayitavya": ['ddsa', 'mw'],
    "grāhaṃ": ['ap90'],
    "grāhi": ['cae', 'gra', 'mw'],
    "grāhia": ['gra'],
    "grāhika": ['mw'],
    "grāhikā": ['mw'],
    "grāhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "grāhiphala": ['mw'],
    "grāhita": ['ap90', 'mw'],
    "grāhiḥ": ['ap90'],
    "grāhiṇī": ['mw'],
    "grāhuka": ['ap90', 'cae', 'mw'],
    "grāhya": ['ap90', 'cae', 'gra', 'mw'],
    "grāhyagir": ['mw'],
    "grāhyaka": ['mw'],
    "grāhyarūpa": ['mw'],
    "grāhyatva": ['mw'],
    "grāhyavat": ['mw'],
    "grāhyavāc": ['mw'],
    "grāhyā": ['mw'],
    "grāhī": ['mw'],
    "grāma": ['cae', 'ddsa', 'gra', 'mw'],
    "grāmabhṛta": ['mw'],
    "grāmabālajana": ['mw'],
    "grāmacaitya": ['mw'],
    "grāmacara": ['mw'],
    "grāmacaryā": ['mw'],
    "grāmacaṭaka": ['mw'],
    "grāmadaśeśa": ['cae', 'mw'],
    "grāmadeva": ['mw'],
    "grāmadevatā": ['mw'],
    "grāmadharma": ['mw'],
    "grāmadharā": ['mw'],
    "grāmadruma": ['mw'],
    "grāmaga": ['mw'],
    "grāmagamin": ['mw'],
    "grāmagata": ['mw'],
    "grāmageya": ['mw'],
    "grāmageyagāna": ['mw'],
    "grāmaghoṣa": ['bhs'],
    "grāmaghoṣin": ['mw'],
    "grāmaghāta": ['cae', 'mw'],
    "grāmaghātaka": ['mw'],
    "grāmaghātin": ['mw'],
    "grāmagoduh": ['mw'],
    "grāmagāmin": ['mw'],
    "grāmagṛhya": ['mw'],
    "grāmagṛhyaka": ['mw'],
    "grāmahāsaka": ['mw'],
    "grāmaja": ['cae'],
    "grāmajaniṣpāvī": ['mw'],
    "grāmajit": ['cae', 'gra', 'mw'],
    "grāmajā": ['mw'],
    "grāmajāla": ['mw'],
    "grāmajālin": ['mw'],
    "grāmajāta": ['cae', 'mw'],
    "grāmaka": ['mw'],
    "grāmakanda": ['mw'],
    "grāmakaḥ": ['ap90'],
    "grāmakaṇṭaka": ['mw'],
    "grāmakhaṇḍa": ['mw'],
    "grāmakola": ['mw'],
    "grāmakroḍa": ['mw'],
    "grāmakukkuṭa": ['cae', 'mw'],
    "grāmakulāla": ['mw'],
    "grāmakulālikā": ['mw'],
    "grāmakumāra": ['mw'],
    "grāmakumārikā": ['mw'],
    "grāmakāma": ['ddsa', 'mw'],
    "grāmakūṭa": ['mw'],
    "grāmakūṭaka": ['mw'],
    "grāmalekhaka": ['mw'],
    "grāmaluka": ['bhs'],
    "grāmaluṇṭhaka": ['mw'],
    "grāmaluṇṭhana": ['mw'],
    "grāmamadgurikā": ['mw'],
    "grāmamahiṣī": ['mw'],
    "grāmamaryādā": ['mw'],
    "grāmamaukhya": ['mw'],
    "grāmamukha": ['mw'],
    "grāmamṛga": ['mw'],
    "grāmanivāsin": ['mw'],
    "grāmanāpita": ['mw'],
    "grāmapati": ['mw'],
    "grāmapiṣṭa": ['mw'],
    "grāmapreṣya": ['mw'],
    "grāmapuruṣa": ['mw'],
    "grāmaputra": ['mw'],
    "grāmaputrikā": ['mw'],
    "grāmapāla": ['mw'],
    "grāmapālaka": ['mw'],
    "grāmapātra": ['mw'],
    "grāmarajaka": ['mw'],
    "grāmarathyā": ['mw'],
    "grāmasad": ['mw'],
    "grāmasaṃgha": ['mw'],
    "grāmasaṃkara": ['mw'],
    "grāmasiṃha": ['mw'],
    "grāmastha": ['mw'],
    "grāmasukha": ['mw'],
    "grāmasīmanta": ['mw'],
    "grāmasīmā": ['mw'],
    "grāmasūkara": ['mw'],
    "grāmatakṣa": ['mw'],
    "grāmatas": ['mw'],
    "grāmatva": ['mw'],
    "grāmatā": ['mw'],
    "grāmavat": ['mw'],
    "grāmaviśeṣa": ['mw'],
    "grāmavāsa": ['mw'],
    "grāmavāsin": ['mw'],
    "grāmavāstavya": ['mw'],
    "grāmavṛddha": ['mw'],
    "grāmaya": ['mw'],
    "grāmayati": ['ap90'],
    "grāmayuddha": ['mw'],
    "grāmayājaka": ['mw'],
    "grāmayājana": ['mw'],
    "grāmayājika": ['cae'],
    "grāmayājin": ['cae', 'mw'],
    "grāmaśakaṭika": ['cae', 'mw'],
    "grāmaśata": ['mw'],
    "grāmaśateśa": ['cae', 'mw'],
    "grāmaśatādhyakṣa": ['cae', 'mw'],
    "grāmaḥ": ['ap90'],
    "grāmaṇa": ['mw'],
    "grāmaṇi": ['mw'],
    "grāmaṇibhogīna": ['mw'],
    "grāmaṇika": ['bhs'],
    "grāmaṇī": ['cae', 'gra', 'mw'],
    "grāmaṇīputra": ['mw'],
    "grāmaṇīsava": ['mw'],
    "grāmaṇīthya": ['mw'],
    "grāmaṇītva": ['mw'],
    "grāmaṇīya": ['bhs', 'mw'],
    "grāmaṣaṇḍa": ['mw'],
    "grāmaṣaṇḍikā": ['mw'],
    "grāmaṭikā": ['ap90', 'mw'],
    "grāme": ['mw'],
    "grāmecara": ['mw'],
    "grāmegeya": ['mw'],
    "grāmeluka": ['bhs'],
    "grāmevāsa": ['mw'],
    "grāmevāsin": ['mw'],
    "grāmeya": ['ap90', 'mw'],
    "grāmeyaka": ['mw'],
    "grāmeyakā": ['mw'],
    "grāmeyā": ['mw'],
    "grāmeśa": ['mw'],
    "grāmeśvara": ['mw'],
    "grāmi": ['mw'],
    "grāmia": ['gra'],
    "grāmika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "grāmikya": ['mw'],
    "grāmin": ['ap90', 'cae', 'mw'],
    "grāmiputra": ['mw'],
    "grāmiṇī": ['mw'],
    "grāmopādhyāya": ['mw'],
    "grāmya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "grāmyabuddhi": ['mw'],
    "grāmyadharma": ['mw'],
    "grāmyadharmin": ['mw'],
    "grāmyagaja": ['mw'],
    "grāmyakanda": ['mw'],
    "grāmyakarkaṭī": ['mw'],
    "grāmyakarman": ['mw'],
    "grāmyakola": ['mw'],
    "grāmyakośātakī": ['mw'],
    "grāmyakroḍa": ['mw'],
    "grāmyakukkuṭa": ['ddsa', 'mw'],
    "grāmyakuṅkuma": ['mw'],
    "grāmyakāma": ['mw'],
    "grāmyamadgurikā": ['mw'],
    "grāmyamāṃsa": ['mw'],
    "grāmyamṛga": ['mw'],
    "grāmyapaśu": ['mw'],
    "grāmyarāśi": ['mw'],
    "grāmyasukha": ['mw'],
    "grāmyasūkara": ['mw'],
    "grāmyatva": ['mw'],
    "grāmyatā": ['cae', 'mw'],
    "grāmyavallabhā": ['mw'],
    "grāmyavādin": ['mw'],
    "grāmyavārttā": ['mw'],
    "grāmyehoparama": ['mw'],
    "grāmyā": ['mw'],
    "grāmyāyaṇi": ['mw'],
    "grāmyāśva": ['mw'],
    "grāmācāra": ['mw'],
    "grāmādhikṛta": ['mw'],
    "grāmādhipa": ['cae', 'mw'],
    "grāmādhipati": ['mw'],
    "grāmādhyakṣa": ['mw'],
    "grāmādhyayana": ['mw'],
    "grāmādhāna": ['mw'],
    "grāmāgni": ['ddsa', 'mw'],
    "grāmākṣapaṭalika": ['mw'],
    "grāmānta": ['mw'],
    "grāmāntara": ['cae', 'mw'],
    "grāmānte": ['mw'],
    "grāmāntika": ['mw'],
    "grāmāntīya": ['cae', 'mw'],
    "grāmāraṇya": ['mw'],
    "grāmīna": ['mw'],
    "grāmīya": ['ap90', 'mw'],
    "grāmīyaka": ['cae', 'mw'],
    "grāmīṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "grāmīṇā": ['mw'],
    "grāsa": ['cae', 'ddsa', 'mw'],
    "grāsapramāṇa": ['mw'],
    "grāsapātrīkṛ": ['mw'],
    "grāsaśalya": ['mw'],
    "grāsaḥ": ['ap90'],
    "grāsikā": ['mw'],
    "grāsācchādana": ['cae', 'mw'],
    "grāsāmbu": ['mw'],
    "grāsāvarārdhya": ['mw'],
    "grāsī": ['mw'],
    "grāsīkṛ": ['ddsa', 'mw'],
    "grāsīkṛta": ['mw'],
    "grāva": ['mw'],
    "grāvagrābha": ['ddsa', 'gra', 'mw'],
    "grāvahasta": ['gra', 'mw'],
    "grāvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "grāvarohaka": ['mw'],
    "grāvastotriyā": ['mw'],
    "grāvastotrīya": ['mw'],
    "grāvastotrīyā": ['mw'],
    "grāvastut": ['mw'],
    "grāvāyaṇa": ['mw'],
    "grīva": ['ddsa', 'mw'],
    "grīvabaddha": ['mw'],
    "grīvacchinna": ['mw'],
    "grīvadaghna": ['mw'],
    "grīveya": ['bhs'],
    "grīvin": ['ap90', 'mw'],
    "grīvā": ['ap90', 'gra', 'mw'],
    "grīvābila": ['mw'],
    "grīvāghaṇṭā": ['mw'],
    "grīvākṣa": ['mw'],
    "grīvālikā": ['ap90', 'mw'],
    "grīṣma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "grīṣmabhavā": ['mw'],
    "grīṣmadhānya": ['mw'],
    "grīṣmahemanta": ['mw'],
    "grīṣmahāsa": ['mw'],
    "grīṣmajā": ['mw'],
    "grīṣmakāla": ['mw'],
    "grīṣmamayūrī": ['cae'],
    "grīṣmapuṣpī": ['mw'],
    "grīṣmasamaya": ['cae', 'mw'],
    "grīṣmasundaraka": ['mw'],
    "grīṣmavana": ['mw'],
    "grīṣmika": ['bhs'],
    "grīṣmodbhavā": ['mw'],
    "grīṣmā": ['mw'],
    "grīṣmāṇamāse": ['bhs'],
    "grīṣmī": ['mw'],
    "gu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "guccha": ['cae', 'ddsa', 'mw'],
    "gucchabudhnā": ['mw'],
    "gucchadantikā": ['mw'],
    "gucchagulma": ['cae', 'mw'],
    "gucchaka": ['mw'],
    "gucchakarañja": ['mw'],
    "gucchakaḥ": ['ap90'],
    "gucchakaṇiśa": ['mw'],
    "gucchala": ['mw'],
    "gucchamūlikā": ['mw'],
    "gucchapattra": ['mw'],
    "gucchaphala": ['mw'],
    "gucchaphalā": ['mw'],
    "gucchapuṣpa": ['mw'],
    "gucchapuṣpaka": ['mw'],
    "gucchapuṣpī": ['mw'],
    "gucchavadhrā": ['mw'],
    "gucchaḥ": ['ap90'],
    "gucchin": ['mw'],
    "gucchāhvakanda": ['mw'],
    "gucchāla": ['mw'],
    "gucchārdha": ['mw'],
    "gucchārka": ['mw'],
    "gud": ['ap90', 'mw'],
    "guda": ['cae', 'ddsa', 'mw'],
    "gudabhraṃśa": ['mw'],
    "gudagraha": ['mw'],
    "gudaja": ['mw'],
    "gudakīla": ['mw'],
    "gudakīlaka": ['mw'],
    "gudanirgama": ['mw'],
    "gudaniḥsaraṇa": ['mw'],
    "gudapariṇaddha": ['mw'],
    "gudapāka": ['mw'],
    "gudaroga": ['mw'],
    "gudauṣṭha": ['mw'],
    "gudavadana": ['mw'],
    "gudavadanā": ['mw'],
    "gudavartman": ['mw'],
    "gudayoni": ['mw'],
    "gudaṃ": ['ap90'],
    "gudh": ['ap90', 'mw'],
    "gudhera": ['ap90', 'mw'],
    "gudhita": ['ap90', 'mw'],
    "gudodbhava": ['mw'],
    "gudā": ['ddsa', 'gra', 'mw'],
    "gudānila": ['mw'],
    "gudāvarta": ['mw'],
    "gudāṅkura": ['mw'],
    "guggula": ['mw'],
    "guggulaḥ": ['ap90'],
    "gugguli": ['mw'],
    "guggulu": ['cae', 'ddsa', 'mw'],
    "gugguludru": ['mw'],
    "gugguluka": ['mw'],
    "guggulukaḥ": ['ap90'],
    "guggulākṣa": ['mw'],
    "guh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "guha": ['cae', 'ddsa', 'mw'],
    "guhacandra": ['mw'],
    "guhadavadya": ['gra', 'mw'],
    "guhadeva": ['mw'],
    "guhagupta": ['bhs', 'mw'],
    "guhahata": ['mw'],
    "guhaka": ['mw'],
    "guhalu": ['mw'],
    "guhapriyā": ['mw'],
    "guhara": ['mw'],
    "guharāja": ['mw'],
    "guhasena": ['mw'],
    "guhati": ['bhs', 'mw'],
    "guhavaktra": ['mw'],
    "guhavāhana": ['mw'],
    "guhaśiva": ['mw'],
    "guhaḥ": ['ap90'],
    "guhaṣaṣṭhī": ['mw'],
    "guhera": ['mw'],
    "guheraḥ": ['ap90'],
    "guheśvara": ['mw'],
    "guhia": ['gra'],
    "guhila": ['mw'],
    "guhilaṃ": ['ap90'],
    "guhina": ['mw'],
    "guhinaṃ": ['ap90'],
    "guhmita": ['bhs'],
    "guhya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "guhyabhāṣita": ['mw'],
    "guhyabīja": ['mw'],
    "guhyadevī": ['mw'],
    "guhyadhārā": ['mw'],
    "guhyadīpaka": ['mw'],
    "guhyagupta": ['bhs'],
    "guhyaguru": ['mw'],
    "guhyaka": ['cae', 'ddsa', 'mw'],
    "guhyakapūjana": ['mw'],
    "guhyakaḥ": ['ap90'],
    "guhyakeśvara": ['mw'],
    "guhyakādhipati": ['bhs', 'mw'],
    "guhyakālī": ['mw'],
    "guhyam": ['mw'],
    "guhyaniṣyanda": ['mw'],
    "guhyapati": ['mw'],
    "guhyapatividyā": ['mw'],
    "guhyapattra": ['mw'],
    "guhyapattraka": ['mw'],
    "guhyapidhāna": ['mw'],
    "guhyapuṣpa": ['mw'],
    "guhyaroga": ['mw'],
    "guhyaruj": ['mw'],
    "guhyasamājatantra": ['bhs'],
    "guhyatantra": ['mw'],
    "guhyavidyā": ['mw'],
    "guhyeśvarī": ['mw'],
    "guhyādhipati": ['bhs'],
    "guhā": ['ap90', 'bhs', 'cped', 'ddsa', 'gra', 'mw'],
    "guhācara": ['mw'],
    "guhāgahanavat": ['mw'],
    "guhāgarī": ['mw'],
    "guhāgṛha": ['mw'],
    "guhāhita": ['cae', 'mw'],
    "guhākāram": ['mw'],
    "guhāmukha": ['mw'],
    "guhāsaya": ['cped'],
    "guhāvāsin": ['mw'],
    "guhāvāsinī": ['bhs'],
    "guhāvāsitīrtha": ['mw'],
    "guhāśaya": ['cae', 'ddsa', 'mw'],
    "guj": ['ap90', 'mw'],
    "gujjarī": ['mw'],
    "gula": ['cae', 'ddsa', 'mw'],
    "gulaha": ['mw'],
    "gulasi": ['cped'],
    "gulañcakanda": ['mw'],
    "gulaḥ": ['ap90'],
    "gulgulu": ['cae', 'ddsa', 'mw'],
    "gulhaka": ['cped'],
    "gulika": ['mw'],
    "gulikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "gulikākrīḍā": ['mw'],
    "guliṃkaḥ": ['ap90'],
    "guliṅka": ['mw'],
    "gulma": ['bhs', 'cae', 'ddsa', 'mw'],
    "gulmaka": ['bhs', 'mw'],
    "gulmaketu": ['mw'],
    "gulmakeśa": ['mw'],
    "gulmakuṣṭha": ['mw'],
    "gulmakālānanarasa": ['mw'],
    "gulmalā": ['bhs'],
    "gulmamūla": ['mw'],
    "gulmatarapaṇya": ['mw'],
    "gulmavallī": ['mw'],
    "gulmavat": ['mw'],
    "gulmavāta": ['mw'],
    "gulmaḥ": ['ap90'],
    "gulmin": ['ap90', 'mw'],
    "gulminī": ['mw'],
    "gulmodara": ['mw'],
    "gulmī": ['mw'],
    "gulmībhūta": ['mw'],
    "gulpha": ['cae', 'ddsa', 'mw'],
    "gulphadaghna": ['cae', 'mw'],
    "gulphadvayasa": ['mw'],
    "gulphajāha": ['mw'],
    "gulphaya": ['ddsa'],
    "gulphaḥ": ['ap90'],
    "gulphinī": ['mw'],
    "gulphita": ['mw'],
    "guluccha": ['mw'],
    "gulucchakanda": ['mw'],
    "gulucchaḥ": ['ap90'],
    "gulugudhā": ['mw'],
    "gulugudhākṛ": ['mw'],
    "gulugula": ['bhs'],
    "gulugulita": ['mw'],
    "guluguluyati": ['bhs'],
    "gulugulā": ['mw'],
    "gulugulāyati": ['bhs'],
    "guluha": ['mw'],
    "guluñca": ['mw'],
    "guluñcha": ['mw'],
    "guluñchaka": ['mw'],
    "gulya": ['mw'],
    "gulyaḥ": ['ap90'],
    "gulā": ['bhs', 'mw'],
    "gulī": ['mw'],
    "gulūgudhā": ['mw'],
    "gum": ['mw'],
    "gumagumāyita": ['ddsa', 'mw'],
    "gumba": ['cped'],
    "gumbiya": ['cped'],
    "gumph": ['cae', 'ddsa', 'mw'],
    "gumpha": ['mw'],
    "gumphaka": ['mw'],
    "gumphana": ['mw'],
    "gumphanikā": ['mw'],
    "gumphanā": ['mw'],
    "gumphita": ['mw'],
    "gumugumunti": ['bhs'],
    "gundala": ['mw'],
    "gundr": ['mw'],
    "gundra": ['cae', 'ddsa', 'mw'],
    "gundraphalā": ['mw'],
    "gundrā": ['mw'],
    "gundrāla": ['mw'],
    "gundā": ['cped'],
    "gundāla": ['mw'],
    "gup": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "guph": ['ap90', 'mw'],
    "guphita": ['ap90', 'mw'],
    "gupila": ['mw'],
    "gupilaḥ": ['ap90'],
    "gupita": ['mw'],
    "gupta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "guptacara": ['mw'],
    "guptadhana": ['ddsa', 'mw'],
    "guptadāna": ['mw'],
    "guptadīkṣātantra": ['mw'],
    "guptadūta": ['mw'],
    "guptagati": ['mw'],
    "guptagṛha": ['mw'],
    "guptaka": ['mw'],
    "guptakathā": ['mw'],
    "guptakaḥ": ['ap90'],
    "guptakāma": ['bhs'],
    "guptam": ['mw'],
    "guptamati": ['mw'],
    "guptamaṇi": ['mw'],
    "guptaprayāga": ['mw'],
    "guptarajasvalā": ['mw'],
    "guptasarasvatī": ['mw'],
    "guptasneha": ['mw'],
    "guptasnehā": ['mw'],
    "guptasveda": ['mw'],
    "guptasādhanatantra": ['mw'],
    "guptatama": ['mw'],
    "guptatīrtha": ['mw'],
    "guptavatī": ['mw'],
    "guptaveṣa": ['mw'],
    "guptaveṣe": ['mw'],
    "guptaśīla": ['mw'],
    "gupte": ['mw'],
    "gupti": ['bhs', 'cae', 'ddsa', 'mw'],
    "guptibandham": ['mw'],
    "guptigupta": ['mw'],
    "guptika": ['bhs', 'mw'],
    "guptikā": ['bhs', 'mw'],
    "guptipālaka": ['cae', 'mw'],
    "guptivāda": ['mw'],
    "guptiḥ": ['ap90'],
    "guptyadhikṛta": ['mw'],
    "guptā": ['bhs', 'mw'],
    "guptārma": ['mw'],
    "guptāryaka": ['mw'],
    "guptāsana": ['mw'],
    "guptāvadhūta": ['mw'],
    "guptīkṛ": ['mw'],
    "gur": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "guraṇa": ['mw'],
    "guraṇaṃ": ['ap90'],
    "gurd": ['ap90', 'mw'],
    "gureṭaka": ['mw'],
    "gurgaṇa": ['mw'],
    "gurjara": ['cae', 'ddsa', 'mw'],
    "gurjaraḥ": ['ap90'],
    "gurjarī": ['mw'],
    "guru": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "gurubha": ['mw'],
    "gurubhakti": ['cae'],
    "gurubhāra": ['mw'],
    "gurubhārika": ['mw'],
    "gurubhāryā": ['cae', 'mw'],
    "gurubhāva": ['mw'],
    "gurubhṛt": ['mw'],
    "gurucaryā": ['cae', 'mw'],
    "gurudaivata": ['mw'],
    "gurudakṣiṇā": ['cae', 'mw'],
    "gurudarśana": ['mw'],
    "gurudeva": ['bhs'],
    "gurudevasvāmin": ['mw'],
    "gurudevata": ['mw'],
    "gurudharma": ['bhs'],
    "gurudhur": ['cae', 'mw'],
    "gurudhī": ['mw'],
    "gurudina": ['mw'],
    "gurudivasa": ['mw'],
    "gurudāna": ['mw'],
    "gurudāra": ['cae', 'mw'],
    "gurudāsa": ['mw'],
    "gurudīkṣā": ['mw'],
    "gurudīkṣātantra": ['mw'],
    "gurugata": ['mw'],
    "gurugavī": ['mw'],
    "gurughna": ['mw'],
    "gurugītā": ['mw'],
    "gurugītāstotra": ['mw'],
    "gurugṛha": ['cae', 'mw'],
    "guruha": ['mw'],
    "guruhan": ['mw'],
    "gurujana": ['mw'],
    "gurujanapūjita": ['bhs'],
    "guruka": ['ap90', 'bhs', 'mw'],
    "gurukarman": ['ddsa', 'mw'],
    "gurukaṇṭha": ['mw'],
    "gurukopa": ['mw'],
    "gurukrama": ['mw'],
    "gurukratu": ['mw'],
    "gurukula": ['cae', 'mw'],
    "gurukulavāsa": ['mw'],
    "gurukulāvāsin": ['mw'],
    "gurukāra": ['mw'],
    "gurukārya": ['cae', 'mw'],
    "gurukṛta": ['mw'],
    "gurukṣepa": ['mw'],
    "gurula": ['bhs'],
    "gurulaghutā": ['ddsa', 'mw'],
    "gurulāghava": ['cae', 'mw'],
    "gurumadhya": ['mw'],
    "gurumardala": ['mw'],
    "gurumat": ['mw'],
    "gurumattā": ['mw'],
    "gurumatī": ['mw'],
    "gurumeru": ['mw'],
    "gurumukhī": ['mw'],
    "gurumuṣṭi": ['mw'],
    "guruparipāṭī": ['mw'],
    "gurupatnī": ['cae', 'mw'],
    "gurupattra": ['mw'],
    "gurupattraka": ['mw'],
    "gurupattrā": ['mw'],
    "gurupramoda": ['mw'],
    "guruprasāda": ['mw'],
    "guruprasādanīya": ['mw'],
    "guruprasūta": ['mw'],
    "gurupriya": ['mw'],
    "guruputra": ['cae', 'mw'],
    "guruputraka": ['bhs'],
    "gurupādaka": ['bhs'],
    "gurupādāśraya": ['mw'],
    "gurupāka": ['mw'],
    "gurupūjā": ['cae', 'mw'],
    "gururatna": ['bhs', 'mw'],
    "gurusakhī": ['mw'],
    "gurusamavāya": ['mw'],
    "gurusaṃnidhi": ['mw'],
    "gurusevā": ['mw'],
    "guruskandha": ['mw'],
    "gurusthira": ['mw'],
    "gurustrīgamanīya": ['mw'],
    "gurusuta": ['cae'],
    "gurusārā": ['mw'],
    "gurutalpa": ['cae', 'mw'],
    "gurutalpaga": ['cae', 'mw'],
    "gurutalpagāmin": ['cae', 'mw'],
    "gurutalparata": ['mw'],
    "gurutalpavrata": ['mw'],
    "gurutalpin": ['cae', 'mw'],
    "gurutalpābhigamana": ['mw'],
    "gurutalpāpanutti": ['mw'],
    "gurutama": ['ap90', 'mw'],
    "gurutara": ['mw'],
    "gurutva": ['cae', 'mw'],
    "gurutvaka": ['mw'],
    "gurutā": ['ap90', 'cae', 'mw'],
    "gurutāla": ['mw'],
    "gurutāpa": ['mw'],
    "gurutīrtha": ['mw'],
    "guruvadvṛtti": ['mw'],
    "guruvarcoghna": ['mw'],
    "guruvartaka": ['mw'],
    "guruvartin": ['mw'],
    "guruvartitā": ['mw'],
    "guruvarṇa": ['mw'],
    "guruvat": ['cae', 'mw'],
    "guruvaṃśa": ['mw'],
    "guruvyatha": ['mw'],
    "guruvāra": ['mw'],
    "guruvāsa": ['cae', 'mw'],
    "guruvṛtta": ['mw'],
    "guruvṛtti": ['cae', 'mw'],
    "guruvṛttipara": ['mw'],
    "guruyoṣit": ['cae', 'mw'],
    "guruśikharin": ['mw'],
    "guruśiṃśapā": ['mw'],
    "guruśiṣyasaṃvāda": ['mw'],
    "guruśokānala": ['mw'],
    "guruśrīpādukāpūjā": ['mw'],
    "guruśuśrūṣin": ['mw'],
    "guruśuśrūṣu": ['cae', 'mw'],
    "guruśuśrūṣā": ['cae', 'mw'],
    "guruṇḍa": ['mw'],
    "guruṇṭaka": ['mw'],
    "gurv": ['ap90', 'mw'],
    "gurvakṣara": ['mw'],
    "gurvanta": ['mw'],
    "gurvartha": ['cae', 'ddsa', 'mw'],
    "gurvartham": ['mw'],
    "gurvaṅganā": ['cae', 'mw'],
    "gurvaṅganāgama": ['cae', 'mw'],
    "gurviṇikā": ['bhs'],
    "gurviṇī": ['ap90', 'cae', 'ddsa', 'mw'],
    "gurvāvali": ['mw'],
    "gurvī": ['mw'],
    "gurvīsakhī": ['ddsa', 'mw'],
    "gurū": ['mw'],
    "gurūdaratva": ['mw'],
    "gurūkaraṇa": ['mw'],
    "gurūkṛ": ['mw'],
    "gus": ['ddsa'],
    "gusāyin": ['mw'],
    "gutsa": ['cae', 'ddsa', 'mw'],
    "gutsaka": ['mw'],
    "gutsakapuṣpa": ['mw'],
    "gutsakaḥ": ['ap90'],
    "gutsaḥ": ['ap90'],
    "gutsārdha": ['cae', 'mw'],
    "gutta": ['cped'],
    "guttadvāra": ['cped'],
    "gutti": ['bhs', 'cped'],
    "guvāka": ['cae', 'ddsa', 'mw'],
    "guvākaḥ": ['ap90'],
    "guyha": ['cped'],
    "guyhamanta": ['cped'],
    "guñj": ['cae', 'ddsa', 'mw'],
    "guñja": ['cae', 'ddsa', 'mw'],
    "guñjaka": ['mw'],
    "guñjakṛt": ['mw'],
    "guñjana": ['mw'],
    "guñjikā": ['mw'],
    "guñjin": ['mw'],
    "guñjita": ['ddsa', 'mw'],
    "guñjā": ['cae', 'ddsa', 'mw'],
    "guśri": ['mw'],
    "guḍ": ['ap90', 'mw'],
    "guḍa": ['bhs', 'cae', 'ddsa', 'mw'],
    "guḍabhā": ['mw'],
    "guḍabīja": ['mw'],
    "guḍacī": ['mw'],
    "guḍadhenu": ['mw'],
    "guḍadhānā": ['cae', 'mw'],
    "guḍadāru": ['mw'],
    "guḍaharītakī": ['mw'],
    "guḍajihvikā": ['mw'],
    "guḍajihvikānyāya": ['mw'],
    "guḍaka": ['mw'],
    "guḍakarī": ['mw'],
    "guḍakaḥ": ['ap90'],
    "guḍakṣoda": ['mw'],
    "guḍakṣīramaya": ['mw'],
    "guḍala": ['mw'],
    "guḍalaṃ": ['ap90'],
    "guḍalih": ['mw'],
    "guḍaliṇmat": ['mw'],
    "guḍamaya": ['cae', 'mw'],
    "guḍamiśra": ['mw'],
    "guḍamūla": ['mw'],
    "guḍanakha": ['mw'],
    "guḍaparpaṭaka": ['mw'],
    "guḍaphala": ['mw'],
    "guḍapiṣṭa": ['mw'],
    "guḍapuṣpa": ['mw'],
    "guḍapṛthukā": ['mw'],
    "guḍara": ['mw'],
    "guḍatvac": ['mw'],
    "guḍatvaca": ['mw'],
    "guḍatṛṇa": ['mw'],
    "guḍaudana": ['cae', 'ddsa', 'mw'],
    "guḍaśarkarā": ['cae', 'mw'],
    "guḍaśigru": ['mw'],
    "guḍaśṛṅgikā": ['mw'],
    "guḍaḥ": ['ap90'],
    "guḍera": ['mw'],
    "guḍeraka": ['mw'],
    "guḍeraḥ": ['ap90'],
    "guḍikā": ['bhs', 'ddsa', 'mw'],
    "guḍodaka": ['cae', 'ddsa', 'mw'],
    "guḍodana": ['mw'],
    "guḍodbhavā": ['mw'],
    "guḍucī": ['ap90', 'mw'],
    "guḍuguḍāyana": ['mw'],
    "guḍuguḍāyanaṃ": ['ap90'],
    "guḍuguḍāyate": ['bhs'],
    "guḍuha": ['mw'],
    "guḍā": ['ap90', 'mw'],
    "guḍādi": ['mw'],
    "guḍāguñjikabhūta": ['bhs'],
    "guḍākeśa": ['cae', 'mw'],
    "guḍākeśatā": ['mw'],
    "guḍākeśaḥ": ['ap90'],
    "guḍākā": ['ap90', 'mw'],
    "guḍālaka": ['mw'],
    "guḍālā": ['mw'],
    "guḍāpūpa": ['mw'],
    "guḍāpūpikā": ['mw'],
    "guḍāyati": ['bhs'],
    "guḍāśaya": ['mw'],
    "guḍāṣṭaka": ['mw'],
    "guḍī": ['mw'],
    "guḍūcikā": ['mw'],
    "guḍūcī": ['ap90', 'mw'],
    "guḷa": ['cped'],
    "guḷapiṇḍa": ['cped'],
    "guḷavākala": ['cped'],
    "guḷikā": ['cped'],
    "guḷāguṇdikajāta": ['cped'],
    "guḷāguṇṭhikajāta": ['cped'],
    "guḷāsava": ['cped'],
    "guṃ": ['mw'],
    "guṃdalaḥ": ['ap90'],
    "guṃdr": ['ap90'],
    "guṃdraḥ": ['ap90'],
    "guṃdrālaḥ": ['ap90'],
    "guṃdālaḥ": ['ap90'],
    "guṃjanaṃ": ['ap90'],
    "guṃjaḥ": ['ap90'],
    "guṃjikā": ['ap90'],
    "guṃjitaṃ": ['ap90'],
    "guṃjā": ['ap90'],
    "guṃkvaṇa": ['mw'],
    "guṃkāra": ['mw'],
    "guṃphanā": ['ap90'],
    "guṃphaḥ": ['ap90'],
    "guṃphita": ['ap90'],
    "guṃḍ": ['ap90'],
    "guṃḍakaḥ": ['ap90'],
    "guṃḍanaṃ": ['ap90'],
    "guṃḍaḥ": ['ap90'],
    "guṃḍikaḥ": ['ap90'],
    "guṃḍita": ['ap90'],
    "guṃṭh": ['ap90'],
    "guṃṭhanaṃ": ['ap90'],
    "guṃṭhita": ['ap90'],
    "guṅgu": ['cae', 'ddsa', 'gra', 'mw'],
    "guṅguma": ['mw'],
    "guṅgū": ['gra'],
    "guṇ": ['ap90'],
    "guṇa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "guṇabaddha": ['mw'],
    "guṇabhadra": ['cae', 'mw'],
    "guṇabhedatas": ['cae', 'mw'],
    "guṇabhinna": ['mw'],
    "guṇabhoktṛ": ['cae', 'mw'],
    "guṇabhraṃśa": ['mw'],
    "guṇabhuj": ['mw'],
    "guṇabhāj": ['mw'],
    "guṇabhūta": ['cae', 'mw'],
    "guṇacakravāḍaśiru": ['bhs'],
    "guṇacakravāḍaśrirāja": ['bhs'],
    "guṇacandra": ['bhs', 'mw'],
    "guṇaccheda": ['cae', 'mw'],
    "guṇadeva": ['mw'],
    "guṇadhara": ['mw'],
    "guṇadharma": ['mw'],
    "guṇadhṛta": ['cae', 'mw'],
    "guṇadoṣa": ['mw'],
    "guṇadoṣajña": ['cae'],
    "guṇadoṣaparīkṣaṇa": ['mw'],
    "guṇadoṣīkaraṇa": ['mw'],
    "guṇadīdhitiṭippanī": ['mw'],
    "guṇadīdhitiṭīkā": ['mw'],
    "guṇadīpaka": ['mw'],
    "guṇagandhavat": ['mw'],
    "guṇagaṇa": ['bhs', 'mw'],
    "guṇagaṇavat": ['mw'],
    "guṇaghātin": ['mw'],
    "guṇagraha": ['cae'],
    "guṇagrahaṇa": ['mw'],
    "guṇagrahītṛ": ['mw'],
    "guṇagrāhaka": ['mw'],
    "guṇagrāhin": ['cae', 'mw'],
    "guṇagrāma": ['cae', 'mw'],
    "guṇagupta": ['bhs'],
    "guṇaguru": ['cae', 'mw'],
    "guṇagāna": ['mw'],
    "guṇagṛdhnu": ['mw'],
    "guṇagṛhya": ['cae', 'mw'],
    "guṇahāni": ['mw'],
    "guṇahārya": ['cae', 'mw'],
    "guṇahīna": ['cae', 'mw'],
    "guṇajña": ['cae', 'mw'],
    "guṇajñatā": ['mw'],
    "guṇaka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "guṇakaluṣa": ['cae'],
    "guṇakaraṇḍavyūha": ['mw'],
    "guṇakarman": ['cae', 'ddsa', 'mw'],
    "guṇakarmavibhāga": ['mw'],
    "guṇakarī": ['mw'],
    "guṇakathā": ['mw'],
    "guṇakaḥ": ['ap90'],
    "guṇakesarīśvara": ['bhs'],
    "guṇaketu": ['bhs', 'mw'],
    "guṇakeśī": ['mw'],
    "guṇakiraṇāvalī": ['mw'],
    "guṇakirī": ['mw'],
    "guṇakrī": ['mw'],
    "guṇakusumasāgara": ['bhs'],
    "guṇakāra": ['mw'],
    "guṇakāraka": ['mw'],
    "guṇakīrtana": ['mw'],
    "guṇakṛtya": ['mw'],
    "guṇala": ['mw'],
    "guṇalakṣaṇa": ['mw'],
    "guṇalayanikā": ['mw'],
    "guṇalayanī": ['mw'],
    "guṇaleśasukhada": ['mw'],
    "guṇalubdha": ['mw'],
    "guṇamahat": ['mw'],
    "guṇamata": ['mw'],
    "guṇamati": ['bhs', 'mw'],
    "guṇamaya": ['ap90', 'cae', 'mw'],
    "guṇamaṇḍala": ['bhs'],
    "guṇamukhyā": ['mw'],
    "guṇamātra": ['mw'],
    "guṇana": ['ddsa', 'mw'],
    "guṇanaṃ": ['ap90'],
    "guṇanidhi": ['ddsa', 'mw'],
    "guṇanikā": ['ap90', 'mw'],
    "guṇanī": ['mw'],
    "guṇanīya": ['ap90', 'mw'],
    "guṇapadmaśrīgarbha": ['bhs'],
    "guṇapadī": ['mw'],
    "guṇaparvatateja": ['bhs'],
    "guṇaprabha": ['bhs', 'mw'],
    "guṇaprabhānodgata": ['bhs'],
    "guṇapradīpa": ['bhs'],
    "guṇaprakarṣa": ['mw'],
    "guṇaprakāśadīdhitimāthurī": ['mw'],
    "guṇaprakāśavivṛti": ['mw'],
    "guṇapriya": ['mw'],
    "guṇapālita": ['mw'],
    "guṇapūga": ['mw'],
    "guṇaratna": ['mw'],
    "guṇaratnakośastotra": ['mw'],
    "guṇaratnamaya": ['mw'],
    "guṇaratnamālā": ['mw'],
    "guṇaraśmidhvaja": ['bhs'],
    "guṇarddha": ['mw'],
    "guṇarāga": ['mw'],
    "guṇarāja": ['bhs'],
    "guṇarājaprabhāsa": ['bhs', 'mw'],
    "guṇarāśi": ['bhs', 'mw'],
    "guṇasampad": ['mw'],
    "guṇasampanna": ['mw'],
    "guṇasamudra": ['bhs', 'mw'],
    "guṇasamudraśrī": ['bhs'],
    "guṇasamudrāvabhāsamaṇḍalaśrī": ['bhs'],
    "guṇasaṃcaya": ['bhs'],
    "guṇasaṃgraha": ['mw'],
    "guṇasaṃkhyāna": ['mw'],
    "guṇasaṃkīrtana": ['mw'],
    "guṇasaṃpanna": ['cae'],
    "guṇasaṃskāra": ['mw'],
    "guṇasaṃyukta": ['cae', 'mw'],
    "guṇasaṅga": ['cae', 'mw'],
    "guṇasthānaprakaraṇa": ['mw'],
    "guṇastuti": ['mw'],
    "guṇasumeru": ['bhs'],
    "guṇasumeruprabhateja": ['bhs'],
    "guṇasumeruśrī": ['bhs'],
    "guṇasundara": ['mw'],
    "guṇasāgara": ['bhs', 'mw'],
    "guṇatantra": ['mw'],
    "guṇatas": ['cae', 'mw'],
    "guṇataḥ": ['ap90'],
    "guṇatejas": ['bhs'],
    "guṇatraya": ['mw'],
    "guṇatrayābhāsa": ['mw'],
    "guṇatritaya": ['mw'],
    "guṇatva": ['mw'],
    "guṇatyāgin": ['cae', 'mw'],
    "guṇatā": ['ap90', 'mw'],
    "guṇaugha": ['mw'],
    "guṇava(t)": ['cped'],
    "guṇavacana": ['cae', 'mw'],
    "guṇavadvapus": ['mw'],
    "guṇavaicitrya": ['mw'],
    "guṇavaiśeṣya": ['mw'],
    "guṇavant": ['cae'],
    "guṇavarman": ['mw'],
    "guṇavarta": ['bhs'],
    "guṇavartin": ['mw'],
    "guṇavarṇana": ['mw'],
    "guṇavat": ['ap90', 'mw'],
    "guṇavatpayaska": ['mw'],
    "guṇavattama": ['mw'],
    "guṇavattara": ['mw'],
    "guṇavattva": ['mw'],
    "guṇavattā": ['ap90', 'cae', 'mw'],
    "guṇavatī": ['mw'],
    "guṇavedin": ['mw'],
    "guṇavidha": ['mw'],
    "guṇavipramukta": ['mw'],
    "guṇavistara": ['mw'],
    "guṇavivecana": ['mw'],
    "guṇavivecanā": ['mw'],
    "guṇaviśeṣa": ['mw'],
    "guṇaviśuddhigarbha": ['bhs'],
    "guṇaviṣṇu": ['mw'],
    "guṇavrata": ['mw'],
    "guṇavācaka": ['mw'],
    "guṇavāda": ['mw'],
    "guṇavādin": ['mw'],
    "guṇavṛddhī": ['mw'],
    "guṇavṛkṣa": ['mw'],
    "guṇavṛkṣaka": ['mw'],
    "guṇavṛtti": ['mw'],
    "guṇay": ['cae'],
    "guṇaya": ['ddsa', 'mw'],
    "guṇayoga": ['mw'],
    "guṇayukta": ['ddsa', 'mw'],
    "guṇaśabda": ['mw'],
    "guṇaśata": ['mw'],
    "guṇaśataśālin": ['mw'],
    "guṇaśila": ['mw'],
    "guṇaślāghā": ['mw'],
    "guṇaśrīgarbha": ['bhs'],
    "guṇaśīla": ['mw'],
    "guṇaśīlatas": ['mw'],
    "guṇaḥ": ['ap90'],
    "guṇeśa": ['mw'],
    "guṇeśvara": ['mw'],
    "guṇi": ['mw'],
    "guṇidvaidha": ['mw'],
    "guṇigaṇa": ['mw'],
    "guṇikā": ['ap90', 'mw'],
    "guṇiliṅga": ['mw'],
    "guṇin": ['ap90', 'cae', 'mw'],
    "guṇisarvasva": ['mw'],
    "guṇita": ['ap90', 'mw'],
    "guṇitavya": ['mw'],
    "guṇitā": ['ddsa', 'mw'],
    "guṇodaya": ['cae', 'mw'],
    "guṇojjvala": ['cae', 'mw'],
    "guṇopapanna": ['mw'],
    "guṇopeta": ['mw'],
    "guṇopāsaka": ['mw'],
    "guṇotkarṣa": ['cae', 'ddsa', 'mw'],
    "guṇotkīrtana": ['mw'],
    "guṇotkṛṣṭa": ['cae', 'mw'],
    "guṇottara": ['mw'],
    "guṇya": ['ap90', 'bhs', 'ddsa', 'mw'],
    "guṇyatva": ['mw'],
    "guṇā": ['mw'],
    "guṇābdhi": ['mw'],
    "guṇābhilāṣin": ['cae', 'mw'],
    "guṇābhāsa": ['mw'],
    "guṇābhūta": ['bhs'],
    "guṇādhipa": ['mw'],
    "guṇādhiṣṭhāna": ['mw'],
    "guṇādhiṣṭhānaka": ['mw'],
    "guṇādhāna": ['mw'],
    "guṇādhāra": ['mw'],
    "guṇādi": ['mw'],
    "guṇāgradhārin": ['bhs', 'mw'],
    "guṇāgrya": ['mw'],
    "guṇāguṇa": ['cae', 'mw'],
    "guṇāguṇajña": ['mw'],
    "guṇākara": ['bhs', 'ddsa', 'mw'],
    "guṇākaragupta": ['bhs'],
    "guṇākarasūri": ['mw'],
    "guṇākarā": ['bhs'],
    "guṇākṣara": ['mw'],
    "guṇālaya": ['cae', 'ddsa', 'mw'],
    "guṇālaṃkṛta": ['mw'],
    "guṇālābha": ['mw'],
    "guṇānanda": ['mw'],
    "guṇānandī": ['mw'],
    "guṇāntara": ['cae', 'mw'],
    "guṇāntaraṃvraj": ['mw'],
    "guṇāntarādhāna": ['mw'],
    "guṇāntarāpatti": ['mw'],
    "guṇānurodha": ['mw'],
    "guṇānurāga": ['mw'],
    "guṇānvaya": ['mw'],
    "guṇānvita": ['cae', 'mw'],
    "guṇāpavāda": ['mw'],
    "guṇārāma": ['mw'],
    "guṇāsaha": ['bhs'],
    "guṇātipāta": ['mw'],
    "guṇātiśaya": ['mw'],
    "guṇātman": ['mw'],
    "guṇātīta": ['cae', 'mw'],
    "guṇāvaguṇṭhitabhūta": ['bhs'],
    "guṇāvaha": ['mw'],
    "guṇāvarā": ['mw'],
    "guṇāya": ['ddsa', 'mw'],
    "guṇāyana": ['mw'],
    "guṇāśraya": ['cae', 'mw'],
    "guṇāḍhya": ['cae', 'mw'],
    "guṇāḍhyaka": ['mw'],
    "guṇāṅga": ['mw'],
    "guṇī": ['cae', 'mw'],
    "guṇīas": ['mw'],
    "guṇībhāva": ['mw'],
    "guṇībhū": ['ddsa', 'mw'],
    "guṇībhūta": ['ap90', 'mw'],
    "guṇīkaraṇa": ['mw'],
    "guṇḍ": ['mw'],
    "guṇḍa": ['mw'],
    "guṇḍaka": ['mw'],
    "guṇḍakanda": ['mw'],
    "guṇḍana": ['mw'],
    "guṇḍicā": ['mw'],
    "guṇḍika": ['mw'],
    "guṇḍikā": ['mw'],
    "guṇḍita": ['mw'],
    "guṇḍra": ['mw'],
    "guṇḍā": ['mw'],
    "guṇḍālā": ['mw'],
    "guṇḍārocanikā": ['mw'],
    "guṇḍārocanī": ['mw'],
    "guṇḍāśinī": ['mw'],
    "guṇṭh": ['cae', 'ddsa', 'mw'],
    "guṇṭha": ['bhs'],
    "guṇṭhana": ['cae', 'ddsa', 'mw'],
    "guṇṭhanā": ['mw'],
    "guṇṭhita": ['mw'],
    "guṣpita": ['ap90', 'ddsa', 'gra', 'mw'],
    "guṭikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "guṭikāmukha": ['mw'],
    "guṭikāpāta": ['mw'],
    "guṭikāstra": ['mw'],
    "guṭikāñjana": ['mw'],
    "guṭikīkṛta": ['mw'],
    "guṭī": ['ap90'],
    "guṭṭha": ['cped'],
    "gva": ['gra', 'mw'],
    "gvin": ['mw'],
    "gā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gābdika": ['mw'],
    "gābhīratā": ['bhs'],
    "gādgadya": ['mw'],
    "gādh": ['ap90', 'mw'],
    "gādha": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "gādhana": ['mw'],
    "gādhanī": ['mw'],
    "gādhapratiṣṭhā": ['mw'],
    "gādhati": ['cped'],
    "gādhera": ['mw'],
    "gādherakāyani": ['mw'],
    "gādheri": ['mw'],
    "gādheya": ['cae', 'ddsa', 'mw'],
    "gādheyaḥ": ['ap90'],
    "gādheyī": ['mw'],
    "gādhi": ['cae', 'ddsa', 'mw'],
    "gādhibhū": ['mw'],
    "gādhija": ['cae', 'mw'],
    "gādhin": ['cae', 'mw'],
    "gādhinagara": ['mw'],
    "gādhinandana": ['cae', 'mw'],
    "gādhipura": ['mw'],
    "gādhiputra": ['cae', 'mw'],
    "gādhisūnu": ['cae', 'mw'],
    "gādhiḥ": ['ap90'],
    "gādi": ['mw'],
    "gāditya": ['mw'],
    "gādādharī": ['mw'],
    "gādāyana": ['mw'],
    "gāganāyasa": ['mw'],
    "gāh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gāha": ['ap90', 'bhs', 'cae', 'cped', 'gra', 'mw'],
    "gāhaka": ['cped'],
    "gāhana": ['cae', 'ddsa', 'mw'],
    "gāhanaṃ": ['ap90'],
    "gāhanīya": ['mw'],
    "gāhayati": ['cped'],
    "gāhetuṁ": ['cped'],
    "gāhetvā": ['cped'],
    "gāhikā": ['cped'],
    "gāhita": ['ap90', 'mw'],
    "gāhitṛ": ['ap90', 'mw'],
    "gāhya": ['mw'],
    "gāhāpeti": ['cped'],
    "gāhāpettaba": ['cped'],
    "gāhāpetvā": ['cped'],
    "gāhāyati": ['cped'],
    "gāhī": ['mw'],
    "gāja": ['mw'],
    "gājara": ['mw'],
    "gājaraṃ": ['ap90'],
    "gājavāja": ['mw'],
    "gāla": ['cae', 'ddsa', 'mw'],
    "gālakyaja": ['mw'],
    "gālana": ['cae', 'ddsa', 'mw'],
    "gālanaṃ": ['ap90'],
    "gālava": ['cae', 'ddsa', 'mw'],
    "gālavagaḍula": ['mw'],
    "gālavaḥ": ['ap90'],
    "gālavi": ['mw'],
    "gālaḍi": ['mw'],
    "gālaḥ": ['ap90'],
    "gāli": ['cae', 'ddsa', 'mw'],
    "gālidāna": ['mw'],
    "gālimat": ['mw'],
    "gālin": ['mw'],
    "gālinī": ['ap90', 'mw'],
    "gālipradāna": ['mw'],
    "gālita": ['ap90', 'mw'],
    "gāliḥ": ['ap90'],
    "gāloḍaya": ['mw'],
    "gāloḍita": ['ap90', 'mw'],
    "gāloḍya": ['mw'],
    "gāloḍyaṃ": ['ap90'],
    "gālī": ['ddsa', 'mw'],
    "gāma": ['cped'],
    "gāma'ūpacāra": ['cped'],
    "gāma(k)khetta": ['cped'],
    "gāmabandhana": ['cped'],
    "gāmadhamma": ['cped'],
    "gāmaghāta": ['cped'],
    "gāmaghātaka": ['cped'],
    "gāmagāmika": ['cped'],
    "gāmaka": ['cped'],
    "gāmakamma": ['cped'],
    "gāmakūṭa": ['cped'],
    "gāmakūṭaka": ['cped'],
    "gāman": ['mw'],
    "gāmanta": ['cped'],
    "gāmantaka": ['cped'],
    "gāmantara": ['cped'],
    "gāmantarakappa": ['cped'],
    "gāmapada": ['cped'],
    "gāmapaddhana": ['cped'],
    "gāmapaṭṭa": ['cped'],
    "gāmapaṭṭana": ['cped'],
    "gāmapoddava": ['cped'],
    "gāmapūṭava": ['cped'],
    "gāmayati": ['cped'],
    "gāmaṇika": ['cped'],
    "gāmaṇī": ['cped'],
    "gāmaṇḍala": ['cped'],
    "gāmbhīra": ['mw'],
    "gāmbhīrya": ['cae', 'ddsa', 'mw'],
    "gāmeti": ['cped'],
    "gāmi(n)": ['cped'],
    "gāmika": ['ap90', 'bhs', 'cped', 'mw'],
    "gāmin": ['ap90', 'cae', 'ddsa', 'mw'],
    "gāminikā": ['bhs'],
    "gāmuka": ['ap90', 'mw'],
    "gāna": ['cae', 'ddsa', 'mw'],
    "gānabandhu": ['mw'],
    "gānacchalā": ['mw'],
    "gānavidyā": ['mw'],
    "gānaṃ": ['ap90'],
    "gāndhapiṅgaleya": ['mw'],
    "gāndharva": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "gāndharvacitta": ['mw'],
    "gāndharvaka": ['mw'],
    "gāndharvakalā": ['mw'],
    "gāndharvaveda": ['mw'],
    "gāndharvavidhi": ['cae'],
    "gāndharvavidyā": ['mw'],
    "gāndharvaśālā": ['mw'],
    "gāndharvaśāstra": ['mw'],
    "gāndharvika": ['mw'],
    "gāndharvī": ['mw'],
    "gāndhika": ['ddsa', 'mw'],
    "gāndhikī": ['mw'],
    "gāndhinī": ['mw'],
    "gāndhāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "gāndhāragrāma": ['mw'],
    "gāndhāraka": ['mw'],
    "gāndhārarāja": ['mw'],
    "gāndhāreya": ['mw'],
    "gāndhāri": ['cae', 'ddsa', 'mw'],
    "gāndhārikā": ['mw'],
    "gāndhārisaptasama": ['mw'],
    "gāndhārivāṇija": ['mw'],
    "gāndhārī": ['mw'],
    "gāndika": ['mw'],
    "gāndinī": ['mw'],
    "gāndinīsuta": ['mw'],
    "gāndī": ['mw'],
    "gānin": ['ap90'],
    "gāninī": ['mw'],
    "gānmuta": ['mw'],
    "gāntra": ['mw'],
    "gāntu": ['mw'],
    "gānīya": ['mw'],
    "gāra": ['mw'],
    "gāraka": ['mw'],
    "gārava": ['bhs', 'cped'],
    "gārayha": ['cped'],
    "gārbha": ['ap90', 'cae', 'ddsa', 'mw'],
    "gārbhika": ['cae', 'mw'],
    "gārbhiṇa": ['mw'],
    "gārbhiṇaṃ": ['ap90'],
    "gārbhiṇya": ['mw'],
    "gārbhāyaṇa": ['mw'],
    "gārdabha": ['ap90', 'ddsa', 'mw'],
    "gārdabharathika": ['mw'],
    "gārdabhi": ['mw'],
    "gārdabhin": ['mw'],
    "gārddhya": ['cae', 'ddsa', 'mw'],
    "gārddhyaṃ": ['ap90'],
    "gārdha": ['bhs'],
    "gārdhra": ['ap90', 'mw'],
    "gārdhrapakṣa": ['mw'],
    "gārdhrapattra": ['mw'],
    "gārdhrapṛṣṭa": ['mw'],
    "gārdhrarājita": ['mw'],
    "gārdhravājita": ['mw'],
    "gārdhravāsas": ['mw'],
    "gāredha": ['mw'],
    "gārga": ['ap90', 'mw'],
    "gārgaka": ['mw'],
    "gārgarya": ['mw'],
    "gārgeya": ['mw'],
    "gārgi": ['mw'],
    "gārgika": ['mw'],
    "gārgikā": ['mw'],
    "gārgya": ['ap90', 'cae', 'ddsa', 'mw'],
    "gārgyapariśiṣṭa": ['mw'],
    "gārgyatara": ['mw'],
    "gārgyatva": ['mw'],
    "gārgyāyaṇa": ['cae', 'mw'],
    "gārgyāyaṇaka": ['mw'],
    "gārgyāyaṇi": ['mw'],
    "gārgyāyaṇī": ['mw'],
    "gārgyāyaṇīya": ['mw'],
    "gārgā": ['mw'],
    "gārgābhārya": ['mw'],
    "gārgī": ['mw'],
    "gārgībhūta": ['mw'],
    "gārgībrāhmaṇa": ['mw'],
    "gārgīmāta": ['mw'],
    "gārgīputra": ['mw'],
    "gārgīputrakāyaṇi": ['mw'],
    "gārgīputri": ['mw'],
    "gārgīputrāyaṇi": ['mw'],
    "gārgīya": ['mw'],
    "gārha": ['mw'],
    "gārhakamedhika": ['mw'],
    "gārhamedha": ['ap90', 'mw'],
    "gārhapata": ['ddsa', 'mw'],
    "gārhapataṃ": ['ap90'],
    "gārhapatika": ['bhs'],
    "gārhapatya": ['cae', 'ddsa', 'gra', 'mw'],
    "gārhapatyasthāna": ['mw'],
    "gārhapatyaḥ": ['ap90'],
    "gārhapatyeṣṭakā": ['mw'],
    "gārhapatyāgāra": ['cae', 'mw'],
    "gārhapatyāyatana": ['mw'],
    "gārhasthya": ['cae', 'ddsa', 'mw'],
    "gārhasthyaṃ": ['ap90'],
    "gārhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "gāritra": ['mw'],
    "gāritraṃ": ['ap90'],
    "gārjara": ['mw'],
    "gārmuta": ['mw'],
    "gārtaka": ['mw'],
    "gārtsamada": ['ddsa', 'mw'],
    "gārugi": ['mw'],
    "gārutmata": ['ap90', 'cae', 'ddsa', 'mw'],
    "gārutmatapattrikā": ['mw'],
    "gāruḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "gāruḍapurāṇa": ['mw'],
    "gāruḍika": ['mw'],
    "gāruḍikaḥ": ['ap90'],
    "gāruḍopaniṣad": ['mw'],
    "gāruḍī": ['mw'],
    "gārṣṭeya": ['gra', 'mw'],
    "gātave": ['cae', 'mw'],
    "gātavya": ['ap90', 'mw'],
    "gātha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gāthaka": ['cae', 'mw'],
    "gāthakaḥ": ['ap90'],
    "gāthapati": ['gra', 'mw'],
    "gāthaśravas": ['gra', 'mw'],
    "gāthaḥ": ['ap90'],
    "gāthi": ['mw'],
    "gāthija": ['mw'],
    "gāthikā": ['ap90', 'mw'],
    "gāthin": ['cae', 'ddsa', 'gra', 'mw'],
    "gāthina": ['mw'],
    "gāthinī": ['mw'],
    "gāthā": ['ap90', 'cped', 'ddsa', 'gra', 'mw'],
    "gāthābhigīta": ['cped'],
    "gāthākāra": ['mw'],
    "gāthāntara": ['mw'],
    "gāthānārāśaṃsī": ['mw'],
    "gāthānī": ['ddsa', 'gra', 'mw'],
    "gāthāpada": ['cped'],
    "gātra": ['cae', 'ddsa', 'gra', 'mw'],
    "gātrabhañjana": ['mw'],
    "gātrabhaṅga": ['mw'],
    "gātrabhaṅgā": ['mw'],
    "gātraceṣṭa": ['mw'],
    "gātragupta": ['mw'],
    "gātraka": ['ddsa', 'mw'],
    "gātrakampa": ['mw'],
    "gātrakarśana": ['mw'],
    "gātrakaṃ": ['ap90'],
    "gātralatā": ['mw'],
    "gātramārjanī": ['mw'],
    "gātraruha": ['mw'],
    "gātrasamplava": ['mw'],
    "gātrasaṃkocanī": ['mw'],
    "gātrasaṃkocin": ['mw'],
    "gātrasparśa": ['mw'],
    "gātravairūpyatā": ['mw'],
    "gātravat": ['mw'],
    "gātravatī": ['mw'],
    "gātraveṣṭana": ['mw'],
    "gātravigharṣaṇa": ['mw'],
    "gātravinda": ['mw'],
    "gātraya": ['mw'],
    "gātrayaṣṭi": ['mw'],
    "gātrayuta": ['mw'],
    "gātraśayya": ['mw'],
    "gātraśoṣaṇa": ['mw'],
    "gātraṃ": ['ap90'],
    "gātrikā": ['mw'],
    "gātrikābandha": ['mw'],
    "gātrikāgranthi": ['mw'],
    "gātrotsādana": ['cae', 'mw'],
    "gātrā": ['mw'],
    "gātrānulepanī": ['cae', 'mw'],
    "gātrāvara": ['mw'],
    "gātrāvaraṇa": ['mw'],
    "gātu": ['cae', 'ddsa', 'gra', 'mw'],
    "gātumant": ['cae'],
    "gātumat": ['ddsa', 'gra', 'mw'],
    "gātuvid": ['gra', 'mw'],
    "gātuy": ['cae', 'gra'],
    "gātuya": ['mw'],
    "gātuḥ": ['ap90'],
    "gātāgatika": ['ap90', 'mw'],
    "gātānugatika": ['ap90', 'mw'],
    "gātṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "gāvalgaṇi": ['mw'],
    "gāvalgaṇiḥ": ['ap90'],
    "gāvaya": ['mw'],
    "gāvedhuka": ['mw'],
    "gāveśa": ['mw'],
    "gāveṣa": ['mw'],
    "gāviṣṭhila": ['mw'],
    "gāviṣṭhilāyana": ['mw'],
    "gāviṣṭhira": ['mw'],
    "gāviṣṭhirāyaṇa": ['mw'],
    "gāvāmayanika": ['mw'],
    "gāvī": ['bhs', 'cped', 'mw'],
    "gāvīdhuka": ['mw'],
    "gāya": ['cae', 'ddsa', 'gra', 'mw'],
    "gāyaka": ['cae', 'ddsa', 'mw'],
    "gāyakaḥ": ['ap90'],
    "gāyakī": ['mw'],
    "gāyamāna": ['cped'],
    "gāyana": ['cae', 'ddsa', 'mw'],
    "gāyanaka": ['bhs'],
    "gāyanaḥ": ['ap90'],
    "gāyanta": ['cped'],
    "gāyantikā": ['mw'],
    "gāyantī": ['mw'],
    "gāyanī": ['mw'],
    "gāyas": ['gra', 'mw'],
    "gāyat": ['mw'],
    "gāyati": ['cped'],
    "gāyatra": ['cae', 'ddsa', 'gra', 'mw'],
    "gāyatrabārhata": ['mw'],
    "gāyatracchandas": ['mw'],
    "gāyatrakākubha": ['mw'],
    "gāyatrapārśva": ['mw'],
    "gāyatravartani": ['gra', 'mw'],
    "gāyatravepas": ['gra', 'mw'],
    "gāyatraḥ": ['ap90'],
    "gāyatri": ['mw'],
    "gāyatrin": ['ap90', 'cae', 'gra', 'mw'],
    "gāyatrisāra": ['mw'],
    "gāyatrya": ['mw'],
    "gāyatryāsita": ['mw'],
    "gāyatrī": ['ap90', 'ddsa', 'mw'],
    "gāyatrībhāṣya": ['mw'],
    "gāyatrīkāram": ['mw'],
    "gāyatrīmantra": ['mw'],
    "gāyatrīmukha": ['mw'],
    "gāyatrīpañcāṅga": ['mw'],
    "gāyatrīpañjara": ['mw'],
    "gāyatrīpuraścaraṇa": ['mw'],
    "gāyatrīrahasya": ['mw'],
    "gāyatrīsāman": ['mw'],
    "gāyatrīvallabha": ['mw'],
    "gāyatrīyāman": ['mw'],
    "gāyaḥ": ['ap90'],
    "gāyi": ['cped'],
    "gāyikī": ['mw'],
    "gāyita": ['bhs'],
    "gāyitabba": ['cped'],
    "gāñjikāya": ['mw'],
    "gāñjīkāya": ['mw'],
    "gāñjīvin": ['mw'],
    "gāḍava": ['mw'],
    "gāḍavaḥ": ['ap90'],
    "gāḍeraki": ['mw'],
    "gāḍha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "gāḍhakarṇa": ['mw'],
    "gāḍham": ['bhs', 'mw'],
    "gāḍhamuṣṭi": ['mw'],
    "gāḍhanidra": ['mw'],
    "gāḍhatara": ['mw'],
    "gāḍhataram": ['mw'],
    "gāḍhatva": ['mw'],
    "gāḍhatā": ['cae', 'mw'],
    "gāḍhavacas": ['mw'],
    "gāḍhavarcas": ['mw'],
    "gāḍhavarcastva": ['mw'],
    "gāḍhaśokaprahāra": ['mw'],
    "gāḍhodvega": ['cae', 'mw'],
    "gāḍhāliṅgana": ['mw'],
    "gāḍhānurāgin": ['cae'],
    "gāḍhāṅgada": ['mw'],
    "gāḍhīkaraṇa": ['mw'],
    "gāḍivi": ['mw'],
    "gāḍulya": ['mw'],
    "gāḷha": ['cped'],
    "gāḷhabandhanaṁ bandhati": ['cped'],
    "gāḷhapalepanena": ['cped'],
    "gāḷhaṁ": ['cped'],
    "gāḷhena": ['cped'],
    "gāḷhita": ['cped'],
    "gāḷhūpalepanena": ['cped'],
    "gāṃ": ['mw'],
    "gāṃbhīryaṃ": ['ap90'],
    "gāṃdama": ['mw'],
    "gāṃdharva": ['ap90'],
    "gāṃdharvakaḥ": ['ap90'],
    "gāṃdharvikaḥ": ['ap90'],
    "gāṃdhikaḥ": ['ap90'],
    "gāṃdhāraḥ": ['ap90'],
    "gāṃdhāreyaḥ": ['ap90'],
    "gāṃdhāriḥ": ['ap90'],
    "gāṃdhārī": ['ap90'],
    "gāṃdinī": ['ap90'],
    "gāṃdohasaṃnejana": ['mw'],
    "gāṃdī": ['ap90'],
    "gāṃga": ['ap90'],
    "gāṃgaucya": ['mw'],
    "gāṃgaṭaḥ": ['ap90'],
    "gāṃgeya": ['ap90'],
    "gāṃgāyaniḥ": ['ap90'],
    "gāṃjikāyaḥ": ['ap90'],
    "gāṃmanya": ['mw'],
    "gāṃtrī": ['ap90'],
    "gāṃtuḥ": ['ap90'],
    "gāṃḍivaḥ": ['ap90'],
    "gāṃḍīvin": ['ap90'],
    "gāṅga": ['cae', 'ddsa', 'mw'],
    "gāṅgadeva": ['mw'],
    "gāṅgaugha": ['mw'],
    "gāṅgaṭa": ['mw'],
    "gāṅgaṭaka": ['mw'],
    "gāṅgaṭeya": ['mw'],
    "gāṅgeruka": ['mw'],
    "gāṅgerukī": ['mw'],
    "gāṅgeya": ['cae', 'mw'],
    "gāṅgeyadeva": ['mw'],
    "gāṅgeṣṭhī": ['mw'],
    "gāṅgi": ['mw'],
    "gāṅgia": ['gra'],
    "gāṅgika": ['mw'],
    "gāṅgilā": ['mw'],
    "gāṅgodaki": ['mw'],
    "gāṅgya": ['cae', 'gra', 'mw'],
    "gāṅgyāyani": ['mw'],
    "gāṅgāmahika": ['mw'],
    "gāṅgāyana": ['mw'],
    "gāṅgāyani": ['mw'],
    "gāṅgī": ['mw'],
    "gāṅgū": ['mw'],
    "gāṇagāri": ['mw'],
    "gāṇakārya": ['mw'],
    "gāṇapata": ['ap90', 'mw'],
    "gāṇapatya": ['ddsa', 'mw'],
    "gāṇapatyapūrvatāpanīyopaniṣad": ['mw'],
    "gāṇapatyaḥ": ['ap90'],
    "gāṇeśa": ['ddsa', 'mw'],
    "gāṇeśaḥ": ['ap90'],
    "gāṇeśopapurāṇa": ['mw'],
    "gāṇika": ['mw'],
    "gāṇikya": ['mw'],
    "gāṇikyaṃ": ['ap90'],
    "gāṇina": ['mw'],
    "gāṇitika": ['mw'],
    "gāṇāyana": ['mw'],
    "gāṇāyanya": ['mw'],
    "gāṇḍavya": ['mw'],
    "gāṇḍavyāyanī": ['mw'],
    "gāṇḍiva": ['cae', 'ddsa', 'mw'],
    "gāṇḍivadhara": ['mw'],
    "gāṇḍālī": ['mw'],
    "gāṇḍī": ['mw'],
    "gāṇḍīmaya": ['mw'],
    "gāṇḍīra": ['mw'],
    "gāṇḍīva": ['cae', 'ddsa', 'mw'],
    "gāṇḍīvadhanvan": ['mw'],
    "gāṇḍīvamukta": ['mw'],
    "gāṇḍīvin": ['mw'],
    "gī": ['mw'],
    "gīr": ['mw'],
    "gīratha": ['mw'],
    "gīrbāṇa": ['mw'],
    "gīrdevī": ['mw'],
    "gīrghoṣākṣaravimukta": ['bhs'],
    "gīrlatā": ['mw'],
    "gīrpati": ['mw'],
    "gīrvat": ['mw'],
    "gīrvi": ['mw'],
    "gīrvāṇa": ['cae', 'ddsa', 'mw'],
    "gīrvāṇakusuma": ['mw'],
    "gīrvāṇapadamañjari": ['mw'],
    "gīrvāṇasenāpati": ['mw'],
    "gīrvāṇavartman": ['mw'],
    "gīrvāṇendrasarasvatī": ['mw'],
    "gīrṇa": ['ap90', 'ddsa', 'mw'],
    "gīrṇi": ['mw'],
    "gīrṇiḥ": ['ap90'],
    "gīs": ['mw'],
    "gīstarā": ['mw'],
    "gīstva": ['mw'],
    "gīta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "gītabandhana": ['mw'],
    "gītagaṅgādhara": ['mw'],
    "gītagirīśa": ['mw'],
    "gītagovinda": ['cae', 'mw'],
    "gītajña": ['mw'],
    "gītaka": ['cae', 'mw'],
    "gītakaṃ": ['ap90'],
    "gītakaṇḍikā": ['mw'],
    "gītakrama": ['mw'],
    "gītakā": ['mw'],
    "gītakṣama": ['cae', 'mw'],
    "gītamodin": ['mw'],
    "gītamārga": ['mw'],
    "gītanṛtya": ['cae', 'mw'],
    "gītapriyā": ['mw'],
    "gītapustaka": ['mw'],
    "gītapustakasaṃgraha": ['mw'],
    "gītassara": ['cped'],
    "gītavādana": ['cae', 'mw'],
    "gītaśāstra": ['mw'],
    "gīthā": ['ap90', 'cae', 'ddsa', 'mw'],
    "gīti": ['cae', 'ddsa', 'mw'],
    "gītikā": ['ap90', 'mw'],
    "gītin": ['ap90', 'mw'],
    "gītisūtra": ['mw'],
    "gītiviśeṣa": ['mw'],
    "gītiśataka": ['mw'],
    "gītiḥ": ['ap90'],
    "gītyāryā": ['cae', 'mw'],
    "gītā": ['ap90', 'bhs', 'ddsa', 'mw'],
    "gītācārya": ['cae', 'ddsa', 'mw'],
    "gītāgīta": ['mw'],
    "gītārtha": ['mw'],
    "gītāyana": ['mw'],
    "gīveyyaka": ['cped'],
    "gīveyyakā": ['cped'],
    "gīvā": ['cped'],
    "gīḥ": ['mw'],
    "gīḥkāmya": ['mw'],
    "gīḥpati": ['mw'],
    "gīṣ": ['mw'],
    "gīṣpati": ['mw'],
    "gū": ['ap90', 'mw'],
    "gūh": ['ddsa'],
    "gūha": ['mw'],
    "gūhana": ['cae', 'ddsa', 'mw'],
    "gūhanaṃ": ['ap90'],
    "gūhati": ['bhs'],
    "gūhitavya": ['mw'],
    "gūhā": ['cped'],
    "gūka": ['mw'],
    "gūlā": ['mw'],
    "gūna": ['ap90', 'mw'],
    "gūr": ['ap90', 'mw'],
    "gūraṇa": ['ddsa', 'mw'],
    "gūraṇaṃ": ['ap90'],
    "gūrd": ['ap90', 'mw'],
    "gūrda": ['cae', 'ddsa', 'mw'],
    "gūrdaḥ": ['ap90'],
    "gūrdh": ['ap90', 'mw'],
    "gūrdhay": ['cae', 'gra'],
    "gūrdhaya": ['ddsa'],
    "gūrdī": ['mw'],
    "gūrjaraḥ": ['ap90'],
    "gūrta": ['ap90', 'cae', 'mw'],
    "gūrtamanas": ['gra', 'mw'],
    "gūrtavacas": ['gra', 'mw'],
    "gūrtaśravas": ['gra', 'mw'],
    "gūrti": ['cae', 'ddsa', 'gra', 'mw'],
    "gūrtiḥ": ['ap90'],
    "gūrtāvasu": ['gra', 'mw'],
    "gūrṇa": ['ap90', 'ddsa', 'mw'],
    "gūtha": ['bhs', 'cped', 'mw'],
    "gūthabhakkha": ['cped'],
    "gūthabhastā": ['cped'],
    "gūthagata": ['cped'],
    "gūthaka": ['bhs', 'mw'],
    "gūthakūpa": ['cped'],
    "gūthalakta": ['mw'],
    "gūthaniraya": ['cped'],
    "gūthaḥ": ['ap90'],
    "gūthoḍigalla": ['bhs'],
    "gūthāda": ['cped'],
    "gūthādi(n)": ['cped'],
    "gūvāka": ['ap90', 'mw'],
    "gūvākaḥ": ['ap90'],
    "gūḍha": ['ap90', 'cae', 'ddsa', 'mw'],
    "gūḍhabhāṣita": ['mw'],
    "gūḍhacaturthapādaprahelikā": ['mw'],
    "gūḍhacāra": ['mw'],
    "gūḍhacārin": ['mw'],
    "gūḍhadaṇḍa": ['mw'],
    "gūḍhagulphatā": ['mw'],
    "gūḍhaja": ['cae', 'mw'],
    "gūḍham": ['mw'],
    "gūḍhamaithuna": ['mw'],
    "gūḍhamallikā": ['mw'],
    "gūḍhamantra": ['mw'],
    "gūḍhamārga": ['mw'],
    "gūḍhamāya": ['mw'],
    "gūḍhanīḍa": ['mw'],
    "gūḍhapad": ['mw'],
    "gūḍhapatha": ['mw'],
    "gūḍhapattra": ['mw'],
    "gūḍhaphala": ['mw'],
    "gūḍhapuruṣa": ['mw'],
    "gūḍhapuṣpaka": ['mw'],
    "gūḍhapāda": ['mw'],
    "gūḍhasira": ['mw'],
    "gūḍhasiratā": ['mw'],
    "gūḍhasākṣin": ['mw'],
    "gūḍhatayā": ['mw'],
    "gūḍhatva": ['mw'],
    "gūḍhatā": ['mw'],
    "gūḍhavallikā": ['mw'],
    "gūḍhavarcas": ['mw'],
    "gūḍhavasati": ['mw'],
    "gūḍhe": ['mw'],
    "gūḍhotman": ['mw'],
    "gūḍhotpanna": ['cae', 'mw'],
    "gūḍhā": ['mw'],
    "gūḍhāgāra": ['cae', 'ddsa', 'mw'],
    "gūḍhāgūḍhatva": ['mw'],
    "gūḍhāgūḍhatā": ['mw'],
    "gūḍhārcis": ['mw'],
    "gūḍhārtha": ['cae', 'mw'],
    "gūḍhārthacandrikā": ['mw'],
    "gūḍhārthadīpikā": ['mw'],
    "gūḍhārtharatnamālā": ['mw'],
    "gūḍhārthatattvadīpikā": ['mw'],
    "gūḍhāśaya": ['mw'],
    "gūḍhāṅga": ['mw'],
    "gūḍhāṅghri": ['mw'],
    "gūḥ": ['ap90'],
    "gūḷhaka": ['cped'],
    "gūṣaṇā": ['ap90', 'mw'],
    "gṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "gṛbh": ['cae', 'ddsa', 'gra', 'mw'],
    "gṛbha": ['cae', 'ddsa', 'gra', 'mw'],
    "gṛbhay": ['cae'],
    "gṛbhaya": ['ddsa'],
    "gṛbhayat": ['mw'],
    "gṛbhaṃ": ['ap90'],
    "gṛbhi": ['cae', 'ddsa', 'gra', 'mw'],
    "gṛbhita": ['mw'],
    "gṛbhiḥ": ['ap90'],
    "gṛbhāy": ['gra'],
    "gṛbhāya": ['cae', 'ddsa', 'mw'],
    "gṛbhīta": ['ap90', 'ddsa', 'mw'],
    "gṛbhītatāti": ['gra', 'mw'],
    "gṛbhītvā": ['mw'],
    "gṛda": ['cae', 'mw'],
    "gṛddha": ['bhs', 'cae', 'mw'],
    "gṛddhi": ['bhs', 'mw'],
    "gṛddhin": ['mw'],
    "gṛddhitva": ['mw'],
    "gṛdh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gṛdhnin": ['mw'],
    "gṛdhnu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gṛdhnutā": ['cae', 'mw'],
    "gṛdhra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gṛdhracakra": ['mw'],
    "gṛdhradṛṣṭi": ['mw'],
    "gṛdhrajambūka": ['mw'],
    "gṛdhrakūṭa": ['cae', 'mw'],
    "gṛdhramojāntaka": ['mw'],
    "gṛdhranakhī": ['mw'],
    "gṛdhrapati": ['cae', 'mw'],
    "gṛdhrapattra": ['mw'],
    "gṛdhrapattrā": ['mw'],
    "gṛdhraputrikā": ['mw'],
    "gṛdhrarāj": ['cae', 'mw'],
    "gṛdhrarāja": ['cae', 'mw'],
    "gṛdhrasad": ['mw'],
    "gṛdhrasī": ['ap90', 'mw'],
    "gṛdhravaktrā": ['mw'],
    "gṛdhravaṭa": ['mw'],
    "gṛdhravāja": ['mw'],
    "gṛdhravājita": ['mw'],
    "gṛdhrayātu": ['gra', 'mw'],
    "gṛdhraśīrṣan": ['mw'],
    "gṛdhreśvara": ['mw'],
    "gṛdhrikā": ['ap90', 'mw'],
    "gṛdhriṇī": ['bhs'],
    "gṛdhrāṇa": ['ap90', 'mw'],
    "gṛdhrāṇā": ['mw'],
    "gṛdhrī": ['mw'],
    "gṛdhu": ['ap90', 'mw'],
    "gṛdhya": ['cae', 'ddsa', 'mw'],
    "gṛdhyaṃ": ['ap90'],
    "gṛdhyin": ['cae'],
    "gṛdhyā": ['ddsa', 'mw'],
    "gṛdhū": ['ap90', 'mw'],
    "gṛh": ['cae', 'mw'],
    "gṛha": ['cae', 'ddsa', 'gra', 'mw'],
    "gṛhababhru": ['mw'],
    "gṛhabali": ['cae', 'mw'],
    "gṛhabalibhuj": ['mw'],
    "gṛhabalidevatā": ['mw'],
    "gṛhabalipriya": ['mw'],
    "gṛhabhadraka": ['mw'],
    "gṛhabhartṛ": ['cae', 'mw'],
    "gṛhabhañjana": ['mw'],
    "gṛhabhaṅga": ['mw'],
    "gṛhabhedin": ['mw'],
    "gṛhabhitti": ['mw'],
    "gṛhabhojin": ['mw'],
    "gṛhabhūmi": ['mw'],
    "gṛhacaṭaka": ['mw'],
    "gṛhacchidra": ['mw'],
    "gṛhacetas": ['mw'],
    "gṛhacullī": ['mw'],
    "gṛhada": ['cae'],
    "gṛhadevatā": ['cae', 'mw'],
    "gṛhadevī": ['mw'],
    "gṛhadhūma": ['mw'],
    "gṛhadruma": ['mw'],
    "gṛhadvār": ['mw'],
    "gṛhadvāra": ['cae', 'mw'],
    "gṛhadāha": ['cae', 'mw'],
    "gṛhadāru": ['cae', 'mw'],
    "gṛhadāsa": ['cae', 'mw'],
    "gṛhadāsikā": ['mw'],
    "gṛhadāsī": ['mw'],
    "gṛhadīpti": ['cae', 'mw'],
    "gṛhaghnī": ['mw'],
    "gṛhagodhikā": ['mw'],
    "gṛhagodhā": ['mw'],
    "gṛhagolaka": ['mw'],
    "gṛhagolikā": ['mw'],
    "gṛhagopikā": ['mw'],
    "gṛhagupta": ['mw'],
    "gṛhahan": ['mw'],
    "gṛhaja": ['cae', 'mw'],
    "gṛhajana": ['cae', 'mw'],
    "gṛhajñānin": ['mw'],
    "gṛhajālikā": ['mw'],
    "gṛhajāta": ['cae', 'mw'],
    "gṛhaka": ['mw'],
    "gṛhakacchapa": ['mw'],
    "gṛhakakṣyā": ['mw'],
    "gṛhakalaha": ['mw'],
    "gṛhakanyā": ['mw'],
    "gṛhakapota": ['cae', 'ddsa', 'mw'],
    "gṛhakapotaka": ['cae', 'mw'],
    "gṛhakaraṇa": ['mw'],
    "gṛhakarmadāsa": ['mw'],
    "gṛhakarmakara": ['mw'],
    "gṛhakarman": ['cae', 'mw'],
    "gṛhakartṛ": ['mw'],
    "gṛhakukkuṭa": ['mw'],
    "gṛhakuliṅga": ['mw'],
    "gṛhakumārī": ['mw'],
    "gṛhakāraka": ['mw'],
    "gṛhakārin": ['cae', 'mw'],
    "gṛhakārya": ['cae', 'mw'],
    "gṛhakūlaka": ['mw'],
    "gṛhakṛtya": ['cae', 'mw'],
    "gṛhakṣata": ['mw'],
    "gṛhakṣetrin": ['mw'],
    "gṛhala": ['mw'],
    "gṛhamayūra": ['cae', 'mw'],
    "gṛhamaṇi": ['mw'],
    "gṛhamedha": ['cae', 'gra', 'mw'],
    "gṛhamedhin": ['cae', 'mw'],
    "gṛhamedhinī": ['mw'],
    "gṛhamedhitā": ['mw'],
    "gṛhamedhivrata": ['mw'],
    "gṛhamedhya": ['mw'],
    "gṛhamedhīya": ['cae', 'gra', 'mw'],
    "gṛhamegha": ['mw'],
    "gṛhamocikā": ['mw'],
    "gṛhamukha": ['mw'],
    "gṛhamācikā": ['mw'],
    "gṛhamārjanī": ['mw'],
    "gṛhamūḍhadhī": ['mw'],
    "gṛhamṛga": ['mw'],
    "gṛhanadikā": ['mw'],
    "gṛhanamana": ['mw'],
    "gṛhanaraka": ['mw'],
    "gṛhanirvāha": ['mw'],
    "gṛhanāśana": ['mw'],
    "gṛhanīḍa": ['mw'],
    "gṛhapa": ['cae', 'mw'],
    "gṛhapati": ['bhs', 'cae', 'gra', 'mw'],
    "gṛhapatika": ['bhs'],
    "gṛhapatin": ['mw'],
    "gṛhapativadana": ['mw'],
    "gṛhapatnī": ['gra', 'mw'],
    "gṛhapaṭala": ['mw'],
    "gṛhapotaka": ['mw'],
    "gṛhapoṣaṇa": ['mw'],
    "gṛhaprakaraṇa": ['mw'],
    "gṛhaprapadana": ['mw'],
    "gṛhapraveśa": ['mw'],
    "gṛhapāla": ['cae', 'mw'],
    "gṛhapālāya": ['mw'],
    "gṛhapāta": ['mw'],
    "gṛhapūjā": ['mw'],
    "gṛhapṛṣṭha": ['mw'],
    "gṛharakṣā": ['cae', 'mw'],
    "gṛharandhra": ['mw'],
    "gṛharāja": ['mw'],
    "gṛhasaṃrodha": ['mw'],
    "gṛhasaṃstha": ['mw'],
    "gṛhasaṃveśaka": ['cae', 'mw'],
    "gṛhastha": ['cae', 'mw'],
    "gṛhasthadharma": ['mw'],
    "gṛhasthatā": ['mw'],
    "gṛhasthiti": ['mw'],
    "gṛhasthopaniṣad": ['mw'],
    "gṛhasthā": ['mw'],
    "gṛhasthāna": ['mw'],
    "gṛhasthāśrama": ['mw'],
    "gṛhasthūṇa": ['mw'],
    "gṛhasvāminī": ['mw'],
    "gṛhasāra": ['mw'],
    "gṛhasārasa": ['cae', 'mw'],
    "gṛhatara": ['bhs'],
    "gṛhataṭī": ['mw'],
    "gṛhavarman": ['mw'],
    "gṛhavat": ['mw'],
    "gṛhaviccheda": ['mw'],
    "gṛhavitta": ['mw'],
    "gṛhavrata": ['mw'],
    "gṛhavyāpāra": ['mw'],
    "gṛhavāsa": ['cae', 'mw'],
    "gṛhavāsin": ['mw'],
    "gṛhavāṭikā": ['mw'],
    "gṛhavāṭī": ['mw'],
    "gṛhavṛkṣavāṭikā": ['mw'],
    "gṛhaya": ['mw'],
    "gṛhayantra": ['ddsa', 'mw'],
    "gṛhayālu": ['ap90', 'mw'],
    "gṛhayāyya": ['mw'],
    "gṛhayāyyaḥ": ['ap90'],
    "gṛhaśikhaṇḍin": ['cae', 'mw'],
    "gṛhaśreṇī": ['mw'],
    "gṛhaśuddhi": ['mw'],
    "gṛhaśuka": ['cae', 'mw'],
    "gṛhaśāyin": ['mw'],
    "gṛhaṃ": ['ap90'],
    "gṛhaṇī": ['ap90', 'mw'],
    "gṛhejñānin": ['mw'],
    "gṛheruha": ['mw'],
    "gṛhevāsin": ['mw'],
    "gṛheśa": ['mw'],
    "gṛheśvara": ['cae', 'ddsa', 'mw'],
    "gṛheśvarī": ['mw'],
    "gṛheśūra": ['mw'],
    "gṛhi": ['cae', 'mw'],
    "gṛhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "gṛhiṇī": ['ap90', 'mw'],
    "gṛhodaka": ['mw'],
    "gṛhodyāna": ['mw'],
    "gṛholikā": ['ap90', 'mw'],
    "gṛhopakaraṇa": ['mw'],
    "gṛhotpāta": ['mw'],
    "gṛhu": ['cae', 'ddsa', 'gra', 'mw'],
    "gṛhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "gṛhyagrantha": ['mw'],
    "gṛhyaguru": ['mw'],
    "gṛhyaka": ['ap90', 'mw'],
    "gṛhyakarman": ['mw'],
    "gṛhyakārikā": ['mw'],
    "gṛhyapaddhati": ['mw'],
    "gṛhyapariśiṣṭa": ['mw'],
    "gṛhyasaṃgraha": ['mw'],
    "gṛhyasūtra": ['cae', 'mw'],
    "gṛhyatātparyadarśana": ['mw'],
    "gṛhyavat": ['mw'],
    "gṛhyavivaraṇa": ['mw'],
    "gṛhyā": ['ap90', 'ddsa', 'mw'],
    "gṛhyāgni": ['mw'],
    "gṛhyākarman": ['mw'],
    "gṛhyāsaṃgraha": ['mw'],
    "gṛhābhipālin": ['mw'],
    "gṛhācāra": ['mw'],
    "gṛhādhipa": ['mw'],
    "gṛhāgata": ['ddsa', 'mw'],
    "gṛhājira": ['mw'],
    "gṛhākṣa": ['mw'],
    "gṛhālika": ['mw'],
    "gṛhālikā": ['ap90'],
    "gṛhālikī": ['mw'],
    "gṛhālī": ['mw'],
    "gṛhāmbu": ['mw'],
    "gṛhāmla": ['mw'],
    "gṛhānubaddha": ['mw'],
    "gṛhāpaṇa": ['mw'],
    "gṛhārambha": ['mw'],
    "gṛhārtha": ['cae', 'mw'],
    "gṛhārāma": ['mw'],
    "gṛhārūḍhacetas": ['mw'],
    "gṛhāvagrahaṇī": ['mw'],
    "gṛhāvagrahiṇī": ['mw'],
    "gṛhāvasthita": ['mw'],
    "gṛhāvāsa": ['bhs'],
    "gṛhāya": ['mw'],
    "gṛhāyanika": ['mw'],
    "gṛhāyaṇika": ['mw'],
    "gṛhāśayā": ['mw'],
    "gṛhāśman": ['mw'],
    "gṛhāśrama": ['cae', 'mw'],
    "gṛhāśramavat": ['mw'],
    "gṛhāśramin": ['mw'],
    "gṛhāśrayā": ['mw'],
    "gṛhī": ['cae'],
    "gṛhībhū": ['ap90', 'ddsa', 'mw'],
    "gṛhīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "gṛhītacetas": ['mw'],
    "gṛhītacāpa": ['cae', 'mw'],
    "gṛhītadeha": ['mw'],
    "gṛhītadhanu": ['cae'],
    "gṛhītadhanus": ['mw'],
    "gṛhītadhanvan": ['cae', 'mw'],
    "gṛhītadikka": ['mw'],
    "gṛhītadiś": ['mw'],
    "gṛhītagarbhā": ['mw'],
    "gṛhītahṛdaya": ['mw'],
    "gṛhītaka": ['bhs'],
    "gṛhītakhaḍgacarman": ['mw'],
    "gṛhītamauna": ['mw'],
    "gṛhītamaunavrata": ['mw'],
    "gṛhītanāmadheya": ['cae', 'mw'],
    "gṛhītanāman": ['mw'],
    "gṛhītapaścāttāpa": ['cae', 'mw'],
    "gṛhītapātheya": ['cae', 'mw'],
    "gṛhītapāṇi": ['mw'],
    "gṛhītapṛṣṭha": ['mw'],
    "gṛhītasāra": ['mw'],
    "gṛhītavasatīvarīka": ['mw'],
    "gṛhītavetana": ['mw'],
    "gṛhītavidya": ['mw'],
    "gṛhītavya": ['mw'],
    "gṛhītaśarakārmuka": ['mw'],
    "gṛhītaśarāvāpa": ['mw'],
    "gṛhītaśūla": ['mw'],
    "gṛhīti": ['cae', 'ddsa', 'mw'],
    "gṛhītin": ['ap90', 'mw'],
    "gṛhītvā": ['mw'],
    "gṛhītākṣara": ['cae', 'ddsa', 'mw'],
    "gṛhītāmiṣa": ['mw'],
    "gṛhītārtha": ['cae', 'mw'],
    "gṛhītāstra": ['mw'],
    "gṛhītāvaguṇṭhana": ['cae', 'mw'],
    "gṛhītṛ": ['mw'],
    "gṛhīṇa": ['bhs'],
    "gṛhṇana": ['bhs'],
    "gṛhṇat": ['mw'],
    "gṛhṇāna": ['mw'],
    "gṛj": ['ap90', 'mw'],
    "gṛtsa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "gṛtsamada": ['cae', 'gra', 'mw'],
    "gṛtsamati": ['mw'],
    "gṛtsapati": ['mw'],
    "gṛtsatamas": ['mw'],
    "gṛñj": ['mw'],
    "gṛñja": ['cae', 'ddsa', 'mw'],
    "gṛñjana": ['cae', 'mw'],
    "gṛñjanaka": ['cae', 'mw'],
    "gṛñjina": ['mw'],
    "gṛṃjanaḥ": ['ap90'],
    "gṛṃḍivaḥ": ['ap90'],
    "gṛṃḍīvaḥ": ['ap90'],
    "gṛṇat": ['ddsa', 'mw'],
    "gṛṇīṣaṇi": ['gra'],
    "gṛṇḍiva": ['mw'],
    "gṛṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "gṛṣṭikā": ['mw'],
    "gṛṣṭiḥ": ['ap90'],
    "gṛṣṭyādi": ['mw'],
    "gṝ": ['ap90', 'mw'],
    "ha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "habasora": ['mw'],
    "habuṣā": ['mw'],
    "haci": ['mw'],
    "hacipura": ['mw'],
    "had": ['ap90', 'cae', 'mw'],
    "hadana": ['mw'],
    "hadanaṃ": ['ap90'],
    "hadati": ['cped'],
    "hadaya": ['cped'],
    "hadayamaṁsa": ['cped'],
    "hadayanissita": ['cped'],
    "hadayasantāpa": ['cped'],
    "hadayassita": ['cped'],
    "hadayavatthu": ['cped'],
    "hadayaṅgama": ['cped'],
    "hadda": ['mw'],
    "haddeśa": ['mw'],
    "hahala": ['mw'],
    "hahalaṃ": ['ap90'],
    "hahava": ['bhs', 'mw'],
    "hahe": ['mw'],
    "hahā": ['ap90', 'ddsa', 'mw'],
    "hahāhā": ['mw'],
    "hahāla": ['mw'],
    "hai": ['ap90', 'cae', 'ddsa', 'mw'],
    "haidaraśāha": ['mw'],
    "haihaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "haihayendrakāvya": ['mw'],
    "haiheya": ['mw'],
    "haiheyaḥ": ['ap90'],
    "hailihila": ['mw'],
    "haima": ['ap90', 'cae', 'ddsa', 'mw'],
    "haimacandri": ['mw'],
    "haimacarci": ['mw'],
    "haimacitrasamutsedha": ['mw'],
    "haimagirika": ['mw'],
    "haimahā": ['mw'],
    "haimakośa": ['mw'],
    "haimakūṭa": ['mw'],
    "haimala": ['ap90', 'mw'],
    "haimamudrika": ['mw'],
    "haimamudrikā": ['mw'],
    "haimamudrā": ['mw'],
    "haimana": ['ap90', 'cae', 'ddsa', 'mw'],
    "haimanta": ['ddsa', 'mw'],
    "haimantika": ['bhs', 'cae', 'ddsa', 'mw'],
    "haimaprākṛtadhuṇḍikā": ['mw'],
    "haimasaugandhikavat": ['mw'],
    "haimavalkala": ['mw'],
    "haimavat": ['mw'],
    "haimavata": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "haimavatika": ['mw'],
    "haimavatī": ['ap90', 'mw'],
    "haimavibhramasūtra": ['mw'],
    "haimaśaila": ['mw'],
    "haimaṃtika": ['ap90'],
    "haiminī": ['mw'],
    "haimā": ['mw'],
    "haimācala": ['ddsa', 'mw'],
    "haimānekārtha": ['mw'],
    "haimāṅgikīgaurāṅgadevastuti": ['mw'],
    "haimī": ['mw'],
    "haimībhū": ['cae', 'ddsa'],
    "haimībhūta": ['mw'],
    "hairamba": ['ddsa', 'mw'],
    "hairaṇvatī": ['mw'],
    "hairaṇya": ['cae', 'ddsa', 'mw'],
    "hairaṇyabāheya": ['mw'],
    "hairaṇyagarbha": ['cae', 'ddsa', 'mw'],
    "hairaṇyaka": ['cae', 'mw'],
    "hairaṇyanābha": ['mw'],
    "hairaṇyastūpa": ['mw'],
    "hairaṇyavāsas": ['ap90', 'mw'],
    "hairaṇyika": ['bhs', 'mw'],
    "hairika": ['ddsa', 'mw'],
    "hairikaḥ": ['ap90'],
    "haitanāman": ['mw'],
    "haitanāmana": ['mw'],
    "haituka": ['ap90', 'cae', 'ddsa', 'mw'],
    "haitukya": ['mw'],
    "haivam": ['mw'],
    "haiyaṃgava": ['mw'],
    "haiyaṃgavīna": ['mw'],
    "haiyaṃgavīnaṃ": ['ap90'],
    "haiyaṅgavīna": ['ddsa'],
    "haiḍimba": ['cae', 'mw'],
    "haiḍimbi": ['mw'],
    "haiṃsakāyana": ['mw'],
    "haiṅgula": ['ddsa', 'mw'],
    "hajadeśa": ['mw'],
    "hajāja": ['mw'],
    "hajāji": ['mw'],
    "hak": ['mw'],
    "hakka": ['mw'],
    "hakkaya": ['mw'],
    "hakkaḥ": ['ap90'],
    "hakkā": ['mw'],
    "hakkāhakka": ['mw'],
    "hakkāpradhānā": ['mw'],
    "hakkāra": ['bhs', 'mw'],
    "hakāra": ['mw'],
    "hal": ['ap90', 'ddsa', 'mw'],
    "hala": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "halabandha": ['mw'],
    "halabhūti": ['mw'],
    "halabhṛt": ['cae', 'mw'],
    "halabhṛti": ['mw'],
    "haladaṇḍa": ['mw'],
    "haladdī": ['mw'],
    "haladhara": ['bhs', 'cae', 'mw'],
    "haladī": ['mw'],
    "halagolaka": ['mw'],
    "halahala": ['mw'],
    "halahalā": ['cae', 'ddsa', 'mw'],
    "halahalāśabda": ['mw'],
    "halahati": ['mw'],
    "halaka": ['bhs', 'mw'],
    "halakakud": ['mw'],
    "halakin": ['mw'],
    "halakā": ['mw'],
    "halamuhūrta": ['mw'],
    "halamukha": ['cae', 'mw'],
    "halamukhī": ['mw'],
    "halamārga": ['cae', 'mw'],
    "halanta": ['mw'],
    "halarada": ['mw'],
    "halarākṣa": ['mw'],
    "halasīra": ['bhs', 'mw'],
    "halavaṃśa": ['mw'],
    "halavāhā": ['mw'],
    "halaya": ['mw'],
    "halaṁ": ['cped'],
    "haledvipadikā": ['mw'],
    "halha": ['mw'],
    "hali": ['ddsa', 'mw'],
    "halibha": ['bhs', 'mw'],
    "halibhu": ['bhs'],
    "haliddā": ['cped'],
    "haliddī": ['cped'],
    "halika": ['mw'],
    "halikṣṇa": ['cae', 'mw'],
    "halimā": ['mw'],
    "halin": ['ap90', 'cae', 'ddsa', 'mw'],
    "halinī": ['ap90', 'mw'],
    "halipriya": ['mw'],
    "halipriyā": ['mw'],
    "halirāma": ['mw'],
    "halita": ['bhs'],
    "haliḥ": ['ap90'],
    "haliṅgu": ['mw'],
    "halla": ['mw'],
    "hallaka": ['mw'],
    "hallakaṃ": ['ap90'],
    "hallana": ['mw'],
    "hallanaṃ": ['ap90'],
    "hallīsa": ['mw'],
    "hallīsaka": ['mw'],
    "hallīsakāya": ['mw'],
    "hallīśa": ['ddsa', 'mw'],
    "hallīśaka": ['mw'],
    "hallīśakaḥ": ['ap90'],
    "hallīśaṃ": ['ap90'],
    "hallīṣa": ['mw'],
    "hallīṣaka": ['mw'],
    "hallīṣaṃ": ['ap90'],
    "haluhāra": ['mw'],
    "haluāṇa": ['mw'],
    "halya": ['ap90', 'mw'],
    "halyā": ['ap90', 'mw'],
    "halā": ['ap90', 'cae', 'ddsa', 'mw'],
    "halābha": ['mw'],
    "halābhiyoga": ['mw'],
    "halāha": ['mw'],
    "halāhala": ['cae', 'ddsa', 'mw'],
    "halāhalaṃ": ['ap90'],
    "halāhana": ['cped'],
    "halāhaḥ": ['ap90'],
    "halāyudha": ['cae', 'ddsa', 'mw'],
    "halāyudhacchāndogya": ['mw'],
    "halāyudhastava": ['mw'],
    "halī": ['mw'],
    "halīkṣṇa": ['cae', 'mw'],
    "halīma": ['mw'],
    "halīmaka": ['mw'],
    "halīna": ['mw'],
    "halīnaḥ": ['ap90'],
    "halīṣā": ['ap90', 'mw'],
    "halūāṇa": ['mw'],
    "ham": ['ap90', 'bhs', 'ddsa', 'mw'],
    "hama": ['ddsa', 'mw'],
    "hamba": ['ddsa', 'mw'],
    "hambho": ['bhs', 'cped'],
    "hambhā": ['cae', 'ddsa', 'mw'],
    "hambhārava": ['mw'],
    "hambhāy": ['cae'],
    "hambhāya": ['mw'],
    "hambhāśabda": ['mw'],
    "hambā": ['mw'],
    "hambīrā": ['mw'],
    "hamm": ['mw'],
    "hammiya": ['cped'],
    "hammīra": ['ddsa', 'mw'],
    "hammīracarita": ['mw'],
    "hamīpurya": ['mw'],
    "hamīāṇa": ['mw'],
    "han": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hana": ['mw'],
    "hanamāna": ['cped'],
    "hanana": ['cae', 'cped', 'mw'],
    "hananaśīla": ['mw'],
    "hananaṃ": ['ap90'],
    "hananta": ['cped'],
    "hananīya": ['mw'],
    "hananīyaka": ['mw'],
    "hanati": ['cped'],
    "hanavya": ['mw'],
    "hanaḥ": ['ap90'],
    "handa": ['cped'],
    "hani": ['cped', 'mw'],
    "hanitabba": ['cped'],
    "hanituṁ": ['cped'],
    "hanitvā": ['cped'],
    "haniṣṭha": ['gra'],
    "hanman": ['cae', 'gra', 'mw'],
    "hanna": ['mw'],
    "hannaṃ": ['ap90'],
    "hanta": ['cae', 'ddsa', 'gra', 'mw'],
    "hantabba": ['cped'],
    "hantakāra": ['mw'],
    "hantar": ['cped'],
    "hantavai": ['mw'],
    "hantave": ['mw'],
    "hantavya": ['cae', 'ddsa', 'mw'],
    "hanti": ['cped', 'mw'],
    "hantokti": ['mw'],
    "hantrī": ['mw'],
    "hantrīmukha": ['mw'],
    "hantu": ['cae', 'mw'],
    "hantukāma": ['cae', 'mw'],
    "hantula": ['bhs'],
    "hantumanas": ['mw'],
    "hantuṁ": ['cped'],
    "hantva": ['cae', 'mw'],
    "hantvā": ['cped'],
    "hantṛ": ['cae', 'gra', 'mw'],
    "hantṛtva": ['mw'],
    "hanu": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "hanubheda": ['mw'],
    "hanugraha": ['mw'],
    "hanukā": ['cped', 'mw'],
    "hanula": ['mw'],
    "hanumac": ['mw'],
    "hanumacchata": ['mw'],
    "hanumacitra": ['bhs'],
    "hanumad": ['mw'],
    "hanumadaṅgadasaṃvāda": ['mw'],
    "hanumadaṣṭaka": ['mw'],
    "hanumadaṣṭottaraśatanāman": ['mw'],
    "hanumadbali": ['mw'],
    "hanumadbhāṣya": ['mw'],
    "hanumadbāhuka": ['mw'],
    "hanumaddaṇḍaka": ['mw'],
    "hanumaddurga": ['mw'],
    "hanumaddvādaśanāman": ['mw'],
    "hanumaddīpa": ['mw'],
    "hanumadekamukhakavaca": ['mw'],
    "hanumadgahvara": ['mw'],
    "hanumadrāmāyaṇa": ['mw'],
    "hanumadupaniṣad": ['mw'],
    "hanumadviṣayamantra": ['mw'],
    "hanumadvratakalpa": ['mw'],
    "hanumadīya": ['mw'],
    "hanumaj": ['mw'],
    "hanumajjayantī": ['mw'],
    "hanuman": ['mw'],
    "hanumanmantragahvara": ['mw'],
    "hanumanmantroddhāra": ['mw'],
    "hanumanmālāmantra": ['mw'],
    "hanumannighaṇṭu": ['mw'],
    "hanumannāṭaka": ['cae', 'mw'],
    "hanumant": ['cae'],
    "hanumanta": ['mw'],
    "hanumantabhaṭṭīya": ['mw'],
    "hanumanteśvara": ['mw'],
    "hanumanteśvaratīrtha": ['mw'],
    "hanumat": ['ap90', 'mw'],
    "hanumatkalpa": ['mw'],
    "hanumatkavaca": ['mw'],
    "hanumatkāvya": ['mw'],
    "hanumatkīrtana": ['mw'],
    "hanumatpaddhati": ['mw'],
    "hanumatpañcāṅga": ['mw'],
    "hanumatpaṭala": ['mw'],
    "hanumatprabandha": ['mw'],
    "hanumatpratiṣṭhā": ['mw'],
    "hanumatpratiṣṭhākalpa": ['mw'],
    "hanumatprātaḥstotra": ['mw'],
    "hanumatsahasranāman": ['mw'],
    "hanumatsaṃhitā": ['mw'],
    "hanumatstotra": ['mw'],
    "hanumattailavidhi": ['mw'],
    "hanumokṣa": ['mw'],
    "hanumātīra": ['bhs'],
    "hanusaṃhanana": ['mw'],
    "hanusaṃhati": ['mw'],
    "hanustambha": ['mw'],
    "hanusvana": ['mw'],
    "hanuta": ['cped'],
    "hanuṣa": ['mw'],
    "hanuṣkambha": ['mw'],
    "hanyamāna": ['mw'],
    "hanā": ['mw'],
    "hanīla": ['mw'],
    "hanīyas": ['mw'],
    "hanīyaṃs": ['cae'],
    "hanūmant": ['cae'],
    "hanūmat": ['ap90', 'mw'],
    "hanūṣa": ['mw'],
    "hanūṣaḥ": ['ap90'],
    "hapuṣā": ['mw'],
    "har": ['gra'],
    "hara": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "harabala": ['mw'],
    "harabīja": ['mw'],
    "haracaritacintāmaṇi": ['mw'],
    "haracāpāropaṇa": ['mw'],
    "haracūḍāmaṇi": ['mw'],
    "haradagdhamūrti": ['mw'],
    "haradatta": ['cae', 'mw'],
    "haradattacaritra": ['mw'],
    "haradattasiṃha": ['mw'],
    "haradattācārya": ['mw'],
    "haradattīya": ['mw'],
    "haradāsa": ['mw'],
    "haragalagaralatamāla": ['ddsa'],
    "haragaurī": ['mw'],
    "haragaurīsaṃvāda": ['mw'],
    "haragaṇa": ['mw'],
    "haragovinda": ['mw'],
    "haragupta": ['mw'],
    "harahāra": ['mw'],
    "harahūrā": ['mw'],
    "harajit": ['mw'],
    "harajī": ['mw'],
    "haraka": ['mw'],
    "harakaḥ": ['ap90'],
    "harakeli": ['mw'],
    "harakeśa": ['mw'],
    "harakośa": ['mw'],
    "harakumāraṭhakkura": ['mw'],
    "harakṣetra": ['mw'],
    "haramekhalin": ['mw'],
    "haramekhalā": ['mw'],
    "haramohana": ['mw'],
    "haramuja": ['mw'],
    "haramukuṭamāhātmya": ['mw'],
    "haramāna": ['cped'],
    "haranartaka": ['mw'],
    "haranetra": ['cae', 'mw'],
    "haranta": ['cped'],
    "haranārāyaṇa": ['mw'],
    "haranātha": ['mw'],
    "harapati": ['mw'],
    "harapradīpikā": ['mw'],
    "harapriya": ['mw'],
    "hararāta": ['mw'],
    "hararūpa": ['mw'],
    "haras": ['cae', 'ddsa', 'gra', 'mw'],
    "harasakha": ['cae', 'ddsa', 'mw'],
    "harasiddhipradā": ['mw'],
    "harasiṃha": ['mw'],
    "harasvat": ['gra', 'mw'],
    "harasvin": ['ddsa', 'mw'],
    "harasvāmin": ['mw'],
    "harasūnu": ['cae', 'mw'],
    "haratejas": ['mw'],
    "harati": ['cped'],
    "harave": ['mw'],
    "haravijaya": ['mw'],
    "haravilāsa": ['mw'],
    "haravṛṣabha": ['cae'],
    "harayāṇa": ['cae', 'gra', 'mw'],
    "haraśekharā": ['mw'],
    "haraśūra": ['mw'],
    "haraśṛṅgārā": ['mw'],
    "haraṇa": ['cae', 'cped', 'mw'],
    "haraṇabhāga": ['mw'],
    "haraṇahārika": ['mw'],
    "haraṇaka": ['cped'],
    "haraṇaṃ": ['ap90'],
    "haraṇi": ['mw'],
    "haraṇāharaṇa": ['mw'],
    "haraṇīya": ['mw'],
    "hare": ['cped'],
    "harekṛṣṇamahāmantrārthanirūpaṇa": ['mw'],
    "hareśvara": ['mw'],
    "hareṇu": ['cae', 'ddsa', 'mw'],
    "hareṇuka": ['mw'],
    "hareṇukaḥ": ['ap90'],
    "hareṇuḥ": ['ap90'],
    "hareṇḍa": ['bhs'],
    "hari": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "hariaśva": ['gra'],
    "hariaśvaprasūta": ['gra'],
    "haribabhru": ['mw'],
    "haribala": ['mw'],
    "haribha": ['bhs', 'mw'],
    "haribhadra": ['mw'],
    "haribhadrasūri": ['mw'],
    "haribhadrasūrikathā": ['mw'],
    "haribhakta": ['mw'],
    "haribhakti": ['mw'],
    "haribhaktibhāskarasadvaiṣṇavasārasarvasva": ['mw'],
    "haribhaktibhāskarodaya": ['mw'],
    "haribhaktidīpikā": ['mw'],
    "haribhaktikalpalatikā": ['mw'],
    "haribhaktikalpalatā": ['mw'],
    "haribhaktilatikāstava": ['mw'],
    "haribhaktilatā": ['mw'],
    "haribhaktirahasya": ['mw'],
    "haribhaktirasāmṛtasindhu": ['mw'],
    "haribhaktirasāyana": ['mw'],
    "haribhaktisamāgama": ['mw'],
    "haribhaktisudhodaya": ['mw'],
    "haribhaktisudhārasa": ['mw'],
    "haribhaktisāra": ['mw'],
    "haribhaktitaraṃgiṇī": ['mw'],
    "haribhaktivilāsa": ['mw'],
    "haribhaṭa": ['mw'],
    "haribhaṭṭa": ['mw'],
    "haribhaṭṭadīkṣita": ['mw'],
    "haribhuj": ['mw'],
    "haribhānu": ['mw'],
    "haribhānuśukla": ['mw'],
    "haribhāratī": ['mw'],
    "haribhāskara": ['mw'],
    "haribhāskaraśarman": ['mw'],
    "haribhāvinī": ['mw'],
    "haribhāviṇī": ['mw'],
    "haribhūta": ['mw'],
    "haribodha": ['mw'],
    "haribodhadina": ['mw'],
    "haribrahman": ['mw'],
    "haribuṅgapura": ['mw'],
    "haribābā": ['mw'],
    "haribīja": ['mw'],
    "haricandana": ['cae', 'mw'],
    "haricandanāspada": ['mw'],
    "haricandra": ['mw'],
    "haricandrā": ['bhs'],
    "haricaraṇadāsa": ['mw'],
    "haricaraṇapurī": ['mw'],
    "haricāpa": ['mw'],
    "harid": ['mw'],
    "haridambara": ['mw'],
    "haridarbha": ['mw'],
    "haridatta": ['cae', 'ddsa', 'mw'],
    "haridattabhaṭṭa": ['mw'],
    "haridattadaivajña": ['mw'],
    "haridattamiśra": ['mw'],
    "haridattā": ['mw'],
    "haridaśva": ['cae', 'ddsa', 'mw'],
    "hariddantāvala": ['mw'],
    "harideva": ['mw'],
    "haridevamiśra": ['mw'],
    "haridevasūri": ['mw'],
    "haridgarbha": ['mw'],
    "haridhāritagrantha": ['mw'],
    "haridhāyas": ['gra', 'mw'],
    "haridhūmra": ['mw'],
    "haridina": ['mw'],
    "haridinatilaka": ['mw'],
    "haridiś": ['mw'],
    "haridra": ['cae', 'mw'],
    "haridraka": ['mw'],
    "haridrava": ['mw'],
    "haridrañjanī": ['mw'],
    "haridrika": ['mw'],
    "haridru": ['ddsa', 'gra', 'mw'],
    "haridruka": ['mw'],
    "haridrumat": ['mw'],
    "haridrā": ['ap90', 'ddsa', 'mw'],
    "haridrābha": ['mw'],
    "haridrādvaya": ['mw'],
    "haridrādāna": ['mw'],
    "haridrāgaṇapati": ['mw'],
    "haridrāgaṇapatiprakaraṇa": ['mw'],
    "haridrāgaṇeśa": ['mw'],
    "haridrākta": ['mw'],
    "haridrāmeha": ['mw'],
    "haridrāmehin": ['mw'],
    "haridrārāga": ['mw'],
    "haridrārāgaka": ['mw'],
    "haridrāṅga": ['mw'],
    "haridvarṇa": ['mw'],
    "haridviṣ": ['mw'],
    "haridvāra": ['ddsa', 'mw'],
    "haridvāramāhātmya": ['mw'],
    "haridāsa": ['mw'],
    "haridāsabhaṭṭa": ['mw'],
    "haridāsabhaṭṭācārya": ['mw'],
    "haridāsamiśra": ['mw'],
    "haridāsanyāyavācaspatitarkālaṃkārabhaṭṭācārya": ['mw'],
    "haridāsatarkācārya": ['mw'],
    "haridāsavijaya": ['mw'],
    "haridīkṣita": ['mw'],
    "haridūta": ['mw'],
    "haridṛśvan": ['mw'],
    "harigandha": ['mw'],
    "harigati": ['mw'],
    "harigaṇa": ['mw'],
    "harighoṣa": ['mw'],
    "harigiri": ['cae', 'mw'],
    "harigopaka": ['cae', 'mw'],
    "harigurustavamālā": ['mw'],
    "hariguṇamaṇidarpaṇa": ['mw'],
    "harigītā": ['mw'],
    "harigṛha": ['mw'],
    "harihara": ['cae', 'mw'],
    "hariharabhaṭṭa": ['mw'],
    "hariharabhaṭṭācārya": ['mw'],
    "hariharabhedadhikkāra": ['mw'],
    "hariharabhāṣya": ['mw'],
    "hariharabrahmamānasikasnānavidhi": ['mw'],
    "hariharabrahman": ['mw'],
    "hariharadeva": ['mw'],
    "hariharadevahindūpati": ['mw'],
    "hariharadīkṣita": ['mw'],
    "hariharadīkṣitīya": ['mw'],
    "hariharakathā": ['mw'],
    "hariharakhāna": ['mw'],
    "hariharakṣetra": ['mw'],
    "hariharamahārāja": ['mw'],
    "hariharamaṇḍalaṣoḍaśaliṅgodbhava": ['mw'],
    "hariharamiśra": ['mw'],
    "hariharamāhātmya": ['mw'],
    "hariharapaddhati": ['mw'],
    "hariharapaṇḍita": ['mw'],
    "hariharaprasāda": ['mw'],
    "hariharapraśaṃsā": ['mw'],
    "hariharapurī": ['mw'],
    "hariharasarasvatī": ['mw'],
    "hariharastotra": ['mw'],
    "hariharasvāmin": ['mw'],
    "hariharatarkālaṃkārabhaṭṭācārya": ['mw'],
    "hariharatāratamya": ['mw'],
    "hariharavilāsa": ['mw'],
    "hariharayoga": ['mw'],
    "harihariharivāha": ['mw'],
    "harihariharivāhanasādhana": ['mw'],
    "harihariharivāhanodbhava": ['bhs'],
    "hariharopādhivivecana": ['mw'],
    "hariharopādhyāya": ['mw'],
    "hariharāgnihotrin": ['mw'],
    "hariharānanda": ['mw'],
    "hariharānusaraṇayātrā": ['mw'],
    "hariharārya": ['mw'],
    "hariharātmaka": ['mw'],
    "hariharātmakastotra": ['mw'],
    "hariharāṣṭottaraśatanāman": ['mw'],
    "hariharāṣṭottaraśatanāmāvali": ['mw'],
    "harihaya": ['cae', 'mw'],
    "harihayānuja": ['mw'],
    "hariheti": ['cae', 'mw'],
    "harihetihūti": ['mw'],
    "harihetimant": ['cae'],
    "harihetimat": ['mw'],
    "harija": ['mw'],
    "harijit": ['mw'],
    "harijāta": ['gra', 'mw'],
    "harijīva": ['mw'],
    "harijīvanamiśra": ['mw'],
    "harika": ['mw'],
    "harikarṇa": ['mw'],
    "harikathāmṛta": ['mw'],
    "harikavi": ['mw'],
    "harikavīndra": ['mw'],
    "harikaḥ": ['ap90'],
    "harikaṇṭha": ['mw'],
    "harikelika": ['bhs'],
    "harikelīya": ['mw'],
    "harikeśa": ['cae', 'gra', 'mw'],
    "harikeśī": ['bhs'],
    "harikrāntā": ['mw'],
    "harikutsa": ['mw'],
    "harikāladeva": ['mw'],
    "harikālāvrata": ['mw'],
    "harikālītṛtīyā": ['mw'],
    "harikālītṛtīyāvrata": ['mw'],
    "harikānta": ['mw'],
    "harikārikā": ['mw'],
    "harikīrtana": ['mw'],
    "harikṛṣṇa": ['mw'],
    "harikṛṣṇasamuddhāra": ['mw'],
    "harikṛṣṇasiddhānta": ['mw'],
    "harikṣetra": ['mw'],
    "harile": ['mw'],
    "harilocana": ['mw'],
    "harilocanacandrikā": ['mw'],
    "hariloman": ['mw'],
    "harilāla": ['mw'],
    "harilālamiśra": ['mw'],
    "harilīlā": ['mw'],
    "harilīlākṛṣṇakautaka": ['mw'],
    "harilīlāmṛta": ['mw'],
    "harilīlāvivaraṇasaṃgraha": ['mw'],
    "harilīlāviveka": ['mw'],
    "harimadhyā": ['mw'],
    "harimahiman": ['mw'],
    "hariman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "harimandira": ['mw'],
    "harimant": ['cae'],
    "harimanta": ['mw'],
    "harimantha": ['mw'],
    "harimanthaja": ['mw'],
    "harimanthaka": ['mw'],
    "harimanyusāyaka": ['gra', 'mw'],
    "harimat": ['mw'],
    "harimaṇi": ['mw'],
    "harimaṇḍalākṣa": ['mw'],
    "harimbhara": ['gra', 'mw'],
    "harimedha": ['mw'],
    "harimedhas": ['mw'],
    "harimitra": ['mw'],
    "harimiśra": ['mw'],
    "harimuktāvalī": ['mw'],
    "harimāhātmyadarpaṇa": ['mw'],
    "harimālā": ['mw'],
    "harimīḍe": ['mw'],
    "harimīḍestotra": ['mw'],
    "harin": ['mw'],
    "harinadī": ['mw'],
    "harinadīramya": ['mw'],
    "harinaigumeṣin": ['mw'],
    "harinakṣatra": ['mw'],
    "harinanda": ['mw'],
    "harinandana": ['mw'],
    "harinandin": ['mw'],
    "harinetra": ['cae', 'mw'],
    "harinmaṇi": ['ddsa', 'mw'],
    "harinmaṇimaya": ['mw'],
    "harinmudga": ['mw'],
    "harinābha": ['mw'],
    "harināmakavaca": ['mw'],
    "harināmamālā": ['mw'],
    "harināman": ['mw'],
    "harināmavyākhyā": ['mw'],
    "harināmopaniṣad": ['mw'],
    "harināmāmṛta": ['mw'],
    "harināmāmṛtavaiṣṇavavyākaraṇa": ['mw'],
    "harinānākṛti": ['mw'],
    "harinārāyaṇa": ['mw'],
    "harinārāyaṇaśarman": ['mw'],
    "harinārāyaṇīya": ['mw'],
    "harinātha": ['mw'],
    "harināthagosvāmin": ['mw'],
    "harināthamahopādhyāya": ['mw'],
    "harināthopādhyāya": ['mw'],
    "harināthācārya": ['mw'],
    "harināyaka": ['mw'],
    "harinīla": ['mw'],
    "haripada": ['mw'],
    "hariparvata": ['mw'],
    "hariparṇa": ['mw'],
    "haripañcakavrata": ['mw'],
    "haripañcāyudhastotra": ['mw'],
    "haripaṇḍita": ['mw'],
    "haripaṇḍitīya": ['mw'],
    "haripiṅga": ['cae', 'ddsa', 'mw'],
    "haripiṅgala": ['cae', 'mw'],
    "haripiṅgalā": ['bhs'],
    "haripiṇḍā": ['mw'],
    "hariprabha": ['mw'],
    "hariprabhatva": ['mw'],
    "hariprabodha": ['cae', 'mw'],
    "hariprasāda": ['mw'],
    "hariprasādamāhātmya": ['mw'],
    "haripriya": ['cae', 'gra', 'mw'],
    "haripriyā": ['mw'],
    "haripura": ['mw'],
    "haripā": ['gra', 'mw'],
    "haripāla": ['mw'],
    "haripālabhaṭṭa": ['mw'],
    "haripāladeva": ['mw'],
    "haripūjanavidhi": ['mw'],
    "haripūjāpaddhati": ['mw'],
    "harirasakavi": ['mw'],
    "hariratna": ['mw'],
    "hariripu": ['mw'],
    "hariroman": ['mw'],
    "harirudra": ['mw'],
    "harirāja": ['ddsa', 'mw'],
    "harirāma": ['mw'],
    "harirāmabhaṭṭācārya": ['mw'],
    "harirāmacakravartin": ['mw'],
    "harirāmatarkavāgīśa": ['mw'],
    "harirāmatarkavāgīśabhaṭṭācārya": ['mw'],
    "harirāmatarkālaṃkāra": ['mw'],
    "harirāmatarkālaṃkārabhaṭṭācārya": ['mw'],
    "harirāmavācaspati": ['mw'],
    "harirāya": ['mw'],
    "harirāyaśarman": ['mw'],
    "harisa": ['bhs'],
    "harisakha": ['mw'],
    "harisaktha": ['mw'],
    "harisaṃkīrtana": ['mw'],
    "harisena": ['mw'],
    "harisevakamiśra": ['mw'],
    "harisiddhi": ['mw'],
    "harisiṃha": ['cae', 'mw'],
    "harisiṃhadeva": ['mw'],
    "harisoma": ['mw'],
    "harissavaṇṇa": ['cped'],
    "haristava": ['mw'],
    "haristotra": ['mw'],
    "haristuti": ['mw'],
    "harisumeruśrī": ['bhs'],
    "harisuta": ['mw'],
    "harisvāmin": ['mw'],
    "harisvāmiputra": ['mw'],
    "harisādhanacandrikā": ['mw'],
    "harisūkta": ['mw'],
    "harisūnu": ['mw'],
    "harit": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "harita": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "haritabba": ['cped'],
    "haritabheṣaja": ['mw'],
    "haritacchada": ['cae', 'mw'],
    "haritacārika": ['bhs', 'mw'],
    "haritadhānya": ['cae', 'mw'],
    "haritagarbha": ['mw'],
    "haritagomaya": ['cae', 'mw'],
    "haritahari": ['mw'],
    "haritajambhan": ['mw'],
    "haritaka": ['mw'],
    "haritakapiśa": ['cae', 'mw'],
    "haritakaśāka": ['mw'],
    "haritakaṃ": ['ap90'],
    "haritakātya": ['mw'],
    "haritakī": ['mw'],
    "haritalatā": ['mw'],
    "haritanemin": ['mw'],
    "haritapattramaya": ['mw'],
    "haritapattrikā": ['mw'],
    "haritaprabha": ['mw'],
    "haritapāṇḍu": ['mw'],
    "haritar": ['cped'],
    "haritasena": ['mw'],
    "haritaspṛśa": ['mw'],
    "haritasraj": ['cae', 'mw'],
    "haritatta": ['cped'],
    "haritattvamuktāvali": ['mw'],
    "haritattvamuktāvalī": ['mw'],
    "haritatva": ['mw'],
    "haritatṛṇa": ['mw'],
    "haritayajña": ['mw'],
    "haritayava": ['cae', 'mw'],
    "haritaśāka": ['mw'],
    "haritmat": ['mw'],
    "haritopala": ['ddsa', 'mw'],
    "haritoṣaṇa": ['mw'],
    "haritparṇa": ['mw'],
    "haritpati": ['ddsa', 'mw'],
    "haritrāta": ['mw'],
    "harittaca": ['cped'],
    "harituraga": ['mw'],
    "harituraṃgama": ['mw'],
    "harituraṃgamāyudha": ['mw'],
    "harituṁ": ['cped'],
    "haritvac": ['cae', 'mw'],
    "haritvant": ['cae'],
    "haritvat": ['gra', 'mw'],
    "haritvā": ['cped'],
    "haritā": ['ap90', 'ddsa', 'mw'],
    "haritāla": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "haritālajanaka": ['mw'],
    "haritālaka": ['mw'],
    "haritālamaya": ['mw'],
    "haritālikā": ['mw'],
    "haritālikākathā": ['mw'],
    "haritālikāpūjana": ['mw'],
    "haritālikāvrata": ['mw'],
    "haritālikāvratakathā": ['mw'],
    "haritālikāvratanirṇaya": ['mw'],
    "haritālī": ['mw'],
    "haritārdhakāya": ['mw'],
    "haritāruṇa": ['mw'],
    "haritāya": ['ddsa', 'mw'],
    "haritāśma": ['mw'],
    "haritāśmaka": ['mw'],
    "haritāśman": ['ddsa'],
    "haritāśva": ['cae', 'mw'],
    "haritīkṛ": ['ddsa'],
    "haritīkṛta": ['mw'],
    "hariva": ['bhs', 'mw'],
    "harivallabha": ['mw'],
    "harivallabhā": ['mw'],
    "harivana": ['mw'],
    "harivandana": ['mw'],
    "harivant": ['cae'],
    "harivara": ['mw'],
    "harivarmadeva": ['mw'],
    "harivarman": ['mw'],
    "harivarpas": ['cae', 'gra', 'mw'],
    "harivarṇa": ['mw'],
    "harivarṣa": ['mw'],
    "harivat": ['ddsa', 'gra', 'mw'],
    "harivaṃśa": ['cae', 'mw'],
    "harivaṃśabhaṭṭa": ['mw'],
    "harivaṃśacandragosvāmin": ['mw'],
    "harivaṃśacatuṣka": ['mw'],
    "harivaṃśadeva": ['mw'],
    "harivaṃśagosvāmin": ['mw'],
    "harivaṃśakavi": ['mw'],
    "harivaṃśakṛṣṇalīlā": ['mw'],
    "harivaṃśanyāsa": ['mw'],
    "harivaṃśapaṇḍita": ['mw'],
    "harivaṃśapurāṇa": ['mw'],
    "harivaṃśasāracarita": ['mw'],
    "harivaṃśavilāsa": ['mw'],
    "harivaṃśaśravaṇavidhi": ['mw'],
    "harivaṃśaśravaṇavidhāna": ['mw'],
    "harivaṃśya": ['mw'],
    "harivijaya": ['mw'],
    "harivijayakāvya": ['mw'],
    "harivilāsa": ['mw'],
    "harivilāsakāvya": ['mw'],
    "harivinoda": ['mw'],
    "harivrata": ['gra', 'mw'],
    "harivyāsa": ['mw'],
    "harivyāsadeva": ['mw'],
    "harivyāsamiśra": ['mw'],
    "harivyāsamuni": ['mw'],
    "harivāghala": ['mw'],
    "harivāhana": ['cae', 'mw'],
    "harivāhanadiś": ['mw'],
    "harivāluka": ['mw'],
    "harivāsa": ['mw'],
    "harivāsara": ['mw'],
    "harivāsuka": ['mw'],
    "harivāyustuti": ['mw'],
    "harivṛkṣa": ['mw'],
    "harivṛṣa": ['mw'],
    "hariya": ['mw'],
    "hariyaśas": ['mw'],
    "hariyaśomiśra": ['mw'],
    "hariyaḥ": ['ap90'],
    "hariyoga": ['cae', 'gra', 'mw'],
    "hariyojana": ['cae', 'gra', 'mw'],
    "hariyoni": ['mw'],
    "hariyūpa": ['gra'],
    "hariyūpīyā": ['gra', 'mw'],
    "hariśa": ['mw'],
    "hariśara": ['mw'],
    "hariśarman": ['cae', 'mw'],
    "hariśarmārya": ['mw'],
    "hariśaya": ['mw'],
    "hariśayana": ['mw'],
    "hariśayā": ['mw'],
    "hariśaṃkara": ['mw'],
    "hariścandra": ['cae', 'ddsa', 'gra', 'mw'],
    "hariścandracaritra": ['mw'],
    "hariścandrapura": ['mw'],
    "hariścandrapurāṇa": ['mw'],
    "hariścandratīrtha": ['mw'],
    "hariścandrayaśaścandracandrikā": ['mw'],
    "hariścandropākhyāna": ['mw'],
    "hariścandrākhyāyikā": ['mw'],
    "hariścaṃdraḥ": ['ap90'],
    "hariśikha": ['cae', 'mw'],
    "hariśipra": ['gra', 'mw'],
    "hariśmaśru": ['cae', 'mw'],
    "hariśmaśāru": ['cae', 'gra', 'mw'],
    "hariśrama": ['mw'],
    "hariśravā": ['mw'],
    "hariśrāvā": ['mw'],
    "hariśrī": ['cae', 'gra', 'mw'],
    "hariśrīnidhana": ['mw'],
    "hariṇa": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "hariṇacarman": ['mw'],
    "hariṇadhāman": ['mw'],
    "hariṇahṛdaya": ['mw'],
    "hariṇaka": ['mw'],
    "hariṇakalaṅka": ['mw'],
    "hariṇakaḥ": ['ap90'],
    "hariṇalakṣaṇa": ['mw'],
    "hariṇalakṣman": ['mw'],
    "hariṇalocanā": ['mw'],
    "hariṇalolākṣī": ['mw'],
    "hariṇalāñchana": ['mw'],
    "hariṇanartaka": ['mw'],
    "hariṇanayanā": ['mw'],
    "hariṇapluta": ['mw'],
    "hariṇaplutā": ['mw'],
    "hariṇapṛṇākā": ['mw'],
    "hariṇekṣaṇa": ['cae', 'ddsa'],
    "hariṇekṣaṇā": ['mw'],
    "hariṇeśa": ['mw'],
    "hariṇādhipa": ['mw'],
    "hariṇākrīḍana": ['mw'],
    "hariṇākrīḍita": ['mw'],
    "hariṇākṣa": ['cae', 'mw'],
    "hariṇākṣī": ['mw'],
    "hariṇāntara": ['mw'],
    "hariṇāri": ['mw'],
    "hariṇāya": ['ddsa', 'mw'],
    "hariṇāyatekṣaṇā": ['ddsa', 'mw'],
    "hariṇāśva": ['mw'],
    "hariṇāṅka": ['mw'],
    "hariṇī": ['ap90', 'cae', 'ddsa', 'mw'],
    "hariṇīdṛś": ['cae', 'mw'],
    "hariṇīnayanā": ['cae'],
    "hariṇīnayaṇā": ['mw'],
    "hariṇīrūpāya": ['mw'],
    "hariṇīvṛtta": ['mw'],
    "hariṣa": ['mw'],
    "hariṣac": ['mw'],
    "hariṣeṇa": ['mw'],
    "hariṣāś": ['gra'],
    "hariṣṭhā": ['cae', 'gra', 'mw'],
    "harman": ['ap90', 'mw'],
    "harmia": ['gra'],
    "harmieṣṭhā": ['gra'],
    "harmika": ['bhs'],
    "harmikā": ['mw'],
    "harmita": ['ap90', 'mw'],
    "harmiya": ['bhs'],
    "harmuṭa": ['mw'],
    "harmya": ['cae', 'ddsa', 'gra', 'mw'],
    "harmyabhāj": ['mw'],
    "harmyacara": ['mw'],
    "harmyapṛṣṭha": ['cae', 'mw'],
    "harmyastha": ['mw'],
    "harmyasthala": ['mw'],
    "harmyatala": ['cae', 'mw'],
    "harmyavalabhī": ['cae', 'mw'],
    "harmyaṃ": ['ap90'],
    "harmyeṣṭhā": ['cae', 'ddsa', 'mw'],
    "harmyāgra": ['mw'],
    "harmyāṅgana": ['mw'],
    "harodbheda": ['mw'],
    "harta": ['mw'],
    "hartavai": ['mw'],
    "hartave": ['mw'],
    "hartavya": ['cae', 'ddsa', 'mw'],
    "hartu": ['mw'],
    "hartālikāvratanirṇaya": ['mw'],
    "hartṛ": ['ap90', 'cae', 'mw'],
    "haruṇa": ['bhs', 'mw'],
    "hary": ['ap90', 'cae', 'gra', 'mw'],
    "harya": ['ddsa'],
    "haryajvāyana": ['mw'],
    "haryakṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "haryakṣan": ['mw'],
    "haryamara": ['mw'],
    "haryat": ['mw'],
    "haryata": ['cae', 'ddsa', 'gra', 'mw'],
    "haryataḥ": ['ap90'],
    "haryatvata": ['mw'],
    "haryavana": ['mw'],
    "haryaśva": ['cae', 'ddsa', 'gra', 'mw'],
    "haryaśvacāpa": ['cae', 'mw'],
    "haryaśvaprasūta": ['gra', 'mw'],
    "haryaṅga": ['mw'],
    "haryaṅkakula": ['mw'],
    "haryaṇī": ['bhs'],
    "haryaṣṭaka": ['mw'],
    "haryānanda": ['mw'],
    "haryāta": ['mw'],
    "haryātman": ['mw'],
    "harādri": ['ddsa', 'mw'],
    "harāhara": ['mw'],
    "harāka": ['mw'],
    "harākṣa": ['mw'],
    "harānanda": ['mw'],
    "harānata": ['mw'],
    "harāpesi": ['cped'],
    "harāpeti": ['cped'],
    "harāpetvā": ['cped'],
    "harāpita": ['cped'],
    "harārdha": ['mw'],
    "harārdhatā": ['mw'],
    "harāspada": ['mw'],
    "harāvatī": ['mw'],
    "harāvāsa": ['mw'],
    "harāyatana": ['mw'],
    "harāyati": ['cped'],
    "harāyi": ['cped'],
    "harāyitvā": ['cped'],
    "harāśaya": ['mw'],
    "harāśayā": ['mw'],
    "harī": ['mw'],
    "harīman": ['mw'],
    "harīndravaiśeṣika": ['mw'],
    "harītaka": ['cae', 'cped', 'ddsa'],
    "harītakyādi": ['mw'],
    "harītakī": ['ap90', 'cped', 'mw'],
    "harītakīcūrṇa": ['mw'],
    "harītī": ['bhs'],
    "harīśa": ['cae', 'mw'],
    "harīśaya": ['mw'],
    "harīṣā": ['mw'],
    "harṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "harṣabhāj": ['mw'],
    "harṣacala": ['mw'],
    "harṣacarita": ['cae', 'mw'],
    "harṣacaritasaṃketa": ['mw'],
    "harṣacaritavārttika": ['mw'],
    "harṣadatta": ['bhs', 'mw'],
    "harṣadattasūnu": ['mw'],
    "harṣadeva": ['cae', 'ddsa', 'mw'],
    "harṣadhara": ['mw'],
    "harṣadohala": ['cae', 'mw'],
    "harṣadāna": ['mw'],
    "harṣagadgada": ['mw'],
    "harṣagarbha": ['cae', 'mw'],
    "harṣagaṇi": ['mw'],
    "harṣagupta": ['mw'],
    "harṣaja": ['mw'],
    "harṣajaḍa": ['mw'],
    "harṣaka": ['ap90', 'cae', 'mw'],
    "harṣakara": ['mw'],
    "harṣakaumudī": ['mw'],
    "harṣakrodha": ['mw'],
    "harṣakula": ['mw'],
    "harṣakulāgraṇī": ['mw'],
    "harṣakuśala": ['mw'],
    "harṣakīlaka": ['mw'],
    "harṣakīrti": ['mw'],
    "harṣakṛt": ['mw'],
    "harṣamalla": ['mw'],
    "harṣamaya": ['cae', 'mw'],
    "harṣamitra": ['mw'],
    "harṣanisvana": ['cae', 'mw'],
    "harṣaniḥsvana": ['cae', 'mw'],
    "harṣanāda": ['cae', 'mw'],
    "harṣanāthaśarman": ['mw'],
    "harṣapura": ['mw'],
    "harṣapurī": ['mw'],
    "harṣapūrṇavaktra": ['mw'],
    "harṣaratna": ['mw'],
    "harṣarāma": ['mw'],
    "harṣasamanvita": ['mw'],
    "harṣasampuṭa": ['mw'],
    "harṣasvana": ['mw'],
    "harṣavant": ['cae'],
    "harṣavardhana": ['cae', 'mw'],
    "harṣavarman": ['cae', 'mw'],
    "harṣavat": ['mw'],
    "harṣavatī": ['mw'],
    "harṣaveṇuka": ['mw'],
    "harṣavihvala": ['mw'],
    "harṣavivardhana": ['mw'],
    "harṣavivṛddhasattva": ['mw'],
    "harṣaviṣāda": ['mw'],
    "harṣayitnu": ['ap90', 'mw'],
    "harṣayukta": ['mw'],
    "harṣaśoka": ['cae', 'mw'],
    "harṣaḥ": ['ap90'],
    "harṣaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "harṣaṇatā": ['mw'],
    "harṣaṇīya": ['bhs', 'mw'],
    "harṣeśvaramāhātmya": ['mw'],
    "harṣi": ['gra'],
    "harṣin": ['cae', 'gra', 'mw'],
    "harṣita": ['ap90', 'ddsa', 'mw'],
    "harṣiṇī": ['mw'],
    "harṣodaya": ['mw'],
    "harṣotkarṣa": ['mw'],
    "harṣotphullalocana": ['cae', 'mw'],
    "harṣuka": ['mw'],
    "harṣula": ['cae', 'mw'],
    "harṣulaḥ": ['ap90'],
    "harṣulā": ['mw'],
    "harṣumant": ['cae'],
    "harṣumat": ['gra', 'mw'],
    "harṣya": ['bhs'],
    "harṣyā": ['cae', 'mw'],
    "harṣākula": ['mw'],
    "harṣānvita": ['mw'],
    "harṣātiśaya": ['mw'],
    "harṣāviṣṭa": ['mw'],
    "harṣāya": ['mw'],
    "harṣāśru": ['cae', 'mw'],
    "harṣīkā": ['mw'],
    "has": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hasa": ['cae', 'ddsa', 'gra', 'mw'],
    "hasakṛt": ['mw'],
    "hasamāna": ['cped'],
    "hasana": ['cae', 'cped', 'mw'],
    "hasanaṃ": ['ap90'],
    "hasanta": ['cped'],
    "hasantikā": ['mw'],
    "hasantī": ['mw'],
    "hasanā": ['gra', 'mw'],
    "hasanī": ['ap90', 'bhs', 'mw'],
    "hasanīmaṇi": ['mw'],
    "hasanīya": ['cae', 'mw'],
    "hasat": ['mw'],
    "hasati": ['cped'],
    "hasavajra": ['mw'],
    "hasaḥ": ['ap90'],
    "hasaṃtikā": ['ap90'],
    "hasaṃtī": ['ap90'],
    "hasi": ['cped'],
    "hasikā": ['ap90', 'mw'],
    "hasira": ['mw'],
    "hasita": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "hasitabba": ['cped'],
    "hasituppāda": ['cped'],
    "hasitvā": ['cped'],
    "hasitṛ": ['mw'],
    "haskartṛ": ['cae', 'gra', 'mw'],
    "haskāra": ['cae', 'gra', 'mw'],
    "haskṛti": ['cae', 'gra', 'mw'],
    "hasra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hassa": ['cped'],
    "hasta": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "hastabandha": ['mw'],
    "hastabhraṃśin": ['cae', 'mw'],
    "hastabhraṣṭa": ['cae', 'mw'],
    "hastabimba": ['mw'],
    "hastacaraṇa": ['mw'],
    "hastacchedana": ['mw'],
    "hastacyuta": ['gra', 'mw'],
    "hastacyuti": ['gra', 'mw'],
    "hastacāpa": ['mw'],
    "hastacāpalya": ['mw'],
    "hastadakṣiṇa": ['mw'],
    "hastadatta": ['mw'],
    "hastadhāraṇa": ['cae', 'mw'],
    "hastadhāraṇā": ['mw'],
    "hastadhātrī": ['mw'],
    "hastadoṣa": ['mw'],
    "hastadvaya": ['mw'],
    "hastadā": ['bhs'],
    "hastadīpa": ['cae', 'mw'],
    "hastaga": ['cae', 'mw'],
    "hastagata": ['cae', 'mw'],
    "hastaghna": ['cae', 'gra', 'mw'],
    "hastagiri": ['mw'],
    "hastagirimāhātmya": ['mw'],
    "hastagraha": ['cae', 'mw'],
    "hastagrābha": ['cae', 'gra', 'mw'],
    "hastagrāha": ['cae', 'mw'],
    "hastagrāhaka": ['mw'],
    "hastagāmin": ['cae', 'mw'],
    "hastagṛhya": ['cae', 'gra', 'mw'],
    "hastahoma": ['mw'],
    "hastahārya": ['mw'],
    "hastajyoḍi": ['mw'],
    "hastaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "hastakamala": ['cae', 'mw'],
    "hastakauśala": ['mw'],
    "hastakavapra": ['mw'],
    "hastakaḥ": ['ap90'],
    "hastakita": ['mw'],
    "hastakohali": ['mw'],
    "hastakriyā": ['mw'],
    "hastakārya": ['cae', 'mw'],
    "hastakṛta": ['cae', 'mw'],
    "hastala": ['bhs'],
    "hastalakṣaṇa": ['mw'],
    "hastalekha": ['mw'],
    "hastalepana": ['mw'],
    "hastalāghava": ['mw'],
    "hastamaṇi": ['mw'],
    "hastamuktāvalī": ['mw'],
    "hastamātra": ['mw'],
    "hastaparṇa": ['mw'],
    "hastaprada": ['cae', 'mw'],
    "hastapralehaka": ['bhs'],
    "hastaprāpta": ['cae', 'mw'],
    "hastaprāpya": ['cae', 'mw'],
    "hastapuccha": ['mw'],
    "hastapāda": ['cae', 'mw'],
    "hastapādādi": ['mw'],
    "hastapṛṣṭha": ['mw'],
    "hastaratnāvalī": ['mw'],
    "hastarekhā": ['mw'],
    "hastasaṃdhunakam": ['mw'],
    "hastasaṃjñā": ['cae', 'mw'],
    "hastasaṃjīvanī": ['mw'],
    "hastasaṃlagnikā": ['mw'],
    "hastasaṃvācaka": ['bhs'],
    "hastasaṃvāhana": ['mw'],
    "hastasiddhi": ['mw'],
    "hastastha": ['cae', 'mw'],
    "hastasthayuga": ['mw'],
    "hastasthita": ['mw'],
    "hastasvaralakṣaṇa": ['mw'],
    "hastasvastika": ['mw'],
    "hastasūtra": ['mw'],
    "hastasūtraka": ['mw'],
    "hastatala": ['mw'],
    "hastatalagata": ['mw'],
    "hastatra": ['cae', 'mw'],
    "hastatrayasammite": ['mw'],
    "hastatulā": ['mw'],
    "hastatva": ['bhs'],
    "hastatāla": ['mw'],
    "hastavant": ['cae'],
    "hastavartam": ['mw'],
    "hastavartin": ['mw'],
    "hastavat": ['ap90', 'gra', 'mw'],
    "hastaveṣya": ['mw'],
    "hastavinyāsa": ['mw'],
    "hastavāma": ['mw'],
    "hastavāpa": ['mw'],
    "hastavāraṇa": ['mw'],
    "hastayata": ['gra', 'mw'],
    "hastayoga": ['mw'],
    "hastayugala": ['mw'],
    "hastaśrāddha": ['mw'],
    "hastaḥ": ['ap90'],
    "haste": ['mw'],
    "hastebandha": ['mw'],
    "hastegṛhya": ['cae', 'mw'],
    "hastekaraṇa": ['mw'],
    "hastekṛ": ['mw'],
    "hasti": ['mw'],
    "hastibandha": ['mw'],
    "hastibhadra": ['mw'],
    "hasticarma": ['mw'],
    "hasticāra": ['mw'],
    "hasticārin": ['cae', 'mw'],
    "hasticāriṇī": ['mw'],
    "hastidanta": ['mw'],
    "hastidantaka": ['mw'],
    "hastidantaphalā": ['mw'],
    "hastidantavastramaya": ['mw'],
    "hastidantī": ['mw'],
    "hastidvayasa": ['mw'],
    "hastidāya": ['mw'],
    "hastigarbha": ['bhs'],
    "hastigartā": ['mw'],
    "hastigaurīvratodyāpanavidhi": ['mw'],
    "hastigavāśva": ['cae', 'mw'],
    "hastigavāśvoṣṭradamaka": ['mw'],
    "hastighaṭa": ['mw'],
    "hastighna": ['mw'],
    "hastighoṣā": ['mw'],
    "hastighoṣātakī": ['mw'],
    "hastighāta": ['mw'],
    "hastigiri": ['mw'],
    "hastigiricampū": ['mw'],
    "hastigirimāhātmya": ['mw'],
    "hastigirīśamaṅgalāśāsana": ['mw'],
    "hastigośvoṣṭradamaka": ['cae'],
    "hastigrīvā": ['bhs'],
    "hastihasta": ['mw'],
    "hastihastaparāmṛṣṭa": ['mw'],
    "hastijanaprakāśa": ['mw'],
    "hastijihvā": ['mw'],
    "hastijāgarika": ['mw'],
    "hastijīvin": ['cae', 'mw'],
    "hastika": ['bhs', 'mw'],
    "hastikaccha": ['bhs', 'mw'],
    "hastikakṣa": ['mw'],
    "hastikakṣya": ['bhs', 'mw'],
    "hastikanda": ['mw'],
    "hastikarañja": ['mw'],
    "hastikarañjaka": ['mw'],
    "hastikarkoṭaka": ['mw'],
    "hastikarṇa": ['bhs', 'ddsa', 'mw'],
    "hastikarṇadala": ['mw'],
    "hastikarṇaka": ['mw'],
    "hastikarṇapalāśa": ['mw'],
    "hastikarṇika": ['mw'],
    "hastikarṣū": ['mw'],
    "hastikaśīrṣa": ['bhs'],
    "hastikaṃ": ['ap90'],
    "hastikoli": ['mw'],
    "hastikośātakī": ['mw'],
    "hastikumbha": ['mw'],
    "hastikā": ['mw'],
    "hastikāśyapa": ['mw'],
    "hastilodhraka": ['mw'],
    "hastimada": ['mw'],
    "hastimadhya": ['bhs'],
    "hastimakara": ['mw'],
    "hastimalla": ['mw'],
    "hastimallasena": ['mw'],
    "hastimat": ['mw'],
    "hastimeha": ['mw'],
    "hastimehin": ['mw'],
    "hastimukha": ['mw'],
    "hastimātra": ['mw'],
    "hastimāyā": ['mw'],
    "hastimṛḍitā": ['mw'],
    "hastin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hastinakha": ['ddsa', 'mw'],
    "hastinapuraṃ": ['ap90'],
    "hastinikaśīrṣa": ['bhs'],
    "hastinikā": ['bhs'],
    "hastiniyaṃsa": ['bhs'],
    "hastiniṣadana": ['mw'],
    "hastināga": ['bhs', 'mw'],
    "hastināpura": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "hastināpuraṃ": ['ap90'],
    "hastināsā": ['mw'],
    "hastināyaka": ['mw'],
    "hastinī": ['ap90', 'mw'],
    "hastipa": ['cae', 'ddsa', 'mw'],
    "hastipada": ['mw'],
    "hastipaka": ['cae', 'mw'],
    "hastiparṇikā": ['mw'],
    "hastiparṇinī": ['mw'],
    "hastiparṇī": ['mw'],
    "hastipattra": ['mw'],
    "hastipippalī": ['mw'],
    "hastipiṇḍa": ['mw'],
    "hastipāda": ['mw'],
    "hastipādikā": ['mw'],
    "hastipāla": ['cae', 'mw'],
    "hastipālaka": ['cae', 'mw'],
    "hastipūraṇī": ['mw'],
    "hastipṛṣṭhaka": ['mw'],
    "hastiratha": ['mw'],
    "hastirathadāna": ['mw'],
    "hastirodhraka": ['mw'],
    "hastirohaṇaka": ['mw'],
    "hastiruci": ['mw'],
    "hastirāja": ['cae', 'mw'],
    "hastisena": ['mw'],
    "hastisnāna": ['cae', 'mw'],
    "hastisomā": ['mw'],
    "hastisūtra": ['mw'],
    "hastivadha": ['mw'],
    "hastivaidyaka": ['mw'],
    "hastivaidyakakāra": ['mw'],
    "hastivaktra": ['mw'],
    "hastivarcasa": ['cae', 'mw'],
    "hastivarman": ['mw'],
    "hastiviṣāṇī": ['mw'],
    "hastivrata": ['bhs'],
    "hastivāha": ['mw'],
    "hastivānara": ['mw'],
    "hastivātiṅgaṇa": ['mw'],
    "hastiyaśas": ['mw'],
    "hastiyaśasihastivarcasin": ['mw'],
    "hastiyūtha": ['mw'],
    "hastiśikṣaka": ['mw'],
    "hastiśikṣā": ['cae', 'mw'],
    "hastiśiras": ['mw'],
    "hastiśuṇḍa": ['mw'],
    "hastiśuṇḍā": ['mw'],
    "hastiśuṇḍī": ['mw'],
    "hastiśyāmāka": ['mw'],
    "hastiśālā": ['cae', 'mw'],
    "hastiṣaḍgava": ['mw'],
    "hastocchraya": ['mw'],
    "hastodaka": ['ddsa', 'mw'],
    "hastokta": ['bhs'],
    "hastula": ['bhs'],
    "hasty": ['mw'],
    "hastya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hastyadhyakṣa": ['mw'],
    "hastyaśanā": ['mw'],
    "hastyaśva": ['cae', 'ddsa', 'mw'],
    "hastyaśvadīkṣā": ['mw'],
    "hastyaśvarathaghoṣa": ['mw'],
    "hastyaśvarathasambādha": ['mw'],
    "hastyaśvārohabandhaka": ['mw'],
    "hastyājīva": ['cae', 'mw'],
    "hastyāluka": ['mw'],
    "hastyāroha": ['cae', 'mw'],
    "hastyāyurveda": ['mw'],
    "hastyṛṣabha": ['mw'],
    "hastā": ['ap90', 'mw'],
    "hastābharaṇa": ['cae', 'mw'],
    "hastādāna": ['cae', 'mw'],
    "hastāgni": ['mw'],
    "hastāgra": ['cae', 'ddsa', 'mw'],
    "hastāgralagnā": ['mw'],
    "hastāhasti": ['ap90', 'cae', 'ddsa', 'mw'],
    "hastāhastikā": ['mw'],
    "hastākṣara": ['mw'],
    "hastālamba": ['cae', 'mw'],
    "hastālambana": ['mw'],
    "hastāliṅgana": ['mw'],
    "hastāliṅganaka": ['mw'],
    "hastāmalaka": ['mw'],
    "hastāmalakabhāṣya": ['mw'],
    "hastāmalakasaṃvādastotra": ['mw'],
    "hastāmalakastotra": ['mw'],
    "hastāmalakavedāntaprakaraṇa": ['mw'],
    "hastāmalakaṭīkā": ['mw'],
    "hastāpatti": ['bhs'],
    "hastārūḍha": ['mw'],
    "hastāvalamba": ['cae', 'mw'],
    "hastāvalambana": ['mw'],
    "hastāvalehaka": ['bhs'],
    "hastāvalehakam": ['mw'],
    "hastāvanejana": ['mw'],
    "hastāvāpa": ['cae', 'mw'],
    "hastāvāpin": ['mw'],
    "hastāñjali": ['cae', 'mw'],
    "hastāṅguli": ['cae', 'mw'],
    "hastāṅgulī": ['cae', 'mw'],
    "hastīkṛ": ['cae', 'mw'],
    "hastīna": ['mw'],
    "hasurāja": ['mw'],
    "hasvan": ['gra'],
    "hasāmud": ['mw'],
    "hasāmuda": ['cae', 'mw'],
    "hasīyati": ['cped'],
    "hata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "hatabhaga": ['mw'],
    "hatabhrātṛ": ['mw'],
    "hatabhāgya": ['mw'],
    "hatabhāva": ['cped'],
    "hatabuddhi": ['mw'],
    "hatabāndhava": ['mw'],
    "hatacchedana": ['cped'],
    "hatacchāya": ['cae', 'mw'],
    "hatacetas": ['mw'],
    "hatacitta": ['mw'],
    "hatadaiva": ['mw'],
    "hatadhvānta": ['mw'],
    "hatadhī": ['mw'],
    "hatadviṣ": ['mw'],
    "hatahima": ['mw'],
    "hatahṛdaya": ['cae', 'mw'],
    "hatainas": ['mw'],
    "hatajalpita": ['mw'],
    "hatajyotirniśītha": ['mw'],
    "hatajñāna": ['mw'],
    "hatajīvana": ['cae', 'mw'],
    "hatajīvita": ['cae', 'mw'],
    "hataka": ['ap90', 'cae', 'mw'],
    "hatakaṇṭaka": ['mw'],
    "hatakilbiṣa": ['mw'],
    "hatalakṣaṇa": ['mw'],
    "hatamati": ['mw'],
    "hatamedhas": ['mw'],
    "hatamāna": ['mw'],
    "hatamānasa": ['mw'],
    "hatamātṛ": ['mw'],
    "hatamūrkha": ['mw'],
    "hatantarāya": ['cped'],
    "hataparamārtha": ['mw'],
    "hatapitṛ": ['mw'],
    "hataprabha": ['mw'],
    "hataprabhāva": ['mw'],
    "hatapramāda": ['mw'],
    "hatapravīra": ['mw'],
    "hataprāya": ['mw'],
    "hataputra": ['mw'],
    "hataratha": ['mw'],
    "hatasammada": ['mw'],
    "hatasampada": ['mw'],
    "hatasarvayodha": ['mw'],
    "hatastrīka": ['cae', 'mw'],
    "hatasvara": ['mw'],
    "hatasvasṛ": ['mw'],
    "hatasādhvasa": ['mw'],
    "hatasūta": ['mw'],
    "hatatrapa": ['mw'],
    "hatatviṣ": ['cae', 'mw'],
    "hatatviṭka": ['mw'],
    "hatatāpa": ['mw'],
    "hataujas": ['mw'],
    "hatavarcas": ['mw'],
    "hatavega": ['mw'],
    "hatavidhi": ['cae', 'mw'],
    "hatavikramodyama": ['mw'],
    "hatavinaya": ['mw'],
    "hatavrīḍa": ['mw'],
    "hatavīrya": ['mw'],
    "hatavṛtta": ['mw'],
    "hatavṛttatā": ['mw'],
    "hatavṛṣan": ['gra'],
    "hatavṛṣṇī": ['mw'],
    "hatayuddha": ['mw'],
    "hataśeṣa": ['mw'],
    "hataśiṣṭa": ['mw'],
    "hataśiṣṭajana": ['mw'],
    "hataśrī": ['mw'],
    "hatekṣaṇa": ['mw'],
    "hatha": ['cae', 'gra', 'mw'],
    "hathaḥ": ['ap90'],
    "hathiṇāvagrāma": ['mw'],
    "hati": ['cae', 'ddsa', 'gra', 'mw'],
    "hatiḥ": ['ap90'],
    "hatnu": ['cae', 'gra', 'mw'],
    "hatnuḥ": ['ap90'],
    "hatodyama": ['mw'],
    "hatottara": ['mw'],
    "hatru": ['mw'],
    "hattha": ['cped'],
    "hatthaccheda": ['cped'],
    "hatthacchinna": ['cped'],
    "hatthachedana": ['cped'],
    "hatthagahaṇa": ['cped'],
    "hatthagata": ['cped'],
    "hatthagāha": ['cped'],
    "hatthaka": ['cped'],
    "hatthakamma": ['cped'],
    "hatthapasāraṇa": ['cped'],
    "hatthapāsa": ['cped'],
    "hatthasāra": ['cped'],
    "hatthatala": ['cped'],
    "hatthatthara": ['cped'],
    "hatthavaṭṭaka": ['cped'],
    "hatthavikāra": ['cped'],
    "hatthi": ['cped'],
    "hatthibandha": ['cped'],
    "hatthidamaka": ['cped'],
    "hatthidamma": ['cped'],
    "hatthidanta": ['cped'],
    "hatthigopaka": ['cped'],
    "hatthikalabha": ['cped'],
    "hatthikantavīṇā": ['cped'],
    "hatthikkhandha": ['cped'],
    "hatthikula": ['cped'],
    "hatthikumbha": ['cped'],
    "hatthilaṇḍa": ['cped'],
    "hatthiliṅgasakuṇa": ['cped'],
    "hatthimatta": ['cped'],
    "hatthimeṇḍa": ['cped'],
    "hatthimāraka": ['cped'],
    "hatthināga": ['cped'],
    "hatthinī": ['cped'],
    "hatthipada": ['cped'],
    "hatthippabhinna": ['cped'],
    "hatthipākāra": ['cped'],
    "hatthirūpaka": ['cped'],
    "hatthisippa": ['cped'],
    "hatthisoṇḍā": ['cped'],
    "hatthisālā": ['cped'],
    "hatthiyuddha": ['cped'],
    "hatthiyāna": ['cped'],
    "hatthābharaṇa": ['cped'],
    "hatthācariya": ['cped'],
    "hatthāpalekhana": ['cped'],
    "hatthāroha": ['cped'],
    "hatthī": ['cped'],
    "hatu": ['mw'],
    "hatuna": ['bhs'],
    "hatva": ['mw'],
    "hatvāya": ['mw'],
    "hatvī": ['mw'],
    "hatya": ['cae', 'gra', 'mw'],
    "hatyā": ['ap90', 'gra', 'mw'],
    "hatā": ['mw'],
    "hatādhimantha": ['mw'],
    "hatāghaśaṃsa": ['mw'],
    "hatāroha": ['mw'],
    "hatāvakāsa": ['cped'],
    "hatāvasesaka": ['cped'],
    "hatāvaśeṣa": ['mw'],
    "hatāśa": ['cae', 'mw'],
    "hatāśraya": ['mw'],
    "hatāśva": ['mw'],
    "hau": ['mw'],
    "haumya": ['cae', 'ddsa', 'mw'],
    "haumyadhānya": ['mw'],
    "haumyapariśiṣṭavivecana": ['mw'],
    "haumyaṃ": ['ap90'],
    "haumīya": ['mw'],
    "hauta": ['mw'],
    "hautabhuja": ['mw'],
    "hautna": ['mw'],
    "hautra": ['cae', 'ddsa', 'mw'],
    "hautraka": ['mw'],
    "hautrakalpadruma": ['mw'],
    "hautramañjarī": ['mw'],
    "hautraprayoga": ['mw'],
    "hautrasūtra": ['mw'],
    "hautrasūtrāvaloka": ['mw'],
    "hautraṃ": ['ap90'],
    "hautrika": ['mw'],
    "hautāśana": ['mw'],
    "hautāśani": ['mw'],
    "hautṛka": ['ap90', 'mw'],
    "hauḍ": ['ap90', 'mw'],
    "hauḍa": ['mw'],
    "hauṇikyā": ['mw'],
    "hauṇḍina": ['mw'],
    "hauṣya": ['mw'],
    "hava": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "havai": ['cae', 'ddsa'],
    "havala": ['bhs', 'mw'],
    "havana": ['cae', 'gra', 'mw'],
    "havanapaddhati": ['mw'],
    "havanasyad": ['cae', 'gra', 'mw'],
    "havanaśrut": ['cae', 'gra', 'mw'],
    "havanaṃ": ['ap90'],
    "havanāyus": ['mw'],
    "havanī": ['ap90', 'mw'],
    "havanīya": ['ap90', 'mw'],
    "havas": ['cae', 'gra', 'mw'],
    "havava": ['bhs'],
    "havavat": ['ddsa', 'mw'],
    "havaḥ": ['ap90'],
    "havaṅga": ['mw'],
    "have": ['cped'],
    "havia": ['gra'],
    "havidhra": ['mw'],
    "havin": ['cae', 'ddsa', 'mw'],
    "havir": ['mw'],
    "havirad": ['cae', 'ddsa', 'gra', 'mw'],
    "havirada": ['cae', 'mw'],
    "haviradya": ['cae', 'gra', 'mw'],
    "havirantaraṇa": ['mw'],
    "haviraśana": ['mw'],
    "havirbhuj": ['cae', 'mw'],
    "havirbhāga": ['mw'],
    "havirbhāj": ['mw'],
    "havirbhū": ['mw'],
    "havirbhūta": ['mw'],
    "havirdhāman": ['mw'],
    "havirdhāna": ['cae', 'mw'],
    "havirdhānin": ['mw'],
    "havirdhānī": ['mw'],
    "havirdhūma": ['mw'],
    "havirdā": ['cae', 'gra', 'mw'],
    "havirdāna": ['cae', 'mw'],
    "havirgandhā": ['mw'],
    "havirgeha": ['mw'],
    "havirgrahaṇī": ['cae', 'mw'],
    "havirgṛha": ['mw'],
    "havirhuti": ['mw'],
    "havirmantha": ['mw'],
    "havirmathi": ['cae', 'gra', 'mw'],
    "havirnirvapaṇa": ['mw'],
    "havirucchiṣṭa": ['cae', 'mw'],
    "havirucchiṣṭabhuj": ['cae', 'mw'],
    "havirucchiṣṭaśeṣa": ['mw'],
    "havirucchiṣṭāśa": ['cae', 'mw'],
    "havirucchiṣṭāśana": ['cae', 'mw'],
    "havirvah": ['cae', 'gra', 'mw'],
    "havirvarṣa": ['mw'],
    "havirvāh": ['gra'],
    "haviryajña": ['cae', 'mw'],
    "haviryajñakāṇḍa": ['mw'],
    "haviryajñartvij": ['mw'],
    "haviryajñasaṃsthā": ['mw'],
    "haviryajñavidha": ['mw'],
    "haviryājin": ['mw'],
    "havirāhuti": ['cae', 'mw'],
    "havirātañcana": ['mw'],
    "havis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "havitrī": ['ap90', 'mw'],
    "haviā": ['gra'],
    "haviḥ": ['mw'],
    "haviḥsaṃsthā": ['mw'],
    "haviḥśeṣa": ['cae', 'ddsa', 'mw'],
    "haviḥśeṣabhakṣa": ['mw'],
    "haviḥśravas": ['mw'],
    "haviḥśālā": ['mw'],
    "haviṣ": ['mw'],
    "haviṣkaraṇa": ['cae', 'mw'],
    "haviṣkṛt": ['cae', 'ddsa', 'gra', 'mw'],
    "haviṣkṛta": ['cae', 'mw'],
    "haviṣkṛti": ['cae', 'gra', 'mw'],
    "haviṣmant": ['cae'],
    "haviṣmat": ['ap90', 'gra', 'mw'],
    "haviṣmatī": ['mw'],
    "haviṣpati": ['cae', 'gra', 'mw'],
    "haviṣpaṅkti": ['cae', 'mw'],
    "haviṣpā": ['cae', 'gra', 'mw'],
    "haviṣpāntasūkta": ['mw'],
    "haviṣpāntīya": ['mw'],
    "haviṣpātra": ['cae', 'mw'],
    "haviṣya": ['cae', 'gra', 'mw'],
    "haviṣyabhakṣa": ['mw'],
    "haviṣyabhakṣatā": ['mw'],
    "haviṣyabhuj": ['cae', 'mw'],
    "haviṣyanda": ['mw'],
    "haviṣyantīya": ['mw'],
    "haviṣyaśanna": ['mw'],
    "haviṣyaṃ": ['ap90'],
    "haviṣyā": ['mw'],
    "haviṣyānna": ['cae', 'mw'],
    "haviṣyāśin": ['cae', 'mw'],
    "haviṣṭas": ['mw'],
    "haviṣṭha": ['mw'],
    "haviṣṭva": ['mw'],
    "havya": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "havyabhuj": ['mw'],
    "havyadāti": ['cae', 'gra', 'mw'],
    "havyajuṣṭi": ['cae', 'gra', 'mw'],
    "havyakavya": ['cae', 'mw'],
    "havyakavyavaha": ['mw'],
    "havyakavyāśa": ['mw'],
    "havyalehin": ['mw'],
    "havyamantrādhikṛta": ['mw'],
    "havyapa": ['mw'],
    "havyapāka": ['mw'],
    "havyasūd": ['cae', 'gra', 'mw'],
    "havyasūda": ['cae', 'mw'],
    "havyasūdana": ['cae', 'mw'],
    "havyasūkti": ['mw'],
    "havyavah": ['cae', 'gra', 'mw'],
    "havyavaha": ['mw'],
    "havyavāh": ['gra'],
    "havyavāha": ['cae', 'mw'],
    "havyavāhana": ['cae', 'gra', 'mw'],
    "havyavāhinī": ['mw'],
    "havyayoni": ['mw'],
    "havyaśodhana": ['mw'],
    "havyā": ['gra', 'mw'],
    "havyād": ['cae', 'gra', 'mw'],
    "havyāda": ['cae', 'mw'],
    "havyāhuti": ['cae'],
    "havyāśa": ['mw'],
    "havyāśana": ['mw'],
    "havīman": ['cae', 'ddsa', 'gra', 'mw'],
    "havītu": ['mw'],
    "hay": ['ap90', 'mw'],
    "haya": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "hayacaryā": ['mw'],
    "hayacchaṭā": ['mw'],
    "hayadviṣat": ['mw'],
    "hayadānava": ['mw'],
    "hayagandha": ['mw'],
    "hayagandhā": ['mw'],
    "hayagardabhi": ['mw'],
    "hayaghna": ['mw'],
    "hayagrīva": ['bhs', 'cae', 'mw'],
    "hayagrīvadaṇḍaka": ['mw'],
    "hayagrīvagadya": ['mw'],
    "hayagrīvahan": ['mw'],
    "hayagrīvapañcarātra": ['mw'],
    "hayagrīvapañjara": ['mw'],
    "hayagrīvaprokta": ['mw'],
    "hayagrīvaripu": ['mw'],
    "hayagrīvasahasranāmastotra": ['mw'],
    "hayagrīvasaṃhitā": ['mw'],
    "hayagrīvastotra": ['mw'],
    "hayagrīvavadha": ['mw'],
    "hayagrīvopaniṣad": ['mw'],
    "hayagrīvā": ['mw'],
    "hayahartṛ": ['cae', 'mw'],
    "hayajña": ['cae', 'mw'],
    "hayajñatā": ['mw'],
    "hayajñāna": ['mw'],
    "hayakantharikā": ['mw'],
    "hayakantharā": ['mw'],
    "hayakarman": ['cae', 'mw'],
    "hayakarṇā": ['bhs'],
    "hayakātarikā": ['mw'],
    "hayakātarā": ['mw'],
    "hayalālā": ['mw'],
    "hayalīlāvatī": ['mw'],
    "hayamedha": ['cae', 'mw'],
    "hayamedhayāj": ['mw'],
    "hayamukha": ['cae', 'mw'],
    "hayamukhī": ['mw'],
    "hayamāra": ['mw'],
    "hayamāraka": ['mw'],
    "hayamāraṇa": ['mw'],
    "hayana": ['bhs', 'mw'],
    "hayanirghoṣa": ['mw'],
    "hayapa": ['mw'],
    "hayapati": ['mw'],
    "hayapotaka": ['cped'],
    "hayapriya": ['mw'],
    "hayapriyā": ['mw'],
    "hayapuccha": ['mw'],
    "hayapucchikā": ['mw'],
    "hayapucchī": ['mw'],
    "hayarūpin": ['mw'],
    "hayasaṃgrahaṇa": ['mw'],
    "hayaskandha": ['mw'],
    "hayatattva": ['mw'],
    "hayatattvajña": ['mw'],
    "hayattattva": ['cae'],
    "hayavidyā": ['cae', 'mw'],
    "hayavāhana": ['mw'],
    "hayavāhanasaṃkara": ['mw'],
    "hayavāhanaśaṃkara": ['mw'],
    "hayavāhī": ['cped'],
    "hayaśikṣā": ['mw'],
    "hayaśiras": ['cae', 'mw'],
    "hayaśiśu": ['mw'],
    "hayaśālā": ['mw'],
    "hayaśāstra": ['mw'],
    "hayaśīrṣa": ['cae', 'mw'],
    "hayaśīrṣan": ['cae', 'mw'],
    "hayaśīrṣapañcarātra": ['mw'],
    "hayaḥ": ['ap90'],
    "hayaṃkaṣa": ['mw'],
    "hayaṃkaṣaḥ": ['ap90'],
    "haye": ['cae', 'ddsa', 'gra', 'mw'],
    "hayeṣṭa": ['mw'],
    "hayi": ['mw'],
    "hayin": ['cae', 'mw'],
    "hayottama": ['ddsa', 'mw'],
    "hayottamayuj": ['mw'],
    "hayuṣā": ['mw'],
    "hayā": ['ddsa'],
    "hayādhyakṣa": ['mw'],
    "hayālaya": ['mw'],
    "hayānanā": ['mw'],
    "hayānīka": ['cped'],
    "hayāri": ['mw'],
    "hayāroha": ['cae', 'mw'],
    "hayārūḍha": ['ddsa', 'mw'],
    "hayāsya": ['mw'],
    "hayāsyaka": ['mw'],
    "hayāyurveda": ['mw'],
    "hayāśanā": ['mw'],
    "hayāṅga": ['mw'],
    "hayī": ['ap90', 'ddsa'],
    "hañcā": ['mw'],
    "hañje": ['cae', 'ddsa'],
    "hañji": ['mw'],
    "hañjikā": ['cae', 'mw'],
    "hañjikātva": ['mw'],
    "hañjā": ['mw'],
    "haññamāna": ['cped'],
    "haññana": ['cped'],
    "haññati": ['cped'],
    "haññi": ['cped'],
    "haḍa": ['bhs', 'mw'],
    "haḍhakka": ['mw'],
    "haḍi": ['bhs', 'ddsa', 'mw'],
    "haḍika": ['mw'],
    "haḍikaḥ": ['ap90'],
    "haḍiḥ": ['ap90'],
    "haḍḍa": ['mw'],
    "haḍḍacandra": ['mw'],
    "haḍḍaja": ['mw'],
    "haḍḍaka": ['mw'],
    "haḍḍaṃ": ['ap90'],
    "haḍḍi": ['mw'],
    "haḍḍika": ['mw'],
    "haḍḍipa": ['mw'],
    "haṁsa": ['cped'],
    "haṁsana": ['cped'],
    "haṁsapotaka": ['cped'],
    "haṁsati": ['cped'],
    "haṁseti": ['cped'],
    "haṁsi": ['cped'],
    "haṁsī": ['cped'],
    "haṃbhā": ['ap90'],
    "haṃbā": ['ap90'],
    "haṃce": ['bhs'],
    "haṃho": ['ap90', 'cae', 'ddsa', 'mw'],
    "haṃjā": ['ap90'],
    "haṃsa": ['cae', 'ddsa', 'gra', 'mw'],
    "haṃsabhūpāla": ['mw'],
    "haṃsabīja": ['mw'],
    "haṃsacakrapraśna": ['mw'],
    "haṃsacandrāṃśu": ['cae', 'mw'],
    "haṃsacarasvārodaya": ['mw'],
    "haṃsacchattra": ['mw'],
    "haṃsacihnadukūlavat": ['mw'],
    "haṃsacūḍa": ['mw'],
    "haṃsadhvaja": ['mw'],
    "haṃsadvāra": ['mw'],
    "haṃsadvīpa": ['mw'],
    "haṃsadāhana": ['mw'],
    "haṃsadūta": ['mw'],
    "haṃsaga": ['mw'],
    "haṃsagadgadā": ['mw'],
    "haṃsagamana": ['mw'],
    "haṃsagamanā": ['mw'],
    "haṃsagati": ['cae', 'mw'],
    "haṃsaguhya": ['mw'],
    "haṃsagāminī": ['cae', 'mw'],
    "haṃsaja": ['mw'],
    "haṃsajihva": ['mw'],
    "haṃsajātīya": ['mw'],
    "haṃsaka": ['cae', 'mw'],
    "haṃsakavatī": ['mw'],
    "haṃsakaḥ": ['ap90'],
    "haṃsakuśa": ['bhs'],
    "haṃsakākīya": ['mw'],
    "haṃsakālītanaya": ['mw'],
    "haṃsakāntā": ['mw'],
    "haṃsakāyana": ['mw'],
    "haṃsakīlaka": ['mw'],
    "haṃsakūṭa": ['mw'],
    "haṃsalakṣaṇa": ['bhs'],
    "haṃsalipi": ['mw'],
    "haṃsalohaka": ['mw'],
    "haṃsalomaśa": ['mw'],
    "haṃsalīla": ['mw'],
    "haṃsamauna": ['mw'],
    "haṃsamaṇḍūraka": ['mw'],
    "haṃsamukha": ['cae', 'mw'],
    "haṃsamāheśvara": ['mw'],
    "haṃsamālā": ['cae', 'mw'],
    "haṃsamārga": ['mw'],
    "haṃsamāṣā": ['mw'],
    "haṃsanidāna": ['mw'],
    "haṃsanābha": ['mw'],
    "haṃsanāda": ['mw'],
    "haṃsanādin": ['mw'],
    "haṃsanādinī": ['mw'],
    "haṃsanādopaniṣad": ['mw'],
    "haṃsanīlaka": ['mw'],
    "haṃsapada": ['cae', 'mw'],
    "haṃsapadikā": ['cae', 'mw'],
    "haṃsapadā": ['mw'],
    "haṃsapadī": ['mw'],
    "haṃsapakṣa": ['mw'],
    "haṃsaparameśvara": ['mw'],
    "haṃsapatha": ['mw'],
    "haṃsapoṭṭalī": ['mw'],
    "haṃsaprabodhā": ['mw'],
    "haṃsaprapatana": ['mw'],
    "haṃsapura": ['mw'],
    "haṃsapāda": ['mw'],
    "haṃsapādikā": ['mw'],
    "haṃsapādā": ['mw'],
    "haṃsapādī": ['mw'],
    "haṃsapāla": ['mw'],
    "haṃsaratha": ['mw'],
    "haṃsaroman": ['mw'],
    "haṃsaruta": ['mw'],
    "haṃsarāja": ['cae', 'mw'],
    "haṃsarāmapraśna": ['mw'],
    "haṃsasaṃdeśa": ['mw'],
    "haṃsasaṃghārāma": ['mw'],
    "haṃsasāci": ['cae', 'mw'],
    "haṃsatva": ['mw'],
    "haṃsatā": ['mw'],
    "haṃsatīrtha": ['mw'],
    "haṃsatūla": ['cae', 'mw'],
    "haṃsatūlikā": ['mw'],
    "haṃsavaktra": ['mw'],
    "haṃsavant": ['cae'],
    "haṃsavat": ['mw'],
    "haṃsavatī": ['mw'],
    "haṃsavega": ['mw'],
    "haṃsavikrāntagāmitā": ['mw'],
    "haṃsaviveka": ['mw'],
    "haṃsavāha": ['mw'],
    "haṃsavāhana": ['mw'],
    "haṃsavāraṇagāminī": ['mw'],
    "haṃsayukta": ['mw'],
    "haṃsayuvan": ['mw'],
    "haṃsayāna": ['cae', 'mw'],
    "haṃsaśreṇī": ['mw'],
    "haṃsaśyeta": ['mw'],
    "haṃsaḥ": ['ap90'],
    "haṃseśvaratīrtha": ['mw'],
    "haṃsikā": ['ap90', 'ddsa', 'mw'],
    "haṃsin": ['mw'],
    "haṃsinī": ['mw'],
    "haṃsira": ['mw'],
    "haṃsodaka": ['mw'],
    "haṃsopaniṣad": ['mw'],
    "haṃsābhikhya": ['mw'],
    "haṃsādhirūḍhā": ['mw'],
    "haṃsāhvayā": ['mw'],
    "haṃsākāra": ['mw'],
    "haṃsārūḍha": ['mw'],
    "haṃsāsya": ['mw'],
    "haṃsāvalī": ['cae', 'ddsa', 'mw'],
    "haṃsāvatī": ['ddsa', 'mw'],
    "haṃsāya": ['ddsa', 'mw'],
    "haṃsāṃśu": ['mw'],
    "haṃsāṅghri": ['mw'],
    "haṃsāṅghrī": ['mw'],
    "haṃsāṣṭaka": ['mw'],
    "haṃsī": ['mw'],
    "haṃsīya": ['mw'],
    "haṃsīyugala": ['mw'],
    "haṃta": ['ap90'],
    "haṃtuḥ": ['ap90'],
    "haṃtṛ": ['ap90'],
    "haṃḍe": ['ap90'],
    "haṃḍikā": ['ap90'],
    "haṃḍā": ['ap90'],
    "haṇḍa": ['mw'],
    "haṇḍaka": ['mw'],
    "haṇḍe": ['ddsa'],
    "haṇḍikā": ['cae', 'mw'],
    "haṇḍikāsuta": ['mw'],
    "haṇḍā": ['mw'],
    "haṇḍī": ['mw'],
    "haṭ": ['ap90', 'mw'],
    "haṭa": ['cped', 'mw'],
    "haṭaka": ['mw'],
    "haṭaparṇī": ['mw'],
    "haṭh": ['ap90', 'mw'],
    "haṭha": ['cae', 'cped', 'ddsa', 'mw'],
    "haṭhadīpa": ['mw'],
    "haṭhadīpikā": ['mw'],
    "haṭhakarman": ['cae', 'mw'],
    "haṭhakāmuka": ['cae', 'mw'],
    "haṭhaparṇī": ['mw'],
    "haṭhapradīpikā": ['mw'],
    "haṭharatnāvalī": ['mw'],
    "haṭhasaṃketacandrikā": ['mw'],
    "haṭhatattvakaumudī": ['mw'],
    "haṭhavidyā": ['mw'],
    "haṭhayoga": ['mw'],
    "haṭhayogasaṃgraha": ['mw'],
    "haṭhayogaviveka": ['mw'],
    "haṭhayogin": ['mw'],
    "haṭhaśarman": ['mw'],
    "haṭhaḥ": ['ap90'],
    "haṭhikā": ['cae', 'ddsa', 'mw'],
    "haṭhin": ['mw'],
    "haṭhādeśin": ['mw'],
    "haṭhālu": ['mw'],
    "haṭhātkāra": ['mw'],
    "haṭhāyāta": ['mw'],
    "haṭhāśleṣa": ['mw'],
    "haṭṭa": ['cae', 'ddsa', 'mw'],
    "haṭṭacandra": ['mw'],
    "haṭṭacauraka": ['mw'],
    "haṭṭaveśmālī": ['mw'],
    "haṭṭavilāsinī": ['mw'],
    "haṭṭavāhinī": ['mw'],
    "haṭṭaḥ": ['ap90'],
    "haṭṭha": ['cped'],
    "haṭṭhaloma": ['cped'],
    "haṭṭhatuṭṭha": ['cped'],
    "haṭṭādhyakṣa": ['mw'],
    "haṭṭī": ['ap90', 'mw'],
    "he": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "hehe": ['ap90'],
    "hehiti": ['cped'],
    "hekkā": ['ap90', 'mw'],
    "hel": ['ap90', 'cae', 'ddsa', 'mw'],
    "helaka": ['mw'],
    "helana": ['cae', 'ddsa', 'mw'],
    "helanaṃ": ['ap90'],
    "helanīya": ['mw'],
    "helañci": ['mw'],
    "heli": ['mw'],
    "helihila": ['mw'],
    "helika": ['mw'],
    "helitavya": ['mw'],
    "heliḥ": ['ap90'],
    "helu": ['ddsa', 'mw'],
    "heluga": ['bhs', 'mw'],
    "helugrāma": ['mw'],
    "heluka": ['bhs'],
    "heluta": ['bhs'],
    "heluva": ['bhs'],
    "heluya": ['bhs', 'mw'],
    "helā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "helācakra": ['mw'],
    "helārāja": ['mw'],
    "helāvant": ['cae'],
    "helāvat": ['mw'],
    "helāvuka": ['mw'],
    "helāvukka": ['mw'],
    "helāvukkaḥ": ['ap90'],
    "hel̤": ['mw'],
    "hel̤a": ['mw'],
    "hel̤ana": ['mw'],
    "hel̤as": ['mw'],
    "hema": ['cped', 'mw'],
    "hemabhadrika": ['mw'],
    "hemabhastrā": ['mw'],
    "hemacakra": ['mw'],
    "hemacandra": ['cae', 'mw'],
    "hemacchanna": ['mw'],
    "hemacitra": ['mw'],
    "hemacūlin": ['mw'],
    "hemacūrṇa": ['mw'],
    "hemadantā": ['mw'],
    "hemadhanvan": ['mw'],
    "hemadharma": ['mw'],
    "hemadharman": ['mw'],
    "hemadhānya": ['mw'],
    "hemadhānyaka": ['mw'],
    "hemadhāraṇa": ['mw'],
    "hemadugdha": ['mw'],
    "hemadugdhaka": ['mw'],
    "hemadugdhin": ['mw'],
    "hemadugdhā": ['mw'],
    "hemadugdhī": ['mw'],
    "hemadīnāra": ['mw'],
    "hemagandhinī": ['mw'],
    "hemagarbha": ['mw'],
    "hemagaura": ['mw'],
    "hemagaurāṅga": ['mw'],
    "hemaghna": ['mw'],
    "hemaghnī": ['mw'],
    "hemagiri": ['cae', 'mw'],
    "hemaguha": ['mw'],
    "hemahastiratha": ['mw'],
    "hemahaṃsagaṇi": ['mw'],
    "hemaja": ['mw'],
    "hemajaṭa": ['mw'],
    "hemajvāla": ['mw'],
    "hemajāla": ['bhs', 'cped'],
    "hemajālaprabhu": ['bhs'],
    "hemajālapraticchannā": ['bhs'],
    "hemajālālaṃkṛta": ['bhs', 'mw'],
    "hemajīvantī": ['mw'],
    "hemaka": ['cae', 'ddsa', 'mw'],
    "hemakakṣa": ['mw'],
    "hemakakṣya": ['mw'],
    "hemakalaśa": ['mw'],
    "hemakamala": ['mw'],
    "hemakampana": ['mw'],
    "hemakandala": ['mw'],
    "hemakara": ['mw'],
    "hemakaraka": ['mw'],
    "hemakartṛ": ['cae', 'mw'],
    "hemakaṃ": ['ap90'],
    "hemakaṇṭha": ['mw'],
    "hemakeli": ['mw'],
    "hemaketakī": ['mw'],
    "hemakeśa": ['mw'],
    "hemakirīṭamālin": ['mw'],
    "hemakiñjalka": ['mw'],
    "hemakroḍa": ['bhs'],
    "hemakumbha": ['mw'],
    "hemakuḍya": ['mw'],
    "hemakuṇḍya": ['mw'],
    "hemakānti": ['cae', 'mw'],
    "hemakāra": ['cae', 'mw'],
    "hemakāraka": ['mw'],
    "hemakārikā": ['mw'],
    "hemakūṭa": ['ap90', 'cae', 'mw'],
    "hemakūṭamāhātmya": ['mw'],
    "hemakūṭya": ['mw'],
    "hemakṣīrī": ['mw'],
    "hemala": ['mw'],
    "hemalamba": ['mw'],
    "hemalambaka": ['mw'],
    "hemalatā": ['mw'],
    "hemalaḥ": ['ap90'],
    "hemamarīcimat": ['mw'],
    "hemamaya": ['cae', 'mw'],
    "hemamākṣika": ['mw'],
    "hemamālikā": ['mw'],
    "hemamālin": ['cae', 'mw'],
    "hemamālā": ['mw'],
    "hemamāṣā": ['mw'],
    "hemamṛga": ['mw'],
    "heman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hemanetra": ['mw'],
    "hemanta": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "hemantajabdha": ['mw'],
    "hemantamegha": ['mw'],
    "hemantanātha": ['mw'],
    "hemantapratyavarohaṇa": ['mw'],
    "hemantasamaya": ['mw'],
    "hemantasiṃha": ['mw'],
    "hemantaśiśira": ['mw'],
    "hemantaṛtuvarṇana": ['mw'],
    "hemantika": ['bhs', 'cped'],
    "hemantānila": ['mw'],
    "hemantānta": ['mw'],
    "hemantī": ['mw'],
    "hemanābhi": ['mw'],
    "hemaparvata": ['mw'],
    "hemaphalā": ['mw'],
    "hemapiṅgala": ['cae', 'mw'],
    "hemaprabha": ['mw'],
    "hemapratimā": ['ddsa', 'mw'],
    "hemapuñjaka": ['mw'],
    "hemapuṣkara": ['mw'],
    "hemapuṣpa": ['mw'],
    "hemapuṣpaka": ['mw'],
    "hemapuṣpikā": ['mw'],
    "hemapuṣpī": ['mw'],
    "hemapīṭhādhidevatā": ['mw'],
    "hemapṛṣṭha": ['mw'],
    "hemaratha": ['bhs'],
    "hemaratnamaya": ['cae', 'mw'],
    "hemaratnavant": ['cae'],
    "hemaratnavat": ['mw'],
    "hemareṇu": ['mw'],
    "hemarāgiṇī": ['mw'],
    "hemarāja": ['mw'],
    "hemasabhānāthamāhātmya": ['mw'],
    "hemasiṃha": ['mw'],
    "hemasāra": ['mw'],
    "hemasāvarṇi": ['mw'],
    "hemasūri": ['mw'],
    "hemasūtra": ['cae', 'mw'],
    "hemasūtraka": ['mw'],
    "hemataru": ['mw'],
    "hematilakasūri": ['mw'],
    "hematāla": ['mw'],
    "hematāra": ['mw'],
    "hematāraka": ['mw'],
    "hemavala": ['mw'],
    "hemavallī": ['mw'],
    "hemavant": ['cae'],
    "hemavarṇa": ['bhs', 'cae', 'mw'],
    "hemavat": ['mw'],
    "hemavataka": ['cped'],
    "hemavaṇṇa": ['cped'],
    "hemavibhramasūtra": ['mw'],
    "hemavijaya": ['mw'],
    "hemaviṣāṇin": ['mw'],
    "hemavyākaraṇa": ['mw'],
    "hemayajñopavītavat": ['mw'],
    "hemayūthikā": ['mw'],
    "hemaśaila": ['mw'],
    "hemaśaṅkha": ['mw'],
    "hemaśikhā": ['mw'],
    "hemaśikā": ['mw'],
    "hemaśīta": ['mw'],
    "hemaśṛṅga": ['cae', 'mw'],
    "hemaśṛṅgin": ['mw'],
    "hemaṃ": ['ap90'],
    "hemaṃtaḥ": ['ap90'],
    "hemaṃtī": ['ap90'],
    "hemeśvaramāhātmya": ['mw'],
    "hemiāvat": ['gra'],
    "hemna": ['mw'],
    "hemnā": ['mw'],
    "hemya": ['ap90'],
    "hemyāvat": ['gra', 'mw'],
    "hemā": ['mw'],
    "hemābha": ['cae', 'mw'],
    "hemābhā": ['mw'],
    "hemācala": ['mw'],
    "hemādri": ['cae', 'mw'],
    "hemādridānakhaṇḍasāra": ['mw'],
    "hemādrijaraṇa": ['mw'],
    "hemādrikā": ['mw'],
    "hemādriprayoga": ['mw'],
    "hemādriprāyaścitta": ['mw'],
    "hemāhva": ['mw'],
    "hemāhvā": ['mw'],
    "hemālaṃkāra": ['cae', 'mw'],
    "hemālaṃkārin": ['mw'],
    "hemāmbhoja": ['mw'],
    "hemāmbu": ['mw'],
    "hemāmbuja": ['mw'],
    "hemātra": ['bhs', 'mw'],
    "hemāvatīmāhātmya": ['mw'],
    "hemāya": ['mw'],
    "hemāḍhya": ['mw'],
    "hemāṅga": ['cae', 'mw'],
    "hemāṅgada": ['mw'],
    "hemāṅgā": ['mw'],
    "hemāṅka": ['mw'],
    "hemāṇḍa": ['mw'],
    "hemāṇḍaka": ['mw'],
    "hera": ['mw'],
    "heraka": ['mw'],
    "heramba": ['cae', 'ddsa', 'mw'],
    "herambahaṭṭa": ['mw'],
    "herambajananī": ['mw'],
    "herambaka": ['mw'],
    "herambakasena": ['mw'],
    "herambakānanamāhātmya": ['mw'],
    "herambamantra": ['mw'],
    "herambapāla": ['mw'],
    "herambasena": ['mw'],
    "herambha": ['mw'],
    "herambopaniṣad": ['mw'],
    "heraññika": ['cped'],
    "heraṃ": ['ap90'],
    "heraṃbaḥ": ['ap90'],
    "heri": ['bhs'],
    "herika": ['mw'],
    "herikaḥ": ['ap90'],
    "heruka": ['bhs', 'ddsa', 'mw'],
    "herukaḥ": ['ap90'],
    "herukā": ['mw'],
    "herukī": ['bhs'],
    "hesti": ['bhs'],
    "hesā": ['cped'],
    "hesārava": ['cped'],
    "heti": ['cae', 'ddsa', 'gra', 'mw'],
    "hetika": ['mw'],
    "hetimant": ['cae'],
    "hetimantra": ['mw'],
    "hetimat": ['mw'],
    "hetiḥ": ['ap90'],
    "hetri": ['mw'],
    "hetu": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "hetubalika": ['mw'],
    "hetuduṣṭa": ['mw'],
    "hetudṛṣṭi": ['bhs', 'mw'],
    "hetuhetumadbhāva": ['mw'],
    "hetuhila": ['bhs', 'mw'],
    "hetuhāni": ['mw'],
    "hetuka": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "hetulakṣaṇa": ['mw'],
    "hetulakṣaṇaprakāśa": ['mw'],
    "hetulakṣaṇavivecana": ['mw'],
    "hetulakṣaṇaṭīkā": ['mw'],
    "hetulakṣaṇāloka": ['mw'],
    "hetumant": ['bhs', 'cae'],
    "hetumat": ['ap90', 'mw'],
    "hetumātramaya": ['mw'],
    "hetumātratā": ['mw'],
    "hetuna": ['bhs'],
    "hetupadma": ['bhs'],
    "hetuppabhava": ['cped'],
    "hetupratyaya": ['bhs'],
    "hetura": ['bhs'],
    "heturūpaka": ['cae', 'mw'],
    "hetuso": ['cped'],
    "hetutva": ['mw'],
    "hetutvakhaṇḍana": ['mw'],
    "hetutā": ['ap90', 'mw'],
    "hetuvacana": ['mw'],
    "hetuvidyā": ['cae', 'mw'],
    "hetuviśeṣokti": ['mw'],
    "hetuvāda": ['cae', 'cped', 'mw'],
    "hetuvādika": ['cae', 'mw'],
    "hetuvādin": ['cae', 'mw'],
    "hetuyukta": ['mw'],
    "hetuśas": ['bhs'],
    "hetuśliṣṭa": ['mw'],
    "hetuśāstra": ['mw'],
    "hetuśāstrāśraya": ['mw'],
    "hetuśūnya": ['mw'],
    "hetuḥ": ['ap90'],
    "hetv": ['mw'],
    "hetva": ['mw'],
    "hetvantara": ['mw'],
    "hetvapadeśa": ['mw'],
    "hetvavadhāraṇa": ['mw'],
    "hetvindriya": ['bhs'],
    "hetvābhāsa": ['cae', 'mw'],
    "hetvābhāsadīdhitiṭippaṇī": ['mw'],
    "hetvābhāsanirūpaṇa": ['mw'],
    "hetvābhāsapariṣkāra": ['mw'],
    "hetvābhāsarahasya": ['mw'],
    "hetvābhāsasāmānyalakṣaṇa": ['mw'],
    "hetvābhāsavyākhyā": ['mw'],
    "hetvākṣepa": ['ddsa', 'mw'],
    "hetūkṛ": ['mw'],
    "hetūpamā": ['cae', 'mw'],
    "hetūpanyāsa": ['mw'],
    "hetūtprekṣā": ['mw'],
    "hetṛ": ['cae', 'gra', 'mw'],
    "hevajra": ['bhs', 'mw'],
    "hevara": ['bhs', 'mw'],
    "hevāka": ['ddsa', 'mw'],
    "hevākasa": ['ap90', 'mw'],
    "hevākaḥ": ['ap90'],
    "hevākin": ['ap90', 'ddsa', 'mw'],
    "hevākitā": ['mw'],
    "heya": ['ap90', 'cae', 'ddsa', 'mw'],
    "heyatva": ['mw'],
    "heḍ": ['ap90', 'cae', 'mw'],
    "heḍa": ['cae', 'ddsa', 'gra', 'mw'],
    "heḍaja": ['mw'],
    "heḍana": ['cae', 'gra', 'mw'],
    "heḍas": ['gra', 'mw'],
    "heḍaḥ": ['ap90'],
    "heḍh": ['mw'],
    "heḍieva": ['mw'],
    "heḍābukkaḥ": ['ap90'],
    "heḍāvuka": ['ddsa', 'mw'],
    "heḍāvukka": ['mw'],
    "heḍḍeśaharihara": ['mw'],
    "heṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "heṣa": ['mw'],
    "heṣakratu": ['ddsa', 'gra'],
    "heṣas": ['cae', 'ddsa', 'gra', 'mw'],
    "heṣasvant": ['cae'],
    "heṣasvat": ['gra', 'mw'],
    "heṣaḥ": ['ap90'],
    "heṣin": ['ap90', 'mw'],
    "heṣita": ['ddsa', 'mw'],
    "heṣvi": ['bhs'],
    "heṣā": ['cae', 'ddsa', 'mw'],
    "heṣāy": ['cae'],
    "heṣāya": ['ddsa', 'mw'],
    "heṣṭa": ['bhs'],
    "heṣṭato": ['bhs'],
    "heṣṭe": ['bhs'],
    "heṣṭena": ['bhs'],
    "heṣṭhato": ['bhs'],
    "heṣṭi": ['bhs'],
    "heṣṭima": ['bhs'],
    "heṣṭā": ['bhs'],
    "heṭ": ['mw'],
    "heṭh": ['ap90', 'mw'],
    "heṭha": ['mw'],
    "heṭhaka": ['bhs', 'cped'],
    "heṭhanā": ['bhs', 'cped'],
    "heṭhati": ['bhs'],
    "heṭhayamāna": ['cped'],
    "heṭhayitar": ['bhs'],
    "heṭhaḥ": ['ap90'],
    "heṭhenta": ['cped'],
    "heṭhesi": ['cped'],
    "heṭheti": ['cped'],
    "heṭhetvā": ['cped'],
    "heṭhita": ['cped'],
    "heṭhya": ['bhs'],
    "heṭhā": ['bhs'],
    "heṭṭhato": ['cped'],
    "heṭṭhima": ['cped'],
    "heṭṭhā": ['cped'],
    "heṭṭhābhāga": ['cped'],
    "heṭṭhāmañce": ['cped'],
    "heṭṭābhāga": ['cped'],
    "hi": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "hias": ['gra'],
    "hibuka": ['mw'],
    "hihi": ['mw'],
    "hijja": ['mw'],
    "hijjala": ['mw'],
    "hijjaḥ": ['ap90'],
    "hika": ['mw'],
    "hikk": ['ap90', 'cae', 'ddsa', 'mw'],
    "hikkala": ['mw'],
    "hikkikā": ['cae', 'mw'],
    "hikkin": ['mw'],
    "hikkita": ['mw'],
    "hikkā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "hikkāra": ['bhs'],
    "hikkāśvāsin": ['mw'],
    "hikmatpradīpa": ['mw'],
    "hikmatprakāśa": ['mw'],
    "hikvā": ['mw'],
    "hil": ['ap90', 'mw'],
    "hila": ['mw'],
    "hilamoci": ['mw'],
    "hilamocikā": ['mw'],
    "hilamocī": ['mw'],
    "hilihila": ['mw'],
    "hilima": ['bhs'],
    "hilimā": ['mw'],
    "hilla": ['ddsa', 'mw'],
    "hilliśāla": ['bhs'],
    "hillola": ['mw'],
    "hillolaya": ['mw'],
    "hillolaḥ": ['ap90'],
    "hillāja": ['mw'],
    "hillājadīpikā": ['mw'],
    "hillājagrahaphala": ['mw'],
    "hillājajātaka": ['mw'],
    "hillājatājika": ['mw'],
    "hilvalāḥ": ['ap90'],
    "hilīsamudra": ['mw'],
    "him": ['ddsa', 'gra', 'mw'],
    "hima": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "himabhānu": ['mw'],
    "himabhās": ['mw'],
    "himabhūbhṛt": ['mw'],
    "himabāluka": ['mw'],
    "himabālukā": ['mw'],
    "himadhara": ['mw'],
    "himadhvasta": ['mw'],
    "himadhāman": ['mw'],
    "himadhātu": ['mw'],
    "himadruh": ['mw'],
    "himadruma": ['mw'],
    "himadugdhā": ['mw'],
    "himadurdina": ['mw'],
    "himadyuti": ['cae', 'mw'],
    "himadīdhiti": ['cae', 'mw'],
    "himagarbha": ['cae', 'mw'],
    "himagaura": ['mw'],
    "himaghna": ['mw'],
    "himagiri": ['cae', 'mw'],
    "himagirisutā": ['mw'],
    "himagirisutākānta": ['mw'],
    "himagu": ['mw'],
    "himagṛha": ['mw'],
    "himagṛhaka": ['mw'],
    "himahānakṛt": ['mw'],
    "himahāsaka": ['mw'],
    "himaja": ['mw'],
    "himajhaṇṭi": ['mw'],
    "himajhaṭi": ['mw'],
    "himajvara": ['mw'],
    "himajyotis": ['mw'],
    "himajā": ['mw'],
    "himaka": ['mw'],
    "himakara": ['cae', 'mw'],
    "himakaratanaya": ['mw'],
    "himakaḥ": ['ap90'],
    "himakaṇin": ['mw'],
    "himakaṣāya": ['mw'],
    "himakhaṇḍa": ['mw'],
    "himakiraṇa": ['cae', 'mw'],
    "himakūṭa": ['mw'],
    "himakṣmādhara": ['mw'],
    "himamayūkha": ['cae', 'mw'],
    "himamitra": ['mw'],
    "himanirjharavipruṣmat": ['mw'],
    "himanirmukta": ['mw'],
    "himantrā": ['bhs'],
    "himaprastha": ['mw'],
    "himapāta": ['cae', 'mw'],
    "himaratī": ['bhs'],
    "himaraśmi": ['cae', 'mw'],
    "himaraśmija": ['mw'],
    "himartu": ['mw'],
    "himaruci": ['cae', 'mw'],
    "himarāja": ['mw'],
    "himasaras": ['cae', 'mw'],
    "himasaṃghāta": ['mw'],
    "himasaṃhati": ['mw'],
    "himasaṃkhāta": ['mw'],
    "himasrut": ['mw'],
    "himasruti": ['cae', 'mw'],
    "himataila": ['mw'],
    "himatala": ['mw'],
    "himatviṣ": ['cae', 'mw'],
    "himavaccandana": ['bhs'],
    "himavacchiras": ['mw'],
    "himavadgiri": ['mw'],
    "himavadgirisaṃśraya": ['mw'],
    "himavala": ['mw'],
    "himavanmekhalā": ['mw'],
    "himavanmāhātmya": ['mw'],
    "himavant": ['bhs', 'cae', 'cped'],
    "himavat": ['ap90', 'gra', 'mw'],
    "himavata": ['mw'],
    "himavatkhaṇḍa": ['mw'],
    "himavatkukṣi": ['mw'],
    "himavatprabhava": ['mw'],
    "himavatpura": ['mw'],
    "himavatsuta": ['mw'],
    "himavatsutā": ['mw'],
    "himavatī": ['mw'],
    "himaviddha": ['mw'],
    "himavāluka": ['mw'],
    "himavālukā": ['cae', 'mw'],
    "himavāri": ['cae', 'mw'],
    "himavṛṣṭi": ['mw'],
    "himayukta": ['mw'],
    "himaśaila": ['cae', 'mw'],
    "himaśailaja": ['mw'],
    "himaśailajā": ['mw'],
    "himaśailasutā": ['mw'],
    "himaśarkarā": ['mw'],
    "himaśikharin": ['mw'],
    "himaśranthana": ['mw'],
    "himaśratha": ['mw'],
    "himaśrathana": ['mw'],
    "himaśubhra": ['mw'],
    "himaśucibhasmabhūṣita": ['mw'],
    "himaśītala": ['mw'],
    "himaṛtu": ['mw'],
    "himelu": ['ap90', 'mw'],
    "himeru": ['mw'],
    "himia": ['gra'],
    "himikā": ['ap90', 'mw'],
    "himita": ['ddsa', 'mw'],
    "himmaka": ['ddsa', 'mw'],
    "himmativarman": ['mw'],
    "himna": ['mw'],
    "himnaḥ": ['ap90'],
    "himodaka": ['mw'],
    "himodaki": ['mw'],
    "himodbhavā": ['mw'],
    "himopacāra": ['ddsa', 'mw'],
    "himosra": ['mw'],
    "himotpanna": ['mw'],
    "himotpannā": ['mw'],
    "himottarā": ['mw'],
    "himottarīya": ['mw'],
    "himpativarman": ['mw'],
    "himya": ['ap90', 'mw'],
    "himyā": ['gra', 'mw'],
    "himā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "himābha": ['mw'],
    "himābhra": ['mw'],
    "himābja": ['mw'],
    "himācala": ['cae', 'mw'],
    "himācalendra": ['mw'],
    "himādri": ['cae', 'mw'],
    "himādrijā": ['mw'],
    "himādritanayā": ['mw'],
    "himādritanayāpati": ['mw'],
    "himādrīya": ['mw'],
    "himāga": ['mw'],
    "himāgama": ['cae', 'mw'],
    "himāhati": ['cae', 'mw'],
    "himāhva": ['mw'],
    "himāhvaya": ['mw'],
    "himāla": ['mw'],
    "himālaya": ['cae', 'mw'],
    "himālayasutā": ['mw'],
    "himālayā": ['mw'],
    "himāmbhas": ['cae', 'mw'],
    "himāmbu": ['mw'],
    "himānaddha": ['mw'],
    "himānila": ['mw'],
    "himānta": ['cae', 'ddsa', 'mw'],
    "himānī": ['ap90', 'cae', 'ddsa', 'mw'],
    "himānīviśada": ['mw'],
    "himāpaha": ['mw'],
    "himārdita": ['mw'],
    "himāri": ['mw'],
    "himāriśatru": ['mw'],
    "himārta": ['mw'],
    "himāruṇa": ['mw'],
    "himārāti": ['mw'],
    "himātyaya": ['cae', 'mw'],
    "himāvatī": ['mw'],
    "himāvila": ['mw'],
    "himāya": ['mw'],
    "himāśrayā": ['mw'],
    "himāṃśu": ['cae', 'ddsa', 'mw'],
    "himāṃśumālin": ['mw'],
    "himāṃśvabhikhya": ['mw'],
    "himāṅka": ['mw'],
    "himīkṛ": ['cae', 'mw'],
    "hina": ['ddsa', 'gra', 'mw'],
    "hindola": ['cae', 'ddsa', 'mw'],
    "hindolaka": ['mw'],
    "hindolaya": ['mw'],
    "hindolī": ['mw'],
    "hindu": ['cae', 'mw'],
    "hindudharma": ['mw'],
    "hindusthāna": ['mw'],
    "hinihināyamānā": ['bhs'],
    "hintāla": ['cae', 'cped', 'ddsa', 'mw'],
    "hinv": ['ddsa', 'mw'],
    "hinva": ['cae', 'ddsa', 'gra', 'mw'],
    "hinvidhenāman": ['mw'],
    "hinvāna": ['mw'],
    "hinānnavastraveṣa": ['mw'],
    "hira": ['cae', 'mw'],
    "hirakut": ['mw'],
    "hiramya": ['mw'],
    "hirañña": ['cped'],
    "hiraññasuvaṇṇa": ['cped'],
    "hiraṃguḥ": ['ap90'],
    "hiraṅgu": ['mw'],
    "hiraṇa": ['cae', 'mw'],
    "hiraṇaṃ": ['ap90'],
    "hiraṇin": ['gra', 'mw'],
    "hiraṇmaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "hiraṇvat": ['mw'],
    "hiraṇvatī": ['mw'],
    "hiraṇya": ['cae', 'ddsa', 'gra', 'mw'],
    "hiraṇyabandhana": ['mw'],
    "hiraṇyabindu": ['mw'],
    "hiraṇyabāhu": ['cae', 'gra', 'mw'],
    "hiraṇyacakra": ['cae', 'gra', 'mw'],
    "hiraṇyada": ['cae', 'mw'],
    "hiraṇyadakṣiṇa": ['mw'],
    "hiraṇyadanta": ['cae', 'gra', 'mw'],
    "hiraṇyadat": ['mw'],
    "hiraṇyadatta": ['mw'],
    "hiraṇyadaṃṣṭra": ['mw'],
    "hiraṇyadevīsūkta": ['mw'],
    "hiraṇyadhanus": ['mw'],
    "hiraṇyadhanyaśirika": ['bhs'],
    "hiraṇyadrāpi": ['mw'],
    "hiraṇyadyū": ['mw'],
    "hiraṇyadā": ['cae', 'gra', 'mw'],
    "hiraṇyadāna": ['mw'],
    "hiraṇyagadā": ['mw'],
    "hiraṇyagadādāna": ['mw'],
    "hiraṇyagarbha": ['bhs', 'cae', 'gra', 'mw'],
    "hiraṇyagarbhadāna": ['mw'],
    "hiraṇyagarbhadānaprayoga": ['mw'],
    "hiraṇyagarbhadānavidhi": ['mw'],
    "hiraṇyagarbhahṛdaya": ['mw'],
    "hiraṇyagarbhasaṃhitā": ['mw'],
    "hiraṇyagarbhatantra": ['mw'],
    "hiraṇyagarbhavatī": ['mw'],
    "hiraṇyagarbhavidhi": ['mw'],
    "hiraṇyagarbhā": ['mw'],
    "hiraṇyagupta": ['mw'],
    "hiraṇyahasta": ['cae', 'gra', 'mw'],
    "hiraṇyaheman": ['mw'],
    "hiraṇyajihva": ['cae', 'gra', 'mw'],
    "hiraṇyajit": ['cae', 'gra', 'mw'],
    "hiraṇyajyotis": ['cae', 'mw'],
    "hiraṇyajā": ['mw'],
    "hiraṇyaka": ['mw'],
    "hiraṇyakakṣa": ['mw'],
    "hiraṇyakakṣya": ['mw'],
    "hiraṇyakartṛ": ['cae', 'mw'],
    "hiraṇyakarṇa": ['gra', 'mw'],
    "hiraṇyakavaca": ['mw'],
    "hiraṇyakavacodbhava": ['mw'],
    "hiraṇyakaśipu": ['cae', 'mw'],
    "hiraṇyakaśipucchedin": ['mw'],
    "hiraṇyakaśipudāraṇa": ['mw'],
    "hiraṇyakaśipuhan": ['mw'],
    "hiraṇyakaṇṭha": ['cae', 'mw'],
    "hiraṇyaketu": ['mw'],
    "hiraṇyakeśa": ['cae', 'gra', 'mw'],
    "hiraṇyakeśia": ['gra'],
    "hiraṇyakeśikārikā": ['mw'],
    "hiraṇyakeśin": ['mw'],
    "hiraṇyakeśisūtra": ['mw'],
    "hiraṇyakeśisūtravyākhyāna": ['mw'],
    "hiraṇyakeśiśrautasūtra": ['mw'],
    "hiraṇyakeśiśākhīyabrāhmaṇa": ['mw'],
    "hiraṇyakeśya": ['cae', 'gra', 'mw'],
    "hiraṇyakeśyāhnika": ['mw'],
    "hiraṇyakeśī": ['mw'],
    "hiraṇyakeśīyāgnyādhānapaddhati": ['mw'],
    "hiraṇyakhādi": ['mw'],
    "hiraṇyakośa": ['mw'],
    "hiraṇyakubja": ['mw'],
    "hiraṇyakukṣi": ['mw'],
    "hiraṇyakula": ['mw'],
    "hiraṇyakāmadhenu": ['mw'],
    "hiraṇyakāmadhenudāna": ['mw'],
    "hiraṇyakāmadhenudānaprayoga": ['mw'],
    "hiraṇyakāra": ['cae', 'mw'],
    "hiraṇyakṛt": ['mw'],
    "hiraṇyakṛtacūḍa": ['mw'],
    "hiraṇyakṛṣṇala": ['mw'],
    "hiraṇyalakṣmīsūkta": ['mw'],
    "hiraṇyaloman": ['mw'],
    "hiraṇyamaya": ['cae', 'mw'],
    "hiraṇyamālin": ['mw'],
    "hiraṇyamūrdhan": ['cae', 'mw'],
    "hiraṇyanemi": ['cae', 'gra', 'mw'],
    "hiraṇyanidhi": ['cae', 'mw'],
    "hiraṇyanikāṣam": ['mw'],
    "hiraṇyanirṇij": ['cae', 'gra', 'mw'],
    "hiraṇyanābha": ['mw'],
    "hiraṇyapakṣa": ['gra', 'mw'],
    "hiraṇyaparvata": ['mw'],
    "hiraṇyaparṇa": ['cae', 'gra', 'mw'],
    "hiraṇyapati": ['mw'],
    "hiraṇyapeśas": ['gra', 'mw'],
    "hiraṇyapiṇḍa": ['cae', 'gra', 'mw'],
    "hiraṇyapratipūrṇa": ['mw'],
    "hiraṇyaprauga": ['gra', 'mw'],
    "hiraṇyaprākārā": ['mw'],
    "hiraṇyapura": ['mw'],
    "hiraṇyapuruṣa": ['mw'],
    "hiraṇyapuṣpi": ['mw'],
    "hiraṇyapuṣpī": ['mw'],
    "hiraṇyapātra": ['cae', 'mw'],
    "hiraṇyapāva": ['gra', 'mw'],
    "hiraṇyapāṇi": ['bhs', 'cae', 'gra', 'mw'],
    "hiraṇyaratha": ['cae', 'ddsa', 'gra', 'mw'],
    "hiraṇyaraśana": ['mw'],
    "hiraṇyaretas": ['cae', 'mw'],
    "hiraṇyaretasa": ['mw'],
    "hiraṇyaroman": ['mw'],
    "hiraṇyarūpa": ['cae', 'gra', 'mw'],
    "hiraṇyasaras": ['mw'],
    "hiraṇyasaṃdṛś": ['cae', 'gra', 'mw'],
    "hiraṇyasaṃkāśa": ['mw'],
    "hiraṇyasraj": ['cae', 'mw'],
    "hiraṇyasthāla": ['mw'],
    "hiraṇyastuti": ['mw'],
    "hiraṇyastūpa": ['gra', 'mw'],
    "hiraṇyatejas": ['mw'],
    "hiraṇyatuṣa": ['mw'],
    "hiraṇyatvac": ['gra', 'mw'],
    "hiraṇyatvaca": ['mw'],
    "hiraṇyatvacas": ['mw'],
    "hiraṇyava": ['mw'],
    "hiraṇyavakṣas": ['cae', 'mw'],
    "hiraṇyavandhura": ['cae', 'gra', 'mw'],
    "hiraṇyavant": ['cae'],
    "hiraṇyavarcasa": ['mw'],
    "hiraṇyavarman": ['mw'],
    "hiraṇyavartani": ['cae', 'gra', 'mw'],
    "hiraṇyavarṇa": ['cae', 'gra', 'mw'],
    "hiraṇyavarṇā": ['mw'],
    "hiraṇyavarṇīya": ['mw'],
    "hiraṇyavarṣa": ['mw'],
    "hiraṇyavat": ['gra', 'mw'],
    "hiraṇyavatī": ['bhs', 'mw'],
    "hiraṇyavaḥ": ['ap90'],
    "hiraṇyavid": ['gra', 'mw'],
    "hiraṇyavimita": ['cae', 'mw'],
    "hiraṇyavāha": ['mw'],
    "hiraṇyavāśī": ['cae', 'gra', 'mw'],
    "hiraṇyavāśīmant": ['cae'],
    "hiraṇyavāśīmat": ['gra', 'mw'],
    "hiraṇyavī": ['gra', 'mw'],
    "hiraṇyavīrya": ['mw'],
    "hiraṇyavṛṣabha": ['mw'],
    "hiraṇyavṛṣabhadāna": ['mw'],
    "hiraṇyavṛṣabhadānaprayoga": ['mw'],
    "hiraṇyaya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hiraṇyayaṣṭi": ['mw'],
    "hiraṇyayoni": ['mw'],
    "hiraṇyayu": ['cae', 'gra', 'mw'],
    "hiraṇyayā": ['gra', 'mw'],
    "hiraṇyaśakala": ['mw'],
    "hiraṇyaśakla": ['mw'],
    "hiraṇyaśalka": ['mw'],
    "hiraṇyaśamya": ['gra', 'mw'],
    "hiraṇyaśarīra": ['mw'],
    "hiraṇyaśipra": ['cae', 'gra', 'mw'],
    "hiraṇyaśmaśru": ['cae', 'mw'],
    "hiraṇyaśrāddha": ['mw'],
    "hiraṇyaśīrṣan": ['mw'],
    "hiraṇyaśṛṅga": ['cae', 'gra', 'mw'],
    "hiraṇyaṃ": ['ap90'],
    "hiraṇyaṣṭhīva": ['mw'],
    "hiraṇyaṣṭhīvin": ['mw'],
    "hiraṇyeśaya": ['mw'],
    "hiraṇyeṣṭakā": ['mw'],
    "hiraṇyin": ['mw'],
    "hiraṇyinī": ['mw'],
    "hiraṇyā": ['mw'],
    "hiraṇyābhīśu": ['cae', 'gra', 'mw'],
    "hiraṇyābja": ['mw'],
    "hiraṇyākṣa": ['cae', 'gra', 'mw'],
    "hiraṇyākṣahara": ['mw'],
    "hiraṇyākṣaripu": ['mw'],
    "hiraṇyāśva": ['mw'],
    "hiraṇyāśvadāna": ['mw'],
    "hiraṇyāśvaratha": ['mw'],
    "hiraṇyāṅga": ['mw'],
    "hiri": ['bhs', 'cae', 'cped', 'mw'],
    "hirikeśa": ['bhs'],
    "hirikopīna": ['cped'],
    "hirimant": ['cped'],
    "hirimantatā": ['bhs'],
    "hirivera": ['mw'],
    "hiriśipra": ['cae', 'gra', 'mw'],
    "hiriśmaśru": ['cae', 'gra', 'mw'],
    "hirodaka": ['bhs', 'mw'],
    "hirottappa": ['cped'],
    "hiru": ['bhs', 'mw'],
    "hiruk": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hiruka": ['bhs', 'mw'],
    "hirā": ['bhs', 'ddsa', 'mw'],
    "hirādhara": ['mw'],
    "hirī": ['bhs'],
    "hirīmant": ['cae'],
    "hirīmat": ['gra', 'mw'],
    "hirīmaśa": ['mw'],
    "hirīmaśas": ['gra'],
    "hirīyanā": ['cped'],
    "hirīyati": ['cped'],
    "hita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "hitabuddhi": ['cae', 'mw'],
    "hitacaraṇasaṃkrama": ['bhs'],
    "hitaharivaṃśa": ['mw'],
    "hitaharivaṃśagosvāmin": ['mw'],
    "hitahita": ['mw'],
    "hitaiṣin": ['cae', 'ddsa', 'mw'],
    "hitaiṣitā": ['mw'],
    "hitaka": ['mw'],
    "hitakara": ['cae', 'cped', 'mw'],
    "hitakaḥ": ['ap90'],
    "hitakāma": ['cae', 'mw'],
    "hitakāmyā": ['cae', 'mw'],
    "hitakāraka": ['cae', 'mw'],
    "hitakārin": ['cae', 'mw'],
    "hitakāritva": ['mw'],
    "hitakāritā": ['mw'],
    "hitakṛt": ['cae', 'mw'],
    "hitalālaśarman": ['mw'],
    "hitamitra": ['cae', 'gra', 'mw'],
    "hitanāman": ['mw'],
    "hitapathya": ['mw'],
    "hitapravṛtta": ['mw'],
    "hitaprayas": ['cae', 'gra', 'mw'],
    "hitapraṇī": ['mw'],
    "hitaprepsu": ['cae', 'mw'],
    "hitasūtra": ['mw'],
    "hitavacana": ['cae', 'mw'],
    "hitavant": ['cae'],
    "hitavat": ['mw'],
    "hitavādin": ['mw'],
    "hitavākya": ['mw'],
    "hitavākyasūtra": ['mw'],
    "hitaṃkara": ['bhs'],
    "hitaṃkarin": ['bhs'],
    "hitecchā": ['cae', 'ddsa', 'mw'],
    "hitepsā": ['cae'],
    "hitesī": ['cped'],
    "hiteṣin": ['bhs'],
    "hiti": ['cae', 'gra', 'mw'],
    "hitokti": ['mw'],
    "hitopadeśa": ['cae', 'ddsa', 'mw'],
    "hitopadeṣṭṛ": ['mw'],
    "hitvan": ['cae', 'gra', 'mw'],
    "hitvā": ['cae', 'mw'],
    "hitvāya": ['ddsa', 'mw'],
    "hitā": ['cae', 'ddsa', 'mw'],
    "hitābhaṅga": ['cae', 'ddsa', 'mw'],
    "hitādhāyin": ['ddsa', 'mw'],
    "hitādhāyitā": ['mw'],
    "hitāhita": ['cae', 'mw'],
    "hitāhitā": ['mw'],
    "hitāhitīya": ['mw'],
    "hitānubandhin": ['mw'],
    "hitānukārin": ['mw'],
    "hitānveṣin": ['cae', 'mw'],
    "hitārtha": ['ddsa'],
    "hitārtham": ['cae', 'mw'],
    "hitārthin": ['cae', 'mw'],
    "hitārthāya": ['cae', 'mw'],
    "hitātman": ['mw'],
    "hitāvaha": ['cped'],
    "hitāvalī": ['mw'],
    "hitāvat": ['gra', 'mw'],
    "hitāya": ['ddsa', 'mw'],
    "hitāśaṃsā": ['mw'],
    "hitāśva": ['mw'],
    "hivuka": ['mw'],
    "hiyyo": ['cped'],
    "hiyāna": ['mw'],
    "hiñjīra": ['ddsa', 'mw'],
    "hiḍimba": ['cae', 'ddsa', 'mw'],
    "hiḍimbabhid": ['mw'],
    "hiḍimbadviṣ": ['mw'],
    "hiḍimbajit": ['mw'],
    "hiḍimbanisūdana": ['mw'],
    "hiḍimbavadha": ['mw'],
    "hiḍimbā": ['mw'],
    "hiḍimbāpati": ['mw'],
    "hiḍimbāramaṇa": ['mw'],
    "hiḍiṃbaḥ": ['ap90'],
    "hiṁsamāna": ['cped'],
    "hiṁsana": ['cped'],
    "hiṁsanta": ['cped'],
    "hiṁsanā": ['cped'],
    "hiṁsati": ['cped'],
    "hiṁsi": ['cped'],
    "hiṁsita": ['cped'],
    "hiṁsitvā": ['cped'],
    "hiṁsā": ['cped'],
    "hiṁsāpesi": ['cped'],
    "hiṁsāpeti": ['cped'],
    "hiṁsāpetvā": ['cped'],
    "hiṁsāpita": ['cped'],
    "hiṃdolakaḥ": ['ap90'],
    "hiṃdolaḥ": ['ap90'],
    "hiṃduḥ": ['ap90'],
    "hiṃgu": ['ap90'],
    "hiṃgulaḥ": ['ap90'],
    "hiṃgulikā": ['ap90'],
    "hiṃguliḥ": ['ap90'],
    "hiṃgulu": ['ap90'],
    "hiṃgulī": ['ap90'],
    "hiṃjīraḥ": ['ap90'],
    "hiṃkāraḥ": ['ap90'],
    "hiṃs": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hiṃsa": ['cae', 'ddsa', 'mw'],
    "hiṃsaka": ['ap90', 'cae', 'mw'],
    "hiṃsana": ['cae', 'mw'],
    "hiṃsanaṃ": ['ap90'],
    "hiṃsanīya": ['cae', 'mw'],
    "hiṃsatā": ['bhs'],
    "hiṃsita": ['ap90', 'cae', 'mw'],
    "hiṃsitavya": ['mw'],
    "hiṃsitos": ['mw'],
    "hiṃsra": ['ap90', 'cae', 'gra', 'mw'],
    "hiṃsrajantu": ['cae', 'mw'],
    "hiṃsraka": ['mw'],
    "hiṃsrakaḥ": ['ap90'],
    "hiṃsrapaśu": ['cae', 'mw'],
    "hiṃsrayantra": ['mw'],
    "hiṃsrā": ['ap90', 'mw'],
    "hiṃsrāhiṃsra": ['cae', 'mw'],
    "hiṃsrātmatā": ['mw'],
    "hiṃsya": ['ap90', 'cae', 'mw'],
    "hiṃsā": ['ap90', 'mw'],
    "hiṃsākarman": ['mw'],
    "hiṃsālakṣaṇa": ['mw'],
    "hiṃsālu": ['ap90', 'mw'],
    "hiṃsāluka": ['mw'],
    "hiṃsāprāya": ['cae', 'mw'],
    "hiṃsāprāṇin": ['mw'],
    "hiṃsāprāṇipracura": ['mw'],
    "hiṃsārata": ['cae', 'mw'],
    "hiṃsārthavāda": ['mw'],
    "hiṃsāru": ['mw'],
    "hiṃsāruci": ['mw'],
    "hiṃsārucitva": ['mw'],
    "hiṃsāruḥ": ['ap90'],
    "hiṃsāsamudbhava": ['mw'],
    "hiṃsātmaka": ['cae', 'mw'],
    "hiṃsātman": ['mw'],
    "hiṃsāvihāra": ['mw'],
    "hiṃsāvāda": ['mw'],
    "hiṃsīna": ['mw'],
    "hiṃsīra": ['mw'],
    "hiṃsīraḥ": ['ap90'],
    "hiṃtālaḥ": ['ap90'],
    "hiṃḍ": ['ap90'],
    "hiṃḍanaṃ": ['ap90'],
    "hiṃḍikaḥ": ['ap90'],
    "hiṃḍiraḥ": ['ap90'],
    "hiṃḍī": ['ap90'],
    "hiṃḍīraḥ": ['ap90'],
    "hiṅ": ['cae', 'ddsa', 'gra', 'mw'],
    "hiṅga": ['mw'],
    "hiṅgalācī": ['mw'],
    "hiṅgolāṣṭaka": ['mw'],
    "hiṅgu": ['cae', 'cped', 'ddsa', 'mw'],
    "hiṅgudī": ['mw'],
    "hiṅguka": ['mw'],
    "hiṅgula": ['cae', 'ddsa', 'mw'],
    "hiṅgulaka": ['bhs', 'cae', 'cped', 'mw'],
    "hiṅguli": ['cped', 'mw'],
    "hiṅgulikā": ['mw'],
    "hiṅgulu": ['mw'],
    "hiṅguluka": ['mw'],
    "hiṅgulā": ['mw'],
    "hiṅgulājā": ['mw'],
    "hiṅgulī": ['mw'],
    "hiṅguniryāsa": ['mw'],
    "hiṅgunāḍikā": ['mw'],
    "hiṅguparṇī": ['mw'],
    "hiṅgupattra": ['mw'],
    "hiṅgupattrī": ['mw'],
    "hiṅgurāta": ['mw'],
    "hiṅguśirāṭikā": ['mw'],
    "hiṅguśivāṭikā": ['mw'],
    "hiṅgūjjvalā": ['cae', 'mw'],
    "hiṅgūla": ['mw'],
    "hiṅkartṛ": ['cae', 'mw'],
    "hiṅkriyā": ['mw'],
    "hiṅkāra": ['cae', 'mw'],
    "hiṅkṛ": ['mw'],
    "hiṅkṛṇvat": ['gra'],
    "hiṇḍ": ['cae', 'ddsa', 'mw'],
    "hiṇḍaka": ['mw'],
    "hiṇḍana": ['mw'],
    "hiṇḍati": ['bhs'],
    "hiṇḍi": ['mw'],
    "hiṇḍika": ['mw'],
    "hiṇḍira": ['mw'],
    "hiṇḍuka": ['mw'],
    "hiṇḍī": ['mw'],
    "hiṇḍīkānta": ['mw'],
    "hiṇḍīpriyatama": ['mw'],
    "hiṇḍīra": ['mw'],
    "hiṣati": ['bhs'],
    "hiṣk": ['mw'],
    "hiṣkā": ['mw'],
    "hiṭ": ['mw'],
    "hlag": ['ap90', 'mw'],
    "hlanna": ['mw'],
    "hlanni": ['mw'],
    "hlap": ['ap90', 'mw'],
    "hlas": ['ap90', 'mw'],
    "hlatti": ['mw'],
    "hlattiḥ": ['ap90'],
    "hleṣ": ['mw'],
    "hleṣā": ['mw'],
    "hlād": ['ap90', 'cae', 'ddsa', 'mw'],
    "hlāda": ['cae', 'ddsa', 'mw'],
    "hlādaka": ['cae', 'mw'],
    "hlādana": ['cae', 'mw'],
    "hlādanaṃ": ['ap90'],
    "hlādanīya": ['mw'],
    "hlādaḥ": ['ap90'],
    "hlādika": ['gra'],
    "hlādikāvat": ['gra'],
    "hlādikāvatī": ['cae', 'mw'],
    "hlādin": ['ap90', 'cae', 'mw'],
    "hlādinī": ['ap90', 'mw'],
    "hlādita": ['mw'],
    "hlāditva": ['mw'],
    "hlāduka": ['cae', 'mw'],
    "hlādukāvatī": ['mw'],
    "hlāduni": ['mw'],
    "hlī": ['mw'],
    "hlīka": ['ap90', 'cae', 'ddsa', 'mw'],
    "hlīku": ['mw'],
    "hlīkā": ['mw'],
    "hmal": ['ap90', 'mw'],
    "hmala": ['mw'],
    "hmāla": ['mw'],
    "hnava": ['mw'],
    "hnavana": ['mw'],
    "hnavaḥ": ['ap90'],
    "hnavāyya": ['mw'],
    "hnotavya": ['mw'],
    "hnu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hnuta": ['mw'],
    "hnuti": ['mw'],
    "hnutiḥ": ['ap90'],
    "ho": ['ap90', 'cae', 'ddsa', 'mw'],
    "hobhaṇe": ['bhs'],
    "hohau": ['ap90', 'mw'],
    "hoiḍa": ['mw'],
    "hola": ['ddsa', 'mw'],
    "holaka": ['mw'],
    "holakaḥ": ['ap90'],
    "holarā": ['mw'],
    "holasiṃha": ['mw'],
    "holaḍa": ['ddsa', 'mw'],
    "holikotpatti": ['mw'],
    "holikā": ['ap90', 'mw'],
    "holikāmāhātmya": ['mw'],
    "holikāprayoga": ['mw'],
    "holikāpūjanā": ['mw'],
    "holikāpūjā": ['mw'],
    "holikāvidhāna": ['mw'],
    "holinirṇaya": ['mw'],
    "holā": ['mw'],
    "holāka": ['mw'],
    "holākhelana": ['mw'],
    "holākā": ['ap90', 'mw'],
    "holī": ['mw'],
    "holīra": ['mw'],
    "homa": ['cae', 'cped', 'ddsa', 'mw'],
    "homabhasman": ['mw'],
    "homabhāṇḍa": ['cae', 'ddsa', 'mw'],
    "homadarpaṇavidhi": ['mw'],
    "homadarvī": ['mw'],
    "homadhenu": ['cae', 'mw'],
    "homadhānya": ['mw'],
    "homadhūma": ['mw'],
    "homadravya": ['mw'],
    "homadravyapariṇāma": ['mw'],
    "homaduh": ['mw'],
    "homadvayaprayoga": ['mw'],
    "homadvayasamāsaprayoga": ['mw'],
    "homaka": ['mw'],
    "homakalpa": ['mw'],
    "homakarman": ['cae', 'mw'],
    "homakaḥ": ['ap90'],
    "homakuṇḍa": ['mw'],
    "homakāla": ['cae', 'mw'],
    "homakālātikramaprāyaścittaprayoga": ['mw'],
    "homakāṣṭhī": ['mw'],
    "homalopaprāyaścittaprayoga": ['mw'],
    "homamantrabhāṣya": ['mw'],
    "homan": ['cae', 'ddsa', 'gra'],
    "homanirṇaya": ['mw'],
    "homapaddhati": ['mw'],
    "homaprāyaścitta": ['mw'],
    "homasvarottara": ['mw'],
    "homatarpaṇavidhi": ['mw'],
    "homatattvavidhi": ['mw'],
    "homaturaṃga": ['cae', 'mw'],
    "homavant": ['cae'],
    "homavat": ['mw'],
    "homavelā": ['cae', 'mw'],
    "homavidhi": ['mw'],
    "homavidhāna": ['mw'],
    "homay": ['cae'],
    "homaya": ['ddsa'],
    "homayūpa": ['mw'],
    "homaśālā": ['mw'],
    "homaḥ": ['ap90'],
    "homendhana": ['mw'],
    "homi": ['mw'],
    "homin": ['ap90', 'cae', 'ddsa', 'mw'],
    "hominī": ['mw'],
    "homiḥ": ['ap90'],
    "homya": ['cae', 'mw'],
    "homāgni": ['cae', 'ddsa', 'mw'],
    "homānala": ['cae', 'mw'],
    "homārjunī": ['mw'],
    "homīya": ['ap90', 'cae', 'mw'],
    "homīyadravya": ['mw'],
    "honta": ['cped'],
    "horapāṭhaka": ['bhs'],
    "horilamiśra": ['mw'],
    "horilasiṃha": ['mw'],
    "horā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "horācūḍāmaṇi": ['mw'],
    "horādhyāya": ['mw'],
    "horākandarpajātaka": ['mw'],
    "horālocana": ['cped'],
    "horāmakaranda": ['mw'],
    "horāmakarandoharaṇa": ['mw'],
    "horāpradīpa": ['mw'],
    "horāprakaraṇa": ['mw'],
    "horāprakāśa": ['mw'],
    "horāpāṭhaka": ['cped'],
    "horāratna": ['mw'],
    "horāsetu": ['mw'],
    "horāsāra": ['mw'],
    "horāsārasudhānidhi": ['mw'],
    "horāvid": ['mw'],
    "horāyanta": ['cped'],
    "horāśāstra": ['cae', 'mw'],
    "horāśāstrasudhānidhi": ['mw'],
    "horāśāstrasāra": ['mw'],
    "horāśāstrārṇavasāra": ['mw'],
    "horāṣaṭpañcāśikā": ['mw'],
    "hosiṅgakṛṣṇa": ['mw'],
    "hosiṭakabhaṭṭa": ['mw'],
    "hotabba": ['cped'],
    "hotaryaja": ['mw'],
    "hotavya": ['cae', 'ddsa', 'mw'],
    "hoti": ['bhs', 'cped'],
    "hotos": ['mw'],
    "hotra": ['cae', 'ddsa', 'gra', 'mw'],
    "hotraka": ['cae', 'mw'],
    "hotraprayoga": ['mw'],
    "hotravah": ['cae', 'gra', 'mw'],
    "hotravāh": ['gra', 'mw'],
    "hotravāhana": ['mw'],
    "hotraṃ": ['ap90'],
    "hotrin": ['ap90', 'mw'],
    "hotriya": ['cae', 'ddsa', 'gra', 'mw'],
    "hotrā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hotrābhiḥ": ['mw'],
    "hotrācamasa": ['mw'],
    "hotrāvid": ['cae', 'gra', 'mw'],
    "hotrāśaṃsin": ['cae', 'mw'],
    "hotrī": ['ap90', 'mw'],
    "hotrīya": ['ap90', 'cae', 'mw'],
    "hoturantevasin": ['mw'],
    "hotuṁ": ['cped'],
    "hotva": ['cae', 'mw'],
    "hotvan": ['mw'],
    "hotādhvaryū": ['mw'],
    "hotāpotārau": ['mw'],
    "hotāyakṣa": ['mw'],
    "hotṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hotṛcamasa": ['mw'],
    "hotṛcamasīya": ['mw'],
    "hotṛjapa": ['mw'],
    "hotṛka": ['cae', 'mw'],
    "hotṛkarman": ['mw'],
    "hotṛkaḥ": ['ap90'],
    "hotṛmant": ['cae'],
    "hotṛmat": ['gra', 'mw'],
    "hotṛpravara": ['cae', 'mw'],
    "hotṛsaṃsthājapa": ['mw'],
    "hotṛtva": ['cae', 'mw'],
    "hotṛvarya": ['cae', 'mw'],
    "hotṛveda": ['mw'],
    "hotṛvūria": ['gra'],
    "hotṛvūrya": ['cae', 'gra', 'mw'],
    "hotṛṣadana": ['cae', 'gra', 'mw'],
    "hotṛṣāman": ['mw'],
    "hoḍ": ['ap90', 'mw'],
    "hoḍa": ['mw'],
    "hoḍaḥ": ['ap90'],
    "hoḍha": ['ddsa', 'mw'],
    "hoḍhaṃ": ['ap90'],
    "hoḍiman": ['mw'],
    "hoḍā": ['mw'],
    "hoḍṛ": ['ap90', 'mw'],
    "hoṣa": ['gra'],
    "hoṣin": ['gra', 'mw'],
    "hoṭā": ['mw'],
    "hrada": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "hradagraha": ['mw'],
    "hradaka": ['mw'],
    "hradavya": ['mw'],
    "hradayya": ['cae', 'mw'],
    "hradaḥ": ['ap90'],
    "hradecakṣus": ['gra', 'mw'],
    "hradin": ['cae', 'mw'],
    "hradinī": ['ap90', 'mw'],
    "hradodara": ['mw'],
    "hradrogaḥ": ['ap90'],
    "hradya": ['cae', 'mw'],
    "hradā": ['mw'],
    "hradālayeśamāhātmya": ['mw'],
    "hradāntara": ['mw'],
    "hradī": ['mw'],
    "hrag": ['ap90', 'mw'],
    "hrap": ['ap90', 'mw'],
    "hras": ['ap90', 'cae', 'ddsa', 'mw'],
    "hrasiman": ['ap90', 'mw'],
    "hrasita": ['ap90', 'mw'],
    "hrasiṣṭha": ['ap90', 'cae', 'ddsa', 'mw'],
    "hrasta": ['mw'],
    "hrasva": ['ap90', 'cae', 'ddsa', 'mw'],
    "hrasvabāhu": ['cae', 'mw'],
    "hrasvabāhuka": ['mw'],
    "hrasvadarbha": ['mw'],
    "hrasvadā": ['mw'],
    "hrasvagavedhukā": ['mw'],
    "hrasvairaṇḍa": ['mw'],
    "hrasvajambū": ['mw'],
    "hrasvajātya": ['mw'],
    "hrasvaka": ['ap90', 'cae', 'mw'],
    "hrasvakarṇa": ['cae', 'mw'],
    "hrasvakarṣaṇa": ['mw'],
    "hrasvakuśa": ['mw'],
    "hrasvamūla": ['mw'],
    "hrasvamūlaka": ['mw'],
    "hrasvamūrti": ['mw'],
    "hrasvanirvaṃśaka": ['mw'],
    "hrasvaparṇa": ['mw'],
    "hrasvapattraka": ['mw'],
    "hrasvapattrikā": ['mw'],
    "hrasvaphala": ['mw'],
    "hrasvaphalā": ['mw'],
    "hrasvaplakṣa": ['mw'],
    "hrasvapūrva": ['mw'],
    "hrasvaroman": ['mw'],
    "hrasvasabhā": ['mw'],
    "hrasvataṇḍula": ['mw'],
    "hrasvatva": ['mw'],
    "hrasvatā": ['cae', 'mw'],
    "hrasvaśigruka": ['mw'],
    "hrasvaśākhāśipha": ['mw'],
    "hrasvodaya": ['mw'],
    "hrasvopadha": ['mw'],
    "hrasvā": ['mw'],
    "hrasvāgni": ['mw'],
    "hrasvāṅga": ['mw'],
    "hrasīyas": ['ap90', 'mw'],
    "hrasīyasī": ['mw'],
    "hrasīyaṃs": ['cae'],
    "hraum": ['mw'],
    "hrauḍ": ['ap90', 'mw'],
    "hraya": ['gra'],
    "hraṇiyā": ['mw'],
    "hraṇīyā": ['ap90', 'mw'],
    "hrep": ['ap90', 'mw'],
    "hrepaṇa": ['cae', 'ddsa', 'mw'],
    "hrepaṇaṃ": ['ap90'],
    "hrepita": ['mw'],
    "hretavya": ['bhs'],
    "hreṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "hreṣin": ['cae', 'mw'],
    "hreṣita": ['mw'],
    "hreṣuka": ['cae', 'mw'],
    "hreṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "hrita": ['mw'],
    "hriti": ['mw'],
    "hrivera": ['mw'],
    "hriyāpayati": ['bhs'],
    "hriyāyati": ['bhs'],
    "hriṇiyā": ['mw'],
    "hriṇīya": ['ddsa', 'mw'],
    "hriṇīyate": ['ap90'],
    "hriṇīyā": ['ap90', 'mw'],
    "hrnīy": ['gra'],
    "hroḍa": ['mw'],
    "hru": ['cae', 'ddsa', 'gra', 'mw'],
    "hrum": ['mw'],
    "hrut": ['cae', 'ddsa', 'gra', 'mw'],
    "hruta": ['cae', 'mw'],
    "hruḍ": ['ap90', 'mw'],
    "hrād": ['ap90', 'cae', 'ddsa', 'mw'],
    "hrāda": ['cae', 'ddsa', 'mw'],
    "hrādaka": ['mw'],
    "hrādaḥ": ['ap90'],
    "hrādin": ['ap90', 'cae', 'mw'],
    "hrādinī": ['ap90', 'mw'],
    "hrāduni": ['cae', 'ddsa', 'gra', 'mw'],
    "hrādunihata": ['mw'],
    "hrādunī": ['cae', 'mw'],
    "hrādunīvṛt": ['cae', 'gra', 'mw'],
    "hrām": ['mw'],
    "hrāsa": ['cae', 'ddsa', 'mw'],
    "hrāsaka": ['ap90', 'mw'],
    "hrāsana": ['mw'],
    "hrāsanīya": ['mw'],
    "hrāsaḥ": ['ap90'],
    "hrāsi": ['bhs'],
    "hrāsva": ['mw'],
    "hrāsānveṣaṇavat": ['mw'],
    "hrī": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "hrībala": ['mw'],
    "hrībhaya": ['mw'],
    "hrīch": ['ap90', 'mw'],
    "hrīdeva": ['bhs', 'mw'],
    "hrīdhārin": ['mw'],
    "hrījita": ['mw'],
    "hrīka": ['cae', 'mw'],
    "hrīku": ['ap90', 'mw'],
    "hrīkā": ['ap90', 'mw'],
    "hrīm": ['mw'],
    "hrīmant": ['cae'],
    "hrīmat": ['mw'],
    "hrīmattva": ['mw'],
    "hrīmūḍha": ['mw'],
    "hrīnirāsa": ['mw'],
    "hrīniṣeva": ['mw'],
    "hrīpada": ['ddsa', 'mw'],
    "hrīrapatrāpya": ['bhs'],
    "hrīsannakaṇṭha": ['mw'],
    "hrīta": ['mw'],
    "hrītamukha": ['cae', 'ddsa', 'mw'],
    "hrītamukhin": ['cae', 'mw'],
    "hrīti": ['ddsa', 'mw'],
    "hrīvela": ['mw'],
    "hrīvelaka": ['mw'],
    "hrīvera": ['mw'],
    "hrīveraṃ": ['ap90'],
    "hrīyantraṇā": ['mw'],
    "hrīyāyati": ['bhs'],
    "hrīṇa": ['ap90', 'mw'],
    "hrīṇamukha": ['mw'],
    "hrūḍ": ['mw'],
    "hrūḍru": ['mw'],
    "hrūḍu": ['mw'],
    "hu": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "huduhuduyati": ['bhs'],
    "hugali": ['mw'],
    "hugalī": ['mw'],
    "hugga": ['mw'],
    "huguli": ['mw'],
    "hugulī": ['mw'],
    "huhava": ['mw'],
    "huhu": ['ap90', 'cae', 'ddsa', 'mw'],
    "huhuva": ['bhs', 'mw'],
    "huhuṃ": ['bhs'],
    "huhuṃkajātika": ['bhs'],
    "huhū": ['ap90', 'cae', 'mw'],
    "hukkāra": ['mw'],
    "hul": ['ap90', 'mw'],
    "hula": ['cae', 'mw'],
    "hulahulī": ['ap90', 'cae', 'mw'],
    "hulamātrikā": ['mw'],
    "hulihulī": ['mw'],
    "huliṅga": ['mw'],
    "hulla": ['mw'],
    "hullura": ['bhs', 'mw'],
    "hulu": ['mw'],
    "huluhula": ['mw'],
    "huluhulu": ['bhs', 'mw'],
    "huluhulī": ['cae'],
    "huluka": ['bhs'],
    "huluḍa": ['bhs'],
    "huluṭa": ['bhs'],
    "hulāgrakā": ['mw'],
    "hum": ['ap90', 'cae', 'ddsa', 'mw'],
    "humbhā": ['mw'],
    "hummā": ['mw'],
    "humphaḍanta": ['mw'],
    "humāuṃ": ['mw'],
    "hun": ['mw'],
    "hura": ['gra'],
    "huras": ['cae', 'ddsa', 'mw'],
    "huraś": ['mw'],
    "huraścit": ['cae', 'ddsa', 'gra', 'mw'],
    "huraṁ": ['cped'],
    "hurcch": ['ap90'],
    "hurch": ['mw'],
    "huriñjaka": ['mw'],
    "huruk": ['cae', 'ddsa', 'gra', 'mw'],
    "huruṣkara": ['mw'],
    "huruṭṭaka": ['mw'],
    "hurāhuraṁ": ['cped'],
    "huss": ['mw'],
    "hut": ['cae', 'ddsa', 'mw'],
    "huta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "hutabhakṣa": ['mw'],
    "hutabhojana": ['cae', 'mw'],
    "hutabhoktṛ": ['cae', 'mw'],
    "hutabhugdiś": ['mw'],
    "hutabhuj": ['cae', 'mw'],
    "hutabhukpriyā": ['mw'],
    "hutabhāga": ['cae', 'mw'],
    "hutahavyavaha": ['mw'],
    "hutahoma": ['cae', 'mw'],
    "hutajātavedas": ['mw'],
    "hutasaṃvikta": ['mw'],
    "hutavaha": ['cae', 'mw'],
    "hutavahajvālāsama": ['mw'],
    "hutavahāy": ['cae'],
    "hutavahāya": ['mw'],
    "hutaśeṣa": ['cae', 'mw'],
    "hutaśiṣṭa": ['mw'],
    "hutaśiṣṭāśana": ['mw'],
    "huti": ['cae', 'ddsa', 'mw'],
    "hutiḥ": ['ap90'],
    "hutmat": ['mw'],
    "hutoccheṣaṇa": ['mw'],
    "hutocchiṣṭa": ['cae', 'mw'],
    "hutocchiṣṭabhakṣa": ['mw'],
    "hutta": ['cped'],
    "hutvā": ['cped'],
    "hutād": ['cae', 'mw'],
    "hutāgni": ['cae', 'mw'],
    "hutāhuta": ['mw'],
    "hutāhuti": ['mw'],
    "hutāsanī": ['bhs'],
    "hutāsna": ['cped'],
    "hutāśa": ['cae', 'mw'],
    "hutāśana": ['cae', 'mw'],
    "hutāśanamaya": ['mw'],
    "hutāśanasahāya": ['mw'],
    "hutāśanavant": ['cae'],
    "hutāśanavat": ['mw'],
    "hutāśanā": ['mw'],
    "hutāśanāya": ['mw'],
    "hutāśasuta": ['mw'],
    "hutāśaveśa": ['mw'],
    "hutāśavṛtti": ['mw'],
    "hutāśaśauca": ['mw'],
    "hutāśaśālā": ['mw'],
    "hutāśin": ['cae', 'mw'],
    "hutāṃśa": ['mw'],
    "huvadhyai": ['cae', 'mw'],
    "huvana": ['bhs'],
    "huvany": ['gra'],
    "huvanya": ['cae', 'mw'],
    "huveyya": ['cped'],
    "huviṣka": ['cae', 'ddsa', 'mw'],
    "huvā": ['mw'],
    "huñjikā": ['mw'],
    "huḍ": ['ap90', 'mw'],
    "huḍa": ['cae', 'mw'],
    "huḍaromāśrayaphalā": ['mw'],
    "huḍaḥ": ['ap90'],
    "huḍu": ['cae', 'ddsa', 'mw'],
    "huḍuk": ['mw'],
    "huḍukka": ['mw'],
    "huḍukkahikkā": ['mw'],
    "huḍukkaḥ": ['ap90'],
    "huḍukkā": ['mw'],
    "huḍukkāra": ['mw'],
    "huḍum": ['mw'],
    "huḍumba": ['mw'],
    "huḍut": ['ap90', 'mw'],
    "huḍutkāra": ['mw'],
    "huḍuḥ": ['ap90'],
    "huḍḍuka": ['mw'],
    "huṃ": ['mw'],
    "huṃhuṃkāra": ['bhs', 'mw'],
    "huṃkāra": ['cae', 'mw'],
    "huṃkāragarbha": ['mw'],
    "huṃkāratīrtha": ['mw'],
    "huṃkārā": ['mw'],
    "huṃkārī": ['mw'],
    "huṃkṛ": ['mw'],
    "huṃkṛta": ['mw'],
    "huṃḍ": ['ap90'],
    "huṃḍaḥ": ['ap90'],
    "huṅkāra": ['cped', 'ddsa'],
    "huṇa": ['mw'],
    "huṇḍ": ['mw'],
    "huṇḍa": ['cae', 'ddsa', 'mw'],
    "huṇḍana": ['mw'],
    "huṇḍaneśa": ['mw'],
    "huṇḍi": ['mw'],
    "huṇḍikā": ['ddsa', 'mw'],
    "huṇḍā": ['mw'],
    "huṇḍī": ['mw'],
    "huṣka": ['cae', 'ddsa', 'mw'],
    "huṣkapura": ['mw'],
    "huṣṭuta": ['mw'],
    "hval": ['ap90', 'cae', 'ddsa', 'mw'],
    "hvala": ['cae', 'ddsa', 'mw'],
    "hvalana": ['cae', 'mw'],
    "hvalā": ['mw'],
    "hvara": ['mw'],
    "hvaraka": ['mw'],
    "hvaras": ['cae', 'ddsa', 'gra', 'mw'],
    "hvarita": ['mw'],
    "hvayana": ['mw'],
    "hvayitavya": ['mw'],
    "hve": ['ap90', 'mw'],
    "hveya": ['mw'],
    "hvā": ['cae', 'ddsa', 'mw'],
    "hvāla": ['cae', 'mw'],
    "hvāna": ['cae', 'mw'],
    "hvānaṃ": ['ap90'],
    "hvānīya": ['mw'],
    "hvāra": ['cae', 'ddsa', 'gra', 'mw'],
    "hvāria": ['gra'],
    "hvārya": ['cae', 'gra', 'mw'],
    "hvātavya": ['cae', 'mw'],
    "hvātṛ": ['mw'],
    "hvāya": ['mw'],
    "hvāyaka": ['mw'],
    "hvāyakīya": ['mw'],
    "hvāyayitavya": ['mw'],
    "hvāyin": ['mw'],
    "hvṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hvṛta": ['mw'],
    "hvṝ": ['mw'],
    "hyas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hyastana": ['ap90', 'cae', 'mw'],
    "hyastanadina": ['mw'],
    "hyastanike": ['bhs'],
    "hyastanī": ['mw'],
    "hyastya": ['ap90', 'mw'],
    "hyaḥ": ['mw'],
    "hyaḥkṛta": ['mw'],
    "hyaḥkṛtavat": ['mw'],
    "hyo": ['mw'],
    "hyogodoha": ['mw'],
    "hā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "hādi": ['mw'],
    "hāha": ['bhs'],
    "hāhala": ['mw'],
    "hāhalaṃ": ['ap90'],
    "hāhas": ['ap90', 'mw'],
    "hāhava": ['mw'],
    "hāhā": ['ap90', 'ddsa', 'mw'],
    "hāhābhūta": ['cae'],
    "hāhādhara": ['bhs'],
    "hāhākāra": ['bhs', 'cae'],
    "hāhākṛta": ['cae', 'mw'],
    "hāhāla": ['mw'],
    "hāhālaṃ": ['ap90'],
    "hāhārava": ['mw'],
    "hāhāśabda": ['mw'],
    "hāikāra": ['mw'],
    "hājyakhāna": ['mw'],
    "hākaṣṭaśabda": ['mw'],
    "hākinī": ['mw'],
    "hākkāra": ['bhs'],
    "hākāra": ['cae', 'mw'],
    "hāla": ['cae', 'mw'],
    "hālabandha": ['mw'],
    "hālabhṛt": ['mw'],
    "hālahala": ['bhs', 'mw'],
    "hālahalaṃ": ['ap90'],
    "hālahalī": ['ap90'],
    "hālahāla": ['mw'],
    "hālaka": ['mw'],
    "hālakaḥ": ['ap90'],
    "hālasaptaśataka": ['mw'],
    "hālaḥ": ['ap90'],
    "hāleya": ['mw'],
    "hālika": ['cae', 'ddsa', 'mw'],
    "hālikaḥ": ['ap90'],
    "hālinī": ['ap90', 'mw'],
    "hāliṅgava": ['mw'],
    "hālu": ['mw'],
    "hāluḥ": ['ap90'],
    "hālā": ['cae', 'ddsa', 'mw'],
    "hālāha": ['mw'],
    "hālāhala": ['bhs', 'cae', 'ddsa', 'mw'],
    "hālāhaladhara": ['mw'],
    "hālāhalaḥ": ['ap90'],
    "hālāhalaṃ": ['ap90'],
    "hālāhalā": ['mw'],
    "hālāhalī": ['mw'],
    "hālāsya": ['mw'],
    "hālāsyakhaṇḍa": ['mw'],
    "hālāsyamāhātmya": ['mw'],
    "hālāsyāṣṭaka": ['mw'],
    "hālī": ['ap90', 'mw'],
    "hāmbīrī": ['mw'],
    "hāmigrāma": ['ddsa', 'mw'],
    "hāmpha": ['mw'],
    "hāna": ['cae', 'ddsa', 'mw'],
    "hānabhāgiya": ['cped'],
    "hānavya": ['mw'],
    "hānaṃ": ['ap90'],
    "hāndaṇa": ['mw'],
    "hāndra": ['mw'],
    "hāni": ['cae', 'cped', 'ddsa', 'mw'],
    "hānikara": ['cae', 'mw'],
    "hānikṛt": ['cae', 'mw'],
    "hāniḥ": ['ap90'],
    "hāntra": ['mw'],
    "hānu": ['mw'],
    "hānuka": ['mw'],
    "hānīya": ['mw'],
    "hāpaka": ['cped'],
    "hāpana": ['cped', 'ddsa', 'mw'],
    "hāpanaṃ": ['ap90'],
    "hāpenta": ['cped'],
    "hāpesi": ['cped'],
    "hāpeti": ['cped'],
    "hāpetvā": ['cped'],
    "hāphikā": ['ap90', 'mw'],
    "hāpita": ['cped', 'mw'],
    "hāputrikā": ['mw'],
    "hāputrī": ['mw'],
    "hār": ['cae'],
    "hāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "hārabhūrā": ['mw'],
    "hārabhūṣika": ['mw'],
    "hārabhūṣita": ['bhs'],
    "hāraguṭikā": ['mw'],
    "hārahaura": ['mw'],
    "hārahārā": ['mw'],
    "hārahūra": ['mw'],
    "hārahūraḥ": ['ap90'],
    "hārahūrikā": ['mw'],
    "hārahūrā": ['mw'],
    "hārahūṇa": ['mw'],
    "hāraka": ['bhs', 'cae', 'cped', 'mw'],
    "hārakaḥ": ['ap90'],
    "hāralatā": ['cae', 'mw'],
    "hāram": ['mw'],
    "hāramuktā": ['mw'],
    "hāraphala": ['mw'],
    "hāraphalaka": ['mw'],
    "hārapradānajātaka": ['bhs'],
    "hārava": ['mw'],
    "hāravarṣa": ['mw'],
    "hārayaṣṭi": ['cae', 'mw'],
    "hārayu": ['mw'],
    "hāraśītalāṅga": ['bhs'],
    "hāraḥ": ['ap90'],
    "hāraṇā": ['mw'],
    "hārd": ['ddsa', 'mw'],
    "hārda": ['cae', 'ddsa', 'mw'],
    "hārdavat": ['mw'],
    "hārdavidyā": ['mw'],
    "hārdaṃ": ['ap90'],
    "hārdi": ['cae', 'ddsa', 'gra', 'mw'],
    "hārdikya": ['cae', 'mw'],
    "hārdikā": ['mw'],
    "hārdin": ['ap90', 'cae', 'mw'],
    "hārdivan": ['cae', 'mw'],
    "hārdvan": ['cae', 'mw'],
    "hārga": ['mw'],
    "hāri": ['ap90', 'bhs', 'mw'],
    "hāridra": ['cae', 'ddsa', 'mw'],
    "hāridraka": ['mw'],
    "hāridrameha": ['mw'],
    "hāridramehin": ['mw'],
    "hāridratva": ['mw'],
    "hāridrava": ['cae', 'ddsa', 'gra', 'mw'],
    "hāridraveya": ['mw'],
    "hāridravin": ['mw'],
    "hāridravīya": ['mw'],
    "hāridraḥ": ['ap90'],
    "hāridrumata": ['mw'],
    "hārika": ['bhs', 'mw'],
    "hārikarṇa": ['mw'],
    "hārikarṇīputra": ['mw'],
    "hārikaṇṭha": ['ddsa', 'mw'],
    "hārikeyī": ['mw'],
    "hārikā": ['cped', 'mw'],
    "hārin": ['ap90', 'cae', 'ddsa', 'mw'],
    "hārisa": ['bhs', 'mw'],
    "hārita": ['ap90', 'ddsa', 'mw'],
    "hāritaka": ['bhs', 'mw'],
    "hāritakaḥ": ['ap90'],
    "hāritakāta": ['mw'],
    "hāritayajña": ['mw'],
    "hāritva": ['mw'],
    "hāritā": ['mw'],
    "hāritāsra": ['mw'],
    "hāritāyana": ['mw'],
    "hāritī": ['bhs', 'mw'],
    "hāritīputra": ['mw'],
    "hārivarṇa": ['mw'],
    "hārivāsa": ['mw'],
    "hāriya": ['cped'],
    "hāriyojana": ['gra', 'mw'],
    "hāriṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "hāriṇaka": ['mw'],
    "hāriṇikaḥ": ['ap90'],
    "hāriṇāśvā": ['mw'],
    "hāriṣeṇi": ['mw'],
    "hāriṣeṇya": ['mw'],
    "hārmya": ['mw'],
    "hārtra": ['mw'],
    "hārtrya": ['mw'],
    "hāruka": ['cae', 'mw'],
    "hārya": ['ap90', 'cae', 'ddsa', 'mw'],
    "hāryaputra": ['mw'],
    "hāryaśva": ['mw'],
    "hāryojana": ['mw'],
    "hāryā": ['mw'],
    "hārā": ['mw'],
    "hārāhāra": ['bhs'],
    "hārāpaya": ['mw'],
    "hārāpayati": ['mw'],
    "hārāvalī": ['cae', 'ddsa', 'mw'],
    "hārāya": ['mw'],
    "hārāyaṇa": ['mw'],
    "hārī": ['bhs', 'mw'],
    "hārīta": ['cae', 'ddsa', 'mw'],
    "hārītabandha": ['mw'],
    "hārītadharmaśāstra": ['mw'],
    "hārītaka": ['mw'],
    "hārītasaṃhitā": ['mw'],
    "hārītasmṛti": ['mw'],
    "hārītaśikṣā": ['mw'],
    "hārītaḥ": ['ap90'],
    "hārīti": ['mw'],
    "hārītāyanī": ['bhs'],
    "hārītī": ['bhs', 'mw'],
    "hārītīputra": ['mw'],
    "hārṣṇi": ['mw'],
    "hārṣṭeya": ['mw'],
    "hās": ['cae', 'ddsa', 'gra'],
    "hāsa": ['cae', 'cped', 'ddsa', 'mw'],
    "hāsabhūta": ['mw'],
    "hāsaka": ['cae', 'mw'],
    "hāsakara": ['cped', 'mw'],
    "hāsakaḥ": ['ap90'],
    "hāsakāla": ['cped'],
    "hāsana": ['cae', 'mw'],
    "hāsanika": ['mw'],
    "hāsas": ['ap90', 'mw'],
    "hāsavatī": ['bhs', 'mw'],
    "hāsayamāna": ['cped'],
    "hāsaśīla": ['mw'],
    "hāsaḥ": ['ap90'],
    "hāsenta": ['cped'],
    "hāsesi": ['cped'],
    "hāseti": ['cped'],
    "hāsetvā": ['cped'],
    "hāsikā": ['ap90', 'mw'],
    "hāsin": ['cae', 'mw'],
    "hāsinī": ['mw'],
    "hāsita": ['cped'],
    "hāsta": ['mw'],
    "hāstidanta": ['mw'],
    "hāstidāyi": ['mw'],
    "hāstika": ['cae', 'ddsa', 'mw'],
    "hāstikarṣūka": ['mw'],
    "hāstikaḥ": ['ap90'],
    "hāstina": ['cae', 'ddsa', 'mw'],
    "hāstinapura": ['cae', 'mw'],
    "hāstinapuratva": ['mw'],
    "hāstinaṃ": ['ap90'],
    "hāstināyana": ['mw'],
    "hāstipada": ['mw'],
    "hāstiśīrṣi": ['mw'],
    "hāstāyana": ['mw'],
    "hāsya": ['ap90', 'cae', 'ddsa', 'mw'],
    "hāsyadidṛkṣu": ['mw'],
    "hāsyahīna": ['mw'],
    "hāsyakara": ['cae', 'mw'],
    "hāsyakathā": ['mw'],
    "hāsyakāra": ['mw'],
    "hāsyakāraka": ['bhs'],
    "hāsyakārya": ['mw'],
    "hāsyakṛt": ['mw'],
    "hāsyapadavī": ['mw'],
    "hāsyapadavībhāva": ['mw'],
    "hāsyarasa": ['mw'],
    "hāsyarasavat": ['mw'],
    "hāsyaratnākara": ['mw'],
    "hāsyasthāyibhāva": ['mw'],
    "hāsyatara": ['mw'],
    "hāsyatva": ['mw'],
    "hāsyatā": ['cae', 'mw'],
    "hāsyārṇava": ['cae', 'mw'],
    "hāsyāspada": ['cae', 'mw'],
    "hāsyāspadatva": ['mw'],
    "hāsā": ['mw'],
    "hāsāspada": ['mw'],
    "hāta": ['mw'],
    "hātabba": ['cped'],
    "hātavat": ['mw'],
    "hātavya": ['cae', 'ddsa', 'mw'],
    "hātkṛta": ['mw'],
    "hātra": ['mw'],
    "hātraṃ": ['ap90'],
    "hātu": ['mw'],
    "hātuṁ": ['cped'],
    "hāuhuvaivāsāman": ['mw'],
    "hāukāra": ['mw'],
    "hāuyavādārasṛt": ['mw'],
    "hāva": ['cae', 'ddsa', 'mw'],
    "hāvaka": ['mw'],
    "hāvakaḥ": ['ap90'],
    "hāvanīya": ['mw'],
    "hāvaḥ": ['ap90'],
    "hāvin": ['mw'],
    "hāvirdhāna": ['mw'],
    "hāvirdhāni": ['mw'],
    "hāviryajñika": ['mw'],
    "hāviryajñiya": ['mw'],
    "hāviṣkṛta": ['mw'],
    "hāviṣmata": ['mw'],
    "hāvu": ['mw'],
    "hāyaka": ['mw'],
    "hāyamāna": ['cped'],
    "hāyana": ['cae', 'cped', 'ddsa', 'mw'],
    "hāyanagrantha": ['mw'],
    "hāyanaka": ['mw'],
    "hāyanaphala": ['mw'],
    "hāyanaratna": ['mw'],
    "hāyanasindhu": ['mw'],
    "hāyanasundara": ['mw'],
    "hāyanaḥ": ['ap90'],
    "hāyanottama": ['mw'],
    "hāyanta": ['cped'],
    "hāyanī": ['mw'],
    "hāyas": ['mw'],
    "hāyate": ['bhs'],
    "hāyati": ['cped', 'mw'],
    "hāyi": ['cped', 'mw'],
    "hāyikāra": ['mw'],
    "hāyin": ['mw'],
    "hāyitvā": ['cped'],
    "hāyī": ['cped'],
    "hāyīśabda": ['mw'],
    "hāḍi": ['ddsa', 'mw'],
    "hāḍigrāma": ['mw'],
    "hāḍikā": ['mw'],
    "hāḍī": ['mw'],
    "hāṃgaraḥ": ['ap90'],
    "hāṃsa": ['mw'],
    "hāṃsakāyana": ['mw'],
    "hāṃtraḥ": ['ap90'],
    "hāṅgara": ['mw'],
    "hāṭa": ['mw'],
    "hāṭaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "hāṭakamaya": ['cae', 'mw'],
    "hāṭakaprabhāsa": ['bhs'],
    "hāṭakeśa": ['cae', 'mw'],
    "hāṭakeśvara": ['cae', 'mw'],
    "hāṭakeśvaramāhātmya": ['mw'],
    "hāṭakeśāna": ['cae', 'mw'],
    "hāṭakī": ['mw'],
    "hāṭakīya": ['mw'],
    "hī": ['ap90', 'cae', 'ddsa', 'mw'],
    "hīhī": ['ap90', 'mw'],
    "hīhīkāra": ['mw'],
    "hīka": ['mw'],
    "hīla": ['mw'],
    "hīlaka": ['mw'],
    "hīlana": ['cped'],
    "hīlanā": ['cped', 'mw'],
    "hīlaṃ": ['ap90'],
    "hīluka": ['mw'],
    "hīlukaṃ": ['ap90'],
    "hīl̤": ['mw'],
    "hīl̤a": ['mw'],
    "hīl̤ita": ['mw'],
    "hīmavata": ['bhs'],
    "hīna": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "hīnabala": ['cae', 'mw'],
    "hīnabuddhi": ['mw'],
    "hīnabāhu": ['mw'],
    "hīnacakṣus": ['mw'],
    "hīnacarita": ['mw'],
    "hīnadagdha": ['mw'],
    "hīnadarśanasāmarthya": ['mw'],
    "hīnadīnānukampaka": ['mw'],
    "hīnaguṇa": ['mw'],
    "hīnaja": ['cae', 'mw'],
    "hīnajacca": ['cped'],
    "hīnajāti": ['cae', 'mw'],
    "hīnaka": ['mw'],
    "hīnakarman": ['cae', 'mw'],
    "hīnakośa": ['mw'],
    "hīnakrama": ['mw'],
    "hīnakratu": ['cae', 'mw'],
    "hīnakriya": ['cae', 'mw'],
    "hīnakula": ['mw'],
    "hīnakulatva": ['mw'],
    "hīnakuṣṭa": ['mw'],
    "hīnamūlya": ['mw'],
    "hīnanāyaka": ['mw'],
    "hīnapakṣa": ['cae', 'mw'],
    "hīnapratijña": ['mw'],
    "hīnaroman": ['mw'],
    "hīnarātra": ['mw'],
    "hīnarūpa": ['mw'],
    "hīnasakhya": ['mw'],
    "hīnasaṃdhi": ['mw'],
    "hīnasevā": ['cae', 'mw'],
    "hīnasvara": ['mw'],
    "hīnasvaratā": ['mw'],
    "hīnatara": ['mw'],
    "hīnatarpita": ['mw'],
    "hīnatas": ['mw'],
    "hīnatva": ['mw'],
    "hīnatā": ['mw'],
    "hīnavarga": ['mw'],
    "hīnavarṇa": ['mw'],
    "hīnaviriya": ['cped'],
    "hīnavyañjana": ['mw'],
    "hīnavāda": ['mw'],
    "hīnavādin": ['mw'],
    "hīnavīrya": ['cae', 'mw'],
    "hīnavīryatva": ['mw'],
    "hīnavṛtta": ['cae'],
    "hīnavṛtti": ['mw'],
    "hīnayoni": ['mw'],
    "hīnayāna": ['bhs', 'mw'],
    "hīnita": ['ddsa', 'mw'],
    "hīnodgata": ['mw'],
    "hīnopamā": ['mw'],
    "hīntāla": ['mw'],
    "hīnā": ['mw'],
    "hīnādhika": ['mw'],
    "hīnādhikatva": ['mw'],
    "hīnādhikatā": ['mw'],
    "hīnādhike": ['mw'],
    "hīnādhikāṅga": ['mw'],
    "hīnādhimuttika": ['cped'],
    "hīnārtha": ['mw'],
    "hīnātirikta": ['mw'],
    "hīnātiriktagātra": ['mw'],
    "hīnātiriktakāle": ['mw'],
    "hīnātiriktāṅga": ['mw'],
    "hīnāyāvarta": ['bhs'],
    "hīnāṃśu": ['cae', 'mw'],
    "hīnāṅga": ['cae', 'mw'],
    "hīra": ['cae', 'cped', 'ddsa', 'mw'],
    "hīrabhaṭṭa": ['mw'],
    "hīrajit": ['mw'],
    "hīraka": ['cae', 'cped', 'mw'],
    "hīrakaḥ": ['ap90'],
    "hīrakārya": ['mw'],
    "hīraḥ": ['ap90'],
    "hīroka": ['mw'],
    "hīrā": ['ap90', 'mw'],
    "hīrādevī": ['mw'],
    "hīrānanda": ['mw'],
    "hīrārāma": ['mw'],
    "hīrāṅga": ['mw'],
    "hīyamāna": ['cped', 'mw'],
    "hīyati": ['cped'],
    "hīyi": ['cped'],
    "hīyo": ['cped'],
    "hīḍ": ['cae', 'ddsa', 'gra', 'mw'],
    "hīḍa": ['cae', 'mw'],
    "hīḍas": ['gra'],
    "hīḍita": ['mw'],
    "hīḷayamāna": ['cped'],
    "hīḷesi": ['cped'],
    "hīḷeti": ['cped'],
    "hīḷetvā": ['cped'],
    "hīḷita": ['cped'],
    "hīṃtālaḥ": ['ap90'],
    "hīṣ": ['mw'],
    "hīṣati": ['bhs'],
    "hīṣaṇa": ['bhs'],
    "hīṣīsvara": ['mw'],
    "hū": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "hūhu": ['mw'],
    "hūhū": ['ap90', 'cae', 'ddsa', 'mw'],
    "hūluṇṭa": ['mw'],
    "hūm": ['ap90', 'cae', 'ddsa', 'mw'],
    "hūma": ['bhs'],
    "hūmpha": ['mw'],
    "hūna": ['cae', 'mw'],
    "hūnaḥ": ['ap90'],
    "hūrahūṇa": ['mw'],
    "hūralopa": ['mw'],
    "hūrava": ['mw'],
    "hūravaḥ": ['ap90'],
    "hūrcchanaṃ": ['ap90'],
    "hūrch": ['cae', 'ddsa', 'mw'],
    "hūrchana": ['mw'],
    "hūrchita": ['mw'],
    "hūrchitṛ": ['mw'],
    "hūrā": ['mw'],
    "hūrṇa": ['mw'],
    "hūrṇi": ['mw'],
    "hūta": ['ap90', 'ddsa', 'mw'],
    "hūtavat": ['mw'],
    "hūti": ['cae', 'gra', 'mw'],
    "hūtiḥ": ['ap90'],
    "hūya": ['mw'],
    "hūḍ": ['ap90', 'mw'],
    "hūṃhūṃkārapriya": ['mw'],
    "hūṃhūṃkārapāra": ['mw'],
    "hūṃkāra": ['cae', 'mw'],
    "hūṃkṛ": ['cae'],
    "hūṃkṛti": ['cae'],
    "hūṅkāra": ['ddsa'],
    "hūṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "hūṇaḥ": ['ap90'],
    "hūṣkapura": ['mw'],
    "hṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hṛc": ['mw'],
    "hṛcchaya": ['cae', 'ddsa', 'mw'],
    "hṛcchayapīḍita": ['cae', 'mw'],
    "hṛcchayavardhana": ['cae', 'mw'],
    "hṛcchayāviṣṭa": ['cae'],
    "hṛcchayāviṣṭacetana": ['mw'],
    "hṛcchoka": ['cae', 'mw'],
    "hṛcchoṣa": ['mw'],
    "hṛcchūla": ['mw'],
    "hṛd": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hṛda": ['mw'],
    "hṛdambhoja": ['cae', 'ddsa', 'mw'],
    "hṛdaya": ['cae', 'ddsa', 'gra', 'mw'],
    "hṛdayabandhana": ['mw'],
    "hṛdayabodhikā": ['mw'],
    "hṛdayacandra": ['mw'],
    "hṛdayacaura": ['mw'],
    "hṛdayacchid": ['cae', 'mw'],
    "hṛdayacora": ['mw'],
    "hṛdayadarpaṇa": ['mw'],
    "hṛdayadatta": ['mw'],
    "hṛdayadaurbalya": ['cae', 'mw'],
    "hṛdayadeśa": ['mw'],
    "hṛdayadhara": ['mw'],
    "hṛdayadrava": ['mw'],
    "hṛdayadāhin": ['mw'],
    "hṛdayadīpa": ['mw'],
    "hṛdayadīpaka": ['mw'],
    "hṛdayadūta": ['mw'],
    "hṛdayagata": ['cae', 'mw'],
    "hṛdayagraha": ['mw'],
    "hṛdayagranthi": ['mw'],
    "hṛdayagrāha": ['mw'],
    "hṛdayagrāhaka": ['mw'],
    "hṛdayagrāhin": ['cae', 'mw'],
    "hṛdayahārin": ['cae', 'mw'],
    "hṛdayaja": ['mw'],
    "hṛdayajvara": ['mw'],
    "hṛdayajña": ['cae', 'mw'],
    "hṛdayajñatva": ['mw'],
    "hṛdayakampa": ['mw'],
    "hṛdayakampana": ['cae', 'mw'],
    "hṛdayaklama": ['mw'],
    "hṛdayakṣobha": ['mw'],
    "hṛdayalehya": ['mw'],
    "hṛdayalekha": ['mw'],
    "hṛdayanarapati": ['mw'],
    "hṛdayanārāyaṇadeva": ['mw'],
    "hṛdayanātha": ['mw'],
    "hṛdayaprabodha": ['mw'],
    "hṛdayaprakāśa": ['mw'],
    "hṛdayapramāthin": ['cae', 'mw'],
    "hṛdayaprastara": ['cae', 'mw'],
    "hṛdayapriya": ['cae', 'mw'],
    "hṛdayapuruṣa": ['mw'],
    "hṛdayapuṇḍarīka": ['mw'],
    "hṛdayapīḍā": ['mw'],
    "hṛdayarajju": ['mw'],
    "hṛdayaroga": ['mw'],
    "hṛdayarāma": ['mw'],
    "hṛdayasammita": ['mw'],
    "hṛdayasaṃdhi": ['mw'],
    "hṛdayasaṃghaṭṭa": ['mw'],
    "hṛdayasaṃnihita": ['cae', 'mw'],
    "hṛdayasaṃsarga": ['mw'],
    "hṛdayaspṛś": ['mw'],
    "hṛdayastha": ['cae', 'mw'],
    "hṛdayasthalī": ['mw'],
    "hṛdayasthāna": ['mw'],
    "hṛdayasthāyin": ['mw'],
    "hṛdayasāhi": ['mw'],
    "hṛdayaupaśa": ['mw'],
    "hṛdayavallabha": ['cae', 'mw'],
    "hṛdayavat": ['mw'],
    "hṛdayavedhin": ['mw'],
    "hṛdayavirodha": ['mw'],
    "hṛdayavyathā": ['mw'],
    "hṛdayavyādhi": ['mw'],
    "hṛdayavṛtti": ['cae', 'mw'],
    "hṛdayaśaithilya": ['mw'],
    "hṛdayaśalya": ['cae', 'mw'],
    "hṛdayaśoka": ['mw'],
    "hṛdayaśoṣaṇa": ['mw'],
    "hṛdayaśriṣ": ['mw'],
    "hṛdayaśūla": ['cae', 'mw'],
    "hṛdayaśūlānta": ['mw'],
    "hṛdayaṃ": ['ap90'],
    "hṛdayaṃgama": ['ap90', 'cae', 'mw'],
    "hṛdayaṃgamatā": ['mw'],
    "hṛdayeśa": ['cae', 'mw'],
    "hṛdayeśaya": ['cae', 'mw'],
    "hṛdayeśvara": ['cae', 'mw'],
    "hṛdayeśā": ['mw'],
    "hṛdayika": ['mw'],
    "hṛdayin": ['mw'],
    "hṛdayitnu": ['mw'],
    "hṛdayodaṅka": ['mw'],
    "hṛdayodvartana": ['mw'],
    "hṛdayodveṣṭana": ['mw'],
    "hṛdayonmādakara": ['mw'],
    "hṛdayonmādinī": ['mw'],
    "hṛdayopakartin": ['mw'],
    "hṛdayopalepa": ['mw'],
    "hṛdayopasaraṇa": ['mw'],
    "hṛdayya": ['cae', 'ddsa', 'gra', 'mw'],
    "hṛdayā": ['mw'],
    "hṛdayābharaṇa": ['mw'],
    "hṛdayāgra": ['mw'],
    "hṛdayākāśa": ['mw'],
    "hṛdayālu": ['ap90', 'mw'],
    "hṛdayāmaya": ['cae', 'mw'],
    "hṛdayāmbuja": ['mw'],
    "hṛdayānanda": ['mw'],
    "hṛdayānuga": ['ddsa', 'mw'],
    "hṛdayārāma": ['mw'],
    "hṛdayārṇava": ['mw'],
    "hṛdayātman": ['mw'],
    "hṛdayāvagāḍha": ['mw'],
    "hṛdayāvarjaka": ['mw'],
    "hṛdayāvidh": ['cae', 'gra', 'mw'],
    "hṛdayāvin": ['mw'],
    "hṛdaṃsani": ['ddsa', 'gra', 'mw'],
    "hṛdbala": ['mw'],
    "hṛdbhedatantra": ['mw'],
    "hṛddeśa": ['mw'],
    "hṛddhita": ['mw'],
    "hṛddhātrī": ['mw'],
    "hṛddrava": ['mw'],
    "hṛddvāra": ['mw'],
    "hṛddyota": ['mw'],
    "hṛddyotabheṣaja": ['mw'],
    "hṛddyotana": ['mw'],
    "hṛddāha": ['mw'],
    "hṛdga": ['cae', 'ddsa', 'mw'],
    "hṛdgada": ['mw'],
    "hṛdgama": ['mw'],
    "hṛdgata": ['cae', 'mw'],
    "hṛdghaṭana": ['mw'],
    "hṛdgola": ['mw'],
    "hṛdgolīya": ['mw'],
    "hṛdgraha": ['mw'],
    "hṛdgrantha": ['mw'],
    "hṛdi": ['bhs', 'mw'],
    "hṛdia": ['gra'],
    "hṛdika": ['mw'],
    "hṛdikaḥ": ['ap90'],
    "hṛdimano": ['bhs'],
    "hṛdispṛś": ['ap90', 'cae', 'gra', 'mw'],
    "hṛdispṛśa": ['cae', 'mw'],
    "hṛdistha": ['cae', 'mw'],
    "hṛdiśaya": ['ddsa', 'mw'],
    "hṛdroga": ['cae', 'ddsa', 'gra', 'mw'],
    "hṛdrogapratikāra": ['mw'],
    "hṛdrogavairin": ['mw'],
    "hṛdrogin": ['mw'],
    "hṛdruj": ['mw'],
    "hṛdutkleda": ['mw'],
    "hṛdutkleśa": ['mw'],
    "hṛdvaktrāvartin": ['mw'],
    "hṛdvartin": ['mw'],
    "hṛdvaṇṭaka": ['mw'],
    "hṛdvidāha": ['mw'],
    "hṛdvraṇa": ['mw'],
    "hṛdvyathā": ['mw'],
    "hṛdya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hṛdyagandha": ['mw'],
    "hṛdyagandhaka": ['mw'],
    "hṛdyagandhi": ['mw'],
    "hṛdyagandhā": ['mw'],
    "hṛdyatama": ['mw'],
    "hṛdyatara": ['mw'],
    "hṛdyatva": ['mw'],
    "hṛdyatā": ['mw'],
    "hṛdyota": ['mw'],
    "hṛdyotana": ['mw'],
    "hṛdyā": ['mw'],
    "hṛdyāṃśu": ['mw'],
    "hṛdāmaya": ['mw'],
    "hṛdāvarta": ['mw'],
    "hṛdīka": ['mw'],
    "hṛdīkaḥ": ['ap90'],
    "hṛj": ['mw'],
    "hṛjja": ['mw'],
    "hṛl": ['mw'],
    "hṛllakālola": ['mw'],
    "hṛllekha": ['mw'],
    "hṛllāsa": ['ddsa', 'mw'],
    "hṛllāsaka": ['mw'],
    "hṛllāsikā": ['mw'],
    "hṛn": ['mw'],
    "hṛnmantra": ['mw'],
    "hṛnmoha": ['mw'],
    "hṛt": ['ap90', 'cae', 'ddsa', 'mw'],
    "hṛta": ['ap90', 'cae', 'mw'],
    "hṛtacandra": ['mw'],
    "hṛtadhana": ['mw'],
    "hṛtadravya": ['cae', 'ddsa', 'mw'],
    "hṛtadāra": ['cae', 'mw'],
    "hṛtajñāna": ['mw'],
    "hṛtamānasa": ['mw'],
    "hṛtaprasāda": ['mw'],
    "hṛtarājya": ['cae', 'mw'],
    "hṛtasarvasva": ['cae', 'mw'],
    "hṛtasāra": ['mw'],
    "hṛtavitta": ['mw'],
    "hṛtavāsas": ['mw'],
    "hṛtaśiṣṭa": ['mw'],
    "hṛti": ['cae', 'ddsa', 'mw'],
    "hṛtiḥ": ['ap90'],
    "hṛtkamala": ['mw'],
    "hṛtkampa": ['mw'],
    "hṛtoraga": ['mw'],
    "hṛtottara": ['mw'],
    "hṛtottarīya": ['mw'],
    "hṛtpadma": ['cae', 'mw'],
    "hṛtpati": ['mw'],
    "hṛtpaṅkaja": ['cae', 'mw'],
    "hṛtpiṇḍa": ['mw'],
    "hṛtpratiṣṭha": ['mw'],
    "hṛtpriya": ['mw'],
    "hṛtpuṇḍarīka": ['mw'],
    "hṛtpuṣkara": ['mw'],
    "hṛtpīḍana": ['mw'],
    "hṛtpīḍā": ['mw'],
    "hṛtsphoṭa": ['mw'],
    "hṛtsphoṭam": ['mw'],
    "hṛtstambha": ['mw'],
    "hṛtstha": ['cae', 'mw'],
    "hṛtsuas": ['gra'],
    "hṛtsv": ['mw'],
    "hṛtsvas": ['mw'],
    "hṛtsvāśaya": ['mw'],
    "hṛttas": ['cae', 'ddsa', 'gra', 'mw'],
    "hṛttoṣaṇī": ['mw'],
    "hṛttāpa": ['cae', 'mw'],
    "hṛtādhikāra": ['mw'],
    "hṛṇi": ['mw'],
    "hṛṇiyā": ['ap90', 'mw'],
    "hṛṇāy": ['cae', 'gra'],
    "hṛṇāya": ['mw'],
    "hṛṇāyat": ['ddsa'],
    "hṛṇāyu": ['gra', 'mw'],
    "hṛṇīy": ['cae'],
    "hṛṇīya": ['ddsa', 'mw'],
    "hṛṇīyate": ['ap90'],
    "hṛṇīyā": ['ap90', 'mw'],
    "hṛṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "hṛṣi": ['mw'],
    "hṛṣita": ['ap90', 'cae', 'mw'],
    "hṛṣitasragrajohīna": ['cae', 'mw'],
    "hṛṣitasrajrajohīna": ['ddsa'],
    "hṛṣu": ['mw'],
    "hṛṣyajihva": ['mw'],
    "hṛṣyakā": ['mw'],
    "hṛṣīka": ['cae', 'mw'],
    "hṛṣīkanātha": ['mw'],
    "hṛṣīkaṃ": ['ap90'],
    "hṛṣīkeśa": ['cae', 'ddsa', 'mw'],
    "hṛṣīkeśatva": ['mw'],
    "hṛṣīkeśvara": ['cae', 'mw'],
    "hṛṣīkeśāśrama": ['mw'],
    "hṛṣīvant": ['cae'],
    "hṛṣīvat": ['ddsa', 'gra', 'mw'],
    "hṛṣṭa": ['ap90', 'cae', 'mw'],
    "hṛṣṭacetana": ['mw'],
    "hṛṣṭacetas": ['mw'],
    "hṛṣṭacitta": ['ddsa', 'mw'],
    "hṛṣṭahṛdaya": ['mw'],
    "hṛṣṭamanas": ['mw'],
    "hṛṣṭamānasa": ['mw'],
    "hṛṣṭapuṣṭa": ['mw'],
    "hṛṣṭapuṣṭāṅga": ['mw'],
    "hṛṣṭaroman": ['cae', 'mw'],
    "hṛṣṭarūpa": ['mw'],
    "hṛṣṭasaṃkalpa": ['mw'],
    "hṛṣṭatanu": ['mw'],
    "hṛṣṭatanūruha": ['mw'],
    "hṛṣṭatuṣṭa": ['mw'],
    "hṛṣṭavadana": ['mw'],
    "hṛṣṭavat": ['mw'],
    "hṛṣṭi": ['cae', 'ddsa', 'mw'],
    "hṛṣṭiyoni": ['mw'],
    "hṛṣṭiḥ": ['ap90'],
    "hṝ": ['mw'],
    "i": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ibbha": ['cped'],
    "ibha": ['cae', 'ddsa', 'gra', 'mw'],
    "ibhadantā": ['cae', 'ddsa', 'mw'],
    "ibhagandhā": ['mw'],
    "ibhakaṇā": ['mw'],
    "ibhakesara": ['mw'],
    "ibhamācala": ['mw'],
    "ibhamācalaḥ": ['ap90'],
    "ibhanimīlikā": ['mw'],
    "ibhapa": ['mw'],
    "ibhapoṭā": ['mw'],
    "ibhapālaka": ['mw'],
    "ibhayuvati": ['mw'],
    "ibhayā": ['ap90'],
    "ibhaḥ": ['ap90'],
    "ibhoṣaṇā": ['mw'],
    "ibhya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ibhyaka": ['ap90'],
    "ibhyatilvila": ['mw'],
    "ibhyā": ['mw'],
    "ibhākhya": ['mw'],
    "ibhāri": ['mw'],
    "ibhī": ['mw'],
    "iccha": ['cped'],
    "icchaka": ['ap90', 'mw'],
    "icchakaḥ": ['ap90'],
    "icchamāna": ['cped'],
    "icchantika": ['bhs'],
    "icchat": ['ap90', 'cped'],
    "icchati": ['cped'],
    "icchatva": ['bhs', 'mw'],
    "icchatā": ['mw'],
    "icchavacara": ['cped'],
    "icchavatiṇṇa": ['cped'],
    "icchayā": ['mw'],
    "icchi": ['cped'],
    "icchisaṁ": ['cped'],
    "icchita": ['cped'],
    "icchitabbaka": ['cped'],
    "icchitavya": ['bhs'],
    "icchiṁsu": ['cped'],
    "icchu": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "icchuka": ['ap90'],
    "icchā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "icchābharaṇa": ['mw'],
    "icchādhūmāyita": ['cped'],
    "icchādhūpāyita": ['cped'],
    "icchādāna": ['mw'],
    "icchāgata": ['cped'],
    "icchākṛta": ['mw'],
    "icchāmaraṇa": ['mw'],
    "icchānivṛtti": ['mw'],
    "icchānvita": ['mw'],
    "icchāpakata": ['cped'],
    "icchāphala": ['mw'],
    "icchāpita": ['mw'],
    "icchārāma": ['mw'],
    "icchārūpa": ['mw'],
    "icchāsadṛśa": ['mw'],
    "icchāsampad": ['mw'],
    "icchāvasu": ['mw'],
    "icchāvat": ['mw'],
    "icchāśaktimant": ['cae'],
    "icchāśaktimat": ['mw'],
    "icikila": ['mw'],
    "icikilaḥ": ['ap90'],
    "id": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "idadvasu": ['mw'],
    "idahā": ['mw'],
    "idam": ['cae', 'ddsa', 'gra', 'mw'],
    "idam-atthika": ['cped'],
    "idam-atthitā": ['cped'],
    "idam-aṭṭhitā": ['cped'],
    "idamdvitīya": ['mw'],
    "idammadhu": ['mw'],
    "idammadhura": ['mw'],
    "idammaya": ['mw'],
    "idamprakāram": ['mw'],
    "idamprathama": ['mw'],
    "idamādi": ['ddsa'],
    "idamīya": ['mw'],
    "idantana": ['ddsa', 'mw'],
    "idantā": ['mw'],
    "idantṛtīya": ['mw'],
    "idappaccayatā": ['cped'],
    "idappaccayā": ['cped'],
    "idaṁ": ['cped'],
    "idaṃ": ['ap90'],
    "idaṃmaya": ['ap90'],
    "idaṃpratyaya": ['bhs'],
    "idaṃpratyayatā": ['bhs'],
    "idaṃrūpa": ['cae', 'ddsa', 'mw'],
    "idaṃtana": ['ap90'],
    "idaṃtā": ['ap90'],
    "idaṃvid": ['mw'],
    "idaṃyu": ['ap90', 'mw'],
    "idaṃyuga": ['mw'],
    "idaṃyugīna": ['mw'],
    "idaṃśabda": ['mw'],
    "idaṅkāryā": ['mw'],
    "iddha": ['ap90', 'cped', 'mw'],
    "iddhaagni": ['gra'],
    "iddhabhisaṅkhāra": ['cped'],
    "iddhadīdhiti": ['ddsa', 'mw'],
    "iddhamanyu": ['mw'],
    "iddhatejas": ['mw'],
    "iddhi": ['bhs', 'cped'],
    "iddhima": ['cped'],
    "iddhimat": ['cped'],
    "iddhipahutā": ['cped'],
    "iddhipāda": ['cped'],
    "iddhipāṭihāriya": ['cped'],
    "iddhividhā": ['cped'],
    "iddhivikubbana": ['cped'],
    "iddhivisavitā": ['cped'],
    "iddhāgni": ['gra', 'mw'],
    "idh": ['cae', 'gra', 'mw'],
    "idha": ['bhs', 'cped'],
    "idhaloka": ['cped'],
    "idhma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "idhmabhṛti": ['gra', 'mw'],
    "idhmaciti": ['mw'],
    "idhmajihva": ['mw'],
    "idhman": ['mw'],
    "idhmaparivāsana": ['mw'],
    "idhmapravraścana": ['mw'],
    "idhmaprokṣaṇa": ['mw'],
    "idhmasaṃnahana": ['mw'],
    "idhmavat": ['mw'],
    "idhmavraścana": ['mw'],
    "idhmavāha": ['mw'],
    "idhmaḥ": ['ap90'],
    "idhmābarhis": ['mw'],
    "idhyā": ['ap90'],
    "idm, indh": ['ddsa'],
    "idā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "idādika": ['mw'],
    "idāni": ['bhs', 'cped', 'mw'],
    "idānīm": ['cae', 'gra', 'mw'],
    "idānīntana": ['ddsa'],
    "idānīṃ": ['ap90'],
    "idānīṃtana": ['ap90', 'mw'],
    "idānīṃtanatva": ['mw'],
    "idāvatsara": ['mw'],
    "idāvatsarīya": ['mw'],
    "iha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ihabhojana": ['mw'],
    "ihacitta": ['mw'],
    "ihadvitīyā": ['mw'],
    "ihakratu": ['mw'],
    "ihakāla": ['mw'],
    "ihakāra": ['mw'],
    "ihalaḥ": ['ap90'],
    "ihaloka": ['cae', 'ddsa', 'mw'],
    "ihaloke": ['mw'],
    "ihamanas": ['mw'],
    "ihapañcamī": ['mw'],
    "ihasamaye": ['mw'],
    "ihastha": ['cae', 'ddsa', 'mw'],
    "ihasthāna": ['mw'],
    "ihasthāne": ['mw'],
    "ihatra": ['bhs', 'mw'],
    "ihatya": ['ap90', 'ddsa', 'mw'],
    "ihatyaka": ['mw'],
    "ihavat": ['mw'],
    "iheha": ['mw'],
    "ihehamātṛ": ['gra', 'mw'],
    "iheḍa": ['mw'],
    "ihāgata": ['mw'],
    "ihāmutra": ['mw'],
    "ihāmutraphalabhogavirāga": ['ddsa'],
    "ihārtha": ['cae', 'mw'],
    "ihārtham": ['mw'],
    "ihārthin": ['cae', 'mw'],
    "ij": ['gra'],
    "ijita": ['bhs'],
    "ijjala": ['mw'],
    "ijjalaḥ": ['ap90'],
    "ijjhati": ['cped'],
    "ijjhiṁsu": ['cped'],
    "ijjādevī": ['mw'],
    "ijya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ijyaśīla": ['mw'],
    "ijyā": ['ddsa', 'mw'],
    "ikaṭaḥ": ['ap90'],
    "ikh": ['ap90', 'mw'],
    "ikkavāla": ['mw'],
    "ikkavālaḥ": ['ap90'],
    "ikkaṭa": ['mw'],
    "ikkaṭaḥ": ['ap90'],
    "ikkhaṇikā": ['cped'],
    "ikkāsa": ['cped'],
    "ikāra": ['cae', 'ddsa', 'mw'],
    "ikṣu": ['cae', 'ddsa', 'mw'],
    "ikṣubhakṣikā": ['mw'],
    "ikṣubhakṣita": ['mw'],
    "ikṣubhañjam": ['mw'],
    "ikṣubhañjikā": ['mw'],
    "ikṣubālikā": ['mw'],
    "ikṣudarbhā": ['mw'],
    "ikṣudaṇḍa": ['mw'],
    "ikṣudvādaśī": ['bhs'],
    "ikṣudā": ['mw'],
    "ikṣugandha": ['mw'],
    "ikṣugandhikā": ['mw'],
    "ikṣugandhā": ['mw'],
    "ikṣuja": ['mw'],
    "ikṣuka": ['mw'],
    "ikṣukaḥ": ['ap90'],
    "ikṣukuṭṭaka": ['mw'],
    "ikṣukuṭṭitikam": ['bhs'],
    "ikṣukāṇḍa": ['mw'],
    "ikṣukīya": ['mw'],
    "ikṣukīyā": ['ap90'],
    "ikṣukṣetra": ['mw'],
    "ikṣulā": ['mw'],
    "ikṣumatī": ['mw'],
    "ikṣumeha": ['mw'],
    "ikṣumehin": ['mw'],
    "ikṣumālavī": ['mw'],
    "ikṣumālinī": ['mw'],
    "ikṣumūla": ['mw'],
    "ikṣunetra": ['mw'],
    "ikṣuparṇī": ['mw'],
    "ikṣupattra": ['mw'],
    "ikṣupattrī": ['mw'],
    "ikṣupra": ['mw'],
    "ikṣupāka": ['mw'],
    "ikṣura": ['mw'],
    "ikṣuraka": ['mw'],
    "ikṣurasa": ['mw'],
    "ikṣurasakvātha": ['mw'],
    "ikṣurasakvāthoda": ['mw'],
    "ikṣuraḥ": ['ap90'],
    "ikṣusamudra": ['mw'],
    "ikṣusāra": ['mw'],
    "ikṣutulyā": ['mw'],
    "ikṣuvallarī": ['mw'],
    "ikṣuvallī": ['mw'],
    "ikṣuvaṇa": ['mw'],
    "ikṣuveṣṭana": ['mw'],
    "ikṣuvikāra": ['mw'],
    "ikṣuvāri": ['mw'],
    "ikṣuvāṭikā": ['mw'],
    "ikṣuvāṭī": ['mw'],
    "ikṣuyantra": ['mw'],
    "ikṣuyaṣṭi": ['mw'],
    "ikṣuyoni": ['mw'],
    "ikṣuśalākā": ['mw'],
    "ikṣuśākaṭa": ['mw'],
    "ikṣuśākina": ['mw'],
    "ikṣuḥ": ['ap90'],
    "ikṣvāku": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ikṣvākucandramas": ['mw'],
    "ikṣvākukulaja": ['mw'],
    "ikṣvākuḥ": ['ap90'],
    "ikṣvālika": ['mw'],
    "ikṣvālikā": ['mw'],
    "ikṣvāri": ['mw'],
    "il": ['ap90', 'cae', 'ddsa', 'mw'],
    "ila": ['ap90', 'mw'],
    "ilaspatiḥ": ['ap90'],
    "ilava": ['ap90', 'cae', 'mw'],
    "ilavila": ['mw'],
    "ilavilā": ['ap90', 'mw'],
    "ilaya": ['ap90'],
    "ilikā": ['ap90', 'mw'],
    "ilinā": ['mw'],
    "ilinī": ['mw'],
    "ilivila": ['mw'],
    "illaka": ['ddsa', 'mw'],
    "illala": ['mw'],
    "illisa": ['mw'],
    "illiśa": ['mw'],
    "iluvarda": ['mw'],
    "ilvakā": ['mw'],
    "ilvakāḥ": ['ap90'],
    "ilvala": ['mw'],
    "ilvalā": ['mw'],
    "ilvalāri": ['mw'],
    "ilya": ['mw'],
    "ilā": ['cae', 'mw'],
    "ilādadha": ['mw'],
    "ilādaḍha": ['mw'],
    "ilādevī": ['bhs'],
    "ilādurga": ['mw'],
    "ilāgola": ['mw'],
    "ilāspada": ['mw'],
    "ilāsutā": ['mw'],
    "ilātala": ['mw'],
    "ilāvṛta": ['mw'],
    "ilāṃda": ['mw'],
    "ilī": ['ap90', 'mw'],
    "ilībiśa": ['gra', 'mw'],
    "ilībiśaḥ": ['ap90'],
    "ilīśa": ['mw'],
    "ilīśaḥ": ['ap90'],
    "ilūṣa": ['mw'],
    "il̤as": ['mw'],
    "il̤aspati": ['mw'],
    "il̤ā": ['cae', 'mw'],
    "il̤ādaḍha": ['mw'],
    "im": ['cae', 'mw'],
    "ima": ['cae', 'ddsa', 'gra', 'mw'],
    "imaka": ['mw'],
    "imathā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "imaṃhi": ['bhs'],
    "iminā upāyena": ['cped'],
    "in": ['ap90', 'ddsa', 'gra', 'mw'],
    "ina": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "inakṣ": ['cae', 'ddsa', 'gra', 'mw'],
    "inakṣati": ['ap90'],
    "inasabha": ['mw'],
    "ind": ['mw'],
    "inda": ['cped'],
    "indagopaka": ['cped'],
    "indagopakasañchanna": ['cped'],
    "indakhīla": ['cped'],
    "indambara": ['mw'],
    "indaramādana": ['gra'],
    "indaravāta": ['gra'],
    "indasagotta": ['cped'],
    "indh": ['ddsa', 'gra', 'mw'],
    "indha": ['cae', 'ddsa', 'gra', 'mw'],
    "indhana": ['cae', 'ddsa', 'gra', 'mw'],
    "indhanavat": ['mw'],
    "indhanvan": ['cae', 'gra', 'mw'],
    "indhanīkṛ": ['ddsa', 'mw'],
    "indhi": ['ddsa'],
    "indhita": ['mw'],
    "indhūka": ['mw'],
    "indindirā": ['mw'],
    "indirā": ['ddsa', 'mw'],
    "indirādayita": ['mw'],
    "indirālaya": ['mw'],
    "indirāmandira": ['mw'],
    "indiyārtha": ['ddsa'],
    "indra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "indrabala": ['mw'],
    "indrabhaginī": ['mw'],
    "indrabhaṭṭāraka": ['mw'],
    "indrabheṣaja": ['mw'],
    "indrabhājana": ['mw'],
    "indrabhū": ['mw'],
    "indrabhūti": ['bhs', 'mw'],
    "indrabrāhmaṇa": ['mw'],
    "indrabāhu": ['mw'],
    "indrabīja": ['mw'],
    "indracandana": ['mw'],
    "indracchanda": ['mw'],
    "indracirbhiṭī": ['mw'],
    "indracāpa": ['cae', 'mw'],
    "indracūrṇa": ['bhs'],
    "indradamana": ['bhs', 'mw'],
    "indradatta": ['bhs', 'mw'],
    "indradeva": ['bhs'],
    "indradevī": ['mw'],
    "indradevībhavana": ['mw'],
    "indradhanus": ['cae', 'mw'],
    "indradhruva": ['mw'],
    "indradhvaja": ['bhs', 'mw'],
    "indradhvajaketu": ['bhs'],
    "indradru": ['mw'],
    "indradruma": ['mw'],
    "indradviṣṭa": ['gra', 'mw'],
    "indradvīpa": ['mw'],
    "indradyumna": ['mw'],
    "indradāru": ['mw'],
    "indraghoṣa": ['mw'],
    "indragiri": ['mw'],
    "indragopa": ['bhs', 'cae', 'mw'],
    "indragopā": ['gra'],
    "indragupta": ['mw'],
    "indraguru": ['mw'],
    "indragāthā": ['mw'],
    "indragṛha": ['mw'],
    "indrahasta": ['bhs', 'mw'],
    "indrahava": ['gra', 'mw'],
    "indrahū": ['mw'],
    "indrahūti": ['gra', 'mw'],
    "indraja": ['mw'],
    "indrajanana": ['mw'],
    "indrajananīya": ['mw'],
    "indrajatu": ['mw'],
    "indrajidvijayin": ['mw'],
    "indrajit": ['cae', 'mw'],
    "indrajyeṣṭha": ['cae', 'gra', 'mw'],
    "indrajā": ['mw'],
    "indrajāla": ['cae', 'mw'],
    "indrajālajña": ['mw'],
    "indrajālaparicaya": ['mw'],
    "indrajālapuruṣa": ['mw'],
    "indrajālavidyā": ['mw'],
    "indrajālika": ['cae', 'mw'],
    "indrajālin": ['bhs', 'cae', 'mw'],
    "indrajānu": ['mw'],
    "indrajūta": ['cae', 'gra', 'mw'],
    "indraka": ['bhs', 'mw'],
    "indrakalpa": ['mw'],
    "indrakarman": ['mw'],
    "indrakavi": ['mw'],
    "indraketu": ['bhs', 'mw'],
    "indraketudhvajarāja": ['bhs'],
    "indrakośa": ['mw'],
    "indrakoṣa": ['mw'],
    "indrakoṣaka": ['mw'],
    "indrakrośa": ['mw'],
    "indrakukṣi": ['mw'],
    "indrakuñjara": ['mw'],
    "indrakuśa": ['bhs'],
    "indrakārmuka": ['mw'],
    "indrakīla": ['bhs', 'mw'],
    "indrakīlaka": ['bhs'],
    "indrakūṭa": ['mw'],
    "indrakṛṣṭa": ['mw'],
    "indraloka": ['cae', 'ddsa', 'mw'],
    "indralokeśa": ['mw'],
    "indralokāgamana": ['mw'],
    "indralupta": ['mw'],
    "indraluptaka": ['mw'],
    "indramada": ['cae', 'mw'],
    "indramaghaśrī": ['bhs', 'mw'],
    "indramaha": ['cae', 'mw'],
    "indramahakarman": ['mw'],
    "indramahakāmuka": ['mw'],
    "indramahotsava": ['mw'],
    "indramakha": ['mw'],
    "indramantrin": ['mw'],
    "indramati": ['bhs'],
    "indramedin": ['mw'],
    "indramādana": ['gra', 'mw'],
    "indramārga": ['mw'],
    "indramārgā": ['mw'],
    "indranaasatya": ['gra'],
    "indranakṣatra": ['mw'],
    "indranāsatya": ['gra'],
    "indranīla": ['cae', 'mw'],
    "indranīlaka": ['mw'],
    "indrapada": ['mw'],
    "indraparvata": ['mw'],
    "indraparṇī": ['mw'],
    "indrapatnī": ['gra', 'mw'],
    "indrapaṭa": ['bhs'],
    "indraphala": ['mw'],
    "indrapraharaṇa": ['mw'],
    "indrapramada": ['mw'],
    "indrapramati": ['mw'],
    "indraprastha": ['cae', 'mw'],
    "indraprasūta": ['gra', 'mw'],
    "indraprayāṇa": ['mw'],
    "indrapura": ['bhs'],
    "indrapurogama": ['mw'],
    "indrapurohitā": ['mw'],
    "indraputra": ['cae'],
    "indraputrā": ['mw'],
    "indrapuṣpa": ['mw'],
    "indrapuṣpikā": ['mw'],
    "indrapuṣpā": ['mw'],
    "indrapuṣpī": ['mw'],
    "indrapāla": ['mw'],
    "indrapālita": ['mw'],
    "indrapāna": ['gra', 'mw'],
    "indrapātama": ['gra', 'mw'],
    "indrapīta": ['gra', 'mw'],
    "indrarāja": ['mw'],
    "indrarājan": ['mw'],
    "indrasabhā": ['mw'],
    "indrasakha": ['cae', 'mw'],
    "indrasakhi": ['cae', 'gra', 'mw'],
    "indrasarasvatī": ['mw'],
    "indrasava": ['mw'],
    "indrasaṃdhā": ['mw'],
    "indrasaṃjaya": ['mw'],
    "indrasena": ['bhs', 'cae', 'mw'],
    "indrasenadvitīya": ['mw'],
    "indrasenā": ['cae', 'gra', 'mw'],
    "indrasiṃha": ['mw'],
    "indrasthāna": ['mw'],
    "indrastoma": ['mw'],
    "indrastut": ['mw'],
    "indrasuparṇa": ['mw'],
    "indrasurasa": ['mw'],
    "indrasurisa": ['mw'],
    "indrasurā": ['mw'],
    "indrasuta": ['mw'],
    "indrasvat": ['gra', 'mw'],
    "indrasyābhikranda": ['mw'],
    "indrasāhva": ['mw'],
    "indrasārathi": ['gra', 'mw'],
    "indrasāvarṇi": ['mw'],
    "indrasūnu": ['mw'],
    "indratama": ['cae', 'mw'],
    "indratanū": ['mw'],
    "indratapanā": ['bhs'],
    "indrataru": ['mw'],
    "indrateja": ['bhs'],
    "indratejas": ['mw'],
    "indratoyā": ['mw'],
    "indraturīya": ['mw'],
    "indratva": ['cae', 'mw'],
    "indratvota": ['gra', 'mw'],
    "indratā": ['ddsa', 'mw'],
    "indratāpana": ['mw'],
    "indratūla": ['mw'],
    "indratūlaka": ['mw'],
    "indravah": ['cae', 'gra', 'mw'],
    "indravaidūrya": ['mw'],
    "indravairin": ['mw'],
    "indravajra": ['cae', 'mw'],
    "indravajrā": ['mw'],
    "indravallarī": ['mw'],
    "indravallī": ['mw'],
    "indravana": ['mw'],
    "indravant": ['cae'],
    "indravarman": ['mw'],
    "indravasti": ['mw'],
    "indravat": ['ddsa', 'gra', 'mw'],
    "indravaṃśā": ['cae', 'mw'],
    "indravrata": ['mw'],
    "indravāh": ['gra', 'mw'],
    "indravāha": ['mw'],
    "indravāhana": ['mw'],
    "indravāruṇikā": ['mw'],
    "indravāruṇī": ['mw'],
    "indravāta": ['gra'],
    "indravātatama": ['mw'],
    "indravāyu": ['gra', 'mw'],
    "indravīja": ['mw'],
    "indravīrudh": ['mw'],
    "indravṛddhika": ['mw'],
    "indravṛddhā": ['mw'],
    "indravṛkṣa": ['mw'],
    "indravṛkṣīya": ['mw'],
    "indray": ['cae', 'gra'],
    "indraya": ['ddsa', 'mw'],
    "indrayajña": ['mw'],
    "indrayava": ['mw'],
    "indrayaṣṭi": ['bhs', 'mw'],
    "indrayoga": ['mw'],
    "indrayu": ['ddsa', 'gra', 'mw'],
    "indrayāga": ['mw'],
    "indraśaila": ['bhs', 'mw'],
    "indraśailaguhā": ['bhs'],
    "indraśakti": ['mw'],
    "indraśalabha": ['mw'],
    "indraśarman": ['mw'],
    "indraśatru": ['cae', 'ddsa', 'gra', 'mw'],
    "indraśreṣṭha": ['mw'],
    "indraśrī": ['bhs'],
    "indraūta": ['gra'],
    "indraṇata": ['mw'],
    "indraṛṣabhā": ['mw'],
    "indrejya": ['mw'],
    "indreśvara": ['mw'],
    "indreśvaraliṅga": ['mw'],
    "indreṇata": ['mw'],
    "indreṣita": ['cae', 'ddsa', 'gra', 'mw'],
    "indriya": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "indriyabhāvanā": ['mw'],
    "indriyabodhana": ['mw'],
    "indriyabodhin": ['mw'],
    "indriyabuddhi": ['mw'],
    "indriyaghāta": ['mw'],
    "indriyagocara": ['mw'],
    "indriyagrāma": ['mw'],
    "indriyaiṣyā": ['mw'],
    "indriyajñāna": ['mw'],
    "indriyakāma": ['mw'],
    "indriyakṛta": ['mw'],
    "indriyamocana": ['mw'],
    "indriyanigraha": ['cae', 'mw'],
    "indriyaparimocana": ['mw'],
    "indriyaprasaṅga": ['mw'],
    "indriyasaṃyama": ['mw'],
    "indriyasevana": ['mw'],
    "indriyasparśa": ['mw'],
    "indriyasvāpa": ['mw'],
    "indriyatta": ['cped'],
    "indriyatva": ['mw'],
    "indriyavant": ['cae'],
    "indriyavarga": ['mw'],
    "indriyavat": ['mw'],
    "indriyavikalatā": ['mw'],
    "indriyavipratipatti": ['mw'],
    "indriyaviṣaya": ['mw'],
    "indriyavāda": ['mw'],
    "indriyavṛtti": ['mw'],
    "indriyaśakti": ['cae', 'mw'],
    "indriyeśvara": ['bhs'],
    "indriyāgocara": ['mw'],
    "indriyārtha": ['cae', 'mw'],
    "indriyāsaṅga": ['cae', 'mw'],
    "indriyātman": ['mw'],
    "indriyāvant": ['cae'],
    "indriyāvat": ['mw'],
    "indriyāvin": ['cae', 'mw'],
    "indriyāyatana": ['mw'],
    "indriyāśva": ['mw'],
    "indrota": ['gra', 'mw'],
    "indrotsava": ['ddsa', 'mw'],
    "indrā": ['mw'],
    "indrāagni": ['gra'],
    "indrābha": ['mw'],
    "indrābrahmaṇaspati": ['cae', 'gra', 'mw'],
    "indrābṛhaspati": ['cae', 'gra', 'mw'],
    "indrāditya": ['mw'],
    "indrāgni": ['cae', 'ddsa', 'gra', 'mw'],
    "indrāgnidaiva": ['mw'],
    "indrāgnidaivata": ['mw'],
    "indrāgnidevatā": ['mw'],
    "indrāgnidhūma": ['mw'],
    "indrāhva": ['mw'],
    "indrākutsa": ['gra', 'mw'],
    "indrāmarut": ['cae', 'gra', 'mw'],
    "indrānuja": ['mw'],
    "indrāparvata": ['gra', 'mw'],
    "indrāpūṣan": ['ddsa', 'gra', 'mw'],
    "indrāri": ['mw'],
    "indrāsana": ['mw'],
    "indrāsoma": ['cae', 'gra', 'mw'],
    "indrāsomīya": ['mw'],
    "indrāvaraja": ['mw'],
    "indrāvaruṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "indrāvasikta": ['mw'],
    "indrāvat": ['ddsa', 'gra', 'mw'],
    "indrāviṣṇu": ['cae', 'gra', 'mw'],
    "indrāyatana": ['mw'],
    "indrāyudha": ['cae', 'ddsa', 'mw'],
    "indrāyudhamaya": ['mw'],
    "indrāyudhaśikhin": ['bhs', 'mw'],
    "indrāyudhā": ['mw'],
    "indrāśana": ['mw'],
    "indrāṅka": ['mw'],
    "indrāṇikā": ['mw'],
    "indrāṇya": ['mw'],
    "indrāṇyupaniṣad": ['mw'],
    "indrāṇī": ['cae', 'ddsa', 'gra', 'mw'],
    "indrāṇīgaurīpūjā": ['mw'],
    "indrāṇīkarman": ['mw'],
    "indrāṇīsāman": ['mw'],
    "indrāṇītantra": ['mw'],
    "indrāṇīśāka": ['mw'],
    "indrī": ['mw'],
    "indu": ['cae', 'ddsa', 'gra', 'mw'],
    "indubha": ['mw'],
    "indubhavā": ['mw'],
    "indubhā": ['mw'],
    "indubhṛt": ['mw'],
    "indubimba": ['cae', 'mw'],
    "indudala": ['mw'],
    "indudina": ['mw'],
    "indugaura": ['mw'],
    "induja": ['mw'],
    "indujanaka": ['mw'],
    "indujā": ['mw'],
    "induka": ['mw'],
    "indukakṣā": ['mw'],
    "indukalaśa": ['mw'],
    "indukalikā": ['mw'],
    "indukalā": ['mw'],
    "indukalāvataṃsa": ['mw'],
    "indukamala": ['mw'],
    "indukara": ['mw'],
    "indukesarin": ['mw'],
    "indukirīṭa": ['mw'],
    "indukā": ['mw'],
    "indukānta": ['mw'],
    "indukāntā": ['mw'],
    "indukṣaya": ['mw'],
    "indulekhā": ['mw'],
    "indulohaka": ['mw'],
    "induloka": ['mw'],
    "indumat": ['mw'],
    "indumatī": ['mw'],
    "indumauli": ['mw'],
    "indumaṇi": ['mw'],
    "indumaṇḍala": ['mw'],
    "indumitra": ['mw'],
    "indumukha": ['cae', 'mw'],
    "indunandana": ['mw'],
    "indupada": ['mw'],
    "induphala": ['mw'],
    "induprabha": ['mw'],
    "induputra": ['mw'],
    "indupuṣpikā": ['mw'],
    "induratna": ['mw'],
    "indurekhā": ['mw'],
    "indurāja": ['mw'],
    "indusuta": ['mw'],
    "indusūnu": ['mw'],
    "induvadana": ['mw'],
    "induvadanā": ['mw'],
    "induvallī": ['mw'],
    "induvrata": ['mw'],
    "induvāra": ['mw'],
    "induśakalā": ['mw'],
    "induśapharī": ['mw'],
    "induśekhara": ['cae', 'mw'],
    "indānuja": ['ddsa'],
    "indīvara": ['cae', 'ddsa', 'mw'],
    "indīvaradala": ['mw'],
    "indīvaradṛś": ['mw'],
    "indīvaraprabhā": ['mw'],
    "indīvariṇī": ['mw'],
    "indīvarā": ['mw'],
    "indīvarākṣa": ['mw'],
    "indīvarī": ['mw'],
    "indūra": ['mw'],
    "inodaya": ['mw'],
    "inthihā": ['mw'],
    "inu": ['mw'],
    "inv": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "inva": ['gra', 'mw'],
    "invagā": ['mw'],
    "invaka": ['mw'],
    "invakā": ['mw'],
    "invakāḥ": ['ap90'],
    "inānī": ['mw'],
    "ir": ['ap90', 'mw'],
    "iradh": ['cae', 'ddsa', 'gra', 'mw'],
    "irajy": ['cae', 'gra'],
    "irajya": ['ap90', 'ddsa', 'mw'],
    "irajyu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "irammada": ['ddsa'],
    "iranta": ['bhs'],
    "iras": ['gra', 'mw'],
    "irasy": ['cae', 'gra'],
    "irasya": ['ddsa', 'mw'],
    "irasyati": ['ap90'],
    "irasyā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iraṃmad": ['mw'],
    "iraṃmada": ['ap90', 'mw'],
    "iraṇa": ['mw'],
    "iraṇaṃ": ['ap90'],
    "iraṇya": ['mw'],
    "ireśa": ['mw'],
    "irgala": ['mw'],
    "irgalaṃ": ['ap90'],
    "irgalya": ['mw'],
    "irgalīya": ['mw'],
    "iria": ['gra'],
    "irikā": ['ap90', 'mw'],
    "irikāvana": ['mw'],
    "irimbiṭhi": ['mw'],
    "irimeda": ['mw'],
    "irimedaḥ": ['ap90'],
    "irin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "irivellikā": ['mw'],
    "irivillā": ['ap90', 'mw'],
    "iriya": ['cped'],
    "iriyamāna": ['cped'],
    "iriyat": ['cped'],
    "iriyati": ['cped'],
    "iriyā": ['cped'],
    "iriyāna": ['cped'],
    "iriyāpatha": ['bhs', 'cped'],
    "iriyāpathiya": ['cped'],
    "iriṇa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "iriṇaloṣṭa": ['mw'],
    "iriṇastha": ['cae'],
    "iriṇaṃ": ['ap90'],
    "iriṇya": ['ap90', 'mw'],
    "irvālu": ['mw'],
    "irvāru": ['ap90', 'mw'],
    "irvārukaḥ": ['ap90'],
    "irvāruśuktikā": ['mw'],
    "irya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iryati": ['bhs'],
    "iryā": ['bhs'],
    "irā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "irācara": ['mw'],
    "irāja": ['mw'],
    "irākṣīra": ['mw'],
    "irāmukha": ['mw'],
    "irāvant": ['cae'],
    "irāvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "irāvatī": ['mw'],
    "irīyati": ['cped'],
    "irṣyā": ['bhs'],
    "is": ['ap90', 'cae', 'gra', 'mw'],
    "isi": ['cped'],
    "isikā": ['cped'],
    "isipatana": ['cped'],
    "isippayāta": ['cped'],
    "isisattama": ['cped'],
    "issanti": ['cped'],
    "issara": ['cped'],
    "issarakutta": ['cped'],
    "issaranimmāṇa": ['cped'],
    "issariya": ['cped'],
    "issariyapariyosāna": ['cped'],
    "issariyādhipacca": ['cped'],
    "issarā": ['cped'],
    "issarādhipacca": ['cped'],
    "issati": ['cped'],
    "issattha": ['cped'],
    "issiṁ": ['cped'],
    "issuki": ['cped'],
    "issukin": ['cped'],
    "issā": ['cped'],
    "issāmanaka": ['cped'],
    "issāmi": ['cped'],
    "issāpakata": ['cped'],
    "issāsa": ['cped'],
    "istrigāra": ['bhs'],
    "istrikā": ['bhs'],
    "istrī": ['bhs'],
    "isīkā": ['cped'],
    "it": ['ap90', 'ddsa', 'mw'],
    "ita": ['ap90', 'cae', 'mw'],
    "itara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "itarad": ['mw'],
    "itarajana": ['mw'],
    "itarajātīya": ['mw'],
    "itarapāṇi": ['mw'],
    "itaratas": ['cae', 'mw'],
    "itarataḥ": ['ap90'],
    "itarathā": ['ap90', 'cae', 'mw'],
    "itaratra": ['cae', 'mw'],
    "itaraya": ['ddsa'],
    "itaredyus": ['mw'],
    "itaredyuḥ": ['ap90'],
    "itaretara": ['bhs', 'cae', 'ddsa', 'mw'],
    "itaretarakāmyā": ['cae', 'mw'],
    "itaretarapratyaya": ['mw'],
    "itaretarapratyayatva": ['mw'],
    "itaretarayoga": ['mw'],
    "itaretaropakṛtimat": ['mw'],
    "itaretarānurāga": ['cae'],
    "itaretarāśraya": ['mw'],
    "itaritara": ['cped'],
    "itarā": ['mw'],
    "itarāṅga": ['mw'],
    "itarītara": ['cped'],
    "itas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "itastatas": ['mw'],
    "itasūti": ['gra'],
    "itaūti": ['gra', 'mw'],
    "itaḥprabhṛti": ['mw'],
    "itaḥpradāna": ['mw'],
    "iti": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "iti c’iti ca": ['cped'],
    "iti c’īti ca": ['cped'],
    "iti ha": ['cped'],
    "itiha": ['ap90', 'cped', 'mw'],
    "itihari": ['mw'],
    "itihoti": ['mw'],
    "itihāsa": ['cae', 'cped', 'ddsa', 'mw'],
    "itihāsaka": ['bhs'],
    "itihāsapañcama": ['cped'],
    "itihāsapurāṇa": ['mw'],
    "itihāsasamuccaya": ['mw'],
    "itihāsaḥ": ['ap90'],
    "itihāsopaniṣad": ['mw'],
    "itihītiha": ['cped'],
    "itikaraṇa": ['mw'],
    "itikaraṇīya": ['mw'],
    "itikartavya": ['cae', 'ddsa', 'mw'],
    "itikartavyatā": ['mw'],
    "itikartavyatāmūḍha": ['mw'],
    "itikatha": ['mw'],
    "itikathā": ['mw'],
    "itikira": ['cped'],
    "itikrameṇa": ['mw'],
    "itikāra": ['mw'],
    "itikārya": ['cae', 'mw'],
    "itikṛtya": ['cae', 'mw'],
    "itimātra": ['mw'],
    "itiniścaya": ['mw'],
    "itināman": ['mw'],
    "itipara": ['mw'],
    "itiprabhṛti": ['mw'],
    "itipāṇini": ['mw'],
    "ititha": ['ap90', 'cae', 'mw'],
    "ititi": ['mw'],
    "itivat": ['ap90', 'cae', 'mw'],
    "itivuttaka": ['cped'],
    "itivādapamokkhānisaṁsa": ['cped'],
    "itivādappamokkhānisaṁsa": ['cped'],
    "itivṛtta": ['bhs', 'cae', 'mw'],
    "itivṛttaka": ['bhs'],
    "itiśa": ['mw'],
    "itiḥ": ['ap90'],
    "itkaṭa": ['mw'],
    "itkilā": ['ap90', 'mw'],
    "ito": ['cped'],
    "ito c’ito ca": ['cped'],
    "ito nidāna": ['cped'],
    "ito nidānaṁ": ['cped'],
    "ito paraṁ": ['cped'],
    "itogata": ['cae', 'ddsa', 'mw'],
    "itomukha": ['cae'],
    "itomukham": ['mw'],
    "ittara": ['cped'],
    "ittarajacca": ['cped'],
    "ittaraṁ": ['cped'],
    "ittha": ['mw'],
    "itthabhāva": ['cped'],
    "itthabhāvaññathābhāva": ['cped'],
    "ittham": ['cae', 'ddsa', 'gra', 'mw'],
    "itthambhāva": ['mw'],
    "itthambhūta": ['ddsa', 'mw'],
    "itthamkāram": ['mw'],
    "itthannāma": ['cped'],
    "itthantara": ['cped'],
    "itthanāma": ['cped'],
    "itthatta": ['cped'],
    "itthatva": ['bhs'],
    "itthaśāla": ['mw'],
    "itthaśālaḥ": ['ap90'],
    "itthaṁ": ['cped'],
    "itthaṃ": ['ap90'],
    "itthaṃbhūta": ['cae'],
    "itthaṃgata": ['cae'],
    "itthaṃvidha": ['cae', 'ddsa', 'mw'],
    "itthi": ['cped'],
    "itthibhāva": ['cped'],
    "itthidhutta": ['cped'],
    "itthikutta": ['cped'],
    "itthikā": ['cped'],
    "itthiliṅga": ['cped'],
    "itthindriya": ['cped'],
    "itthipariggaha": ['cped'],
    "itthipumā": ['cped'],
    "itthiratana": ['cped'],
    "itthirūpaka": ['cped'],
    "itthisoṇḍī": ['cped'],
    "itthiyutta": ['cped'],
    "itthiyā": ['cped'],
    "itthā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "itthādhī": ['gra'],
    "itthāgāra": ['cped'],
    "itthāt": ['ap90', 'mw'],
    "itthī": ['cped'],
    "itvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "itvara": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "itvarī": ['mw'],
    "itya": ['ap90', 'mw'],
    "ityahe": ['mw'],
    "ityai": ['ddsa'],
    "ityaka": ['ddsa', 'mw'],
    "ityanta": ['mw'],
    "ityartha": ['ddsa', 'mw'],
    "ityartham": ['cae', 'ddsa', 'mw'],
    "ityetannāmaka": ['ddsa', 'mw'],
    "ityevamādi": ['cae', 'ddsa', 'mw'],
    "ityukta": ['bhs', 'mw'],
    "ityuktaka": ['bhs'],
    "ityunmṛśya": ['mw'],
    "ityā": ['cae', 'gra', 'mw'],
    "ityādi": ['cae', 'ddsa', 'mw'],
    "ityālikhita": ['mw'],
    "itānta": ['ddsa', 'mw'],
    "itāsu": ['mw'],
    "itīka": ['mw'],
    "iva": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ivarṇa": ['mw'],
    "ivopamā": ['mw'],
    "ivīlaka": ['mw'],
    "iyacciram": ['cae', 'ddsa', 'mw'],
    "iyadhyai": ['mw'],
    "iyakṣ": ['cae', 'ddsa', 'gra', 'mw'],
    "iyakṣu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iyam": ['cae', 'ddsa', 'mw'],
    "iyant": ['cae'],
    "iyarti": ['ddsa'],
    "iyas": ['ap90'],
    "iyasita": ['mw'],
    "iyasy": ['cae'],
    "iyasya": ['mw'],
    "iyasā": ['ap90', 'cae', 'mw'],
    "iyat": ['ap90', 'ddsa', 'gra', 'mw'],
    "iyattaka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iyattva": ['mw'],
    "iyattā": ['ap90', 'cae', 'mw'],
    "iyaṃduḥkha": ['bhs'],
    "iyaṃtata": ['bhs'],
    "iyeṣa": ['ddsa'],
    "iñcati": ['bhs'],
    "iñcāka": ['mw'],
    "iñjana": ['bhs', 'cped'],
    "iñjanā": ['mw'],
    "iñjate": ['bhs'],
    "iñjati": ['cped'],
    "iñjaye": ['cped'],
    "iñjayuṁ": ['cped'],
    "iñjita": ['bhs', 'cped'],
    "iñjitatva": ['bhs'],
    "iśādhāra": ['bhs'],
    "iśīkā": ['mw'],
    "iḍ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iḍa": ['cae', 'ddsa', 'mw'],
    "iḍaprajas": ['mw'],
    "iḍas": ['mw'],
    "iḍaspade": ['mw'],
    "iḍaspati": ['mw'],
    "iḍaspatiḥ": ['ap90'],
    "iḍaviḍa": ['mw'],
    "iḍaviḍā": ['mw'],
    "iḍaḥ": ['ap90'],
    "iḍikka": ['mw'],
    "iḍikkaḥ": ['ap90'],
    "iḍikā": ['ap90', 'mw'],
    "iḍopahavana": ['mw'],
    "iḍvara": ['mw'],
    "iḍvaraḥ": ['ap90'],
    "iḍā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iḍābhaṅga": ['mw'],
    "iḍācamasa": ['mw'],
    "iḍācikā": ['ap90', 'mw'],
    "iḍādaḍha": ['mw'],
    "iḍājāta": ['mw'],
    "iḍānta": ['mw'],
    "iḍāprajas": ['mw'],
    "iḍāprāśitra": ['mw'],
    "iḍāpātra": ['mw'],
    "iḍāpātrī": ['mw'],
    "iḍāvant": ['cae'],
    "iḍāvat": ['ap90', 'gra', 'mw'],
    "iḍāyāspade": ['mw'],
    "iḍīya": ['mw'],
    "iḥ": ['ap90'],
    "iṃcākaḥ": ['ap90'],
    "iṃd": ['ap90'],
    "iṃdaṃbaraṃ": ['ap90'],
    "iṃdh": ['ap90'],
    "iṃdha": ['ap90'],
    "iṃdhana": ['ap90'],
    "iṃdhanavat": ['ap90'],
    "iṃdhanvan": ['ap90'],
    "iṃdirā": ['ap90'],
    "iṃdivaraṃ": ['ap90'],
    "iṃdiṃdiraḥ": ['ap90'],
    "iṃdrakaṃ": ['ap90'],
    "iṃdraprastha": ['ap90'],
    "iṃdrasvat": ['ap90'],
    "iṃdratama": ['ap90'],
    "iṃdratā": ['ap90'],
    "iṃdrayu": ['ap90'],
    "iṃdraḥ": ['ap90'],
    "iṃdriya": ['ap90'],
    "iṃdriyavat": ['ap90'],
    "iṃdrāṇikā": ['ap90'],
    "iṃdrāṇī": ['ap90'],
    "iṃdumat": ['ap90'],
    "iṃdumatī": ['ap90'],
    "iṃduḥ": ['ap90'],
    "iṃdīvaraṃ": ['ap90'],
    "iṃdīvariṇī": ['ap90'],
    "iṃdīvāraḥ": ['ap90'],
    "iṃdūraḥ": ['ap90'],
    "iṃg": ['ap90'],
    "iṃga": ['ap90'],
    "iṃganaṃ": ['ap90'],
    "iṃgita": ['ap90'],
    "iṃgudaḥ": ['ap90'],
    "iṃguḥ": ['ap90'],
    "iṃgya": ['ap90'],
    "iṃthihā": ['ap90'],
    "iṃḍraḥ": ['ap90'],
    "iṅg": ['cae', 'ddsa', 'gra', 'mw'],
    "iṅga": ['cae', 'mw'],
    "iṅgana": ['cae', 'mw'],
    "iṅganā": ['ddsa'],
    "iṅgha": ['cped'],
    "iṅgita": ['cae', 'mw'],
    "iṅgitajña": ['mw'],
    "iṅgitakovida": ['mw'],
    "iṅgitalakṣya": ['mw'],
    "iṅgitamaraṇa": ['mw'],
    "iṅgitādhyāsita": ['mw'],
    "iṅgiḍa": ['cae', 'mw'],
    "iṅguda": ['cae', 'ddsa', 'mw'],
    "iṅgudataila": ['mw'],
    "iṅgula": ['mw'],
    "iṅgya": ['mw'],
    "iṅgā": ['bhs', 'mw'],
    "iṅgāla": ['cped'],
    "iṅgālakhu": ['cped'],
    "iṅk": ['mw'],
    "iṅkh": ['mw'],
    "iṅkhika": ['bhs'],
    "iṅkāra": ['mw'],
    "iṅkṛta": ['mw'],
    "iṇa": ['cped'],
    "iṇaghāta": ['cped'],
    "iṇamūla": ['cped'],
    "iṇaṭṭa": ['cped'],
    "iṇverikā": ['mw'],
    "iṇādāna": ['cped'],
    "iṇāyika": ['cped'],
    "iṇḍalī": ['mw'],
    "iṇḍarī": ['mw'],
    "iṇḍva": ['cae', 'mw'],
    "iṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "iṣan": ['mw'],
    "iṣavant": ['cae'],
    "iṣavat": ['gra', 'mw'],
    "iṣavya": ['ap90', 'gra', 'mw'],
    "iṣay": ['cae', 'gra'],
    "iṣaya": ['ddsa', 'mw'],
    "iṣayati": ['ap90'],
    "iṣayu": ['cae', 'ddsa', 'gra', 'mw'],
    "iṣaḥ": ['ap90'],
    "iṣaḥstut": ['gra', 'mw'],
    "iṣaṃdhara": ['bhs'],
    "iṣaṇay": ['cae', 'gra'],
    "iṣaṇaya": ['ddsa', 'mw'],
    "iṣaṇayate": ['ap90'],
    "iṣaṇi": ['gra', 'mw'],
    "iṣaṇiḥ": ['ap90'],
    "iṣaṇy": ['gra'],
    "iṣaṇya": ['mw'],
    "iṣaṇyati": ['ap90'],
    "iṣaṇyā": ['ap90', 'cae', 'gra', 'mw'],
    "iṣetvaka": ['mw'],
    "iṣi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iṣidatta": ['bhs'],
    "iṣidh": ['cae', 'ddsa', 'gra', 'mw'],
    "iṣika": ['bhs'],
    "iṣikā": ['ap90', 'mw'],
    "iṣira": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iṣiram": ['mw'],
    "iṣita": ['ap90', 'mw'],
    "iṣitasena": ['mw'],
    "iṣitatvatā": ['gra', 'mw'],
    "iṣkartṛ": ['ap90', 'cae', 'gra', 'mw'],
    "iṣkṛ": ['ap90', 'mw'],
    "iṣkṛta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iṣkṛti": ['cae', 'gra', 'mw'],
    "iṣkṛtiḥ": ['ap90'],
    "iṣkṛtāhāva": ['gra', 'mw'],
    "iṣma": ['ap90', 'mw'],
    "iṣmin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iṣovṛdhīya": ['mw'],
    "iṣu": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "iṣubala": ['gra', 'mw'],
    "iṣubhṛt": ['mw'],
    "iṣudhanva": ['mw'],
    "iṣudhanvan": ['mw'],
    "iṣudhanvin": ['mw'],
    "iṣudhara": ['mw'],
    "iṣudhi": ['cae', 'ddsa', 'gra', 'mw'],
    "iṣudhimant": ['cae'],
    "iṣudhimat": ['mw'],
    "iṣudhiḥ": ['ap90'],
    "iṣudhy": ['cae', 'gra'],
    "iṣudhya": ['mw'],
    "iṣudhyati": ['ap90'],
    "iṣudhyu": ['ap90', 'cae', 'gra', 'mw'],
    "iṣudhyā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iṣuhasta": ['gra', 'mw'],
    "iṣuhata": ['mw'],
    "iṣuka": ['ap90', 'mw'],
    "iṣukā": ['mw'],
    "iṣukāmaśamī": ['mw'],
    "iṣukāra": ['mw'],
    "iṣukṛt": ['gra', 'mw'],
    "iṣukṣepa": ['mw'],
    "iṣumat": ['ddsa', 'gra', 'mw'],
    "iṣumukha": ['mw'],
    "iṣumārga": ['mw'],
    "iṣumātra": ['mw'],
    "iṣumātram": ['mw'],
    "iṣunibandhana": ['mw'],
    "iṣupa": ['mw'],
    "iṣupad": ['mw'],
    "iṣuparṣin": ['mw'],
    "iṣupatha": ['mw'],
    "iṣupuṣpā": ['mw'],
    "iṣupāta": ['mw'],
    "iṣustrikāṃḍā": ['ap90'],
    "iṣustrikāṇḍā": ['mw'],
    "iṣusāhva": ['mw'],
    "iṣuvadha": ['mw'],
    "iṣuvarṣa": ['mw'],
    "iṣuvikṣepa": ['mw'],
    "iṣuḥ": ['ap90'],
    "iṣva": ['mw'],
    "iṣvagra": ['mw'],
    "iṣvagrīya": ['mw'],
    "iṣvanīka": ['mw'],
    "iṣvanīkīya": ['mw'],
    "iṣvarga": ['mw'],
    "iṣvasana": ['cae', 'ddsa', 'mw'],
    "iṣvastra": ['cae', 'mw'],
    "iṣvastrakarman": ['cae'],
    "iṣvaḥ": ['ap90'],
    "iṣvā": ['mw'],
    "iṣvāsa": ['cae', 'ddsa', 'mw'],
    "iṣvāyudha": ['mw'],
    "iṣya": ['mw'],
    "iṣyate": ['bhs'],
    "iṣyaḥ": ['ap90'],
    "iṣādhāra": ['bhs'],
    "iṣāṃdhara": ['bhs'],
    "iṣāṇa": ['bhs'],
    "iṣīka": ['mw'],
    "iṣīkatūla": ['mw'],
    "iṣīkā": ['ap90', 'cae', 'ddsa', 'mw'],
    "iṣīkātūla": ['mw'],
    "iṣīkāñji": ['mw'],
    "iṣīkāṭavī": ['mw'],
    "iṣūguha": ['mw'],
    "iṣūy": ['cae', 'gra'],
    "iṣūya": ['ddsa', 'mw'],
    "iṣūyati": ['ap90'],
    "iṣṇuc": ['ddsa'],
    "iṣṭa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "iṣṭaaśva": ['gra'],
    "iṣṭadarpaṇa": ['mw'],
    "iṣṭadeva": ['mw'],
    "iṣṭadevatā": ['mw'],
    "iṣṭagandha": ['mw'],
    "iṣṭajana": ['cae', 'ddsa', 'mw'],
    "iṣṭaka": ['bhs'],
    "iṣṭakacita": ['mw'],
    "iṣṭakaikaśatavidha": ['mw'],
    "iṣṭakarman": ['mw'],
    "iṣṭakā": ['ap90', 'cae', 'ddsa', 'mw'],
    "iṣṭakāciti": ['mw'],
    "iṣṭakāgṛha": ['mw'],
    "iṣṭakāmaduh": ['cae', 'ddsa', 'mw'],
    "iṣṭakāmaya": ['mw'],
    "iṣṭakāmātrā": ['mw'],
    "iṣṭakānyāsa": ['mw'],
    "iṣṭakāpatha": ['mw'],
    "iṣṭakāpathaka": ['mw'],
    "iṣṭakāpathika": ['mw'],
    "iṣṭakāpaśu": ['mw'],
    "iṣṭakāpurāṇa": ['mw'],
    "iṣṭakārāśi": ['mw'],
    "iṣṭakāsaṃpad": ['mw'],
    "iṣṭakāvat": ['mw'],
    "iṣṭakṛt": ['mw'],
    "iṣṭalābha": ['ddsa'],
    "iṣṭam": ['mw'],
    "iṣṭani": ['cae', 'ddsa', 'gra', 'mw'],
    "iṣṭaraśmi": ['gra', 'mw'],
    "iṣṭarga": ['ddsa', 'mw'],
    "iṣṭarūpa": ['bhs'],
    "iṣṭasaṃpādin": ['mw'],
    "iṣṭasviṣṭakṛt": ['mw'],
    "iṣṭasādhana": ['cae'],
    "iṣṭasāhasa": ['mw'],
    "iṣṭatama": ['mw'],
    "iṣṭatara": ['mw'],
    "iṣṭatas": ['mw'],
    "iṣṭatva": ['mw'],
    "iṣṭatā": ['mw'],
    "iṣṭavrata": ['cae', 'ddsa', 'gra', 'mw'],
    "iṣṭayajus": ['mw'],
    "iṣṭayāman": ['gra', 'mw'],
    "iṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "iṣṭihautra": ['mw'],
    "iṣṭikā": ['ap90', 'bhs', 'mw'],
    "iṣṭikālanirṇaya": ['mw'],
    "iṣṭimaya": ['mw'],
    "iṣṭimuṣ": ['mw'],
    "iṣṭin": ['mw'],
    "iṣṭipaca": ['mw'],
    "iṣṭirūpa": ['mw'],
    "iṣṭitva": ['mw'],
    "iṣṭiyā": ['bhs'],
    "iṣṭiyājuka": ['mw'],
    "iṣṭiśrāddha": ['mw'],
    "iṣṭiḥ": ['ap90'],
    "iṣṭu": ['mw'],
    "iṣṭuḥ": ['ap90'],
    "iṣṭvā": ['ddsa', 'mw'],
    "iṣṭvīnam": ['mw'],
    "iṣṭyayana": ['mw'],
    "iṣṭā": ['bhs', 'mw'],
    "iṣṭāhotrya": ['mw'],
    "iṣṭāhotrīya": ['mw'],
    "iṣṭākṛta": ['mw'],
    "iṣṭāpūrta": ['cae', 'ddsa', 'gra', 'mw'],
    "iṣṭāpūrtasyāparijyāni": ['mw'],
    "iṣṭāpūrtaṃ": ['ap90'],
    "iṣṭāpūrti": ['mw'],
    "iṣṭāpūrtin": ['mw'],
    "iṣṭārtha": ['mw'],
    "iṣṭārthodyukta": ['mw'],
    "iṣṭātithitva": ['mw'],
    "iṣṭāvat": ['mw'],
    "iṣṭāśva": ['gra', 'mw'],
    "iṣṭī": ['bhs'],
    "iṣṭīkṛta": ['mw'],
    "iṭ": ['ap90', 'mw'],
    "iṭa": ['cae', 'ddsa', 'mw'],
    "iṭasūna": ['mw'],
    "iṭat": ['mw'],
    "iṭatas": ['gra'],
    "iṭaḥ": ['ap90'],
    "iṭcara": ['mw'],
    "iṭcaraḥ": ['ap90'],
    "iṭhimikā": ['mw'],
    "iṭṭha": ['cped'],
    "iṭṭhakā": ['cped'],
    "iṭṭhikā": ['cped'],
    "iṭṭā": ['bhs'],
    "ja": ['ap90', 'cae', 'ddsa', 'mw'],
    "jabdha": ['mw'],
    "jabdhṛ": ['mw'],
    "jabh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jabhya": ['mw'],
    "jabālā": ['mw'],
    "jabāru": ['gra', 'mw'],
    "jaccandha": ['cped'],
    "jaga": ['mw'],
    "jaga(t)": ['cped'],
    "jagac": ['mw'],
    "jagaccakṣus": ['ddsa', 'mw'],
    "jagaccandra": ['mw'],
    "jagaccandrikā": ['mw'],
    "jagacchandas": ['mw'],
    "jagaccitra": ['mw'],
    "jagad": ['mw'],
    "jagada": ['ddsa', 'mw'],
    "jagadambikā": ['mw'],
    "jagadambā": ['mw'],
    "jagadambāprādurbhāva": ['mw'],
    "jagadanta": ['mw'],
    "jagadantaka": ['ddsa', 'mw'],
    "jagadantakāntaka": ['mw'],
    "jagadantarātman": ['mw'],
    "jagadaḥ": ['ap90'],
    "jagadaṇḍa": ['cae', 'ddsa', 'mw'],
    "jagadaṇḍaka": ['mw'],
    "jagadbala": ['mw'],
    "jagadbhaya": ['mw'],
    "jagadbhūṣaṇakoṣṭhaka": ['mw'],
    "jagadbimba": ['mw'],
    "jagadbīja": ['mw'],
    "jagaddala": ['mw'],
    "jagaddeva": ['mw'],
    "jagaddhara": ['ap90', 'mw'],
    "jagaddhitātman": ['mw'],
    "jagaddhātrī": ['mw'],
    "jagaddhātṛ": ['cae', 'mw'],
    "jagaddruh": ['mw'],
    "jagaddīpa": ['cae', 'mw'],
    "jagadekacakṣus": ['mw'],
    "jagadekanātha": ['mw'],
    "jagadekapāvana": ['mw'],
    "jagadgaurī": ['mw'],
    "jagadghātin": ['mw'],
    "jagadguru": ['cae', 'ddsa', 'mw'],
    "jagadindrarāja": ['bhs'],
    "jagadrocana": ['bhs'],
    "jagadrāma": ['mw'],
    "jagaduddhāra": ['mw'],
    "jagadvahā": ['mw'],
    "jagadvaidyaka": ['mw'],
    "jagadvandya": ['mw'],
    "jagadvañcaka": ['mw'],
    "jagadvidhi": ['mw'],
    "jagadvināśa": ['mw'],
    "jagadvyāpāra": ['mw'],
    "jagadvyūhagarbha": ['bhs'],
    "jagadyatrā": ['mw'],
    "jagadyoni": ['cae', 'mw'],
    "jagadābharaṇa": ['mw'],
    "jagadādhāra": ['mw'],
    "jagadādija": ['mw'],
    "jagadānanda": ['mw'],
    "jagadātmaka": ['mw'],
    "jagadātman": ['mw'],
    "jagadāyu": ['mw'],
    "jagadāyus": ['mw'],
    "jagadīśa": ['cae', 'mw'],
    "jagadīśatoṣiṇī": ['mw'],
    "jagadīśaśataka": ['mw'],
    "jagadīśitṛ": ['mw'],
    "jagadīśvara": ['cae', 'mw'],
    "jagaj": ['mw'],
    "jagajjīva": ['ddsa', 'mw'],
    "jagajjīvanadāsa": ['mw'],
    "jagala": ['ap90', 'mw'],
    "jagamantrasāgaranirghoṣamati": ['bhs'],
    "jagamyā": ['mw'],
    "jagan": ['mw'],
    "jaganmaya": ['mw'],
    "jaganmaṇi": ['mw'],
    "jaganmitra": ['bhs'],
    "jaganmohana": ['mw'],
    "jaganmohinī": ['mw'],
    "jaganmukha": ['mw'],
    "jaganmātṛ": ['cae', 'mw'],
    "jagannetra": ['mw'],
    "jagannidhi": ['mw'],
    "jagannivāsa": ['cae', 'mw'],
    "jagannu": ['mw'],
    "jagannuḥ": ['ap90'],
    "jagannātha": ['cae', 'ddsa', 'mw'],
    "jagannāthakṣetra": ['mw'],
    "jagannāthapaṃḍita": ['ap90'],
    "jagannāthavallabhanāṭaka": ['mw'],
    "jagannāthavijaya": ['mw'],
    "jagannāthā": ['mw'],
    "jaganu": ['mw'],
    "jaganuḥ": ['ap90'],
    "jaganvas": ['mw'],
    "jagapradīpaśri": ['bhs'],
    "jagara": ['mw'],
    "jagaraḥ": ['ap90'],
    "jagat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jagatkartṛ": ['mw'],
    "jagatkāraṇa": ['cae', 'ddsa', 'mw'],
    "jagatkāraṇakāraṇa": ['mw'],
    "jagatkṛtsna": ['mw'],
    "jagatkṣaya": ['mw'],
    "jagatogadha": ['cped'],
    "jagatparāyaṇa": ['mw'],
    "jagatpati": ['cae', 'mw'],
    "jagatpitṛ": ['mw'],
    "jagatprabhu": ['cae', 'mw'],
    "jagatpradhāna": ['mw'],
    "jagatprakāśa": ['cae', 'mw'],
    "jagatprasiddha": ['mw'],
    "jagatprāsāha": ['mw'],
    "jagatprāṇa": ['mw'],
    "jagatprīti": ['mw'],
    "jagatpā": ['gra'],
    "jagatsamagra": ['mw'],
    "jagatsarva": ['mw'],
    "jagatseṭa": ['mw'],
    "jagatsiṃha": ['mw'],
    "jagatsraṣṭṛ": ['cae', 'mw'],
    "jagatsvāmin": ['cae', 'mw'],
    "jagatsvāmitva": ['mw'],
    "jagatsākṣin": ['mw'],
    "jagatsāman": ['mw'],
    "jagattraya": ['cae', 'mw'],
    "jagattritaya": ['cae', 'mw'],
    "jagattuṅga": ['mw'],
    "jagatya": ['mw'],
    "jagatī": ['ap90', 'cped', 'mw'],
    "jagatībhartṛ": ['cae', 'mw'],
    "jagatībhuj": ['mw'],
    "jagatīcara": ['mw'],
    "jagatīdhara": ['mw'],
    "jagatīgata": ['cae'],
    "jagatījāni": ['ddsa', 'mw'],
    "jagatīmadhya": ['mw'],
    "jagatīpati": ['cae', 'mw'],
    "jagatīpatikanyakā": ['mw'],
    "jagatīpāla": ['cae', 'mw'],
    "jagatīruh": ['mw'],
    "jagatīruha": ['mw'],
    "jagatītala": ['cae', 'mw'],
    "jagatīvarāha": ['mw'],
    "jagatīṃdhara": ['bhs'],
    "jagdha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jagdhapāpman": ['mw'],
    "jagdhasāraṃga": ['mw'],
    "jagdhatṛṇa": ['cae', 'mw'],
    "jagdhi": ['cae', 'ddsa', 'mw'],
    "jagdhiḥ": ['ap90'],
    "jagdhvā": ['mw'],
    "jagdhvāya": ['ddsa', 'mw'],
    "jagdhārdha": ['cae', 'mw'],
    "jagga(t)": ['cped'],
    "jaggati": ['cped'],
    "jaggika": ['ddsa', 'mw'],
    "jaghana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jaghanacapalā": ['cae', 'mw'],
    "jaghanacyuti": ['mw'],
    "jaghanagaurava": ['mw'],
    "jaghanakūpaka": ['mw'],
    "jaghanatas": ['mw'],
    "jaghanavipulā": ['mw'],
    "jaghanaṃ": ['ap90'],
    "jaghanena": ['cae', 'ddsa', 'mw'],
    "jaghanephalā": ['mw'],
    "jaghanin": ['ap90', 'mw'],
    "jaghanvas": ['mw'],
    "jaghanya": ['ap90', 'cae', 'ddsa', 'mw'],
    "jaghanyabhāva": ['mw'],
    "jaghanyaguṇa": ['mw'],
    "jaghanyaja": ['cae', 'mw'],
    "jaghanyakārin": ['mw'],
    "jaghanyam": ['mw'],
    "jaghanyaprabhava": ['cae', 'mw'],
    "jaghanyarātre": ['mw'],
    "jaghanyasaṃveśin": ['mw'],
    "jaghanyatara": ['mw'],
    "jaghanyatas": ['mw'],
    "jaghanyaśāyin": ['mw'],
    "jaghanye": ['mw'],
    "jaghanyāyus": ['mw'],
    "jaghanārdha": ['mw'],
    "jaghni": ['cae', 'ddsa', 'gra', 'mw'],
    "jaghnivas": ['mw'],
    "jaghnivat": ['ddsa', 'mw'],
    "jaghniḥ": ['ap90'],
    "jaghnu": ['ap90', 'mw'],
    "jaghri": ['cae', 'ddsa', 'gra', 'mw'],
    "jagmi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jagmivas": ['mw'],
    "jagmāna": ['mw'],
    "jaguri": ['cae', 'ddsa', 'gra', 'mw'],
    "jah": ['gra'],
    "jaha": ['bhs', 'cped', 'mw'],
    "jaha(t)": ['cped'],
    "jahaka": ['ap90', 'mw'],
    "jahakā": ['cae', 'ddsa', 'mw'],
    "jahallakṣaṇā": ['cae', 'ddsa', 'mw'],
    "jahana": ['bhs', 'mw'],
    "jahassu": ['cped'],
    "jahat": ['ap90', 'mw'],
    "jahati": ['cped'],
    "jahatsvārtha": ['ddsa', 'mw'],
    "jahatsvārthā": ['mw'],
    "jahe": ['cped'],
    "jahetvā": ['cped'],
    "jaheyya": ['cped'],
    "jahi": ['mw'],
    "jahijoḍa": ['mw'],
    "jahina": ['mw'],
    "jahissanti": ['cped'],
    "jahissati": ['cped'],
    "jahissāmi": ['cped'],
    "jahistambha": ['mw'],
    "jahita": ['cae', 'cped', 'ddsa', 'mw'],
    "jahitvā": ['cped'],
    "jahla": ['mw'],
    "jahman": ['ap90', 'mw'],
    "jahnu": ['cae', 'gra', 'mw'],
    "jahnukanyā": ['cae', 'mw'],
    "jahnuprajā": ['mw'],
    "jahnusaptamī": ['mw'],
    "jahnusutā": ['cae', 'mw'],
    "jahnutanayā": ['mw'],
    "jahnuḥ": ['ap90'],
    "jahnāvī": ['gra', 'mw'],
    "jahu": ['cae', 'ddsa', 'mw'],
    "jahuḥ": ['ap90'],
    "jahā": ['mw'],
    "jahāka": ['mw'],
    "jahānaka": ['mw'],
    "jahānakaḥ": ['ap90'],
    "jahāti": ['bhs', 'cped'],
    "jahāṅgīra": ['mw'],
    "jahī": ['cped'],
    "jai": ['ap90', 'mw'],
    "jaigīṣavya": ['mw'],
    "jaigīṣavyeśvara": ['mw'],
    "jaigīṣavyāyaṇī": ['mw'],
    "jaihmati": ['mw'],
    "jaihmaya": ['cae'],
    "jaihmi": ['mw'],
    "jaihmya": ['ddsa', 'mw'],
    "jaihmyaṃ": ['ap90'],
    "jaihmākani": ['mw'],
    "jaihmāśineya": ['mw'],
    "jaihnavaka": ['mw'],
    "jaihva": ['cae', 'ddsa', 'mw'],
    "jaihvalāyani": ['mw'],
    "jaihvya": ['cae', 'mw'],
    "jaihvyaṃ": ['ap90'],
    "jaihvākāta": ['mw'],
    "jaijjaṭa": ['mw'],
    "jaikaśūnya": ['mw'],
    "jaimani": ['mw'],
    "jaimantāyana": ['mw'],
    "jaimini": ['cae', 'ddsa', 'mw'],
    "jaiminibhāgavata": ['mw'],
    "jaiminibhārata": ['mw'],
    "jaiminikaḍāra": ['mw'],
    "jaiminikośasūtra": ['mw'],
    "jaiminisūtra": ['mw'],
    "jaiminiḥ": ['ap90'],
    "jaiminīya": ['cae', 'mw'],
    "jaiminīyanyāyamālāvistara": ['mw'],
    "jaimūta": ['mw'],
    "jaina": ['cae', 'ddsa', 'mw'],
    "jainanagara": ['mw'],
    "jainapāla": ['mw'],
    "jainataraṃgiṇī": ['mw'],
    "jainaḥ": ['ap90'],
    "jainendra": ['mw'],
    "jainendravyākaraṇa": ['mw'],
    "jainya": ['mw'],
    "jaināyatana": ['mw'],
    "jaināśrama": ['mw'],
    "jainī": ['mw'],
    "jaipāla": ['mw'],
    "jaipālaka": ['mw'],
    "jaitra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jaitraratha": ['cae', 'mw'],
    "jaitrayātrā": ['cae'],
    "jaitriya": ['cae', 'mw'],
    "jaitrāyaṇa": ['mw'],
    "jaitrāyaṇi": ['mw'],
    "jaitrī": ['mw'],
    "jaitva": ['mw'],
    "jaitvāyani": ['mw'],
    "jaiva": ['ap90', 'cae', 'ddsa', 'mw'],
    "jaivala": ['mw'],
    "jaivali": ['mw'],
    "jaivanti": ['mw'],
    "jaivantyāyani": ['mw'],
    "jaivantāyana": ['mw'],
    "jaivantāyani": ['mw'],
    "jaiveya": ['mw'],
    "jaiveyaḥ": ['ap90'],
    "jaivi": ['mw'],
    "jaivātṛka": ['ap90', 'cae', 'ddsa', 'mw'],
    "jaiyaṭa": ['mw'],
    "jaiyyaṭa": ['mw'],
    "jaiṣṇava": ['mw'],
    "jaj": ['ap90', 'mw'],
    "jaja": ['cae', 'ddsa', 'mw'],
    "jajaujas": ['mw'],
    "jajaḥ": ['ap90'],
    "jajaṃ": ['ap90'],
    "jajhjh": ['cae', 'gra'],
    "jajhjhatī": ['mw'],
    "jajja": ['ddsa', 'mw'],
    "jajjala": ['mw'],
    "jajjalā": ['mw'],
    "jajjara": ['cped'],
    "jajjararathaka": ['cped'],
    "jajjh": ['ap90'],
    "jajñana": ['mw'],
    "jajñi": ['cae', 'ddsa', 'mw'],
    "jajñivas": ['mw'],
    "jajñāna": ['ddsa'],
    "jaka": ['mw'],
    "jakkarī": ['mw'],
    "jakuṭa": ['mw'],
    "jakuṭaḥ": ['ap90'],
    "jakāra": ['mw'],
    "jakṛt": ['bhs'],
    "jakṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jakṣaṇa": ['mw'],
    "jakṣaṇaṃ": ['ap90'],
    "jakṣi": ['mw'],
    "jakṣita": ['mw'],
    "jakṣivas": ['mw'],
    "jakṣivān": ['ddsa'],
    "jakṣma": ['mw'],
    "jakṣā": ['mw'],
    "jal": ['ap90', 'mw'],
    "jala": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "jala(t)": ['cped'],
    "jalabandhaka": ['mw'],
    "jalabandhu": ['mw'],
    "jalabhauta": ['mw'],
    "jalabhājana": ['cae', 'mw'],
    "jalabhū": ['mw'],
    "jalabhūṣaṇa": ['mw'],
    "jalabhṛt": ['mw'],
    "jalabilva": ['mw'],
    "jalabimba": ['mw'],
    "jalabindu": ['bhs', 'cae', 'mw'],
    "jalabindujā": ['mw'],
    "jalabiḍāla": ['mw'],
    "jalabrahmī": ['mw'],
    "jalabudbuda": ['cae', 'mw'],
    "jalabṛṃhaṇa": ['mw'],
    "jalacakra": ['mw'],
    "jalacandra": ['mw'],
    "jalacara": ['cae', 'mw'],
    "jalacarajīva": ['mw'],
    "jalacarājīva": ['mw'],
    "jalacatvara": ['mw'],
    "jalacañcala": ['mw'],
    "jalacārin": ['cae', 'mw'],
    "jalada": ['cae', 'ddsa', 'mw'],
    "jaladaivatya": ['mw'],
    "jaladakāla": ['mw'],
    "jaladakṣaya": ['mw'],
    "jaladapaṅkti": ['mw'],
    "jaladardaraka": ['bhs'],
    "jaladardura": ['mw'],
    "jaladasamaya": ['mw'],
    "jaladasaṃhati": ['mw'],
    "jaladeva": ['mw'],
    "jaladevatā": ['mw'],
    "jaladhara": ['bhs', 'cae', 'mw'],
    "jaladharagarjitaghoṣasusvaranakṣatrarājasaṃkusumitābhijña": ['bhs', 'mw'],
    "jaladharamālā": ['mw'],
    "jaladharābhyudaya": ['mw'],
    "jaladhenu": ['mw'],
    "jaladhi": ['cae', 'mw'],
    "jaladhigā": ['mw'],
    "jaladhijā": ['mw'],
    "jaladhikanyakā": ['mw'],
    "jaladhinandinī": ['mw'],
    "jaladhiraśana": ['mw'],
    "jaladhisambhava": ['mw'],
    "jaladhitā": ['mw'],
    "jaladhāra": ['mw'],
    "jaladhāraṇa": ['mw'],
    "jaladhārā": ['cae', 'mw'],
    "jaladravya": ['cae', 'mw'],
    "jaladroṇī": ['mw'],
    "jaladvipa": ['mw'],
    "jaladvīpa": ['mw'],
    "jaladābha": ['mw'],
    "jaladāgama": ['cae', 'mw'],
    "jaladāna": ['ddsa', 'mw'],
    "jaladātyaya": ['mw'],
    "jaladāśana": ['mw'],
    "jalagambu": ['mw'],
    "jalagandhebha": ['mw'],
    "jalagarbha": ['bhs', 'mw'],
    "jalaghaṭi": ['mw'],
    "jalagulma": ['mw'],
    "jalagāhana": ['mw'],
    "jalagṛha": ['mw'],
    "jalaha": ['mw'],
    "jalahara": ['bhs'],
    "jalaharaṇa": ['mw'],
    "jalahastin": ['mw'],
    "jalahrada": ['mw'],
    "jalahāra": ['cae', 'mw'],
    "jalahāriṇī": ['mw'],
    "jalahārī": ['mw'],
    "jalahāsa": ['mw'],
    "jalahāsaka": ['mw'],
    "jalahīna": ['cae', 'mw'],
    "jalaja": ['cae', 'mw'],
    "jalajadravya": ['mw'],
    "jalajakusuma": ['mw'],
    "jalajakusumayoni": ['mw'],
    "jalajambukā": ['mw'],
    "jalajambukālatā": ['mw'],
    "jalajanman": ['mw'],
    "jalajantu": ['cae', 'mw'],
    "jalajantukā": ['mw'],
    "jalajasumanā": ['mw'],
    "jalajekṣaṇā": ['mw'],
    "jalajihva": ['mw'],
    "jalajinī": ['mw'],
    "jalajinībandhu": ['mw'],
    "jalajñāna": ['mw'],
    "jalajā": ['mw'],
    "jalajājīva": ['mw'],
    "jalajākṣī": ['mw'],
    "jalajāsana": ['mw'],
    "jalajāta": ['mw'],
    "jalajīvin": ['cae', 'mw'],
    "jalajīvinī": ['mw'],
    "jalaka": ['mw'],
    "jalakalka": ['mw'],
    "jalakalmaṣa": ['mw'],
    "jalakapi": ['ddsa', 'mw'],
    "jalakapota": ['mw'],
    "jalakara": ['mw'],
    "jalakaraṅka": ['mw'],
    "jalakaṃ": ['ap90'],
    "jalakaṇṭaka": ['mw'],
    "jalakeli": ['mw'],
    "jalakelivarṇana": ['mw'],
    "jalaketu": ['mw'],
    "jalakeśa": ['mw'],
    "jalakhaga": ['cae', 'mw'],
    "jalakirāṭa": ['mw'],
    "jalakriyā": ['cae', 'mw'],
    "jalakrīḍā": ['mw'],
    "jalakubjaka": ['mw'],
    "jalakukkubha": ['mw'],
    "jalakukkuṭa": ['mw'],
    "jalakukkuṭī": ['mw'],
    "jalakumbha": ['mw'],
    "jalakumbhikā": ['mw'],
    "jalakumāraka": ['mw'],
    "jalakuntala": ['mw'],
    "jalakāka": ['mw'],
    "jalakāmukā": ['mw'],
    "jalakānta": ['mw'],
    "jalakāntāra": ['mw'],
    "jalakāntāśman": ['mw'],
    "jalakāṅkṣa": ['mw'],
    "jalakāṅkṣin": ['mw'],
    "jalakūpī": ['mw'],
    "jalakūrma": ['mw'],
    "jalakṛt": ['mw'],
    "jalakṣālanavidhi": ['mw'],
    "jalalatā": ['mw'],
    "jalalekhā": ['mw'],
    "jalalohita": ['mw'],
    "jalamadgu": ['mw'],
    "jalamadhūka": ['mw'],
    "jalamagna": ['mw'],
    "jalamakṣikā": ['mw'],
    "jalamandira": ['mw'],
    "jalamarkaṭa": ['mw'],
    "jalamasi": ['mw'],
    "jalamaya": ['cae', 'mw'],
    "jalambala": ['mw'],
    "jalamitra": ['mw'],
    "jalamoda": ['mw'],
    "jalamuc": ['cae', 'mw'],
    "jalamāna": ['cped'],
    "jalamānuṣa": ['mw'],
    "jalamānuṣī": ['mw'],
    "jalamārga": ['mw'],
    "jalamārjāra": ['mw'],
    "jalamātaṅga": ['mw'],
    "jalamātreṇa": ['mw'],
    "jalamūrti": ['mw'],
    "jalamūrtikā": ['mw'],
    "jalanakula": ['mw'],
    "jalanara": ['mw'],
    "jalanidhi": ['cae', 'mw'],
    "jalanidhinātha": ['cae'],
    "jalanidhivacas": ['mw'],
    "jalanirgama": ['mw'],
    "jalanivaha": ['mw'],
    "jalanta": ['cped'],
    "jalanāḍī": ['mw'],
    "jalanīlikā": ['mw'],
    "jalanīlī": ['mw'],
    "jalapadavī": ['mw'],
    "jalapaddhati": ['mw'],
    "jalapakṣacara": ['mw'],
    "jalapakṣin": ['mw'],
    "jalaparyāya": ['mw'],
    "jalaparṇikā": ['mw'],
    "jalapatha": ['bhs', 'mw'],
    "jalapati": ['mw'],
    "jalapattana": ['mw'],
    "jalapavitra": ['mw'],
    "jalaphala": ['mw'],
    "jalaphena": ['mw'],
    "jalapippalī": ['mw'],
    "jalapippikā": ['mw'],
    "jalapitta": ['mw'],
    "jalaplava": ['mw'],
    "jalaplāvana": ['mw'],
    "jalapradāna": ['mw'],
    "jalapradānika": ['mw'],
    "jalapralaya": ['mw'],
    "jalaprapāta": ['mw'],
    "jalaprasaraṇa": ['mw'],
    "jalapravāha": ['mw'],
    "jalapriya": ['mw'],
    "jalapriyā": ['mw'],
    "jalaprānta": ['mw'],
    "jalaprāya": ['mw'],
    "jalapuṣpa": ['mw'],
    "jalapāda": ['mw'],
    "jalapālikā": ['mw'],
    "jalapāna": ['cae', 'mw'],
    "jalapārāvata": ['mw'],
    "jalapātra": ['mw'],
    "jalapīna": ['mw'],
    "jalapūra": ['mw'],
    "jalapūruṣa": ['mw'],
    "jalapūrvakam": ['mw'],
    "jalapūrṇa": ['mw'],
    "jalapṛkta": ['mw'],
    "jalapṛṣṭhajā": ['mw'],
    "jalarasa": ['mw'],
    "jalarañja": ['mw'],
    "jalaraṅka": ['mw'],
    "jalaraṅku": ['mw'],
    "jalaraṇḍa": ['mw'],
    "jalarekhā": ['mw'],
    "jalaruh": ['cae', 'mw'],
    "jalaruha": ['cae', 'mw'],
    "jalaruhakusuma": ['mw'],
    "jalaruhekṣaṇa": ['mw'],
    "jalaruṇḍa": ['mw'],
    "jalarākṣasī": ['cae', 'mw'],
    "jalarāśi": ['cae', 'mw'],
    "jalarūpa": ['mw'],
    "jalarūpaka": ['mw'],
    "jalasambhava": ['mw'],
    "jalasamparka": ['mw'],
    "jalasamudra": ['mw'],
    "jalasarasa": ['mw'],
    "jalasarpiṇī": ['mw'],
    "jalasaṃdha": ['cae', 'mw'],
    "jalasaṃniveśa": ['mw'],
    "jalasaṃsarga": ['mw'],
    "jalaseka": ['mw'],
    "jalasikta": ['mw'],
    "jalasnāna": ['cae', 'mw'],
    "jalasrāva": ['mw'],
    "jalastambha": ['mw'],
    "jalastambhana": ['mw'],
    "jalastha": ['cae', 'mw'],
    "jalasthā": ['mw'],
    "jalasthāna": ['cae', 'mw'],
    "jalasthāya": ['mw'],
    "jalasāt": ['mw'],
    "jalasūci": ['mw'],
    "jalasūkara": ['mw'],
    "jalasūrya": ['mw'],
    "jalasūryaka": ['mw'],
    "jalataraṃga": ['mw'],
    "jalataraṃgiṇī": ['mw'],
    "jalataskara": ['mw'],
    "jalataṇḍulīya": ['mw'],
    "jalati": ['cped'],
    "jalatiktikā": ['mw'],
    "jalatrā": ['mw'],
    "jalatrāsa": ['cae', 'mw'],
    "jalatrāsin": ['mw'],
    "jalatumbikānyāya": ['mw'],
    "jalaturaga": ['mw'],
    "jalatā": ['mw'],
    "jalatāla": ['mw'],
    "jalatāpika": ['mw'],
    "jalatāpin": ['mw'],
    "jalatāḍana": ['mw'],
    "jalaugha": ['mw'],
    "jalauka": ['cae', 'ddsa', 'mw'],
    "jalaukas": ['cae', 'mw'],
    "jalaukasa": ['mw'],
    "jalaukasā": ['mw'],
    "jalaukovaseka": ['cae'],
    "jalaukovraṇa": ['cae'],
    "jalaukā": ['mw'],
    "jalaukāvacāraṇīya": ['cae', 'mw'],
    "jalavalkala": ['mw'],
    "jalavallī": ['mw'],
    "jalavant": ['cae'],
    "jalavaraṇṭa": ['mw'],
    "jalavartikā": ['mw'],
    "jalavat": ['mw'],
    "jalavetasa": ['mw'],
    "jalavihaṃgama": ['cae', 'mw'],
    "jalaviṣuva": ['mw'],
    "jalavyadha": ['mw'],
    "jalavyatha": ['mw'],
    "jalavyāla": ['mw'],
    "jalavādita": ['mw'],
    "jalavādya": ['mw'],
    "jalavāha": ['cae', 'mw'],
    "jalavāhaka": ['mw'],
    "jalavāhana": ['bhs', 'mw'],
    "jalavāhanī": ['mw'],
    "jalavālaka": ['mw'],
    "jalavālikā": ['mw'],
    "jalavāluka": ['mw'],
    "jalavāsa": ['cae', 'mw'],
    "jalavāsin": ['cae', 'mw'],
    "jalavāsā": ['mw'],
    "jalavāyasa": ['mw'],
    "jalavīrya": ['mw'],
    "jalavṛścika": ['mw'],
    "jalayantra": ['bhs', 'cae', 'ddsa', 'mw'],
    "jalayantracakra": ['mw'],
    "jalayantragṛha": ['mw'],
    "jalayantraka": ['cae', 'mw'],
    "jalayantramandira": ['mw'],
    "jalayantraniketana": ['mw'],
    "jalayati": ['cped'],
    "jalayāna": ['mw'],
    "jalayātrā": ['mw'],
    "jalaśarkarā": ['mw'],
    "jalaśaya": ['mw'],
    "jalaśayana": ['mw'],
    "jalaśayyā": ['cae', 'mw'],
    "jalaśoṣa": ['mw'],
    "jalaśuci": ['mw'],
    "jalaśukti": ['mw'],
    "jalaśunaka": ['mw'],
    "jalaśāyin": ['mw'],
    "jalaśāyitīrtha": ['mw'],
    "jalaśūka": ['mw'],
    "jalaḍimba": ['mw'],
    "jalaḍā": ['mw'],
    "jalaṃdhama": ['mw'],
    "jalaṃdhamā": ['mw'],
    "jalaṃdhara": ['mw'],
    "jalaṃdharapura": ['mw'],
    "jalaṃga": ['ap90', 'mw'],
    "jalaṃgama": ['ap90', 'mw'],
    "jale": ['mw'],
    "jalebha": ['mw'],
    "jalebhī": ['mw'],
    "jalecara": ['cae', 'ddsa', 'mw'],
    "jalecchayā": ['mw'],
    "jalejaṃ": ['ap90'],
    "jalejāta": ['mw'],
    "jalelā": ['mw'],
    "jalendhana": ['mw'],
    "jalendra": ['mw'],
    "jaleniprabha": ['bhs'],
    "jaleruha": ['mw'],
    "jaleruhā": ['mw'],
    "jaleti": ['cped'],
    "jalevāha": ['mw'],
    "jalevāhaḥ": ['ap90'],
    "jaleyu": ['mw'],
    "jaleśa": ['cae', 'ddsa', 'mw'],
    "jaleśaya": ['cae', 'mw'],
    "jaleśayaḥ": ['ap90'],
    "jaleśvara": ['cae', 'ddsa', 'mw'],
    "jaleśvaratīrtha": ['mw'],
    "jalha": ['ddsa'],
    "jalhaṇa": ['mw'],
    "jalhuḥ": ['ap90'],
    "jalikā": ['ap90', 'mw'],
    "jalita": ['cped'],
    "jalla": ['bhs', 'cped'],
    "jallakin": ['mw'],
    "jallāladīndra": ['mw'],
    "jalocchvāsa": ['mw'],
    "jalodara": ['cae', 'ddsa', 'mw'],
    "jalodbhava": ['cae', 'mw'],
    "jalodbhavā": ['mw'],
    "jalodbhūta": ['mw'],
    "jalodbhūtā": ['mw'],
    "jaloddhatagati": ['cae', 'mw'],
    "jalogi": ['cped'],
    "jaloka": ['ddsa', 'mw'],
    "jalokikā": ['ap90', 'mw'],
    "jalokā": ['ap90', 'mw'],
    "jalonnāda": ['mw'],
    "jalopala": ['mw'],
    "jaloragī": ['mw'],
    "jalp": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jalpa": ['bhs', 'cae', 'ddsa', 'mw'],
    "jalpaka": ['ap90', 'cae', 'mw'],
    "jalpakalpalatā": ['mw'],
    "jalpakalpataru": ['mw'],
    "jalpana": ['mw'],
    "jalpanaṃ": ['ap90'],
    "jalpaḥ": ['ap90'],
    "jalpeśvaramāhātmya": ['mw'],
    "jalpi": ['cae', 'gra', 'mw'],
    "jalpin": ['cae', 'mw'],
    "jalpita": ['ap90', 'cae', 'mw'],
    "jalpitṛ": ['mw'],
    "jalpiḥ": ['ap90'],
    "jalpya": ['cae', 'mw'],
    "jalpāka": ['cae', 'mw'],
    "jalukā": ['ap90', 'mw'],
    "jalā": ['bhs', 'mw'],
    "jalābhiṣeka": ['mw'],
    "jalābuja": ['cped'],
    "jalādarśa": ['mw'],
    "jalādhidaivata": ['mw'],
    "jalādhipa": ['mw'],
    "jalādhipati": ['mw'],
    "jalādhvan": ['mw'],
    "jalādhyakṣa": ['mw'],
    "jalādhāra": ['cae', 'mw'],
    "jalāgama": ['cae', 'mw'],
    "jalāgamā": ['bhs'],
    "jalāhara": ['bhs'],
    "jalāhati": ['ddsa', 'mw'],
    "jalāhvaya": ['mw'],
    "jalākara": ['mw'],
    "jalākhu": ['mw'],
    "jalākā": ['ap90'],
    "jalākāṅkṣa": ['mw'],
    "jalākṣī": ['mw'],
    "jalāladīnāhakavarasāha": ['mw'],
    "jalālokā": ['mw'],
    "jalālu": ['mw'],
    "jalāluhā": ['mw'],
    "jalāluka": ['mw'],
    "jalālukā": ['ap90'],
    "jalālūka": ['mw'],
    "jalāmatra": ['mw'],
    "jalāmbara": ['bhs', 'mw'],
    "jalāmbikā": ['mw'],
    "jalāmbugarbhā": ['bhs', 'mw'],
    "jalāmoda": ['mw'],
    "jalānila": ['mw'],
    "jalāntaka": ['mw'],
    "jalāntam": ['mw'],
    "jalānusāra": ['mw'],
    "jalāpasparśana": ['mw'],
    "jalārdra": ['cae', 'mw'],
    "jalārdrikā": ['mw'],
    "jalārdrā": ['mw'],
    "jalārka": ['mw'],
    "jalārthin": ['cae', 'ddsa', 'mw'],
    "jalārṇava": ['mw'],
    "jalāsah": ['mw'],
    "jalāsukā": ['mw'],
    "jalāsāha": ['mw'],
    "jalātmikā": ['mw'],
    "jalātyaya": ['mw'],
    "jalāvarta": ['mw'],
    "jalāvaseka": ['cae'],
    "jalāvatāra": ['mw'],
    "jalāvila": ['mw'],
    "jalāya": ['ddsa', 'mw'],
    "jalāyukā": ['cae', 'ddsa', 'mw'],
    "jalāñcala": ['mw'],
    "jalāñjali": ['cae', 'mw'],
    "jalāśaya": ['cae', 'mw'],
    "jalāśayapratiṣṭhā": ['mw'],
    "jalāśayotsargatattva": ['mw'],
    "jalāśayotsargavidhi": ['mw'],
    "jalāśayā": ['mw'],
    "jalāśayāntara": ['mw'],
    "jalāśraya": ['mw'],
    "jalāśrayā": ['mw'],
    "jalāḍhya": ['mw'],
    "jalāṃśu": ['ddsa', 'mw'],
    "jalāṇuka": ['mw'],
    "jalāṇḍaka": ['mw'],
    "jalāṇṭaka": ['mw'],
    "jalāṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jalāṣabheṣaja": ['cae', 'gra', 'mw'],
    "jalāṣah": ['mw'],
    "jalāṣṭhīlī": ['mw'],
    "jalāṭana": ['mw'],
    "jalāṭanī": ['mw'],
    "jalī": ['bhs'],
    "jalūka": ['bhs'],
    "jalūkā": ['ap90', 'mw'],
    "jalūkāvanaṣaṇḍa": ['bhs'],
    "jalūṣita": ['bhs'],
    "jal̤hu": ['mw'],
    "jam": ['ap90', 'mw'],
    "jamadagni": ['cae', 'ddsa', 'gra', 'mw'],
    "jamadagnidatta": ['gra', 'mw'],
    "jamadagnitīrtha": ['mw'],
    "jamadagniḥ": ['ap90'],
    "jamaja": ['mw'],
    "jamana": ['mw'],
    "jamanaṃ": ['ap90'],
    "jamat": ['mw'],
    "jamaśva": ['mw'],
    "jamba": ['mw'],
    "jambh": ['gra', 'mw'],
    "jambha": ['cae', 'ddsa', 'gra', 'mw'],
    "jambhabhedin": ['mw'],
    "jambhadviṣ": ['mw'],
    "jambhaga": ['mw'],
    "jambhaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "jambhakuṇḍa": ['mw'],
    "jambhakā": ['mw'],
    "jambhala": ['bhs', 'mw'],
    "jambhaladatta": ['mw'],
    "jambhalajalendra": ['bhs'],
    "jambhalikā": ['cae', 'ddsa', 'mw'],
    "jambhalā": ['mw'],
    "jambhan": ['mw'],
    "jambhana": ['cae', 'mw'],
    "jambhaniśumbhana": ['mw'],
    "jambhara": ['mw'],
    "jambhasuta": ['gra', 'mw'],
    "jambhaṃjambham": ['mw'],
    "jambhi": ['bhs'],
    "jambhikā": ['mw'],
    "jambhin": ['mw'],
    "jambhya": ['cae', 'mw'],
    "jambhā": ['mw'],
    "jambhāri": ['mw'],
    "jambhāribhujastambhana": ['mw'],
    "jambhārāti": ['mw'],
    "jambhī": ['mw'],
    "jambhīra": ['bhs', 'mw'],
    "jambhīranagara": ['mw'],
    "jambira": ['mw'],
    "jambonada": ['cped'],
    "jambu": ['cae', 'cped', 'ddsa', 'mw'],
    "jambucoraka": ['cped'],
    "jambudhvaja": ['bhs', 'mw'],
    "jambudvīpa": ['cae', 'ddsa', 'mw'],
    "jambudvīpaka": ['bhs'],
    "jambudvīpaprajñapti": ['mw'],
    "jambudvīpavaralocana": ['mw'],
    "jambudīpa": ['cped'],
    "jambudīpaka": ['cped'],
    "jambuka": ['cae', 'ddsa', 'mw'],
    "jambukeśa": ['mw'],
    "jambukeśvaratīrtha": ['mw'],
    "jambukā": ['mw'],
    "jambukāñcana": ['bhs'],
    "jambula": ['mw'],
    "jambumat": ['mw'],
    "jambumatī": ['mw'],
    "jambumālin": ['mw'],
    "jambuparvata": ['mw'],
    "jambuprastha": ['mw'],
    "jambupālaka": ['cped'],
    "jamburudra": ['mw'],
    "jambusara": ['mw'],
    "jambusaṇḍa": ['cped'],
    "jambuvanaja": ['mw'],
    "jambuḍa": ['bhs'],
    "jambuḍikā": ['bhs'],
    "jambvoṣṭha": ['mw'],
    "jambāla": ['cae', 'ddsa', 'mw'],
    "jambālinī": ['mw'],
    "jambālī": ['cped'],
    "jambīra": ['cae', 'mw'],
    "jambīraka": ['mw'],
    "jambīranagara": ['mw'],
    "jambū": ['cae', 'cped', 'mw'],
    "jambūchāyaka": ['bhs'],
    "jambūdvīpa": ['mw'],
    "jambūdvīpaka": ['bhs'],
    "jambūdvīpaprajñapti": ['mw'],
    "jambūdvīpaśīrṣa": ['bhs'],
    "jambūdvīpeśvara": ['mw'],
    "jambūka": ['cae', 'ddsa', 'mw'],
    "jambūkhaṇḍa": ['cae', 'mw'],
    "jambūkhaṇḍavinirmāṇaparvan": ['mw'],
    "jambūkuñja": ['ddsa'],
    "jambūkā": ['mw'],
    "jambūkāñcana": ['bhs'],
    "jambūkī": ['mw'],
    "jambūla": ['mw'],
    "jambūlamālikā": ['mw'],
    "jambūlikā": ['bhs'],
    "jambūmārga": ['mw'],
    "jambūnada": ['bhs', 'cped'],
    "jambūnadaprabhāsavatī": ['bhs'],
    "jambūnadī": ['mw'],
    "jambūprastha": ['mw'],
    "jambūsvāmin": ['mw'],
    "jamma": ['cped'],
    "jammana": ['cped'],
    "jampatī": ['bhs', 'mw'],
    "jampāna": ['mw'],
    "jamvaḥ": ['ap90'],
    "jamālin": ['mw'],
    "jamū": ['ap90'],
    "jan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jana": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "janabhakṣa": ['gra', 'mw'],
    "janabhṛt": ['mw'],
    "janabālikā": ['mw'],
    "janabāndhava": ['mw'],
    "janacakṣus": ['mw'],
    "janacandra": ['mw'],
    "janacaraṇāmalina": ['ddsa'],
    "janadeva": ['cae', 'mw'],
    "janadhā": ['mw'],
    "janadhāya": ['mw'],
    "janadhāyas": ['mw'],
    "janadvat": ['mw'],
    "janadāhasthāna": ['mw'],
    "janagat": ['mw'],
    "janagatya": ['mw'],
    "janaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "janakabhadra": ['mw'],
    "janakacandra": ['mw'],
    "janakakāṇa": ['ddsa', 'mw'],
    "janakalpa": ['mw'],
    "janakalpā": ['mw'],
    "janakanandinī": ['mw'],
    "janakarāja": ['mw'],
    "janakarī": ['mw'],
    "janakasaptarātra": ['mw'],
    "janakasiṃha": ['mw'],
    "janakasutā": ['cae', 'mw'],
    "janakatanayā": ['cae', 'mw'],
    "janakatva": ['mw'],
    "janakatā": ['mw'],
    "janakeśvaratīrtha": ['mw'],
    "janakāhvaya": ['mw'],
    "janakārin": ['mw'],
    "janakātmajā": ['cae', 'mw'],
    "janakāya": ['bhs', 'mw'],
    "janakīya": ['mw'],
    "janakṣetriya": ['bhs'],
    "janaloka": ['mw'],
    "janamaraka": ['cae', 'mw'],
    "janamejaya": ['cae', 'ddsa', 'mw'],
    "janamejayaḥ": ['ap90'],
    "janamohinī": ['mw'],
    "janamāna": ['mw'],
    "janamāra": ['cae', 'mw'],
    "janamāraṇa": ['mw'],
    "janamārī": ['mw'],
    "janana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "janani": ['cae', 'mw'],
    "jananiḥ": ['ap90'],
    "jananāntara": ['ddsa', 'mw'],
    "jananātha": ['ddsa', 'mw'],
    "jananī": ['ap90', 'bhs', 'mw'],
    "jananīya": ['bhs', 'mw'],
    "janapada": ['cae', 'cped', 'mw'],
    "janapadaghātaka": ['mw'],
    "janapadakalyāṇī": ['bhs', 'cped'],
    "janapadamahattara": ['mw'],
    "janapadamaṇḍala": ['mw'],
    "janapadanirutti": ['cped'],
    "janapadatthāvariya": ['cped'],
    "janapadatthāvariyapatta": ['cped'],
    "janapadatudana": ['cped'],
    "janapadeśvara": ['mw'],
    "janapadi": ['bhs'],
    "janapadin": ['mw'],
    "janapadoddhvaṃsanīya": ['mw'],
    "janapadādhipa": ['mw'],
    "janapadāyuta": ['mw'],
    "janapati": ['cae', 'ddsa', 'mw'],
    "janapravāda": ['cae', 'mw'],
    "janapriya": ['mw'],
    "janapriyaphalā": ['mw'],
    "janapālaka": ['mw'],
    "janapāna": ['gra', 'mw'],
    "janar": ['ap90', 'mw'],
    "janarava": ['cae', 'ddsa', 'mw'],
    "janarañjana": ['mw'],
    "janarañjanī": ['mw'],
    "janarloka": ['mw'],
    "janarāj": ['cae', 'mw'],
    "janarājan": ['cae', 'gra', 'mw'],
    "janas": ['cae', 'ddsa', 'gra', 'mw'],
    "janasambādha": ['mw'],
    "janasammarda": ['ddsa', 'mw'],
    "janasaṃkṣaya": ['mw'],
    "janasaṃmarda": ['cae'],
    "janasaṃsad": ['mw'],
    "janastha": ['mw'],
    "janasthāna": ['ap90', 'cae', 'mw'],
    "janasthānaruha": ['mw'],
    "janat": ['mw'],
    "janatraya": ['mw'],
    "janatrā": ['mw'],
    "janatā": ['ap90', 'cae', 'cped', 'mw'],
    "janau": ['mw'],
    "janaugha": ['mw'],
    "janava(t)": ['cped'],
    "janavallabha": ['mw'],
    "janavat": ['mw'],
    "janavati": ['cped', 'mw'],
    "janavid": ['mw'],
    "janavyavahāra": ['mw'],
    "janavāda": ['cae', 'mw'],
    "janavādin": ['mw'],
    "janayanta": ['mw'],
    "janayati": ['bhs', 'cped', 'mw'],
    "janayatiḥ": ['ap90'],
    "janayaṃta": ['ap90'],
    "janayetha": ['cped'],
    "janayi": ['cped'],
    "janayitavya": ['mw'],
    "janayitnu": ['mw'],
    "janayitrī": ['ap90', 'bhs', 'mw'],
    "janayittha": ['cped'],
    "janayitṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "janayiṣṇu": ['mw'],
    "janayiṣṇuḥ": ['ap90'],
    "janayopana": ['gra', 'mw'],
    "janaśruta": ['mw'],
    "janaśruti": ['mw'],
    "janaśrutā": ['mw'],
    "janaśrī": ['gra', 'mw'],
    "janaḥ": ['ap90'],
    "janaṃgama": ['mw'],
    "janaṃgamaḥ": ['ap90'],
    "janaṃgamā": ['mw'],
    "janaṃsaha": ['gra', 'mw'],
    "janaṃtapa": ['mw'],
    "janaṅgama": ['ddsa'],
    "janduraka": ['bhs', 'mw'],
    "jandāka": ['bhs'],
    "janendra": ['cae', 'ddsa', 'mw'],
    "janesi": ['cped'],
    "janeti": ['cped'],
    "janetrī": ['bhs'],
    "janettī": ['cped'],
    "janetukā": ['bhs'],
    "janetvā": ['cped'],
    "janevāda": ['mw'],
    "janeyya": ['cped'],
    "janeśa": ['cae', 'mw'],
    "janeśvara": ['cae', 'mw'],
    "janeṣṭa": ['mw'],
    "janeṣṭā": ['mw'],
    "janhu": ['ddsa'],
    "jani": ['cae', 'ddsa', 'gra', 'mw'],
    "jania": ['gra'],
    "janidhā": ['gra', 'mw'],
    "janidivasa": ['mw'],
    "janidā": ['gra', 'mw'],
    "janika": ['mw'],
    "janikartṛ": ['cae', 'ddsa', 'mw'],
    "janikā": ['mw'],
    "janikāma": ['mw'],
    "janiman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "janimant": ['cae'],
    "janimat": ['mw'],
    "janinda": ['cped'],
    "janinīlikā": ['mw'],
    "janipaddhati": ['mw'],
    "janita": ['ap90', 'cped', 'mw'],
    "janitasvana": ['mw'],
    "janitavya": ['mw'],
    "janitodyama": ['mw'],
    "janitos": ['ddsa'],
    "janitra": ['cae', 'ddsa', 'gra', 'mw'],
    "janitravatī": ['bhs'],
    "janitraṃ": ['ap90'],
    "janitrī": ['ap90', 'gra', 'mw'],
    "janitva": ['cae', 'ddsa', 'gra', 'mw'],
    "janitvana": ['gra', 'mw'],
    "janitvaḥ": ['ap90'],
    "janitvā": ['mw'],
    "janitā": ['bhs'],
    "janitṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "janivant": ['cae'],
    "janivat": ['gra', 'mw'],
    "janivid": ['mw'],
    "janiya": ['mw'],
    "janiḥ": ['ap90'],
    "janiṣya": ['cae', 'ddsa', 'mw'],
    "janiṣṭha": ['cae', 'mw'],
    "janma": ['mw'],
    "janmabandha": ['mw'],
    "janmabha": ['mw'],
    "janmabhāj": ['cae', 'mw'],
    "janmabhāṣā": ['mw'],
    "janmabhū": ['cae'],
    "janmabhūmi": ['cae', 'mw'],
    "janmabhūmibhūta": ['mw'],
    "janmabhūmika": ['bhs'],
    "janmabhṛt": ['mw'],
    "janmacintāmaṇi": ['mw'],
    "janmacitra": ['bhs', 'mw'],
    "janmacitraka": ['mw'],
    "janmada": ['cae', 'mw'],
    "janmadina": ['cae', 'mw'],
    "janmagṛha": ['mw'],
    "janmajanman": ['mw'],
    "janmajanmani": ['mw'],
    "janmajanmāntara": ['mw'],
    "janmajarāntaka": ['mw'],
    "janmajyeṣṭha": ['mw'],
    "janmajātaka": ['mw'],
    "janmaka": ['mw'],
    "janmakanātha": ['mw'],
    "janmakara": ['mw'],
    "janmakāla": ['cae', 'ddsa', 'mw'],
    "janmakīla": ['mw'],
    "janmakṛt": ['cae', 'mw'],
    "janmakṛta": ['mw'],
    "janmakṣetra": ['cae', 'mw'],
    "janmalagna": ['mw'],
    "janmalābha": ['cae'],
    "janmamṛtyu": ['cae', 'mw'],
    "janman": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "janmanakṣatra": ['mw'],
    "janmanideśa": ['bhs'],
    "janmanāman": ['mw'],
    "janmapa": ['mw'],
    "janmaparigraha": ['mw'],
    "janmapatha": ['mw'],
    "janmapattra": ['mw'],
    "janmapattrikā": ['mw'],
    "janmaprabhṛti": ['mw'],
    "janmaprada": ['mw'],
    "janmapradīpa": ['mw'],
    "janmapratiṣṭhā": ['cae', 'mw'],
    "janmapādapa": ['ddsa', 'mw'],
    "janmarkṣa": ['ddsa', 'mw'],
    "janmarogin": ['mw'],
    "janmarāśi": ['mw'],
    "janmarāśyadhipa": ['mw'],
    "janmasamudra": ['mw'],
    "janmasthāna": ['cae', 'mw'],
    "janmasāphalya": ['mw'],
    "janmatas": ['cae', 'mw'],
    "janmatithi": ['mw'],
    "janmatāra": ['mw'],
    "janmavailakṣaṇya": ['mw'],
    "janmavartman": ['mw'],
    "janmavasudhā": ['mw'],
    "janmavat": ['mw'],
    "janmavattā": ['mw'],
    "janmavaṃśa": ['mw'],
    "janmavātsalya": ['mw'],
    "janmayoga": ['mw'],
    "janmaśayyā": ['mw'],
    "janmaśodhana": ['mw'],
    "janmaṃ": ['ap90'],
    "janmejaya": ['mw'],
    "janmeśa": ['mw'],
    "janmika": ['bhs'],
    "janmin": ['ap90', 'cae', 'ddsa', 'mw'],
    "janmodayarkṣa": ['mw'],
    "janmādhipa": ['mw'],
    "janmāndha": ['mw'],
    "janmāndhatva": ['mw'],
    "janmāntakara": ['mw'],
    "janmāntara": ['cae', 'ddsa', 'mw'],
    "janmāntaragata": ['cae', 'mw'],
    "janmāntarita": ['mw'],
    "janmāntarīya": ['mw'],
    "janmāntarīṇa": ['mw'],
    "janmāspada": ['cae', 'mw'],
    "janmāṣṭamī": ['mw'],
    "janmāṣṭamīnirṇaya": ['mw'],
    "janmāṣṭamītattva": ['mw'],
    "janmāṣṭamīvrata": ['mw'],
    "jannu": ['cped'],
    "jannuka": ['cped'],
    "jano": ['mw'],
    "janodāharaṇa": ['mw'],
    "janoloka": ['mw'],
    "janta": ['bhs'],
    "jantagga": ['cped'],
    "jantita": ['bhs'],
    "jantra": ['bhs'],
    "jantu": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jantughna": ['mw'],
    "jantughnī": ['mw'],
    "jantugṛha": ['mw'],
    "jantuhantrī": ['mw'],
    "jantujātamaya": ['mw'],
    "jantuka": ['mw'],
    "jantukambu": ['mw'],
    "jantukarṇa": ['bhs'],
    "jantukā": ['mw'],
    "jantukārī": ['mw'],
    "jantulā": ['mw'],
    "jantumat": ['mw'],
    "jantumārin": ['mw'],
    "jantumātṛ": ['mw'],
    "jantunāśana": ['mw'],
    "jantuphala": ['mw'],
    "jantupādapa": ['mw'],
    "janturasa": ['mw'],
    "jantva": ['cae', 'gra', 'mw'],
    "jantāghara": ['cped'],
    "jantāka": ['bhs'],
    "janu": ['ap90', 'mw'],
    "janus": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "januḥpaddhati": ['mw'],
    "januṣā": ['mw'],
    "januṣāndha": ['mw'],
    "janya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "janyatva": ['mw'],
    "janyatā": ['mw'],
    "janyavṛtti": ['mw'],
    "janyayātrā": ['cae', 'mw'],
    "janyu": ['mw'],
    "janyuḥ": ['ap90', 'ddsa'],
    "janyā": ['mw'],
    "janyīya": ['mw'],
    "janā": ['ddsa', 'mw'],
    "janācāra": ['mw'],
    "janādhinātha": ['mw'],
    "janādhipa": ['cae', 'cped', 'mw'],
    "janākīrṇa": ['mw'],
    "janālaya": ['mw'],
    "janānta": ['mw'],
    "janāntara": ['cae'],
    "janāntika": ['mw'],
    "janāntikam": ['cae', 'mw'],
    "janāntike": ['mw'],
    "janāpavāda": ['cae', 'mw'],
    "janārava": ['cae', 'mw'],
    "janārdana": ['bhs', 'cae', 'mw'],
    "janārdanavibudha": ['mw'],
    "janārthaśabda": ['mw'],
    "janārṇava": ['cae', 'mw'],
    "janātiga": ['ddsa', 'mw'],
    "janāv": ['mw'],
    "janāyana": ['mw'],
    "janāśana": ['mw'],
    "janāśraya": ['mw'],
    "janāṣah": ['gra', 'mw'],
    "janī": ['cae', 'cped', 'gra', 'mw'],
    "janīmāta(r)": ['cped'],
    "janīna": ['mw'],
    "janīpita(r)": ['cped'],
    "janīsuta": ['bhs'],
    "janīy": ['gra'],
    "janīya": ['mw'],
    "janīyati": ['ap90'],
    "janū": ['mw'],
    "janūrvāsas": ['mw'],
    "jap": ['ap90', 'cae', 'ddsa', 'mw'],
    "japa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "japahoma": ['cae', 'mw'],
    "japamālā": ['cae', 'ddsa', 'mw'],
    "japana": ['cae', 'ddsa', 'mw'],
    "japanaṃ": ['ap90'],
    "japanīya": ['mw'],
    "japaparāyaṇa": ['mw'],
    "japati": ['cped'],
    "japatā": ['mw'],
    "japayajña": ['cae', 'mw'],
    "japeti": ['cped'],
    "japila": ['mw'],
    "japin": ['cae', 'ddsa', 'mw'],
    "japita": ['mw'],
    "jappa": ['cped'],
    "jappa(t)": ['cped'],
    "jappanā": ['cped'],
    "jappati": ['cped'],
    "jappeti": ['cped'],
    "jappita": ['cped'],
    "jappāyanā": ['cped'],
    "japta": ['mw'],
    "japtavya": ['mw'],
    "japya": ['ap90', 'cae', 'ddsa', 'mw'],
    "japyaka": ['ddsa', 'mw'],
    "japyakarman": ['mw'],
    "japyeśvaratīrtha": ['mw'],
    "japā": ['ap90', 'cae', 'ddsa', 'mw'],
    "japākhyā": ['mw'],
    "japākusumasaṃnibha": ['mw'],
    "japāpīḍa": ['cae', 'mw'],
    "jar": ['cae', 'gra'],
    "jara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jara(s)": ['cped'],
    "jara(t)": ['cped'],
    "jarad": ['mw'],
    "jaradaṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "jaraddāsa": ['mw'],
    "jaradgava": ['cae', 'ddsa', 'mw'],
    "jaradgavavīthi": ['mw'],
    "jaradgavī": ['mw'],
    "jaradviṣ": ['gra', 'mw'],
    "jaradvṛkṣa": ['mw'],
    "jaradyoṣit": ['cae'],
    "jaradyoṣā": ['mw'],
    "jaraggava": ['cped'],
    "jaraka": ['mw'],
    "jaramāṇa": ['mw'],
    "jarant": ['cae'],
    "jaranta": ['mw'],
    "jarantaka": ['mw'],
    "jaras": ['cae', 'ddsa', 'gra', 'mw'],
    "jarasa": ['mw'],
    "jarasakata": ['cped'],
    "jarasigāla": ['cped'],
    "jarasiṅgala": ['cped'],
    "jarasālā": ['cped'],
    "jarasāna": ['mw'],
    "jarat": ['ap90', 'ddsa', 'mw'],
    "jarataḥ": ['ap90'],
    "jaratikā": ['ap90', 'ddsa', 'mw'],
    "jaratin": ['mw'],
    "jaratkakṣa": ['mw'],
    "jaratkarṇa": ['mw'],
    "jaratkāra": ['mw'],
    "jaratkāru": ['cae', 'ddsa', 'mw'],
    "jaratkārupriyā": ['cae', 'mw'],
    "jaratkārvāśrama": ['mw'],
    "jaratpittaśūla": ['mw'],
    "jarayitṛ": ['mw'],
    "jarayu": ['gra', 'mw'],
    "jaraḍī": ['mw'],
    "jaraṃḍa": ['ap90'],
    "jaraṇa": ['ap90', 'cae', 'gra', 'mw'],
    "jaraṇadruma": ['mw'],
    "jaraṇiprā": ['gra', 'mw'],
    "jaraṇyu": ['cae', 'gra', 'mw'],
    "jaraṇyā": ['ap90', 'cae', 'gra', 'mw'],
    "jaraṇā": ['gra', 'mw'],
    "jaraṇḍa": ['mw'],
    "jaraṭha": ['ap90', 'cae', 'mw'],
    "jaraṭhita": ['mw'],
    "jaraṭī": ['mw'],
    "jarbhari": ['cae', 'gra', 'mw'],
    "jarbhur": ['cae', 'ddsa'],
    "jarbhurat": ['mw'],
    "jarc": ['ap90', 'mw'],
    "jarch": ['mw'],
    "jarhila": ['mw'],
    "jarhilaḥ": ['ap90'],
    "jariman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jarin": ['ap90', 'mw'],
    "jarita": ['ap90', 'mw'],
    "jaritā": ['cae', 'ddsa', 'mw'],
    "jaritāri": ['cae', 'mw'],
    "jaritṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "jariṣṇu": ['mw'],
    "jarj": ['mw'],
    "jarjalpa": ['mw'],
    "jarjara": ['ap90', 'cae', 'ddsa', 'mw'],
    "jarjaraka": ['mw'],
    "jarjarapūjā": ['mw'],
    "jarjaratva": ['mw'],
    "jarjarita": ['ap90', 'cae', 'ddsa', 'mw'],
    "jarjarā": ['mw'],
    "jarjarānanā": ['mw'],
    "jarjarī": ['mw'],
    "jarjarībhūta": ['mw'],
    "jarjarīka": ['ap90', 'mw'],
    "jarjarīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "jarjarīkṛta": ['mw'],
    "jarjh": ['ap90', 'mw'],
    "jarodapāna": ['bhs'],
    "jarta": ['mw'],
    "jartika": ['mw'],
    "jartila": ['mw'],
    "jartilayavāgū": ['mw'],
    "jartilaḥ": ['ap90'],
    "jarts": ['ap90', 'mw'],
    "jartu": ['mw'],
    "jartuḥ": ['ap90'],
    "jarudapana": ['cped'],
    "jarvara": ['mw'],
    "jarya": ['mw'],
    "jarā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jarābhibhūta": ['mw'],
    "jarābhīru": ['mw'],
    "jarābhīta": ['mw'],
    "jarābodha": ['gra', 'mw'],
    "jarābodhīya": ['mw'],
    "jarādhamma": ['cped'],
    "jarādharma": ['mw'],
    "jarāghara": ['cped'],
    "jarājarjara": ['cae'],
    "jarākāsa": ['mw'],
    "jarālakṣman": ['mw'],
    "jarāmaraṇasaṅghāta": ['cped'],
    "jarāmṛtyu": ['mw'],
    "jarānvita": ['mw'],
    "jarāpariṇata": ['mw'],
    "jarāprajñāyate": ['bhs'],
    "jarāpuṣṭa": ['mw'],
    "jarāsaṃdha": ['cae', 'mw'],
    "jarāsaṃdhajit": ['mw'],
    "jarāsaṃdhapura": ['mw'],
    "jarātura": ['mw'],
    "jarāvant": ['cae'],
    "jarāvasthā": ['mw'],
    "jarāvat": ['ddsa', 'mw'],
    "jarāyaṇi": ['mw'],
    "jarāyaṇiḥ": ['ap90'],
    "jarāyu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jarāyudha": ['mw'],
    "jarāyuja": ['cae', 'mw'],
    "jarāyuka": ['mw'],
    "jarūdapāna": ['cped'],
    "jarūtha": ['ap90', 'gra', 'mw'],
    "jarṇa": ['ap90', 'mw'],
    "jarṇu": ['mw'],
    "jas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jasada": ['mw'],
    "jasmarāja": ['ddsa'],
    "jasra": ['cae', 'gra', 'mw'],
    "jasraṃ": ['ap90'],
    "jassarāja": ['mw'],
    "jasu": ['cae', 'ddsa', 'gra', 'mw'],
    "jasuri": ['ap90', 'cae', 'gra', 'mw'],
    "jasuḥ": ['ap90'],
    "jasvan": ['cae', 'gra', 'mw'],
    "jatru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jatruka": ['mw'],
    "jatu": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "jatudhāman": ['mw'],
    "jatugeha": ['cae', 'mw'],
    "jatugṛha": ['cae', 'mw'],
    "jatugṛhaparvan": ['mw'],
    "jatuka": ['mw'],
    "jatukaṃ": ['ap90'],
    "jatukaṇṇin": ['cped'],
    "jatukā": ['ap90', 'mw'],
    "jatukārī": ['mw'],
    "jatukṛt": ['mw'],
    "jatukṛṣṇā": ['mw'],
    "jatumaya": ['mw'],
    "jatumayasaraṇa": ['mw'],
    "jatumaṇi": ['mw'],
    "jatumaṭṭhaka": ['cped'],
    "jatumudrā": ['cae'],
    "jatumukha": ['mw'],
    "jatumāsaka": ['cped'],
    "jatunī": ['ap90', 'mw'],
    "jatuputraka": ['mw'],
    "jaturaka": ['mw'],
    "jaturasa": ['mw'],
    "jatuveśman": ['mw'],
    "jatuyantra": ['bhs'],
    "jatvaśmaka": ['mw'],
    "jatya": ['bhs'],
    "jatū": ['cae', 'ddsa', 'mw'],
    "jatūkarṇa": ['mw'],
    "jatūkā": ['mw'],
    "jatṛṇa": ['mw'],
    "jauhava": ['mw'],
    "jauhotyādika": ['mw'],
    "jaulāyanabhakta": ['mw'],
    "jaumara": ['mw'],
    "java": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "javana": ['ap90', 'cae', 'cped', 'gra', 'mw'],
    "javanapañña": ['cped'],
    "javanikā": ['ap90', 'cae', 'mw'],
    "javanikāntara": ['mw'],
    "javaniman": ['ap90', 'mw'],
    "javanāla": ['mw'],
    "javanī": ['mw'],
    "javas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "javasa": ['mw'],
    "javasaḥ": ['ap90'],
    "javavat": ['mw'],
    "javayukta": ['mw'],
    "javin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "javina": ['ap90', 'bhs', 'mw'],
    "javita": ['bhs', 'mw'],
    "javiṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "javā": ['ap90', 'cae', 'ddsa', 'mw'],
    "javādhika": ['ddsa', 'mw'],
    "javādi": ['mw'],
    "javāgraja": ['mw'],
    "javāla": ['mw'],
    "javānila": ['mw'],
    "javāpuṣpa": ['mw'],
    "javāt": ['mw'],
    "javīyas": ['gra', 'mw'],
    "javīyaṃs": ['cae'],
    "jaya": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jaya(t)": ['cped'],
    "jayabhaṭa": ['mw'],
    "jayabherī": ['mw'],
    "jayabāhu": ['mw'],
    "jayacandra": ['mw'],
    "jayacaryā": ['mw'],
    "jayad": ['mw'],
    "jayada": ['cae', 'ddsa', 'mw'],
    "jayadatta": ['bhs', 'mw'],
    "jayadbala": ['mw'],
    "jayadeva": ['ap90', 'cae', 'mw'],
    "jayadevaka": ['mw'],
    "jayadhara": ['mw'],
    "jayadharman": ['mw'],
    "jayadhvaja": ['cae', 'ddsa', 'mw'],
    "jayadhvajāya": ['ddsa', 'mw'],
    "jayadhvani": ['mw'],
    "jayadratha": ['cae', 'ddsa', 'mw'],
    "jayadrathaḥ": ['ap90'],
    "jayadruma": ['mw'],
    "jayadurgā": ['mw'],
    "jayadvalaḥ": ['ap90'],
    "jayadā": ['mw'],
    "jayagarva": ['mw'],
    "jayagata": ['mw'],
    "jayaghaṇṭā": ['mw'],
    "jayaghoṣa": ['cae', 'mw'],
    "jayaghoṣaṇa": ['mw'],
    "jayaghoṣaṇā": ['mw'],
    "jayaghoṣā": ['mw'],
    "jayagovinda": ['mw'],
    "jayagupta": ['mw'],
    "jayaiṣin": ['cae'],
    "jayaka": ['ap90', 'ddsa', 'mw'],
    "jayakarṇa": ['mw'],
    "jayakeśi": ['mw'],
    "jayakolāhala": ['mw'],
    "jayakuñjara": ['cae', 'mw'],
    "jayakārikā": ['mw'],
    "jayakārin": ['mw'],
    "jayakāṅkṣin": ['mw'],
    "jayakīrti": ['mw'],
    "jayakṛt": ['cae', 'mw'],
    "jayakṛṣṇa": ['mw'],
    "jayakṣetra": ['mw'],
    "jayalakṣmaṇa": ['mw'],
    "jayalakṣmī": ['cae', 'mw'],
    "jayalekha": ['mw'],
    "jayamalla": ['mw'],
    "jayamati": ['bhs', 'mw'],
    "jayamatī": ['mw'],
    "jayamaṅgala": ['mw'],
    "jayamitra": ['bhs'],
    "jayampati": ['cped'],
    "jayampatika": ['cped'],
    "jayamādhava": ['mw'],
    "jayana": ['ddsa', 'mw'],
    "jayanayuj": ['mw'],
    "jayanaṃ": ['ap90'],
    "jayanta": ['bhs', 'cae', 'ddsa', 'mw'],
    "jayantadeva": ['bhs'],
    "jayantasvāmin": ['mw'],
    "jayantī": ['bhs', 'mw'],
    "jayantīpura": ['mw'],
    "jayantīsaptamī": ['mw'],
    "jayanāman": ['mw'],
    "jayanārāyaṇa": ['mw'],
    "jayanī": ['mw'],
    "jayanīrājana": ['mw'],
    "jayanṛsiṃha": ['mw'],
    "jayaparājaya": ['cae', 'mw'],
    "jayapattra": ['mw'],
    "jayapatākā": ['bhs', 'cae', 'ddsa', 'mw'],
    "jayaprabha": ['bhs'],
    "jayaprasthāna": ['mw'],
    "jayaprepsu": ['cae'],
    "jayapriya": ['mw'],
    "jayapriyā": ['mw'],
    "jayapura": ['mw'],
    "jayaputraka": ['mw'],
    "jayapāla": ['mw'],
    "jayaratha": ['mw'],
    "jayarāja": ['mw'],
    "jayarāma": ['mw'],
    "jayarāta": ['mw'],
    "jayasena": ['cae', 'mw'],
    "jayasenā": ['mw'],
    "jayasiṃha": ['mw'],
    "jayasiṃhadeva": ['mw'],
    "jayaskandha": ['mw'],
    "jayastambha": ['mw'],
    "jayasthala": ['mw'],
    "jayasvāmin": ['mw'],
    "jayasvāmipura": ['mw'],
    "jayasvāmivirocana": ['mw'],
    "jayasīla": ['mw'],
    "jayat": ['mw'],
    "jayati": ['ddsa', 'mw'],
    "jayatsena": ['mw'],
    "jayatsenaḥ": ['ap90'],
    "jayatsenā": ['mw'],
    "jayatuṅga": ['mw'],
    "jayatuṅgodaya": ['mw'],
    "jayatīrtha": ['mw'],
    "jayatīrthabhikṣu": ['mw'],
    "jayatīrthayati": ['mw'],
    "jayavaha": ['mw'],
    "jayavana": ['mw'],
    "jayavardhana": ['mw'],
    "jayavarmadeva": ['mw'],
    "jayavarman": ['cae', 'mw'],
    "jayavat": ['mw'],
    "jayavatī": ['mw'],
    "jayavilāsa": ['mw'],
    "jayavādya": ['mw'],
    "jayavāhana": ['mw'],
    "jayavāhinī": ['mw'],
    "jayavārāhatīrtha": ['mw'],
    "jayayajña": ['mw'],
    "jayaśabda": ['cae', 'mw'],
    "jayaśarman": ['mw'],
    "jayaśaṅkha": ['mw'],
    "jayaśekhara": ['mw'],
    "jayaśekharā": ['mw'],
    "jayaśrī": ['bhs', 'cae', 'mw'],
    "jayaśṛṅga": ['mw'],
    "jayaḍhakkā": ['mw'],
    "jayaḥ": ['ap90'],
    "jayaṃgama": ['bhs'],
    "jayaṃtaḥ": ['ap90'],
    "jayendra": ['cae', 'ddsa', 'mw'],
    "jayendrasenā": ['mw'],
    "jayendravihāra": ['mw'],
    "jayeśvara": ['cae', 'mw'],
    "jayin": ['ap90', 'cae', 'mw'],
    "jayitṛ": ['cae', 'mw'],
    "jayiṣṇu": ['cae', 'mw'],
    "jayoddhura": ['mw'],
    "jayodāharaṇa": ['mw'],
    "jayollāsanidhi": ['mw'],
    "jayottama": ['bhs'],
    "jayottara": ['cae', 'ddsa', 'mw'],
    "jayoṣmāyatana": ['bhs'],
    "jayoṣmāyatanavimokṣa": ['bhs'],
    "jayoṣṇīṣa": ['bhs'],
    "jayus": ['cae', 'gra', 'mw'],
    "jayya": ['ap90', 'cae', 'ddsa', 'mw'],
    "jayā": ['bhs', 'mw'],
    "jayābhaṭṭārikā": ['ddsa', 'mw'],
    "jayādevī": ['ddsa', 'mw'],
    "jayāditya": ['cae', 'mw'],
    "jayāhvā": ['mw'],
    "jayājaya": ['cae', 'mw'],
    "jayākara": ['ddsa', 'mw'],
    "jayānanda": ['ddsa', 'mw'],
    "jayānandavāra": ['mw'],
    "jayāntarāya": ['mw'],
    "jayānīka": ['mw'],
    "jayāpīḍa": ['mw'],
    "jayārava": ['mw'],
    "jayārṇava": ['mw'],
    "jayāsiṃha": ['mw'],
    "jayātmaja": ['mw'],
    "jayāvaghoṣa": ['ddsa', 'mw'],
    "jayāvaha": ['mw'],
    "jayāvahā": ['mw'],
    "jayāvatī": ['mw'],
    "jayāyya": ['mw'],
    "jayāśis": ['cae', 'mw'],
    "jayāśrayā": ['mw'],
    "jayāśva": ['mw'],
    "jayḷtṛ": ['ddsa'],
    "jañj": ['cae', 'gra', 'mw'],
    "jañja": ['mw'],
    "jañjapūka": ['ddsa', 'mw'],
    "jañjaṇā": ['cae'],
    "jañjaṇābhavat": ['gra', 'mw'],
    "jaññajañña": ['cped'],
    "jaññā": ['cped'],
    "jaśas": ['mw'],
    "jaḍa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "jaḍabharata": ['mw'],
    "jaḍabhāva": ['mw'],
    "jaḍabuddhi": ['cae', 'mw'],
    "jaḍadhī": ['mw'],
    "jaḍakriya": ['mw'],
    "jaḍamati": ['cae', 'mw'],
    "jaḍamūka": ['mw'],
    "jaḍaprakṛti": ['cae', 'mw'],
    "jaḍatva": ['mw'],
    "jaḍatā": ['ap90', 'ddsa', 'mw'],
    "jaḍavipra": ['mw'],
    "jaḍay": ['cae'],
    "jaḍaya": ['ddsa', 'mw'],
    "jaḍayati": ['ap90'],
    "jaḍhu": ['gra'],
    "jaḍiman": ['ap90', 'cae', 'ddsa', 'mw'],
    "jaḍita": ['mw'],
    "jaḍula": ['mw'],
    "jaḍulaḥ": ['ap90'],
    "jaḍuvāra": ['bhs'],
    "jaḍā": ['mw'],
    "jaḍātmaka": ['cae', 'mw'],
    "jaḍātman": ['cae', 'mw'],
    "jaḍāy": ['cae'],
    "jaḍāya": ['ddsa', 'mw'],
    "jaḍāśaya": ['ddsa', 'mw'],
    "jaḍāṃśu": ['cae', 'ddsa', 'mw'],
    "jaḍī": ['mw'],
    "jaḍībhāva": ['cae', 'mw'],
    "jaḍībhāvaḥ": ['ap90'],
    "jaḍībhū": ['ap90'],
    "jaḍībhūta": ['mw'],
    "jaḍīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "jaḍīkṛta": ['mw'],
    "jaḷa": ['cped'],
    "jaḷogi": ['cped'],
    "jaṃbhaka": ['ap90'],
    "jaṃbhakā": ['ap90'],
    "jaṃbhalaḥ": ['ap90'],
    "jaṃbhanaṃ": ['ap90'],
    "jaṃbharaḥ": ['ap90'],
    "jaṃbhaḥ": ['ap90'],
    "jaṃbhin": ['ap90'],
    "jaṃbhīraḥ": ['ap90'],
    "jaṃbu": ['ap90'],
    "jaṃbukaḥ": ['ap90'],
    "jaṃbulaḥ": ['ap90'],
    "jaṃbālaḥ": ['ap90'],
    "jaṃbālinī": ['ap90'],
    "jaṃbīraḥ": ['ap90'],
    "jaṃbūkaḥ": ['ap90'],
    "jaṃbūmat": ['ap90'],
    "jaṃgala": ['ap90'],
    "jaṃgama": ['ap90'],
    "jaṃghila": ['ap90'],
    "jaṃghā": ['ap90'],
    "jaṃghāla": ['ap90'],
    "jaṃgulaṃ": ['ap90'],
    "jaṃgālaḥ": ['ap90'],
    "jaṃh": ['ddsa', 'mw'],
    "jaṃhas": ['cae', 'ddsa', 'gra', 'mw'],
    "jaṃjana": ['ap90'],
    "jaṃjapūka": ['ap90'],
    "jaṃpatī": ['ap90'],
    "jaṃs": ['ap90', 'mw'],
    "jaṃtukā": ['ap90'],
    "jaṃtumatī": ['ap90'],
    "jaṃtuḥ": ['ap90'],
    "jaṅga": ['cae', 'ddsa', 'mw'],
    "jaṅgahe": ['gra'],
    "jaṅgala": ['bhs', 'cped', 'ddsa', 'mw'],
    "jaṅgalapatha": ['mw'],
    "jaṅgama": ['cae', 'cped', 'ddsa', 'mw'],
    "jaṅgamakuṭī": ['mw'],
    "jaṅgamana": ['mw'],
    "jaṅgamatva": ['mw'],
    "jaṅgametara": ['mw'],
    "jaṅgamā": ['bhs'],
    "jaṅgapūga": ['mw'],
    "jaṅgha": ['mw'],
    "jaṅghapesanika": ['cped'],
    "jaṅghapesaniya": ['cped'],
    "jaṅgheratha": ['mw'],
    "jaṅgheyyaka": ['cped'],
    "jaṅghikā": ['mw'],
    "jaṅghila": ['mw'],
    "jaṅghā": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jaṅghābala": ['cae', 'mw'],
    "jaṅghābandhu": ['mw'],
    "jaṅghājaghanya": ['mw'],
    "jaṅghākara": ['mw'],
    "jaṅghākarika": ['ddsa', 'mw'],
    "jaṅghākārika": ['mw'],
    "jaṅghākāśyapa": ['bhs'],
    "jaṅghāla": ['cae', 'ddsa', 'mw'],
    "jaṅghālatva": ['mw'],
    "jaṅghāmātra": ['mw'],
    "jaṅghānalaka": ['cae', 'mw'],
    "jaṅghāpiṇḍī": ['mw'],
    "jaṅghāprahata": ['mw'],
    "jaṅghāprahṛta": ['mw'],
    "jaṅghāpreṣaṇa": ['bhs'],
    "jaṅghāratha": ['mw'],
    "jaṅghāri": ['mw'],
    "jaṅghātrāṇa": ['mw'],
    "jaṅghāvihāra": ['bhs', 'cped', 'mw'],
    "jaṅgiḍa": ['cae', 'mw'],
    "jaṅgula": ['mw'],
    "jaṅgāla": ['mw'],
    "jaṅgāri": ['mw'],
    "jaṅkṣ": ['mw'],
    "jaṇṇu": ['cped'],
    "jaṇṇuka": ['cped'],
    "jaṣ": ['ap90', 'mw'],
    "jaṣa": ['cae', 'ddsa', 'mw'],
    "jaṭ": ['ap90', 'mw'],
    "jaṭa": ['ap90', 'mw'],
    "jaṭadharana": ['cped'],
    "jaṭamalla": ['mw'],
    "jaṭamissa": ['cped'],
    "jaṭaṇduva": ['cped'],
    "jaṭeśvaratīrtha": ['mw'],
    "jaṭhala": ['gra', 'mw'],
    "jaṭhalaṃ": ['ap90'],
    "jaṭhara": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "jaṭharagada": ['mw'],
    "jaṭharajvalana": ['mw'],
    "jaṭharajvālā": ['mw'],
    "jaṭharanud": ['mw'],
    "jaṭhararoga": ['mw'],
    "jaṭharastha": ['mw'],
    "jaṭharasthita": ['mw'],
    "jaṭharasthāyin": ['mw'],
    "jaṭharatva": ['mw'],
    "jaṭharavyathā": ['mw'],
    "jaṭharayantraṇā": ['mw'],
    "jaṭhareṇa": ['mw'],
    "jaṭharin": ['mw'],
    "jaṭharotsava": ['mw'],
    "jaṭharāgni": ['mw'],
    "jaṭharāmaya": ['mw'],
    "jaṭharīkṛta": ['ap90', 'mw'],
    "jaṭi": ['mw'],
    "jaṭi(n)": ['cped'],
    "jaṭika": ['mw'],
    "jaṭikāyana": ['mw'],
    "jaṭila": ['ap90', 'cae', 'cped', 'mw'],
    "jaṭilaka": ['cped', 'mw'],
    "jaṭilasthala": ['mw'],
    "jaṭilaya": ['mw'],
    "jaṭilikā": ['bhs', 'mw'],
    "jaṭilā": ['mw'],
    "jaṭilī": ['mw'],
    "jaṭilībhāva": ['mw'],
    "jaṭilībhāvaḥ": ['ap90'],
    "jaṭilīkṛ": ['ap90', 'ddsa', 'mw'],
    "jaṭin": ['ap90', 'cae', 'ddsa', 'mw'],
    "jaṭita": ['cped'],
    "jaṭiḥ": ['ap90'],
    "jaṭiṃdhara": ['bhs'],
    "jaṭoccha": ['mw'],
    "jaṭula": ['mw'],
    "jaṭulaḥ": ['ap90'],
    "jaṭā": ['cae', 'cped', 'ddsa', 'mw'],
    "jaṭābandha": ['mw'],
    "jaṭābhāra": ['cae', 'mw'],
    "jaṭābhāradhara": ['cae'],
    "jaṭācīra": ['mw'],
    "jaṭācīradhara": ['cae'],
    "jaṭādhara": ['cae', 'mw'],
    "jaṭādharī": ['mw'],
    "jaṭādhārin": ['cae', 'mw'],
    "jaṭādhāriśaivamata": ['mw'],
    "jaṭājhāṭa": ['mw'],
    "jaṭājinin": ['mw'],
    "jaṭājvāla": ['mw'],
    "jaṭājāla": ['mw'],
    "jaṭājūṭa": ['cae', 'mw'],
    "jaṭākalāpa": ['cae', 'mw'],
    "jaṭākara": ['mw'],
    "jaṭākaraṇakarman": ['bhs'],
    "jaṭāla": ['ap90', 'cae', 'ddsa', 'mw'],
    "jaṭālaka": ['ap90', 'mw'],
    "jaṭālikā": ['mw'],
    "jaṭāmaṇḍala": ['cae', 'mw'],
    "jaṭāmālin": ['mw'],
    "jaṭāmāṃsī": ['mw'],
    "jaṭāmūlā": ['mw'],
    "jaṭāntā": ['mw'],
    "jaṭāpaṭala": ['mw'],
    "jaṭāpura": ['bhs'],
    "jaṭāpāṭha": ['mw'],
    "jaṭāsura": ['mw'],
    "jaṭātaṅka": ['mw'],
    "jaṭāvalkalin": ['ddsa', 'mw'],
    "jaṭāvallī": ['mw'],
    "jaṭāvarman": ['mw'],
    "jaṭāvat": ['mw'],
    "jaṭāvatī": ['mw'],
    "jaṭāyu": ['cae', 'ddsa', 'mw'],
    "jaṭāyus": ['cae', 'mw'],
    "jaṭāyuḥ": ['ap90'],
    "jaṭāśaṃkara": ['mw'],
    "jaṭāṭīra": ['mw'],
    "jaṭī": ['ap90', 'mw'],
    "je": ['cped'],
    "jeguccha": ['cped'],
    "jegucchi": ['cped'],
    "jegucchi(n)": ['cped'],
    "jegucchiya": ['cped'],
    "jeh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jehila": ['mw'],
    "jehrīyate": ['bhs'],
    "jejjaṭa": ['mw'],
    "jelaka": ['ddsa', 'mw'],
    "jeman": ['cae', 'gra', 'mw'],
    "jemana": ['cae', 'mw'],
    "jemanaka": ['mw'],
    "jemanaṃ": ['ap90'],
    "jen": ['bhs'],
    "jenia": ['gra'],
    "jeniāvasu": ['gra'],
    "jenta": ['bhs'],
    "jentāka": ['mw'],
    "jentī": ['bhs'],
    "jenya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jenyāvasu": ['mw'],
    "jesa": ['gra'],
    "jeta": ['mw'],
    "jeta(r)": ['cped'],
    "jetabba": ['cped'],
    "jetasāhvaya": ['mw'],
    "jetavana": ['bhs', 'ddsa', 'mw'],
    "jetavanīya": ['bhs', 'mw'],
    "jetavya": ['cae', 'ddsa', 'mw'],
    "jeti": ['cped'],
    "jetukāma": ['mw'],
    "jetuṁ": ['cped'],
    "jetva": ['cae', 'gra', 'mw'],
    "jetvā": ['cped'],
    "jetvāna": ['cped'],
    "jetṛ": ['ap90', 'cae', 'gra', 'mw'],
    "jevanika": ['cped'],
    "jevanīya": ['cped'],
    "jeya": ['cae', 'mw'],
    "jeyya": ['cped'],
    "jeṃtākaḥ": ['ap90'],
    "jeṣ": ['ap90', 'mw'],
    "jeṣa": ['cae', 'mw'],
    "jeṣṭha": ['bhs'],
    "jeṭṭha": ['cped'],
    "jeṭṭhāpacāyi(n)": ['cped'],
    "jeṭṭhāpacāyitā": ['cped'],
    "jha": ['ap90', 'mw'],
    "jhagajhagāya": ['mw'],
    "jhagajhagāyate": ['ap90'],
    "jhagati": ['ap90'],
    "jhagiti": ['ap90', 'mw'],
    "jhakāra": ['mw'],
    "jhalajjhalā": ['ap90', 'ddsa', 'mw'],
    "jhalakkā": ['mw'],
    "jhalarī": ['mw'],
    "jhali": ['mw'],
    "jhaliḥ": ['ap90'],
    "jhalla": ['cae', 'ddsa', 'mw'],
    "jhallaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "jhallakaṃ": ['ap90'],
    "jhallakaṃṭhaḥ": ['ap90'],
    "jhallakaṇṭha": ['mw'],
    "jhallakī": ['mw'],
    "jhallanā": ['mw'],
    "jhallarā": ['ap90'],
    "jhallarī": ['mw'],
    "jhallaḥ": ['ap90'],
    "jhallikā": ['ap90', 'mw'],
    "jhallola": ['mw'],
    "jhallolaḥ": ['ap90'],
    "jhallī": ['mw'],
    "jhallīkā": ['mw'],
    "jhallīṣaka": ['mw'],
    "jhalujhalu": ['bhs'],
    "jhalā": ['ap90', 'mw'],
    "jham": ['ap90', 'mw'],
    "jhampa": ['cae', 'ddsa', 'mw'],
    "jhampaḍa": ['mw'],
    "jhampin": ['mw'],
    "jhampā": ['mw'],
    "jhampāka": ['mw'],
    "jhampānṛtya": ['mw'],
    "jhampāru": ['mw'],
    "jhampātāla": ['mw'],
    "jhampāśin": ['mw'],
    "jhanatkāra": ['mw'],
    "jhanatkāraḥ": ['ap90'],
    "jhar": ['cae', 'ddsa'],
    "jhara": ['mw'],
    "jharasī": ['mw'],
    "jharat": ['mw'],
    "jharavāhalā": ['mw'],
    "jharaḥ": ['ap90'],
    "jharaṇodaka": ['mw'],
    "jharc": ['ap90', 'mw'],
    "jharch": ['mw'],
    "jharjh": ['mw'],
    "jharjhara": ['cae', 'ddsa', 'mw'],
    "jharjharaka": ['mw'],
    "jharjharakaḥ": ['ap90'],
    "jharjharaḥ": ['ap90'],
    "jharjharikā": ['mw'],
    "jharjharin": ['ap90', 'mw'],
    "jharjharita": ['cae', 'ddsa', 'mw'],
    "jharjharā": ['mw'],
    "jharjharāvatī": ['ap90'],
    "jharjharī": ['mw'],
    "jharjharīka": ['mw'],
    "jharjharīkaḥ": ['ap90'],
    "jharā": ['cae', 'ddsa'],
    "jharī": ['cae', 'mw'],
    "jhatta": ['cped'],
    "jhatvā": ['cped'],
    "jhatvāna": ['cped'],
    "jhaulika": ['cae', 'ddsa', 'mw'],
    "jhañjhana": ['mw'],
    "jhañjhā": ['cae', 'ddsa', 'mw'],
    "jhañjhāmarut": ['cae', 'mw'],
    "jhañjhāmāruta": ['cae', 'mw'],
    "jhañjhānila": ['cae', 'mw'],
    "jhañjhāvāta": ['mw'],
    "jhaṃjhanaṃ": ['ap90'],
    "jhaṃjhā": ['ap90'],
    "jhaṃkāra": ['cae'],
    "jhaṃkāraḥ": ['ap90'],
    "jhaṃkārin": ['cae'],
    "jhaṃkārita": ['cae'],
    "jhaṃkāriṇī": ['ap90'],
    "jhaṃkṛti": ['cae'],
    "jhaṃkṛtiḥ": ['ap90'],
    "jhaṃpaḥ": ['ap90'],
    "jhaṃpākaḥ": ['ap90'],
    "jhaṅ": ['mw'],
    "jhaṅki": ['mw'],
    "jhaṅkāra": ['ddsa', 'mw'],
    "jhaṅkārin": ['mw'],
    "jhaṅkārita": ['mw'],
    "jhaṅkī": ['mw'],
    "jhaṅkṛta": ['mw'],
    "jhaṇ": ['cae', 'ddsa', 'mw'],
    "jhaṇajhaṇa": ['cae'],
    "jhaṇajhaṇaṃ": ['ap90'],
    "jhaṇajhaṇārava": ['ddsa', 'mw'],
    "jhaṇajhaṇāy": ['cae'],
    "jhaṇajhaṇāya": ['ddsa', 'mw'],
    "jhaṇajhaṇāyita": ['ap90', 'mw'],
    "jhaṇajhaṇībhūta": ['mw'],
    "jhaṇajjhaṇatkārin": ['mw'],
    "jhaṇajjhaṇita": ['mw'],
    "jhaṇatkāra": ['cae', 'ddsa', 'mw'],
    "jhaṇatkāraḥ": ['ap90'],
    "jhaṇiti": ['ddsa', 'mw'],
    "jhaṇḍuka": ['mw'],
    "jhaṇḍī": ['mw'],
    "jhaṇḍū": ['mw'],
    "jhaṇḍūka": ['mw'],
    "jhaṇṭi": ['mw'],
    "jhaṇṭī": ['mw'],
    "jhaṇṭīśa": ['mw'],
    "jhaṣ": ['ap90', 'mw'],
    "jhaṣa": ['cae', 'ddsa', 'mw'],
    "jhaṣadhvaja": ['cae', 'mw'],
    "jhaṣaketana": ['cae', 'mw'],
    "jhaṣapitta": ['mw'],
    "jhaṣarāja": ['mw'],
    "jhaṣaśreṣṭha": ['mw'],
    "jhaṣaḥ": ['ap90'],
    "jhaṣodarī": ['mw'],
    "jhaṣā": ['mw'],
    "jhaṣāśana": ['mw'],
    "jhaṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "jhaṭi": ['mw'],
    "jhaṭiti": ['ap90', 'cae', 'ddsa', 'mw'],
    "jhaṭiḥ": ['ap90'],
    "jhijjī": ['mw'],
    "jhillarī": ['mw'],
    "jhilli": ['mw'],
    "jhillika": ['cae', 'mw'],
    "jhillikā": ['ap90', 'ddsa', 'mw'],
    "jhillin": ['mw'],
    "jhilliḥ": ['ap90'],
    "jhillī": ['ap90', 'cae', 'ddsa', 'mw'],
    "jhillīka": ['mw'],
    "jhillīkaḥ": ['ap90'],
    "jhillīkaṇṭha": ['mw'],
    "jhillīkā": ['mw'],
    "jhirikā": ['ap90', 'mw'],
    "jhirukā": ['mw'],
    "jhirī": ['mw'],
    "jhirīkā": ['mw'],
    "jhiñjhima": ['mw'],
    "jhiñjhiriṣṭā": ['mw'],
    "jhiñjhiriṭā": ['mw'],
    "jhiñjhirā": ['mw'],
    "jhiñjhirīṭā": ['mw'],
    "jhiñjhī": ['mw'],
    "jhiṃginī": ['ap90'],
    "jhiṃjhimaḥ": ['ap90'],
    "jhiṃjhī": ['ap90'],
    "jhiṃṭī": ['ap90'],
    "jhiṅginī": ['cae', 'mw'],
    "jhiṅgāka": ['mw'],
    "jhiṅgī": ['cae', 'mw'],
    "jhiṇikā": ['mw'],
    "jhiṇṭi": ['mw'],
    "jhiṇṭikā": ['mw'],
    "jhiṇṭī": ['mw'],
    "jhombaka": ['mw'],
    "jhoḍa": ['mw'],
    "jhoṃḍaḥ": ['ap90'],
    "jhu": ['mw'],
    "jhumari": ['mw'],
    "jhumbarī": ['mw'],
    "jhuṃṭaḥ": ['ap90'],
    "jhuṇṭa": ['mw'],
    "jhyu": ['ap90', 'mw'],
    "jhā": ['mw'],
    "jhābuka": ['mw'],
    "jhālarī": ['mw'],
    "jhāli": ['mw'],
    "jhāliḥ": ['ap90'],
    "jhālā": ['mw'],
    "jhāmaka": ['mw'],
    "jhāmakaṃ": ['ap90'],
    "jhāmakaṇu": ['cped'],
    "jhāmara": ['mw'],
    "jhāmaraḥ": ['ap90'],
    "jhāna": ['cped'],
    "jhāna(p)pasuta": ['cped'],
    "jhānajjhayana": ['cped'],
    "jhānājjhāyana": ['cped'],
    "jhānānuyuta": ['cped'],
    "jhāpayati": ['cped'],
    "jhāpesi": ['cped'],
    "jhāpeti": ['cped'],
    "jhāpetvā": ['cped'],
    "jhāpita": ['cped'],
    "jhārjhara": ['mw'],
    "jhārjharaḥ": ['ap90'],
    "jhārjharika": ['mw'],
    "jhāvu": ['mw'],
    "jhāvuka": ['mw'],
    "jhāvū": ['mw'],
    "jhāya(t)": ['cped'],
    "jhāyaka": ['cped'],
    "jhāyanta": ['cped'],
    "jhāyati": ['cped'],
    "jhāyi": ['cped'],
    "jhāyi(n)": ['cped'],
    "jhāṃ": ['mw'],
    "jhāṃkāra": ['mw'],
    "jhāṃkārin": ['mw'],
    "jhāṃkṛta": ['mw'],
    "jhāṃkṛtaṃ": ['ap90'],
    "jhāṅkārin": ['ddsa'],
    "jhāṣayati": ['bhs'],
    "jhāṭa": ['mw'],
    "jhāṭala": ['mw'],
    "jhāṭali": ['mw'],
    "jhāṭaḥ": ['ap90'],
    "jhāṭikā": ['ap90', 'mw'],
    "jhāṭkārin": ['ddsa', 'mw'],
    "jhāṭā": ['mw'],
    "jhāṭāmalā": ['mw'],
    "jhāṭāstraka": ['mw'],
    "jhāṭāstrakaḥ": ['ap90'],
    "jhāṭīkā": ['ap90', 'mw'],
    "jhīrikā": ['mw'],
    "jhīrukā": ['ap90', 'mw'],
    "jhūliḥ": ['ap90'],
    "jhūṇi": ['mw'],
    "jhūṇiḥ": ['ap90'],
    "jhūṣ": ['mw'],
    "jhṝ": ['ap90', 'mw'],
    "ji": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jieṣṭha": ['gra'],
    "jigamiṣu": ['cae', 'ddsa', 'mw'],
    "jigamiṣā": ['mw'],
    "jigariṣu": ['mw'],
    "jigarti": ['gra', 'mw'],
    "jigatnu": ['cae', 'gra', 'mw'],
    "jigatnuḥ": ['ap90'],
    "jighaccha(t)": ['cped'],
    "jighacchita": ['cped'],
    "jighacchā": ['cped'],
    "jighatnu": ['gra', 'mw'],
    "jighatnuḥ": ['ap90'],
    "jighatsita": ['bhs'],
    "jighatsu": ['ap90', 'cae', 'mw'],
    "jighatsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "jighnate": ['ddsa'],
    "jighra": ['ap90', 'mw'],
    "jighāṃs": ['cae'],
    "jighāṃsaka": ['ap90', 'mw'],
    "jighāṃsin": ['cae', 'mw'],
    "jighāṃsita": ['bhs'],
    "jighāṃsu": ['ap90', 'cae', 'mw'],
    "jighāṃsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "jighāṃsīyas": ['mw'],
    "jighṛkṣu": ['cae', 'mw'],
    "jighṛkṣutā": ['mw'],
    "jighṛkṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "jigiṁsa(t)": ['cped'],
    "jigiṁsaka": ['cped'],
    "jigiṁsamāna": ['cped'],
    "jigiṁsanā": ['cped'],
    "jigiṁsati": ['cped'],
    "jigucchamāna": ['cped'],
    "jigucchanta": ['cped'],
    "jigucchati": ['cped'],
    "jigucchita": ['cped'],
    "jigucchitabba": ['cped'],
    "jigucchitvā": ['cped'],
    "jigyu": ['cae', 'gra', 'mw'],
    "jigīsaka": ['cped'],
    "jigīṣita": ['mw'],
    "jigīṣotsāhavat": ['mw'],
    "jigīṣu": ['ap90', 'cae', 'gra', 'mw'],
    "jigīṣutā": ['mw'],
    "jigīṣā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jihlu": ['mw'],
    "jihma": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "jihmabāra": ['gra', 'mw'],
    "jihmaga": ['cae', 'ddsa', 'mw'],
    "jihmagati": ['mw'],
    "jihmakārin": ['mw'],
    "jihmam": ['mw'],
    "jihmamohana": ['mw'],
    "jihmamīna": ['mw'],
    "jihmaprekṣin": ['mw'],
    "jihmatva": ['mw'],
    "jihmatā": ['mw'],
    "jihmayodhin": ['mw'],
    "jihmaśalya": ['mw'],
    "jihmaśiras": ['mw'],
    "jihmaśī": ['cae', 'gra', 'mw'],
    "jihmetara": ['mw'],
    "jihmita": ['cae', 'ddsa', 'mw'],
    "jihmākṣa": ['mw'],
    "jihmāya": ['mw'],
    "jihmāyati": ['ap90'],
    "jihmāśin": ['mw'],
    "jihmī": ['mw'],
    "jihmībhavati": ['bhs'],
    "jihmībhū": ['mw'],
    "jihmīkara": ['bhs', 'mw'],
    "jihmīkaraṇa": ['bhs', 'mw'],
    "jihmīkaroti": ['bhs'],
    "jihmīkṛta": ['mw'],
    "jihnu": ['mw'],
    "jihnuna": ['bhs'],
    "jihrīyati": ['bhs'],
    "jihva": ['cae', 'mw'],
    "jihvaka": ['cae', 'mw'],
    "jihvala": ['ap90', 'mw'],
    "jihvaḥ": ['ap90'],
    "jihvikā": ['gra', 'mw'],
    "jihvodbhava": ['mw'],
    "jihvollekhana": ['mw'],
    "jihvollekhanikā": ['mw'],
    "jihvollekhanī": ['mw'],
    "jihvā": ['ap90', 'ddsa', 'gra', 'mw'],
    "jihvāchedana": ['mw'],
    "jihvāgra": ['ddsa', 'mw'],
    "jihvākātya": ['mw'],
    "jihvālatā": ['mw'],
    "jihvālaulya": ['mw'],
    "jihvālih": ['mw'],
    "jihvāmala": ['mw'],
    "jihvāmaya": ['mw'],
    "jihvāmūla": ['cae', 'mw'],
    "jihvāmūlīya": ['cae', 'mw'],
    "jihvānirlekhana": ['mw'],
    "jihvānirlekhanika": ['bhs', 'mw'],
    "jihvāpa": ['mw'],
    "jihvāprathana": ['mw'],
    "jihvāpāvan": ['mw'],
    "jihvārada": ['mw'],
    "jihvāstambha": ['mw'],
    "jihvāsvāda": ['mw'],
    "jihvātala": ['mw'],
    "jihvāvat": ['mw'],
    "jihvāśalya": ['mw'],
    "jihvāśodhana": ['mw'],
    "jihāna": ['ap90', 'mw'],
    "jihānaka": ['mw'],
    "jihānakaḥ": ['ap90'],
    "jihāsu": ['cae', 'ddsa', 'mw'],
    "jihāsā": ['cae', 'mw'],
    "jihāṅgīra": ['mw'],
    "jihīraṣā": ['mw'],
    "jihīrṣu": ['ddsa', 'mw'],
    "jihīrṣya": ['mw'],
    "jihīrṣā": ['cae', 'mw'],
    "jihīti": ['mw'],
    "jijyūṣita": ['mw'],
    "jijñu": ['mw'],
    "jijñāpayiṣu": ['mw'],
    "jijñāsaka": ['mw'],
    "jijñāsana": ['cae', 'ddsa', 'mw'],
    "jijñāsanā": ['bhs'],
    "jijñāsanīya": ['mw'],
    "jijñāsita": ['ap90', 'mw'],
    "jijñāsitavya": ['mw'],
    "jijñāsu": ['ap90', 'cae', 'mw'],
    "jijñāsya": ['mw'],
    "jijñāsā": ['ap90', 'cae', 'mw'],
    "jijñāsāprastāva": ['mw'],
    "jijīviṣu": ['mw'],
    "jijīviṣā": ['cae', 'ddsa', 'mw'],
    "jijīṣu": ['mw'],
    "jikana": ['mw'],
    "jillika": ['mw'],
    "jim": ['ap90', 'mw'],
    "jimbha": ['mw'],
    "jimbhajihvatā": ['mw'],
    "jimha": ['cped'],
    "jimheyya": ['cped'],
    "jimita": ['mw'],
    "jina": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "jinabhadra": ['mw'],
    "jinabhakti": ['mw'],
    "jinabhāskara": ['bhs'],
    "jinabimbapratiṣṭhā": ['mw'],
    "jinacakra": ['bhs'],
    "jinacandra": ['mw'],
    "jinadatta": ['mw'],
    "jinadattacaritra": ['mw'],
    "jinadattakathāsamuccaya": ['mw'],
    "jinadeva": ['mw'],
    "jinadharma": ['mw'],
    "jinadāsa": ['mw'],
    "jinaharṣa": ['mw'],
    "jinahaṃsa": ['mw'],
    "jinajyā": ['mw'],
    "jinakalpa": ['mw'],
    "jinakalpika": ['mw'],
    "jinakuśala": ['mw'],
    "jinakāntāra": ['bhs'],
    "jinakīrti": ['mw'],
    "jinalabdhi": ['mw'],
    "jinalābha": ['mw'],
    "jinamaṇḍana": ['mw'],
    "jinamitra": ['mw'],
    "jinamāṇikya": ['mw'],
    "jinana": ['mw'],
    "jinapadma": ['mw'],
    "jinapati": ['mw'],
    "jinaprabha": ['mw'],
    "jinaprabodha": ['mw'],
    "jinaputra": ['bhs', 'mw'],
    "jinarakṣita": ['mw'],
    "jinaratna": ['mw'],
    "jinarāja": ['mw'],
    "jinarṣabha": ['bhs'],
    "jinarṣi": ['mw'],
    "jinasadman": ['mw'],
    "jinasahasranāmastotra": ['mw'],
    "jinasamudra": ['mw'],
    "jinasaukhya": ['mw'],
    "jinasena": ['mw'],
    "jinasiṃha": ['mw'],
    "jinastuti": ['mw'],
    "jinasāgara": ['mw'],
    "jinasūrya": ['bhs'],
    "jinati": ['cped'],
    "jinaurasa": ['bhs'],
    "jinavaktra": ['bhs', 'mw'],
    "jinavallabha": ['mw'],
    "jinavardhana": ['mw'],
    "jinavaruttama": ['bhs'],
    "jinavimala": ['mw'],
    "jinavrata": ['bhs'],
    "jinavṛtta": ['mw'],
    "jinayajñakalpa": ['mw'],
    "jinayoni": ['mw'],
    "jinaśataka": ['mw'],
    "jinaśatapañjikā": ['mw'],
    "jinaśekhara": ['mw'],
    "jinaśrāvaka": ['bhs'],
    "jinaśrī": ['mw'],
    "jinaśāsana": ['mw'],
    "jindurāja": ['ddsa', 'mw'],
    "jine": ['cped'],
    "jinendra": ['bhs', 'cae', 'ddsa', 'mw'],
    "jinendrabuddhi": ['mw'],
    "jinendracaritra": ['mw'],
    "jinendraghoṣā": ['bhs'],
    "jineśa": ['mw'],
    "jineśvara": ['mw'],
    "jini": ['cped'],
    "jinitvā": ['cped'],
    "jiniṁsu": ['cped'],
    "jinodaya": ['mw'],
    "jinorasa": ['mw'],
    "jinottama": ['mw'],
    "jinv": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jinva": ['cae', 'gra', 'mw'],
    "jinādhāra": ['mw'],
    "jinādivijaya": ['mw'],
    "jināti": ['bhs'],
    "jināṃśajyā": ['mw'],
    "jināṅkura": ['mw'],
    "jiok": ['gra'],
    "jirati": ['cped'],
    "jiraṇa": ['mw'],
    "jiri": ['ap90', 'mw'],
    "jirvi": ['mw'],
    "jirīyati": ['cped'],
    "jit": ['ap90', 'cae', 'ddsa', 'mw'],
    "jita": ['ap90', 'cped', 'mw'],
    "jitahasta": ['mw'],
    "jitaklama": ['cae', 'mw'],
    "jitakopa": ['mw'],
    "jitakrodha": ['cae', 'mw'],
    "jitakāśi": ['mw'],
    "jitakāśin": ['cae', 'mw'],
    "jitaloka": ['mw'],
    "jitam": ['bhs'],
    "jitamanas": ['mw'],
    "jitamanyu": ['mw'],
    "jitanemi": ['mw'],
    "jitasaṅga": ['mw'],
    "jitasvarga": ['mw'],
    "jitatara": ['mw'],
    "jitavatī": ['mw'],
    "jitavrata": ['mw'],
    "jitaśatru": ['bhs', 'mw'],
    "jitaśiśnodara": ['mw'],
    "jitaśrama": ['ddsa', 'mw'],
    "jitaśvāsa": ['mw'],
    "jitendriya": ['cae', 'ddsa', 'mw'],
    "jitendriyatva": ['mw'],
    "jitendriyāhva": ['mw'],
    "jiti": ['cae', 'ddsa', 'gra', 'mw'],
    "jitiḥ": ['ap90'],
    "jitma": ['mw'],
    "jittama": ['mw'],
    "jittamaḥ": ['ap90'],
    "jituma": ['mw'],
    "jitvan": ['ap90', 'cae', 'gra', 'mw'],
    "jitvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "jitvarī": ['mw'],
    "jitvā": ['cped'],
    "jitya": ['ap90', 'mw'],
    "jityā": ['cae', 'mw'],
    "jitāhava": ['mw'],
    "jitāhāra": ['mw'],
    "jitākṣa": ['ddsa', 'mw'],
    "jitākṣara": ['mw'],
    "jitāmitra": ['mw'],
    "jitāri": ['mw'],
    "jitāsana": ['mw'],
    "jitātman": ['cae', 'mw'],
    "jitāśva": ['mw'],
    "jitāṣṭamī": ['mw'],
    "jivhadhātu": ['cped'],
    "jivhagga": ['cped'],
    "jivhanicchākaraṁ": ['cped'],
    "jivhaviññeyya": ['cped'],
    "jivhindriya": ['cped'],
    "jivhā": ['cped'],
    "jivhānittaddana": ['cped'],
    "jivhāyatana": ['cped'],
    "jivri": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jivājivaḥ": ['ap90'],
    "jivājīva": ['mw'],
    "jiyati": ['cped'],
    "jiyyati": ['cped'],
    "jiyā": ['cped'],
    "jiā": ['gra'],
    "jiākā": ['gra'],
    "jiāvāja": ['gra'],
    "jiāyas": ['gra'],
    "jiḍadhana": ['mw'],
    "jiḥ": ['ap90'],
    "jiṅgaśalya": ['mw'],
    "jiṅginī": ['mw'],
    "jiṅgiṇī": ['mw'],
    "jiṅgī": ['cae', 'ddsa', 'mw'],
    "jiṇṇa": ['cped'],
    "jiṇṇaka": ['cped'],
    "jiṣ": ['ap90', 'mw'],
    "jiṣe": ['cae', 'mw'],
    "jiṣṇu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jiṣṇugupta": ['mw'],
    "jiṣṇuja": ['mw'],
    "jman": ['cae', 'gra', 'mw'],
    "jmayā": ['cae', 'gra', 'mw'],
    "jmā": ['cae', 'gra'],
    "jmāy": ['gra'],
    "jmāyant": ['cae'],
    "jmāyat": ['mw'],
    "jogū": ['cae', 'gra', 'mw'],
    "johūtra": ['cae', 'ddsa', 'gra', 'mw'],
    "jola": ['mw'],
    "jomā": ['bhs', 'mw'],
    "jonarāja": ['mw'],
    "jonnālā": ['mw'],
    "jontaka": ['bhs'],
    "jota": ['bhs'],
    "jotati": ['cped'],
    "jotayati": ['cped'],
    "joteti": ['cped'],
    "joti": ['cped'],
    "jotika": ['cped', 'mw'],
    "jotimat)": ['cped'],
    "jotimālika": ['cped'],
    "jotiparāyana": ['cped'],
    "jotiṣ": ['bhs'],
    "joḍa": ['bhs', 'mw'],
    "joḍaḥ": ['ap90'],
    "joṃgaṃ": ['ap90'],
    "joṃgaṭaḥ": ['ap90'],
    "joṅga": ['cae', 'ddsa', 'mw'],
    "joṅgaka": ['cae', 'mw'],
    "joṅgala": ['mw'],
    "joṅgaṭa": ['mw'],
    "joṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "joṣaka": ['mw'],
    "joṣam": ['mw'],
    "joṣas": ['gra', 'mw'],
    "joṣavāka": ['gra', 'mw'],
    "joṣayitavya": ['mw'],
    "joṣayitṛ": ['mw'],
    "joṣaḥ": ['ap90'],
    "joṣaṇa": ['cae', 'ddsa', 'mw'],
    "joṣaṇaṃ": ['ap90'],
    "joṣaṇā": ['mw'],
    "joṣia": ['gra'],
    "joṣikā": ['ap90', 'mw'],
    "joṣit": ['mw'],
    "joṣitā": ['mw'],
    "joṣya": ['gra', 'mw'],
    "joṣā": ['ap90', 'mw'],
    "joṣṭṛ": ['cae', 'gra', 'mw'],
    "joṭin": ['mw'],
    "joṭiṃgaḥ": ['ap90'],
    "joṭiṅga": ['mw'],
    "joṭīṅga": ['mw'],
    "jraya": ['cae', 'gra', 'mw'],
    "jrayas": ['cae', 'ddsa', 'gra', 'mw'],
    "jrayasāna": ['gra', 'mw'],
    "jri": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jrī": ['mw'],
    "ju": ['cae', 'mw'],
    "jugupiṣu": ['mw'],
    "jugups": ['cae'],
    "jugupsana": ['mw'],
    "jugupsanaṃ": ['ap90'],
    "jugupsanā": ['bhs'],
    "jugupsanīya": ['mw'],
    "jugupsita": ['cae', 'ddsa', 'mw'],
    "jugupsitatama": ['mw'],
    "jugupsitatva": ['mw'],
    "jugupsu": ['mw'],
    "jugupsya": ['mw'],
    "jugupsā": ['cae', 'ddsa', 'mw'],
    "jugurvaṇi": ['cae', 'gra', 'mw'],
    "jugutsu": ['bhs'],
    "juha(t)": ['cped'],
    "juhana": ['bhs', 'cped'],
    "juhanta": ['cped'],
    "juhati": ['cped'],
    "juhitabba": ['cped'],
    "juhitvā": ['cped'],
    "juhiṁ": ['cped'],
    "juhoti": ['cae', 'cped', 'ddsa', 'mw'],
    "juhoticodana": ['mw'],
    "juhotiyajatikriyā": ['cae', 'mw'],
    "juhotiḥ": ['ap90'],
    "juhotyādi": ['mw'],
    "juhurāṇa": ['ap90', 'ddsa', 'mw'],
    "juhuvāna": ['mw'],
    "juhuvānaḥ": ['ap90'],
    "juhuvāṇa": ['mw'],
    "juhvat": ['mw'],
    "juhvāna": ['mw'],
    "juhvāsya": ['cae', 'gra', 'mw'],
    "juhāti": ['cped'],
    "juhū": ['cae', 'ddsa', 'gra', 'mw'],
    "juhūmagrīya": ['mw'],
    "juhūrāṇa": ['mw'],
    "juhūrāṇaḥ": ['ap90'],
    "juhūtva": ['mw'],
    "juhūvat": ['ap90', 'mw'],
    "juhūvāṇaḥ": ['ap90'],
    "juhūāsia": ['gra'],
    "juhūḥ": ['ap90'],
    "juhūṣu": ['cae', 'ddsa', 'mw'],
    "jukuṭa": ['mw'],
    "jukuṭaḥ": ['ap90'],
    "jul": ['ap90', 'mw'],
    "jumara": ['mw'],
    "jumaranandin": ['mw'],
    "jumbaka": ['cae', 'mw'],
    "jun": ['ap90', 'mw'],
    "jur": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jut": ['ap90', 'mw'],
    "juti": ['cped'],
    "jutima(t)": ['cped'],
    "jutimanta": ['cped'],
    "jutindhara": ['cped'],
    "jutīma(t)": ['cped'],
    "juvas": ['ap90', 'cae', 'gra', 'mw'],
    "juñc": ['mw'],
    "juḍ": ['ap90', 'mw'],
    "juḍī": ['mw'],
    "juṃbakaḥ": ['ap90'],
    "juṃg": ['ap90'],
    "juṃgita": ['ap90'],
    "juṅg": ['mw'],
    "juṅga": ['mw'],
    "juṅgaka": ['mw'],
    "juṅgita": ['mw'],
    "juṅgā": ['mw'],
    "juṅkaka": ['mw'],
    "juṇha": ['cped'],
    "juṇhā": ['cped'],
    "juṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "juṣa": ['mw'],
    "juṣka": ['mw'],
    "juṣkaka": ['mw'],
    "juṣkapura": ['mw'],
    "juṣya": ['ap90', 'mw'],
    "juṣāṇa": ['mw'],
    "juṣāṇavat": ['mw'],
    "juṣṭa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "juṣṭatama": ['mw'],
    "juṣṭatara": ['mw'],
    "juṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "juṣṭā": ['mw'],
    "juṭ": ['mw'],
    "juṭaka": ['cae', 'mw'],
    "juṭakaṃ": ['ap90'],
    "juṭikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "jval": ['ap90', 'cae', 'ddsa', 'mw'],
    "jvala": ['ap90', 'cae', 'ddsa', 'mw'],
    "jvalaccharīra": ['mw'],
    "jvalakā": ['ap90', 'mw'],
    "jvalamukhī": ['mw'],
    "jvalan": ['mw'],
    "jvalana": ['ap90', 'cae', 'ddsa', 'mw'],
    "jvalanabhū": ['mw'],
    "jvalanakaṇa": ['mw'],
    "jvalanasaprabha": ['cae'],
    "jvalanaśirīśa": ['bhs'],
    "jvalanmaṇi": ['mw'],
    "jvalanolka": ['bhs'],
    "jvalant": ['cae'],
    "jvalantaśikharā": ['bhs', 'mw'],
    "jvalantī": ['mw'],
    "jvalanā": ['mw'],
    "jvalanādhipati": ['bhs', 'mw'],
    "jvalanāntaratejorāja": ['bhs'],
    "jvalanārciḥparvataśrīvyūha": ['bhs'],
    "jvalanāśman": ['mw'],
    "jvalanī": ['bhs'],
    "jvalanīya": ['mw'],
    "jvalat": ['mw'],
    "jvalatkukūla": ['bhs'],
    "jvalatprabhā": ['mw'],
    "jvalattva": ['mw'],
    "jvalinī": ['mw'],
    "jvalita": ['ap90', 'cae', 'ddsa', 'mw'],
    "jvalitacakṣus": ['mw'],
    "jvalitanayana": ['mw'],
    "jvalitanetra": ['mw'],
    "jvalitatejas": ['bhs'],
    "jvalitayaśas": ['bhs'],
    "jvalitānana": ['mw'],
    "jvalitṛ": ['mw'],
    "jvalānana": ['mw'],
    "jvar": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "jvarabrahmāstra": ['mw'],
    "jvaracikitsā": ['mw'],
    "jvaradhūmaketu": ['mw'],
    "jvaraghna": ['mw'],
    "jvarahantrī": ['mw'],
    "jvarahara": ['mw'],
    "jvarakṣaya": ['mw'],
    "jvaranirṇaya": ['mw'],
    "jvaranāśaka": ['mw'],
    "jvaranāśinī": ['mw'],
    "jvarapralāpa": ['mw'],
    "jvarin": ['cae', 'mw'],
    "jvarita": ['ap90', 'cae', 'ddsa', 'mw'],
    "jvarāgni": ['mw'],
    "jvarānta": ['mw'],
    "jvarāntaka": ['mw'],
    "jvarāpaha": ['mw'],
    "jvarāpahā": ['mw'],
    "jvarāri": ['mw'],
    "jvarātīsāra": ['mw'],
    "jvarāśani": ['mw'],
    "jvarāṅgī": ['mw'],
    "jvarāṅkuśa": ['mw'],
    "jvāla": ['ap90', 'cae', 'ddsa', 'mw'],
    "jvālamālākula": ['mw'],
    "jvālana": ['cae'],
    "jvāleśvara": ['mw'],
    "jvālin": ['ap90', 'cae', 'ddsa', 'mw'],
    "jvālinī": ['mw'],
    "jvālā": ['ap90', 'mw'],
    "jvālādhvaja": ['mw'],
    "jvālāgardabhaka": ['mw'],
    "jvālājihva": ['mw'],
    "jvālākharagada": ['mw'],
    "jvālālakṣaṇa": ['mw'],
    "jvālāliṅga": ['mw'],
    "jvālāmukha": ['mw'],
    "jvālāmukhī": ['bhs', 'mw'],
    "jvālāmālin": ['mw'],
    "jvālānala": ['mw'],
    "jvālārāsabhakāmaya": ['mw'],
    "jvālāvaktra": ['mw'],
    "jvālāyana": ['mw'],
    "jvāra": ['cae', 'gra', 'mw'],
    "jya": ['mw'],
    "jyaiṣṭha": ['cae', 'ddsa', 'mw'],
    "jyaiṣṭhasāmika": ['mw'],
    "jyaiṣṭhaḥ": ['ap90'],
    "jyaiṣṭhineya": ['ap90', 'ddsa', 'mw'],
    "jyaiṣṭhya": ['cae', 'ddsa', 'gra', 'mw'],
    "jyaiṣṭhyaṃ": ['ap90'],
    "jyaiṣṭhī": ['mw'],
    "jyakā": ['mw'],
    "jyau": ['mw'],
    "jyautiṣa": ['mw'],
    "jyautiṣika": ['mw'],
    "jyautiṣikaḥ": ['ap90'],
    "jyautsna": ['ap90', 'cae', 'ddsa', 'mw'],
    "jyautsnikā": ['mw'],
    "jyautsnī": ['mw'],
    "jyauḥ": ['ap90'],
    "jyeya": ['ap90', 'mw'],
    "jyeṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jyeṣṭhabalā": ['mw'],
    "jyeṣṭhabandhu": ['cae', 'mw'],
    "jyeṣṭhabhavikā": ['bhs', 'mw'],
    "jyeṣṭhabhāryā": ['mw'],
    "jyeṣṭhabrāhmaṇa": ['mw'],
    "jyeṣṭhaghnī": ['mw'],
    "jyeṣṭhagṛhya": ['mw'],
    "jyeṣṭhajaghanya": ['mw'],
    "jyeṣṭhakalaśa": ['mw'],
    "jyeṣṭhalakṣma": ['mw'],
    "jyeṣṭhalakṣmī": ['mw'],
    "jyeṣṭhalalitā": ['mw'],
    "jyeṣṭham": ['mw'],
    "jyeṣṭhaprathama": ['mw'],
    "jyeṣṭhapuṣkara": ['mw'],
    "jyeṣṭhapāla": ['mw'],
    "jyeṣṭharāj": ['cae', 'gra', 'mw'],
    "jyeṣṭhasthāna": ['mw'],
    "jyeṣṭhastoma": ['mw'],
    "jyeṣṭhasāmaga": ['cae', 'mw'],
    "jyeṣṭhasāmaka": ['mw'],
    "jyeṣṭhasāman": ['cae', 'mw'],
    "jyeṣṭhatama": ['cae', 'gra', 'mw'],
    "jyeṣṭhatara": ['cae', 'ddsa', 'mw'],
    "jyeṣṭhataraka": ['bhs'],
    "jyeṣṭhatarikā": ['mw'],
    "jyeṣṭhatarā": ['mw'],
    "jyeṣṭhatas": ['mw'],
    "jyeṣṭhatva": ['mw'],
    "jyeṣṭhatā": ['cae', 'mw'],
    "jyeṣṭhatāta": ['mw'],
    "jyeṣṭhatāti": ['gra', 'mw'],
    "jyeṣṭhavara": ['mw'],
    "jyeṣṭhavarṇa": ['mw'],
    "jyeṣṭhavarṇin": ['mw'],
    "jyeṣṭhavayas": ['cae', 'mw'],
    "jyeṣṭhavṛtti": ['cae', 'mw'],
    "jyeṣṭhayajña": ['mw'],
    "jyeṣṭhaśvaśrū": ['mw'],
    "jyeṣṭheśvara": ['mw'],
    "jyeṣṭhilā": ['mw'],
    "jyeṣṭhinī": ['mw'],
    "jyeṣṭhā": ['mw'],
    "jyeṣṭhāmalaka": ['mw'],
    "jyeṣṭhāmbu": ['mw'],
    "jyeṣṭhāmūla": ['ap90', 'mw'],
    "jyeṣṭhāmūlīya": ['mw'],
    "jyeṣṭhānujyeṣṭhatā": ['mw'],
    "jyeṣṭhāpūjāvilāsa": ['mw'],
    "jyeṣṭhāvrata": ['mw'],
    "jyeṣṭhāśrama": ['mw'],
    "jyeṣṭhāśramin": ['mw'],
    "jyeṣṭhāṃśa": ['cae', 'mw'],
    "jyo": ['ap90', 'mw'],
    "jyog": ['mw'],
    "jyogaparuddha": ['mw'],
    "jyogjīvātu": ['mw'],
    "jyogāmayāvin": ['mw'],
    "jyok": ['cae', 'ddsa', 'gra', 'mw'],
    "jyokkṛ": ['mw'],
    "jyoktamām": ['mw'],
    "jyokti": ['mw'],
    "jyotayamāmaka": ['mw'],
    "jyoti": ['bhs', 'mw'],
    "jyotidarśana": ['mw'],
    "jyotigupta": ['bhs'],
    "jyotika": ['bhs', 'mw'],
    "jyotiprabha": ['bhs'],
    "jyotiprabhāsa": ['bhs'],
    "jyotipāla": ['bhs'],
    "jyotir": ['mw'],
    "jyotiragra": ['ddsa', 'gra', 'mw'],
    "jyotiranīka": ['gra', 'mw'],
    "jyotirata": ['mw'],
    "jyotirathyā": ['mw'],
    "jyotirathā": ['mw'],
    "jyotiraśmirājendra": ['bhs'],
    "jyotirbhāga": ['mw'],
    "jyotirbhāsamaṇi": ['mw'],
    "jyotirbhāsin": ['mw'],
    "jyotirbīja": ['mw'],
    "jyotirdhvaja": ['bhs'],
    "jyotirdhāman": ['mw'],
    "jyotirgarga": ['mw'],
    "jyotirgaṇa": ['cae', 'mw'],
    "jyotirhastā": ['mw'],
    "jyotiriṅga": ['mw'],
    "jyotiriṅgaṇa": ['mw'],
    "jyotirjarāyu": ['gra', 'mw'],
    "jyotirjvalanārciśrīgarbha": ['bhs', 'mw'],
    "jyotirjña": ['cae', 'ddsa', 'mw'],
    "jyotirlatā": ['mw'],
    "jyotirlekhā": ['mw'],
    "jyotirlekhāvalayin": ['mw'],
    "jyotirliṅga": ['mw'],
    "jyotirloka": ['mw'],
    "jyotirmantra": ['mw'],
    "jyotirmaya": ['ap90', 'cae', 'mw'],
    "jyotirmaṇḍala": ['mw'],
    "jyotirmedhātithi": ['mw'],
    "jyotirmilin": ['mw'],
    "jyotirmukha": ['mw'],
    "jyotirnirbandha": ['mw'],
    "jyotirnāma": ['bhs'],
    "jyotirudgamana": ['mw'],
    "jyotirvid": ['cae', 'mw'],
    "jyotirvidyā": ['mw'],
    "jyotirvidābharaṇa": ['cae', 'mw'],
    "jyotirvivaraṇa": ['mw'],
    "jyotirīśa": ['mw'],
    "jyotirīśvara": ['mw'],
    "jyotis": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "jyotisomyagandhaobhāsaśrī": ['bhs'],
    "jyotissātkṛ": ['mw'],
    "jyotistattva": ['mw'],
    "jyotisūryagandhaobhāsaśrī": ['bhs'],
    "jyotita": ['mw'],
    "jyotiś": ['mw'],
    "jyotiścakra": ['mw'],
    "jyotiścandrārka": ['mw'],
    "jyotiḥ": ['mw'],
    "jyotiḥparāśara": ['mw'],
    "jyotiḥpitāmaha": ['mw'],
    "jyotiḥprakāśa": ['mw'],
    "jyotiḥsiddhānta": ['mw'],
    "jyotiḥsāgara": ['mw'],
    "jyotiḥsāman": ['mw'],
    "jyotiḥsāra": ['mw'],
    "jyotiḥśāstra": ['cae', 'ddsa', 'mw'],
    "jyotiḥṣṭoma": ['cae', 'ddsa', 'mw'],
    "jyotiṃdhara": ['bhs'],
    "jyotiṣ": ['mw'],
    "jyotiṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "jyotiṣakūṭa": ['bhs'],
    "jyotiṣaratnamālā": ['mw'],
    "jyotiṣasaṃgraha": ['mw'],
    "jyotiṣatattva": ['mw'],
    "jyotiṣavidyā": ['mw'],
    "jyotiṣika": ['mw'],
    "jyotiṣikaḥ": ['ap90'],
    "jyotiṣka": ['bhs', 'mw'],
    "jyotiṣkalpa": ['mw'],
    "jyotiṣkalpalatā": ['mw'],
    "jyotiṣkara": ['bhs', 'mw'],
    "jyotiṣkaraṇḍaka": ['mw'],
    "jyotiṣkaumudī": ['mw'],
    "jyotiṣkaṇa": ['ddsa', 'mw'],
    "jyotiṣkā": ['mw'],
    "jyotiṣkṛ": ['mw'],
    "jyotiṣkṛt": ['cae', 'gra', 'mw'],
    "jyotiṣmant": ['cae'],
    "jyotiṣmat": ['ap90', 'gra', 'mw'],
    "jyotiṣmati": ['bhs'],
    "jyotiṣmatī": ['mw'],
    "jyotiṣpakṣa": ['mw'],
    "jyotiṣprabha": ['bhs', 'mw'],
    "jyotiṣprabhā": ['bhs'],
    "jyotiṣprahīṇa": ['mw'],
    "jyotiṣpāla": ['bhs'],
    "jyotiṣya": ['mw'],
    "jyotiṣā": ['mw'],
    "jyotiṣārṇava": ['mw'],
    "jyotiṣī": ['ap90'],
    "jyotiṣīka": ['mw'],
    "jyotiṣīmat": ['mw'],
    "jyotiṣṭama": ['mw'],
    "jyotiṣṭoma": ['mw'],
    "jyotiṣṭomika": ['mw'],
    "jyotiṣṭva": ['mw'],
    "jyotpatti": ['mw'],
    "jyotsneśa": ['mw'],
    "jyotsnikā": ['cae', 'ddsa', 'mw'],
    "jyotsnā": ['ap90', 'cae', 'ddsa', 'mw'],
    "jyotsnādi": ['mw'],
    "jyotsnākālī": ['mw'],
    "jyotsnāmaya": ['mw'],
    "jyotsnāpakṣatantra": ['mw'],
    "jyotsnāpriya": ['mw'],
    "jyotsnāvat": ['mw'],
    "jyotsnāvāpī": ['mw'],
    "jyotsnāvṛkṣa": ['mw'],
    "jyotsnāḍhya": ['cae', 'mw'],
    "jyotsnī": ['ap90', 'mw'],
    "jyotā": ['mw'],
    "jyotī": ['mw'],
    "jyotīrasa": ['bhs', 'ddsa', 'mw'],
    "jyotīratha": ['cae', 'gra', 'mw'],
    "jyotīrathā": ['mw'],
    "jyotīrūpasvayambhū": ['mw'],
    "jyotīrūpeśvara": ['mw'],
    "jyotīvara": ['bhs'],
    "jyoḍi": ['mw'],
    "jyu": ['ap90', 'mw'],
    "jyut": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jyuti": ['cae'],
    "jyutimat": ['mw'],
    "jyutiḥ": ['ap90'],
    "jyā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jyābāṇeya": ['mw'],
    "jyāghoṣa": ['mw'],
    "jyāghoṣā": ['cae'],
    "jyāhroḍa": ['mw'],
    "jyākā": ['cae', 'gra', 'mw'],
    "jyākāra": ['mw'],
    "jyākṛṣṭi": ['cae', 'ddsa', 'mw'],
    "jyāmagha": ['mw'],
    "jyāna": ['cae', 'mw'],
    "jyānaṃ": ['ap90'],
    "jyāni": ['cae', 'ddsa', 'mw'],
    "jyānivāraṇa": ['mw'],
    "jyāniḥ": ['ap90'],
    "jyāpiṇḍa": ['mw'],
    "jyāpiṇḍaka": ['mw'],
    "jyāpāśa": ['cae', 'ddsa', 'mw'],
    "jyārdha": ['mw'],
    "jyārdhapiṇḍa": ['mw'],
    "jyārohaṇa": ['mw'],
    "jyāvāja": ['gra', 'mw'],
    "jyāya": ['ddsa', 'mw'],
    "jyāyamāna": ['mw'],
    "jyāyas": ['ap90', 'ddsa', 'gra', 'mw'],
    "jyāyasa": ['mw'],
    "jyāyastva": ['mw'],
    "jyāyasvant": ['cae'],
    "jyāyasvat": ['mw'],
    "jyāyaṃs": ['cae'],
    "jyāyiṣṭha": ['ap90', 'cae', 'ddsa', 'mw'],
    "jyāyu": ['mw'],
    "jña": ['ap90', 'cae', 'ddsa', 'mw'],
    "jñaka": ['mw'],
    "jñammanya": ['ddsa'],
    "jñapita": ['ap90', 'mw'],
    "jñapta": ['mw'],
    "jñapti": ['bhs', 'ddsa', 'mw'],
    "jñapticaturtha": ['mw'],
    "jñaptika": ['cae', 'mw'],
    "jñaptiḥ": ['ap90'],
    "jñata": ['mw'],
    "jñatva": ['mw'],
    "jñatā": ['cae', 'ddsa', 'mw'],
    "jñaudanīya": ['mw'],
    "jñaśakti": ['ddsa', 'mw'],
    "jñaṃmanya": ['mw'],
    "jñeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "jñeyajña": ['mw'],
    "jñeyamallaka": ['mw'],
    "jñeyatva": ['mw'],
    "jñeyatā": ['mw'],
    "jñeyārṇava": ['mw'],
    "jñu": ['cae', 'gra', 'mw'],
    "jñubādh": ['cae', 'gra', 'mw'],
    "jñā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jñāmaka": ['bhs'],
    "jñāna": ['bhs', 'cae', 'ddsa', 'mw'],
    "jñānabalaparvatateja": ['bhs'],
    "jñānabhāskara": ['mw'],
    "jñānabhāskarateja": ['bhs'],
    "jñānabodhinī": ['mw'],
    "jñānabuddhi": ['bhs'],
    "jñānacakṣus": ['cae', 'mw'],
    "jñānacandra": ['mw'],
    "jñānada": ['cae', 'mw'],
    "jñānadarpaṇa": ['mw'],
    "jñānadarśana": ['bhs', 'mw'],
    "jñānadatta": ['bhs', 'mw'],
    "jñānadeva": ['mw'],
    "jñānadhvaja": ['bhs'],
    "jñānadurbala": ['mw'],
    "jñānadīpa": ['mw'],
    "jñānadīrgha": ['mw'],
    "jñānagamya": ['cae', 'mw'],
    "jñānagarbha": ['bhs', 'mw'],
    "jñānaghana": ['mw'],
    "jñānaghanācārya": ['mw'],
    "jñānagūha": ['mw'],
    "jñānahasti": ['mw'],
    "jñānakanda": ['mw'],
    "jñānakautūhala": ['mw'],
    "jñānakauṇḍinya": ['bhs'],
    "jñānaketu": ['bhs', 'mw'],
    "jñānaketudhvaja": ['bhs', 'mw'],
    "jñānakhaṇḍa": ['mw'],
    "jñānakāṇḍa": ['mw'],
    "jñānakīrti": ['mw'],
    "jñānalakṣaṇā": ['mw'],
    "jñānalotu": ['bhs'],
    "jñānamati": ['bhs'],
    "jñānamatibuddha": ['bhs'],
    "jñānamaya": ['ap90', 'cae', 'mw'],
    "jñānamayī": ['mw'],
    "jñānamaṇḍalaprabhāsa": ['bhs'],
    "jñānamaṇḍapa": ['mw'],
    "jñānameru": ['bhs', 'mw'],
    "jñānamudra": ['mw'],
    "jñānamudrā": ['bhs', 'mw'],
    "jñānamālā": ['mw'],
    "jñānamārga": ['mw'],
    "jñānamūrti": ['mw'],
    "jñānanidhi": ['mw'],
    "jñānaniścaya": ['mw'],
    "jñānaniṣṭha": ['mw'],
    "jñānapara": ['mw'],
    "jñānaparvatadharmadhātudikpratapanatejorāja": ['bhs'],
    "jñānapata": ['mw'],
    "jñānapati": ['mw'],
    "jñānapaṇya": ['cae', 'mw'],
    "jñānaprabha": ['bhs', 'mw'],
    "jñānapradīpa": ['mw'],
    "jñānaprakāśa": ['mw'],
    "jñānaprasthāna": ['bhs', 'mw'],
    "jñānapravāda": ['mw'],
    "jñānapātra": ['mw'],
    "jñānapāvana": ['mw'],
    "jñānapūrva": ['cae', 'mw'],
    "jñānapūrvakṛta": ['mw'],
    "jñānaratnāvalī": ['mw'],
    "jñānaraśmimeghaprabha": ['bhs'],
    "jñānarādha": ['mw'],
    "jñānarāja": ['mw'],
    "jñānasambhāra": ['mw'],
    "jñānasaṃbhārodgata": ['bhs'],
    "jñānasaṃtati": ['mw'],
    "jñānasaṃtāna": ['mw'],
    "jñānasaṅga": ['cae'],
    "jñānasiddhi": ['mw'],
    "jñānasiṃhaketudhvajarāja": ['bhs'],
    "jñānasāgara": ['mw'],
    "jñānasūryatejas": ['bhs'],
    "jñānasūryodaya": ['mw'],
    "jñānatapas": ['mw'],
    "jñānatas": ['cae', 'mw'],
    "jñānatattva": ['mw'],
    "jñānataḥ": ['ap90'],
    "jñānatva": ['mw'],
    "jñānatā": ['bhs'],
    "jñānatīrtha": ['mw'],
    "jñānavaipulyasūtra": ['bhs'],
    "jñānavairocana": ['bhs'],
    "jñānavairocanagarbha": ['bhs'],
    "jñānavajra": ['mw'],
    "jñānavajratejas": ['bhs'],
    "jñānavant": ['cae'],
    "jñānavarman": ['mw'],
    "jñānavat": ['mw'],
    "jñānavatī": ['bhs'],
    "jñānavatīparivarta": ['bhs'],
    "jñānavibhūtigarbha": ['bhs', 'mw'],
    "jñānavijñāna": ['mw'],
    "jñānavilāsakāvya": ['mw'],
    "jñānavāpī": ['mw'],
    "jñānavṛddha": ['mw'],
    "jñānayajña": ['cae', 'mw'],
    "jñānayoga": ['cae', 'mw'],
    "jñānayuta": ['cae'],
    "jñānaśakti": ['mw'],
    "jñānaśaktimant": ['cae'],
    "jñānaśaktimat": ['mw'],
    "jñānaśikharārcimegha": ['bhs'],
    "jñānaśreṣṭha": ['mw'],
    "jñānaśrī": ['bhs', 'mw'],
    "jñānaśrīpuṇyaprabhā": ['bhs'],
    "jñānaśāstra": ['mw'],
    "jñānaṃ": ['ap90'],
    "jñānecchākriyāśaktimant": ['cae'],
    "jñānecchākriyāśaktimat": ['ddsa'],
    "jñānendrasarasvatī": ['mw'],
    "jñānendriya": ['cae', 'ddsa', 'mw'],
    "jñāneśvara": ['bhs'],
    "jñānin": ['ap90', 'cae', 'ddsa', 'mw'],
    "jñānitva": ['mw'],
    "jñānitvaṃ": ['ap90'],
    "jñānodatīrtha": ['mw'],
    "jñānodgata": ['bhs'],
    "jñānolka": ['bhs'],
    "jñānolkā": ['mw'],
    "jñānolkāvabhāsarāja": ['bhs'],
    "jñānotkṛṣṭa": ['mw'],
    "jñānottama": ['mw'],
    "jñānottarajñānin": ['bhs'],
    "jñānā": ['mw'],
    "jñānāgni": ['cae', 'mw'],
    "jñānājñānakṛta": ['mw'],
    "jñānākara": ['bhs', 'mw'],
    "jñānākaracūḍa": ['bhs'],
    "jñānāmṛta": ['mw'],
    "jñānānanda": ['mw'],
    "jñānānutpāda": ['mw'],
    "jñānārcijvalitaśarīra": ['bhs'],
    "jñānārcisāgaraśiri": ['bhs'],
    "jñānārcitejaśiri": ['bhs'],
    "jñānārciḥśrīsāgara": ['bhs'],
    "jñānārthin": ['cae'],
    "jñānārṇava": ['mw'],
    "jñānāsi": ['cae'],
    "jñānātman": ['mw'],
    "jñānāvabhāsatejas": ['bhs'],
    "jñānāvalokālaṃkāra": ['mw'],
    "jñānāvaraṇa": ['mw'],
    "jñānāvaraṇīya": ['mw'],
    "jñānāvasthita": ['mw'],
    "jñānīya": ['mw'],
    "jñānīyati": ['ap90'],
    "jñāpaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "jñāpakasamuccaya": ['mw'],
    "jñāpakāvalī": ['mw'],
    "jñāpana": ['cae', 'mw'],
    "jñāpanaṃ": ['ap90'],
    "jñāpanīya": ['cae', 'mw'],
    "jñāpita": ['ap90', 'mw'],
    "jñāpti": ['bhs', 'mw'],
    "jñāpya": ['cae', 'mw'],
    "jñās": ['cae', 'gra', 'mw'],
    "jñāta": ['ap90', 'bhs', 'cae', 'mw'],
    "jñātaka": ['mw'],
    "jñātakulīna": ['mw'],
    "jñātamātre": ['mw'],
    "jñātanandana": ['mw'],
    "jñātaputra": ['bhs', 'mw'],
    "jñātasarvasva": ['mw'],
    "jñātasiddhānta": ['mw'],
    "jñātatā": ['mw'],
    "jñātavya": ['ap90', 'cae', 'ddsa', 'mw'],
    "jñāteya": ['mw'],
    "jñāteyaṃ": ['ap90'],
    "jñāti": ['cae', 'ddsa', 'gra', 'mw'],
    "jñātibheda": ['cae', 'mw'],
    "jñātibhāva": ['cae', 'mw'],
    "jñātidāsī": ['mw'],
    "jñātika": ['bhs'],
    "jñātikarman": ['mw'],
    "jñātikārya": ['mw'],
    "jñātimant": ['cae'],
    "jñātimat": ['mw'],
    "jñātimukha": ['mw'],
    "jñātiprabhuka": ['cae', 'mw'],
    "jñātiprāya": ['cae', 'mw'],
    "jñātiputra": ['bhs', 'mw'],
    "jñātitva": ['cae', 'mw'],
    "jñātivid": ['mw'],
    "jñātiḥ": ['ap90'],
    "jñātra": ['bhs', 'cae', 'mw'],
    "jñātādharmakathā": ['mw'],
    "jñātānvaya": ['mw'],
    "jñātṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "jñātṛtva": ['mw'],
    "jñīps": ['cae'],
    "jñīpsyamāna": ['mw'],
    "jñīpsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "jā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jābāla": ['ddsa', 'mw'],
    "jābālaśruti": ['mw'],
    "jābālaḥ": ['ap90'],
    "jābāli": ['mw'],
    "jābālin": ['mw'],
    "jābāliḥ": ['ap90'],
    "jābālopaniṣad": ['mw'],
    "jābālāyana": ['mw'],
    "jābālīśvara": ['mw'],
    "jāgara": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "jāgara(t)": ['cped'],
    "jāgaraka": ['ap90', 'cae', 'mw'],
    "jāgaram": ['mw'],
    "jāgaranta": ['cped'],
    "jāgarati": ['cped'],
    "jāgaraṇa": ['cae', 'mw'],
    "jāgaraṇaṃ": ['ap90'],
    "jāgarikā": ['bhs'],
    "jāgarin": ['ap90', 'mw'],
    "jāgarita": ['ap90', 'cae', 'cped', 'mw'],
    "jāgaritadeśa": ['mw'],
    "jāgaritasthāna": ['cae', 'mw'],
    "jāgaritavat": ['mw'],
    "jāgaritānta": ['cae', 'mw'],
    "jāgaritṛ": ['ap90', 'mw'],
    "jāgariya": ['cped'],
    "jāgariyānuyoga": ['cped'],
    "jāgariṣṇu": ['cae', 'mw'],
    "jāgarotsava": ['mw'],
    "jāgartavya": ['mw'],
    "jāgarti": ['mw'],
    "jāgartiḥ": ['ap90'],
    "jāgarya": ['bhs'],
    "jāgaryā": ['mw'],
    "jāgarā": ['ap90', 'mw'],
    "jāgarūka": ['cae', 'gra', 'mw'],
    "jāgata": ['cae', 'ddsa', 'mw'],
    "jāgataṃ": ['ap90'],
    "jāgatineya": ['mw'],
    "jāghana": ['gra'],
    "jāghanī": ['ap90', 'cae', 'ddsa', 'mw'],
    "jāghanīguda": ['mw'],
    "jāgrad": ['mw'],
    "jāgradavasthā": ['mw'],
    "jāgraddaśā": ['mw'],
    "jāgradduṣvapnya": ['mw'],
    "jāgran": ['mw'],
    "jāgranmiśra": ['mw'],
    "jāgrat": ['ap90', 'cae', 'ddsa', 'mw'],
    "jāgratprapañca": ['mw'],
    "jāgratsvapna": ['cae', 'gra', 'mw'],
    "jāgraṇa": ['bhs'],
    "jāgriyā": ['mw'],
    "jāguḍa": ['mw'],
    "jāguḍaṃ": ['ap90'],
    "jāgṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "jāgṛta": ['bhs'],
    "jāgṛtavya": ['mw'],
    "jāgṛvas": ['cae', 'mw'],
    "jāgṛvi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jāha": ['mw'],
    "jāhaka": ['cae', 'mw'],
    "jāhakaḥ": ['ap90'],
    "jāhaṃ": ['ap90'],
    "jāhnava": ['cae', 'mw'],
    "jāhnavī": ['ap90', 'mw'],
    "jāhnavīya": ['cae', 'mw'],
    "jāhu": ['bhs'],
    "jāhuṣa": ['cae', 'gra', 'mw'],
    "jājala": ['mw'],
    "jājali": ['mw'],
    "jājalin": ['mw'],
    "jājalla": ['mw'],
    "jājalāyani": ['mw'],
    "jājamat": ['mw'],
    "jājanāga": ['mw'],
    "jājin": ['ap90', 'ddsa', 'mw'],
    "jājvalyamāna": ['mw'],
    "jāla": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "jālabaddha": ['mw'],
    "jālabandha": ['cae', 'mw'],
    "jālabhūṣaṇa": ['mw'],
    "jāladaṇḍa": ['mw'],
    "jālagardabha": ['mw'],
    "jālagavākṣa": ['mw'],
    "jālagavākṣaka": ['mw'],
    "jālagoṇikā": ['mw'],
    "jālahrada": ['mw'],
    "jālahāsinī": ['mw'],
    "jālaka": ['cae', 'ddsa', 'mw'],
    "jālakagardabha": ['mw'],
    "jālakajāta": ['cped'],
    "jālakamālin": ['mw'],
    "jālakarman": ['mw'],
    "jālakaṃ": ['ap90'],
    "jālaki": ['mw'],
    "jālakin": ['ap90'],
    "jālakinī": ['ap90', 'mw'],
    "jālakita": ['mw'],
    "jālakāra": ['mw'],
    "jālakāraka": ['mw'],
    "jālakīṭa": ['mw'],
    "jālakṣīrya": ['mw'],
    "jālamālā": ['cae', 'mw'],
    "jālamāni": ['mw'],
    "jālamānīya": ['mw'],
    "jālamārga": ['cae', 'mw'],
    "jālapacchanna": ['cped'],
    "jālapad": ['mw'],
    "jālapada": ['mw'],
    "jālapadī": ['mw'],
    "jālaprāyā": ['mw'],
    "jālapura": ['mw'],
    "jālapāda": ['cae', 'mw'],
    "jālapādabhuja": ['mw'],
    "jālapāśa": ['mw'],
    "jālasarasa": ['mw'],
    "jālavant": ['cae'],
    "jālavarvurika": ['mw'],
    "jālavarvūraka": ['mw'],
    "jālavat": ['ap90', 'mw'],
    "jālayati": ['bhs', 'cped'],
    "jālaṃ": ['ap90'],
    "jālaṃdhara": ['ap90', 'mw'],
    "jālaṃdharaḥ": ['ap90'],
    "jālaṃdhari": ['mw'],
    "jālaṃdharāyaṇa": ['mw'],
    "jālaṃdharāyaṇaka": ['mw'],
    "jāleti": ['cped'],
    "jāletuṁ": ['cped'],
    "jāli(n)": ['cped'],
    "jālika": ['cae', 'ddsa', 'mw'],
    "jālikaḥ": ['ap90'],
    "jālikā": ['bhs', 'ddsa', 'mw'],
    "jālin": ['bhs', 'mw'],
    "jālinī": ['ap90', 'bhs', 'cped', 'mw'],
    "jālinīmukha": ['bhs', 'mw'],
    "jālinīprabha": ['bhs'],
    "jālituṁ": ['cped'],
    "jālma": ['ap90', 'cae', 'ddsa', 'mw'],
    "jālmaka": ['ap90', 'mw'],
    "jālodgīrṇa": ['ddsa'],
    "jālopajīvin": ['cae', 'mw'],
    "jālora": ['ddsa', 'mw'],
    "jālya": ['mw'],
    "jālā": ['bhs'],
    "jālābaddhāṅgulipāṇipādatalatā": ['mw'],
    "jālāhatthapāda": ['cped'],
    "jālākṣa": ['cae', 'ddsa', 'mw'],
    "jālāmukha": ['mw'],
    "jālāntara": ['bhs'],
    "jālāsaṅkhāta": ['cped'],
    "jālāvanaddha": ['mw'],
    "jālāvātapāna": ['cped'],
    "jālāya": ['ddsa', 'mw'],
    "jālāṅgulika": ['mw'],
    "jālāṣa": ['cae', 'mw'],
    "jālāṣaṃ": ['ap90'],
    "jālī": ['mw'],
    "jālīdeśa": ['mw'],
    "jālūka": ['mw'],
    "jāmadagna": ['cae', 'ddsa', 'mw'],
    "jāmadagneya": ['ddsa', 'mw'],
    "jāmadagniya": ['mw'],
    "jāmadagnya": ['cae', 'mw'],
    "jāmadagnyadvādaśī": ['mw'],
    "jāmadagnyaka": ['mw'],
    "jāmadagnyaḥ": ['ap90'],
    "jāmadagnyāyita": ['mw'],
    "jāmala": ['mw'],
    "jāmaria": ['gra'],
    "jāmarya": ['gra', 'mw'],
    "jāmba": ['mw'],
    "jāmbava": ['mw'],
    "jāmbavaka": ['mw'],
    "jāmbavant": ['cae'],
    "jāmbavat": ['mw'],
    "jāmbavata": ['mw'],
    "jāmbavataka": ['mw'],
    "jāmbavatī": ['mw'],
    "jāmbavatīharaṇa": ['mw'],
    "jāmbavatīpati": ['mw'],
    "jāmbavatīvijaya": ['mw'],
    "jāmbavauṣṭha": ['mw'],
    "jāmbavoṣṭha": ['mw'],
    "jāmbavī": ['mw'],
    "jāmbeya": ['mw'],
    "jāmbha": ['mw'],
    "jāmbila": ['cae', 'mw'],
    "jāmboṣṭha": ['mw'],
    "jāmbudvīpaka": ['bhs', 'mw'],
    "jāmbuka": ['cae', 'ddsa', 'mw'],
    "jāmbukāñcana": ['bhs'],
    "jāmbunada": ['bhs'],
    "jāmbuvat": ['mw'],
    "jāmbuḍī": ['bhs'],
    "jāmbāla": ['bhs'],
    "jāmbīla": ['cae', 'mw'],
    "jāmbīra": ['mw'],
    "jāmbūdvīpaka": ['bhs'],
    "jāmbūnada": ['cae', 'ddsa', 'mw'],
    "jāmbūnadamaya": ['cae', 'mw'],
    "jāmbūnadaparvata": ['mw'],
    "jāmbūnadaprabha": ['mw'],
    "jāmbūnadaprabhāsa": ['bhs'],
    "jāmbūnadatejorāja": ['bhs'],
    "jāmbūnadī": ['mw'],
    "jāmeya": ['mw'],
    "jāmeyaḥ": ['ap90'],
    "jāmi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jāmikṛt": ['mw'],
    "jāmitra": ['ddsa', 'mw'],
    "jāmitraṃ": ['ap90'],
    "jāmitva": ['cae', 'ddsa', 'gra', 'mw'],
    "jāmivat": ['gra', 'mw'],
    "jāmiśaṃsa": ['mw'],
    "jāmuna": ['mw'],
    "jāmā": ['ap90', 'mw'],
    "jāmāta(r)": ['cped'],
    "jāmātara": ['cped'],
    "jāmātika": ['bhs'],
    "jāmātṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jāmātṛka": ['mw'],
    "jāmātṛkaḥ": ['ap90'],
    "jāmātṛtva": ['mw'],
    "jāmī": ['mw'],
    "jāna": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jāna(t)": ['cped'],
    "jānaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "jānaki": ['mw'],
    "jānakī": ['ap90', 'mw'],
    "jānakīdehabhūṣa": ['mw'],
    "jānakīgītā": ['mw'],
    "jānakīharaṇa": ['mw'],
    "jānakīmantra": ['mw'],
    "jānakīnātha": ['cae', 'mw'],
    "jānakīnāthaliṅga": ['mw'],
    "jānakīnāthaśarman": ['mw'],
    "jānakīpariṇaya": ['mw'],
    "jānakīramacandravilāsa": ['mw'],
    "jānakīrāghava": ['mw'],
    "jānakīsahasranāmastotra": ['mw'],
    "jānakīsvayaṃvara": ['mw'],
    "jānakīvallabha": ['cae', 'mw'],
    "jānakīya": ['mw'],
    "jānakīśa": ['cae', 'mw'],
    "jānamana": ['cped'],
    "jānana": ['bhs'],
    "jānanaka": ['bhs'],
    "jānanta": ['cped'],
    "jānanti": ['ddsa', 'mw'],
    "jānapada": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "jānapadaḥ": ['ap90'],
    "jānapadika": ['ap90', 'mw'],
    "jānapadī": ['mw'],
    "jānapati": ['bhs'],
    "jānapaṭicchanna": ['cped'],
    "jānarājya": ['cae', 'mw'],
    "jānat": ['mw'],
    "jānatā": ['bhs'],
    "jānavādika": ['mw'],
    "jānayati": ['bhs'],
    "jānaśruteya": ['mw'],
    "jānaśruti": ['mw'],
    "jānaṁ": ['cped'],
    "jānaṃ": ['ap90'],
    "jānaṃtapi": ['mw'],
    "jānemu": ['cped'],
    "jānevādika": ['mw'],
    "jāneya": ['bhs'],
    "jāneyya": ['cped'],
    "jāneyyuṁ": ['cped'],
    "jāneyyāma": ['cped'],
    "jāneyyāsi": ['cped'],
    "jānhava": ['ddsa'],
    "jānhavīya": ['ddsa'],
    "jāni": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jānikaḥ": ['bhs'],
    "jānimha": ['cped'],
    "jānipatayo": ['cped'],
    "jānipatī": ['cped'],
    "jānipita(r)": ['cped'],
    "jānissami": ['cped'],
    "jānissati": ['cped'],
    "jānitabba": ['cped'],
    "jānituṁ": ['cped'],
    "jānitvā": ['cped'],
    "jāniyāma": ['cped'],
    "jāniyāmase": ['cped'],
    "jāniyāna": ['cped'],
    "jāniṁha": ['cped'],
    "jāniṁsu": ['cped'],
    "jānovādika": ['mw'],
    "jānu": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jānucalana": ['ddsa', 'mw'],
    "jānudaghna": ['cae', 'mw'],
    "jānudaghne": ['mw'],
    "jānudaghnāmbhas": ['mw'],
    "jānujaṅgha": ['mw'],
    "jānuka": ['cae', 'cped', 'ddsa', 'mw'],
    "jānukā": ['cae', 'ddsa', 'mw'],
    "jānumaṇḍala": ['bhs', 'cped', 'mw'],
    "jānumātra": ['mw'],
    "jānunikuñcana": ['mw'],
    "jānuphalaka": ['mw'],
    "jānupracalana": ['mw'],
    "jānuprahṛta": ['mw'],
    "jānuprahṛtika": ['mw'],
    "jānusaṃdhi": ['mw'],
    "jānutrasta": ['bhs'],
    "jānuśiras": ['mw'],
    "jānuṣa": ['gra'],
    "jānv": ['mw'],
    "jānvakna": ['mw'],
    "jānvantarā": ['mw'],
    "jānvasthi": ['cae', 'ddsa', 'mw'],
    "jānvākna": ['mw'],
    "jānya": ['bhs', 'mw'],
    "jānā": ['cped'],
    "jānāhi": ['cped'],
    "jānāna": ['ap90', 'mw'],
    "jānārdana": ['mw'],
    "jānāti": ['cped'],
    "jānāyana": ['mw'],
    "jānī": ['mw'],
    "jāpa": ['cae', 'ddsa', 'mw'],
    "jāpaka": ['ap90', 'cae', 'mw'],
    "jāpana": ['mw'],
    "jāpanaṃ": ['ap90'],
    "jāpanā": ['bhs'],
    "jāpayati": ['bhs', 'cped'],
    "jāpaḥ": ['ap90'],
    "jāpetaya": ['cped'],
    "jāpeti": ['cped'],
    "jāpin": ['cae', 'mw'],
    "jāpya": ['ap90', 'cae', 'mw'],
    "jāra": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jārabharā": ['mw'],
    "jāradgava": ['ap90', 'mw'],
    "jāradvaya": ['mw'],
    "jāradvṛkṣa": ['mw'],
    "jāragarbha": ['ddsa', 'mw'],
    "jāragarbhā": ['mw'],
    "jāraghnī": ['mw'],
    "jāraja": ['cae', 'mw'],
    "jārajanman": ['mw'],
    "jārajāta": ['cae', 'mw'],
    "jārajātaka": ['cae', 'mw'],
    "jāraka": ['ap90', 'mw'],
    "jāramaṇya": ['mw'],
    "jāramāṇa": ['mw'],
    "jāratineya": ['mw'],
    "jāratkārava": ['mw'],
    "jārattana": ['cped'],
    "jāratā": ['cae', 'mw'],
    "jāravṛttānta": ['cae'],
    "jāray": ['gra'],
    "jāraya": ['mw'],
    "jārayanmakha": ['gra', 'mw'],
    "jāraḥ": ['ap90'],
    "jāraṇa": ['mw'],
    "jāraṇaṃ": ['ap90'],
    "jāraṇā": ['mw'],
    "jāraṇī": ['mw'],
    "jāria": ['gra'],
    "jārin": ['mw'],
    "jāriṇī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jārtika": ['mw'],
    "jārudhi": ['mw'],
    "jāruja": ['mw'],
    "jārya": ['gra', 'mw'],
    "jāryaka": ['ddsa', 'mw'],
    "jārāsaṃdhi": ['cae', 'mw'],
    "jārī": ['cped', 'mw'],
    "jārūthya": ['cae', 'mw'],
    "jārūthī": ['mw'],
    "jāsaṭa": ['ddsa', 'mw'],
    "jāspati": ['cae', 'ddsa', 'gra', 'mw'],
    "jāspatiḥ": ['ap90'],
    "jāspatya": ['cae', 'gra', 'mw'],
    "jāta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jāta(s)sara": ['cped'],
    "jātabala": ['cae', 'mw'],
    "jātabhāva": ['mw'],
    "jātabhī": ['mw'],
    "jātabrāhmaṇaśabda": ['mw'],
    "jātabuddhi": ['mw'],
    "jātadanta": ['cae', 'mw'],
    "jātadoṣa": ['mw'],
    "jātaharṣa": ['mw'],
    "jātahārda": ['mw'],
    "jātahāriṇī": ['mw'],
    "jātaikabhakti": ['mw'],
    "jātaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "jātakabhūṣaṇa": ['mw'],
    "jātakadarpaṇa": ['mw'],
    "jātakadhvani": ['mw'],
    "jātakalakṣaṇa": ['mw'],
    "jātakalāpa": ['mw'],
    "jātakamañjarī": ['mw'],
    "jātakamuktāvalī": ['mw'],
    "jātakapaddhati": ['mw'],
    "jātakaratna": ['mw'],
    "jātakarman": ['cae', 'ddsa', 'mw'],
    "jātakasaṃgraha": ['mw'],
    "jātakautuka": ['mw'],
    "jātakautūhala": ['mw'],
    "jātakopa": ['mw'],
    "jātakrodha": ['mw'],
    "jātakāma": ['mw'],
    "jātakāmbhonidhi": ['mw'],
    "jātakṣobha": ['mw'],
    "jātamaha": ['bhs'],
    "jātamanmatha": ['mw'],
    "jātamāsā": ['mw'],
    "jātamātra": ['cae', 'mw'],
    "jātamṛta": ['mw'],
    "jātanaṣṭa": ['mw'],
    "jātapakṣa": ['cae', 'mw'],
    "jātapratyaya": ['mw'],
    "jātaprāya": ['mw'],
    "jātaputra": ['mw'],
    "jātapāśa": ['mw'],
    "jātapūrva": ['cae', 'mw'],
    "jātarajas": ['mw'],
    "jātarasa": ['mw'],
    "jātaroma": ['mw'],
    "jātaroṣa": ['mw'],
    "jātarāga": ['mw'],
    "jātarūpa": ['cae', 'cped', 'mw'],
    "jātarūpamaya": ['cae', 'mw'],
    "jātarūpapariṣkṛta": ['mw'],
    "jātarūpapaṭirūpaka": ['cped'],
    "jātarūpaprabha": ['mw'],
    "jātarūpatā": ['mw'],
    "jātarūpaśila": ['mw'],
    "jātarūpya": ['bhs'],
    "jātasasneha": ['mw'],
    "jātasaṃkalpa": ['cae', 'mw'],
    "jātasaṃvatsarā": ['mw'],
    "jātasaṃvṛddha": ['mw'],
    "jātasena": ['mw'],
    "jātasenya": ['mw'],
    "jātasneha": ['mw'],
    "jātaspṛha": ['mw'],
    "jātasādhvasa": ['mw'],
    "jātatarṣa": ['mw'],
    "jātatokā": ['mw'],
    "jātavat": ['mw'],
    "jātaveda": ['cped', 'mw'],
    "jātavedas": ['cae', 'gra', 'mw'],
    "jātavedasa": ['mw'],
    "jātavedastva": ['mw'],
    "jātavedasya": ['mw'],
    "jātavedasī": ['mw'],
    "jātavedasīya": ['mw'],
    "jātavepathu": ['mw'],
    "jātaveśman": ['cae', 'mw'],
    "jātavibhrama": ['mw'],
    "jātavidyā": ['cae', 'gra', 'mw'],
    "jātavinaṣṭa": ['mw'],
    "jātaviśvāsa": ['cae', 'mw'],
    "jātavāsagṛha": ['mw'],
    "jātavāsaka": ['mw'],
    "jātaya": ['bhs'],
    "jātaśilā": ['mw'],
    "jātaśmaśru": ['mw'],
    "jātaśrama": ['mw'],
    "jātaśṛṅga": ['mw'],
    "jāterṣya": ['ddsa'],
    "jāteṣṭi": ['cae', 'mw'],
    "jāti": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "jātibhraṃśa": ['cae', 'mw'],
    "jātibhraṃśakara": ['cae', 'mw'],
    "jātibhraṣṭa": ['mw'],
    "jātibhāj": ['mw'],
    "jātibhūmaka": ['cped'],
    "jātibhūmika": ['cped'],
    "jātibrāhmaṇa": ['mw'],
    "jātidhamma": ['cped'],
    "jātidharma": ['cae', 'mw'],
    "jātidhvaṃsa": ['mw'],
    "jātidīpaka": ['mw'],
    "jātihīna": ['cae', 'mw'],
    "jātijarāmaraṇīya": ['bhs'],
    "jātijānapada": ['cae', 'ddsa', 'mw'],
    "jātijāramaṇīka": ['cped'],
    "jātijāramaṇīya": ['cped'],
    "jātijārūpaga": ['cped'],
    "jātijārūpagāmin": ['cped'],
    "jātijātika": ['cped'],
    "jātika": ['bhs'],
    "jātikhaya": ['cped'],
    "jātikhayāntadassi(n)": ['cped'],
    "jātikkhaya": ['cped'],
    "jātikośa": ['mw'],
    "jātikośī": ['mw'],
    "jātilakṣaṇa": ['mw'],
    "jātilinī": ['bhs'],
    "jātima(t)": ['cped'],
    "jātimaha": ['bhs', 'mw'],
    "jātimant": ['cae'],
    "jātimanta": ['cped'],
    "jātimat": ['ap90', 'mw'],
    "jātimattva": ['mw'],
    "jātimālā": ['mw'],
    "jātimātra": ['cae', 'mw'],
    "jātimātrajīvin": ['mw'],
    "jātimātropajīvin": ['mw'],
    "jātinirṇaya": ['mw'],
    "jātiparivṛtti": ['mw'],
    "jātiparṇī": ['mw'],
    "jātipattrī": ['mw'],
    "jātiphala": ['mw'],
    "jātiprajñāyate": ['bhs'],
    "jātisambheda": ['cped'],
    "jātisampanna": ['mw'],
    "jātisasya": ['mw'],
    "jātisaṃpanna": ['cae'],
    "jātismara": ['cae', 'mw'],
    "jātismarahrada": ['mw'],
    "jātismaratva": ['mw'],
    "jātismaratā": ['mw'],
    "jātismaraṇa": ['cae', 'mw'],
    "jātisvabhāva": ['mw'],
    "jātisāra": ['mw'],
    "jātisāṃkarya": ['mw'],
    "jātitas": ['cae', 'mw'],
    "jātithera": ['cped'],
    "jātitva": ['mw'],
    "jātitā": ['mw'],
    "jātivacana": ['mw'],
    "jātivailakṣaṇya": ['mw'],
    "jātivaira": ['mw'],
    "jātivibhaṅga": ['cped'],
    "jātivicāra": ['mw'],
    "jātiviveka": ['mw'],
    "jātivācaka": ['mw'],
    "jātivāda": ['bhs'],
    "jātiya": ['bhs', 'cped'],
    "jātiśabda": ['mw'],
    "jātiśasya": ['mw'],
    "jātiḥ": ['ap90'],
    "jātiṃdhara": ['mw'],
    "jātodaka": ['mw'],
    "jātokṣa": ['mw'],
    "jātu": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jātudhāna": ['ddsa', 'mw'],
    "jātudhānaḥ": ['ap90'],
    "jātuka": ['mw'],
    "jātukarṇa": ['bhs'],
    "jātuki": ['mw'],
    "jāturaki": ['mw'],
    "jātuṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "jāty": ['mw'],
    "jātya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "jātyandha": ['cae', 'ddsa', 'mw'],
    "jātyandhabadhira": ['cae', 'mw'],
    "jātyantarīyaka": ['bhs', 'mw'],
    "jātyapahārin": ['mw'],
    "jātyaratnamaya": ['mw'],
    "jātyaśva": ['mw'],
    "jātyutkarṣa": ['mw'],
    "jātyutpala": ['mw'],
    "jātyutpattikrama": ['mw'],
    "jātā": ['mw'],
    "jātābhiṣaṅga": ['mw'],
    "jātāgas": ['mw'],
    "jātāmarṣa": ['mw'],
    "jātānukampa": ['mw'],
    "jātāparādha": ['mw'],
    "jātāpatya": ['ddsa'],
    "jātāpatyā": ['mw'],
    "jātāstha": ['mw'],
    "jātāyana": ['mw'],
    "jātāśru": ['mw'],
    "jātī": ['ap90', 'ddsa', 'mw'],
    "jātīkośa": ['cae', 'mw'],
    "jātīmahī": ['bhs'],
    "jātīpattrī": ['mw'],
    "jātīphala": ['mw'],
    "jātīphalā": ['cae', 'mw'],
    "jātīrasa": ['mw'],
    "jātīrasaphalā": ['mw'],
    "jātīya": ['ap90', 'bhs', 'ddsa', 'mw'],
    "jātīyaka": ['mw'],
    "jātū": ['mw'],
    "jātūbharman": ['gra', 'mw'],
    "jātūkarṇa": ['cae', 'ddsa', 'mw'],
    "jātūkarṇaḥ": ['ap90'],
    "jātūkarṇya": ['ddsa', 'mw'],
    "jātūkarṇī": ['mw'],
    "jātūḥ": ['ap90'],
    "jātūṣṭhira": ['gra', 'mw'],
    "jātṛ": ['mw'],
    "jāva": ['bhs'],
    "jāvan": ['cae', 'gra', 'mw'],
    "jāvanikā": ['mw'],
    "jāvant": ['cae'],
    "jāvanya": ['mw'],
    "jāvanyaṃ": ['ap90'],
    "jāvat": ['gra', 'mw'],
    "jāvaḍa": ['mw'],
    "jāvita": ['bhs'],
    "jāvāyani": ['mw'],
    "jāya": ['ddsa'],
    "jāyadratha": ['mw'],
    "jāyaka": ['cae', 'ddsa', 'mw'],
    "jāyakaṃ": ['ap90'],
    "jāyala": ['mw'],
    "jāyampatikā": ['cped'],
    "jāyampatī": ['mw'],
    "jāyamāna": ['cped', 'mw'],
    "jāyanta": ['cped', 'mw'],
    "jāyanteya": ['mw'],
    "jāyantīputra": ['mw'],
    "jāyapatika": ['bhs'],
    "jāyapatikā": ['cped'],
    "jāyatana": ['cped'],
    "jāyate": ['bhs', 'cped'],
    "jāyati": ['cped'],
    "jāyendra": ['bhs'],
    "jāyenya": ['mw'],
    "jāyikā": ['cped'],
    "jāyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "jāyissati": ['cped'],
    "jāyitvā": ['cped'],
    "jāyu": ['ap90', 'cae', 'gra', 'mw'],
    "jāyuka": ['cae', 'mw'],
    "jāyā": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jāyāghna": ['mw'],
    "jāyājīva": ['mw'],
    "jāyāmpatika": ['mw'],
    "jāyānujīvin": ['mw'],
    "jāyānya": ['mw'],
    "jāyāpatika": ['bhs', 'cped'],
    "jāyāpatī": ['mw'],
    "jāyātva": ['mw'],
    "jāyāṃpatika": ['bhs'],
    "jāñati": ['cped'],
    "jāḍya": ['cae', 'ddsa', 'mw'],
    "jāḍyabhāva": ['ddsa'],
    "jāḍyaṃ": ['ap90'],
    "jāḍyāri": ['mw'],
    "jāḍāra": ['mw'],
    "jāḍāyana": ['mw'],
    "jāṃbavat": ['ap90'],
    "jāṃbavaṃ": ['ap90'],
    "jāṃbīraṃ": ['ap90'],
    "jāṃbūnadaṃ": ['ap90'],
    "jāṃdhita": ['mw'],
    "jāṃgala": ['ap90'],
    "jāṃgaliḥ": ['ap90'],
    "jāṃghika": ['ap90'],
    "jāṃgulaṃ": ['ap90'],
    "jāṃguliḥ": ['ap90'],
    "jāṃhagiri": ['mw'],
    "jāṃhāgira": ['mw'],
    "jāṃhāgiranagara": ['mw'],
    "jāṅgala": ['cae', 'ddsa', 'mw'],
    "jāṅgalapathika": ['mw'],
    "jāṅgali": ['mw'],
    "jāṅgalika": ['mw'],
    "jāṅgalin": ['mw'],
    "jāṅgalī": ['mw'],
    "jāṅghalāyana": ['mw'],
    "jāṅghi": ['mw'],
    "jāṅghika": ['cae', 'ddsa', 'mw'],
    "jāṅghāprahatika": ['mw'],
    "jāṅghāprahṛtika": ['mw'],
    "jāṅgula": ['mw'],
    "jāṅguli": ['bhs', 'mw'],
    "jāṅgulika": ['mw'],
    "jāṅgulā": ['mw'],
    "jāṅgulī": ['bhs', 'mw'],
    "jāṅmāyana": ['mw'],
    "jāṇu": ['cped'],
    "jāṇuka": ['cped'],
    "jāṇumaṇḍala": ['cped'],
    "jāṇḍaka": ['mw'],
    "jāṇḍāra": ['mw'],
    "jāṣaka": ['mw'],
    "jāṣkamada": ['mw'],
    "jāṭali": ['mw'],
    "jāṭalikā": ['mw'],
    "jāṭhara": ['ap90', 'cae', 'ddsa', 'mw'],
    "jāṭharya": ['mw'],
    "jāṭilika": ['mw'],
    "jāṭya": ['mw'],
    "jāṭāsuri": ['mw'],
    "jī": ['mw'],
    "jīgarta": ['mw'],
    "jīka": ['mw'],
    "jīla": ['cae', 'ddsa', 'mw'],
    "jīmūta": ['cae', 'ddsa', 'gra', 'mw'],
    "jīmūtaka": ['mw'],
    "jīmūtaketu": ['mw'],
    "jīmūtamūla": ['mw'],
    "jīmūtasvana": ['mw'],
    "jīmūtavarṣin": ['mw'],
    "jīmūtavāha": ['cae', 'mw'],
    "jīmūtavāhana": ['cae', 'mw'],
    "jīmūtavāhin": ['mw'],
    "jīmūtaḥ": ['ap90'],
    "jīmūtāṣṭamī": ['mw'],
    "jīna": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "jīra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jīraaśva": ['gra'],
    "jīradānu": ['cae', 'ddsa', 'gra', 'mw'],
    "jīraka": ['mw'],
    "jīrakaḥ": ['ap90'],
    "jīramāna": ['cped'],
    "jīrati": ['cped'],
    "jīraṅka": ['bhs'],
    "jīraṇa": ['mw'],
    "jīraṇata": ['cped'],
    "jīri": ['cae', 'cped', 'gra', 'mw'],
    "jīrikā": ['mw'],
    "jīriḥ": ['ap90'],
    "jīrti": ['mw'],
    "jīrvi": ['mw'],
    "jīrviḥ": ['ap90'],
    "jīrādhvara": ['gra', 'mw'],
    "jīrāśva": ['cae', 'gra', 'mw'],
    "jīrīyati": ['cped'],
    "jīrṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "jīrṇabudhna": ['mw'],
    "jīrṇabudhnaka": ['mw'],
    "jīrṇadevāyatana": ['cae'],
    "jīrṇadāru": ['mw'],
    "jīrṇajvara": ['mw'],
    "jīrṇajvarahara": ['mw'],
    "jīrṇajvarin": ['mw'],
    "jīrṇaka": ['ap90', 'bhs', 'mw'],
    "jīrṇamata": ['mw'],
    "jīrṇaparṇa": ['mw'],
    "jīrṇaparṇaja": ['mw'],
    "jīrṇapattra": ['mw'],
    "jīrṇapattrikā": ['mw'],
    "jīrṇaphañjī": ['mw'],
    "jīrṇapuṣpaka": ['mw'],
    "jīrṇatva": ['mw'],
    "jīrṇatā": ['cae', 'mw'],
    "jīrṇatājika": ['mw'],
    "jīrṇavajra": ['mw'],
    "jīrṇavastra": ['cae', 'mw'],
    "jīrṇavat": ['mw'],
    "jīrṇaviṣa": ['mw'],
    "jīrṇavāṭikā": ['mw'],
    "jīrṇaśakti": ['mw'],
    "jīrṇaṭīkā": ['mw'],
    "jīrṇi": ['cae', 'ddsa', 'mw'],
    "jīrṇiḥ": ['ap90'],
    "jīrṇoddhāra": ['mw'],
    "jīrṇoddhṛta": ['mw'],
    "jīrṇodyāna": ['cae', 'mw'],
    "jīrṇā": ['mw'],
    "jīrṇāmayajvara": ['mw'],
    "jīrṇāraṇya": ['cae'],
    "jīta": ['ap90', 'ddsa', 'mw'],
    "jītadhara": ['mw'],
    "jītakalpasūtra": ['mw'],
    "jītavyavahārasūtra": ['mw'],
    "jīti": ['cae', 'gra'],
    "jītiḥ": ['ap90'],
    "jīv": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jīva": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jīva(g)gāhaṁ": ['cped'],
    "jīva(t)": ['cped'],
    "jīvabarhis": ['mw'],
    "jīvabhadrā": ['mw'],
    "jīvabhojana": ['mw'],
    "jīvabhūta": ['cae', 'mw'],
    "jīvacūrṇa": ['mw'],
    "jīvad": ['mw'],
    "jīvada": ['mw'],
    "jīvadatta": ['cae', 'ddsa', 'mw'],
    "jīvadattaka": ['mw'],
    "jīvadayāprakaraṇa": ['mw'],
    "jīvadaśā": ['mw'],
    "jīvadbhartṛkā": ['mw'],
    "jīvadeva": ['mw'],
    "jīvadhana": ['mw'],
    "jīvadhanya": ['gra', 'mw'],
    "jīvadhānī": ['mw'],
    "jīvadvatsā": ['mw'],
    "jīvadvibhāga": ['mw'],
    "jīvadā": ['mw'],
    "jīvadāman": ['mw'],
    "jīvadāna": ['mw'],
    "jīvadānu": ['mw'],
    "jīvadātrī": ['mw'],
    "jīvadāyaka": ['cae', 'mw'],
    "jīvaghana": ['mw'],
    "jīvaghoṣasvāmin": ['mw'],
    "jīvaghātin": ['mw'],
    "jīvaghātya": ['mw'],
    "jīvaghātyā": ['mw'],
    "jīvagraha": ['mw'],
    "jīvagrāham": ['mw'],
    "jīvagṛbh": ['cae', 'gra', 'mw'],
    "jīvahiṃsā": ['mw'],
    "jīvaja": ['cae', 'mw'],
    "jīvajīva": ['mw'],
    "jīvajīvaka": ['cae', 'cped', 'mw'],
    "jīvaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "jīvakajīvaka": ['bhs'],
    "jīvakośa": ['mw'],
    "jīvakoṣaṇī": ['mw'],
    "jīvala": ['ap90', 'cae', 'ddsa', 'mw'],
    "jīvalaukika": ['mw'],
    "jīvaloka": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jīvalā": ['mw'],
    "jīvamandira": ['mw'],
    "jīvamaya": ['cae', 'mw'],
    "jīvameṣaka": ['mw'],
    "jīvamiśra": ['mw'],
    "jīvan": ['mw'],
    "jīvana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jīvanada": ['mw'],
    "jīvanahetu": ['cae', 'mw'],
    "jīvanaka": ['ap90', 'mw'],
    "jīvanasyā": ['cae', 'mw'],
    "jīvanatā": ['mw'],
    "jīvanauṣadha": ['mw'],
    "jīvanavat": ['mw'],
    "jīvanavidambana": ['mw'],
    "jīvanayoni": ['mw'],
    "jīvanaś": ['cae', 'ddsa', 'mw'],
    "jīvanetrī": ['mw'],
    "jīvani": ['mw'],
    "jīvanikā": ['mw'],
    "jīvanikāya": ['mw'],
    "jīvanmaraṇa": ['ddsa', 'mw'],
    "jīvanmriyamāṇa": ['mw'],
    "jīvanmukta": ['cae', 'mw'],
    "jīvanmukti": ['mw'],
    "jīvanmuktiviveka": ['mw'],
    "jīvanmṛta": ['cae', 'mw'],
    "jīvanmṛtaka": ['cae'],
    "jīvanmṛtatva": ['mw'],
    "jīvanopāya": ['mw'],
    "jīvanta": ['cped', 'mw'],
    "jīvantaka": ['bhs', 'mw'],
    "jīvantasvāmin": ['mw'],
    "jīvanti": ['mw'],
    "jīvantika": ['mw'],
    "jīvantikā": ['mw'],
    "jīvantiśāka": ['mw'],
    "jīvantiśūlāṃkṛ": ['mw'],
    "jīvantyāyana": ['mw'],
    "jīvantī": ['mw'],
    "jīvanvimukta": ['mw'],
    "jīvanā": ['mw'],
    "jīvanāghāta": ['mw'],
    "jīvanānta": ['mw'],
    "jīvanārha": ['mw'],
    "jīvanātha": ['mw'],
    "jīvanāvāsa": ['mw'],
    "jīvanāya": ['mw'],
    "jīvanāyaka": ['mw'],
    "jīvanāśa": ['mw'],
    "jīvanāśam": ['mw'],
    "jīvanī": ['mw'],
    "jīvanīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "jīvanīyā": ['mw'],
    "jīvapati": ['cae', 'ddsa', 'mw'],
    "jīvapatnī": ['mw'],
    "jīvapattra": ['mw'],
    "jīvapattrapracāyikā": ['mw'],
    "jīvapitṛ": ['cae', 'mw'],
    "jīvapitṛka": ['cae', 'mw'],
    "jīvapraja": ['cae', 'mw'],
    "jīvapriyā": ['mw'],
    "jīvapurā": ['cae', 'mw'],
    "jīvaputra": ['cae', 'gra', 'mw'],
    "jīvaputraka": ['mw'],
    "jīvaputrapracāyikā": ['mw'],
    "jīvapuṣpa": ['mw'],
    "jīvapuṣpā": ['mw'],
    "jīvapuṣṭā": ['mw'],
    "jīvapītasarga": ['gra', 'mw'],
    "jīvapṛṣṭā": ['mw'],
    "jīvarahita": ['mw'],
    "jīvarakta": ['mw'],
    "jīvarāja": ['mw'],
    "jīvarājadīkṣita": ['mw'],
    "jīvasamāsa": ['mw'],
    "jīvasarvasva": ['cae'],
    "jīvasaṃjña": ['mw'],
    "jīvasaṃkramaṇa": ['mw'],
    "jīvase": ['cae', 'ddsa'],
    "jīvasiddhi": ['mw'],
    "jīvasthāna": ['mw'],
    "jīvasuta": ['cae', 'mw'],
    "jīvasādhana": ['mw'],
    "jīvasākṣin": ['mw'],
    "jīvasāphalya": ['mw'],
    "jīvasū": ['cae', 'mw'],
    "jīvasūvarī": ['mw'],
    "jīvat": ['ap90', 'mw'],
    "jīvataṇḍula": ['mw'],
    "jīvatha": ['ap90', 'mw'],
    "jīvati": ['bhs', 'cped'],
    "jīvatokā": ['mw'],
    "jīvatpati": ['mw'],
    "jīvatpatikā": ['ddsa', 'mw'],
    "jīvatpatnī": ['mw'],
    "jīvatpitṛ": ['mw'],
    "jīvatpitṛka": ['mw'],
    "jīvatpitṛkanirṇaya": ['mw'],
    "jīvattokā": ['mw'],
    "jīvattokī": ['mw'],
    "jīvatva": ['mw'],
    "jīvatyāga": ['mw'],
    "jīvavadha": ['cae', 'mw'],
    "jīvavallī": ['mw'],
    "jīvavardhanī": ['mw'],
    "jīvavat": ['mw'],
    "jīvavatī": ['mw'],
    "jīvavicāra": ['mw'],
    "jīvavicāraprakaraṇa": ['mw'],
    "jīvavijaya": ['mw'],
    "jīvavinaya": ['mw'],
    "jīvaviṣaya": ['mw'],
    "jīvaviṣāṇa": ['mw'],
    "jīvavṛtti": ['mw'],
    "jīvayoni": ['mw'],
    "jīvayāja": ['gra', 'mw'],
    "jīvañjīvaka": ['cped'],
    "jīvaśarman": ['mw'],
    "jīvaśaṃsa": ['cae', 'gra', 'mw'],
    "jīvaśeṣa": ['cae', 'mw'],
    "jīvaśoṇita": ['mw'],
    "jīvaśreṣṭhā": ['mw'],
    "jīvaśuklā": ['mw'],
    "jīvaśāka": ['mw'],
    "jīvaśūlaka": ['bhs'],
    "jīvaśṛṅga": ['mw'],
    "jīvaṃdharaṇacaritra": ['mw'],
    "jīvaṃjīva": ['mw'],
    "jīvaṃjīvaka": ['cae', 'mw'],
    "jīvaṃjīvika": ['mw'],
    "jīvaṃta": ['ap90'],
    "jīvaṃtikaḥ": ['ap90'],
    "jīvendhana": ['mw'],
    "jīvika": ['bhs'],
    "jīvikā": ['ap90', 'cped', 'ddsa', 'mw'],
    "jīvikākṛ": ['mw'],
    "jīvikāpanna": ['mw'],
    "jīvikāprāpta": ['mw'],
    "jīvin": ['ap90', 'cae', 'ddsa', 'mw'],
    "jīvita": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "jīvitabba": ['cped'],
    "jīvitabhūta": ['mw'],
    "jīvitada": ['mw'],
    "jīvitagupta": ['mw'],
    "jīvitagṛdhnutā": ['mw'],
    "jīvitahārin": ['mw'],
    "jīvitajñā": ['mw'],
    "jīvitaka": ['bhs'],
    "jīvitakāla": ['mw'],
    "jīvitakṣaya": ['cae', 'ddsa', 'mw'],
    "jīvitamaraṇa": ['cae', 'mw'],
    "jīvitanikanti": ['cped'],
    "jīvitanātha": ['cae', 'mw'],
    "jīvitaparikkhārā": ['cped'],
    "jīvitapradāyin": ['cae', 'mw'],
    "jīvitapriya": ['cae', 'mw'],
    "jīvitasama": ['cae', 'ddsa', 'mw'],
    "jīvitasarvasva": ['cae', 'mw'],
    "jīvitasaṃskāra": ['bhs'],
    "jīvitasaṃśaya": ['cae', 'mw'],
    "jīvitatṛṣṇā": ['cae', 'mw'],
    "jīvitavya": ['ap90', 'cae', 'ddsa', 'mw'],
    "jīvitavyasaṃdeha": ['mw'],
    "jīvitavyaviṣaya": ['mw'],
    "jīvitavyaya": ['mw'],
    "jīvitayopana": ['mw'],
    "jīvitepsu": ['mw'],
    "jīviteśa": ['cae', 'ddsa', 'mw'],
    "jīviteśvara": ['cae', 'mw'],
    "jīviteśā": ['mw'],
    "jīvitindriya": ['cped'],
    "jīvitodvahana": ['cae', 'mw'],
    "jīvitukāma": ['mw'],
    "jīvitva": ['mw'],
    "jīvitvā": ['cped'],
    "jīvitākāṅkṣin": ['ddsa', 'mw'],
    "jīvitānta": ['cae', 'mw'],
    "jīvitāntaga": ['mw'],
    "jīvitāntaka": ['cae', 'mw'],
    "jīvitāntakara": ['mw'],
    "jīvitāsā": ['cped'],
    "jīvitātyaya": ['cae', 'mw'],
    "jīvitāvabhṛtha": ['mw'],
    "jīvitāvasāna": ['cae', 'mw'],
    "jīvitāśā": ['cae', 'mw'],
    "jīvopalambhaprakaraṇa": ['mw'],
    "jīvopāya": ['mw'],
    "jīvorṇā": ['mw'],
    "jīvotsarga": ['mw'],
    "jīvya": ['cae', 'mw'],
    "jīvyaṃ": ['ap90'],
    "jīvyopāya": ['mw'],
    "jīvyā": ['mw'],
    "jīvā": ['ap90', 'mw'],
    "jīvābhigamasūtra": ['mw'],
    "jīvādhāna": ['mw'],
    "jīvāditya": ['mw'],
    "jīvādāna": ['mw'],
    "jīvāgāra": ['mw'],
    "jīvājīvādhārakṣetra": ['mw'],
    "jīvālā": ['mw'],
    "jīvānanda": ['mw'],
    "jīvāntaka": ['mw'],
    "jīvānusiddhikulaka": ['mw'],
    "jīvāpita": ['mw'],
    "jīvāstikāya": ['mw'],
    "jīvātman": ['cae', 'ddsa', 'mw'],
    "jīvātu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jīvātukāmyā": ['mw'],
    "jīvātumat": ['mw'],
    "jīvāśa": ['mw'],
    "jīvāśaṅkin": ['cae', 'mw'],
    "jīvāśā": ['mw'],
    "jīvī": ['mw'],
    "jīyittha": ['cped'],
    "jū": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jūhana": ['cped'],
    "jūjuvas": ['cae', 'mw'],
    "jūjuvāna": ['cae', 'mw'],
    "jūka": ['mw'],
    "jūkaḥ": ['ap90'],
    "jūmaranandin": ['mw'],
    "jūr": ['ap90', 'mw'],
    "jūra": ['ddsa', 'mw'],
    "jūria": ['gra'],
    "jūrti": ['mw'],
    "jūrtiḥ": ['ap90'],
    "jūrv": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "jūrya": ['cae', 'gra', 'mw'],
    "jūrī": ['mw'],
    "jūrṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "jūrṇi": ['ap90', 'cae', 'gra', 'mw'],
    "jūrṇin": ['cae', 'gra', 'mw'],
    "jūrṇāhva": ['mw'],
    "jūrṇāhvaya": ['mw'],
    "jūrṇākhya": ['mw'],
    "jūrṇī": ['cae', 'mw'],
    "jūta": ['ap90', 'mw'],
    "jūti": ['cae', 'gra', 'mw'],
    "jūtikā": ['mw'],
    "jūtimant": ['cae'],
    "jūtimat": ['mw'],
    "jūtiḥ": ['ap90'],
    "jūḥ": ['ap90'],
    "jūṣ": ['ap90', 'mw'],
    "jūṣa": ['mw'],
    "jūṣaḥ": ['ap90'],
    "jūṣaṇa": ['mw'],
    "jūṭa": ['ddsa', 'mw'],
    "jūṭaka": ['mw'],
    "jūṭakaṃ": ['ap90'],
    "jūṭaḥ": ['ap90'],
    "jūṭikā": ['mw'],
    "jṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "jṛbh": ['ap90'],
    "jṛmbh": ['cae', 'ddsa', 'gra', 'mw'],
    "jṛmbha": ['cae', 'ddsa', 'mw'],
    "jṛmbhaka": ['mw'],
    "jṛmbhaṇa": ['cae', 'mw'],
    "jṛmbhaṇakara": ['cae'],
    "jṛmbhikā": ['mw'],
    "jṛmbhin": ['mw'],
    "jṛmbhita": ['cae', 'mw'],
    "jṛmbhiṇī": ['mw'],
    "jṛmbhā": ['mw'],
    "jṛmbhāvat": ['mw'],
    "jṛmbhīkṛta": ['bhs'],
    "jṛṃbhakaḥ": ['ap90'],
    "jṛṃbhaḥ": ['ap90'],
    "jṛṃbhaṇa": ['ap90'],
    "jṛṃbhita": ['ap90'],
    "jṛṅga": ['mw'],
    "jṛṅgi": ['mw'],
    "jṝ": ['ap90', 'mw'],
    "ka": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ka cana": ['cped'],
    "ka ci": ['cped'],
    "kab": ['ap90', 'mw'],
    "kabala": ['cped'],
    "kabaliṅkāra": ['cped'],
    "kabalāvacchedakaṁ": ['cped'],
    "kabandha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kabandhamuni": ['mw'],
    "kabandhatva": ['mw'],
    "kabandhatā": ['mw'],
    "kabandhavadha": ['mw'],
    "kabandhin": ['cae', 'gra', 'mw'],
    "kabara": ['ap90', 'cae', 'ddsa', 'mw'],
    "kabaracchāya": ['cped'],
    "kabarī": ['ap90'],
    "kabaḷa": ['cped'],
    "kabaḷikā": ['cped'],
    "kabaḷīkāra": ['cped'],
    "kabaṃdhaḥ": ['ap90'],
    "kabaṃdhin": ['ap90'],
    "kabhalli": ['bhs'],
    "kabila": ['ap90', 'mw'],
    "kabittha": ['mw'],
    "kabitthaḥ": ['ap90'],
    "kabru": ['mw'],
    "kabuli": ['mw'],
    "kabuliḥ": ['ap90'],
    "kac": ['ap90', 'gra', 'mw'],
    "kaca": ['bhs', 'cae', 'ddsa', 'mw'],
    "kacabhāra": ['ddsa', 'mw'],
    "kacadugdhikā": ['mw'],
    "kacagraha": ['mw'],
    "kacagrahaṇa": ['mw'],
    "kacahasta": ['mw'],
    "kacaka": ['mw'],
    "kacamāla": ['mw'],
    "kacapa": ['mw'],
    "kacapakṣa": ['mw'],
    "kacapāśa": ['mw'],
    "kacaripuphalā": ['mw'],
    "kacarūpin": ['cae', 'mw'],
    "kacavara": ['cped'],
    "kacaḥ": ['ap90'],
    "kacaṃgalaḥ": ['ap90'],
    "kacaṃganaṃ": ['ap90'],
    "kacaṅgala": ['mw'],
    "kacaṅgalā": ['bhs'],
    "kacaṭatapagajaḍadaba": ['cae', 'ddsa'],
    "kaccara": ['ap90', 'mw'],
    "kaccati": ['bhs'],
    "kaccaṭa": ['mw'],
    "kaccaṭaṃ": ['ap90'],
    "kaccha": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kacchabhū": ['mw'],
    "kacchadeśa": ['mw'],
    "kacchajā": ['mw'],
    "kacchaka": ['cped'],
    "kacchamāna": ['cped'],
    "kacchanīra": ['mw'],
    "kacchanīrabila": ['mw'],
    "kacchapa": ['cae', 'cped', 'mw'],
    "kacchapadeśa": ['mw'],
    "kacchapaghāta": ['mw'],
    "kacchapaka": ['mw'],
    "kacchapikā": ['ap90', 'mw'],
    "kacchapuṭa": ['mw'],
    "kacchapā": ['bhs'],
    "kacchapāri": ['mw'],
    "kacchapī": ['mw'],
    "kaccharuhā": ['mw'],
    "kacchavihāra": ['mw'],
    "kacchaḥ": ['ap90'],
    "kacchaṭikā": ['ap90', 'mw'],
    "kaccheśvara": ['mw'],
    "kaccheṣṭa": ['mw'],
    "kacchiya": ['mw'],
    "kacchora": ['mw'],
    "kacchoraṃ": ['ap90'],
    "kacchoṭikā": ['ap90', 'mw'],
    "kacchu": ['mw'],
    "kacchughna": ['mw'],
    "kacchughnī": ['mw'],
    "kacchula": ['bhs'],
    "kacchumatī": ['ap90'],
    "kacchura": ['ap90', 'mw'],
    "kacchurā": ['mw'],
    "kacchuḥ": ['ap90'],
    "kacchā": ['cped', 'mw'],
    "kacchādi": ['mw'],
    "kacchāhāra": ['bhs'],
    "kacchālaṃkāra": ['mw'],
    "kacchānta": ['mw'],
    "kacchāntaruhā": ['mw'],
    "kacchāra": ['mw'],
    "kacchāṭikā": ['bhs', 'mw'],
    "kacchāṭī": ['mw'],
    "kacchū": ['cped', 'mw'],
    "kacchūmatī": ['mw'],
    "kacchūrākṣasa": ['mw'],
    "kacci": ['cped'],
    "kaccid": ['cae', 'ddsa', 'mw'],
    "kaccit": ['ap90'],
    "kacela": ['mw'],
    "kacelaṃ": ['ap90'],
    "kaceśvara": ['mw'],
    "kacora": ['mw'],
    "kacu": ['mw'],
    "kacurāya": ['mw'],
    "kacuḥ": ['ap90'],
    "kacvī": ['ap90', 'mw'],
    "kacvīvana": ['mw'],
    "kacā": ['mw'],
    "kacācita": ['mw'],
    "kacākaci": ['ap90', 'ddsa', 'mw'],
    "kacāku": ['ap90', 'mw'],
    "kacāmoda": ['mw'],
    "kacāra": ['mw'],
    "kacāṭura": ['mw'],
    "kacāṭuraḥ": ['ap90'],
    "kad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kada": ['ap90', 'mw'],
    "kadadhvaga": ['mw'],
    "kadadhvan": ['mw'],
    "kadagni": ['mw'],
    "kadaka": ['mw'],
    "kadakaṃ": ['ap90'],
    "kadakṣara": ['mw'],
    "kadala": ['cae', 'ddsa', 'mw'],
    "kadalaka": ['mw'],
    "kadalaḥ": ['ap90'],
    "kadalikā": ['ap90', 'cae', 'mw'],
    "kadalimigapavarapaccttharaṇa": ['cped'],
    "kadalin": ['ap90', 'mw'],
    "kadalā": ['mw'],
    "kadalī": ['cped', 'mw'],
    "kadalīgarbha": ['mw'],
    "kadalīgarbhā": ['mw'],
    "kadalīgṛha": ['cae'],
    "kadalīkanda": ['mw'],
    "kadalīkṣatā": ['ap90', 'mw'],
    "kadalīskandha": ['mw'],
    "kadalīsukham": ['mw'],
    "kadamba": ['cae', 'ddsa', 'mw'],
    "kadambabhramamaṇḍala": ['mw'],
    "kadambada": ['mw'],
    "kadambagola": ['cae', 'mw'],
    "kadambaka": ['cae', 'mw'],
    "kadambakorakanyāya": ['mw'],
    "kadambakīkṛ": ['mw'],
    "kadambapuṣpatva": ['cae'],
    "kadambapuṣpā": ['mw'],
    "kadambapuṣpī": ['mw'],
    "kadambavallarī": ['mw'],
    "kadambavāyu": ['mw'],
    "kadambavṛtta": ['mw'],
    "kadambayuddha": ['mw'],
    "kadambikā": ['mw'],
    "kadambānila": ['mw'],
    "kadambī": ['mw'],
    "kadana": ['cae', 'ddsa', 'mw'],
    "kadanapriya": ['mw'],
    "kadanapura": ['mw'],
    "kadanaṃ": ['ap90'],
    "kadanna": ['ddsa', 'mw'],
    "kadannatā": ['mw'],
    "kadapatya": ['mw'],
    "kadara": ['mw'],
    "kadaraḥ": ['ap90'],
    "kadariya": ['cped'],
    "kadartha": ['cae', 'ddsa', 'gra', 'mw'],
    "kadarthana": ['cae', 'ddsa', 'mw'],
    "kadarthanīya": ['mw'],
    "kadarthay": ['cae'],
    "kadarthaya": ['mw'],
    "kadarthita": ['mw'],
    "kadarthīkṛ": ['mw'],
    "kadarthīkṛti": ['mw'],
    "kadarya": ['bhs', 'cae', 'ddsa', 'mw'],
    "kadaryabhāva": ['mw'],
    "kadaryatva": ['mw'],
    "kadaryatā": ['mw'],
    "kadaśva": ['mw'],
    "kadaṃbadaḥ": ['ap90'],
    "kadaṃbaḥ": ['ap90'],
    "kaddama": ['cped'],
    "kaddamamodaka": ['cped'],
    "kadgara": ['bhs'],
    "kadha": ['gra'],
    "kadhapriya": ['ap90', 'cae', 'gra', 'mw'],
    "kadhaprī": ['cae', 'gra', 'mw'],
    "kadhi": ['mw'],
    "kadindriya": ['mw'],
    "kadindriyagaṇa": ['mw'],
    "kadratha": ['mw'],
    "kadriac": ['gra'],
    "kadru": ['ap90', 'cae', 'ddsa', 'mw'],
    "kadruja": ['mw'],
    "kadruka": ['mw'],
    "kadruputra": ['mw'],
    "kadrusuta": ['mw'],
    "kadruṇa": ['ap90', 'mw'],
    "kadryañc": ['mw'],
    "kadrū": ['gra', 'mw'],
    "kadrūka": ['mw'],
    "kadrūṇa": ['mw'],
    "kaduṣṇa": ['mw'],
    "kaduṣṭra": ['mw'],
    "kadvada": ['mw'],
    "kadvara": ['mw'],
    "kadvaraṃ": ['ap90'],
    "kadvat": ['mw'],
    "kadvindu": ['mw'],
    "kadā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kadāci": ['cped'],
    "kadāci karahaci": ['cped'],
    "kadācikāt": ['bhs'],
    "kadācāra": ['mw'],
    "kadāhāra": ['mw'],
    "kadākhya": ['bhs', 'mw'],
    "kadākāra": ['mw'],
    "kadāmatta": ['mw'],
    "kadāśaya": ['mw'],
    "kadīśitṛ": ['mw'],
    "kadūhi": ['mw'],
    "kag": ['ap90', 'mw'],
    "kagittha": ['mw'],
    "kahaya": ['mw'],
    "kahaṁ": ['cped'],
    "kahi": ['bhs'],
    "kahika": ['mw'],
    "kahlaṇa": ['mw'],
    "kahlāra": ['cae', 'mw'],
    "kahlāraṃ": ['ap90'],
    "kahola": ['mw'],
    "kahoḍa": ['cae', 'mw'],
    "kahva": ['mw'],
    "kahvaḥ": ['ap90'],
    "kahāhaḥ": ['ap90'],
    "kahāpaṇa": ['bhs', 'cped'],
    "kahāpaṇaka": ['cped'],
    "kahāpaṇika": ['cped'],
    "kahūya": ['mw'],
    "kahūṣa": ['mw'],
    "kai": ['ap90', 'mw'],
    "kaicchikila": ['mw'],
    "kaidarbha": ['mw'],
    "kaideva": ['mw'],
    "kaidāra": ['ap90', 'mw'],
    "kaidāraka": ['mw'],
    "kaidārika": ['ddsa', 'mw'],
    "kaidārya": ['mw'],
    "kaijava": ['mw'],
    "kaikasa": ['mw'],
    "kaikasaḥ": ['ap90'],
    "kaikasī": ['mw'],
    "kaikaya": ['mw'],
    "kaikayaḥ": ['ap90'],
    "kaikayī": ['mw'],
    "kaikeya": ['cae', 'ddsa', 'mw'],
    "kaikeyaḥ": ['ap90'],
    "kaikeyī": ['mw'],
    "kaila": ['mw'],
    "kailakila": ['mw'],
    "kailakilaḥ": ['ap90'],
    "kailaṃ": ['ap90'],
    "kailikila": ['mw'],
    "kailiñja": ['mw'],
    "kailāsa": ['cae', 'ddsa', 'mw'],
    "kailāsaniketana": ['mw'],
    "kailāsanātha": ['mw'],
    "kailāsapati": ['mw'],
    "kailāsapaṇḍita": ['mw'],
    "kailāsaukas": ['mw'],
    "kailāsaśikharavāsin": ['mw'],
    "kailāsaḥ": ['ap90'],
    "kailāta": ['mw'],
    "kailātaka": ['mw'],
    "kailāvata": ['mw'],
    "kaimarthakya": ['mw'],
    "kaimarthya": ['ddsa', 'mw'],
    "kaimutika": ['ddsa', 'mw'],
    "kaimutikanyāya": ['mw'],
    "kaimutikaḥ": ['ap90'],
    "kaimutya": ['mw'],
    "kaimutyanyāya": ['mw'],
    "kaimāyani": ['mw'],
    "kaineya": ['bhs'],
    "kainnara": ['ap90'],
    "kairaleya": ['mw'],
    "kairalī": ['mw'],
    "kairava": ['ddsa', 'mw'],
    "kairavabandhu": ['mw'],
    "kairavakorakīya": ['mw'],
    "kairavaḥ": ['ap90'],
    "kairavin": ['ap90', 'mw'],
    "kairaviṇī": ['ap90', 'ddsa', 'mw'],
    "kairaviṇīkhaṇḍa": ['mw'],
    "kairavī": ['mw'],
    "kairaṇaka": ['mw'],
    "kairiśi": ['cae', 'ddsa', 'mw'],
    "kairmedura": ['mw'],
    "kairāla": ['mw'],
    "kairālī": ['mw'],
    "kairāta": ['ap90', 'cae', 'ddsa', 'mw'],
    "kairātaka": ['ap90', 'mw'],
    "kairātasaras": ['mw'],
    "kairātika": ['ap90'],
    "kairāṭaka": ['mw'],
    "kairāṭakaḥ": ['ap90'],
    "kaitaka": ['ddsa', 'mw'],
    "kaitakaṃ": ['ap90'],
    "kaitava": ['cae', 'ddsa', 'mw'],
    "kaitavaka": ['mw'],
    "kaitavakaṃ": ['ap90'],
    "kaitavaprayoga": ['mw'],
    "kaitavavāda": ['mw'],
    "kaitavaṃ": ['ap90'],
    "kaitaveya": ['mw'],
    "kaitavya": ['mw'],
    "kaitavāpahnuti": ['mw'],
    "kaitavāyana": ['mw'],
    "kaitavāyani": ['mw'],
    "kaitavī": ['mw'],
    "kaitiputra": ['mw'],
    "kaitāyana": ['mw'],
    "kaivala": ['mw'],
    "kaivalya": ['cae', 'ddsa', 'mw'],
    "kaivalyadīpikā": ['mw'],
    "kaivalyakalpadruma": ['mw'],
    "kaivalyatantra": ['mw'],
    "kaivalyaṃ": ['ap90'],
    "kaivalyendra": ['mw'],
    "kaivalyopaniṣad": ['mw'],
    "kaivalyānanda": ['mw'],
    "kaivalyāśrama": ['mw'],
    "kaivarta": ['bhs', 'cae', 'ddsa', 'mw'],
    "kaivartaka": ['mw'],
    "kaivartakaḥ": ['ap90'],
    "kaivartamusta": ['mw'],
    "kaivartamustaka": ['mw'],
    "kaivartamustā": ['mw'],
    "kaivartaḥ": ['ap90'],
    "kaivartikā": ['mw'],
    "kaivartimustaka": ['mw'],
    "kaivartī": ['mw'],
    "kaivartīmustaka": ['mw'],
    "kaivartīya": ['mw'],
    "kaiyaṭa": ['mw'],
    "kaiyyaṭa": ['mw'],
    "kaiñjalka": ['bhs', 'mw'],
    "kaiśava": ['ddsa', 'mw'],
    "kaiśika": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaiśikī": ['mw'],
    "kaiśina": ['mw'],
    "kaiśinya": ['mw'],
    "kaiśora": ['mw'],
    "kaiśoraka": ['mw'],
    "kaiśorakaguggulu": ['mw'],
    "kaiśoravayas": ['mw'],
    "kaiśoraṃ": ['ap90'],
    "kaiśori": ['mw'],
    "kaiśorikeya": ['mw'],
    "kaiśorya": ['mw'],
    "kaiśya": ['mw'],
    "kaiśyaṃ": ['ap90'],
    "kaiḍarya": ['mw'],
    "kaiṃdarbha": ['mw'],
    "kaiṃdāsa": ['mw'],
    "kaiṃdāsāyana": ['mw'],
    "kaiṃkalāyana": ['mw'],
    "kaiṃkarya": ['mw'],
    "kaiṃkaryaṃ": ['ap90'],
    "kaiṃkarāyaṇa": ['mw'],
    "kaiṃkirāta": ['cae', 'mw'],
    "kaiṃkirātaḥ": ['ap90'],
    "kaiṃnara": ['mw'],
    "kaiṃśuka": ['mw'],
    "kaiṃśukaṃ": ['ap90'],
    "kaiṅkirāta": ['ddsa'],
    "kaiṣkindha": ['mw'],
    "kaiṭa": ['ap90', 'mw'],
    "kaiṭabha": ['bhs', 'cae', 'ddsa', 'mw'],
    "kaiṭabhabhid": ['mw'],
    "kaiṭabhadviṣ": ['mw'],
    "kaiṭabhahan": ['mw'],
    "kaiṭabhajit": ['mw'],
    "kaiṭabhaḥ": ['ap90'],
    "kaiṭabheśvaralakṣaṇa": ['mw'],
    "kaiṭabheśvarī": ['mw'],
    "kaiṭabhārdana": ['mw'],
    "kaiṭabhāri": ['mw'],
    "kaiṭarya": ['mw'],
    "kaj": ['ap90', 'mw'],
    "kaja": ['ap90', 'cae', 'ddsa', 'mw'],
    "kajiṅga": ['mw'],
    "kajjala": ['cae', 'ddsa', 'mw'],
    "kajjaladhvaja": ['mw'],
    "kajjalamaya": ['mw'],
    "kajjalarocaka": ['mw'],
    "kajjalaṃ": ['ap90'],
    "kajjalikā": ['mw'],
    "kajjalita": ['ap90', 'mw'],
    "kajjalī": ['mw'],
    "kajjalītīrtha": ['mw'],
    "kajjvala": ['mw'],
    "kajjvalaṃ": ['ap90'],
    "kajāsana": ['mw'],
    "kajāva": ['bhs'],
    "kak": ['ap90', 'mw'],
    "kakaca": ['cped'],
    "kakacopama": ['cped'],
    "kakacūpama": ['cped'],
    "kakacūpamaovāda": ['cped'],
    "kakacūpamovāda": ['cped'],
    "kakacūpamā": ['cped'],
    "kakajākṛta": ['ap90', 'mw'],
    "kakanda": ['mw'],
    "kakara": ['mw'],
    "kakaraḥ": ['ap90'],
    "kakardu": ['gra', 'mw'],
    "kakarduḥ": ['ap90'],
    "kakaṃdaḥ": ['ap90'],
    "kakeruka": ['mw'],
    "kakerukaḥ": ['ap90'],
    "kakh": ['ap90', 'mw'],
    "kakhatīra": ['mw'],
    "kakhorda": ['bhs'],
    "kakhyā": ['ap90', 'mw'],
    "kakk": ['ap90', 'mw'],
    "kakka": ['cped'],
    "kakkala": ['mw'],
    "kakkarāja": ['mw'],
    "kakkasa": ['cped'],
    "kakkassa": ['cped'],
    "kakkaṭa": ['mw'],
    "kakkaṭaka": ['cped'],
    "kakkaṭaḥ": ['ap90'],
    "kakkh": ['ap90', 'mw'],
    "kakkhaḷa": ['cped'],
    "kakkhaṭa": ['ap90', 'bhs', 'mw'],
    "kakkhaṭapattraka": ['mw'],
    "kakkhaṭatva": ['bhs'],
    "kakkhaṭī": ['ap90', 'bhs', 'mw'],
    "kakkinda": ['mw'],
    "kakkola": ['cae', 'ddsa', 'mw'],
    "kakkolaka": ['mw'],
    "kakkolaḥ": ['ap90'],
    "kakkolikā": ['mw'],
    "kakkolī": ['mw'],
    "kakkula": ['mw'],
    "kakkulaḥ": ['ap90'],
    "kakub": ['mw'],
    "kakubbhaṇḍa": ['mw'],
    "kakubh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kakubha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kakubhamaya": ['mw'],
    "kakubhvat": ['mw'],
    "kakubhā": ['mw'],
    "kakubhādinī": ['mw'],
    "kakubhākāra": ['mw'],
    "kakubjaya": ['ddsa', 'mw'],
    "kakuca": ['mw'],
    "kakucchanda": ['bhs'],
    "kakud": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kakuda": ['cae', 'ddsa', 'mw'],
    "kakudakātyāyana": ['bhs', 'mw'],
    "kakudarūpin": ['mw'],
    "kakudavat": ['mw'],
    "kakudaḥ": ['ap90'],
    "kakuddruma": ['mw'],
    "kakudha": ['cped'],
    "kakudin": ['mw'],
    "kakudman": ['cae', 'mw'],
    "kakudmant": ['cae'],
    "kakudmat": ['ap90', 'ddsa', 'gra', 'mw'],
    "kakudmatī": ['mw'],
    "kakudmi": ['mw'],
    "kakudmikanyā": ['mw'],
    "kakudmin": ['ap90', 'cae', 'ddsa', 'mw'],
    "kakudminī": ['mw'],
    "kakudruma": ['ddsa'],
    "kakudvat": ['ap90', 'mw'],
    "kakudvatī": ['mw'],
    "kakudākṣa": ['mw'],
    "kakudāvarta": ['mw'],
    "kakudāvartin": ['mw'],
    "kakuha": ['ap90', 'cae', 'gra', 'mw'],
    "kakuhastinā": ['mw'],
    "kakum": ['mw'],
    "kakummatī": ['mw'],
    "kakummukha": ['ddsa', 'mw'],
    "kakun": ['mw'],
    "kakundara": ['ddsa', 'mw'],
    "kakunmant": ['cae'],
    "kakunmat": ['mw'],
    "kakup": ['mw'],
    "kakupkāram": ['mw'],
    "kakuppradāha": ['mw'],
    "kakut": ['mw'],
    "kakutsala": ['mw'],
    "kakutstha": ['cae', 'ddsa', 'mw'],
    "kakutthaka": ['cped'],
    "kakuyaṣṭikā": ['mw'],
    "kakuñjala": ['mw'],
    "kakuṃdaraṃ": ['ap90'],
    "kakuṃjalaḥ": ['ap90'],
    "kakuṭapāda": ['cped'],
    "kakuṭha": ['mw'],
    "kakvala": ['mw'],
    "kakāra": ['cae', 'ddsa', 'mw'],
    "kakātā": ['gra'],
    "kakāṭa": ['mw'],
    "kakāṭikā": ['ap90', 'mw'],
    "kakṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "kakṣadhara": ['mw'],
    "kakṣaka": ['mw'],
    "kakṣaloman": ['mw'],
    "kakṣapa": ['mw'],
    "kakṣapuṭa": ['mw'],
    "kakṣaruhā": ['mw'],
    "kakṣas": ['mw'],
    "kakṣasena": ['mw'],
    "kakṣastha": ['mw'],
    "kakṣatu": ['mw'],
    "kakṣaśāya": ['mw'],
    "kakṣaḥ": ['ap90'],
    "kakṣeyu": ['mw'],
    "kakṣia": ['gra'],
    "kakṣiaprā": ['gra'],
    "kakṣin": ['mw'],
    "kakṣodaka": ['mw'],
    "kakṣotthā": ['mw'],
    "kakṣya": ['ap90', 'cae', 'gra', 'mw'],
    "kakṣyaprā": ['gra', 'mw'],
    "kakṣyā": ['ddsa', 'mw'],
    "kakṣyāstotra": ['mw'],
    "kakṣyāvat": ['mw'],
    "kakṣyāvekṣaka": ['mw'],
    "kakṣā": ['mw'],
    "kakṣādhyāya": ['mw'],
    "kakṣāgni": ['mw'],
    "kakṣāntara": ['mw'],
    "kakṣāpaṭa": ['mw'],
    "kakṣāpuṭa": ['mw'],
    "kakṣāpuṭi": ['mw'],
    "kakṣāvekṣaka": ['mw'],
    "kakṣāya": ['mw'],
    "kakṣāyate": ['ap90'],
    "kakṣāśrita": ['mw'],
    "kakṣī": ['mw'],
    "kakṣīkaraṇa": ['mw'],
    "kakṣīkartavya": ['mw'],
    "kakṣīkāra": ['mw'],
    "kakṣīkṛ": ['mw'],
    "kakṣīkṛta": ['ap90', 'mw'],
    "kakṣīvant": ['cae'],
    "kakṣīvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "kal": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kala": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kalabha": ['bhs', 'cae', 'ddsa', 'mw'],
    "kalabhairava": ['mw'],
    "kalabhaka": ['mw'],
    "kalabhava": ['mw'],
    "kalabhavallabha": ['mw'],
    "kalabhaḥ": ['ap90'],
    "kalabhāga": ['cped'],
    "kalabhāṣaṇa": ['mw'],
    "kalabhāṣin": ['cae', 'ddsa', 'mw'],
    "kalabhī": ['mw'],
    "kalaca": ['mw'],
    "kalacuri": ['mw'],
    "kalacurisaṃvatsara": ['mw'],
    "kalacūri": ['mw'],
    "kaladhauta": ['cae', 'ddsa', 'mw'],
    "kaladhautalipi": ['mw'],
    "kaladhautamaya": ['mw'],
    "kaladhvani": ['mw'],
    "kaladhūta": ['mw'],
    "kalaghoṣa": ['mw'],
    "kalaha": ['cae', 'cped', 'ddsa', 'mw'],
    "kalahajāta": ['cped'],
    "kalahakandala": ['mw'],
    "kalahakaṇṭaka": ['ddsa'],
    "kalahakāra": ['cae', 'mw'],
    "kalahakāraka": ['cped'],
    "kalahakārikā": ['mw'],
    "kalahakārin": ['mw'],
    "kalahanāśana": ['mw'],
    "kalahappavaḍḍhana": ['cped'],
    "kalahappavaḍḍhana-akiccakari": ['cped'],
    "kalahappavaḍḍhana-akiccakarin": ['cped'],
    "kalahappavaḍḍhanī": ['cped'],
    "kalahapriya": ['bhs', 'cae', 'mw'],
    "kalahapriyā": ['mw'],
    "kalahavant": ['cae'],
    "kalahavat": ['mw'],
    "kalahayati": ['bhs'],
    "kalahaḥ": ['ap90'],
    "kalahaṃsa": ['cae', 'ddsa', 'mw'],
    "kalahaṃsagāminī": ['cae', 'mw'],
    "kalahaṃsaka": ['mw'],
    "kalahaṃsī": ['mw'],
    "kalahin": ['cae', 'ddsa', 'mw'],
    "kalahu": ['mw'],
    "kalahā": ['mw'],
    "kalahākulā": ['mw'],
    "kalahāntaritā": ['mw'],
    "kalahāpahṛta": ['mw'],
    "kalahāy": ['cae'],
    "kalahāya": ['ddsa', 'mw'],
    "kalahāṅkura": ['mw'],
    "kalaja": ['mw'],
    "kalaka": ['mw'],
    "kalakala": ['cae', 'mw'],
    "kalakalarava": ['mw'],
    "kalakalavat": ['mw'],
    "kalakaleśvaratīrtha": ['mw'],
    "kalakalārava": ['mw'],
    "kalakaḥ": ['ap90'],
    "kalakaṇṭha": ['cae', 'mw'],
    "kalakaṇṭhikā": ['cae', 'mw'],
    "kalakaṇṭhin": ['cae', 'mw'],
    "kalakaṇṭhī": ['mw'],
    "kalakīṭa": ['mw'],
    "kalakūjikā": ['mw'],
    "kalakūṇikā": ['mw'],
    "kalakūṭa": ['mw'],
    "kalala": ['cped', 'mw'],
    "kalalaja": ['mw'],
    "kalalajaḥ": ['ap90'],
    "kalalajodbhava": ['mw'],
    "kalalaḥ": ['ap90'],
    "kalalībhūta": ['cped'],
    "kalama": ['bhs', 'cae', 'ddsa', 'mw'],
    "kalamagopavadhū": ['mw'],
    "kalamagopī": ['mw'],
    "kalamakedāra": ['cae', 'mw'],
    "kalamasthāna": ['mw'],
    "kalamaudana": ['cae', 'mw'],
    "kalamaḥ": ['ap90'],
    "kalamba": ['mw'],
    "kalambaka": ['mw'],
    "kalambhi": ['mw'],
    "kalambikā": ['mw'],
    "kalambukā": ['bhs', 'cped', 'mw'],
    "kalambuṭa": ['mw'],
    "kalambī": ['mw'],
    "kalambū": ['mw'],
    "kalamottama": ['mw'],
    "kalamā": ['bhs'],
    "kalamūka": ['mw'],
    "kalana": ['ap90', 'cae', 'ddsa', 'mw'],
    "kalandaka": ['bhs', 'mw'],
    "kalandakanivāpa": ['bhs'],
    "kalandana": ['mw'],
    "kalandara": ['mw'],
    "kalandhu": ['mw'],
    "kalandikā": ['mw'],
    "kalantaka": ['mw'],
    "kalanā": ['mw'],
    "kalanāda": ['mw'],
    "kalanātha": ['mw'],
    "kalapralāpa": ['mw'],
    "kalapālī": ['bhs'],
    "kalarava": ['ddsa', 'mw'],
    "kalasa": ['cae', 'cped', 'mw'],
    "kalasi": ['mw'],
    "kalasvana": ['mw'],
    "kalasvara": ['mw'],
    "kalasī": ['bhs'],
    "kalata": ['ap90', 'mw'],
    "kalatra": ['bhs', 'cae', 'ddsa', 'mw'],
    "kalatratā": ['mw'],
    "kalatravant": ['cae'],
    "kalatravat": ['mw'],
    "kalatraṃ": ['ap90'],
    "kalatrin": ['cae', 'ddsa', 'mw'],
    "kalatrīkṛ": ['mw'],
    "kalatva": ['mw'],
    "kalatā": ['mw'],
    "kalatūlikā": ['mw'],
    "kalavacas": ['mw'],
    "kalavikala": ['mw'],
    "kalavikalavadha": ['mw'],
    "kalavikarṇī": ['mw'],
    "kalaviṃkaḥ": ['ap90'],
    "kalaviṅka": ['bhs', 'cae', 'ddsa', 'mw'],
    "kalaviṅkaka": ['bhs'],
    "kalaviṅkasvara": ['mw'],
    "kalavyāghra": ['mw'],
    "kalaya": ['mw'],
    "kalayaja": ['mw'],
    "kalayati": ['bhs'],
    "kalañja": ['cae', 'ddsa', 'mw'],
    "kalaśa": ['cae', 'ddsa', 'gra', 'mw'],
    "kalaśabhū": ['mw'],
    "kalaśadir": ['mw'],
    "kalaśajanman": ['mw'],
    "kalaśapotaka": ['mw'],
    "kalaśapura": ['mw'],
    "kalaśayoni": ['mw'],
    "kalaśaḥ": ['ap90'],
    "kalaśi": ['ddsa', 'mw'],
    "kalaśoda": ['bhs'],
    "kalaśodaka": ['cae', 'ddsa'],
    "kalaśodara": ['bhs', 'mw'],
    "kalaśodarī": ['bhs', 'mw'],
    "kalaśodbhava": ['mw'],
    "kalaśī": ['ap90', 'mw'],
    "kalaśīkaṇṭha": ['mw'],
    "kalaśīmukha": ['mw'],
    "kalaśīpadī": ['mw'],
    "kalaśīsuta": ['mw'],
    "kalaṃbaḥ": ['ap90'],
    "kalaṃbikā": ['ap90'],
    "kalaṃbuṭa": ['ap90'],
    "kalaṃdaraḥ": ['ap90'],
    "kalaṃdikā": ['ap90'],
    "kalaṃjaḥ": ['ap90'],
    "kalaṃkayati": ['ap90'],
    "kalaṃkaḥ": ['ap90'],
    "kalaṃkaṣa": ['mw'],
    "kalaṃkaṣaḥ": ['ap90'],
    "kalaṃkita": ['ap90'],
    "kalaṃkura": ['mw'],
    "kalaṃkuraḥ": ['ap90'],
    "kalaṅka": ['cae', 'ddsa', 'mw'],
    "kalaṅkahṛt": ['mw'],
    "kalaṅkakalā": ['mw'],
    "kalaṅkakara": ['mw'],
    "kalaṅkalekhā": ['mw'],
    "kalaṅkamaya": ['mw'],
    "kalaṅkaya": ['mw'],
    "kalaṅkeśa": ['mw'],
    "kalaṅkin": ['mw'],
    "kalaṅkita": ['mw'],
    "kalaṅkāṅka": ['mw'],
    "kalaṇḍaka": ['bhs'],
    "kalaṇḍakanivāpa": ['bhs'],
    "kalaṭa": ['mw'],
    "kalaṭaṃ": ['ap90'],
    "kalevara": ['cae', 'ddsa', 'mw'],
    "kalevarapuṣ": ['mw'],
    "kalevaraḥ": ['ap90'],
    "kalhaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kalhoḍīgaṅgeśvaratīrtha": ['mw'],
    "kalhāra": ['ddsa', 'mw'],
    "kalhāraṃ": ['ap90'],
    "kali": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kalicchandas": ['mw'],
    "kalidharmanirṇaya": ['mw'],
    "kalidharmasārasaṃgraha": ['mw'],
    "kalidru": ['mw'],
    "kalidruma": ['ddsa', 'mw'],
    "kaliggaha": ['cped'],
    "kalihārī": ['mw'],
    "kalika": ['mw'],
    "kalikaḥ": ['ap90'],
    "kalikuñcikā": ['mw'],
    "kalikā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kalikāla": ['mw'],
    "kalikāpūrva": ['mw'],
    "kalikāra": ['mw'],
    "kalikāraka": ['mw'],
    "kalikārikā": ['mw'],
    "kalikārī": ['mw'],
    "kalikātā": ['cae', 'ddsa', 'mw'],
    "kalikṛt": ['mw'],
    "kalila": ['ap90', 'cae', 'ddsa', 'mw'],
    "kalimālaka": ['mw'],
    "kalimālya": ['mw'],
    "kalimāraka": ['mw'],
    "kalina": ['bhs'],
    "kalinda": ['ddsa', 'mw'],
    "kalindajā": ['mw'],
    "kalindakanivāpa": ['bhs'],
    "kalindakanyā": ['cae', 'mw'],
    "kalindanandinī": ['mw'],
    "kalindasutā": ['mw'],
    "kalindatanayā": ['cae', 'mw'],
    "kalindaśailajātā": ['mw'],
    "kalindikā": ['mw'],
    "kalindā": ['mw'],
    "kalindātmajā": ['mw'],
    "kalindī": ['mw'],
    "kalinātha": ['mw'],
    "kalinī": ['mw'],
    "kaliprada": ['mw'],
    "kalipriya": ['mw'],
    "kalisaṃtaraṇa": ['mw'],
    "kalisaṃśraya": ['mw'],
    "kalistoma": ['mw'],
    "kalisāsana": ['cped'],
    "kalita": ['ap90', 'cae', 'mw'],
    "kalitacaraṇa": ['ddsa'],
    "kalitakusuma": ['cae', 'mw'],
    "kalivarjya": ['mw'],
    "kalivināśinī": ['mw'],
    "kaliviṣṇuvardhana": ['mw'],
    "kalivṛkṣa": ['mw'],
    "kaliyuga": ['ddsa', 'mw'],
    "kaliñja": ['mw'],
    "kaliñjara": ['ddsa', 'mw'],
    "kaliśatru": ['mw'],
    "kaliśāsana": ['mw'],
    "kaliḥ": ['ap90'],
    "kaliṃdaḥ": ['ap90'],
    "kaliṃga": ['ap90'],
    "kaliṃjaḥ": ['ap90'],
    "kaliṅga": ['cae', 'ddsa', 'mw'],
    "kaliṅgabīja": ['mw'],
    "kaliṅgadeśa": ['cae'],
    "kaliṅgaka": ['mw'],
    "kaliṅgakā": ['mw'],
    "kaliṅgara": ['cped'],
    "kaliṅgarājan": ['bhs'],
    "kaliṅgasenā": ['mw'],
    "kaliṅgavana": ['bhs'],
    "kaliṅgayava": ['mw'],
    "kaliṅgā": ['mw'],
    "kalka": ['ap90', 'cae', 'ddsa', 'mw'],
    "kalkala": ['mw'],
    "kalkana": ['mw'],
    "kalkanaṃ": ['ap90'],
    "kalkaphala": ['mw'],
    "kalkaṭatva": ['bhs'],
    "kalki": ['cae', 'ddsa', 'mw'],
    "kalkidvādaśīvrata": ['mw'],
    "kalkin": ['ap90', 'cae', 'mw'],
    "kalkipurāṇa": ['mw'],
    "kalkiḥ": ['ap90'],
    "kalkuṣī": ['mw'],
    "kalkālaya": ['mw'],
    "kalkībhū": ['ddsa', 'mw'],
    "kalkīkṛ": ['mw'],
    "kall": ['ap90', 'mw'],
    "kalla": ['ap90', 'bhs', 'cped', 'mw'],
    "kallamūka": ['mw'],
    "kallarūpa": ['cped'],
    "kallatva": ['mw'],
    "kallatā": ['cped', 'mw'],
    "kallatākusala": ['cped'],
    "kallavāla": ['bhs'],
    "kallavīratantra": ['mw'],
    "kallaṭa": ['mw'],
    "kalli": ['ap90', 'mw'],
    "kallinātha": ['mw'],
    "kallitā": ['cped'],
    "kallitākusala": ['cped'],
    "kallola": ['ap90', 'cae', 'ddsa', 'mw'],
    "kallolajātaka": ['mw'],
    "kallolinī": ['ap90', 'mw'],
    "kallolita": ['mw'],
    "kallāleśa": ['mw'],
    "kallārya": ['mw'],
    "kallāṭa": ['mw'],
    "kalmali": ['cae', 'gra', 'mw'],
    "kalmaliḥ": ['ap90'],
    "kalmalīka": ['mw'],
    "kalmalīkaṃ": ['ap90'],
    "kalmalīkin": ['cae', 'gra', 'mw'],
    "kalman": ['ap90', 'mw'],
    "kalmaṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kalmaṣadhvaṃsa": ['mw'],
    "kalmaṣadhvaṃsakārin": ['mw'],
    "kalmaṣā": ['mw'],
    "kalmāṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kalmāṣadamya": ['bhs'],
    "kalmāṣagrīva": ['mw'],
    "kalmāṣaka": ['bhs'],
    "kalmāṣakaṇṭha": ['mw'],
    "kalmāṣapuccha": ['mw'],
    "kalmāṣapāda": ['bhs', 'mw'],
    "kalmāṣapādacarita": ['mw'],
    "kalmāṣatantura": ['mw'],
    "kalmāṣatā": ['mw'],
    "kalmāṣita": ['ddsa', 'mw'],
    "kalmāṣābhibhava": ['mw'],
    "kalmāṣāṅghri": ['mw'],
    "kalmāṣī": ['mw'],
    "kalopī": ['bhs'],
    "kalottāla": ['mw'],
    "kalp": ['ddsa', 'gra'],
    "kalpa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kalpabhava": ['mw'],
    "kalpacintāmaṇi": ['mw'],
    "kalpadhenu": ['cae', 'mw'],
    "kalpadru": ['mw'],
    "kalpadrukalikā": ['mw'],
    "kalpadruma": ['cae', 'mw'],
    "kalpadrumakalikā": ['mw'],
    "kalpadrumatantra": ['mw'],
    "kalpadrumatā": ['mw'],
    "kalpadrumāvadāna": ['mw'],
    "kalpadrumībhū": ['mw'],
    "kalpaduṣya": ['bhs'],
    "kalpaduṣyagupta": ['bhs'],
    "kalpadvīpa": ['mw'],
    "kalpadūṣya": ['mw'],
    "kalpagā": ['mw'],
    "kalpaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "kalpakataru": ['mw'],
    "kalpakaḥ": ['ap90'],
    "kalpakaṣāya": ['bhs'],
    "kalpakedāra": ['mw'],
    "kalpakāra": ['bhs', 'mw'],
    "kalpakṣaya": ['cae', 'mw'],
    "kalpalatikā": ['mw'],
    "kalpalatā": ['mw'],
    "kalpalatāprakāśa": ['mw'],
    "kalpalatātantra": ['mw'],
    "kalpalatāvatāra": ['mw'],
    "kalpam": ['bhs', 'mw'],
    "kalpamahīruh": ['mw'],
    "kalpamahīruha": ['mw'],
    "kalpamātra": ['mw'],
    "kalpana": ['bhs', 'cae', 'ddsa', 'mw'],
    "kalpanavidhi": ['mw'],
    "kalpanaṃ": ['ap90'],
    "kalpanā": ['mw'],
    "kalpanāmaṇḍitikā": ['bhs'],
    "kalpanātha": ['mw'],
    "kalpanāśakti": ['mw'],
    "kalpanī": ['ap90', 'mw'],
    "kalpanīya": ['ap90', 'cae', 'mw'],
    "kalpanṛtya": ['mw'],
    "kalpapradīpa": ['mw'],
    "kalpapradīpikā": ['mw'],
    "kalpapuṣpa": ['bhs'],
    "kalpapādapa": ['cae', 'mw'],
    "kalpapāla": ['ddsa', 'mw'],
    "kalpasiddhānta": ['mw'],
    "kalpasthiti": ['bhs'],
    "kalpasthitika": ['bhs'],
    "kalpasthāna": ['mw'],
    "kalpasūtra": ['cae', 'mw'],
    "kalpasūtravyākhyā": ['mw'],
    "kalpatantra": ['mw'],
    "kalpataru": ['cae', 'mw'],
    "kalpataruparimala": ['mw'],
    "kalpatarurasa": ['mw'],
    "kalpatā": ['mw'],
    "kalpavallī": ['mw'],
    "kalpavarṣa": ['mw'],
    "kalpavaṭa": ['mw'],
    "kalpavidhi": ['mw'],
    "kalpavivaraṇa": ['mw'],
    "kalpaviṭapin": ['mw'],
    "kalpavrata": ['mw'],
    "kalpavāyu": ['mw'],
    "kalpavṛkṣa": ['cae', 'mw'],
    "kalpavṛkṣalatā": ['mw'],
    "kalpavṛnda": ['bhs'],
    "kalpayati": ['bhs'],
    "kalpayitavya": ['mw'],
    "kalpayukti": ['mw'],
    "kalpaśata": ['mw'],
    "kalpaśākhin": ['mw'],
    "kalpetara": ['mw'],
    "kalpika": ['ap90', 'bhs', 'mw'],
    "kalpikaśālā": ['bhs'],
    "kalpikāra": ['bhs'],
    "kalpikāraka": ['bhs'],
    "kalpin": ['mw'],
    "kalpita": ['ap90', 'bhs', 'mw'],
    "kalpitatva": ['mw'],
    "kalpitopamā": ['mw'],
    "kalpitā": ['mw'],
    "kalpitārgha": ['ddsa'],
    "kalpiya": ['bhs'],
    "kalpopaniṣad": ['mw'],
    "kalpotthāyin": ['mw'],
    "kalpuṣa": ['mw'],
    "kalpya": ['cae', 'ddsa', 'mw'],
    "kalpādhikārin": ['mw'],
    "kalpādi": ['cae', 'mw'],
    "kalpāgni": ['ddsa', 'mw'],
    "kalpānta": ['cae', 'mw'],
    "kalpāntara": ['mw'],
    "kalpāntasthāyin": ['mw'],
    "kalpāntavāsin": ['mw'],
    "kalpānupada": ['mw'],
    "kalpāpayati": ['bhs'],
    "kalpātyaya": ['mw'],
    "kalpātīta": ['mw'],
    "kalpāvaśeṣam": ['bhs'],
    "kalpāya": ['ddsa'],
    "kalpāṅka": ['mw'],
    "kalpīkaroti": ['bhs'],
    "kalukka": ['mw'],
    "kalukkaḥ": ['ap90'],
    "kalukkā": ['mw'],
    "kaluṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaluṣacetas": ['cae', 'mw'],
    "kaluṣamati": ['cae', 'mw'],
    "kaluṣamañjarī": ['mw'],
    "kaluṣatva": ['mw'],
    "kaluṣatā": ['mw'],
    "kaluṣay": ['cae'],
    "kaluṣaya": ['mw'],
    "kaluṣayoni": ['mw'],
    "kaluṣayonija": ['cae', 'mw'],
    "kaluṣin": ['mw'],
    "kaluṣita": ['ap90', 'mw'],
    "kaluṣā": ['mw'],
    "kaluṣātman": ['mw'],
    "kaluṣāy": ['cae'],
    "kaluṣāya": ['ddsa', 'mw'],
    "kaluṣībhū": ['mw'],
    "kaluṣīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "kalya": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kalyacitta": ['mw'],
    "kalyajagdhi": ['mw'],
    "kalyam": ['mw'],
    "kalyapāla": ['mw'],
    "kalyapālaka": ['mw'],
    "kalyasya": ['bhs'],
    "kalyato": ['bhs'],
    "kalyatva": ['mw'],
    "kalyatā": ['cped', 'mw'],
    "kalyatākusala": ['cped'],
    "kalyavarta": ['cae', 'ddsa', 'mw'],
    "kalye": ['mw'],
    "kalyotthāyin": ['mw'],
    "kalyā": ['ap90', 'mw'],
    "kalyāpāla": ['mw'],
    "kalyāṇa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kalyāṇabhadra": ['bhs'],
    "kalyāṇabhattika": ['cped'],
    "kalyāṇabhaṭṭa": ['mw'],
    "kalyāṇabīja": ['mw'],
    "kalyāṇacandra": ['mw'],
    "kalyāṇacāra": ['mw'],
    "kalyāṇadevī": ['mw'],
    "kalyāṇadharman": ['mw'],
    "kalyāṇagarbha": ['bhs'],
    "kalyāṇagiri": ['mw'],
    "kalyāṇaka": ['ap90', 'mw'],
    "kalyāṇakaghṛta": ['mw'],
    "kalyāṇakaguḍa": ['mw'],
    "kalyāṇakalavaṇa": ['mw'],
    "kalyāṇakara": ['mw'],
    "kalyāṇakaṭaka": ['cae', 'mw'],
    "kalyāṇakāma": ['bhs'],
    "kalyāṇakāra": ['mw'],
    "kalyāṇakāraka": ['mw'],
    "kalyāṇakāri": ['cped'],
    "kalyāṇakārin": ['cped'],
    "kalyāṇakīrti": ['mw'],
    "kalyāṇakṛt": ['cae', 'mw'],
    "kalyāṇalakṣaṇa": ['mw'],
    "kalyāṇamalla": ['mw'],
    "kalyāṇamandira": ['mw'],
    "kalyāṇamandirastotra": ['mw'],
    "kalyāṇamandiraṭīkā": ['mw'],
    "kalyāṇamaya": ['mw'],
    "kalyāṇamitra": ['bhs', 'mw'],
    "kalyāṇamitrasevana": ['mw'],
    "kalyāṇamitratā": ['mw'],
    "kalyāṇamitta": ['cped'],
    "kalyāṇamittatā": ['cped'],
    "kalyāṇapañcakapūjā": ['mw'],
    "kalyāṇapañcamīka": ['mw'],
    "kalyāṇapañña": ['cped'],
    "kalyāṇapuccha": ['mw'],
    "kalyāṇapura": ['mw'],
    "kalyāṇapīti": ['cped'],
    "kalyāṇapītin": ['cped'],
    "kalyāṇarājacaritra": ['mw'],
    "kalyāṇarāya": ['mw'],
    "kalyāṇasahāya": ['cped'],
    "kalyāṇasampavaṅka": ['cped'],
    "kalyāṇasaptamī": ['mw'],
    "kalyāṇasaptamīvrata": ['mw'],
    "kalyāṇasattva": ['mw'],
    "kalyāṇasaṅghatika": ['cped'],
    "kalyāṇasena": ['mw'],
    "kalyāṇasvāmikeśava": ['mw'],
    "kalyāṇasūcaka": ['cae'],
    "kalyāṇasūtra": ['mw'],
    "kalyāṇatara": ['cped', 'mw'],
    "kalyāṇavacana": ['mw'],
    "kalyāṇavardhana": ['mw'],
    "kalyāṇavarman": ['mw'],
    "kalyāṇavartman": ['mw'],
    "kalyāṇavat": ['mw'],
    "kalyāṇavatī": ['mw'],
    "kalyāṇavākkaraṇa": ['cped'],
    "kalyāṇavīja": ['mw'],
    "kalyāṇavṛtta": ['mw'],
    "kalyāṇaśarman": ['mw'],
    "kalyāṇikā": ['mw'],
    "kalyāṇin": ['ap90', 'ddsa', 'mw'],
    "kalyāṇinī": ['mw'],
    "kalyāṇitara": ['cped'],
    "kalyāṇyādi": ['mw'],
    "kalyāṇābhijana": ['mw'],
    "kalyāṇābhijātika": ['cped'],
    "kalyāṇābhiniveśin": ['mw'],
    "kalyāṇācāra": ['mw'],
    "kalyāṇādhimuttika": ['cped'],
    "kalyāṇī": ['mw'],
    "kalyāṇīdaśama": ['mw'],
    "kalyāṇīpañcama": ['mw'],
    "kalyāṇīpañcamā": ['mw'],
    "kalyāṇīpañcamīka": ['mw'],
    "kalyāṇīpriya": ['mw'],
    "kalyāṇīstotra": ['mw'],
    "kalā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kalābhara": ['ddsa', 'mw'],
    "kalābhṛt": ['cae', 'mw'],
    "kalābuka": ['cped'],
    "kalābāhya": ['mw'],
    "kalācika": ['ap90', 'mw'],
    "kalācikā": ['bhs', 'mw'],
    "kalācī": ['bhs', 'mw'],
    "kalāda": ['mw'],
    "kalādaḥ": ['ap90'],
    "kalādhara": ['mw'],
    "kalādhika": ['mw'],
    "kalādhikaḥ": ['ap90'],
    "kalādīkṣā": ['mw'],
    "kalāhaka": ['mw'],
    "kalāhakaḥ": ['ap90'],
    "kalājña": ['cae', 'mw'],
    "kalājājī": ['mw'],
    "kalākanda": ['mw'],
    "kalākeli": ['mw'],
    "kalākula": ['mw'],
    "kalākuśala": ['mw'],
    "kalālāpa": ['ddsa', 'mw'],
    "kalāmaka": ['mw'],
    "kalāmakaḥ": ['ap90'],
    "kalāmbi": ['mw'],
    "kalāmbikā": ['mw'],
    "kalānaka": ['mw'],
    "kalānidhi": ['cae', 'mw'],
    "kalāntara": ['ddsa', 'mw'],
    "kalānunādin": ['mw'],
    "kalānyāsa": ['mw'],
    "kalānātha": ['cae', 'mw'],
    "kalāpa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kalāpacchanda": ['mw'],
    "kalāpadvīpa": ['mw'],
    "kalāpagrāma": ['mw'],
    "kalāpaka": ['bhs', 'mw'],
    "kalāpakaṃ": ['ap90'],
    "kalāpakhañja": ['mw'],
    "kalāpatattvārṇava": ['mw'],
    "kalāpavarman": ['mw'],
    "kalāpaśas": ['mw'],
    "kalāpaśiras": ['mw'],
    "kalāpaḥ": ['ap90'],
    "kalāpi": ['mw'],
    "kalāpin": ['ap90', 'cae', 'mw'],
    "kalāpinī": ['ap90', 'mw'],
    "kalāpī": ['mw'],
    "kalāpūra": ['mw'],
    "kalāpūrṇa": ['mw'],
    "kalārūpa": ['mw'],
    "kalārūpiṇī": ['mw'],
    "kalārūpā": ['mw'],
    "kalārṇava": ['mw'],
    "kalāsāra": ['mw'],
    "kalātman": ['mw'],
    "kalāva": ['bhs'],
    "kalāvant": ['cae'],
    "kalāvat": ['ap90', 'mw'],
    "kalāvatī": ['mw'],
    "kalāvid": ['mw'],
    "kalāvida": ['cae'],
    "kalāvidhi": ['mw'],
    "kalāvidhitantra": ['mw'],
    "kalāvidvas": ['mw'],
    "kalāvika": ['mw'],
    "kalāvikala": ['mw'],
    "kalāvikaḥ": ['ap90'],
    "kalāvilāsa": ['mw'],
    "kalāvirodha": ['mw'],
    "kalāvāda": ['mw'],
    "kalāya": ['mw'],
    "kalāyakhañja": ['mw'],
    "kalāyamatta": ['cped'],
    "kalāyana": ['mw'],
    "kalāyapaṭibhasta": ['cped'],
    "kalāyasūpa": ['mw'],
    "kalāyayūsa": ['cped'],
    "kalāyaḥ": ['ap90'],
    "kalāyā": ['mw'],
    "kalāśas": ['mw'],
    "kalāśeṣa": ['cae'],
    "kalāślāghya": ['mw'],
    "kalāśuri": ['mw'],
    "kalāśāstra": ['mw'],
    "kalāṃbiḥ": ['ap90'],
    "kalāṃkuraḥ": ['ap90'],
    "kalāṃśa": ['mw'],
    "kalāṃśarūpiṇī": ['mw'],
    "kalāṅgala": ['mw'],
    "kalāṅkura": ['mw'],
    "kalāṇḍī": ['mw'],
    "kalāṭīna": ['mw'],
    "kalāṭīnaḥ": ['ap90'],
    "kalī": ['bhs', 'cped'],
    "kalūtara": ['mw'],
    "kam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kama": ['bhs'],
    "kamadyū": ['gra', 'mw'],
    "kamaka": ['mw'],
    "kamala": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kamalabhava": ['mw'],
    "kamalabhavana": ['mw'],
    "kamalabhidā": ['mw'],
    "kamalabhū": ['mw'],
    "kamalabālanāla": ['mw'],
    "kamalabālanālaya": ['mw'],
    "kamalabāndhava": ['mw'],
    "kamaladalavimalanakṣatrarājasaṃkusumitābhijña": ['bhs'],
    "kamaladeva": ['mw'],
    "kamaladevī": ['mw'],
    "kamaladhara": ['bhs'],
    "kamalagarbha": ['mw'],
    "kamalagarbhābha": ['mw'],
    "kamalaja": ['mw'],
    "kamalaka": ['mw'],
    "kamalakaṃ": ['ap90'],
    "kamalakhaṇḍa": ['mw'],
    "kamalakīra": ['mw'],
    "kamalakīṭa": ['mw'],
    "kamalalocana": ['cae', 'mw'],
    "kamalalocanā": ['mw'],
    "kamalamati": ['mw'],
    "kamalamaya": ['mw'],
    "kamalamukha": ['cae', 'mw'],
    "kamalanayana": ['cae', 'mw'],
    "kamalanetra": ['cae', 'mw'],
    "kamalanābha": ['mw'],
    "kamalapattra": ['cae', 'mw'],
    "kamalapattrākṣa": ['mw'],
    "kamalapādukā": ['cped'],
    "kamalasaptamīvrata": ['mw'],
    "kamalasaṃbhava": ['mw'],
    "kamalavadana": ['mw'],
    "kamalavana": ['cae', 'mw'],
    "kamalavanamaya": ['mw'],
    "kamalavardhana": ['mw'],
    "kamalavarman": ['mw'],
    "kamalavatī": ['mw'],
    "kamalayoni": ['mw'],
    "kamalaśīla": ['mw'],
    "kamalaṣaṣṭhīvrata": ['mw'],
    "kamalekṣaṇa": ['cae', 'ddsa', 'mw'],
    "kamalinī": ['ap90', 'cae', 'ddsa', 'mw'],
    "kamalinībandhu": ['mw'],
    "kamalinīdala": ['cae'],
    "kamalinīkānta": ['mw'],
    "kamalodaya": ['mw'],
    "kamalodbhava": ['mw'],
    "kamalotpalamālin": ['mw'],
    "kamalottara": ['mw'],
    "kamaloṣṇīṣa": ['bhs'],
    "kamalā": ['ap90', 'mw'],
    "kamalābhakta": ['mw'],
    "kamalāchāyā": ['mw'],
    "kamalādi": ['mw'],
    "kamalāgrajā": ['mw'],
    "kamalāhaṭṭa": ['mw'],
    "kamalāhāsa": ['mw'],
    "kamalākara": ['bhs', 'ddsa', 'mw'],
    "kamalākaratīrthayātrā": ['mw'],
    "kamalākeśava": ['mw'],
    "kamalākṣa": ['bhs', 'cae', 'mw'],
    "kamalākṣī": ['mw'],
    "kamalālaya": ['mw'],
    "kamalālayā": ['mw'],
    "kamalānandana": ['mw'],
    "kamalāpati": ['mw'],
    "kamalāpāta": ['mw'],
    "kamalāsana": ['mw'],
    "kamalāsanastha": ['mw'],
    "kamalātmikā": ['mw'],
    "kamalātīrtha": ['mw'],
    "kamalāy": ['cae'],
    "kamalāyatākṣa": ['mw'],
    "kamalāyudha": ['mw'],
    "kamalīkā": ['mw'],
    "kamamāna": ['cped'],
    "kamana": ['ap90', 'ddsa', 'mw'],
    "kamanacchada": ['mw'],
    "kamandaka": ['mw'],
    "kamandha": ['mw'],
    "kamantaka": ['mw'],
    "kamanīya": ['ap90', 'cped', 'mw'],
    "kamanīyatva": ['mw'],
    "kamanīyatā": ['mw'],
    "kamara": ['ap90', 'mw'],
    "kamaraka": ['bhs'],
    "kamati": ['cped'],
    "kamaṃḍaluḥ": ['ap90'],
    "kamaṇḍalu": ['cae', 'cped', 'ddsa', 'mw'],
    "kamaṇḍalucaryā": ['mw'],
    "kamaṇḍaluka": ['bhs', 'cped'],
    "kamaṇḍalūdaka": ['cae'],
    "kamaṭa": ['mw'],
    "kamaṭha": ['cae', 'ddsa', 'mw'],
    "kamaṭhapati": ['mw'],
    "kamaṭhaḥ": ['ap90'],
    "kamaṭhāsuravadha": ['mw'],
    "kamaṭhī": ['mw'],
    "kamb": ['mw'],
    "kambala": ['cae', 'cped', 'ddsa', 'mw'],
    "kambalabarhiṣa": ['mw'],
    "kambalacārāyaṇīya": ['mw'],
    "kambaladhāvaka": ['mw'],
    "kambalahāra": ['mw'],
    "kambalaka": ['mw'],
    "kambalakāraka": ['mw'],
    "kambalasukhuma": ['cped'],
    "kambalavāhya": ['mw'],
    "kambalavāhyaka": ['mw'],
    "kambalikā": ['mw'],
    "kambalin": ['mw'],
    "kambalivāhyaka": ['mw'],
    "kambaliya": ['cped'],
    "kambalya": ['mw'],
    "kambalālukā": ['mw'],
    "kambalārṇa": ['mw'],
    "kambalīya": ['cped', 'mw'],
    "kambara": ['mw'],
    "kambha": ['mw'],
    "kambhu": ['mw'],
    "kambhākṛta": ['bhs'],
    "kambhārī": ['mw'],
    "kambi": ['mw'],
    "kamboja": ['bhs', 'cae', 'ddsa', 'mw'],
    "kambojaka": ['bhs'],
    "kambojamuṇḍa": ['mw'],
    "kambojādi": ['mw'],
    "kambu": ['cae', 'ddsa', 'mw'],
    "kambugrīva": ['cae', 'mw'],
    "kambugrīvā": ['bhs', 'mw'],
    "kambuja": ['mw'],
    "kambuka": ['bhs', 'mw'],
    "kambukaṃdhara": ['mw'],
    "kambukaṇṭha": ['cae', 'mw'],
    "kambukā": ['mw'],
    "kambukāṣṭhā": ['mw'],
    "kambumālinī": ['mw'],
    "kambupuṣpī": ['mw'],
    "kambvātāyin": ['mw'],
    "kambā": ['mw'],
    "kambālāyin": ['mw'],
    "kambū": ['mw'],
    "kambūka": ['mw'],
    "kami": ['cae', 'ddsa'],
    "kamitṛ": ['ap90', 'mw'],
    "kamma": ['cped'],
    "kammadheyya": ['cped'],
    "kammakara": ['cped'],
    "kammakata": ['cped'],
    "kammakāra": ['cped'],
    "kammakāraka": ['cped'],
    "kammakāraṇa": ['cped'],
    "kammakāraṇā": ['cped'],
    "kammaniya": ['cped'],
    "kammanta": ['cped'],
    "kammapatha": ['cped'],
    "kammappatta": ['cped'],
    "kammassaka": ['cped'],
    "kammavācā": ['cped'],
    "kammavāda": ['cped'],
    "kammavādi": ['cped'],
    "kammavādin": ['cped'],
    "kammayanta": ['cped'],
    "kammayantavighāṭana": ['cped'],
    "kammañña": ['cped'],
    "kammaṇiya": ['cped'],
    "kammaṭṭhāna": ['cped'],
    "kammika": ['cped'],
    "kammāra": ['cped'],
    "kammārabhaṇḍu": ['cped'],
    "kammāraggarī": ['cped'],
    "kammāraha": ['cped'],
    "kammāraputta": ['cped'],
    "kammārāma": ['cped'],
    "kammāsa": ['cped'],
    "kammāsakāri": ['cped'],
    "kammāsakārin": ['cped'],
    "kammāvaraṇa": ['cped'],
    "kamp": ['cae', 'ddsa', 'gra', 'mw'],
    "kampa": ['cae', 'ddsa', 'mw'],
    "kampalakṣman": ['mw'],
    "kampana": ['cae', 'mw'],
    "kampanā": ['mw'],
    "kampanādhipati": ['mw'],
    "kampanīya": ['mw'],
    "kamparāja": ['mw'],
    "kampati": ['cped'],
    "kampavant": ['cae'],
    "kampayati": ['cped'],
    "kampayi": ['cped'],
    "kampenta": ['cped'],
    "kampeti": ['cped'],
    "kamphilla": ['mw'],
    "kampikā": ['mw'],
    "kampila": ['bhs', 'mw'],
    "kampilla": ['bhs', 'mw'],
    "kampillaka": ['mw'],
    "kampilvaka": ['mw'],
    "kampilya": ['mw'],
    "kampilyaka": ['mw'],
    "kampin": ['cae', 'mw'],
    "kampita": ['cae', 'mw'],
    "kampottara": ['ddsa'],
    "kampra": ['cae', 'mw'],
    "kampya": ['mw'],
    "kampāka": ['mw'],
    "kampānvita": ['mw'],
    "kampāya": ['mw'],
    "kampāṅka": ['mw'],
    "kampīla": ['mw'],
    "kampīṭa": ['mw'],
    "kamra": ['ap90', 'cae', 'ddsa', 'mw'],
    "kamrā": ['mw'],
    "kamujā": ['mw'],
    "kamuñjā": ['mw'],
    "kamvant": ['cae'],
    "kamvat": ['mw'],
    "kamā": ['ap90', 'mw'],
    "kamībala": ['bhs'],
    "kan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kana": ['gra', 'mw'],
    "kanadeva": ['mw'],
    "kanaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "kanakabhaṅga": ['mw'],
    "kanakabhujendra": ['bhs'],
    "kanakabimbābha": ['bhs'],
    "kanakacampaka": ['mw'],
    "kanakacandra": ['mw'],
    "kanakadatta": ['mw'],
    "kanakadaṇḍa": ['mw'],
    "kanakadhvaja": ['mw'],
    "kanakagairika": ['mw'],
    "kanakagaura": ['mw'],
    "kanakagiri": ['mw'],
    "kanakajālakāyavibhūṣita": ['bhs'],
    "kanakakadalī": ['mw'],
    "kanakakalaśa": ['mw'],
    "kanakaketakī": ['mw'],
    "kanakakuṇḍalā": ['mw'],
    "kanakakāra": ['mw'],
    "kanakakṣāra": ['mw'],
    "kanakakṣīrī": ['mw'],
    "kanakalatikā": ['mw'],
    "kanakalatā": ['mw'],
    "kanakalodbhava": ['mw'],
    "kanakamaniparvataghoṣa": ['bhs'],
    "kanakamaya": ['ap90', 'cae', 'mw'],
    "kanakamañjarī": ['mw'],
    "kanakamaṇiparvatatejobhadra": ['bhs'],
    "kanakameghapradīpadhvajā": ['bhs'],
    "kanakamuni": ['bhs', 'mw'],
    "kanakamālā": ['mw'],
    "kanakanāgarājateja": ['bhs'],
    "kanakapala": ['mw'],
    "kanakaparvata": ['bhs', 'mw'],
    "kanakaparāga": ['mw'],
    "kanakapattra": ['mw'],
    "kanakaphala": ['mw'],
    "kanakapiṅgala": ['mw'],
    "kanakaprabha": ['bhs', 'mw'],
    "kanakaprabhā": ['mw'],
    "kanakaprasavā": ['mw'],
    "kanakaprasūna": ['mw'],
    "kanakapura": ['mw'],
    "kanakapurī": ['mw'],
    "kanakapuṣpikā": ['mw'],
    "kanakapuṣpī": ['mw'],
    "kanakarambhā": ['mw'],
    "kanakarasa": ['cae', 'mw'],
    "kanakarekhā": ['mw'],
    "kanakarāśi": ['bhs'],
    "kanakasena": ['mw'],
    "kanakastambha": ['mw'],
    "kanakastambharucira": ['mw'],
    "kanakastambhā": ['mw'],
    "kanakasthalī": ['mw'],
    "kanakasūtra": ['cae', 'mw'],
    "kanakatanusannibha": ['cped'],
    "kanakatāla": ['bhs'],
    "kanakatālābha": ['mw'],
    "kanakavalaya": ['cae'],
    "kanakavarman": ['mw'],
    "kanakavarṇa": ['bhs', 'mw'],
    "kanakavarṣa": ['mw'],
    "kanakavatī": ['bhs', 'mw'],
    "kanakavigraha": ['mw'],
    "kanakavimalaprabha": ['bhs'],
    "kanakavāhinī": ['mw'],
    "kanakaśaka": ['mw'],
    "kanakaśakti": ['cae', 'mw'],
    "kanakaśikharin": ['mw'],
    "kanakaśṛṅgamaya": ['mw'],
    "kanakaṃ": ['ap90'],
    "kanakaṭaṅka": ['mw'],
    "kanakeśvaratīrtha": ['mw'],
    "kanakhala": ['ap90', 'cae', 'ddsa', 'mw'],
    "kanakhalaṃ": ['ap90'],
    "kanaknaka": ['mw'],
    "kanakojjvala": ['cae', 'mw'],
    "kanakā": ['mw'],
    "kanakābha": ['mw'],
    "kanakābja": ['cae', 'mw'],
    "kanakācala": ['mw'],
    "kanakādhyakṣa": ['mw'],
    "kanakādri": ['mw'],
    "kanakādrikhaṇḍa": ['mw'],
    "kanakāhva": ['mw'],
    "kanakāhvaya": ['bhs', 'mw'],
    "kanakākara": ['mw'],
    "kanakākṣa": ['bhs', 'mw'],
    "kanakākṣī": ['mw'],
    "kanakālukā": ['mw'],
    "kanakāntaka": ['mw'],
    "kanakāpīḍa": ['mw'],
    "kanakāraka": ['mw'],
    "kanakāsana": ['ddsa'],
    "kanakāvalī": ['mw'],
    "kanakāvatī": ['bhs', 'mw'],
    "kanakāvatīmādhava": ['mw'],
    "kanakāyu": ['mw'],
    "kanakāyus": ['mw'],
    "kanakāṅgada": ['mw'],
    "kanala": ['mw'],
    "kanana": ['ap90'],
    "kanapa": ['mw'],
    "kanavaka": ['mw'],
    "kanaya": ['bhs', 'mw'],
    "kanayati": ['ap90'],
    "kanaṭī": ['ap90', 'mw'],
    "kand": ['mw'],
    "kanda": ['cae', 'ddsa', 'mw'],
    "kandabahulā": ['mw'],
    "kandada": ['mw'],
    "kandaguḍūcī": ['mw'],
    "kandaja": ['mw'],
    "kandala": ['cae', 'ddsa', 'mw'],
    "kandalatā": ['mw'],
    "kandalay": ['cae'],
    "kandalaya": ['mw'],
    "kandali": ['mw'],
    "kandalin": ['mw'],
    "kandalita": ['mw'],
    "kandalānta": ['mw'],
    "kandalāyana": ['mw'],
    "kandalī": ['cae', 'mw'],
    "kandalīchinna": ['bhs'],
    "kandalīkusuma": ['mw'],
    "kandalīkāra": ['mw'],
    "kandamūla": ['mw'],
    "kandamūlaka": ['mw'],
    "kandamūlaphalabhojana": ['cped'],
    "kandanta": ['cped'],
    "kandaphalā": ['mw'],
    "kandara": ['cae', 'cped', 'ddsa', 'mw'],
    "kandaraka": ['bhs'],
    "kandaravat": ['mw'],
    "kandarohiṇī": ['mw'],
    "kandarpa": ['cae', 'ddsa', 'mw'],
    "kandarpacūḍāmaṇi": ['mw'],
    "kandarpadahana": ['mw'],
    "kandarpajanana": ['cae'],
    "kandarpajvara": ['mw'],
    "kandarpajīva": ['mw'],
    "kandarpakeli": ['mw'],
    "kandarpaketu": ['mw'],
    "kandarpakūpa": ['mw'],
    "kandarpamathana": ['mw'],
    "kandarpamusala": ['mw'],
    "kandarpamātṛ": ['mw'],
    "kandarpasenā": ['mw'],
    "kandarpasiddhānta": ['mw'],
    "kandarpaśṛṅkhala": ['mw'],
    "kandarpā": ['mw'],
    "kandarā": ['cped', 'mw'],
    "kandarākara": ['mw'],
    "kandarāla": ['mw'],
    "kandarālaka": ['mw'],
    "kandarāntara": ['mw'],
    "kandasaṃbhava": ['mw'],
    "kandasaṃjña": ['mw'],
    "kandasāra": ['mw'],
    "kandasāraka": ['mw'],
    "kandati": ['cped'],
    "kandauṣadha": ['mw'],
    "kandavallī": ['mw'],
    "kandavardhana": ['mw'],
    "kandavat": ['mw'],
    "kandaśāka": ['mw'],
    "kandaśūraṇa": ['mw'],
    "kandaṭa": ['mw'],
    "kandekṣu": ['mw'],
    "kandha": ['bhs'],
    "kandhara": ['ddsa'],
    "kandila": ['mw'],
    "kandin": ['mw'],
    "kandirī": ['mw'],
    "kanditvā": ['cped'],
    "kandodbhavā": ['mw'],
    "kandota": ['mw'],
    "kandottha": ['cae', 'mw'],
    "kandoṭa": ['mw'],
    "kandu": ['cae', 'ddsa', 'mw'],
    "kandugṛha": ['mw'],
    "kanduka": ['bhs', 'cae', 'mw'],
    "kandukagṛha": ['mw'],
    "kandukalīlā": ['mw'],
    "kandukaprastha": ['mw'],
    "kandukeśa": ['mw'],
    "kandukeśvaraliṅga": ['mw'],
    "kandukotsava": ['mw'],
    "kandukāya": ['mw'],
    "kandupakva": ['mw'],
    "kanduśālā": ['mw'],
    "kandālu": ['mw'],
    "kandāmṛtā": ['mw'],
    "kandārha": ['mw'],
    "kandāśana": ['mw'],
    "kandāḍhya": ['mw'],
    "kandī": ['mw'],
    "kandūraka": ['mw'],
    "kanerā": ['ap90', 'mw'],
    "kanikrada": ['ap90', 'mw'],
    "kanikradat": ['ddsa'],
    "kanima": ['bhs'],
    "kaniā": ['gra'],
    "kaniṣka": ['bhs', 'cae', 'ddsa', 'mw'],
    "kaniṣkan": ['ddsa'],
    "kaniṣkapura": ['mw'],
    "kaniṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kaniṣṭhaga": ['mw'],
    "kaniṣṭhaka": ['ap90', 'cae', 'mw'],
    "kaniṣṭhamūla": ['mw'],
    "kaniṣṭhapada": ['mw'],
    "kaniṣṭhaprathama": ['mw'],
    "kaniṣṭhatva": ['mw'],
    "kaniṣṭhatā": ['mw'],
    "kaniṣṭhikā": ['mw'],
    "kaniṣṭhā": ['mw'],
    "kaniṣṭhātreya": ['mw'],
    "kaniṭṭha": ['cped'],
    "kaniṭṭhaka": ['cped'],
    "kanna": ['mw'],
    "kannaṃ": ['ap90'],
    "kanta": ['cped', 'mw'],
    "kantati": ['cped'],
    "kantatisalla": ['cped'],
    "kantehi": ['cped'],
    "kantena": ['cped'],
    "kanteti": ['cped'],
    "kanthaka": ['bhs', 'mw'],
    "kanthakā": ['mw'],
    "kantharī": ['mw'],
    "kantheśvaratīrtha": ['mw'],
    "kanthā": ['bhs', 'cae', 'ddsa', 'mw'],
    "kanthādhāraṇa": ['mw'],
    "kanthādhārin": ['mw'],
    "kanthārikā": ['mw'],
    "kanthārī": ['mw'],
    "kanti": ['mw'],
    "kantika": ['cped'],
    "kantikā": ['cped'],
    "kantitasutta": ['cped'],
    "kantiya": ['cped'],
    "kantu": ['mw'],
    "kantva": ['cae', 'ddsa', 'mw'],
    "kantāra": ['cped'],
    "kantāraddha": ['cped'],
    "kantāraddhan": ['cped'],
    "kantāraddhāna": ['cped'],
    "kantāramagga": ['cped'],
    "kantārika": ['bhs'],
    "kanya": ['cae', 'ddsa', 'mw'],
    "kanyaka": ['cae', 'mw'],
    "kanyakubja": ['cae', 'mw'],
    "kanyakubjadeśa": ['mw'],
    "kanyakubjaka": ['bhs'],
    "kanyakumārī": ['mw'],
    "kanyakā": ['ap90', 'mw'],
    "kanyakābhāva": ['cae'],
    "kanyakācchala": ['mw'],
    "kanyakāchala": ['mw'],
    "kanyakāguṇa": ['mw'],
    "kanyakāgāra": ['mw'],
    "kanyakājāta": ['mw'],
    "kanyakāpati": ['mw'],
    "kanyalā": ['ap90', 'mw'],
    "kanyanā": ['ap90', 'gra', 'mw'],
    "kanyasa": ['ap90', 'mw'],
    "kanyasaḥ": ['ap90'],
    "kanyasā": ['mw'],
    "kanyikā": ['mw'],
    "kanyuṣa": ['mw'],
    "kanyuṣaṃ": ['ap90'],
    "kanyā": ['ap90', 'ddsa', 'gra', 'mw'],
    "kanyābhaikṣa": ['cae', 'mw'],
    "kanyābhartṛ": ['mw'],
    "kanyābhāva": ['cae', 'mw'],
    "kanyādarśam": ['mw'],
    "kanyādhana": ['mw'],
    "kanyādoṣa": ['mw'],
    "kanyādāna": ['cae', 'mw'],
    "kanyādātṛ": ['cae', 'mw'],
    "kanyādūṣaka": ['cae', 'mw'],
    "kanyādūṣayitṛ": ['mw'],
    "kanyādūṣaṇa": ['mw'],
    "kanyādūṣin": ['mw'],
    "kanyāgarbha": ['mw'],
    "kanyāgata": ['mw'],
    "kanyāgrahaṇa": ['mw'],
    "kanyāgāra": ['mw'],
    "kanyāgṛha": ['mw'],
    "kanyāharaṇa": ['mw'],
    "kanyāhrada": ['mw'],
    "kanyāja": ['mw'],
    "kanyājāta": ['mw'],
    "kanyākubja": ['mw'],
    "kanyākumārī": ['mw'],
    "kanyākā": ['mw'],
    "kanyākāla": ['mw'],
    "kanyākūpa": ['mw'],
    "kanyāmaya": ['ap90', 'mw'],
    "kanyāpati": ['mw'],
    "kanyāpipīlikā": ['mw'],
    "kanyāpradāna": ['cae', 'mw'],
    "kanyāpravahaṇa": ['mw'],
    "kanyāpura": ['cae', 'mw'],
    "kanyāputra": ['mw'],
    "kanyāpāla": ['mw'],
    "kanyāratna": ['mw'],
    "kanyārthika": ['mw'],
    "kanyārthin": ['mw'],
    "kanyārāma": ['mw'],
    "kanyārāśi": ['mw'],
    "kanyāsamudbhava": ['mw'],
    "kanyāsaṃpradāna": ['mw'],
    "kanyāsaṃvedya": ['mw'],
    "kanyāsvayaṃvara": ['mw'],
    "kanyātva": ['cae', 'mw'],
    "kanyātīrtha": ['mw'],
    "kanyāvat": ['mw'],
    "kanyāvedin": ['mw'],
    "kanyāvratasthā": ['mw'],
    "kanyāśrama": ['mw'],
    "kanyāśulka": ['mw'],
    "kanyāṭa": ['mw'],
    "kanā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kanānakā": ['mw'],
    "kanāṭha": ['mw'],
    "kanī": ['ap90', 'cae', 'ddsa', 'mw'],
    "kanīci": ['mw'],
    "kanīciḥ": ['ap90'],
    "kanīna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kanīnaka": ['cae', 'gra', 'mw'],
    "kanīnakaḥ": ['ap90'],
    "kanīnakā": ['mw'],
    "kanīnika": ['mw'],
    "kanīnikā": ['mw'],
    "kanīnī": ['mw'],
    "kanīyas": ['ap90', 'ddsa', 'gra', 'mw'],
    "kanīyasa": ['ap90', 'cae', 'mw'],
    "kanīyastva": ['mw'],
    "kanīyasvin": ['mw'],
    "kanīyaḥstana": ['mw'],
    "kanīyaṃs": ['cae'],
    "kanīyokṣara": ['mw'],
    "kanūja": ['ap90'],
    "kap": ['ap90', 'mw'],
    "kapa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kapala": ['cae', 'ddsa', 'mw'],
    "kapalaṃ": ['ap90'],
    "kapalla": ['cped'],
    "kapanaḥ": ['ap90'],
    "kapanā": ['cae', 'gra', 'mw'],
    "kaparda": ['cae', 'ddsa', 'gra', 'mw'],
    "kapardaka": ['cae', 'mw'],
    "kapardayakṣa": ['mw'],
    "kapardaḥ": ['ap90'],
    "kapardibhāṣya": ['mw'],
    "kapardikā": ['ap90', 'mw'],
    "kapardikārikā": ['mw'],
    "kapardin": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "kapardinī": ['mw'],
    "kapardisvāmin": ['mw'],
    "kapardīśaliṅga": ['mw'],
    "kapardīśvaratīrtha": ['mw'],
    "kapaḍa": ['bhs'],
    "kapaṇa": ['cped'],
    "kapaṇikā": ['cped'],
    "kapaṭa": ['cae', 'ddsa', 'mw'],
    "kapaṭacīḍā": ['mw'],
    "kapaṭadaitya": ['mw'],
    "kapaṭadaityavadha": ['mw'],
    "kapaṭakāpaṭika": ['cae'],
    "kapaṭakāpaṭikā": ['mw'],
    "kapaṭalekhya": ['mw'],
    "kapaṭanātaka": ['mw'],
    "kapaṭanāṭaka": ['cae', 'mw'],
    "kapaṭaprabandha": ['mw'],
    "kapaṭatva": ['mw'],
    "kapaṭatā": ['mw'],
    "kapaṭatāpasa": ['mw'],
    "kapaṭavacana": ['mw'],
    "kapaṭaveśa": ['mw'],
    "kapaṭaveśin": ['mw'],
    "kapaṭaḥ": ['ap90'],
    "kapaṭeśvara": ['mw'],
    "kapaṭeśvarī": ['mw'],
    "kapaṭika": ['mw'],
    "kapaṭikaḥ": ['ap90'],
    "kapaṭin": ['ap90', 'mw'],
    "kapaṭinī": ['mw'],
    "kapaṭī": ['mw'],
    "kapha": ['cae', 'ddsa', 'mw'],
    "kaphada": ['mw'],
    "kaphagaṇḍa": ['mw'],
    "kaphaghna": ['mw'],
    "kaphaghnī": ['mw'],
    "kaphagulma": ['mw'],
    "kaphahara": ['mw'],
    "kaphahṛt": ['mw'],
    "kaphaja": ['mw'],
    "kaphajvara": ['mw'],
    "kaphakara": ['mw'],
    "kaphakarakūrcikā": ['mw'],
    "kaphakarakṣaya": ['mw'],
    "kaphala": ['ap90', 'mw'],
    "kaphalikā": ['bhs'],
    "kaphanāśana": ['mw'],
    "kaphaprāya": ['mw'],
    "kaphasaṃbhava": ['mw'],
    "kaphauḍa": ['mw'],
    "kaphauḍaḥ": ['ap90'],
    "kaphavairin": ['mw'],
    "kaphavardhaka": ['mw'],
    "kaphavardhana": ['mw'],
    "kaphavirodhin": ['mw'],
    "kaphavātika": ['mw'],
    "kaphaḥ": ['ap90'],
    "kaphaṇi": ['mw'],
    "kaphaṇiḥ": ['ap90'],
    "kaphelū": ['ap90', 'mw'],
    "kaphila": ['mw'],
    "kaphin": ['ap90', 'bhs', 'mw'],
    "kaphina": ['bhs', 'mw'],
    "kaphinī": ['mw'],
    "kaphiṇa": ['bhs'],
    "kaphoṇi": ['mw'],
    "kaphoṇighāta": ['mw'],
    "kaphoṇiguḍa": ['mw'],
    "kaphoṇiguḍāya": ['mw'],
    "kaphāntaka": ['mw'],
    "kaphāntika": ['mw'],
    "kaphāri": ['mw'],
    "kaphātmaka": ['mw'],
    "kapi": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kapibhakṣa": ['mw'],
    "kapicitta": ['bhs'],
    "kapicūta": ['mw'],
    "kapicūḍa": ['mw'],
    "kapidhvaja": ['cae', 'mw'],
    "kapija": ['mw'],
    "kapijaṅghikā": ['mw'],
    "kapikacchu": ['mw'],
    "kapikacchuphalopamā": ['mw'],
    "kapikacchurā": ['mw'],
    "kapikanduka": ['mw'],
    "kapiketana": ['cae', 'mw'],
    "kapiketu": ['mw'],
    "kapikeśa": ['mw'],
    "kapikoli": ['mw'],
    "kapikā": ['mw'],
    "kapila": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kapilabhadrā": ['mw'],
    "kapilabhāṣya": ['mw'],
    "kapiladeva": ['mw'],
    "kapiladhārā": ['mw'],
    "kapiladhūsara": ['mw'],
    "kapiladruma": ['mw'],
    "kapiladrākṣā": ['mw'],
    "kapiladyuti": ['mw'],
    "kapilagītā": ['mw'],
    "kapilajaṭa": ['mw'],
    "kapilaka": ['mw'],
    "kapilaloha": ['mw'],
    "kapilalāṭa": ['mw'],
    "kapilapañcarātra": ['mw'],
    "kapilaphalā": ['mw'],
    "kapilapura": ['bhs', 'mw'],
    "kapilarudra": ['mw'],
    "kapilarṣi": ['cae', 'mw'],
    "kapilasaṃhitā": ['mw'],
    "kapilasāhvaya": ['bhs'],
    "kapilasāṃkhyapravacana": ['mw'],
    "kapilasāṃkhyapravacanabhāṣya": ['mw'],
    "kapilavastu": ['bhs', 'cae', 'mw'],
    "kapilavatthu": ['cped'],
    "kapilavāstavya": ['bhs'],
    "kapilaśarman": ['mw'],
    "kapilaśiṃśapā": ['mw'],
    "kapileśvaradeva": ['mw'],
    "kapileśvaratīrtha": ['mw'],
    "kapilikā": ['mw'],
    "kapiloha": ['mw'],
    "kapilolā": ['mw'],
    "kapilomaphalā": ['mw'],
    "kapilā": ['bhs', 'mw'],
    "kapilācārya": ['mw'],
    "kapilādhikā": ['mw'],
    "kapilāhrada": ['mw'],
    "kapilāhvaya": ['bhs', 'mw'],
    "kapilākṣā": ['mw'],
    "kapilākṣī": ['mw'],
    "kapilāpati": ['mw'],
    "kapilātīrtha": ['mw'],
    "kapilāvaṭa": ['mw'],
    "kapilāya": ['mw'],
    "kapilāñjana": ['mw'],
    "kapilāśrama": ['mw'],
    "kapilāśva": ['mw'],
    "kapilāṅga": ['bhs'],
    "kapilāṣaṣṭhī": ['mw'],
    "kapilīkṛ": ['ddsa', 'mw'],
    "kapinahya": ['bhs'],
    "kapināmaka": ['mw'],
    "kapināman": ['mw'],
    "kapināsa": ['mw'],
    "kapināsikā": ['mw'],
    "kapināśana": ['mw'],
    "kapinṛttā": ['mw'],
    "kapipati": ['cae', 'mw'],
    "kapipippalī": ['mw'],
    "kapiprabhu": ['mw'],
    "kapiprabhā": ['mw'],
    "kapipriya": ['mw'],
    "kapiraka": ['mw'],
    "kapirasāḍhyā": ['mw'],
    "kapiratha": ['mw'],
    "kapiromalatā": ['mw'],
    "kapiromaphalā": ['mw'],
    "kapiskandha": ['mw'],
    "kapisthala": ['mw'],
    "kapisvara": ['mw'],
    "kapisīsa": ['cped'],
    "kapisīsaka": ['cped'],
    "kapitaila": ['mw'],
    "kapittha": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kapitthaka": ['bhs', 'mw'],
    "kapitthana": ['cped'],
    "kapitthaparṇī": ['mw'],
    "kapitthaphala": ['mw'],
    "kapitthatvac": ['mw'],
    "kapitthaḥ": ['ap90'],
    "kapitthinī": ['mw'],
    "kapitthānī": ['mw'],
    "kapitthāsya": ['mw'],
    "kapitva": ['mw'],
    "kapitīrtha": ['mw'],
    "kapivaktra": ['mw'],
    "kapivallikā": ['mw'],
    "kapivallī": ['mw'],
    "kapivana": ['mw'],
    "kapiñjala": ['cae', 'cped', 'ddsa', 'mw'],
    "kapiñjalanyāya": ['mw'],
    "kapiñjalā": ['mw'],
    "kapiñjalāda": ['mw'],
    "kapiñjalārma": ['mw'],
    "kapiñjara": ['cped'],
    "kapiśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kapiśabhrū": ['mw'],
    "kapiśaya": ['mw'],
    "kapiśiras": ['mw'],
    "kapiśita": ['ap90', 'mw'],
    "kapiśā": ['ap90', 'mw'],
    "kapiśāka": ['mw'],
    "kapiśāputra": ['mw'],
    "kapiśāvadāna": ['mw'],
    "kapiśāñjana": ['mw'],
    "kapiśīkā": ['ap90', 'mw'],
    "kapiśīkṛ": ['mw'],
    "kapiśīrṣa": ['mw'],
    "kapiśīrṣṇī": ['mw'],
    "kapiḥ": ['ap90'],
    "kapiṃjalaḥ": ['ap90'],
    "kapiṅgala": ['mw'],
    "kapiṣṭhala": ['cae', 'ddsa', 'mw'],
    "kapiṣṭhalasaṃhitā": ['mw'],
    "kapiṣṭhalāyana": ['bhs'],
    "kapiṭṭha": ['cped'],
    "kapiṭṭhana": ['cped'],
    "kaplaka": ['mw'],
    "kapola": ['cae', 'ddsa', 'mw'],
    "kapolabhitti": ['mw'],
    "kapolakavi": ['mw'],
    "kapolakāṣa": ['mw'],
    "kapolapattra": ['mw'],
    "kapolaphalaka": ['mw'],
    "kapolapāli": ['mw'],
    "kapolapālī": ['mw'],
    "kapolarāga": ['mw'],
    "kapolatāḍana": ['mw'],
    "kapolaḥ": ['ap90'],
    "kapolī": ['mw'],
    "kapota": ['cae', 'ddsa', 'gra', 'mw'],
    "kapotabāṇā": ['mw'],
    "kapotacaraṇā": ['mw'],
    "kapotahasta": ['mw'],
    "kapotahastaka": ['mw'],
    "kapotaka": ['mw'],
    "kapotakarbura": ['mw'],
    "kapotakaḥ": ['ap90'],
    "kapotakī": ['mw'],
    "kapotakīya": ['mw'],
    "kapotakīyā": ['ap90'],
    "kapotapadadarśana": ['mw'],
    "kapotapeṭaka": ['mw'],
    "kapotapāda": ['mw'],
    "kapotapāka": ['mw'],
    "kapotapākī": ['mw'],
    "kapotapāli": ['mw'],
    "kapotapālikā": ['cae', 'mw'],
    "kapotapālī": ['mw'],
    "kapotaretasa": ['mw'],
    "kapotaroman": ['mw'],
    "kapotasāra": ['mw'],
    "kapotavakra": ['mw'],
    "kapotavallī": ['mw'],
    "kapotavarṇa": ['mw'],
    "kapotavarṇī": ['mw'],
    "kapotavaṅkā": ['mw'],
    "kapotavegā": ['mw'],
    "kapotaḥ": ['ap90'],
    "kapotikā": ['ddsa', 'mw'],
    "kapotin": ['mw'],
    "kapotābha": ['mw'],
    "kapotāri": ['mw'],
    "kapotāñjana": ['mw'],
    "kapotāṅghri": ['mw'],
    "kapotī": ['ap90', 'mw'],
    "kapoṭamālā": ['bhs'],
    "kappa": ['cped'],
    "kappaka": ['cped'],
    "kappakata": ['cped'],
    "kappara": ['cped'],
    "kappati": ['cped'],
    "kappaya": ['cped'],
    "kappayat": ['cped'],
    "kappayati": ['cped'],
    "kappayiṁsu": ['cped'],
    "kappaṁ": ['cped'],
    "kappaṁ-jaha": ['cped'],
    "kappaṭṭha": ['cped'],
    "kappaṭṭhika": ['cped'],
    "kappaṭṭhiya": ['cped'],
    "kappaṭṭhāyi": ['cped'],
    "kappaṭṭhāyin": ['cped'],
    "kappesi": ['cped'],
    "kappesuṁ": ['cped'],
    "kappeta": ['cped'],
    "kappetabba": ['cped'],
    "kappetar": ['cped'],
    "kappeti": ['cped'],
    "kappetvā": ['cped'],
    "kapphilla": ['mw'],
    "kapphiṇa": ['bhs', 'mw'],
    "kappita": ['cped'],
    "kappitakesamassu": ['cped'],
    "kappiya": ['cped'],
    "kappiyakuṭī": ['cped'],
    "kappiyakāraka": ['cped'],
    "kappākappa": ['cped'],
    "kappāpetabba": ['cped'],
    "kappāpeti": ['cped'],
    "kappāsa": ['cped'],
    "kappāsapicu": ['cped'],
    "kappāsika": ['cped'],
    "kappāsikapaṇṇa": ['cped'],
    "kappāsikasukhuma": ['cped'],
    "kappāsikā": ['cped'],
    "kappāsiya": ['cped'],
    "kappāsiyā": ['cped'],
    "kappātetvā": ['cped'],
    "kappāvasesaṁ": ['cped'],
    "kapucchala": ['cae', 'ddsa', 'mw'],
    "kapucchalaṃ": ['ap90'],
    "kaputsala": ['mw'],
    "kapuṣṇikā": ['mw'],
    "kapuṣṭikā": ['mw'],
    "kapyākhya": ['mw'],
    "kapyāri": ['bhs'],
    "kapyāsa": ['mw'],
    "kapāla": ['cae', 'cped', 'ddsa', 'mw'],
    "kapālabhātī": ['mw'],
    "kapālabhṛt": ['mw'],
    "kapālahasta": ['mw'],
    "kapālahatta": ['cped'],
    "kapālaka": ['cae', 'mw'],
    "kapālaketu": ['mw'],
    "kapālakhaḍgin": ['mw'],
    "kapālakoṭanī": ['bhs'],
    "kapālakuṇḍalā": ['cae'],
    "kapālamocana": ['mw'],
    "kapālamocanī": ['bhs'],
    "kapālamālin": ['cae', 'mw'],
    "kapālamālā": ['mw'],
    "kapālanālikā": ['mw'],
    "kapālapāśin": ['mw'],
    "kapālapāṇitva": ['mw'],
    "kapālasaṃdhi": ['mw'],
    "kapālasphoṭa": ['mw'],
    "kapālavajrin": ['mw'],
    "kapālavat": ['mw'],
    "kapālaśaktihasta": ['mw'],
    "kapālaśiras": ['mw'],
    "kapālaśūlakhaṭvāṅgin": ['mw'],
    "kapālaḥ": ['ap90'],
    "kapāleśvara": ['mw'],
    "kapāleśvaratīrtha": ['mw'],
    "kapāleśvarī": ['mw'],
    "kapāli": ['mw'],
    "kapālikā": ['ap90', 'ddsa', 'mw'],
    "kapālin": ['ap90', 'cae', 'ddsa', 'mw'],
    "kapālina": ['mw'],
    "kapālinī": ['bhs', 'mw'],
    "kapāliḥ": ['ap90'],
    "kapālī": ['mw'],
    "kapāpikā": ['bhs'],
    "kapāṭa": ['bhs', 'cae', 'ddsa', 'mw'],
    "kapāṭaghna": ['mw'],
    "kapāṭaka": ['mw'],
    "kapāṭamudrā": ['mw'],
    "kapāṭasaṃdhi": ['mw'],
    "kapāṭasaṃdhika": ['mw'],
    "kapāṭatoraṇavat": ['mw'],
    "kapāṭavakṣas": ['cae', 'mw'],
    "kapāṭaḥ": ['ap90'],
    "kapāṭita": ['mw'],
    "kapāṭodghāṭana": ['mw'],
    "kapīdaka": ['bhs'],
    "kapījya": ['mw'],
    "kapīkacchu": ['mw'],
    "kapīndra": ['cae', 'ddsa', 'mw'],
    "kapīta": ['mw'],
    "kapītaka": ['mw'],
    "kapītana": ['cae', 'ddsa', 'mw'],
    "kapītanaḥ": ['ap90'],
    "kapīvat": ['mw'],
    "kapīvatī": ['mw'],
    "kapīśvara": ['cae', 'mw'],
    "kapīṣṭa": ['mw'],
    "kapūya": ['ap90', 'cae', 'ddsa', 'mw'],
    "kapṛth": ['cae', 'ddsa', 'gra', 'mw'],
    "kapṛtha": ['cae', 'gra', 'mw'],
    "kar": ['gra'],
    "kara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "karabadara": ['mw'],
    "karabaka": ['mw'],
    "karabha": ['bhs', 'cae', 'mw'],
    "karabhagrāma": ['mw'],
    "karabhagrīva": ['mw'],
    "karabhaka": ['cae', 'mw'],
    "karabhakaḥ": ['ap90'],
    "karabhakāṇḍikā": ['mw'],
    "karabhapriya": ['mw'],
    "karabhapriyā": ['mw'],
    "karabhavallabha": ['mw'],
    "karabhañjaka": ['mw'],
    "karabhañjika": ['mw'],
    "karabhaḥ": ['ap90'],
    "karabhin": ['ap90', 'mw'],
    "karabhorū": ['cae', 'mw'],
    "karabhā": ['mw'],
    "karabhādanī": ['mw'],
    "karabhājana": ['mw'],
    "karabhāṣṭaka": ['mw'],
    "karabhī": ['mw'],
    "karabhīraḥ": ['ap90'],
    "karabhīya": ['mw'],
    "karabhū": ['mw'],
    "karabhūṣaṇa": ['cae', 'mw'],
    "karabāla": ['mw'],
    "karacchada": ['mw'],
    "karacchadā": ['mw'],
    "karaculi": ['mw'],
    "karad": ['mw'],
    "karada": ['bhs', 'mw'],
    "karadakṣa": ['mw'],
    "karadhṛta": ['mw'],
    "karadruma": ['mw'],
    "karadviṣ": ['mw'],
    "karadvīpa": ['mw'],
    "karadāyaka": ['mw'],
    "karadīkṛ": ['mw'],
    "karadīkṛta": ['mw'],
    "karagharṣaṇa": ['mw'],
    "karagharṣin": ['mw'],
    "karaghāṭa": ['mw'],
    "karagraha": ['cae', 'mw'],
    "karagrahaṇa": ['mw'],
    "karagrāham": ['mw'],
    "karagrāhin": ['mw'],
    "karagṛhīti": ['mw'],
    "karahati": ['mw'],
    "karahañcā": ['mw'],
    "karahāra": ['mw'],
    "karahāṭa": ['mw'],
    "karahāṭaka": ['mw'],
    "karahāṭaḥ": ['ap90'],
    "karaja": ['ddsa', 'mw'],
    "karajapya": ['mw'],
    "karajavardhana": ['mw'],
    "karajyoḍi": ['mw'],
    "karajākhya": ['mw'],
    "karajāla": ['mw'],
    "karaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "karakacaturthī": ['mw'],
    "karakacchapikā": ['mw'],
    "karakalaśa": ['mw'],
    "karakamala": ['mw'],
    "karakandikara": ['bhs'],
    "karakapātrikā": ['mw'],
    "karakarṇa": ['mw'],
    "karakarṇin": ['bhs'],
    "karakatoya": ['mw'],
    "karakaḥ": ['ap90'],
    "karakaṇḍa": ['bhs'],
    "karakaṇṭaka": ['mw'],
    "karakaṭa": ['mw'],
    "karakaṭaka": ['cped'],
    "karakisalaya": ['cae', 'ddsa', 'mw'],
    "karakiṇī": ['bhs'],
    "karakoṣa": ['mw'],
    "karakudmala": ['mw'],
    "karakā": ['ddsa'],
    "karakābhighāta": ['mw'],
    "karakāmbhas": ['mw'],
    "karakāmbu": ['mw'],
    "karakāsāra": ['mw'],
    "karakāya": ['cped'],
    "karakāyu": ['mw'],
    "karakṛtātman": ['mw'],
    "karalāya": ['mw'],
    "karama": ['bhs', 'mw'],
    "karamadhya": ['mw'],
    "karamanda": ['mw'],
    "karamarda": ['mw'],
    "karamardaka": ['mw'],
    "karamardā": ['mw'],
    "karamardī": ['mw'],
    "karamarin": ['ap90'],
    "karamarānīta": ['cped'],
    "karamarī": ['mw'],
    "karamaṇḍalin": ['mw'],
    "karamaṭṭa": ['mw'],
    "karamaṭṭaḥ": ['ap90'],
    "karamba": ['mw'],
    "karambha": ['cae', 'ddsa', 'gra', 'mw'],
    "karambhabhāga": ['mw'],
    "karambhaka": ['mw'],
    "karambhapātra": ['mw'],
    "karambhavālukā": ['cae', 'mw'],
    "karambhavālukātāpa": ['mw'],
    "karambhi": ['mw'],
    "karambhin": ['gra', 'mw'],
    "karambhā": ['mw'],
    "karambhād": ['cae', 'gra', 'mw'],
    "karambita": ['mw'],
    "karamocana": ['mw'],
    "karamokṣa": ['mw'],
    "karamukta": ['mw'],
    "karamukteśvara": ['mw'],
    "karamāla": ['mw'],
    "karamālā": ['mw'],
    "karandakanivāpa": ['bhs'],
    "karanihita": ['mw'],
    "karaniveśita": ['ddsa'],
    "karanta": ['bhs'],
    "karantha": ['mw'],
    "karanyastakapolāntam": ['mw'],
    "karanyāsa": ['mw'],
    "karapadma": ['mw'],
    "karapallava": ['cae', 'mw'],
    "karaparṇa": ['mw'],
    "karapattra": ['cae', 'mw'],
    "karapattraka": ['mw'],
    "karapattravat": ['mw'],
    "karapattrikā": ['bhs', 'mw'],
    "karapattrā": ['mw'],
    "karapaṅkaja": ['mw'],
    "karapaṇya": ['mw'],
    "karaphu": ['bhs', 'mw'],
    "karapraceya": ['mw'],
    "karaprada": ['mw'],
    "karaprāpta": ['mw'],
    "karapuṭa": ['mw'],
    "karapuṭāñjali": ['mw'],
    "karapuṭī": ['mw'],
    "karapāla": ['cae', 'mw'],
    "karapālaka": ['mw'],
    "karapāli": ['mw'],
    "karapālikā": ['mw'],
    "karapātra": ['mw'],
    "karapātrī": ['mw'],
    "karapṛṣṭha": ['mw'],
    "kararddhi": ['mw'],
    "kararuddha": ['mw'],
    "kararudh": ['mw'],
    "kararuha": ['cae', 'ddsa', 'mw'],
    "kararuhapada": ['mw'],
    "karas": ['cae', 'ddsa', 'gra', 'mw'],
    "karasaṃdaṃśa": ['mw'],
    "karasaṃdaṃśahīnaka": ['mw'],
    "karasna": ['cae', 'ddsa', 'gra', 'mw'],
    "karaspanda": ['mw'],
    "karasphoṭa": ['mw'],
    "karastha": ['cae', 'ddsa', 'mw'],
    "karasthālin": ['mw'],
    "karasthīkṛ": ['mw'],
    "karasvana": ['mw'],
    "karasvāmin": ['mw'],
    "karasāda": ['mw'],
    "karasūtra": ['mw'],
    "karat": ['cped'],
    "karatala": ['cae', 'ddsa', 'mw'],
    "karataladhṛta": ['mw'],
    "karatalagata": ['mw'],
    "karatalastha": ['mw'],
    "karatalatāla": ['mw'],
    "karatalā": ['mw'],
    "karatalāmalaka": ['mw'],
    "karatalīkṛ": ['mw'],
    "karatalīkṛta": ['mw'],
    "karatanu": ['mw'],
    "karatas": ['mw'],
    "karatha": ['mw'],
    "karati": ['bhs'],
    "karatoyinī": ['mw'],
    "karatoyā": ['mw'],
    "karatāla": ['mw'],
    "karatālaka": ['mw'],
    "karatālikā": ['mw'],
    "karatṛṇa": ['mw'],
    "karavallī": ['mw'],
    "karavartam": ['mw'],
    "karavat": ['mw'],
    "karavika": ['cped'],
    "karavimukti": ['mw'],
    "karavinda": ['mw'],
    "karavindīya": ['mw'],
    "karaviṅka": ['bhs'],
    "karavraṇa": ['mw'],
    "karavāla": ['cae', 'mw'],
    "karavālaputrī": ['mw'],
    "karavāli": ['mw'],
    "karavālikā": ['mw'],
    "karavāraka": ['mw'],
    "karavāri": ['mw'],
    "karavī": ['mw'],
    "karavīka": ['cped', 'mw'],
    "karavīkabhāṇi": ['cped'],
    "karavīkabhāṇin": ['cped'],
    "karavīra": ['bhs', 'cae', 'mw'],
    "karavīrabhujā": ['mw'],
    "karavīrabhūṣā": ['mw'],
    "karavīradāma": ['cae'],
    "karavīraka": ['mw'],
    "karavīrakandasaṃjña": ['mw'],
    "karavīrakarambhin": ['mw'],
    "karavīrakā": ['mw'],
    "karavīramāhātmya": ['mw'],
    "karavīrapatta": ['cped'],
    "karavīrapura": ['mw'],
    "karavīravrata": ['mw'],
    "karavīrikā": ['bhs'],
    "karavīrya": ['mw'],
    "karavīrā": ['mw'],
    "karavīrākara": ['mw'],
    "karavīrī": ['mw'],
    "karañja": ['cae', 'ddsa', 'gra', 'mw'],
    "karañjaha": ['gra', 'mw'],
    "karañjaka": ['bhs', 'mw'],
    "karañjaphalaka": ['mw'],
    "karañjī": ['mw'],
    "karaśuddhi": ['mw'],
    "karaśākhā": ['mw'],
    "karaśīkara": ['mw'],
    "karaśūka": ['mw'],
    "karaḷa": ['cped'],
    "karaṃba": ['ap90'],
    "karaṃbaḥ": ['ap90'],
    "karaṃbhakaṃ": ['ap90'],
    "karaṃbhaḥ": ['ap90'],
    "karaṃdhama": ['mw'],
    "karaṃdhaya": ['ap90', 'mw'],
    "karaṃjaḥ": ['ap90'],
    "karaṃkaḥ": ['ap90'],
    "karaṃḍakaḥ": ['ap90'],
    "karaṃḍaḥ": ['ap90'],
    "karaṃḍin": ['ap90'],
    "karaṅgaṇa": ['mw'],
    "karaṅka": ['bhs', 'cae', 'ddsa', 'mw'],
    "karaṅkaśāli": ['mw'],
    "karaṅkiṇī": ['mw'],
    "karaṇa": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "karaṇagrāma": ['mw'],
    "karaṇakesarin": ['mw'],
    "karaṇakutūhala": ['mw'],
    "karaṇamantra": ['mw'],
    "karaṇaneri": ['mw'],
    "karaṇanerika": ['mw'],
    "karaṇaniyama": ['mw'],
    "karaṇapaddhati": ['mw'],
    "karaṇaprabodha": ['mw'],
    "karaṇaprakāśa": ['mw'],
    "karaṇaprayoga": ['mw'],
    "karaṇarūpa": ['cae'],
    "karaṇasthānabheda": ['mw'],
    "karaṇasāra": ['mw'],
    "karaṇasūtra": ['mw'],
    "karaṇatrāṇa": ['mw'],
    "karaṇatva": ['mw'],
    "karaṇatā": ['mw'],
    "karaṇavat": ['mw'],
    "karaṇavigama": ['mw'],
    "karaṇavinyaya": ['mw'],
    "karaṇavyāpāra": ['mw'],
    "karaṇayati": ['mw'],
    "karaṇi": ['mw'],
    "karaṇin": ['mw'],
    "karaṇā": ['bhs'],
    "karaṇābda": ['mw'],
    "karaṇādhikāra": ['mw'],
    "karaṇādhipa": ['mw'],
    "karaṇāṭṭa": ['mw'],
    "karaṇī": ['bhs', 'mw'],
    "karaṇīya": ['bhs', 'cae', 'cped', 'mw'],
    "karaṇḍa": ['cae', 'cped', 'ddsa', 'mw'],
    "karaṇḍaka": ['bhs', 'cped', 'mw'],
    "karaṇḍakanivāpa": ['mw'],
    "karaṇḍakavat": ['mw'],
    "karaṇḍaphalaka": ['mw'],
    "karaṇḍavyūha": ['mw'],
    "karaṇḍin": ['mw'],
    "karaṭa": ['cae', 'ddsa', 'mw'],
    "karaṭaka": ['cae', 'mw'],
    "karaṭakaḥ": ['ap90'],
    "karaṭaḥ": ['ap90'],
    "karaṭikautuka": ['mw'],
    "karaṭin": ['ap90', 'mw'],
    "karaṭu": ['mw'],
    "karaṭuḥ": ['ap90'],
    "karaṭā": ['mw'],
    "karaṭāmukha": ['mw'],
    "karaṭī": ['mw'],
    "karb": ['ap90', 'mw'],
    "karbara": ['ap90', 'mw'],
    "karbarā": ['mw'],
    "karbela": ['mw'],
    "karbu": ['ap90', 'cae', 'ddsa', 'mw'],
    "karbudāra": ['mw'],
    "karbudāraka": ['mw'],
    "karbuka": ['mw'],
    "karbura": ['ap90', 'cae', 'mw'],
    "karburaka": ['mw'],
    "karburaphala": ['mw'],
    "karburita": ['ap90'],
    "karburā": ['mw'],
    "karburāṅgā": ['mw'],
    "karburī": ['mw'],
    "karbūra": ['ap90', 'mw'],
    "karbūraka": ['mw'],
    "karbūrita": ['mw'],
    "karbūrā": ['mw'],
    "karcarikā": ['mw'],
    "karcarī": ['mw'],
    "karcūra": ['cae', 'ddsa', 'mw'],
    "karcūraka": ['mw'],
    "karcūrakaḥ": ['ap90'],
    "karcūraḥ": ['ap90'],
    "karcūṭikā": ['mw'],
    "kard": ['ap90', 'mw'],
    "karda": ['mw'],
    "kardama": ['cae', 'ddsa', 'mw'],
    "kardamaka": ['mw'],
    "kardamakaḥ": ['ap90'],
    "kardamarāja": ['mw'],
    "kardamarājan": ['mw'],
    "kardamavīsarpa": ['mw'],
    "kardamaḥ": ['ap90'],
    "kardameśvaramāhātmya": ['mw'],
    "kardamila": ['mw'],
    "kardaminī": ['mw'],
    "kardamita": ['ap90', 'cae', 'mw'],
    "kardamodbhava": ['mw'],
    "kardamākhya": ['mw'],
    "kardamāṭaka": ['mw'],
    "kardamī": ['mw'],
    "kardana": ['ddsa', 'mw'],
    "kardanaṃ": ['ap90'],
    "kardanī": ['mw'],
    "kardaḥ": ['ap90'],
    "kardaṭa": ['mw'],
    "kare": ['cped'],
    "karenara": ['mw'],
    "karenaraḥ": ['ap90'],
    "karenduka": ['mw'],
    "karerikuṭikā": ['cped'],
    "karerimaṇḍalamālā": ['cped'],
    "karevara": ['mw'],
    "karevaraḥ": ['ap90'],
    "kareyya": ['cped'],
    "kareyyasi": ['cped'],
    "kareyyatha": ['cped'],
    "kareyyaṁ": ['cped'],
    "kareyyāma": ['cped'],
    "kareḍuka": ['mw'],
    "kareṇu": ['cae', 'ddsa', 'mw'],
    "kareṇubhū": ['mw'],
    "kareṇuka": ['mw'],
    "kareṇukaṃ": ['ap90'],
    "kareṇukā": ['mw'],
    "kareṇumatī": ['mw'],
    "kareṇupāla": ['mw'],
    "kareṇusuta": ['mw'],
    "kareṇuvarya": ['mw'],
    "kareṇuḥ": ['ap90'],
    "kareṇū": ['ap90'],
    "kareṭa": ['mw'],
    "kareṭavyā": ['mw'],
    "kareṭaḥ": ['ap90'],
    "kareṭu": ['mw'],
    "kareṭuḥ": ['ap90'],
    "karhacid": ['bhs'],
    "karhi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "karhicit": ['ap90'],
    "kari": ['mw'],
    "karibandha": ['mw'],
    "karibha": ['mw'],
    "karicarman": ['mw'],
    "karidanta": ['cae', 'mw'],
    "karidāraka": ['mw'],
    "karigarjita": ['mw'],
    "karihasta": ['mw'],
    "karija": ['mw'],
    "karika": ['ddsa', 'mw'],
    "karikaṇā": ['mw'],
    "karikaṇāvallī": ['mw'],
    "karikrata": ['mw'],
    "karikumbha": ['mw'],
    "karikusumbha": ['mw'],
    "karikusumbhaka": ['mw'],
    "karikā": ['ap90', 'mw'],
    "karikāra": ['bhs'],
    "karikṛt": ['mw'],
    "karikṛṣṇā": ['mw'],
    "karimakara": ['mw'],
    "karimaṇḍita": ['mw'],
    "karimha": ['cped'],
    "karimukha": ['mw'],
    "karimuktā": ['mw'],
    "karimācala": ['mw'],
    "karin": ['ap90', 'cae', 'ddsa', 'mw'],
    "karināsikā": ['mw'],
    "karināsā": ['mw'],
    "karipa": ['mw'],
    "karipatha": ['mw'],
    "karipattra": ['mw'],
    "karipippalī": ['mw'],
    "karipota": ['mw'],
    "karira": ['mw'],
    "karirata": ['mw'],
    "kariskandha": ['mw'],
    "karissasi": ['cped'],
    "karissati": ['cped'],
    "karissāma": ['cped'],
    "karissāmi": ['cped'],
    "karisundarikā": ['mw'],
    "karitva": ['mw'],
    "karitvā": ['cped'],
    "karitvāna": ['cped'],
    "karivaijayantī": ['mw'],
    "karivara": ['mw'],
    "kariya": ['bhs', 'cped'],
    "kariyyate": ['cped'],
    "kariyyati": ['cped'],
    "kariyādas": ['mw'],
    "kariśāvaka": ['mw'],
    "kariṇa": ['bhs'],
    "kariṇī": ['ap90', 'mw'],
    "kariṇīsahāya": ['mw'],
    "kariṣya": ['ddsa', 'gra', 'mw'],
    "kariṣyat": ['mw'],
    "kariṣṇu": ['ddsa', 'mw'],
    "kariṣṭha": ['cae', 'gra', 'mw'],
    "karj": ['ap90', 'mw'],
    "kark": ['ap90', 'mw'],
    "karka": ['ap90', 'cae', 'ddsa', 'mw'],
    "karkacandreśvaratantra": ['mw'],
    "karkacirbhiṭā": ['mw'],
    "karkakhaṇḍa": ['mw'],
    "karkandhu": ['cae', 'ddsa', 'gra', 'mw'],
    "karkandhukuṇa": ['mw'],
    "karkandhumatī": ['mw'],
    "karkandhuprastha": ['mw'],
    "karkandhurohita": ['mw'],
    "karkandhusaktu": ['mw'],
    "karkandhūkā": ['mw'],
    "karkaphala": ['mw'],
    "karkara": ['ap90', 'cae', 'ddsa', 'mw'],
    "karkarabhadra": ['bhs'],
    "karkaracchadā": ['mw'],
    "karkarava": ['bhs'],
    "karkareḍu": ['mw'],
    "karkareḍuka": ['mw'],
    "karkareṭa": ['mw'],
    "karkareṭu": ['ddsa', 'mw'],
    "karkari": ['cae', 'gra', 'mw'],
    "karkarika": ['mw'],
    "karkarikarṇa": ['mw'],
    "karkarāhvā": ['mw'],
    "karkarāja": ['mw'],
    "karkarākṣa": ['mw'],
    "karkarālaḥ": ['ap90'],
    "karkarāndhaka": ['mw'],
    "karkarāndhuka": ['mw'],
    "karkarāṅga": ['mw'],
    "karkarāṭu": ['mw'],
    "karkarāṭuka": ['mw'],
    "karkarāṭuḥ": ['ap90'],
    "karkarī": ['ap90', 'bhs', 'cae', 'mw'],
    "karkarīkā": ['mw'],
    "karkasvāmin": ['mw'],
    "karkasāra": ['mw'],
    "karkavallī": ['mw'],
    "karkaśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "karkaśacchada": ['mw'],
    "karkaśacchadā": ['mw'],
    "karkaśadala": ['mw'],
    "karkaśadalā": ['mw'],
    "karkaśatva": ['mw'],
    "karkaśikā": ['ap90', 'mw'],
    "karkaśā": ['mw'],
    "karkaśī": ['mw'],
    "karkaṃdhuḥ": ['ap90'],
    "karkaṭa": ['cae', 'ddsa', 'mw'],
    "karkaṭaka": ['bhs', 'cae', 'mw'],
    "karkaṭakaḥ": ['ap90'],
    "karkaṭakāsthi": ['mw'],
    "karkaṭapura": ['mw'],
    "karkaṭavallī": ['mw'],
    "karkaṭaśṛṅga": ['mw'],
    "karkaṭaśṛṅgikā": ['mw'],
    "karkaṭaśṛṅgī": ['mw'],
    "karkaṭaḥ": ['ap90'],
    "karkaṭeśa": ['mw'],
    "karkaṭeśvaratīrtha": ['mw'],
    "karkaṭi": ['mw'],
    "karkaṭikā": ['ap90', 'mw'],
    "karkaṭinī": ['mw'],
    "karkaṭiḥ": ['ap90'],
    "karkaṭu": ['mw'],
    "karkaṭuḥ": ['ap90'],
    "karkaṭā": ['mw'],
    "karkaṭāhva": ['mw'],
    "karkaṭāhvā": ['mw'],
    "karkaṭākhyā": ['mw'],
    "karkaṭākṣa": ['mw'],
    "karkaṭāsthi": ['mw'],
    "karkaṭāṅgā": ['mw'],
    "karkaṭī": ['mw'],
    "karketana": ['cae', 'mw'],
    "karketanaḥ": ['ap90'],
    "karketaraka": ['cae'],
    "karketaṇa": ['cae'],
    "karketila": ['mw'],
    "karkeṇata": ['mw'],
    "karki": ['cae', 'ddsa', 'mw'],
    "karkin": ['cae', 'mw'],
    "karkiprastha": ['mw'],
    "karkiḥ": ['ap90'],
    "karkoṭa": ['cae', 'ddsa', 'mw'],
    "karkoṭaka": ['cae', 'mw'],
    "karkoṭakaviṣa": ['mw'],
    "karkoṭaki": ['mw'],
    "karkoṭakī": ['mw'],
    "karkoṭavāpī": ['mw'],
    "karkoṭaḥ": ['ap90'],
    "karkoṭikā": ['mw'],
    "karkoṭī": ['mw'],
    "karkyādi": ['mw'],
    "karkā": ['mw'],
    "karkāhva": ['mw'],
    "karkākṣa": ['mw'],
    "karkāra": ['mw'],
    "karkārava": ['bhs'],
    "karkāru": ['cae', 'mw'],
    "karkāruka": ['cae', 'mw'],
    "karkārukaḥ": ['ap90'],
    "karkī": ['mw'],
    "karkīprastha": ['mw'],
    "karma": ['mw'],
    "karmabandha": ['cae', 'mw'],
    "karmabandhana": ['cae', 'mw'],
    "karmabhedavicāra": ['mw'],
    "karmabhū": ['mw'],
    "karmabhūmi": ['mw'],
    "karmabhūya": ['mw'],
    "karmabuddhi": ['mw'],
    "karmabāhulya": ['mw'],
    "karmabīja": ['mw'],
    "karmacandra": ['mw'],
    "karmacaṇḍāla": ['mw'],
    "karmaceṣṭā": ['cae', 'mw'],
    "karmacit": ['mw'],
    "karmacodanā": ['cae', 'mw'],
    "karmacārin": ['mw'],
    "karmadaṇḍa": ['mw'],
    "karmadeha": ['mw'],
    "karmadeva": ['mw'],
    "karmadhvaṃsa": ['mw'],
    "karmadhāraya": ['cae', 'mw'],
    "karmadoṣa": ['cae', 'mw'],
    "karmaduṣṭa": ['mw'],
    "karmadāyāda": ['mw'],
    "karmadīpa": ['mw'],
    "karmagati": ['mw'],
    "karmaghāta": ['mw'],
    "karmagrantha": ['mw'],
    "karmagranthiprathamavicāra": ['mw'],
    "karmagupta": ['mw'],
    "karmahasta": ['mw'],
    "karmahetu": ['cae', 'mw'],
    "karmahīna": ['mw'],
    "karmaja": ['cae', 'mw'],
    "karmajaguṇa": ['mw'],
    "karmajanya": ['mw'],
    "karmajanyatā": ['cae', 'mw'],
    "karmajit": ['mw'],
    "karmajita": ['mw'],
    "karmajña": ['mw'],
    "karmaka": ['cae', 'ddsa', 'mw'],
    "karmakara": ['cae', 'mw'],
    "karmakartṛ": ['cae', 'mw'],
    "karmakarī": ['mw'],
    "karmakarībhāva": ['mw'],
    "karmakaumudī": ['mw'],
    "karmakośa": ['mw'],
    "karmakriyākāṇḍa": ['mw'],
    "karmakāla": ['mw'],
    "karmakālanirṇaya": ['mw'],
    "karmakāra": ['mw'],
    "karmakāraka": ['bhs', 'mw'],
    "karmakāraṇa": ['bhs'],
    "karmakārin": ['mw'],
    "karmakārmuka": ['mw'],
    "karmakārāpaya": ['mw'],
    "karmakārī": ['mw'],
    "karmakāṇḍa": ['mw'],
    "karmakīlaka": ['mw'],
    "karmakṛt": ['cae', 'mw'],
    "karmakṛtavat": ['mw'],
    "karmakṛtya": ['cae', 'mw'],
    "karmakṣama": ['mw'],
    "karmakṣaya": ['mw'],
    "karmakṣetra": ['mw'],
    "karmalocana": ['mw'],
    "karmamaya": ['cae', 'mw'],
    "karmamārga": ['mw'],
    "karmamāsa": ['mw'],
    "karmamīmāṃsā": ['mw'],
    "karmamūla": ['mw'],
    "karman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "karmanda": ['mw'],
    "karmandin": ['mw'],
    "karmanibandha": ['mw'],
    "karmanirhāra": ['mw'],
    "karmanirṇaya": ['mw'],
    "karmanivṛtti": ['mw'],
    "karmaniṣṭha": ['cae', 'mw'],
    "karmaniṣṭhā": ['cae', 'gra'],
    "karmanyāsa": ['mw'],
    "karmanāman": ['cae', 'ddsa', 'mw'],
    "karmanāśā": ['mw'],
    "karmapaddhati": ['mw'],
    "karmapatha": ['bhs', 'mw'],
    "karmaphala": ['cae', 'mw'],
    "karmaphalahetu": ['mw'],
    "karmaphalodaya": ['mw'],
    "karmaploti": ['mw'],
    "karmapradīpa": ['mw'],
    "karmapradīpikā": ['mw'],
    "karmaprakāśa": ['mw'],
    "karmaprakāśikā": ['mw'],
    "karmaprakāśinī": ['mw'],
    "karmapravacanīya": ['cae', 'mw'],
    "karmapravāda": ['mw'],
    "karmapāka": ['cae', 'mw'],
    "karmapāradā": ['mw'],
    "karmapātaka": ['mw'],
    "karmara": ['mw'],
    "karmaraka": ['mw'],
    "karmaratnāvalī": ['mw'],
    "karmaraṅga": ['mw'],
    "karmargha": ['mw'],
    "karmarāṣṭra": ['mw'],
    "karmarī": ['ap90', 'mw'],
    "karmasa": ['mw'],
    "karmasaciva": ['mw'],
    "karmasamāpta": ['mw'],
    "karmasaṃbhava": ['cae', 'mw'],
    "karmasaṃgraha": ['cae', 'mw'],
    "karmasaṃnyāsika": ['mw'],
    "karmasaṃvatsara": ['mw'],
    "karmasaṅga": ['cae', 'mw'],
    "karmasaṅgin": ['cae', 'mw'],
    "karmasena": ['mw'],
    "karmasenīya": ['mw'],
    "karmasiddhi": ['cae', 'mw'],
    "karmastava": ['mw'],
    "karmastha": ['mw'],
    "karmasthāna": ['mw'],
    "karmasvaka": ['bhs', 'mw'],
    "karmasādhaka": ['mw'],
    "karmasādhana": ['mw'],
    "karmasākṣin": ['cae', 'mw'],
    "karmasārathi": ['mw'],
    "karmasūtra": ['mw'],
    "karmatattvapradīpikā": ['mw'],
    "karmatva": ['mw'],
    "karmatyāga": ['mw'],
    "karmatā": ['cae', 'ddsa', 'mw'],
    "karmavacana": ['mw'],
    "karmavajra": ['mw'],
    "karmavajrī": ['bhs'],
    "karmavat": ['mw'],
    "karmavaśa": ['mw'],
    "karmavaśitā": ['mw'],
    "karmavibhaṅga": ['bhs'],
    "karmavibhaṅgasūtra": ['bhs'],
    "karmavidhi": ['cae', 'mw'],
    "karmavighna": ['mw'],
    "karmaviparyaya": ['mw'],
    "karmavipāka": ['cae', 'mw'],
    "karmavipākasaṃgraha": ['mw'],
    "karmavipākasāra": ['mw'],
    "karmavirodhin": ['mw'],
    "karmaviśeṣa": ['mw'],
    "karmavyatihāra": ['mw'],
    "karmavācanā": ['bhs'],
    "karmavāda": ['mw'],
    "karmavāṭī": ['mw'],
    "karmayoga": ['cae', 'mw'],
    "karmayoni": ['mw'],
    "karmayuga": ['mw'],
    "karmaśa": ['mw'],
    "karmaśalya": ['mw'],
    "karmaśataka": ['mw'],
    "karmaśauca": ['mw'],
    "karmaśreṣṭha": ['mw'],
    "karmaśālā": ['mw'],
    "karmaśālī": ['mw'],
    "karmaśīla": ['mw'],
    "karmaśūra": ['mw'],
    "karmaṃdin": ['ap90'],
    "karmaṇi": ['mw'],
    "karmaṇia": ['gra'],
    "karmaṇiya": ['bhs'],
    "karmaṇya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "karmaṇyabhuj": ['mw'],
    "karmaṇyakṛt": ['mw'],
    "karmaṇyatā": ['mw'],
    "karmaṇyesthita": ['bhs'],
    "karmaṇyā": ['mw'],
    "karmaṇyābhuj": ['mw'],
    "karmaṇīya": ['bhs'],
    "karmaṣa": ['mw'],
    "karmaṭha": ['ap90', 'cae', 'ddsa', 'mw'],
    "karmendriya": ['cae', 'ddsa', 'mw'],
    "karmika": ['bhs', 'mw'],
    "karmin": ['ap90', 'cae', 'ddsa', 'mw'],
    "karmira": ['bhs'],
    "karmiṣṭha": ['ap90', 'mw'],
    "karmodyoga": ['mw'],
    "karmodyukta": ['mw'],
    "karmodāra": ['mw'],
    "karmopakaraṇa": ['cae', 'mw'],
    "karmābhidhāyaka": ['mw'],
    "karmābhidhāyin": ['mw'],
    "karmābhyāsa": ['mw'],
    "karmādhikāra": ['mw'],
    "karmādhyakṣa": ['mw'],
    "karmāditya": ['mw'],
    "karmājīva": ['mw'],
    "karmākṣama": ['mw'],
    "karmānta": ['cae', 'mw'],
    "karmāntara": ['mw'],
    "karmāntika": ['mw'],
    "karmāntikaloka": ['mw'],
    "karmānubandha": ['mw'],
    "karmānubandhin": ['cae', 'mw'],
    "karmānurūpa": ['mw'],
    "karmānurūpatas": ['mw'],
    "karmānusāra": ['mw'],
    "karmānusāratas": ['mw'],
    "karmānuṣṭhāna": ['mw'],
    "karmānuṣṭhāyin": ['mw'],
    "karmāra": ['cae', 'ddsa', 'gra', 'mw'],
    "karmāraka": ['mw'],
    "karmārambha": ['mw'],
    "karmāravana": ['mw'],
    "karmāraḥ": ['ap90'],
    "karmārha": ['mw'],
    "karmātman": ['cae', 'ddsa', 'mw'],
    "karmāvadāna": ['mw'],
    "karmāvaraṇapratiprasrabdhi": ['bhs'],
    "karmāvaraṇaviśuddhisūtra": ['bhs'],
    "karmāśaya": ['mw'],
    "karmāśritabhakta": ['mw'],
    "karmāṅga": ['mw'],
    "karmīra": ['ap90', 'mw'],
    "karmīṇa": ['mw'],
    "karodaka": ['mw'],
    "karohi": ['cped'],
    "karoma": ['cped'],
    "karonta": ['cped'],
    "karotha": ['cped'],
    "karoti": ['bhs', 'cped', 'ddsa'],
    "karotkara": ['mw'],
    "karotpala": ['mw'],
    "karotu": ['cped'],
    "karoṭa": ['bhs', 'mw'],
    "karoṭaka": ['bhs', 'mw'],
    "karoṭapāṇi": ['bhs', 'mw'],
    "karoṭaṃ": ['ap90'],
    "karoṭi": ['cae', 'ddsa', 'mw'],
    "karoṭika": ['mw'],
    "karpara": ['cae', 'ddsa', 'mw'],
    "karparaka": ['bhs', 'mw'],
    "karparaḥ": ['ap90'],
    "karparikā": ['mw'],
    "karparāla": ['mw'],
    "karparāśa": ['mw'],
    "karparāṃśa": ['mw'],
    "karparī": ['mw'],
    "karpaṇa": ['cae', 'ddsa', 'mw'],
    "karpaṇaḥ": ['ap90'],
    "karpaṭa": ['cae', 'ddsa', 'mw'],
    "karpaṭadhārin": ['mw'],
    "karpaṭaka": ['bhs', 'mw'],
    "karpaṭaḥ": ['ap90'],
    "karpaṭi": ['mw'],
    "karpaṭika": ['ap90', 'mw'],
    "karpaṭin": ['mw'],
    "karphara": ['mw'],
    "karpharaḥ": ['ap90'],
    "karpāsa": ['ddsa', 'mw'],
    "karpāsadhenumāhātmya": ['mw'],
    "karpāsakī": ['mw'],
    "karpāsapicu": ['bhs'],
    "karpāsaḥ": ['ap90'],
    "karpāsika": ['bhs'],
    "karpūra": ['cae', 'ddsa', 'mw'],
    "karpūradvīpa": ['mw'],
    "karpūragaura": ['mw'],
    "karpūraharidrā": ['mw'],
    "karpūraka": ['mw'],
    "karpūrakaḥ": ['ap90'],
    "karpūrakeli": ['cae', 'mw'],
    "karpūramaya": ['mw'],
    "karpūramañjarī": ['cae', 'mw'],
    "karpūramaṇi": ['mw'],
    "karpūranālikā": ['mw'],
    "karpūrapaṭa": ['cae', 'mw'],
    "karpūraprakaraṇa": ['mw'],
    "karpūrarasa": ['mw'],
    "karpūrasaras": ['mw'],
    "karpūrasena": ['mw'],
    "karpūrastava": ['mw'],
    "karpūrastotra": ['mw'],
    "karpūrataila": ['mw'],
    "karpūratilaka": ['cae', 'mw'],
    "karpūratilakā": ['mw'],
    "karpūravarṣa": ['mw'],
    "karpūravilāsa": ['cae', 'mw'],
    "karpūraḥ": ['ap90'],
    "karpūrila": ['mw'],
    "karpūrin": ['mw'],
    "karpūrā": ['mw'],
    "karpūrāśman": ['mw'],
    "kart": ['ap90', 'gra', 'mw'],
    "karta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kartana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kartanabhāṇḍa": ['mw'],
    "kartanasādhana": ['mw'],
    "kartanī": ['ap90', 'mw'],
    "kartapatya": ['mw'],
    "kartapraskanda": ['mw'],
    "kartari": ['cae', 'mw'],
    "kartarikā": ['ap90', 'mw'],
    "kartaryāsya": ['mw'],
    "kartarī": ['cae', 'mw'],
    "kartarīmukha": ['mw'],
    "kartarīphala": ['mw'],
    "kartarīya": ['mw'],
    "kartati": ['bhs'],
    "kartavai": ['mw'],
    "kartave": ['ddsa', 'mw'],
    "kartavya": ['ap90', 'cae', 'mw'],
    "kartavyatva": ['mw'],
    "kartavyatā": ['cae', 'mw'],
    "karthika": ['bhs'],
    "kartin": ['bhs'],
    "kartos": ['cae', 'ddsa', 'mw'],
    "kartr": ['mw'],
    "kartra": ['cae', 'mw'],
    "kartraṃ": ['ap90'],
    "kartrikā": ['ap90'],
    "kartrīya": ['mw'],
    "karttavya": ['ddsa', 'mw'],
    "karttikā": ['mw'],
    "karttrikā": ['mw'],
    "karttrī": ['mw'],
    "karttṛ": ['cae', 'ddsa', 'mw'],
    "karttṛkā": ['ddsa', 'mw'],
    "kartu": ['mw'],
    "kartukāma": ['cae', 'mw'],
    "kartumanas": ['ddsa'],
    "kartva": ['ap90', 'cae', 'ddsa', 'mw'],
    "kartya": ['ddsa', 'mw'],
    "kartṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kartṛbhūta": ['cae', 'mw'],
    "kartṛga": ['mw'],
    "kartṛgupta": ['mw'],
    "kartṛguptaka": ['mw'],
    "kartṛgāmin": ['mw'],
    "kartṛka": ['ap90', 'cae', 'mw'],
    "kartṛkara": ['mw'],
    "kartṛkatva": ['mw'],
    "kartṛkā": ['ap90'],
    "kartṛma": ['bhs'],
    "kartṛmat": ['mw'],
    "kartṛpura": ['mw'],
    "kartṛrūpa": ['cae'],
    "kartṛstha": ['mw'],
    "kartṛsthabhāvaka": ['mw'],
    "kartṛsthakriyaka": ['mw'],
    "kartṛtva": ['mw'],
    "kartṛtā": ['cae', 'mw'],
    "kartṛvācya": ['mw'],
    "karuma": ['mw'],
    "karundhaka": ['mw'],
    "karutthāma": ['mw'],
    "karuṁ": ['cped'],
    "karuṇa": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "karuṇadhvani": ['cae', 'mw'],
    "karuṇam": ['mw'],
    "karuṇamallī": ['mw'],
    "karuṇapuṇḍarīka": ['mw'],
    "karuṇatejas": ['bhs'],
    "karuṇavaruṇālaya": ['mw'],
    "karuṇavedin": ['cae', 'mw'],
    "karuṇaveditva": ['mw'],
    "karuṇaveditṛ": ['mw'],
    "karuṇeśvara": ['mw'],
    "karuṇin": ['ap90', 'mw'],
    "karuṇā": ['ap90', 'bhs', 'cped', 'mw'],
    "karuṇābhidhāna": ['bhs'],
    "karuṇākalpalatā": ['mw'],
    "karuṇākara": ['mw'],
    "karuṇāmallī": ['mw'],
    "karuṇāmaya": ['mw'],
    "karuṇānandakāvya": ['mw'],
    "karuṇāpara": ['mw'],
    "karuṇārambha": ['mw'],
    "karuṇārdra": ['mw'],
    "karuṇāsahagata": ['cped'],
    "karuṇātman": ['mw'],
    "karuṇāvat": ['mw'],
    "karuṇāvatī": ['mw'],
    "karuṇāveditā": ['mw'],
    "karuṇāvicintin": ['bhs'],
    "karuṇāvipralambha": ['mw'],
    "karuṇāvṛkṣa": ['bhs'],
    "karuṇāvṛtti": ['mw'],
    "karuṇāya": ['mw'],
    "karuṇāyamāna": ['cped'],
    "karuṇī": ['mw'],
    "karv": ['ap90', 'mw'],
    "karva": ['mw'],
    "karvara": ['ap90', 'cae', 'gra', 'mw'],
    "karvarī": ['mw'],
    "karvaḥ": ['ap90'],
    "karvaṭa": ['cae', 'ddsa', 'mw'],
    "karvaṭaka": ['bhs', 'mw'],
    "karvaṭapradeśa": ['bhs'],
    "karvaṭaḥ": ['ap90'],
    "karvaṭī": ['mw'],
    "karviṇī": ['mw'],
    "karvura": ['ap90'],
    "karvurita": ['ap90'],
    "karvūra": ['ap90'],
    "karāghāta": ['mw'],
    "karāgra": ['ddsa', 'mw'],
    "karāgraja": ['mw'],
    "karāgrapallava": ['mw'],
    "karāhati": ['ddsa'],
    "karāla": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "karālabhairava": ['mw'],
    "karāladantī": ['bhs'],
    "karāladaṃṣṭra": ['mw'],
    "karālajanaka": ['mw'],
    "karālaka": ['mw'],
    "karālakara": ['mw'],
    "karālakesara": ['mw'],
    "karālalocana": ['mw'],
    "karālamba": ['ddsa', 'mw'],
    "karālambana": ['mw'],
    "karālamukha": ['mw'],
    "karālatripuṭā": ['mw'],
    "karālavadana": ['cae', 'ddsa', 'mw'],
    "karālavadanā": ['mw'],
    "karālavaktra": ['mw'],
    "karālika": ['mw'],
    "karālikaḥ": ['ap90'],
    "karālikā": ['bhs', 'mw'],
    "karālin": ['mw'],
    "karālita": ['ddsa', 'mw'],
    "karālā": ['mw'],
    "karālākṣa": ['mw'],
    "karālānana": ['mw'],
    "karālāya": ['ddsa'],
    "karālī": ['bhs', 'mw'],
    "karāmalaka": ['mw'],
    "karāmarda": ['mw'],
    "karāmbuka": ['mw'],
    "karāmla": ['mw'],
    "karāmlaka": ['mw'],
    "karānta": ['mw'],
    "karāpayati": ['bhs'],
    "karārgala": ['mw'],
    "karārin": ['mw'],
    "karāroha": ['mw'],
    "karāroṭa": ['mw'],
    "karārpaṇa": ['cae', 'mw'],
    "karārpita": ['mw'],
    "karāyikā": ['ap90', 'ddsa', 'mw'],
    "karāḍa": ['bhs'],
    "karāṃgaṇaḥ": ['ap90'],
    "karāṅgaṇa": ['mw'],
    "karāṅguli": ['cae', 'mw'],
    "karāṭa": ['mw'],
    "karī": ['cped'],
    "karīkṛ": ['ddsa', 'mw'],
    "karīladeśa": ['mw'],
    "karīndra": ['mw'],
    "karīra": ['cae', 'ddsa', 'mw'],
    "karīraka": ['mw'],
    "karīrakaṃ": ['ap90'],
    "karīrakuṇa": ['mw'],
    "karīraprastha": ['mw'],
    "karīravatī": ['mw'],
    "karīraḥ": ['ap90'],
    "karīrikā": ['ap90', 'mw'],
    "karīsa": ['cped'],
    "karīsaparibandha": ['cped'],
    "karīti": ['mw'],
    "karīyamāna": ['cped'],
    "karīyas": ['mw'],
    "karīyate": ['cped'],
    "karīyati": ['cped'],
    "karīṣa": ['cae', 'ddsa', 'mw'],
    "karīṣagandhi": ['mw'],
    "karīṣaka": ['mw'],
    "karīṣaḥ": ['ap90'],
    "karīṣaṃkaṣa": ['mw'],
    "karīṣaṃkaṣā": ['ap90'],
    "karīṣaṇī": ['mw'],
    "karīṣin": ['mw'],
    "karīṣiṇī": ['ap90', 'mw'],
    "karīṣottha": ['mw'],
    "karīṣāgni": ['mw'],
    "karś": ['gra'],
    "karśana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "karśanīya": ['mw'],
    "karśapha": ['mw'],
    "karśita": ['mw'],
    "karśya": ['mw'],
    "karūkara": ['mw'],
    "karūl̤atin": ['mw'],
    "karūḍatin": ['gra'],
    "karūṣa": ['mw'],
    "karūṣaja": ['mw'],
    "karūṣaka": ['mw'],
    "karṇ": ['ap90', 'mw'],
    "karṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "karṇabhaṅga": ['cae', 'mw'],
    "karṇabhūṣaṇa": ['cae', 'mw'],
    "karṇabhūṣā": ['mw'],
    "karṇacchidra": ['mw'],
    "karṇacāmara": ['mw'],
    "karṇadarpaṇa": ['mw'],
    "karṇadeva": ['mw'],
    "karṇadhvanana": ['mw'],
    "karṇadhāra": ['cae', 'mw'],
    "karṇadhāraka": ['bhs', 'mw'],
    "karṇadhāratā": ['mw'],
    "karṇadhāriṇī": ['mw'],
    "karṇadhārā": ['bhs', 'mw'],
    "karṇadundubhi": ['mw'],
    "karṇadārin": ['mw'],
    "karṇaga": ['mw'],
    "karṇagiri": ['mw'],
    "karṇagocara": ['mw'],
    "karṇagrāha": ['mw'],
    "karṇagrāhavat": ['mw'],
    "karṇagūtha": ['mw'],
    "karṇagūthaka": ['mw'],
    "karṇagṛhya": ['gra'],
    "karṇagṛhyā": ['mw'],
    "karṇagṛhīta": ['mw'],
    "karṇahallikā": ['mw'],
    "karṇahīna": ['mw'],
    "karṇaja": ['mw'],
    "karṇajalaukas": ['mw'],
    "karṇajalaukā": ['mw'],
    "karṇajalūkā": ['mw'],
    "karṇajapa": ['mw'],
    "karṇajit": ['mw'],
    "karṇajvara": ['mw'],
    "karṇajyoti": ['mw'],
    "karṇajāha": ['mw'],
    "karṇajāpa": ['mw'],
    "karṇaka": ['bhs', 'cae', 'mw'],
    "karṇakarṇikā": ['mw'],
    "karṇakavat": ['mw'],
    "karṇakaḥ": ['ap90'],
    "karṇakaṇḍū": ['mw'],
    "karṇakaṣāya": ['mw'],
    "karṇakharaka": ['mw'],
    "karṇakharika": ['mw'],
    "karṇakisalaya": ['cae'],
    "karṇakita": ['mw'],
    "karṇakiṭṭa": ['mw'],
    "karṇakrośa": ['mw'],
    "karṇakubja": ['mw'],
    "karṇakumārī": ['mw'],
    "karṇakutūhala": ['mw'],
    "karṇakuvalaya": ['mw'],
    "karṇakāvat": ['mw'],
    "karṇakīṭā": ['mw'],
    "karṇakīṭī": ['mw'],
    "karṇakṣveḍa": ['mw'],
    "karṇala": ['mw'],
    "karṇalatikā": ['mw'],
    "karṇalatā": ['mw'],
    "karṇalatāmaya": ['mw'],
    "karṇalaḥ": ['ap90'],
    "karṇamadgura": ['mw'],
    "karṇamala": ['mw'],
    "karṇamoṭi": ['mw'],
    "karṇamoṭā": ['mw'],
    "karṇamoṭī": ['mw'],
    "karṇamukha": ['mw'],
    "karṇamukura": ['mw'],
    "karṇamuni": ['mw'],
    "karṇamūla": ['cae', 'mw'],
    "karṇamūlīya": ['mw'],
    "karṇandu": ['mw'],
    "karṇanirvāka": ['mw'],
    "karṇanāda": ['mw'],
    "karṇanāsā": ['mw'],
    "karṇanīlotpala": ['mw'],
    "karṇapa": ['mw'],
    "karṇaparaṃparā": ['mw'],
    "karṇaparvan": ['mw'],
    "karṇaparākrama": ['mw'],
    "karṇapatha": ['cae', 'mw'],
    "karṇapathātithi": ['mw'],
    "karṇapattrabhaṅga": ['mw'],
    "karṇapattraka": ['mw'],
    "karṇaphala": ['mw'],
    "karṇapitṛ": ['mw'],
    "karṇapiśācī": ['mw'],
    "karṇaprakāśa": ['mw'],
    "karṇapratināha": ['mw'],
    "karṇapratīnāha": ['mw'],
    "karṇaprayāga": ['mw'],
    "karṇaprādheya": ['mw'],
    "karṇaprānta": ['mw'],
    "karṇaprāvaraṇa": ['mw'],
    "karṇaprāvaraṇā": ['mw'],
    "karṇaprāveya": ['mw'],
    "karṇapur": ['mw'],
    "karṇapurī": ['mw'],
    "karṇaputraka": ['mw'],
    "karṇaputrikā": ['mw'],
    "karṇapuṣpa": ['mw'],
    "karṇapuṭa": ['mw'],
    "karṇapāka": ['mw'],
    "karṇapāli": ['mw'],
    "karṇapālyāmaya": ['mw'],
    "karṇapālī": ['mw'],
    "karṇapāśa": ['mw'],
    "karṇapīṭha": ['mw'],
    "karṇapūra": ['cae', 'mw'],
    "karṇapūraka": ['mw'],
    "karṇapūraṇa": ['mw'],
    "karṇapūrīkṛ": ['mw'],
    "karṇarandhra": ['mw'],
    "karṇarasāyana": ['mw'],
    "karṇaroga": ['mw'],
    "karṇarogapratiṣedha": ['mw'],
    "karṇarogavijñāna": ['mw'],
    "karṇasakha": ['mw'],
    "karṇasaṃsrāva": ['mw'],
    "karṇasphoṭā": ['mw'],
    "karṇasrotas": ['mw'],
    "karṇasrāva": ['mw'],
    "karṇasubhaga": ['mw'],
    "karṇasundarī": ['mw'],
    "karṇasū": ['mw'],
    "karṇasūci": ['mw'],
    "karṇatas": ['mw'],
    "karṇatā": ['mw'],
    "karṇatāla": ['cae', 'mw'],
    "karṇatālalatā": ['mw'],
    "karṇavallī": ['mw'],
    "karṇavant": ['cae'],
    "karṇavarjita": ['mw'],
    "karṇavat": ['ap90', 'gra', 'mw'],
    "karṇavaṃśa": ['mw'],
    "karṇavedha": ['mw'],
    "karṇavedhanikā": ['mw'],
    "karṇavedhanī": ['mw'],
    "karṇaveṣṭa": ['cae', 'mw'],
    "karṇaveṣṭaka": ['cae', 'mw'],
    "karṇaveṣṭakya": ['mw'],
    "karṇaveṣṭakīya": ['mw'],
    "karṇaveṣṭana": ['cae', 'mw'],
    "karṇavivara": ['mw'],
    "karṇaviṣ": ['cae', 'mw'],
    "karṇaviṣa": ['mw'],
    "karṇaviṣayīkṛta": ['mw'],
    "karṇaviṭka": ['mw'],
    "karṇavyadha": ['mw'],
    "karṇayoni": ['gra', 'mw'],
    "karṇaśaṣkulikā": ['mw'],
    "karṇaśaṣkulī": ['mw'],
    "karṇaśirīṣa": ['cae', 'mw'],
    "karṇaśobhana": ['gra', 'mw'],
    "karṇaśrava": ['cae', 'mw'],
    "karṇaśravas": ['mw'],
    "karṇaśrut": ['mw'],
    "karṇaśrāvin": ['mw'],
    "karṇaśūla": ['mw'],
    "karṇaśūlin": ['mw'],
    "karṇaśūnya": ['mw'],
    "karṇecuracurā": ['mw'],
    "karṇecurucurā": ['mw'],
    "karṇejapa": ['mw'],
    "karṇendu": ['mw'],
    "karṇesumana": ['bhs'],
    "karṇeṭiriṭirā": ['mw'],
    "karṇeṭiṭṭibha": ['mw'],
    "karṇi": ['mw'],
    "karṇika": ['ap90', 'bhs', 'mw'],
    "karṇikikā": ['mw'],
    "karṇikin": ['ap90', 'mw'],
    "karṇikā": ['ddsa', 'mw'],
    "karṇikācala": ['mw'],
    "karṇikādri": ['mw'],
    "karṇikāra": ['cae', 'ddsa', 'mw'],
    "karṇikāraka": ['mw'],
    "karṇikārapriya": ['mw'],
    "karṇikāraḥ": ['ap90'],
    "karṇikāyā": ['bhs'],
    "karṇila": ['ap90'],
    "karṇin": ['ap90', 'cae', 'ddsa', 'mw'],
    "karṇinī": ['mw'],
    "karṇodaya": ['mw'],
    "karṇopaghātin": ['cae'],
    "karṇopakarṇikā": ['mw'],
    "karṇorṇa": ['mw'],
    "karṇotpala": ['cae', 'ddsa', 'mw'],
    "karṇya": ['cae', 'mw'],
    "karṇābharaṇa": ['cae', 'mw'],
    "karṇābharaṇaka": ['mw'],
    "karṇādarśa": ['mw'],
    "karṇādi": ['mw'],
    "karṇākarṇi": ['ap90', 'mw'],
    "karṇākhya": ['mw'],
    "karṇālaṃkaraṇa": ['cae', 'mw'],
    "karṇālaṃkāra": ['mw'],
    "karṇālaṃkṛti": ['mw'],
    "karṇāmṛta": ['mw'],
    "karṇāndu": ['mw'],
    "karṇāndū": ['mw'],
    "karṇāntikacara": ['ddsa', 'mw'],
    "karṇānuja": ['mw'],
    "karṇārdha": ['mw'],
    "karṇāri": ['mw'],
    "karṇārpaṇa": ['mw'],
    "karṇārā": ['mw'],
    "karṇārśas": ['mw'],
    "karṇāsphāla": ['mw'],
    "karṇātarda": ['mw'],
    "karṇāvadhāna": ['mw'],
    "karṇāvataṃsa": ['mw'],
    "karṇāvataṃsīkṛ": ['mw'],
    "karṇāñjali": ['ddsa', 'mw'],
    "karṇāśva": ['mw'],
    "karṇāṭa": ['cae', 'ddsa', 'mw'],
    "karṇāṭabhāṣā": ['mw'],
    "karṇāṭadeśa": ['mw'],
    "karṇāṭagauḍa": ['mw'],
    "karṇāṭaka": ['mw'],
    "karṇāṭakabhāṣā": ['mw'],
    "karṇāṭakadeśa": ['mw'],
    "karṇāṭakalaha": ['cae', 'mw'],
    "karṇāṭaḥ": ['ap90'],
    "karṇāṭikā": ['mw'],
    "karṇāṭī": ['mw'],
    "karṇī": ['ap90', 'mw'],
    "karṇīratha": ['ddsa', 'mw'],
    "karṇīsuta": ['mw'],
    "karṣ": ['gra'],
    "karṣa": ['cae', 'ddsa', 'mw'],
    "karṣaka": ['ap90', 'cae', 'mw'],
    "karṣaphala": ['mw'],
    "karṣaphalā": ['mw'],
    "karṣaḥ": ['ap90'],
    "karṣaṇa": ['ap90', 'cae', 'mw'],
    "karṣaṇi": ['mw'],
    "karṣaṇiḥ": ['ap90'],
    "karṣaṇī": ['mw'],
    "karṣaṇīya": ['mw'],
    "karṣi": ['mw'],
    "karṣika": ['bhs'],
    "karṣin": ['ap90', 'cae', 'mw'],
    "karṣita": ['ap90', 'mw'],
    "karṣiṇī": ['mw'],
    "karṣāpaṇa": ['mw'],
    "karṣārdha": ['mw'],
    "karṣū": ['cae', 'mw'],
    "karṣūsveda": ['mw'],
    "karṣūvīriṇavat": ['mw'],
    "karṣūśaya": ['mw'],
    "karṣūḥ": ['ap90'],
    "kas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kasa": ['cped', 'mw'],
    "kasaka": ['cped'],
    "kasambakajāta": ['bhs'],
    "kasambu": ['cped'],
    "kasambujāta": ['cped'],
    "kasambuka": ['cped'],
    "kasambukajāta": ['cped'],
    "kasana": ['mw'],
    "kasanotpāṭana": ['mw'],
    "kasanta": ['cped'],
    "kasanā": ['ap90', 'mw'],
    "kasarṇīla": ['mw'],
    "kasarṇīra": ['mw'],
    "kasat": ['cped'],
    "kasati": ['cped'],
    "kasaḥ": ['ap90'],
    "kaseru": ['ap90', 'mw'],
    "kaserukā": ['ap90'],
    "kaseruḥ": ['ap90'],
    "kasetu": ['mw'],
    "kasi": ['cped'],
    "kasina": ['bhs'],
    "kasipu": ['mw'],
    "kasipuḥ": ['ap90'],
    "kasira": ['cped'],
    "kasiralābhi": ['cped'],
    "kasiralābhin": ['cped'],
    "kasiravuttika": ['cped'],
    "kasirena": ['cped'],
    "kasitvā": ['cped'],
    "kasitvāna": ['cped'],
    "kasiṇa": ['cped'],
    "kasiṇāyatana": ['cped'],
    "kaskādi": ['mw'],
    "kasmala": ['ap90', 'mw'],
    "kasmā": ['cped'],
    "kasmāt": ['cae', 'ddsa', 'mw'],
    "kasphila": ['bhs', 'mw'],
    "kassaka": ['cped'],
    "kassate": ['cped'],
    "kassati": ['cped'],
    "kassaṁ": ['cped'],
    "kassāmi": ['cped'],
    "kastambhī": ['cae', 'ddsa', 'mw'],
    "kastaṃbhī": ['ap90'],
    "kasturikā": ['ap90', 'cae'],
    "kastīra": ['mw'],
    "kastīraṃ": ['ap90'],
    "kastūri": ['mw'],
    "kastūrikaiṇī": ['mw'],
    "kastūrikā": ['cae', 'ddsa', 'mw'],
    "kastūrikākuraṅga": ['mw'],
    "kastūrikāmada": ['mw'],
    "kastūrikāmṛga": ['mw'],
    "kastūrikāmṛgī": ['mw'],
    "kastūrikāṇḍa": ['bhs'],
    "kastūrismṛti": ['mw'],
    "kastūrī": ['cae', 'ddsa', 'mw'],
    "kastūrīmallikā": ['mw'],
    "kastūrīmṛga": ['mw'],
    "kasulā": ['bhs'],
    "kasun": ['ddsa', 'mw'],
    "kasvara": ['ap90', 'mw'],
    "kasā": ['cped', 'mw'],
    "kasāmbu": ['mw'],
    "kasāniviṭṭha": ['cped'],
    "kasāpetabba": ['cped'],
    "kasāra": ['mw'],
    "kasāras": ['mw'],
    "kasāva": ['cped'],
    "kasāya": ['cped'],
    "kasī": ['cped'],
    "kasīya": ['mw'],
    "kat": ['mw'],
    "kata": ['bhs', 'cped', 'mw'],
    "katabba": ['cped'],
    "katabhaṇḍa": ['cped'],
    "katabhīruttāṇa": ['cped'],
    "katahattha": ['cped'],
    "kataka": ['cae', 'cped', 'ddsa', 'mw'],
    "kataludda": ['cped'],
    "katama": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "katamadvidha": ['bhs'],
    "katamatra": ['bhs'],
    "katamena": ['cped'],
    "katamoraga": ['mw'],
    "katamāla": ['mw'],
    "katamālaḥ": ['ap90'],
    "katana": ['cped'],
    "kataphala": ['mw'],
    "kataphalaḥ": ['ap90'],
    "katara": ['ap90', 'bhs', 'cae', 'cped', 'gra', 'mw'],
    "kataratas": ['cae', 'mw'],
    "katarataḥ": ['ap90'],
    "katarathā": ['mw'],
    "katasāmaṇa": ['cped'],
    "katavedi": ['cped'],
    "katavedin": ['cped'],
    "katayogga": ['cped'],
    "katañjalī": ['cped'],
    "kataññū": ['cped'],
    "kataḥ": ['ap90'],
    "kataṁ": ['cped'],
    "kath": ['ap90', 'mw'],
    "katha": ['bhs'],
    "kathaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "kathala": ['cped'],
    "kathali": ['cped'],
    "katham": ['cae', 'ddsa', 'gra', 'mw'],
    "kathambhūta": ['ddsa'],
    "kathan nu": ['cped'],
    "kathan nu kho": ['cped'],
    "kathana": ['ap90', 'cae', 'ddsa', 'mw'],
    "kathanika": ['mw'],
    "kathanīya": ['ap90', 'cae', 'mw'],
    "kathatva": ['bhs'],
    "kathay": ['cae'],
    "kathaya": ['ddsa'],
    "kathayati": ['cped'],
    "kathayitavya": ['cae', 'ddsa', 'mw'],
    "kathayāna": ['ap90', 'mw'],
    "kathañ ci": ['cped'],
    "kathañjātīyaka": ['ddsa'],
    "kathaṁ": ['cped'],
    "kathaṁ carahi": ['cped'],
    "kathaṁ hi": ['cped'],
    "kathaṁ hi nāma": ['cped'],
    "kathaṁ kathaṁ": ['cped'],
    "kathaṁgotta": ['cped'],
    "kathaṁjīvi": ['cped'],
    "kathaṁjīvin": ['cped'],
    "kathaṁkathi": ['cped'],
    "kathaṁkathin": ['cped'],
    "kathaṁkathā": ['cped'],
    "kathaṁkāri": ['cped'],
    "kathaṁkārin": ['cped'],
    "kathaṁvidha": ['cped'],
    "kathaṁvihitaka": ['cped'],
    "kathaṃ": ['ap90', 'mw'],
    "kathaṃbhāva": ['mw'],
    "kathaṃbhūta": ['cae', 'mw'],
    "kathaṃjātīyaka": ['cae', 'mw'],
    "kathaṃkara": ['bhs'],
    "kathaṃkarman": ['mw'],
    "kathaṃkathika": ['mw'],
    "kathaṃkathikatā": ['mw'],
    "kathaṃkathin": ['bhs'],
    "kathaṃkathā": ['bhs', 'mw'],
    "kathaṃkāram": ['mw'],
    "kathaṃpramāṇa": ['mw'],
    "kathaṃruru": ['mw'],
    "kathaṃrūpa": ['cae', 'ddsa', 'mw'],
    "kathaṃtarām": ['mw'],
    "kathaṃtā": ['ap90', 'mw'],
    "kathaṃvīrya": ['cae', 'mw'],
    "kathenta": ['cped'],
    "kathesi": ['cped'],
    "kathetave": ['cped'],
    "katheti": ['cped'],
    "kathetuṁ": ['cped'],
    "kathika": ['bhs', 'cped', 'mw'],
    "kathikaḥ": ['ap90'],
    "kathikā": ['cped'],
    "kathin": ['bhs'],
    "kathina": ['bhs'],
    "kathita": ['ap90', 'cae', 'ddsa', 'mw'],
    "kathitapada": ['mw'],
    "kathodaya": ['cae', 'ddsa', 'mw'],
    "kathodghāta": ['mw'],
    "kathojja": ['cped'],
    "kathopakathana": ['mw'],
    "kathopākhyāna": ['mw'],
    "kathya": ['ddsa', 'mw'],
    "kathyāyitta": ['bhs'],
    "kathā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kathācaṇa": ['mw'],
    "kathācchala": ['mw'],
    "kathāchala": ['mw'],
    "kathādi": ['mw'],
    "kathājava": ['mw'],
    "kathākautuka": ['mw'],
    "kathākośa": ['mw'],
    "kathākrama": ['ddsa', 'mw'],
    "kathālakṣaṇa": ['mw'],
    "kathālāpa": ['ddsa', 'mw'],
    "kathāmukha": ['mw'],
    "kathāmātra": ['mw'],
    "kathāmātrāvaśeṣita": ['mw'],
    "kathāmātrāvaśiṣṭa": ['mw'],
    "kathāmṛtanidhi": ['mw'],
    "kathānaka": ['cae', 'ddsa', 'mw'],
    "kathānakaṃ": ['ap90'],
    "kathānta": ['mw'],
    "kathāntara": ['cae', 'ddsa', 'mw'],
    "kathānurāga": ['mw'],
    "kathāpaya": ['mw'],
    "kathāpayati": ['ap90'],
    "kathāprabandha": ['mw'],
    "kathāprasaṅga": ['mw'],
    "kathāprasaṅgena": ['mw'],
    "kathāprasaṅgāt": ['mw'],
    "kathāprastāvatas": ['mw'],
    "kathāprāṇa": ['mw'],
    "kathāpuruṣa": ['bhs'],
    "kathāpābhata": ['cped'],
    "kathāpīṭha": ['ddsa', 'mw'],
    "kathārambha": ['mw'],
    "kathārambhakāla": ['mw'],
    "kathārāma": ['mw'],
    "kathārṇava": ['mw'],
    "kathāsallāpa": ['cped'],
    "kathāsaritsāgara": ['cae', 'mw'],
    "kathāsaṃdhi": ['mw'],
    "kathāsaṃgraha": ['mw'],
    "kathātrayī": ['mw'],
    "kathāvalī": ['cae', 'mw'],
    "kathāvastu": ['bhs'],
    "kathāvatthu": ['cped'],
    "kathāvatāra": ['mw'],
    "kathāvaśeṣa": ['mw'],
    "kathāvaśeṣatā": ['mw'],
    "kathāvaśeṣībhū": ['mw'],
    "kathāvirakta": ['mw'],
    "kathāyoga": ['mw'],
    "kathāśeṣa": ['ddsa', 'mw'],
    "kathīkṛ": ['ap90', 'ddsa', 'mw'],
    "kathīkṛta": ['ap90', 'mw'],
    "kati": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "katibheda": ['mw'],
    "katidha": ['cae'],
    "katidhā": ['ap90', 'cae', 'gra', 'mw'],
    "katihaṁ": ['cped'],
    "katihāyana": ['mw'],
    "katika": ['mw'],
    "katikkhattuṁ": ['cped'],
    "katikā": ['cped'],
    "katikṛtvas": ['ap90', 'mw'],
    "katima": ['bhs', 'cped'],
    "katindriya": ['cped'],
    "katipaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "katipayakusuma": ['cae'],
    "katipayarātram": ['cae'],
    "katipayatha": ['ap90', 'mw'],
    "katipayena": ['mw'],
    "katipayāhasya": ['cae'],
    "katipayāt": ['mw'],
    "katipāhakaṁ": ['cped'],
    "katipāhaṁ": ['cped'],
    "katira": ['bhs'],
    "katisaṃkhya": ['mw'],
    "katitha": ['gra', 'mw'],
    "katititha": ['mw'],
    "kativassa": ['cped'],
    "katividha": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "katiśas": ['ap90', 'mw'],
    "katokāsa": ['cped'],
    "katpaya": ['ap90', 'gra', 'mw'],
    "katpayam": ['ddsa'],
    "katr": ['ap90', 'mw'],
    "katsavara": ['mw'],
    "katsavaraṃ": ['ap90'],
    "kattabbaka": ['cped'],
    "kattar)": ['cped'],
    "kattara": ['cped'],
    "kattaradaṇḍa": ['cped'],
    "kattarasuppa": ['cped'],
    "kattari": ['cped'],
    "kattarikā": ['cped'],
    "kattariyā": ['cped'],
    "katth": ['ap90', 'cae', 'ddsa', 'mw'],
    "kattha": ['cped'],
    "katthaci": ['cped'],
    "katthacina": ['cped'],
    "katthaka": ['mw'],
    "katthana": ['ap90', 'cae', 'ddsa', 'mw'],
    "katthanā": ['mw'],
    "katthapariyāpann": ['cped'],
    "katthi": ['cped'],
    "katthin": ['cped'],
    "katthita": ['cped', 'mw'],
    "katthitar": ['cped'],
    "katthitavya": ['mw'],
    "katthogadha": ['cped'],
    "kattikacoraka": ['cped'],
    "kattikacātumāsinī": ['cped'],
    "kattikanakkhatta": ['cped'],
    "kattikapuṇṇamā": ['cped'],
    "kattikatemāsikapuṇṇamā": ['cped'],
    "kattikatemāsipuṇṇamā": ['cped'],
    "kattikā": ['cped'],
    "kattoya": ['mw'],
    "kattri": ['mw'],
    "kattryādi": ['mw'],
    "kattukāma": ['cped'],
    "kattuṁ": ['cped'],
    "kattā": ['cae', 'cped'],
    "kattāśabda": ['mw'],
    "kattṛna": ['mw'],
    "kattṛṇa": ['mw'],
    "katupāsana": ['cped'],
    "katuṁ": ['cped'],
    "katuṅka": ['bhs'],
    "katvā": ['cped'],
    "katvāna": ['cped'],
    "katākata": ['cped'],
    "katāvakāsa": ['cped'],
    "katāvi": ['cped'],
    "katāvin": ['cped'],
    "katīmuṣa": ['ddsa', 'mw'],
    "katīya": ['bhs'],
    "kaubera": ['ap90', 'cae', 'ddsa', 'mw'],
    "kauberaka": ['mw'],
    "kauberatīrtha": ['mw'],
    "kauberikeya": ['mw'],
    "kauberiṇī": ['mw'],
    "kauberī": ['bhs', 'mw'],
    "kaubjya": ['mw'],
    "kaubjyaṃ": ['ap90'],
    "kaucahasti": ['mw'],
    "kaucavāra": ['mw'],
    "kaucavārya": ['mw'],
    "kaucumārayoga": ['mw'],
    "kaucāpāka": ['mw'],
    "kauddāla": ['mw'],
    "kaudhuma": ['bhs'],
    "kaudravika": ['mw'],
    "kaudravikaṃ": ['ap90'],
    "kaudravīṇa": ['mw'],
    "kaudravīṇaka": ['mw'],
    "kaudreya": ['mw'],
    "kaudrāyaṇa": ['mw'],
    "kaudrāyaṇaka": ['mw'],
    "kaudālika": ['mw'],
    "kaudālikaḥ": ['ap90'],
    "kaudālīka": ['mw'],
    "kauhala": ['mw'],
    "kauhalīputra": ['mw'],
    "kauhalīya": ['mw'],
    "kauhaḍa": ['mw'],
    "kauhaḍi": ['mw'],
    "kauhita": ['mw'],
    "kauja": ['mw'],
    "kaujapa": ['mw'],
    "kaukila": ['mw'],
    "kaukkuḍīvaha": ['mw'],
    "kaukkuḍīvahaka": ['mw'],
    "kaukkuṭa": ['ap90', 'mw'],
    "kaukkuṭika": ['bhs', 'mw'],
    "kaukkuṭikandala": ['mw'],
    "kaukkuṭikaḥ": ['ap90'],
    "kaukulikā": ['mw'],
    "kaukuntaka": ['mw'],
    "kaukura": ['mw'],
    "kaukuruṇḍi": ['mw'],
    "kaukuvādi": ['mw'],
    "kaukuṇḍihi": ['mw'],
    "kaukuṭṭaka": ['mw'],
    "kaukākṣa": ['mw'],
    "kaukūsta": ['mw'],
    "kaukṛtika": ['bhs'],
    "kaukṛtya": ['bhs', 'mw'],
    "kaukṛtyaṃ": ['ap90'],
    "kaukṣa": ['ap90', 'mw'],
    "kaukṣaka": ['mw'],
    "kaukṣeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaukṣeyaka": ['cae', 'mw'],
    "kaukṣeyakaḥ": ['ap90'],
    "kaula": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kaulaba": ['mw'],
    "kaulaka": ['mw'],
    "kaulakeya": ['ap90', 'mw'],
    "kaulaki": ['mw'],
    "kaulakāvatī": ['mw'],
    "kaulamārga": ['mw'],
    "kaulapata": ['mw'],
    "kaulapatya": ['mw'],
    "kaulaputra": ['mw'],
    "kaulaputraka": ['mw'],
    "kaularahasya": ['mw'],
    "kaulattha": ['mw'],
    "kaulatthīna": ['mw'],
    "kaulava": ['mw'],
    "kaulavrata": ['mw'],
    "kaulavārṇava": ['mw'],
    "kaulaṭera": ['mw'],
    "kaulaṭeraḥ": ['ap90'],
    "kaulaṭeya": ['mw'],
    "kaulaṭeyaḥ": ['ap90'],
    "kaulaṭineya": ['mw'],
    "kaulaṭineyaḥ": ['ap90'],
    "kauleya": ['cae', 'ddsa', 'mw'],
    "kauleyaka": ['ap90', 'cae', 'mw'],
    "kauleyakuṭumbinī": ['mw'],
    "kauleśabhairavī": ['mw'],
    "kauleśvara": ['mw'],
    "kauleśī": ['mw'],
    "kauli": ['mw'],
    "kaulika": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaulikatantra": ['mw'],
    "kaulinda": ['mw'],
    "kaulitara": ['cae', 'ddsa', 'gra', 'mw'],
    "kauliśika": ['mw'],
    "kauliśāyani": ['mw'],
    "kaulmalabarhiṣa": ['mw'],
    "kaulmāṣika": ['mw'],
    "kaulmāṣī": ['mw'],
    "kaulmāṣīṇa": ['mw'],
    "kaulopaniṣad": ['mw'],
    "kaulya": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaulāla": ['mw'],
    "kaulālacakra": ['mw'],
    "kaulālaka": ['ap90', 'mw'],
    "kaulārcanadīpikā": ['mw'],
    "kaulāsa": ['mw'],
    "kaulāvalīya": ['mw'],
    "kaulī": ['mw'],
    "kaulīka": ['mw'],
    "kaulīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaulīni": ['mw'],
    "kaulīnya": ['mw'],
    "kaulīnyaṃ": ['ap90'],
    "kaulīrā": ['mw'],
    "kaulūna": ['mw'],
    "kaulūta": ['cae', 'ddsa', 'mw'],
    "kaulūtara": ['mw'],
    "kaulūtaḥ": ['ap90'],
    "kaumbha": ['mw'],
    "kaumbhakarṇa": ['mw'],
    "kaumbhakarṇi": ['mw'],
    "kaumbhakāraka": ['mw'],
    "kaumbhakāreya": ['mw'],
    "kaumbhakāri": ['mw'],
    "kaumbhakārya": ['mw'],
    "kaumbheyaka": ['mw'],
    "kaumbhya": ['mw'],
    "kaumbhāyana": ['mw'],
    "kaumbhāyani": ['mw'],
    "kaumedura": ['mw'],
    "kaumodakī": ['ap90', 'ddsa', 'mw'],
    "kaumodī": ['bhs', 'mw'],
    "kaumuda": ['cae', 'ddsa', 'mw'],
    "kaumudagandhyā": ['mw'],
    "kaumudaḥ": ['ap90'],
    "kaumudika": ['bhs', 'mw'],
    "kaumudikā": ['cae', 'mw'],
    "kaumudvateya": ['mw'],
    "kaumudī": ['ap90', 'mw'],
    "kaumudīcāra": ['mw'],
    "kaumudījīvana": ['mw'],
    "kaumudīmaha": ['cae', 'mw'],
    "kaumudīmahotsava": ['mw'],
    "kaumudīnirṇaya": ['mw'],
    "kaumudīpati": ['mw'],
    "kaumudīprabhā": ['mw'],
    "kaumudīpracāra": ['mw'],
    "kaumudīrajanī": ['mw'],
    "kaumudītaru": ['mw'],
    "kaumudīvilāsa": ['mw'],
    "kaumudīvṛkṣa": ['mw'],
    "kaumāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaumārabandhakī": ['cae', 'mw'],
    "kaumārabhṛtya": ['mw'],
    "kaumārabrahmacārin": ['mw'],
    "kaumāracārin": ['mw'],
    "kaumārahara": ['mw'],
    "kaumārahārita": ['mw'],
    "kaumāraka": ['mw'],
    "kaumārakaṃ": ['ap90'],
    "kaumāraparvata": ['mw'],
    "kaumāraprabhṛtyaka": ['mw'],
    "kaumārarājya": ['mw'],
    "kaumāratantra": ['mw'],
    "kaumāravrata": ['cae'],
    "kaumāravratacārin": ['mw'],
    "kaumārika": ['mw'],
    "kaumārikatantra": ['mw'],
    "kaumārikaḥ": ['ap90'],
    "kaumārikeya": ['mw'],
    "kaumārikeyaḥ": ['ap90'],
    "kaumārikā": ['mw'],
    "kaumārila": ['mw'],
    "kaumārāyaṇa": ['mw'],
    "kaumārī": ['ddsa', 'mw'],
    "kaunakhya": ['cae', 'ddsa', 'mw'],
    "kaunakhyaṃ": ['ap90'],
    "kaunakīya": ['mw'],
    "kaunda": ['cae', 'ddsa', 'mw'],
    "kaundrāyaṇa": ['mw'],
    "kaunta": ['mw'],
    "kauntala": ['mw'],
    "kaunteya": ['cae', 'ddsa', 'mw'],
    "kaunteyavṛtta": ['mw'],
    "kauntika": ['mw'],
    "kauntya": ['mw'],
    "kauntālī": ['mw'],
    "kauntāyani": ['mw'],
    "kauntī": ['mw'],
    "kauntīnāgara": ['bhs'],
    "kaunāmi": ['mw'],
    "kaunāmika": ['mw'],
    "kaunṛtika": ['mw'],
    "kaupa": ['ap90', 'ddsa', 'mw'],
    "kaupiñjala": ['mw'],
    "kaupodakī": ['ap90', 'mw'],
    "kauputraka": ['mw'],
    "kaupya": ['mw'],
    "kaupādakī": ['mw'],
    "kaupīna": ['cae', 'ddsa', 'mw'],
    "kaupīnavat": ['mw'],
    "kaupīnaṃ": ['ap90'],
    "kaupīnācchādana": ['mw'],
    "kaurama": ['mw'],
    "kaurava": ['ap90', 'cae', 'ddsa', 'mw'],
    "kauravaka": ['mw'],
    "kauravapāṇḍavīya": ['mw'],
    "kauraveya": ['cae', 'mw'],
    "kauravya": ['bhs', 'cae', 'mw'],
    "kauravyaḥ": ['ap90'],
    "kauravyāyaṇa": ['mw'],
    "kauravyāyaṇi": ['mw'],
    "kauravyāyaṇī": ['mw'],
    "kauravyāyaṇīputra": ['mw'],
    "kauravāyaṇi": ['mw'],
    "kauravī": ['mw'],
    "kaurayāṇa": ['gra', 'mw'],
    "kaurma": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaurmopapurāṇa": ['mw'],
    "kaurpara": ['bhs', 'mw'],
    "kaurpi": ['mw'],
    "kaurpya": ['mw'],
    "kaurpyaḥ": ['ap90'],
    "kaurujaṅgala": ['mw'],
    "kaurujāṅgala": ['mw'],
    "kaurukullaka": ['bhs', 'mw'],
    "kaurukātya": ['mw'],
    "kaurukṣetra": ['mw'],
    "kauruma": ['mw'],
    "kaurupathi": ['mw'],
    "kaurupañcāla": ['mw'],
    "kaurupāñcāla": ['mw'],
    "kaurvata": ['mw'],
    "kausala": ['cae', 'mw'],
    "kausalaka": ['mw'],
    "kausaleya": ['mw'],
    "kausalya": ['ap90', 'ddsa', 'mw'],
    "kausalyaṃ": ['cae'],
    "kausalyeya": ['mw'],
    "kausalyā": ['mw'],
    "kausalyāmātṛ": ['mw'],
    "kausalyānandana": ['mw'],
    "kausalyāyani": ['mw'],
    "kausalā": ['mw'],
    "kausalī": ['mw'],
    "kausida": ['mw'],
    "kausita": ['mw'],
    "kaustra": ['mw'],
    "kaustubha": ['cae', 'ddsa', 'mw'],
    "kaustubhabhṛt": ['mw'],
    "kaustubhadhāman": ['mw'],
    "kaustubhadūṣaṇa": ['mw'],
    "kaustubhalakṣaṇa": ['mw'],
    "kaustubhavakṣas": ['mw'],
    "kaustubhaḥ": ['ap90'],
    "kaustubhoras": ['mw'],
    "kaustubhīya": ['mw'],
    "kausuma": ['ap90', 'cae', 'ddsa', 'mw'],
    "kausumbha": ['cae', 'ddsa', 'mw'],
    "kausumbhaka": ['mw'],
    "kausumāyudha": ['mw'],
    "kausurubinda": ['mw'],
    "kausurubindi": ['mw'],
    "kausuṃbha": ['ap90'],
    "kausīda": ['ap90', 'cae', 'ddsa', 'mw'],
    "kausīdya": ['bhs', 'mw'],
    "kausīdyaṃ": ['ap90'],
    "kausṛtika": ['mw'],
    "kausṛtikaḥ": ['ap90'],
    "kauta": ['mw'],
    "kautapa": ['mw'],
    "kautaskuta": ['mw'],
    "kautasta": ['mw'],
    "kauthuma": ['mw'],
    "kauthumaka": ['mw'],
    "kauthumī": ['mw'],
    "kautomata": ['mw'],
    "kautsa": ['cae', 'ddsa', 'mw'],
    "kautsaṃ": ['ap90'],
    "kautsya": ['bhs'],
    "kautsāyana": ['mw'],
    "kautsī": ['mw'],
    "kautsīputra": ['mw'],
    "kautuka": ['bhs', 'cae', 'ddsa', 'mw'],
    "kautukacintāmaṇi": ['mw'],
    "kautukagṛha": ['cae', 'mw'],
    "kautukakriyā": ['cae', 'mw'],
    "kautukalīlāvatī": ['mw'],
    "kautukamaya": ['mw'],
    "kautukamaṅgala": ['mw'],
    "kautukapura": ['mw'],
    "kautukarahasya": ['mw'],
    "kautukaratnākara": ['cae'],
    "kautukasarvasva": ['mw'],
    "kautukatoraṇa": ['mw'],
    "kautukavat": ['mw'],
    "kautukaṃ": ['ap90'],
    "kautuki": ['mw'],
    "kautukibhāva": ['mw'],
    "kautukin": ['ap90', 'mw'],
    "kautukita": ['ap90', 'ddsa', 'mw'],
    "kautukitā": ['mw'],
    "kautukāgāra": ['mw'],
    "kautukālaṃkāra": ['cae'],
    "kautukāt": ['mw'],
    "kautūhala": ['cae', 'ddsa', 'mw'],
    "kautūhalapara": ['mw'],
    "kautūhalatā": ['mw'],
    "kautūhalaṃ": ['ap90'],
    "kautūhalya": ['mw'],
    "kautūhalyaṃ": ['ap90'],
    "kautūhalānvita": ['mw'],
    "kautūla": ['mw'],
    "kauvala": ['mw'],
    "kauvera": ['ap90', 'cae', 'ddsa'],
    "kauvidārya": ['mw'],
    "kauvindī": ['mw'],
    "kauñca": ['mw'],
    "kauñcarā": ['bhs'],
    "kauñcikī": ['mw'],
    "kauñcādri": ['mw'],
    "kauñcī": ['bhs', 'mw'],
    "kauñjara": ['ddsa', 'mw'],
    "kauñji": ['mw'],
    "kauñjāyana": ['mw'],
    "kauñjāyanya": ['mw'],
    "kauñjāyanī": ['mw'],
    "kauśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kauśakī": ['mw'],
    "kauśala": ['cae', 'ddsa', 'mw'],
    "kauśalaṃ": ['ap90'],
    "kauśaleyaḥ": ['ap90'],
    "kauśali": ['mw'],
    "kauśalikaṃ": ['ap90'],
    "kauśalikā": ['ap90', 'mw'],
    "kauśalya": ['cae', 'mw'],
    "kauśalyaka": ['bhs'],
    "kauśalyaṃ": ['ap90'],
    "kauśalyā": ['ap90', 'mw'],
    "kauśalyāyaniḥ": ['ap90'],
    "kauśalī": ['mw'],
    "kauśeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "kauśeyaka": ['mw'],
    "kauśija": ['mw'],
    "kauśika": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kauśikagṛhyasūtra": ['mw'],
    "kauśikaphala": ['mw'],
    "kauśikapriya": ['mw'],
    "kauśikatva": ['mw'],
    "kauśikatā": ['mw'],
    "kauśikin": ['mw'],
    "kauśikyoja": ['mw'],
    "kauśikā": ['mw'],
    "kauśikāditya": ['mw'],
    "kauśikāra": ['mw'],
    "kauśikāraṇya": ['mw'],
    "kauśikāri": ['mw'],
    "kauśikārāti": ['mw'],
    "kauśikātmaja": ['mw'],
    "kauśikāyani": ['mw'],
    "kauśikāyudha": ['mw'],
    "kauśikāṅguli": ['mw'],
    "kauśikī": ['ap90', 'mw'],
    "kauśikīputra": ['mw'],
    "kauśikīvaraprasāda": ['mw'],
    "kauśila": ['mw'],
    "kauśilya": ['mw'],
    "kauśreya": ['mw'],
    "kauśya": ['mw'],
    "kauśāmba": ['mw'],
    "kauśāmbaka": ['bhs'],
    "kauśāmbhas": ['mw'],
    "kauśāmbi": ['mw'],
    "kauśāmbikā": ['cae', 'ddsa', 'mw'],
    "kauśāmbya": ['mw'],
    "kauśāmbī": ['cae', 'ddsa', 'mw'],
    "kauśāmbīya": ['cae', 'mw'],
    "kauśāśvī": ['mw'],
    "kauśāṃbeya": ['mw'],
    "kauśāṃbī": ['ap90'],
    "kauśīdhānya": ['mw'],
    "kauśīdhānyaṃ": ['ap90'],
    "kauśīdya": ['bhs'],
    "kauśīlava": ['cae', 'ddsa', 'mw'],
    "kauśīlavaṃ": ['ap90'],
    "kauśīlavya": ['cae', 'mw'],
    "kauśīnāgara": ['bhs'],
    "kauśīrakeya": ['mw'],
    "kauḍavika": ['mw'],
    "kauḍeyaka": ['mw'],
    "kauḍodari": ['mw'],
    "kauḍya": ['mw'],
    "kauṃjara": ['ap90'],
    "kauṃkaḥ": ['ap90'],
    "kauṃteyaḥ": ['ap90'],
    "kauṃtikaḥ": ['ap90'],
    "kauṅka": ['mw'],
    "kauṅkaṇa": ['mw'],
    "kauṅkaṇodbhūta": ['mw'],
    "kauṅkiṇa": ['mw'],
    "kauṅkuma": ['cae', 'ddsa', 'mw'],
    "kauṇakutsya": ['cae', 'ddsa', 'mw'],
    "kauṇapa": ['cae', 'ddsa', 'mw'],
    "kauṇapadanta": ['mw'],
    "kauṇapaḥ": ['ap90'],
    "kauṇapāśana": ['mw'],
    "kauṇeya": ['mw'],
    "kauṇinda": ['mw'],
    "kauṇya": ['mw'],
    "kauṇyaṃ": ['ap90'],
    "kauṇḍala": ['mw'],
    "kauṇḍalika": ['mw'],
    "kauṇḍapāyina": ['mw'],
    "kauṇḍila": ['mw'],
    "kauṇḍilya": ['mw'],
    "kauṇḍilyaka": ['mw'],
    "kauṇḍina": ['mw'],
    "kauṇḍineyaka": ['mw'],
    "kauṇḍinya": ['bhs', 'ddsa', 'mw'],
    "kauṇḍinyaka": ['mw'],
    "kauṇḍinyāyana": ['mw'],
    "kauṇḍinī": ['mw'],
    "kauṇḍodari": ['mw'],
    "kauṇḍoparatha": ['mw'],
    "kauṇḍoparathīya": ['mw'],
    "kauṇḍāgnaka": ['mw'],
    "kauṇḍāyana": ['mw'],
    "kauṇḍīvṛsya": ['mw'],
    "kauṇḍīvṛsī": ['mw'],
    "kauṇḍīvṛṣa": ['mw'],
    "kauṇṭharavya": ['mw'],
    "kauṇṭhya": ['mw'],
    "kauṣeya": ['ap90', 'mw'],
    "kauṣmāṇḍa": ['mw'],
    "kauṣmāṇḍika": ['mw'],
    "kauṣya": ['mw'],
    "kauṣārava": ['cae', 'ddsa', 'mw'],
    "kauṣāravi": ['mw'],
    "kauṣīdya": ['mw'],
    "kauṣītaka": ['cae', 'ddsa', 'mw'],
    "kauṣītakeya": ['mw'],
    "kauṣītaki": ['cae', 'mw'],
    "kauṣītakibrāhmaṇa": ['cae', 'mw'],
    "kauṣītakibrāhmaṇopaniṣad": ['mw'],
    "kauṣītakin": ['cae', 'mw'],
    "kauṣītakirahasya": ['mw'],
    "kauṣītakirahasyabrāhmaṇa": ['mw'],
    "kauṣītakyupaniṣad": ['mw'],
    "kauṣītakī": ['mw'],
    "kauṣṭacitka": ['mw'],
    "kauṣṭha": ['cae', 'ddsa', 'mw'],
    "kauṣṭhavitka": ['mw'],
    "kauṣṭhika": ['mw'],
    "kauṣṭhila": ['bhs', 'mw'],
    "kauṣṭhya": ['mw'],
    "kauṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kauṭabhī": ['ap90', 'mw'],
    "kauṭaja": ['mw'],
    "kauṭajabhārika": ['mw'],
    "kauṭajika": ['mw'],
    "kauṭakika": ['mw'],
    "kauṭakikaḥ": ['ap90'],
    "kauṭali": ['mw'],
    "kauṭalya": ['ap90', 'mw'],
    "kauṭaphala": ['mw'],
    "kauṭasthya": ['ddsa', 'mw'],
    "kauṭasākṣin": ['mw'],
    "kauṭasākṣya": ['cae', 'mw'],
    "kauṭatakṣa": ['mw'],
    "kauṭavī": ['ap90', 'mw'],
    "kauṭhuma": ['mw'],
    "kauṭhāra": ['mw'],
    "kauṭhārikeya": ['mw'],
    "kauṭi": ['mw'],
    "kauṭika": ['ap90', 'mw'],
    "kauṭilika": ['mw'],
    "kauṭilikaḥ": ['ap90'],
    "kauṭilya": ['cae', 'ddsa', 'mw'],
    "kauṭilyaśāstra": ['mw'],
    "kauṭilyaṃ": ['ap90'],
    "kauṭiryā": ['mw'],
    "kauṭubha": ['bhs'],
    "kauṭumba": ['bhs', 'cae', 'ddsa', 'mw'],
    "kauṭumbika": ['cae', 'mw'],
    "kauṭuṃba": ['ap90'],
    "kauṭuṃbika": ['ap90'],
    "kauṭya": ['mw'],
    "kauṭyā": ['mw'],
    "kauṭāyana": ['mw'],
    "kauṭīgava": ['mw'],
    "kauṭīgavya": ['mw'],
    "kauṭīra": ['ap90', 'mw'],
    "kauṭīryā": ['ap90', 'mw'],
    "kauṭīya": ['mw'],
    "kauṭṭanya": ['ddsa', 'mw'],
    "kav": ['ap90', 'mw'],
    "kava": ['cae', 'ddsa', 'gra', 'mw'],
    "kavaca": ['cae', 'cped', 'ddsa', 'mw'],
    "kavacadhara": ['cae', 'mw'],
    "kavacahara": ['mw'],
    "kavacapattra": ['mw'],
    "kavacapāśa": ['mw'],
    "kavacaśiva": ['mw'],
    "kavacaḥ": ['ap90'],
    "kavacikā": ['bhs'],
    "kavacin": ['cae', 'ddsa', 'mw'],
    "kavacita": ['bhs', 'mw'],
    "kavaka": ['cae', 'ddsa', 'mw'],
    "kavakaḥ": ['ap90'],
    "kavala": ['cae', 'ddsa', 'mw'],
    "kavalagraha": ['mw'],
    "kavalagrāha": ['mw'],
    "kavalana": ['cae', 'mw'],
    "kavalaprastha": ['mw'],
    "kavalatā": ['mw'],
    "kavalaya": ['cae', 'mw'],
    "kavalayati": ['ap90'],
    "kavalaḥ": ['ap90'],
    "kavalikā": ['ap90', 'mw'],
    "kavalikāra": ['bhs'],
    "kavalita": ['ap90', 'mw'],
    "kavalya": ['mw'],
    "kavalīkārāhāra": ['bhs'],
    "kavalīkṛ": ['mw'],
    "kavana": ['mw'],
    "kavanaṃ": ['ap90'],
    "kavandha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kavandhin": ['cae', 'mw'],
    "kavantaka": ['mw'],
    "kavapatha": ['mw'],
    "kavara": ['ap90', 'mw'],
    "kavarabhāra": ['mw'],
    "kavarakī": ['ap90', 'mw'],
    "kavarapuccha": ['mw'],
    "kavarga": ['mw'],
    "kavarā": ['mw'],
    "kavarī": ['ap90', 'mw'],
    "kavarībhara": ['mw'],
    "kavarībhāra": ['mw'],
    "kavarībhṛt": ['mw'],
    "kavasa": ['mw'],
    "kavasaḥ": ['ap90'],
    "kavat": ['mw'],
    "kavatnu": ['ap90', 'cae', 'gra', 'mw'],
    "kavaya": ['ddsa'],
    "kavayitṛ": ['mw'],
    "kavayī": ['mw'],
    "kavaḍa": ['bhs', 'mw'],
    "kavaḍachedakam": ['bhs'],
    "kavaḍaka": ['bhs'],
    "kavaḍaḥ": ['ap90'],
    "kavaṃdhin": ['ap90'],
    "kavaṣ": ['cae', 'mw'],
    "kavaṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kavaṣin": ['mw'],
    "kavaṭa": ['mw'],
    "kavaṭī": ['ap90', 'mw'],
    "kavela": ['mw'],
    "kavelaṃ": ['ap90'],
    "kaverakanyā": ['mw'],
    "kavi": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kavibhaṭṭa": ['mw'],
    "kavibhūma": ['mw'],
    "kavibhūṣaṇa": ['mw'],
    "kavicakravartin": ['mw'],
    "kavicandra": ['mw'],
    "kavicchad": ['mw'],
    "kavichad": ['gra'],
    "kavidarpaṇa": ['mw'],
    "kavijanavinoda": ['mw'],
    "kavijanaśevadhi": ['mw'],
    "kavijyeṣṭha": ['mw'],
    "kavika": ['mw'],
    "kavikalpadruma": ['mw'],
    "kavikalpalatā": ['mw'],
    "kavikamalasadman": ['mw'],
    "kavikarpaṭī": ['mw'],
    "kavikarṇapūrṇa": ['mw'],
    "kavikaḥ": ['ap90'],
    "kavikaṇṭhahāra": ['mw'],
    "kavikaṇṭhābharaṇa": ['mw'],
    "kavikrama": ['mw'],
    "kavikratu": ['cae', 'gra', 'mw'],
    "kavikā": ['ddsa', 'mw'],
    "kavila": ['mw'],
    "kavilāsikā": ['mw'],
    "kavilāśikā": ['mw'],
    "kavimaṇḍana": ['mw'],
    "kavipraśasta": ['gra', 'mw'],
    "kavipriyā": ['mw'],
    "kaviputra": ['cae', 'mw'],
    "kavipūrṇa": ['mw'],
    "kavirahasya": ['mw'],
    "kaviratha": ['mw'],
    "kaviratnapuruṣottamamiśra": ['mw'],
    "kavirāja": ['cae', 'mw'],
    "kavirājabhikṣu": ['mw'],
    "kavirājakautuka": ['mw'],
    "kavirājavasuṃdhara": ['mw'],
    "kavirājayati": ['mw'],
    "kavirāmāyaṇa": ['mw'],
    "kavita": ['bhs'],
    "kavitama": ['mw'],
    "kavitara": ['mw'],
    "kavitva": ['cae', 'gra', 'mw'],
    "kavitvana": ['gra', 'mw'],
    "kavitvaratnākara": ['mw'],
    "kavitā": ['ap90', 'cae', 'ddsa', 'mw'],
    "kavitāmṛtakūpa": ['mw'],
    "kavitārahasya": ['mw'],
    "kavitāratnākara": ['mw'],
    "kavitārkikasiṃha": ['mw'],
    "kavitāvali": ['mw'],
    "kavitāvedin": ['mw'],
    "kavitāśakti": ['mw'],
    "kavitṛ": ['mw'],
    "kavivallabha": ['mw'],
    "kavivṛdha": ['gra', 'mw'],
    "kavivṛṣan": ['mw'],
    "kaviya": ['mw'],
    "kaviyaṃ": ['ap90'],
    "kaviśasta": ['cae', 'gra', 'mw'],
    "kaviśikṣā": ['mw'],
    "kaviṭa": ['mw'],
    "kavoṣṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kavoṣṇatā": ['mw'],
    "kavya": ['cae', 'ddsa', 'gra', 'mw'],
    "kavyabhojana": ['mw'],
    "kavyabhuj": ['mw'],
    "kavyahavyabhuj": ['mw'],
    "kavyat": ['mw'],
    "kavyatā": ['gra', 'mw'],
    "kavyavah": ['mw'],
    "kavyavāhana": ['mw'],
    "kavyavāla": ['mw'],
    "kavyavāḍa": ['mw'],
    "kavyaṃ": ['ap90'],
    "kavāgni": ['mw'],
    "kavāra": ['mw'],
    "kavāraṃ": ['ap90'],
    "kavāri": ['ap90', 'cae', 'gra', 'mw'],
    "kavāsakha": ['gra', 'mw'],
    "kavātiryañc": ['mw'],
    "kavāṭa": ['ap90', 'cped', 'ddsa', 'mw'],
    "kavāṭabaddha": ['cped'],
    "kavāṭaghna": ['mw'],
    "kavāṭaka": ['mw'],
    "kavāṭapiṭṭha": ['cped'],
    "kavāṭavakra": ['mw'],
    "kavīndra": ['mw'],
    "kavīndrakalpataru": ['mw'],
    "kavīndrakarṇābharaṇa": ['mw'],
    "kavīndu": ['mw'],
    "kavīy": ['gra'],
    "kavīya": ['mw'],
    "kavīyamāna": ['mw'],
    "kavīyas": ['mw'],
    "kavīyat": ['mw'],
    "kavīyaṃ": ['ap90'],
    "kavīśvara": ['mw'],
    "kavūla": ['mw'],
    "kaya": ['cae', 'cped', 'gra', 'mw'],
    "kayasthā": ['mw'],
    "kayavikkaya": ['cped'],
    "kayira": ['cped'],
    "kayiramāna": ['cped'],
    "kayirati": ['cped'],
    "kayirā": ['cped'],
    "kayirātha": ['cped'],
    "kayita": ['cped'],
    "kayya": ['mw'],
    "kayyaka": ['mw'],
    "kayyaṭa": ['ap90', 'mw'],
    "kayā": ['cae', 'gra', 'mw'],
    "kayād": ['mw'],
    "kayādhu": ['mw'],
    "kayādhūḥ": ['ap90'],
    "kayāśubhīya": ['ddsa', 'mw'],
    "kañc": ['mw'],
    "kañcana": ['cped'],
    "kañcanasannibhattaca": ['cped'],
    "kañcaḍa": ['mw'],
    "kañcaṭa": ['mw'],
    "kañcideka": ['mw'],
    "kañcidevā": ['mw'],
    "kañcikā": ['mw'],
    "kañcu": ['bhs'],
    "kañcuka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kañcukin": ['cae', 'mw'],
    "kañcukirecaka": ['mw'],
    "kañcukita": ['mw'],
    "kañcukoṣṇīṣin": ['mw'],
    "kañcukālu": ['mw'],
    "kañcukī": ['mw'],
    "kañcukīya": ['bhs', 'mw'],
    "kañcula": ['mw'],
    "kañculikā": ['mw'],
    "kañculī": ['mw'],
    "kañcāra": ['mw'],
    "kañcūla": ['mw'],
    "kañjaka": ['mw'],
    "kañjala": ['mw'],
    "kañjana": ['mw'],
    "kañjara": ['mw'],
    "kañjika": ['cped'],
    "kañjikā": ['ddsa', 'mw'],
    "kañjinī": ['mw'],
    "kañjāra": ['mw'],
    "kaññā": ['cped'],
    "kaś": ['ap90', 'mw'],
    "kaśa": ['cae', 'ddsa', 'mw'],
    "kaśaku": ['mw'],
    "kaśakṛtsna": ['mw'],
    "kaśambakajāta": ['bhs'],
    "kaśambūka": ['mw'],
    "kaśaplaka": ['gra', 'mw'],
    "kaśas": ['ap90', 'mw'],
    "kaśaḥ": ['ap90'],
    "kaścana": ['mw'],
    "kaśeraka": ['mw'],
    "kaśeru": ['ap90', 'mw'],
    "kaśeruka": ['mw'],
    "kaśerukaḥ": ['ap90'],
    "kaśerumat": ['mw'],
    "kaśerus": ['mw'],
    "kaśeruyajña": ['mw'],
    "kaśerū": ['mw'],
    "kaśerūmat": ['mw'],
    "kaśika": ['mw'],
    "kaśikapāda": ['mw'],
    "kaśikaḥ": ['ap90'],
    "kaśikā": ['cae', 'mw'],
    "kaśipu": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaśipūpabarhaṇa": ['mw'],
    "kaśmala": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kaśmalacetas": ['mw'],
    "kaśmalamaya": ['mw'],
    "kaśmaśa": ['mw'],
    "kaśmīra": ['cae', 'ddsa', 'mw'],
    "kaśmīrajanman": ['mw'],
    "kaśmīraḥ": ['ap90'],
    "kaśojū": ['gra', 'mw'],
    "kaśoka": ['mw'],
    "kaśu": ['cae', 'gra', 'mw'],
    "kaśya": ['ap90', 'mw'],
    "kaśyapa": ['cae', 'ddsa', 'gra', 'mw'],
    "kaśyapabhāskara": ['mw'],
    "kaśyapadvīpa": ['mw'],
    "kaśyapagrīva": ['mw'],
    "kaśyapanandana": ['mw'],
    "kaśyapapuccha": ['mw'],
    "kaśyapasaṃhitā": ['mw'],
    "kaśyapasmṛti": ['mw'],
    "kaśyapasūnujyeṣṭha": ['mw'],
    "kaśyapatuṅga": ['mw'],
    "kaśyapavrata": ['mw'],
    "kaśyapaḥ": ['ap90'],
    "kaśyapeśvara": ['mw'],
    "kaśyapeśvaratīrtha": ['mw'],
    "kaśyapottarasaṃhitā": ['mw'],
    "kaśyapā": ['mw'],
    "kaśyapāpatya": ['mw'],
    "kaśyapīya": ['bhs'],
    "kaśyata": ['mw'],
    "kaśā": ['gra', 'mw'],
    "kaśāghāta": ['mw'],
    "kaśāhata": ['bhs'],
    "kaśānipāta": ['mw'],
    "kaśāpāta": ['mw'],
    "kaśārha": ['mw'],
    "kaśāri": ['mw'],
    "kaśātraya": ['mw'],
    "kaśāvant": ['cae'],
    "kaśāvat": ['gra', 'mw'],
    "kaśāya": ['mw'],
    "kaśīkā": ['cae', 'gra', 'mw'],
    "kaḍ": ['ap90', 'mw'],
    "kaḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaḍacchaka": ['mw'],
    "kaḍaka": ['mw'],
    "kaḍakaṃ": ['ap90'],
    "kaḍamba": ['mw'],
    "kaḍambā": ['bhs'],
    "kaḍambī": ['mw'],
    "kaḍandikā": ['mw'],
    "kaḍat": ['mw'],
    "kaḍatkāra": ['mw'],
    "kaḍatra": ['bhs', 'mw'],
    "kaḍatraṃ": ['ap90'],
    "kaḍavaka": ['mw'],
    "kaḍaṃbaḥ": ['ap90'],
    "kaḍaṃdikā": ['ap90'],
    "kaḍaṃgara": ['mw'],
    "kaḍaṃgaraḥ": ['ap90'],
    "kaḍaṃgarīya": ['ap90', 'mw'],
    "kaḍaṃgaḥ": ['ap90'],
    "kaḍaṃkara": ['mw'],
    "kaḍaṃkaraḥ": ['ap90'],
    "kaḍaṃkarīya": ['ap90', 'mw'],
    "kaḍaṅga": ['mw'],
    "kaḍaṅgaka": ['mw'],
    "kaḍaṅgara": ['bhs', 'mw'],
    "kaḍera": ['mw'],
    "kaḍevara": ['bhs'],
    "kaḍhalya": ['bhs'],
    "kaḍitula": ['mw'],
    "kaḍitulaḥ": ['ap90'],
    "kaḍiṃtala": ['bhs'],
    "kaḍulī": ['mw'],
    "kaḍāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaḍārādi": ['mw'],
    "kaḍḍ": ['ap90', 'mw'],
    "kaḥ": ['ap90'],
    "kaḷevara": ['cped'],
    "kaḷimbha": ['cped'],
    "kaḷimbhaka": ['cped'],
    "kaḷiṅgara": ['cped'],
    "kaḷopi": ['cped'],
    "kaḷīra": ['cped'],
    "kaṁsa": ['cped'],
    "kaṁsanīla": ['cped'],
    "kaṁsapattharika": ['cped'],
    "kaṁsapātī": ['cped'],
    "kaṁsathāla": ['cped'],
    "kaṁsūpadhāraṇa": ['cped'],
    "kaṃb": ['ap90'],
    "kaṃbalakaḥ": ['ap90'],
    "kaṃbalaḥ": ['ap90'],
    "kaṃbalikā": ['ap90'],
    "kaṃbalin": ['ap90'],
    "kaṃbara": ['ap90'],
    "kaṃbhu": ['ap90'],
    "kaṃbiḥ": ['ap90'],
    "kaṃbojaḥ": ['ap90'],
    "kaṃbu": ['ap90'],
    "kaṃbukaḥ": ['ap90'],
    "kaṃbū": ['ap90'],
    "kaṃbūlaṃ": ['ap90'],
    "kaṃc": ['ap90'],
    "kaṃcikā": ['ap90'],
    "kaṃcukaḥ": ['ap90'],
    "kaṃcukin": ['ap90'],
    "kaṃcukita": ['ap90'],
    "kaṃcukāluḥ": ['ap90'],
    "kaṃculikā": ['ap90'],
    "kaṃcāraḥ": ['ap90'],
    "kaṃcūlaṃ": ['ap90'],
    "kaṃd": ['ap90'],
    "kaṃda": ['mw'],
    "kaṃdakaḥ": ['ap90'],
    "kaṃdalaḥ": ['ap90'],
    "kaṃdalita": ['ap90'],
    "kaṃdalī": ['ap90'],
    "kaṃdaraḥ": ['ap90'],
    "kaṃdarpaḥ": ['ap90'],
    "kaṃdaḥ": ['ap90'],
    "kaṃdaṭṭaṃ": ['ap90'],
    "kaṃdha": ['mw'],
    "kaṃdhara": ['cae', 'mw'],
    "kaṃdharaḥ": ['ap90'],
    "kaṃdhaḥ": ['ap90'],
    "kaṃdhi": ['mw'],
    "kaṃdhiḥ": ['ap90'],
    "kaṃdin": ['ap90'],
    "kaṃdirī": ['ap90'],
    "kaṃdotaḥ": ['ap90'],
    "kaṃdoṭaḥ": ['ap90'],
    "kaṃdukaḥ": ['ap90'],
    "kaṃduḥ": ['ap90'],
    "kaṃgu": ['ap90'],
    "kaṃgulaḥ": ['ap90'],
    "kaṃja": ['mw'],
    "kaṃjabāhu": ['mw'],
    "kaṃjaja": ['mw'],
    "kaṃjakaḥ": ['ap90'],
    "kaṃjalaḥ": ['ap90'],
    "kaṃjanaḥ": ['ap90'],
    "kaṃjanābha": ['mw'],
    "kaṃjaraḥ": ['ap90'],
    "kaṃjasū": ['mw'],
    "kaṃjavadana": ['mw'],
    "kaṃjaḥ": ['ap90'],
    "kaṃjikā": ['ap90'],
    "kaṃk": ['ap90'],
    "kaṃkaloḍyaṃ": ['ap90'],
    "kaṃkara": ['ap90'],
    "kaṃkarolaḥ": ['ap90'],
    "kaṃkataḥ": ['ap90'],
    "kaṃkaḥ": ['ap90'],
    "kaṃkaṇaḥ": ['ap90'],
    "kaṃkaṇin": ['ap90'],
    "kaṃkaṭaḥ": ['ap90'],
    "kaṃkellaḥ": ['ap90'],
    "kaṃkeruḥ": ['ap90'],
    "kaṃkhaṃ": ['ap90'],
    "kaṃkolī": ['ap90'],
    "kaṃkuḥ": ['ap90'],
    "kaṃkuṣṭhaḥ": ['ap90'],
    "kaṃkālayaḥ": ['ap90'],
    "kaṃkālaḥ": ['ap90'],
    "kaṃkūṣaḥ": ['ap90'],
    "kaṃp": ['ap90'],
    "kaṃpana": ['ap90'],
    "kaṃpaḥ": ['ap90'],
    "kaṃpilla": ['ap90'],
    "kaṃpita": ['ap90'],
    "kaṃpra": ['ap90'],
    "kaṃpākaḥ": ['ap90'],
    "kaṃs": ['ap90', 'mw'],
    "kaṃsa": ['cae', 'ddsa', 'mw'],
    "kaṃsadhvaṃsana": ['mw'],
    "kaṃsadoha": ['bhs'],
    "kaṃsahan": ['mw'],
    "kaṃsahanana": ['mw'],
    "kaṃsajit": ['mw'],
    "kaṃsaka": ['mw'],
    "kaṃsakaṃ": ['ap90'],
    "kaṃsakeśīniṣūdana": ['mw'],
    "kaṃsakāra": ['mw'],
    "kaṃsakūṭa": ['bhs'],
    "kaṃsakṛṣ": ['mw'],
    "kaṃsamardana": ['mw'],
    "kaṃsamākṣika": ['mw'],
    "kaṃsanidhana": ['mw'],
    "kaṃsaniṣūdana": ['cae', 'mw'],
    "kaṃsaparimṛj": ['mw'],
    "kaṃsapātra": ['mw'],
    "kaṃsapātrī": ['bhs'],
    "kaṃsasthāla": ['mw'],
    "kaṃsavadha": ['mw'],
    "kaṃsavatī": ['ap90', 'mw'],
    "kaṃsavaṇij": ['mw'],
    "kaṃsavidrāvaṇakarī": ['mw'],
    "kaṃsayajña": ['mw'],
    "kaṃsaśatru": ['cae', 'mw'],
    "kaṃsaḥ": ['ap90'],
    "kaṃsika": ['ap90', 'mw'],
    "kaṃsodbhavā": ['mw'],
    "kaṃsopadohinī": ['bhs'],
    "kaṃsā": ['mw'],
    "kaṃsāra": ['mw'],
    "kaṃsāraṃ": ['ap90'],
    "kaṃsāri": ['cae', 'mw'],
    "kaṃsārāti": ['mw'],
    "kaṃsāsthi": ['mw'],
    "kaṃsīya": ['ap90', 'mw'],
    "kaṃta": ['ap90'],
    "kaṃthā": ['ap90'],
    "kaṃtu": ['ap90'],
    "kaṃva": ['mw'],
    "kaṃvant": ['cae'],
    "kaṃvat": ['mw'],
    "kaṃvūla": ['mw'],
    "kaṃya": ['mw'],
    "kaṃyu": ['mw'],
    "kaṃyya": ['ap90', 'mw'],
    "kaṃyyu": ['mw'],
    "kaṃśa": ['mw'],
    "kaṃḍ": ['ap90'],
    "kaṃḍanaṃ": ['ap90'],
    "kaṃḍarā": ['ap90'],
    "kaṃḍikā": ['ap90'],
    "kaṃḍita": ['ap90'],
    "kaṃḍolakaḥ": ['ap90'],
    "kaṃḍolaḥ": ['ap90'],
    "kaṃḍoṣaḥ": ['ap90'],
    "kaṃḍura": ['ap90'],
    "kaṃḍuḥ": ['ap90'],
    "kaṃḍānakaḥ": ['ap90'],
    "kaṃḍūla": ['ap90'],
    "kaṃḍūmat": ['ap90'],
    "kaṃḍūrā": ['ap90'],
    "kaṃḍūtiḥ": ['ap90'],
    "kaṃḍūyana": ['ap90'],
    "kaṃḍūyati": ['ap90'],
    "kaṃḍūyitaṃ": ['ap90'],
    "kaṃḍūyitṛ": ['ap90'],
    "kaṃḍūyā": ['ap90'],
    "kaṃṭ": ['ap90'],
    "kaṃṭa": ['ap90'],
    "kaṃṭakaḥ": ['ap90'],
    "kaṃṭakilaḥ": ['ap90'],
    "kaṃṭakin": ['ap90'],
    "kaṃṭakita": ['ap90'],
    "kaṃṭakālaḥ": ['ap90'],
    "kaṃṭakāraḥ": ['ap90'],
    "kaṃṭakārikā": ['ap90'],
    "kaṃṭalaḥ": ['ap90'],
    "kaṃṭh": ['ap90'],
    "kaṃṭhataḥ": ['ap90'],
    "kaṃṭhaḥ": ['ap90'],
    "kaṃṭhekālaḥ": ['ap90'],
    "kaṃṭhikā": ['ap90'],
    "kaṃṭhin": ['ap90'],
    "kaṃṭhya": ['ap90'],
    "kaṃṭhālaḥ": ['ap90'],
    "kaṃṭhī": ['ap90'],
    "kaṃṭhīlaḥ": ['ap90'],
    "kaṃṭin": ['ap90'],
    "kaṃṭāhvayaṃ": ['ap90'],
    "kaṃṭāluḥ": ['ap90'],
    "kaṅganīla": ['mw'],
    "kaṅgu": ['cped', 'mw'],
    "kaṅguka": ['mw'],
    "kaṅgula": ['mw'],
    "kaṅgunī": ['mw'],
    "kaṅgunīpattrā": ['mw'],
    "kaṅgū": ['mw'],
    "kaṅk": ['mw'],
    "kaṅka": ['cae', 'cped', 'ddsa', 'mw'],
    "kaṅkacit": ['mw'],
    "kaṅkadeva": ['mw'],
    "kaṅkahrada": ['mw'],
    "kaṅkalatā": ['mw'],
    "kaṅkaloḍya": ['mw'],
    "kaṅkamukha": ['mw'],
    "kaṅkamālā": ['mw'],
    "kaṅkaparvan": ['mw'],
    "kaṅkapattra": ['cae', 'mw'],
    "kaṅkapattrin": ['cae', 'mw'],
    "kaṅkapat‍tra": ['ddsa'],
    "kaṅkapṛṣṭhī": ['mw'],
    "kaṅkara": ['bhs', 'mw'],
    "kaṅkaraṅka": ['mw'],
    "kaṅkarola": ['mw'],
    "kaṅkata": ['cae', 'ddsa', 'gra', 'mw'],
    "kaṅkatikā": ['mw'],
    "kaṅkatroṭa": ['mw'],
    "kaṅkatroṭi": ['mw'],
    "kaṅkatuṇḍa": ['mw'],
    "kaṅkatī": ['mw'],
    "kaṅkatīya": ['mw'],
    "kaṅkavadana": ['mw'],
    "kaṅkavājita": ['mw'],
    "kaṅkaśatru": ['mw'],
    "kaṅkaśāya": ['mw'],
    "kaṅkaṇa": ['cae', 'cped', 'ddsa', 'mw'],
    "kaṅkaṇabhūṣaṇa": ['mw'],
    "kaṅkaṇadhara": ['mw'],
    "kaṅkaṇadharā": ['mw'],
    "kaṅkaṇahārikā": ['mw'],
    "kaṅkaṇamaṇī": ['mw'],
    "kaṅkaṇapriya": ['mw'],
    "kaṅkaṇapura": ['mw'],
    "kaṅkaṇavarṣa": ['mw'],
    "kaṅkaṇavarṣitā": ['mw'],
    "kaṅkaṇikā": ['bhs'],
    "kaṅkaṇin": ['ddsa', 'mw'],
    "kaṅkaṇā": ['mw'],
    "kaṅkaṇābharaṇa": ['cae', 'mw'],
    "kaṅkaṇī": ['mw'],
    "kaṅkaṇīka": ['mw'],
    "kaṅkaṇīkā": ['mw'],
    "kaṅkaṭa": ['cae', 'ddsa', 'mw'],
    "kaṅkaṭaka": ['mw'],
    "kaṅkaṭerī": ['mw'],
    "kaṅkaṭika": ['mw'],
    "kaṅkaṭila": ['mw'],
    "kaṅkaṭin": ['mw'],
    "kaṅkaṭīka": ['mw'],
    "kaṅkeli": ['cae', 'mw'],
    "kaṅkella": ['mw'],
    "kaṅkelli": ['cae', 'ddsa', 'mw'],
    "kaṅkeru": ['mw'],
    "kaṅkha": ['mw'],
    "kaṅkhacchida": ['cped'],
    "kaṅkhachida": ['cped'],
    "kaṅkhanīya": ['cped'],
    "kaṅkhati": ['cped'],
    "kaṅkhaṭṭhānīya": ['cped'],
    "kaṅkhi": ['cped'],
    "kaṅkhin": ['cped'],
    "kaṅkhita": ['cped'],
    "kaṅkhitā": ['cped'],
    "kaṅkhā": ['cped'],
    "kaṅkhāyita": ['cped'],
    "kaṅkhāṭṭhānīya": ['cped'],
    "kaṅkola": ['cae', 'ddsa', 'mw'],
    "kaṅkolaka": ['mw'],
    "kaṅku": ['mw'],
    "kaṅkuṣṭha": ['mw'],
    "kaṅkā": ['mw'],
    "kaṅkāla": ['cae', 'ddsa', 'mw'],
    "kaṅkālabhairava": ['mw'],
    "kaṅkālabhairavatantra": ['mw'],
    "kaṅkālaketu": ['mw'],
    "kaṅkālamusala": ['mw'],
    "kaṅkālamālabhārin": ['mw'],
    "kaṅkālamālin": ['mw'],
    "kaṅkālaya": ['mw'],
    "kaṅkālin": ['mw'],
    "kaṅkālinī": ['mw'],
    "kaṅkālī": ['bhs'],
    "kaṅkūṣa": ['mw'],
    "kaṇ": ['ap90', 'mw'],
    "kaṇa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kaṇabha": ['mw'],
    "kaṇabhaka": ['mw'],
    "kaṇabhakka": ['cped'],
    "kaṇabhakṣa": ['mw'],
    "kaṇabhakṣaka": ['mw'],
    "kaṇabhaḥ": ['ap90'],
    "kaṇabhuj": ['mw'],
    "kaṇadhūma": ['mw'],
    "kaṇaguggulu": ['mw'],
    "kaṇahoma": ['cped'],
    "kaṇaja": ['mw'],
    "kaṇajīra": ['mw'],
    "kaṇajīraka": ['mw'],
    "kaṇakukkuṭa": ['mw'],
    "kaṇalābha": ['mw'],
    "kaṇapa": ['mw'],
    "kaṇapaḥ": ['ap90'],
    "kaṇapriya": ['mw'],
    "kaṇapāyin": ['mw'],
    "kaṇavāhin": ['cae'],
    "kaṇaya": ['bhs'],
    "kaṇaśas": ['mw'],
    "kaṇaśaḥ": ['ap90'],
    "kaṇaḥ": ['ap90'],
    "kaṇe": ['ap90', 'mw'],
    "kaṇera": ['mw'],
    "kaṇeraḥ": ['ap90'],
    "kaṇeru": ['mw'],
    "kaṇeruka": ['bhs'],
    "kaṇeruloḷita": ['cped'],
    "kaṇerā": ['mw'],
    "kaṇha": ['cped'],
    "kaṇhakhandhaka": ['cped'],
    "kaṇhapakkha": ['cped'],
    "kaṇhasappa": ['cped'],
    "kaṇhavattanī": ['cped'],
    "kaṇhuttara": ['cped'],
    "kaṇhābhijāti": ['cped'],
    "kaṇhābhijātika": ['cped'],
    "kaṇhābhijātiya": ['cped'],
    "kaṇika": ['cae', 'cped', 'ddsa', 'mw'],
    "kaṇikaḥ": ['ap90'],
    "kaṇikā": ['mw'],
    "kaṇikārapuppha": ['cped'],
    "kaṇima": ['bhs'],
    "kaṇita": ['mw'],
    "kaṇitaṃ": ['ap90'],
    "kaṇiśa": ['ddsa', 'mw'],
    "kaṇiśakiṃsāru": ['mw'],
    "kaṇiśaḥ": ['ap90'],
    "kaṇiṣṭha": ['ap90'],
    "kaṇva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kaṇvabṛhat": ['mw'],
    "kaṇvahotṛ": ['gra', 'mw'],
    "kaṇvajambhana": ['mw'],
    "kaṇvamat": ['ap90', 'gra', 'mw'],
    "kaṇvarathaṃtara": ['mw'],
    "kaṇvasakhi": ['gra', 'mw'],
    "kaṇvasūtra": ['mw'],
    "kaṇvatama": ['ap90', 'mw'],
    "kaṇvavat": ['mw'],
    "kaṇvaveda": ['mw'],
    "kaṇvopaniṣad": ['mw'],
    "kaṇvādi": ['mw'],
    "kaṇvāya": ['mw'],
    "kaṇvāśrama": ['mw'],
    "kaṇvīya": ['mw'],
    "kaṇvīyasaṃhitāhoma": ['mw'],
    "kaṇā": ['mw'],
    "kaṇāda": ['cae', 'ddsa', 'mw'],
    "kaṇādarahasyasaṃgraha": ['mw'],
    "kaṇādaḥ": ['ap90'],
    "kaṇāhvā": ['mw'],
    "kaṇājaka": ['cped'],
    "kaṇānna": ['cae', 'ddsa', 'mw'],
    "kaṇānnatā": ['mw'],
    "kaṇāṭīna": ['mw'],
    "kaṇāṭīnaḥ": ['ap90'],
    "kaṇāṭīra": ['ddsa', 'mw'],
    "kaṇāṭīraka": ['mw'],
    "kaṇī": ['mw'],
    "kaṇīci": ['mw'],
    "kaṇīciḥ": ['ap90'],
    "kaṇīka": ['ap90', 'mw'],
    "kaṇīkā": ['mw'],
    "kaṇīyas": ['mw'],
    "kaṇūkay": ['cae', 'gra'],
    "kaṇūkaya": ['ddsa', 'mw'],
    "kaṇḍ": ['mw'],
    "kaṇḍa": ['bhs', 'cped', 'mw'],
    "kaṇḍacitraka": ['cped'],
    "kaṇḍacittaka": ['cped'],
    "kaṇḍagopāla": ['mw'],
    "kaṇḍaka": ['bhs'],
    "kaṇḍana": ['cae', 'ddsa', 'mw'],
    "kaṇḍanī": ['mw'],
    "kaṇḍarachinna": ['cped'],
    "kaṇḍarika": ['bhs'],
    "kaṇḍarā": ['mw'],
    "kaṇḍarīka": ['mw'],
    "kaṇḍikā": ['mw'],
    "kaṇḍita": ['bhs'],
    "kaṇḍola": ['ddsa', 'mw'],
    "kaṇḍolaka": ['mw'],
    "kaṇḍolapāda": ['mw'],
    "kaṇḍolavīṇā": ['mw'],
    "kaṇḍolikā": ['cped'],
    "kaṇḍolī": ['mw'],
    "kaṇḍoṣa": ['mw'],
    "kaṇḍu": ['cae', 'cped', 'ddsa', 'mw'],
    "kaṇḍuka": ['bhs', 'mw'],
    "kaṇḍula": ['cae', 'mw'],
    "kaṇḍupaṭicchādī": ['cped'],
    "kaṇḍura": ['cae', 'mw'],
    "kaṇḍurā": ['mw'],
    "kaṇḍuvamāna": ['cped'],
    "kaṇḍuvana": ['cped'],
    "kaṇḍuvanta": ['cped'],
    "kaṇḍuvati": ['cped'],
    "kaṇḍvādi": ['mw'],
    "kaṇḍānaka": ['mw'],
    "kaṇḍīkṛ": ['mw'],
    "kaṇḍīra": ['mw'],
    "kaṇḍū": ['mw'],
    "kaṇḍūghna": ['mw'],
    "kaṇḍūjuṣ": ['mw'],
    "kaṇḍūkarī": ['mw'],
    "kaṇḍūla": ['ddsa', 'mw'],
    "kaṇḍūlabhāva": ['mw'],
    "kaṇḍūlā": ['mw'],
    "kaṇḍūmakā": ['mw'],
    "kaṇḍūmat": ['mw'],
    "kaṇḍūna": ['mw'],
    "kaṇḍūra": ['mw'],
    "kaṇḍūrā": ['mw'],
    "kaṇḍūsika": ['bhs'],
    "kaṇḍūti": ['cae', 'mw'],
    "kaṇḍūvamāna": ['cped'],
    "kaṇḍūvana": ['cped'],
    "kaṇḍūvati": ['cped'],
    "kaṇḍūy": ['cae'],
    "kaṇḍūya": ['ddsa', 'mw'],
    "kaṇḍūyana": ['cae', 'mw'],
    "kaṇḍūyanaka": ['mw'],
    "kaṇḍūyanī": ['mw'],
    "kaṇḍūyita": ['mw'],
    "kaṇḍūyitṛ": ['mw'],
    "kaṇḍūyā": ['mw'],
    "kaṇṇa": ['cped'],
    "kaṇṇacchidda": ['cped'],
    "kaṇṇacchinna": ['cped'],
    "kaṇṇagūthaka": ['cped'],
    "kaṇṇajappana": ['cped'],
    "kaṇṇakaṭuka": ['cped'],
    "kaṇṇakita": ['cped'],
    "kaṇṇakālakkhana": ['cped'],
    "kaṇṇasota": ['cped'],
    "kaṇṇikālakkhaṇa": ['cped'],
    "kaṇṭ": ['mw'],
    "kaṇṭa": ['mw'],
    "kaṇṭadalā": ['mw'],
    "kaṇṭaka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kaṇṭakabhuj": ['mw'],
    "kaṇṭakadalā": ['mw'],
    "kaṇṭakadhāna": ['cped'],
    "kaṇṭakadruma": ['mw'],
    "kaṇṭakalatā": ['mw'],
    "kaṇṭakaphala": ['mw'],
    "kaṇṭakapraticchedana": ['mw'],
    "kaṇṭakaprāvṛtā": ['mw'],
    "kaṇṭakasthalī": ['mw'],
    "kaṇṭakatraya": ['mw'],
    "kaṇṭakautsa": ['ddsa'],
    "kaṇṭakavat": ['mw'],
    "kaṇṭakavaṭṭa": ['cped'],
    "kaṇṭakavuttika": ['cped'],
    "kaṇṭakavṛntākī": ['mw'],
    "kaṇṭakayukta": ['mw'],
    "kaṇṭakaśreṇī": ['mw'],
    "kaṇṭakaṭṭhāna": ['cped'],
    "kaṇṭaki": ['mw'],
    "kaṇṭakidruma": ['cae', 'ddsa'],
    "kaṇṭakija": ['mw'],
    "kaṇṭakikṣīrin": ['mw'],
    "kaṇṭakila": ['mw'],
    "kaṇṭakilatā": ['mw'],
    "kaṇṭakin": ['cae', 'mw'],
    "kaṇṭakinī": ['mw'],
    "kaṇṭakiphala": ['mw'],
    "kaṇṭakita": ['cae', 'ddsa', 'mw'],
    "kaṇṭakivṛkṣa": ['cae', 'mw'],
    "kaṇṭakoddharaṇa": ['mw'],
    "kaṇṭakoddhāra": ['mw'],
    "kaṇṭakuraṇṭa": ['mw'],
    "kaṇṭakāgāra": ['mw'],
    "kaṇṭakākhya": ['mw'],
    "kaṇṭakāla": ['mw'],
    "kaṇṭakāluka": ['mw'],
    "kaṇṭakāpassaya": ['cped'],
    "kaṇṭakāpassayika": ['cped'],
    "kaṇṭakāra": ['mw'],
    "kaṇṭakāraka": ['mw'],
    "kaṇṭakārikā": ['mw'],
    "kaṇṭakārī": ['mw'],
    "kaṇṭakārītraya": ['mw'],
    "kaṇṭakāśana": ['mw'],
    "kaṇṭakāḍhya": ['mw'],
    "kaṇṭakāṣṭhīla": ['mw'],
    "kaṇṭakī": ['mw'],
    "kaṇṭakīvāṭa": ['cped'],
    "kaṇṭala": ['mw'],
    "kaṇṭapattra": ['mw'],
    "kaṇṭapattraphalā": ['mw'],
    "kaṇṭapattrikā": ['mw'],
    "kaṇṭaphala": ['mw'],
    "kaṇṭaphalā": ['mw'],
    "kaṇṭapuṅkhikā": ['mw'],
    "kaṇṭapāda": ['mw'],
    "kaṇṭatanu": ['mw'],
    "kaṇṭavallī": ['mw'],
    "kaṇṭavṛkṣa": ['mw'],
    "kaṇṭh": ['mw'],
    "kaṇṭha": ['cae', 'cped', 'ddsa', 'mw'],
    "kaṇṭhabandha": ['mw'],
    "kaṇṭhabhaṅga": ['mw'],
    "kaṇṭhabhūṣaṇa": ['cae', 'mw'],
    "kaṇṭhabhūṣā": ['mw'],
    "kaṇṭhaccheda": ['mw'],
    "kaṇṭhadaghna": ['mw'],
    "kaṇṭhadhāna": ['mw'],
    "kaṇṭhadvayasa": ['mw'],
    "kaṇṭhaga": ['cae', 'mw'],
    "kaṇṭhagata": ['cae', 'mw'],
    "kaṇṭhagraha": ['cae', 'mw'],
    "kaṇṭhagrahaṇa": ['mw'],
    "kaṇṭhaguṇa": ['bhs'],
    "kaṇṭhaka": ['bhs', 'mw'],
    "kaṇṭhakubja": ['mw'],
    "kaṇṭhakubjapratīkāra": ['mw'],
    "kaṇṭhakāpāśraya": ['bhs'],
    "kaṇṭhakūpa": ['mw'],
    "kaṇṭhakūṇikā": ['mw'],
    "kaṇṭhalagna": ['mw'],
    "kaṇṭhalatā": ['mw'],
    "kaṇṭhalā": ['mw'],
    "kaṇṭhamaṇi": ['bhs', 'mw'],
    "kaṇṭhamūla": ['mw'],
    "kaṇṭhamūlīya": ['mw'],
    "kaṇṭhanāla": ['ddsa', 'mw'],
    "kaṇṭhanālikā": ['bhs', 'mw'],
    "kaṇṭhanālī": ['mw'],
    "kaṇṭhanāḍyā": ['bhs'],
    "kaṇṭhanīlaka": ['mw'],
    "kaṇṭhanīḍaka": ['mw'],
    "kaṇṭhapañcama": ['cped'],
    "kaṇṭhapaṇḍita": ['mw'],
    "kaṇṭhapraṇālikā": ['mw'],
    "kaṇṭhaprāvṛta": ['mw'],
    "kaṇṭhapāśaka": ['mw'],
    "kaṇṭhapīḍā": ['mw'],
    "kaṇṭhapīṭha": ['mw'],
    "kaṇṭhapīṭhī": ['mw'],
    "kaṇṭharava": ['mw'],
    "kaṇṭharodha": ['mw'],
    "kaṇṭhasajjana": ['cae'],
    "kaṇṭhasañjana": ['mw'],
    "kaṇṭhastha": ['mw'],
    "kaṇṭhasthalī": ['mw'],
    "kaṇṭhasthānīya": ['mw'],
    "kaṇṭhasutta": ['cped'],
    "kaṇṭhasuttaka": ['cped'],
    "kaṇṭhasūtra": ['mw'],
    "kaṇṭhatalāsikā": ['mw'],
    "kaṇṭhatas": ['mw'],
    "kaṇṭhataṭa": ['mw'],
    "kaṇṭhataṭinī": ['mw'],
    "kaṇṭhatrāṇa": ['mw'],
    "kaṇṭhavartin": ['cae', 'mw'],
    "kaṇṭhavibhūṣaṇa": ['mw'],
    "kaṇṭhaya": ['ddsa'],
    "kaṇṭhaśoṣa": ['mw'],
    "kaṇṭhaśruti": ['mw'],
    "kaṇṭhaśuṇḍī": ['mw'],
    "kaṇṭhaśālūka": ['mw'],
    "kaṇṭheguḍa": ['mw'],
    "kaṇṭheguṇa": ['bhs'],
    "kaṇṭhekāla": ['mw'],
    "kaṇṭheviddha": ['mw'],
    "kaṇṭheśvaratīrtha": ['mw'],
    "kaṇṭhikā": ['bhs', 'ddsa', 'mw'],
    "kaṇṭhin": ['mw'],
    "kaṇṭhokta": ['mw'],
    "kaṇṭhokti": ['mw'],
    "kaṇṭhya": ['cae', 'mw'],
    "kaṇṭhyasvara": ['mw'],
    "kaṇṭhyavarṇa": ['mw'],
    "kaṇṭhābharaṇa": ['mw'],
    "kaṇṭhābharaṇadarpaṇa": ['mw'],
    "kaṇṭhābharaṇamārjana": ['mw'],
    "kaṇṭhāgata": ['mw'],
    "kaṇṭhāgni": ['mw'],
    "kaṇṭhāla": ['mw'],
    "kaṇṭhālā": ['mw'],
    "kaṇṭhāraka": ['ddsa'],
    "kaṇṭhārava": ['mw'],
    "kaṇṭhāvasakta": ['mw'],
    "kaṇṭhāśleṣa": ['cae', 'ddsa', 'mw'],
    "kaṇṭhī": ['mw'],
    "kaṇṭhīla": ['mw'],
    "kaṇṭhīrava": ['ddsa', 'mw'],
    "kaṇṭhīravī": ['mw'],
    "kaṇṭin": ['mw'],
    "kaṇṭāhvaya": ['mw'],
    "kaṇṭālikā": ['mw'],
    "kaṇṭālu": ['mw'],
    "kaṇṭāphala": ['mw'],
    "kaṇṭārikā": ['mw'],
    "kaṇṭārtagalā": ['mw'],
    "kaṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaṣaca": ['bhs'],
    "kaṣaka": ['mw'],
    "kaṣambakajāta": ['bhs'],
    "kaṣanmukha": ['mw'],
    "kaṣapaṭṭikā": ['mw'],
    "kaṣapāṣāṇa": ['mw'],
    "kaṣava": ['bhs'],
    "kaṣaṇa": ['ap90', 'cae', 'mw'],
    "kaṣaṭa": ['bhs'],
    "kaṣaṭṭa": ['bhs'],
    "kaṣerukā": ['ap90', 'mw'],
    "kaṣi": ['ap90', 'mw'],
    "kaṣikā": ['ap90'],
    "kaṣita": ['ap90', 'mw'],
    "kaṣkaṣa": ['ap90', 'mw'],
    "kaṣmīlita": ['bhs'],
    "kaṣotka": ['mw'],
    "kaṣphila": ['mw'],
    "kaṣā": ['ap90', 'mw'],
    "kaṣāghāta": ['mw'],
    "kaṣākaṣa": ['mw'],
    "kaṣāku": ['mw'],
    "kaṣākuḥ": ['ap90'],
    "kaṣāputra": ['mw'],
    "kaṣāya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kaṣāyacitra": ['mw'],
    "kaṣāyadanta": ['mw'],
    "kaṣāyadaśana": ['mw'],
    "kaṣāyaka": ['mw'],
    "kaṣāyakṛt": ['mw'],
    "kaṣāyapāda": ['mw'],
    "kaṣāyapāṇa": ['mw'],
    "kaṣāyatā": ['mw'],
    "kaṣāyavaktratā": ['mw'],
    "kaṣāyavasana": ['mw'],
    "kaṣāyavastra": ['mw'],
    "kaṣāyavāsas": ['mw'],
    "kaṣāyavāsika": ['mw'],
    "kaṣāyayāvanāla": ['mw'],
    "kaṣāyikā": ['bhs'],
    "kaṣāyin": ['ap90', 'mw'],
    "kaṣāyita": ['ap90', 'mw'],
    "kaṣāyā": ['mw'],
    "kaṣāyānvita": ['mw'],
    "kaṣāyībhūta": ['mw'],
    "kaṣāyīkṛ": ['mw'],
    "kaṣāyīkṛta": ['mw'],
    "kaṣāyīkṛtalocana": ['mw'],
    "kaṣīkā": ['ap90', 'mw'],
    "kaṣṇavarṇa": ['ddsa'],
    "kaṣṇāyas": ['ddsa'],
    "kaṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaṣṭabhāgineya": ['mw'],
    "kaṣṭaguggula": ['mw'],
    "kaṣṭakara": ['mw'],
    "kaṣṭakāraka": ['mw'],
    "kaṣṭalabhya": ['mw'],
    "kaṣṭam": ['mw'],
    "kaṣṭamātula": ['mw'],
    "kaṣṭasthāna": ['mw'],
    "kaṣṭasādhya": ['mw'],
    "kaṣṭatapas": ['cae', 'mw'],
    "kaṣṭatara": ['mw'],
    "kaṣṭatva": ['mw'],
    "kaṣṭatā": ['cae', 'mw'],
    "kaṣṭaśrita": ['mw'],
    "kaṣṭi": ['mw'],
    "kaṣṭiḥ": ['ap90'],
    "kaṣṭādhika": ['mw'],
    "kaṣṭāgata": ['mw'],
    "kaṣṭārtha": ['mw'],
    "kaṣṭārthatva": ['mw'],
    "kaṣṭāya": ['mw'],
    "kaṭ": ['ap90', 'mw'],
    "kaṭa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kaṭabhaṅga": ['mw'],
    "kaṭabhī": ['mw'],
    "kaṭabhū": ['mw'],
    "kaṭaccha": ['bhs'],
    "kaṭacchu": ['bhs', 'cped', 'mw'],
    "kaṭacchubhikkhā": ['cped'],
    "kaṭacchuka": ['cped'],
    "kaṭacchuparissāvana": ['cped'],
    "kaṭaggaha": ['cped'],
    "kaṭaggāha": ['cped'],
    "kaṭaghoṣa": ['mw'],
    "kaṭaghoṣīya": ['mw'],
    "kaṭajaka": ['mw'],
    "kaṭaka": ['bhs', 'cae', 'mw'],
    "kaṭakagṛha": ['mw'],
    "kaṭakara": ['mw'],
    "kaṭakaraṇa": ['cae'],
    "kaṭakavalayin": ['mw'],
    "kaṭakavārāṇasī": ['mw'],
    "kaṭakaḥ": ['ap90'],
    "kaṭakaṭa": ['ap90', 'cped', 'mw'],
    "kaṭakaṭā": ['ap90', 'mw'],
    "kaṭakaṭāpaya": ['mw'],
    "kaṭakaṭāpayati": ['ap90'],
    "kaṭakaṭāy": ['cae'],
    "kaṭakaṭāya": ['ddsa', 'mw'],
    "kaṭakhādaka": ['mw'],
    "kaṭakin": ['ap90', 'mw'],
    "kaṭakola": ['mw'],
    "kaṭakriyā": ['mw'],
    "kaṭakuṭi": ['mw'],
    "kaṭakya": ['mw'],
    "kaṭakīya": ['mw'],
    "kaṭakṛt": ['mw'],
    "kaṭamarda": ['mw'],
    "kaṭamba": ['mw'],
    "kaṭambarā": ['mw'],
    "kaṭamālinī": ['mw'],
    "kaṭana": ['cped', 'mw'],
    "kaṭanagara": ['mw'],
    "kaṭanagarīya": ['mw'],
    "kaṭanaṃ": ['ap90'],
    "kaṭani": ['mw'],
    "kaṭapallikuñcikā": ['mw'],
    "kaṭapalvala": ['mw'],
    "kaṭapalvalīya": ['mw'],
    "kaṭaprū": ['mw'],
    "kaṭapūtana": ['cae', 'ddsa', 'mw'],
    "kaṭasaṃghāta": ['mw'],
    "kaṭasivaḍḍhana": ['cped'],
    "kaṭasthala": ['mw'],
    "kaṭasthāla": ['mw'],
    "kaṭasī": ['ap90', 'bhs', 'cped', 'mw'],
    "kaṭavraṇa": ['mw'],
    "kaṭaśarkarā": ['mw'],
    "kaṭaḥ": ['ap90'],
    "kaṭaṃbaḥ": ['ap90'],
    "kaṭaṃbhara": ['ap90', 'mw'],
    "kaṭaṃbharā": ['mw'],
    "kaṭaṃkaṭa": ['mw'],
    "kaṭaṃkaṭaḥ": ['ap90'],
    "kaṭaṃkaṭerī": ['ap90', 'mw'],
    "kaṭaṅkaṭa": ['bhs', 'ddsa'],
    "kaṭaṭṭhika": ['cped'],
    "kaṭerakagrāma": ['mw'],
    "kaṭh": ['ap90', 'mw'],
    "kaṭha": ['cae', 'ddsa', 'mw'],
    "kaṭhadhūrta": ['mw'],
    "kaṭhakalāpa": ['mw'],
    "kaṭhakauthuma": ['mw'],
    "kaṭhala": ['bhs', 'cped'],
    "kaṭhali": ['cped'],
    "kaṭhalla": ['mw'],
    "kaṭhalya": ['mw'],
    "kaṭhalyaḥ": ['ap90'],
    "kaṭhamarda": ['mw'],
    "kaṭhamardaḥ": ['ap90'],
    "kaṭhara": ['ap90', 'mw'],
    "kaṭhasūtra": ['mw'],
    "kaṭhavallī": ['mw'],
    "kaṭhaśrotriya": ['mw'],
    "kaṭhaśruti": ['mw'],
    "kaṭhaśākhā": ['mw'],
    "kaṭhaśāṭha": ['mw'],
    "kaṭhaśāṭhin": ['mw'],
    "kaṭhaḥ": ['ap90'],
    "kaṭhera": ['ap90', 'mw'],
    "kaṭheraṇi": ['mw'],
    "kaṭheru": ['mw'],
    "kaṭhikā": ['ap90', 'mw'],
    "kaṭhilla": ['mw'],
    "kaṭhillaka": ['mw'],
    "kaṭhina": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kaṭhinacitta": ['mw'],
    "kaṭhinadussa": ['cped'],
    "kaṭhinahṛdaya": ['mw'],
    "kaṭhinaka": ['cped', 'mw'],
    "kaṭhinaphala": ['mw'],
    "kaṭhinapṛṣṭha": ['mw'],
    "kaṭhinapṛṣṭhaka": ['mw'],
    "kaṭhinarajju": ['cped'],
    "kaṭhinasamuṭṭhāna": ['cped'],
    "kaṭhinattharaṇa": ['cped'],
    "kaṭhinatthāra": ['cped'],
    "kaṭhinatthāraka": ['cped'],
    "kaṭhinatva": ['mw'],
    "kaṭhinatā": ['ap90', 'mw'],
    "kaṭhinatārakanātha": ['mw'],
    "kaṭhinay": ['cae'],
    "kaṭhinaya": ['ddsa', 'mw'],
    "kaṭhinekṣu": ['mw'],
    "kaṭhinikā": ['ap90', 'mw'],
    "kaṭhinubbhāra": ['cped'],
    "kaṭhinuddhāra": ['cped'],
    "kaṭhinā": ['mw'],
    "kaṭhināvadāna": ['mw'],
    "kaṭhinī": ['ap90', 'ddsa', 'mw'],
    "kaṭhinībhū": ['mw'],
    "kaṭhinībhūta": ['mw'],
    "kaṭhinīkṛ": ['ddsa', 'mw'],
    "kaṭhita": ['cped'],
    "kaṭhiñjara": ['mw'],
    "kaṭhiṃjaraḥ": ['ap90'],
    "kaṭhola": ['ap90', 'mw'],
    "kaṭhopaniṣad": ['ddsa', 'mw'],
    "kaṭhopaniṣadbhāṣya": ['mw'],
    "kaṭhopaniṣadbhāṣyaṭīkā": ['mw'],
    "kaṭhopaniṣadbhāṣyaṭīkāvivaraṇa": ['mw'],
    "kaṭhora": ['ap90', 'cae', 'ddsa', 'mw'],
    "kaṭhoracitta": ['cae', 'mw'],
    "kaṭhoragiri": ['mw'],
    "kaṭhorahṛdaya": ['mw'],
    "kaṭhoratva": ['mw'],
    "kaṭhoratā": ['ap90', 'mw'],
    "kaṭhoratārādhipa": ['mw'],
    "kaṭhoray": ['cae'],
    "kaṭhoraya": ['ddsa', 'mw'],
    "kaṭhorayati": ['ap90'],
    "kaṭhorita": ['mw'],
    "kaṭhorībhū": ['mw'],
    "kaṭhura": ['ddsa', 'mw'],
    "kaṭhādhyāpaka": ['mw'],
    "kaṭhāhaka": ['mw'],
    "kaṭhāhakaḥ": ['ap90'],
    "kaṭhāku": ['mw'],
    "kaṭhākuḥ": ['ap90'],
    "kaṭhī": ['mw'],
    "kaṭi": ['bhs', 'cae', 'cped', 'mw'],
    "kaṭibandha": ['mw'],
    "kaṭideśa": ['mw'],
    "kaṭika": ['mw'],
    "kaṭikarpaṭa": ['mw'],
    "kaṭikuṣṭha": ['mw'],
    "kaṭikā": ['ap90', 'bhs', 'mw'],
    "kaṭikūpa": ['mw'],
    "kaṭilla": ['mw'],
    "kaṭillaka": ['mw'],
    "kaṭillakaḥ": ['ap90'],
    "kaṭillaḥ": ['ap90'],
    "kaṭimālikā": ['mw'],
    "kaṭin": ['ap90', 'mw'],
    "kaṭināḍikā": ['mw'],
    "kaṭiprotha": ['mw'],
    "kaṭirohaka": ['mw'],
    "kaṭistha": ['mw'],
    "kaṭisuttaka": ['cped'],
    "kaṭisūtra": ['mw'],
    "kaṭitaṭa": ['mw'],
    "kaṭitra": ['mw'],
    "kaṭivāsa": ['mw'],
    "kaṭiśīrṣaka": ['mw'],
    "kaṭiśūla": ['mw'],
    "kaṭiśṛṅkhalā": ['mw'],
    "kaṭiḥ": ['ap90'],
    "kaṭiṭṭhika": ['cped'],
    "kaṭkāra": ['bhs'],
    "kaṭm, kaṭī": ['ddsa'],
    "kaṭodaka": ['mw'],
    "kaṭola": ['ap90', 'mw'],
    "kaṭolaka": ['mw'],
    "kaṭolakapāda": ['mw'],
    "kaṭolapāda": ['mw'],
    "kaṭolavīṇā": ['mw'],
    "kaṭora": ['mw'],
    "kaṭoraṃ": ['ap90'],
    "kaṭorā": ['ap90'],
    "kaṭphala": ['cae', 'ddsa', 'mw'],
    "kaṭphalaḥ": ['ap90'],
    "kaṭphalā": ['mw'],
    "kaṭu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kaṭubadarī": ['mw'],
    "kaṭubhadra": ['mw'],
    "kaṭubhaṅga": ['mw'],
    "kaṭubhāṣin": ['cae'],
    "kaṭubhāṣitā": ['mw'],
    "kaṭubījā": ['mw'],
    "kaṭucchada": ['mw'],
    "kaṭucāturjātaka": ['mw'],
    "kaṭudalā": ['mw'],
    "kaṭugranthi": ['mw'],
    "kaṭuja": ['mw'],
    "kaṭuka": ['ap90', 'bhs', 'cae', 'cped', 'gra', 'mw'],
    "kaṭukabhakṣin": ['mw'],
    "kaṭukanda": ['mw'],
    "kaṭukapabhedana": ['cped'],
    "kaṭukaphala": ['mw'],
    "kaṭukapphala": ['cped'],
    "kaṭukarañja": ['mw'],
    "kaṭukarohiṇī": ['cped', 'mw'],
    "kaṭukataila": ['bhs'],
    "kaṭukatara": ['cped'],
    "kaṭukatraya": ['mw'],
    "kaṭukatva": ['mw'],
    "kaṭukatvaṃ": ['ap90'],
    "kaṭukatā": ['mw'],
    "kaṭukavallī": ['mw'],
    "kaṭukaviṭapa": ['mw'],
    "kaṭukiman": ['mw'],
    "kaṭukita": ['cae', 'ddsa', 'mw'],
    "kaṭukodaya": ['mw'],
    "kaṭukvāṇa": ['mw'],
    "kaṭukālābu": ['mw'],
    "kaṭukārohiṇī": ['mw'],
    "kaṭukāñjanī": ['mw'],
    "kaṭukīṭa": ['mw'],
    "kaṭukīṭaka": ['mw'],
    "kaṭumañjarikā": ['mw'],
    "kaṭumoda": ['mw'],
    "kaṭumūla": ['mw'],
    "kaṭuniṣpāva": ['mw'],
    "kaṭupadra": ['mw'],
    "kaṭupattra": ['mw'],
    "kaṭupattraka": ['mw'],
    "kaṭupattrikā": ['mw'],
    "kaṭuphala": ['mw'],
    "kaṭuphalā": ['mw'],
    "kaṭupāka": ['mw'],
    "kaṭupākin": ['mw'],
    "kaṭura": ['mw'],
    "kaṭurava": ['mw'],
    "kaṭuraṃ": ['ap90'],
    "kaṭurohiṇikā": ['mw'],
    "kaṭurohiṇī": ['mw'],
    "kaṭusneha": ['mw'],
    "kaṭutaila": ['mw'],
    "kaṭutikta": ['mw'],
    "kaṭutiktaka": ['mw'],
    "kaṭutiktakā": ['mw'],
    "kaṭutraya": ['mw'],
    "kaṭutrika": ['mw'],
    "kaṭutumbinī": ['mw'],
    "kaṭutumbī": ['mw'],
    "kaṭutuṇḍikā": ['mw'],
    "kaṭutuṇḍī": ['mw'],
    "kaṭutva": ['mw'],
    "kaṭutā": ['ddsa', 'mw'],
    "kaṭuvallī": ['mw'],
    "kaṭuvipāka": ['mw'],
    "kaṭuviya": ['cped'],
    "kaṭuviyakata": ['cped'],
    "kaṭuvārttākī": ['mw'],
    "kaṭuśṛṅga": ['mw'],
    "kaṭuśṛṅgāṭa": ['mw'],
    "kaṭuṃbharā": ['mw'],
    "kaṭuṃkatā": ['ap90'],
    "kaṭuṅka": ['bhs'],
    "kaṭuṅkatā": ['mw'],
    "kaṭvara": ['ap90', 'mw'],
    "kaṭvaṅga": ['cae', 'ddsa'],
    "kaṭvāṅga": ['mw'],
    "kaṭā": ['bhs'],
    "kaṭāgni": ['cae', 'ddsa', 'mw'],
    "kaṭāha": ['cae', 'cped', 'ddsa', 'mw'],
    "kaṭāhaka": ['bhs', 'mw'],
    "kaṭāhakaṃ": ['ap90'],
    "kaṭāhaḥ": ['ap90'],
    "kaṭākuḥ": ['ap90'],
    "kaṭākṣa": ['cae', 'ddsa', 'mw'],
    "kaṭākṣakṣetra": ['mw'],
    "kaṭākṣamuṣṭa": ['mw'],
    "kaṭākṣamāhātmya": ['mw'],
    "kaṭākṣaviśikha": ['mw'],
    "kaṭākṣaya": ['mw'],
    "kaṭākṣepa": ['mw'],
    "kaṭākṣipya": ['mw'],
    "kaṭākṣita": ['mw'],
    "kaṭākṣāveṣaṇa": ['mw'],
    "kaṭāla": ['mw'],
    "kaṭālu": ['mw'],
    "kaṭāra": ['mw'],
    "kaṭāramalla": ['mw'],
    "kaṭāraḥ": ['ap90'],
    "kaṭāyana": ['mw'],
    "kaṭāyanaṃ": ['ap90'],
    "kaṭāṭaṃkaḥ": ['ap90'],
    "kaṭāṭaṅka": ['mw'],
    "kaṭī": ['cae', 'mw'],
    "kaṭīka": ['mw'],
    "kaṭīkataruṇa": ['mw'],
    "kaṭīkṛta": ['bhs'],
    "kaṭīnivasana": ['mw'],
    "kaṭīpaṭa": ['mw'],
    "kaṭīra": ['mw'],
    "kaṭīraka": ['ddsa', 'mw'],
    "kaṭīrakaṃ": ['ap90'],
    "kaṭīraḥ": ['ap90'],
    "kaṭītala": ['mw'],
    "kaṭītalaḥ": ['ap90'],
    "kaṭūpaga": ['cped'],
    "kaṭūpiya": ['cped'],
    "kaṭūtkaṭa": ['mw'],
    "kaṭūtkaṭaka": ['mw'],
    "kaṭūṣaṇa": ['mw'],
    "kaṭṭ": ['cae', 'ddsa', 'mw'],
    "kaṭṭana": ['mw'],
    "kaṭṭarinṛtya": ['mw'],
    "kaṭṭati": ['bhs'],
    "kaṭṭha": ['cped'],
    "kaṭṭhahāra": ['cped'],
    "kaṭṭhahāraka": ['cped'],
    "kaṭṭhaka": ['cped'],
    "kaṭṭhapuñja": ['cped'],
    "kaṭṭhatumba": ['cped'],
    "kaṭṭhatāla": ['cped'],
    "kaṭṭhissa": ['cped'],
    "kaṭṭāra": ['mw'],
    "kaṭṭāraka": ['ddsa', 'mw'],
    "kaṭṭāraḥ": ['ap90'],
    "kaṭṭāṃkriyati": ['bhs'],
    "kecuka": ['mw'],
    "kedara": ['ap90', 'mw'],
    "kedhuka": ['bhs'],
    "kedāra": ['cae', 'ddsa', 'mw'],
    "kedārabhaṭṭa": ['cae', 'mw'],
    "kedāradeva": ['mw'],
    "kedāraja": ['mw'],
    "kedāraka": ['mw'],
    "kedārakalpa": ['mw'],
    "kedārakaṭu": ['mw'],
    "kedārakaṭukā": ['mw'],
    "kedārakhaṇḍa": ['mw'],
    "kedāraliṅga": ['mw'],
    "kedāramalla": ['mw'],
    "kedāramāhātmya": ['mw'],
    "kedāranātha": ['mw'],
    "kedārapurāṇa": ['mw'],
    "kedārasetu": ['mw'],
    "kedāratīrtha": ['mw'],
    "kedāraśambhu": ['mw'],
    "kedāraḥ": ['ap90'],
    "kedāreśa": ['mw'],
    "kedāreśvara": ['mw'],
    "kedāreśvaraliṅga": ['mw'],
    "kedāreśvarasthalī": ['mw'],
    "kedārikā": ['mw'],
    "kedārī": ['mw'],
    "kedṛśa": ['bhs'],
    "kehladeva": ['mw'],
    "kekala": ['mw'],
    "kekara": ['ap90', 'ddsa', 'mw'],
    "kekaraka": ['mw'],
    "kekaralocana": ['mw'],
    "kekaranetra": ['mw'],
    "kekarākṣa": ['mw'],
    "kekaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "kekayaḥ": ['ap90'],
    "kekayī": ['mw'],
    "kekeyī": ['mw'],
    "kekika": ['mw'],
    "kekin": ['ddsa', 'mw'],
    "kekiśikhā": ['mw'],
    "kekotkaṇṭha": ['cae', 'mw'],
    "kekā": ['ap90', 'cae', 'ddsa', 'mw'],
    "kekārava": ['mw'],
    "kekāsura": ['mw'],
    "kekāvala": ['mw'],
    "kekāvalaḥ": ['ap90'],
    "kekāya": ['ddsa', 'mw'],
    "kekāṇa": ['mw'],
    "kel": ['ap90', 'mw'],
    "kela": ['bhs', 'mw'],
    "kelaka": ['mw'],
    "kelakaḥ": ['ap90'],
    "kelaṭaka": ['mw'],
    "keli": ['cae', 'ddsa', 'mw'],
    "keligṛha": ['cae', 'mw'],
    "kelika": ['mw'],
    "kelikadamba": ['mw'],
    "kelikailāsa": ['mw'],
    "kelikala": ['cae', 'mw'],
    "kelikalaha": ['cae', 'mw'],
    "kelikalā": ['mw'],
    "kelikamala": ['mw'],
    "kelikaḥ": ['ap90'],
    "kelikila": ['mw'],
    "kelikilā": ['mw'],
    "kelikośa": ['mw'],
    "kelikuñcikā": ['mw'],
    "kelikānana": ['mw'],
    "kelikīrṇa": ['mw'],
    "kelimandira": ['mw'],
    "kelimaṇḍapa": ['mw'],
    "kelimukha": ['mw'],
    "kelimālin": ['bhs'],
    "kelin": ['bhs'],
    "keliniketana": ['mw'],
    "kelināgara": ['mw'],
    "kelipalvala": ['mw'],
    "kelipara": ['mw'],
    "keliraivataka": ['mw'],
    "keliraṅga": ['mw'],
    "kelisaciva": ['mw'],
    "kelisadana": ['mw'],
    "kelisthalī": ['mw'],
    "kelisāra": ['mw'],
    "kelita": ['cae', 'mw'],
    "kelivana": ['cae', 'mw'],
    "kelivṛkṣa": ['mw'],
    "keliśaila": ['mw'],
    "keliśayana": ['cae', 'mw'],
    "keliśuṣi": ['mw'],
    "keliśvetasahasrapattra": ['mw'],
    "keliḥ": ['ap90'],
    "kelu": ['bhs'],
    "kelāsa": ['mw'],
    "kelāsaḥ": ['ap90'],
    "kelāya": ['mw'],
    "kelāyanā": ['bhs'],
    "kelāyate": ['ap90'],
    "kelāyati": ['bhs', 'cped'],
    "kelī": ['ap90', 'mw'],
    "kelīkalita": ['mw'],
    "kelīpika": ['mw'],
    "kelīvanī": ['mw'],
    "kelīśālabhañjikā": ['mw'],
    "kelūṭa": ['mw'],
    "kemadruma": ['mw'],
    "kembuka": ['mw'],
    "kemuka": ['mw'],
    "kena": ['cae', 'ddsa', 'mw'],
    "kena upāyena": ['cped'],
    "kenatī": ['ap90', 'mw'],
    "kenava": ['mw'],
    "kendra": ['cae', 'ddsa', 'mw'],
    "kendrakā": ['mw'],
    "kendu": ['mw'],
    "kenduka": ['mw'],
    "kenduvilla": ['mw'],
    "keneṣitopaniṣad": ['cae', 'ddsa', 'mw'],
    "kenipa": ['ap90', 'cae', 'gra', 'mw'],
    "kenipāta": ['mw'],
    "kenipātaka": ['mw'],
    "kenipātana": ['mw'],
    "kenipātaḥ": ['ap90'],
    "kenopaniṣad": ['cae', 'mw'],
    "kenāmā": ['cped'],
    "kenāra": ['mw'],
    "kenāraḥ": ['ap90'],
    "kep": ['ap90', 'mw'],
    "kepi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "keraka": ['bhs', 'mw'],
    "kerala": ['ap90', 'cae', 'ddsa', 'mw'],
    "keralajātaka": ['mw'],
    "keralaka": ['mw'],
    "keralasiddhānta": ['mw'],
    "keralatantra": ['mw'],
    "keralaḥ": ['ap90'],
    "keralikā": ['mw'],
    "keralotpatti": ['mw'],
    "keralī": ['mw'],
    "keru": ['cae', 'gra', 'mw'],
    "kerā": ['mw'],
    "kesa": ['cped'],
    "kesakambala": ['cped'],
    "kesamassu": ['cped'],
    "kesamassulocaka": ['cped'],
    "kesamassulocana": ['cped'],
    "kesara": ['cae', 'ddsa', 'mw'],
    "kesaragrāma": ['mw'],
    "kesaraguṇḍa": ['cae'],
    "kesaramālikā": ['cae'],
    "kesaramālā": ['mw'],
    "kesaraprābandhā": ['mw'],
    "kesarapura": ['mw'],
    "kesarapāśa": ['mw'],
    "kesaravara": ['mw'],
    "kesaravat": ['mw'],
    "kesaravṛkṣa": ['cae'],
    "kesaraḥ": ['ap90'],
    "kesari": ['cped'],
    "kesarin": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kesarisuta": ['mw'],
    "kesariḥ": ['ap90'],
    "kesariṇī": ['mw'],
    "kesarā": ['mw'],
    "kesarāgra": ['cae', 'ddsa'],
    "kesarāla": ['cae', 'mw'],
    "kesarāvalā": ['cae'],
    "kesarāya": ['mw'],
    "kesi": ['cped'],
    "kesin": ['cped'],
    "kesārukā": ['mw'],
    "keta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ketaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "ketakakāṇḍaka": ['cae'],
    "ketakaḥ": ['ap90'],
    "ketaki": ['mw'],
    "ketakī": ['mw'],
    "ketalikīrti": ['mw'],
    "ketana": ['cae', 'ddsa', 'mw'],
    "ketanajuṣ": ['cae'],
    "ketanaṃ": ['ap90'],
    "ketapū": ['mw'],
    "ketasap": ['gra', 'mw'],
    "ketavedas": ['gra', 'mw'],
    "ketay": ['cae'],
    "ketaya": ['ddsa', 'mw'],
    "ketayati": ['ap90'],
    "ketayitṛ": ['mw'],
    "ketita": ['ap90', 'mw'],
    "kettaka": ['bhs'],
    "ketu": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ketubha": ['mw'],
    "ketubhūta": ['mw'],
    "ketucakra": ['mw'],
    "ketudharman": ['mw'],
    "ketudhvaja": ['bhs'],
    "ketugaṇa": ['mw'],
    "ketugraha": ['mw'],
    "ketugrahavallabha": ['mw'],
    "ketukā": ['bhs'],
    "ketumant": ['bhs', 'cae'],
    "ketumat": ['gra', 'mw'],
    "ketumatī": ['bhs', 'mw'],
    "ketumāla": ['mw'],
    "ketumālaka": ['mw'],
    "ketumāli": ['mw'],
    "ketumālin": ['mw'],
    "ketumālā": ['mw'],
    "ketuprabhā": ['bhs'],
    "keturatna": ['mw'],
    "ketutārā": ['mw'],
    "ketuvarman": ['mw'],
    "ketuvīrya": ['mw'],
    "ketuyaṣṭi": ['mw'],
    "ketuśrī": ['bhs'],
    "ketuśṛṅga": ['mw'],
    "ketuḥ": ['ap90'],
    "ketuṁ": ['cped'],
    "ketūttama": ['bhs'],
    "ketṛ": ['mw'],
    "kev": ['ap90', 'mw'],
    "keva": ['bhs'],
    "kevacira": ['bhs'],
    "kevaka": ['bhs'],
    "kevala": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kevalabarhis": ['mw'],
    "kevalabrahmopaniṣad": ['mw'],
    "kevaladravya": ['mw'],
    "kevalajñāna": ['mw'],
    "kevalajñānin": ['mw'],
    "kevalaka": ['bhs'],
    "kevalakalpa": ['bhs'],
    "kevalakappa": ['cped'],
    "kevalakappaṁ": ['cped'],
    "kevalakarmin": ['mw'],
    "kevalam": ['mw'],
    "kevalamānuṣa": ['mw'],
    "kevalanaiyāyika": ['mw'],
    "kevalaparipuṇṇa": ['cped'],
    "kevalaparipūra": ['cped'],
    "kevalaputrā": ['mw'],
    "kevalatas": ['ap90', 'mw'],
    "kevalatva": ['mw'],
    "kevalavaiyākaraṇa": ['mw'],
    "kevalavyatirekin": ['mw'],
    "kevalavātika": ['mw'],
    "kevalaśas": ['mw'],
    "kevalaṁ": ['cped'],
    "kevali": ['cped'],
    "kevalin": ['ap90', 'cped', 'mw'],
    "kevalā": ['mw'],
    "kevalādin": ['cae', 'gra', 'mw'],
    "kevalādvaitavādakuliśa": ['mw'],
    "kevalāgha": ['cae', 'ddsa', 'gra', 'mw'],
    "kevalānvayigrantha": ['mw'],
    "kevalānvayin": ['mw'],
    "kevalānvayirahasya": ['mw'],
    "kevalānvayivāda": ['mw'],
    "kevalātman": ['mw'],
    "kevalī": ['mw'],
    "kevarta": ['cae', 'ddsa', 'mw'],
    "kevartaḥ": ['ap90'],
    "kevarūpa": ['bhs'],
    "kevatika": ['bhs'],
    "kevatta": ['bhs'],
    "kevattaka": ['bhs'],
    "kevaṭa": ['cae', 'ddsa', 'gra', 'mw'],
    "kevaṭaḥ": ['ap90'],
    "kevaṭṭa": ['bhs', 'cped'],
    "kevikā": ['mw'],
    "kevuka": ['mw'],
    "kevālabhū": ['mw'],
    "kevālakṛ": ['mw'],
    "kevālā": ['mw'],
    "kevālīas": ['mw'],
    "kevāsī": ['mw'],
    "kevāsīas": ['mw'],
    "kevāsībhū": ['mw'],
    "kevāsīkṛ": ['mw'],
    "kevī": ['mw'],
    "kevūka": ['mw'],
    "keyūra": ['cae', 'cped', 'ddsa', 'mw'],
    "keyūrabala": ['bhs', 'mw'],
    "keyūradharā": ['bhs', 'mw'],
    "keyūraka": ['mw'],
    "keyūraḥ": ['ap90'],
    "keyūrin": ['ap90', 'mw'],
    "keyūrāya": ['mw'],
    "keñca": ['mw'],
    "keśa": ['cae', 'ddsa', 'gra', 'mw'],
    "keśabandha": ['cae', 'mw'],
    "keśabhū": ['mw'],
    "keśabhūmi": ['mw'],
    "keśacaitya": ['mw'],
    "keśacaṇa": ['mw'],
    "keśacchid": ['mw'],
    "keśacīvara": ['bhs'],
    "keśacūḍa": ['mw'],
    "keśadamanī": ['mw'],
    "keśadhara": ['mw'],
    "keśadhāraṇa": ['mw'],
    "keśadhāriṇī": ['mw'],
    "keśadhṛt": ['mw'],
    "keśadṛṃhaṇa": ['mw'],
    "keśagarbha": ['mw'],
    "keśagarbhaka": ['mw'],
    "keśaghna": ['mw'],
    "keśagraha": ['cae', 'mw'],
    "keśagrahaṇa": ['mw'],
    "keśagranthi": ['mw'],
    "keśagrāham": ['mw'],
    "keśagṛhīta": ['mw'],
    "keśahantrī": ['mw'],
    "keśahantṛphalā": ['mw'],
    "keśahasta": ['cae', 'mw'],
    "keśahṛtphalā": ['mw'],
    "keśajāha": ['mw'],
    "keśaka": ['mw'],
    "keśakalpanā": ['cae', 'mw'],
    "keśakalāpa": ['mw'],
    "keśakambala": ['bhs'],
    "keśakarman": ['mw'],
    "keśakarṣaṇa": ['ddsa', 'mw'],
    "keśakaḥ": ['ap90'],
    "keśakāra": ['mw'],
    "keśakārin": ['mw'],
    "keśakīṭa": ['mw'],
    "keśakīṭāvapatita": ['mw'],
    "keśakūṭa": ['mw'],
    "keśalucana": ['bhs'],
    "keśaluñcaka": ['mw'],
    "keśaluñcana": ['mw'],
    "keśamardana": ['mw'],
    "keśamathanī": ['mw'],
    "keśamaṇḍala": ['mw'],
    "keśamiśra": ['mw'],
    "keśamuṣṭi": ['mw'],
    "keśamuṣṭika": ['mw'],
    "keśamārjaka": ['mw'],
    "keśamārjana": ['mw'],
    "keśanidhāna": ['mw'],
    "keśapakṣa": ['mw'],
    "keśaparṇī": ['mw'],
    "keśapaṅkti": ['mw'],
    "keśapiṅgala": ['mw'],
    "keśapradharṣaṇa": ['mw'],
    "keśaprasāra": ['mw'],
    "keśapratigraha": ['mw'],
    "keśapratigrahaṇa": ['bhs'],
    "keśapāśa": ['cae', 'mw'],
    "keśapāśī": ['mw'],
    "keśara": ['bhs', 'mw'],
    "keśaracanā": ['cae', 'mw'],
    "keśaranandin": ['bhs'],
    "keśarañjana": ['mw'],
    "keśari": ['mw'],
    "keśarikā": ['mw'],
    "keśarin": ['ap90', 'bhs', 'mw'],
    "keśariṇī": ['mw'],
    "keśaroccaṭā": ['mw'],
    "keśaromā": ['mw'],
    "keśaruhā": ['mw'],
    "keśarācala": ['mw'],
    "keśarāgra": ['mw'],
    "keśarāja": ['mw'],
    "keśarāmla": ['mw'],
    "keśarāpīḍa": ['mw'],
    "keśarūpā": ['mw'],
    "keśas": ['bhs'],
    "keśasaṃvardhana": ['mw'],
    "keśasthālin": ['bhs'],
    "keśastuka": ['mw'],
    "keśava": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "keśavabhakti": ['mw'],
    "keśavabhaṭṭa": ['mw'],
    "keśavadaivajña": ['mw'],
    "keśavadāsa": ['mw'],
    "keśavadīkṣita": ['mw'],
    "keśavajātakapaddhatyudāharaṇa": ['mw'],
    "keśavajīnandaśarman": ['mw'],
    "keśavamiśra": ['mw'],
    "keśavant": ['cae'],
    "keśavapana": ['cae', 'mw'],
    "keśavapanīya": ['mw'],
    "keśavaprabhu": ['mw'],
    "keśavardhana": ['mw'],
    "keśavardhanī": ['mw'],
    "keśavasvāmin": ['mw'],
    "keśavat": ['gra', 'mw'],
    "keśavatī": ['mw'],
    "keśavaśikṣā": ['mw'],
    "keśavaśreṣṭhin": ['mw'],
    "keśaveṣa": ['mw'],
    "keśaveṣṭa": ['mw'],
    "keśavyaparopaṇa": ['mw'],
    "keśavyudāharaṇa": ['mw'],
    "keśavācārya": ['mw'],
    "keśavāditya": ['mw'],
    "keśavālaya": ['mw'],
    "keśavāpa": ['mw'],
    "keśavārka": ['mw'],
    "keśavāvāsa": ['mw'],
    "keśavāyudha": ['mw'],
    "keśayantrī": ['mw'],
    "keśaśeṣakaraṇa": ['mw'],
    "keśaśmaśru": ['mw'],
    "keśaśmaśrulomanakha": ['mw'],
    "keśaśūla": ['mw'],
    "keśaḥ": ['ap90'],
    "keśaṭa": ['mw'],
    "keśaṭaḥ": ['ap90'],
    "keśi": ['mw'],
    "keśidhvaja": ['mw'],
    "keśigṛhapati": ['mw'],
    "keśihan": ['cae', 'mw'],
    "keśihantṛ": ['cae', 'mw'],
    "keśika": ['ap90', 'mw'],
    "keśikī": ['mw'],
    "keśimathana": ['cae', 'mw'],
    "keśin": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "keśiniṣūdana": ['cae', 'ddsa', 'mw'],
    "keśinī": ['ap90', 'bhs', 'mw'],
    "keśisūdana": ['cae', 'mw'],
    "keśitīrtha": ['mw'],
    "keśoccaya": ['mw'],
    "keśoṇḍaka": ['bhs'],
    "keśoṇḍraka": ['mw'],
    "keśoṇḍu": ['bhs'],
    "keśoṇḍuka": ['bhs', 'mw'],
    "keśya": ['mw'],
    "keśāda": ['mw'],
    "keśāgra": ['cae', 'ddsa', 'mw'],
    "keśākeśi": ['ap90', 'cae', 'ddsa', 'mw'],
    "keśāli": ['mw'],
    "keśāmbu": ['mw'],
    "keśānta": ['cae', 'mw'],
    "keśāntakaraṇa": ['mw'],
    "keśāntika": ['cae', 'mw'],
    "keśānī": ['mw'],
    "keśāpahā": ['mw'],
    "keśārhā": ['mw'],
    "keśāri": ['mw'],
    "keśāruhā": ['mw'],
    "keśārukā": ['mw'],
    "keśāvamarṣaṇa": ['mw'],
    "keśī": ['mw'],
    "keḷāyati": ['cped'],
    "keṃdraṃ": ['ap90'],
    "keṇikā": ['ap90', 'mw'],
    "keṭubhi": ['cped'],
    "keṭubhin": ['cped'],
    "kha": ['cae', 'ddsa', 'gra', 'mw'],
    "khabha": ['mw'],
    "khabhrānti": ['mw'],
    "khabāṣpa": ['mw'],
    "khac": ['ap90', 'cae', 'ddsa', 'mw'],
    "khacamasa": ['mw'],
    "khacana": ['bhs'],
    "khacara": ['cae', 'ddsa', 'mw'],
    "khacaratva": ['mw'],
    "khacita": ['ap90', 'cae', 'mw'],
    "khacitra": ['mw'],
    "khacārin": ['mw'],
    "khad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "khadana": ['mw'],
    "khadhūpa": ['mw'],
    "khadikā": ['mw'],
    "khadikāḥ": ['ap90'],
    "khadira": ['cae', 'ddsa', 'gra', 'mw'],
    "khadirabhū": ['mw'],
    "khadiracañcu": ['mw'],
    "khadiraja": ['mw'],
    "khadiraka": ['bhs', 'mw'],
    "khadirakovida": ['bhs'],
    "khadirakuṇa": ['mw'],
    "khadirakā": ['mw'],
    "khadiramaya": ['mw'],
    "khadirapattrikā": ['mw'],
    "khadirapattrī": ['mw'],
    "khadirarasa": ['mw'],
    "khadirasvāmin": ['mw'],
    "khadirasāra": ['mw'],
    "khadiravanika": ['bhs', 'mw'],
    "khadiravarman": ['mw'],
    "khadiravarṇapakṣa": ['mw'],
    "khadiravarṇaparṇa": ['mw'],
    "khadiravatī": ['mw'],
    "khadiravaṇa": ['mw'],
    "khadiravaṇika": ['mw'],
    "khadiravaṇītārā": ['bhs'],
    "khadiravāri": ['mw'],
    "khadiraḥ": ['ap90'],
    "khadirodaka": ['mw'],
    "khadiropama": ['mw'],
    "khadirā": ['mw'],
    "khadirājira": ['mw'],
    "khadirāṣṭaka": ['mw'],
    "khadirī": ['mw'],
    "khadukatā": ['bhs'],
    "khadyota": ['cae', 'ddsa', 'mw'],
    "khadyotaka": ['bhs', 'mw'],
    "khadyotana": ['mw'],
    "khadyotā": ['mw'],
    "khadā": ['bhs', 'cae', 'ddsa', 'mw'],
    "khadūra": ['mw'],
    "khadūraka": ['mw'],
    "khadūravāsinī": ['mw'],
    "khaga": ['cae', 'ddsa', 'mw'],
    "khagalya": ['ddsa', 'mw'],
    "khagama": ['cae', 'ddsa', 'mw'],
    "khagapati": ['cae', 'mw'],
    "khagapatigamanā": ['mw'],
    "khagapattra": ['mw'],
    "khagarbha": ['bhs', 'mw'],
    "khagarāj": ['mw'],
    "khagasthāna": ['mw'],
    "khagata": ['mw'],
    "khagati": ['mw'],
    "khagavaktra": ['mw'],
    "khagavatī": ['mw'],
    "khagañja": ['mw'],
    "khagaśatru": ['mw'],
    "khagaṅgā": ['mw'],
    "khagaṇa": ['mw'],
    "khagendra": ['cae', 'mw'],
    "khagendradhvaja": ['mw'],
    "khageśvara": ['mw'],
    "khagga": ['cped'],
    "khaggabaddhakappa": ['cped'],
    "khaggaḍa": ['mw'],
    "khaggaḍaḥ": ['ap90'],
    "khagola": ['mw'],
    "khagolaka": ['mw'],
    "khagolavidyā": ['mw'],
    "khagoḍa": ['mw'],
    "khaguṇa": ['mw'],
    "khagābhirāma": ['mw'],
    "khagādhipa": ['cae', 'ddsa', 'mw'],
    "khagānanā": ['bhs'],
    "khagāntaka": ['mw'],
    "khagāsana": ['mw'],
    "khahara": ['mw'],
    "khai": ['mw'],
    "khailika": ['ap90', 'mw'],
    "khailāyana": ['mw'],
    "khaimakhā": ['mw'],
    "khaj": ['ap90', 'mw'],
    "khaja": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "khajaka": ['mw'],
    "khajakaḥ": ['ap90'],
    "khajakṛt": ['gra', 'mw'],
    "khajala": ['cae', 'ddsa', 'mw'],
    "khajapa": ['mw'],
    "khajapaṃ": ['ap90'],
    "khajaḥ": ['ap90'],
    "khajaṃkara": ['gra', 'mw'],
    "khajikā": ['mw'],
    "khajit": ['mw'],
    "khajja": ['bhs', 'cped'],
    "khajjabhojja": ['cped'],
    "khajjabhājaka": ['cped'],
    "khajjaka": ['bhs', 'cped'],
    "khajjakabhājaka": ['cped'],
    "khajjanta": ['cped'],
    "khajjati": ['bhs', 'cped'],
    "khajjiṁ": ['cped'],
    "khajjopanaka": ['cped'],
    "khajjupanaka": ['cped'],
    "khajjūpanaka": ['cped'],
    "khajyotis": ['mw'],
    "khajā": ['ddsa', 'mw'],
    "khajājikā": ['ap90'],
    "khajāka": ['mw'],
    "khajākaḥ": ['ap90'],
    "khajākā": ['mw'],
    "khakhara": ['bhs'],
    "khakharaka": ['bhs'],
    "khakhaṭatva": ['bhs'],
    "khakholka": ['mw'],
    "khakholkāditya": ['mw'],
    "khakkh": ['ap90', 'mw'],
    "khakkhala": ['bhs'],
    "khakkhara": ['bhs', 'mw'],
    "khakkharaḥ": ['ap90'],
    "khakkhaṭa": ['ap90', 'bhs', 'mw'],
    "khakkhaṭatva": ['bhs'],
    "khakuntala": ['mw'],
    "khakāminī": ['mw'],
    "khakāra": ['mw'],
    "khal": ['ap90', 'ddsa', 'mw'],
    "khala": ['cae', 'ddsa', 'gra', 'mw'],
    "khalabhujaṅga": ['ddsa'],
    "khaladhāna": ['mw'],
    "khaladhānya": ['mw'],
    "khalahāna": ['bhs'],
    "khalaja": ['mw'],
    "khalaka": ['bhs'],
    "khalakaḥ": ['ap90'],
    "khalakhalāya": ['ddsa', 'mw'],
    "khalakhalāyati": ['bhs'],
    "khalakula": ['mw'],
    "khalamālin": ['mw'],
    "khalamūrti": ['mw'],
    "khalaprīti": ['mw'],
    "khalapū": ['mw'],
    "khalartha": ['ddsa'],
    "khalasaṃsarga": ['mw'],
    "khalati": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "khalatika": ['mw'],
    "khalatikaḥ": ['ap90'],
    "khalatulaparṇī": ['mw'],
    "khalatva": ['mw'],
    "khalatā": ['ddsa', 'mw'],
    "khalayajña": ['mw'],
    "khalaḥ": ['ap90'],
    "khale": ['mw'],
    "khalebusam": ['mw'],
    "khaledhānī": ['ap90', 'mw'],
    "khalekapotanyāya": ['ddsa', 'mw'],
    "khalekapotikā": ['mw'],
    "khalevālī": ['mw'],
    "khaleyavam": ['mw'],
    "khaleśa": ['mw'],
    "khaleśaya": ['mw'],
    "khali": ['bhs', 'mw'],
    "khalidruma": ['mw'],
    "khalikhā": ['cped'],
    "khalin": ['ap90', 'mw'],
    "khalina": ['mw'],
    "khalinaḥ": ['ap90'],
    "khalinī": ['ap90', 'mw'],
    "khalita": ['bhs', 'cped'],
    "khalitasira": ['cped'],
    "khalitasiras": ['cped'],
    "khalitaṁsira": ['cped'],
    "khalitaṁsiras": ['cped'],
    "khalitvā": ['cped'],
    "khaliśa": ['mw'],
    "khaliḥ": ['ap90'],
    "khall": ['cae', 'ddsa', 'mw'],
    "khalla": ['cae', 'ddsa', 'mw'],
    "khallaka": ['bhs', 'cped'],
    "khallaḥ": ['ap90'],
    "khalli": ['bhs', 'mw'],
    "khallikā": ['ap90', 'cae', 'mw'],
    "khallita": ['mw'],
    "khalliśa": ['mw'],
    "khalliṭa": ['ap90', 'mw'],
    "khallu": ['bhs'],
    "khallāsara": ['mw'],
    "khallāṭaka": ['bhs', 'mw'],
    "khallī": ['mw'],
    "khallīṭa": ['ap90', 'mw'],
    "khalokti": ['mw'],
    "khalu": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "khalubhakta": ['bhs'],
    "khaluj": ['ap90', 'mw'],
    "khalupacchābhatti": ['cped'],
    "khalupacchābhattika": ['cped'],
    "khalupacchābhattin": ['cped'],
    "khalupaścādbhaktika": ['bhs'],
    "khalureṣa": ['mw'],
    "khalureṣaka": ['mw'],
    "khalutas": ['mw'],
    "khaluṅka": ['cped'],
    "khaluṅkajjhāyita": ['cped'],
    "khalva": ['cae', 'ddsa', 'mw'],
    "khalvakā": ['mw'],
    "khalvala": ['mw'],
    "khalvavāhana": ['bhs'],
    "khalvaṅga": ['mw'],
    "khalvaṭa": ['mw'],
    "khalvāṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "khalvāṭabilvīya": ['mw'],
    "khalya": ['cae', 'mw'],
    "khalyakā": ['mw'],
    "khalyā": ['ap90', 'mw'],
    "khalyāṅga": ['mw'],
    "khalā": ['mw'],
    "khalābhidhāna": ['bhs'],
    "khalādhāna": ['mw'],
    "khalādhārā": ['mw'],
    "khalājina": ['mw'],
    "khalājinīya": ['mw'],
    "khalāy": ['cae'],
    "khalāya": ['ddsa', 'mw'],
    "khalī": ['mw'],
    "khalīkāra": ['ddsa', 'mw'],
    "khalīkāraḥ": ['ap90'],
    "khalīkṛ": ['cae', 'mw'],
    "khalīkṛti": ['mw'],
    "khalīkṛtya": ['mw'],
    "khalīna": ['ddsa', 'mw'],
    "khalūrikā": ['ap90', 'mw'],
    "khalūrī": ['mw'],
    "kham": ['mw'],
    "kham, khaṇḍ": ['ddsa'],
    "khama": ['cped'],
    "khamamāna": ['cped'],
    "khamanīya": ['cped'],
    "khamataṁ": ['cped'],
    "khamati": ['cped'],
    "khamatu": ['cped'],
    "khamaṇi": ['mw'],
    "khamb": ['mw'],
    "khambha": ['cped'],
    "khambhakata": ['cped'],
    "khambhanā": ['cped'],
    "khambhayati": ['cped'],
    "khambheti": ['cped'],
    "khambhīrapati": ['bhs'],
    "khamehi": ['cped'],
    "khamitabba": ['cped'],
    "khamāhi": ['cped'],
    "khamāpayati": ['cped'],
    "khamāpayi": ['cped'],
    "khamāpesi": ['cped'],
    "khamāpetabba": ['cped'],
    "khamāpeti": ['cped'],
    "khamāpita": ['cped'],
    "khamāpiyamāna": ['cped'],
    "khamāṇika": ['mw'],
    "khamīlana": ['mw'],
    "khamūli": ['mw'],
    "khamūlikā": ['mw'],
    "khamūlī": ['mw'],
    "khamūrti": ['mw'],
    "khamūrtimant": ['cae'],
    "khamūrtimat": ['mw'],
    "khan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "khana": ['cae', 'ddsa', 'mw'],
    "khanaka": ['ap90', 'cae', 'mw'],
    "khanakhanāya": ['ddsa'],
    "khanakī": ['mw'],
    "khanana": ['cae', 'mw'],
    "khananaṃ": ['ap90'],
    "khananta": ['cped'],
    "khananīya": ['mw'],
    "khanapāna": ['mw'],
    "khanati": ['cped', 'ddsa', 'mw'],
    "khanayitrī": ['mw'],
    "khandha": ['cped'],
    "khandhabīja": ['cped'],
    "khandhaja": ['cped'],
    "khandhaka": ['cped'],
    "khandhakavatta": ['cped'],
    "khandhādhisa": ['cped'],
    "khandhādhivacana": ['cped'],
    "khandhāvāra": ['bhs'],
    "khani": ['cae', 'mw'],
    "khanika": ['mw'],
    "khanimsu": ['cped'],
    "khaninetra": ['mw'],
    "khanita": ['cped'],
    "khanitra": ['cae', 'ddsa', 'gra', 'mw'],
    "khanitraka": ['mw'],
    "khanitrakaṃ": ['ap90'],
    "khanitraṃ": ['ap90'],
    "khanitrikā": ['mw'],
    "khanitrima": ['ap90', 'cae', 'gra', 'mw'],
    "khanitrā": ['mw'],
    "khanittī": ['cped'],
    "khanitvā": ['cped', 'mw'],
    "khanitṛ": ['ap90', 'cae', 'gra', 'mw'],
    "khaniḥ": ['ap90'],
    "khanta": ['cped'],
    "khantar": ['cped'],
    "khanti": ['cped'],
    "khantī": ['cped'],
    "khanya": ['bhs', 'cae', 'ddsa', 'mw'],
    "khanyavādin": ['mw'],
    "khanāpeti": ['cped'],
    "khanātaka": ['mw'],
    "khanī": ['mw'],
    "khanīnetra": ['mw'],
    "khapariḍīṇaka": ['mw'],
    "khaparāga": ['mw'],
    "khapura": ['mw'],
    "khapurapuṣpa": ['mw'],
    "khapuṣpa": ['ddsa', 'mw'],
    "khapuṣpaṭīkā": ['mw'],
    "khapuṭa": ['mw'],
    "khapūraḥ": ['ap90'],
    "khar": ['ddsa'],
    "khara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kharacchada": ['mw'],
    "kharadalā": ['mw'],
    "kharadaṇḍa": ['mw'],
    "kharadhvaṃsin": ['mw'],
    "kharadhāra": ['mw'],
    "kharadūṣaṇa": ['mw'],
    "kharadūṣaṇavadha": ['mw'],
    "kharagandhanibhā": ['mw'],
    "kharagandhā": ['mw'],
    "kharagata": ['cped'],
    "kharageha": ['mw'],
    "kharaghātana": ['mw'],
    "kharagoyuga": ['mw'],
    "kharagraha": ['mw'],
    "kharagṛha": ['bhs', 'mw'],
    "kharajaṅghā": ['mw'],
    "kharajru": ['gra', 'mw'],
    "kharaka": ['mw'],
    "kharakarṇa": ['bhs'],
    "kharakarṇī": ['mw'],
    "kharakaṇḍūyana": ['mw'],
    "kharakaṇḍūyita": ['mw'],
    "kharakaṇṭha": ['mw'],
    "kharaketu": ['mw'],
    "kharakomala": ['mw'],
    "kharakoṇa": ['mw'],
    "kharakuṭī": ['mw'],
    "kharakvāṇa": ['mw'],
    "kharakāṣṭhikā": ['mw'],
    "kharakṣaya": ['mw'],
    "kharaloman": ['mw'],
    "kharam": ['mw'],
    "kharamajra": ['gra', 'mw'],
    "kharamayūkha": ['cae', 'mw'],
    "kharamañjari": ['mw'],
    "kharamañjarī": ['mw'],
    "kharamukha": ['mw'],
    "kharamukhikā": ['mw'],
    "kharanakhara": ['mw'],
    "kharanarāya": ['mw'],
    "kharanāda": ['mw'],
    "kharanādin": ['mw'],
    "kharanādinī": ['mw'],
    "kharanāla": ['mw'],
    "kharapa": ['mw'],
    "kharaparṇinī": ['mw'],
    "kharapattra": ['mw'],
    "kharapattraka": ['mw'],
    "kharapattrā": ['mw'],
    "kharapattrī": ['mw'],
    "kharapostā": ['bhs'],
    "kharapriya": ['mw'],
    "kharaprāṇa": ['mw'],
    "kharapuṣpa": ['mw'],
    "kharapuṣpā": ['mw'],
    "kharapādāḍhya": ['mw'],
    "kharapāla": ['mw'],
    "kharapātra": ['mw'],
    "khararaśmi": ['mw'],
    "kharari": ['mw'],
    "khararoman": ['mw'],
    "kharaskandha": ['bhs', 'mw'],
    "kharaskandhā": ['mw'],
    "kharasolla": ['mw'],
    "kharasonda": ['mw'],
    "kharasoni": ['mw'],
    "kharasparśa": ['mw'],
    "kharassara": ['cped'],
    "kharasvarā": ['mw'],
    "kharasāda": ['mw'],
    "kharatara": ['mw'],
    "kharaturagīya": ['ddsa', 'mw'],
    "kharatva": ['mw'],
    "kharatvac": ['mw'],
    "kharavallikā": ['mw'],
    "kharavṛṣabha": ['mw'],
    "kharayaṣṭikā": ['mw'],
    "kharayāna": ['cae', 'mw'],
    "kharaśabda": ['mw'],
    "kharaśāka": ['mw'],
    "kharaśāla": ['mw'],
    "kharaśālā": ['mw'],
    "kharaṇas": ['mw'],
    "kharaṇasa": ['mw'],
    "kharaṭa": ['mw'],
    "kharaṭakharaṭā": ['mw'],
    "kharb": ['mw'],
    "kharba": ['ap90'],
    "kharbujaṃ": ['ap90'],
    "kharbūja": ['mw'],
    "khard": ['ap90', 'mw'],
    "khargala": ['mw'],
    "khargalā": ['cae', 'gra', 'mw'],
    "kharigata": ['cped'],
    "kharikā": ['ap90', 'mw'],
    "kharita": ['mw'],
    "khariṃ": ['mw'],
    "khariṃdhama": ['ap90', 'mw'],
    "khariṃdhaya": ['mw'],
    "kharj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kharja": ['mw'],
    "kharjanaṃ": ['ap90'],
    "kharjikā": ['ap90', 'mw'],
    "kharju": ['mw'],
    "kharjughna": ['mw'],
    "kharjura": ['mw'],
    "kharjuraka": ['bhs'],
    "kharjurakarṇa": ['mw'],
    "kharjuraṃ": ['ap90'],
    "kharjuḥ": ['ap90'],
    "kharjya": ['mw'],
    "kharjū": ['mw'],
    "kharjūghna": ['mw'],
    "kharjūla": ['mw'],
    "kharjūra": ['cae', 'ddsa', 'mw'],
    "kharjūraka": ['mw'],
    "kharjūrakarṇa": ['mw'],
    "kharjūrakaḥ": ['ap90'],
    "kharjūrapura": ['mw'],
    "kharjūrarasa": ['mw'],
    "kharjūraḥ": ['ap90'],
    "kharjūrikā": ['bhs', 'mw'],
    "kharjūrī": ['mw'],
    "kharjūrīrasaja": ['mw'],
    "kharjūḥ": ['ap90'],
    "kharkhoda": ['ddsa', 'mw'],
    "kharma": ['cae', 'ddsa', 'mw'],
    "kharoṣṭra": ['mw'],
    "kharoṣṭī": ['bhs', 'mw'],
    "kharpara": ['bhs', 'cae', 'ddsa', 'mw'],
    "kharparaḥ": ['ap90'],
    "kharparikā": ['bhs', 'mw'],
    "kharparāla": ['mw'],
    "kharparī": ['mw'],
    "kharparīkā": ['ap90'],
    "kharparīrasaka": ['mw'],
    "kharparītuttha": ['mw'],
    "kharta": ['bhs'],
    "kharu": ['ap90', 'mw'],
    "kharukharā": ['bhs'],
    "kharuṣṭa": ['bhs'],
    "kharv": ['ap90', 'mw'],
    "kharva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kharvaka": ['mw'],
    "kharvapattrā": ['mw'],
    "kharvarī": ['bhs'],
    "kharvavāsin": ['mw'],
    "kharvaya": ['mw'],
    "kharvaśākha": ['mw'],
    "kharvaṭa": ['mw'],
    "kharvaṭaḥ": ['ap90'],
    "kharvikā": ['mw'],
    "kharvita": ['mw'],
    "kharvujaṃ": ['ap90'],
    "kharvurā": ['mw'],
    "kharvīkṛ": ['ddsa'],
    "kharvīkṛta": ['mw'],
    "kharvūrā": ['mw'],
    "kharya": ['mw'],
    "kharā": ['mw'],
    "kharābdāṅkuraka": ['mw'],
    "kharāgarī": ['mw'],
    "kharāhvā": ['mw'],
    "kharājina": ['cped'],
    "kharālaka": ['mw'],
    "kharālika": ['mw'],
    "kharālikaḥ": ['ap90'],
    "kharāsyā": ['mw'],
    "kharāy": ['cae'],
    "kharāya": ['ddsa'],
    "kharāyita": ['mw'],
    "kharāśvā": ['mw'],
    "kharāṃśu": ['cae', 'mw'],
    "kharāṃśutanaya": ['mw'],
    "kharāṇḍaka": ['mw'],
    "kharī": ['ap90', 'ddsa', 'mw'],
    "kharībhū": ['mw'],
    "kharījaṅgha": ['mw'],
    "kharīkhan": ['mw'],
    "kharīviṣāṇa": ['mw'],
    "kharīvātsalya": ['mw'],
    "kharīvṛṣa": ['mw'],
    "khasa": ['cae', 'ddsa', 'mw'],
    "khasabīja": ['mw'],
    "khasagandha": ['mw'],
    "khasakanda": ['mw'],
    "khasama": ['mw'],
    "khasambhava": ['mw'],
    "khasambhavā": ['mw'],
    "khasamuttha": ['mw'],
    "khasaphalakṣīra": ['mw'],
    "khasarpaṇa": ['bhs', 'mw'],
    "khasatila": ['mw'],
    "khasatilaḥ": ['ap90'],
    "khasaḥ": ['ap90'],
    "khasindhu": ['mw'],
    "khaskhasa": ['mw'],
    "khaskhasarasa": ['mw'],
    "khaskhasasāra": ['mw'],
    "khaskhasaḥ": ['ap90'],
    "khasphaṭika": ['mw'],
    "khastanī": ['mw'],
    "khastha": ['cae', 'mw'],
    "khasā": ['mw'],
    "khasāka": ['mw'],
    "khasātmaja": ['mw'],
    "khasīka": ['mw'],
    "khasūci": ['mw'],
    "khasūciḥ": ['ap90'],
    "khasṛma": ['mw'],
    "khata": ['cped'],
    "khatamāla": ['mw'],
    "khatayati": ['bhs'],
    "khatilaka": ['mw'],
    "khatta": ['cped', 'mw'],
    "khattakhutta": ['mw'],
    "khattar": ['cped'],
    "khattavijjā": ['cped'],
    "khattavijjāsippa": ['cped'],
    "khattaṃ": ['bhs'],
    "khattiya": ['cped'],
    "khattiyakaññā": ['cped'],
    "khattiyamahāsāla": ['cped'],
    "khattiyā": ['cped'],
    "khattiyābhiseka": ['cped'],
    "khattiyānī": ['cped'],
    "khattiyī": ['cped'],
    "khav": ['ap90', 'mw'],
    "khavallī": ['mw'],
    "khavāri": ['mw'],
    "khaya": ['cped'],
    "khayita": ['cped'],
    "khayoga": ['mw'],
    "khayogadha": ['cped'],
    "khayānupassi": ['cped'],
    "khayānupassin": ['cped'],
    "khayātita": ['cped'],
    "khañj": ['cae', 'ddsa', 'mw'],
    "khañja": ['cae', 'cped', 'ddsa', 'mw'],
    "khañjabāhu": ['mw'],
    "khañjacaraṇa": ['mw'],
    "khañjaka": ['mw'],
    "khañjakhela": ['mw'],
    "khañjakheṭa": ['mw'],
    "khañjalekha": ['mw'],
    "khañjamāna": ['cped'],
    "khañjana": ['cae', 'ddsa', 'mw'],
    "khañjanaka": ['cae', 'mw'],
    "khañjanarata": ['mw'],
    "khañjanikā": ['mw'],
    "khañjanā": ['mw'],
    "khañjanākṛti": ['mw'],
    "khañjara": ['mw'],
    "khañjarīṭa": ['cae', 'ddsa', 'mw'],
    "khañjarīṭaka": ['cae', 'mw'],
    "khañjarīṭī": ['mw'],
    "khañjati": ['cped'],
    "khañjatva": ['mw'],
    "khañjatā": ['mw'],
    "khañjā": ['mw'],
    "khañjāhva": ['bhs'],
    "khañjāla": ['mw'],
    "khañjāra": ['mw'],
    "khaññati": ['cped'],
    "khaśa": ['mw'],
    "khaśabdāṅkuraja": ['mw'],
    "khaśarīra": ['mw'],
    "khaśarīrin": ['cae', 'ddsa', 'mw'],
    "khaśaya": ['mw'],
    "khaśaḥ": ['ap90'],
    "khaśera": ['mw'],
    "khaśeṭa": ['mw'],
    "khaśvāsa": ['mw'],
    "khaśīra": ['mw'],
    "khaśīraḥ": ['ap90'],
    "khaḍ": ['ap90', 'mw'],
    "khaḍa": ['cae', 'ddsa', 'mw'],
    "khaḍaka": ['mw'],
    "khaḍakkikā": ['ap90', 'mw'],
    "khaḍatū": ['mw'],
    "khaḍavat": ['mw'],
    "khaḍaḥ": ['ap90'],
    "khaḍaṇḍa": ['mw'],
    "khaḍga": ['bhs', 'cae', 'ddsa', 'mw'],
    "khaḍgabandha": ['mw'],
    "khaḍgacarmadhara": ['mw'],
    "khaḍgadhara": ['cae', 'mw'],
    "khaḍgadhenu": ['mw'],
    "khaḍgadhārā": ['mw'],
    "khaḍgadhārāvrata": ['mw'],
    "khaḍgadṛh": ['mw'],
    "khaḍgagrāhin": ['mw'],
    "khaḍgahasta": ['cae', 'mw'],
    "khaḍgahastā": ['mw'],
    "khaḍgajvalanā": ['bhs', 'mw'],
    "khaḍgaka": ['mw'],
    "khaḍgakośa": ['mw'],
    "khaḍgalatā": ['cae', 'mw'],
    "khaḍgalekhā": ['mw'],
    "khaḍgamaya": ['mw'],
    "khaḍgamaṇi": ['mw'],
    "khaḍgamālātantra": ['mw'],
    "khaḍgamāṃsa": ['mw'],
    "khaḍgapattra": ['mw'],
    "khaḍgapattravana": ['mw'],
    "khaḍgaphala": ['mw'],
    "khaḍgapidhāna": ['mw'],
    "khaḍgapidhānaka": ['mw'],
    "khaḍgaprahāra": ['cae', 'mw'],
    "khaḍgaputrikā": ['mw'],
    "khaḍgapāta": ['mw'],
    "khaḍgapātra": ['mw'],
    "khaḍgapāṇi": ['cae', 'mw'],
    "khaḍgaratna": ['mw'],
    "khaḍgaroman": ['mw'],
    "khaḍgasadman": ['mw'],
    "khaḍgasakha": ['mw'],
    "khaḍgasena": ['mw'],
    "khaḍgavat": ['ap90', 'mw'],
    "khaḍgavidyā": ['cae', 'mw'],
    "khaḍgaviṣāṇa": ['bhs', 'mw'],
    "khaḍgavāri": ['mw'],
    "khaḍgaśataka": ['mw'],
    "khaḍgaśimbī": ['mw'],
    "khaḍgaḥ": ['ap90'],
    "khaḍgaṭa": ['mw'],
    "khaḍgi": ['mw'],
    "khaḍgidhenukā": ['ddsa', 'mw'],
    "khaḍgika": ['bhs', 'mw'],
    "khaḍgikaḥ": ['ap90'],
    "khaḍgimāra": ['mw'],
    "khaḍgin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "khaḍgrāhin": ['ddsa'],
    "khaḍgābhihata": ['mw'],
    "khaḍgādhāra": ['mw'],
    "khaḍgāghāta": ['mw'],
    "khaḍgāhva": ['mw'],
    "khaḍgākhaḍgi": ['mw'],
    "khaḍgāmiṣa": ['mw'],
    "khaḍgāriṭa": ['mw'],
    "khaḍgārīṭaḥ": ['ap90'],
    "khaḍgāṅga": ['mw'],
    "khaḍgīka": ['mw'],
    "khaḍgīkaṃ": ['ap90'],
    "khaḍika": ['mw'],
    "khaḍikā": ['ap90', 'mw'],
    "khaḍonmattā": ['mw'],
    "khaḍukā": ['mw'],
    "khaḍuḥ": ['ap90'],
    "khaḍuṅka": ['bhs'],
    "khaḍī": ['mw'],
    "khaḍīna": ['mw'],
    "khaḍū": ['mw'],
    "khaḍūra": ['mw'],
    "khaḍḍukā": ['mw'],
    "khaḥ": ['ap90'],
    "khaḷopi": ['cped'],
    "khaḷuṅka": ['cped'],
    "khaṃj": ['ap90'],
    "khaṃja": ['ap90'],
    "khaṃjaka": ['ap90'],
    "khaṃjanakaḥ": ['ap90'],
    "khaṃjanaḥ": ['ap90'],
    "khaṃjarīṭaḥ": ['ap90'],
    "khaṃkara": ['mw'],
    "khaṃkaraḥ": ['ap90'],
    "khaṃḍ": ['ap90'],
    "khaṃḍa": ['ap90'],
    "khaṃḍaka": ['ap90'],
    "khaṃḍalaḥ": ['ap90'],
    "khaṃḍana": ['ap90'],
    "khaṃḍanīya": ['ap90'],
    "khaṃḍaśas": ['ap90'],
    "khaṃḍikaḥ": ['ap90'],
    "khaṃḍin": ['ap90'],
    "khaṃḍita": ['ap90'],
    "khaṃḍya": ['ap90'],
    "khaṃḍīkṛ": ['ap90'],
    "khaṅga": ['mw'],
    "khaṅgāha": ['mw'],
    "khaṅgāmiṣa": ['ddsa'],
    "khaṅkha": ['ddsa', 'mw'],
    "khaṅkhara": ['bhs', 'mw'],
    "khaṅkharaka": ['bhs'],
    "khaṅkhaṇa": ['cae', 'mw'],
    "khaṅkhaṇā": ['mw'],
    "khaṅkhaṭa": ['bhs'],
    "khaṅkhaṭika": ['bhs'],
    "khaṇa": ['cped', 'mw'],
    "khaṇakhaṇāya": ['ddsa', 'mw'],
    "khaṇakhaṇāyate": ['ap90'],
    "khaṇakhaṇāyita": ['mw'],
    "khaṇakicca": ['cped'],
    "khaṇanta": ['cped'],
    "khaṇapita": ['bhs'],
    "khaṇati": ['cped'],
    "khaṇatkhaṇīkṛta": ['mw'],
    "khaṇaññu": ['cped'],
    "khaṇe khaṇe": ['cped'],
    "khaṇena": ['cped'],
    "khaṇi": ['cped'],
    "khaṇimsu": ['cped'],
    "khaṇita": ['cped'],
    "khaṇittī": ['cped'],
    "khaṇitvā": ['cped'],
    "khaṇvakhā": ['mw'],
    "khaṇāpeti": ['cped'],
    "khaṇātīta": ['cped'],
    "khaṇḍ": ['mw'],
    "khaṇḍa": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "khaṇḍadanta": ['cped'],
    "khaṇḍadeva": ['mw'],
    "khaṇḍadhārā": ['cae', 'mw'],
    "khaṇḍadravya": ['mw'],
    "khaṇḍagiri": ['mw'],
    "khaṇḍaja": ['mw'],
    "khaṇḍaka": ['bhs', 'cae', 'mw'],
    "khaṇḍakanda": ['mw'],
    "khaṇḍakathā": ['mw'],
    "khaṇḍakhaṇḍam": ['bhs'],
    "khaṇḍakhaṇḍā": ['mw'],
    "khaṇḍakhaṇḍīkṛta": ['bhs'],
    "khaṇḍakhādya": ['mw'],
    "khaṇḍakhādyakaraṇa": ['mw'],
    "khaṇḍakhāḍaka": ['mw'],
    "khaṇḍakhāṭṭaka": ['mw'],
    "khaṇḍakuṣmāṇḍaka": ['mw'],
    "khaṇḍakālu": ['mw'],
    "khaṇḍakāluka": ['mw'],
    "khaṇḍakāpālika": ['mw'],
    "khaṇḍakāra": ['mw'],
    "khaṇḍakāraka": ['bhs'],
    "khaṇḍakāri": ['cped'],
    "khaṇḍakārin": ['cped'],
    "khaṇḍakāvya": ['mw'],
    "khaṇḍala": ['mw'],
    "khaṇḍalavaṇa": ['mw'],
    "khaṇḍalekhaka": ['mw'],
    "khaṇḍamallaka": ['bhs'],
    "khaṇḍamaya": ['mw'],
    "khaṇḍamaṇḍala": ['mw'],
    "khaṇḍamodaka": ['cae', 'ddsa', 'mw'],
    "khaṇḍamātrā": ['mw'],
    "khaṇḍana": ['cae', 'ddsa', 'mw'],
    "khaṇḍanakhaṇḍakhādya": ['mw'],
    "khaṇḍanakāra": ['mw'],
    "khaṇḍanakṛt": ['mw'],
    "khaṇḍanarata": ['mw'],
    "khaṇḍanimitta": ['cped'],
    "khaṇḍanā": ['mw'],
    "khaṇḍanīya": ['mw'],
    "khaṇḍaparaśu": ['mw'],
    "khaṇḍaparśu": ['mw'],
    "khaṇḍapattra": ['mw'],
    "khaṇḍaphaṇa": ['mw'],
    "khaṇḍaphulla": ['cped'],
    "khaṇḍapralaya": ['mw'],
    "khaṇḍaprastāra": ['mw'],
    "khaṇḍapraśasti": ['mw'],
    "khaṇḍapāka": ['mw'],
    "khaṇḍapāla": ['mw'],
    "khaṇḍapāṇi": ['mw'],
    "khaṇḍara": ['bhs', 'mw'],
    "khaṇḍarakṣa": ['mw'],
    "khaṇḍarasa": ['mw'],
    "khaṇḍarohā": ['bhs'],
    "khaṇḍasaṃsthāpaka": ['mw'],
    "khaṇḍasphuṭapratisaṃskaraṇa": ['mw'],
    "khaṇḍasāra": ['mw'],
    "khaṇḍatā": ['mw'],
    "khaṇḍatāla": ['mw'],
    "khaṇḍava": ['mw'],
    "khaṇḍavaṭaka": ['ddsa', 'mw'],
    "khaṇḍavikṛti": ['mw'],
    "khaṇḍay": ['cae'],
    "khaṇḍaya": ['ddsa'],
    "khaṇḍaśarkarā": ['mw'],
    "khaṇḍaśas": ['cae', 'ddsa', 'mw'],
    "khaṇḍaśaḥkṛ": ['mw'],
    "khaṇḍaśobhū": ['mw'],
    "khaṇḍaśogam": ['mw'],
    "khaṇḍaśoyā": ['mw'],
    "khaṇḍaśākhā": ['mw'],
    "khaṇḍaśīlā": ['mw'],
    "khaṇḍendu": ['mw'],
    "khaṇḍendumaṇḍana": ['ddsa', 'mw'],
    "khaṇḍerāya": ['mw'],
    "khaṇḍicca": ['cped'],
    "khaṇḍika": ['mw'],
    "khaṇḍikopādhyāya": ['mw'],
    "khaṇḍikā": ['bhs', 'mw'],
    "khaṇḍila": ['mw'],
    "khaṇḍiman": ['mw'],
    "khaṇḍin": ['mw'],
    "khaṇḍinī": ['mw'],
    "khaṇḍita": ['cped', 'mw'],
    "khaṇḍitavigraha": ['mw'],
    "khaṇḍitavṛtta": ['cae', 'ddsa', 'mw'],
    "khaṇḍitā": ['mw'],
    "khaṇḍitāśaṃsa": ['mw'],
    "khaṇḍodbhava": ['mw'],
    "khaṇḍodbhūta": ['mw'],
    "khaṇḍoṣṭha": ['mw'],
    "khaṇḍu": ['mw'],
    "khaṇḍya": ['mw'],
    "khaṇḍābhra": ['mw'],
    "khaṇḍākhaṇḍika": ['cped'],
    "khaṇḍākhaṇḍikaṁ": ['cped'],
    "khaṇḍālī": ['mw'],
    "khaṇḍāmalaka": ['mw'],
    "khaṇḍāmra": ['mw'],
    "khaṇḍīka": ['mw'],
    "khaṇḍīkṛ": ['mw'],
    "khaṇḍīra": ['mw'],
    "khaṇḍīya": ['mw'],
    "khaṣ": ['ap90', 'mw'],
    "khaṣa": ['bhs'],
    "khaṣpa": ['mw'],
    "khaṣpaḥ": ['ap90'],
    "khaṭ": ['ap90', 'mw'],
    "khaṭa": ['bhs', 'mw'],
    "khaṭaka": ['bhs', 'mw'],
    "khaṭakaḥ": ['ap90'],
    "khaṭakaṭāhaka": ['mw'],
    "khaṭakhaṭasadda": ['cped'],
    "khaṭakhaṭāy": ['cae'],
    "khaṭakhaṭāya": ['ddsa', 'mw'],
    "khaṭakhādaka": ['mw'],
    "khaṭakkikā": ['ap90', 'mw'],
    "khaṭakā": ['bhs', 'mw'],
    "khaṭakāmukha": ['mw'],
    "khaṭakāmukhaṃ": ['ap90'],
    "khaṭakāsya": ['mw'],
    "khaṭakāvardhamāna": ['mw'],
    "khaṭaḥ": ['ap90'],
    "khaṭika": ['mw'],
    "khaṭikaḥ": ['ap90'],
    "khaṭikā": ['cae', 'ddsa', 'mw'],
    "khaṭinī": ['ap90', 'cae', 'mw'],
    "khaṭopikā": ['cped'],
    "khaṭu": ['bhs', 'mw'],
    "khaṭuka": ['bhs'],
    "khaṭukī": ['mw'],
    "khaṭvakā": ['mw'],
    "khaṭvara": ['mw'],
    "khaṭvaya": ['ddsa', 'mw'],
    "khaṭvayati": ['ap90'],
    "khaṭvikā": ['mw'],
    "khaṭvā": ['ap90', 'cae', 'ddsa', 'mw'],
    "khaṭvābhāra": ['mw'],
    "khaṭvākā": ['ap90', 'mw'],
    "khaṭvāpluta": ['mw'],
    "khaṭvārūḍha": ['mw'],
    "khaṭvātala": ['cae', 'ddsa'],
    "khaṭvātale": ['mw'],
    "khaṭvāṅga": ['cae', 'ddsa', 'mw'],
    "khaṭvāṅgabhṛt": ['cae', 'mw'],
    "khaṭvāṅgadhara": ['cae', 'mw'],
    "khaṭvāṅgadhāra": ['cae', 'mw'],
    "khaṭvāṅgaghaṇṭā": ['mw'],
    "khaṭvāṅgahasta": ['mw'],
    "khaṭvāṅgaka": ['mw'],
    "khaṭvāṅganāmikā": ['mw'],
    "khaṭvāṅgavana": ['mw'],
    "khaṭvāṅgaśūlin": ['mw'],
    "khaṭvāṅgin": ['cae', 'ddsa', 'mw'],
    "khaṭvāṅgī": ['mw'],
    "khaṭvīya": ['mw'],
    "khaṭya": ['mw'],
    "khaṭī": ['mw'],
    "khaṭū": ['mw'],
    "khaṭṭ": ['ap90', 'mw'],
    "khaṭṭa": ['mw'],
    "khaṭṭana": ['ap90', 'mw'],
    "khaṭṭeraka": ['ap90', 'mw'],
    "khaṭṭi": ['mw'],
    "khaṭṭika": ['bhs', 'mw'],
    "khaṭṭikaḥ": ['ap90'],
    "khaṭṭikā": ['mw'],
    "khaṭṭikī": ['mw'],
    "khaṭṭiḥ": ['ap90'],
    "khaṭṭā": ['ap90', 'mw'],
    "khaṭṭāsa": ['mw'],
    "khaṭṭāśa": ['mw'],
    "khaṭṭāśaḥ": ['ap90'],
    "khaṭṭāśī": ['mw'],
    "khaṭṭāṅga": ['mw'],
    "khe": ['mw'],
    "khecara": ['ap90', 'cae', 'ddsa', 'mw'],
    "khecaratva": ['mw'],
    "khecaratā": ['mw'],
    "khecarā": ['mw'],
    "khecarānna": ['mw'],
    "khecarāñjana": ['mw'],
    "khecarī": ['mw'],
    "kheda": ['cae', 'ddsa', 'mw'],
    "khedana": ['cae', 'mw'],
    "khedanaṃ": ['ap90'],
    "khedanā": ['bhs'],
    "khedatā": ['bhs'],
    "khedavigama": ['mw'],
    "khedayitavya": ['cae', 'mw'],
    "khedaḥ": ['ap90'],
    "khedi": ['mw'],
    "khedin": ['ap90', 'cae', 'mw'],
    "khedinī": ['mw'],
    "khedita": ['ap90', 'mw'],
    "kheditavya": ['mw'],
    "khedā": ['gra', 'mw'],
    "khedānvita": ['mw'],
    "khedāṅgasāra": ['mw'],
    "khegamana": ['mw'],
    "kheja": ['bhs'],
    "khekhīraka": ['mw'],
    "khel": ['ap90', 'cae', 'ddsa', 'mw'],
    "khela": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "khelagamana": ['cae', 'mw'],
    "khelagati": ['mw'],
    "khelagāmin": ['mw'],
    "khelam": ['mw'],
    "khelana": ['cae', 'mw'],
    "khelanaka": ['cae', 'mw'],
    "khelanaṃ": ['ap90'],
    "khelanā": ['mw'],
    "khelanī": ['mw'],
    "khelata": ['bhs'],
    "kheli": ['cae', 'mw'],
    "kheliḥ": ['ap90'],
    "khelu": ['bhs'],
    "kheluda": ['bhs', 'mw'],
    "kheludu": ['bhs'],
    "kheluka": ['bhs'],
    "khelā": ['mw'],
    "khelāya": ['mw'],
    "khema": ['cped'],
    "khemadassi": ['cped'],
    "khemadassin": ['cped'],
    "khemakarṇa": ['mw'],
    "khemantabhūmi": ['cped'],
    "khemasiṃha": ['mw'],
    "khematta": ['cped'],
    "khematā": ['cped'],
    "khemi": ['cped'],
    "khemin": ['cped'],
    "kheparibhrama": ['mw'],
    "khepetvā": ['cped'],
    "khepita": ['cped'],
    "khesara": ['mw'],
    "khesaraḥ": ['ap90'],
    "khetasiṃha": ['mw'],
    "khetta": ['cped'],
    "khettajina": ['cped'],
    "khettapāla": ['cped'],
    "khettaññu": ['cped'],
    "khev": ['ap90', 'mw'],
    "kheya": ['ap90', 'ddsa', 'mw'],
    "kheśaya": ['mw'],
    "kheḍ": ['mw'],
    "kheḍa": ['mw'],
    "kheḍitāla": ['mw'],
    "kheḷa": ['cped'],
    "kheḷamallaka": ['cped'],
    "kheḷāsaka": ['cped'],
    "kheḷāsika": ['cped'],
    "kheṭ": ['ap90', 'mw'],
    "kheṭa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kheṭabhūṣaṇa": ['mw'],
    "kheṭabodha": ['mw'],
    "kheṭaka": ['mw'],
    "kheṭakapura": ['mw'],
    "kheṭakarman": ['mw'],
    "kheṭakaḥ": ['ap90'],
    "kheṭana": ['mw'],
    "kheṭapiṇḍa": ['mw'],
    "kheṭapīṭhamālā": ['mw'],
    "kheṭika": ['mw'],
    "kheṭin": ['ap90', 'mw'],
    "kheṭita": ['ap90', 'mw'],
    "kheṭitāla": ['mw'],
    "kheṭitānaḥ": ['ap90'],
    "khicci": ['mw'],
    "khiccā": ['mw'],
    "khiccī": ['mw'],
    "khid": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "khidira": ['mw'],
    "khidiraḥ": ['ap90'],
    "khidra": ['cae', 'ddsa', 'gra', 'mw'],
    "khidraḥ": ['ap90'],
    "khidvas": ['gra', 'mw'],
    "khidvaṃs": ['cae'],
    "khijjati": ['bhs'],
    "khikhi": ['mw'],
    "khikhiḥ": ['ap90'],
    "khikkhimin": ['mw'],
    "khikkhira": ['bhs'],
    "khikkhirika": ['bhs'],
    "khila": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "khilagrantha": ['mw'],
    "khilajāta": ['cped'],
    "khilakāṇḍa": ['mw'],
    "khilakṣetra": ['ddsa', 'mw'],
    "khilapāṭha": ['mw'],
    "khilaḥ": ['ap90'],
    "khilya": ['cae', 'ddsa', 'gra', 'mw'],
    "khilyaḥ": ['ap90'],
    "khilī": ['mw'],
    "khilībhūta": ['mw'],
    "khilīkṛ": ['cae', 'ddsa', 'mw'],
    "khilīkṛta": ['mw'],
    "khimiḍī": ['mw'],
    "khindaka": ['mw'],
    "khindhi": ['mw'],
    "khindhika": ['mw'],
    "khinna": ['ap90', 'cae', 'mw'],
    "khinnamānasa": ['mw'],
    "khipa": ['cped'],
    "khipati": ['cped'],
    "khipi": ['cped'],
    "khipita": ['cped'],
    "khipitabba": ['cped'],
    "khipitasadda": ['cped'],
    "khippa": ['cped'],
    "khippamāna": ['cped'],
    "khippanisanti": ['cped'],
    "khippanisantin": ['cped'],
    "khippatara": ['cped'],
    "khippataraṁ": ['cped'],
    "khippaṁ": ['cped'],
    "khippābhiña": ['cped'],
    "khirahiṭṭī": ['mw'],
    "khitta": ['cped'],
    "khittacitta": ['cped'],
    "khiyyanaka": ['cped'],
    "khiyyati": ['cped'],
    "khiḍga": ['mw'],
    "khiḍḍā": ['cped'],
    "khiḍḍāpadosika": ['cped'],
    "khiḍḍāpadūsika": ['cped'],
    "khiṃkhiraḥ": ['ap90'],
    "khiṅkhira": ['mw'],
    "khiṅkhirī": ['mw'],
    "khiṭ": ['ap90', 'mw'],
    "kho": ['bhs', 'cped'],
    "khobhayati": ['cped'],
    "khobheti": ['cped'],
    "khodaka": ['bhs'],
    "khol": ['mw'],
    "khola": ['ap90', 'ddsa', 'mw'],
    "kholaka": ['bhs', 'mw'],
    "kholakaḥ": ['ap90'],
    "kholaśiras": ['mw'],
    "kholaḥ": ['ap90'],
    "kholi": ['mw'],
    "kholiḥ": ['ap90'],
    "kholka": ['mw'],
    "kholmuka": ['mw'],
    "kholā": ['bhs'],
    "khoma": ['cped'],
    "khomasukhuma": ['cped'],
    "khonamukha": ['mw'],
    "khor": ['mw'],
    "khora": ['ap90', 'bhs', 'cae', 'mw'],
    "khoraka": ['mw'],
    "khorakā": ['bhs'],
    "khori": ['mw'],
    "khorī": ['mw'],
    "khosayati": ['bhs'],
    "khoḍ": ['mw'],
    "khoḍa": ['ap90', 'bhs', 'mw'],
    "khoḍaka": ['bhs'],
    "khoḍakaśīrṣaka": ['mw'],
    "khoṃgāhaḥ": ['ap90'],
    "khoṅgāha": ['mw'],
    "khoṣaḍaha": ['mw'],
    "khoṭ": ['ap90', 'mw'],
    "khoṭa": ['cae', 'ddsa', 'mw'],
    "khoṭaka": ['bhs'],
    "khoṭana": ['bhs', 'mw'],
    "khoṭi": ['mw'],
    "khoṭiḥ": ['ap90'],
    "khoṭī": ['mw'],
    "khu": ['ap90', 'bhs', 'cped', 'mw'],
    "khud": ['cae', 'ddsa', 'gra', 'mw'],
    "khudda": ['cped'],
    "khuddaka": ['cped'],
    "khuddakanagaraka": ['cped'],
    "khuddakavatthuka": ['cped'],
    "khuddalaka": ['bhs'],
    "khuddamadhu": ['cped'],
    "khuddarāja": ['cped'],
    "khuddarājan": ['cped'],
    "khuddānukhuddaka": ['cped'],
    "khudrāka": ['bhs'],
    "khudā": ['cped'],
    "khuj": ['ap90', 'mw'],
    "khujja": ['cped'],
    "khujjaka": ['cped'],
    "khujjāka": ['mw'],
    "khulaka": ['mw'],
    "khulla": ['ap90', 'mw'],
    "khullaka": ['mw'],
    "khullama": ['mw'],
    "khullamaḥ": ['ap90'],
    "khullatāta": ['mw'],
    "khulukhulukārakaṁ": ['cped'],
    "khum": ['mw'],
    "khun": ['mw'],
    "khunamukha": ['mw'],
    "khunamuṣa": ['ddsa'],
    "khur": ['ap90', 'mw'],
    "khura": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "khurabhaṇḍa": ['cped'],
    "khuradhāra": ['cped'],
    "khuraka": ['cae', 'ddsa', 'mw'],
    "khurakhura": ['bhs', 'mw'],
    "khurakhurāyate": ['bhs'],
    "khurakāsa": ['cped'],
    "khurakṣepa": ['mw'],
    "khuralī": ['ap90', 'mw'],
    "khuramuṇḍa": ['cped'],
    "khuramālin": ['bhs', 'mw'],
    "khuranyāsa": ['mw'],
    "khurapadavī": ['mw'],
    "khurapariyanta": ['cped'],
    "khurappa": ['cped'],
    "khurapra": ['mw'],
    "khurapravāra": ['bhs'],
    "khurasilā": ['cped'],
    "khurasipāṭikā": ['cped'],
    "khuratrāṇa": ['mw'],
    "khuraḥ": ['ap90'],
    "khuraṇas": ['mw'],
    "khuraṇasa": ['mw'],
    "khurd": ['ap90', 'mw'],
    "khurdati": ['bhs'],
    "khurin": ['cae', 'ddsa', 'mw'],
    "khurukhura": ['bhs'],
    "khurukhurāya": ['mw'],
    "khurābhighāta": ['mw'],
    "khurāghāta": ['mw'],
    "khurāgra": ['mw'],
    "khurāka": ['mw'],
    "khurākaḥ": ['ap90'],
    "khurālaka": ['mw'],
    "khurālakaḥ": ['ap90'],
    "khurālika": ['mw'],
    "khurālikaḥ": ['ap90'],
    "khurāsāna": ['mw'],
    "khurāsāṇa": ['mw'],
    "khurī": ['mw'],
    "khussa": ['bhs'],
    "khusta": ['bhs'],
    "khuttaṃ": ['bhs'],
    "khuḍ": ['ap90', 'mw'],
    "khuḍa": ['mw'],
    "khuḍaka": ['mw'],
    "khuḍakaḥ": ['ap90'],
    "khuḍavāta": ['mw'],
    "khuḍula": ['mw'],
    "khuḍḍaka": ['bhs', 'mw'],
    "khuḍḍulaka": ['bhs'],
    "khuḍḍāka": ['bhs', 'mw'],
    "khuḍḍīka": ['bhs'],
    "khuṁsana": ['cped'],
    "khuṁsayati": ['cped'],
    "khuṁsenta": ['cped'],
    "khuṁsesi": ['cped'],
    "khuṁseti": ['cped'],
    "khuṃgāhaḥ": ['ap90'],
    "khuṃḍ": ['ap90'],
    "khuṅgāha": ['mw'],
    "khuṅkhuṇī": ['mw'],
    "khuṇḍ": ['mw'],
    "khuṭkhuṭā": ['bhs'],
    "khyan": ['ddsa'],
    "khyā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "khyāna": ['cae', 'ddsa', 'mw'],
    "khyāpaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "khyāpana": ['cae', 'ddsa', 'mw'],
    "khyāpanaṃ": ['ap90'],
    "khyāpanīya": ['mw'],
    "khyāpin": ['cae', 'ddsa', 'mw'],
    "khyāpita": ['mw'],
    "khyāpya": ['cae', 'mw'],
    "khyāta": ['ap90', 'cae', 'mw'],
    "khyātagarhaṇa": ['mw'],
    "khyātagarhita": ['mw'],
    "khyātakīrti": ['cae', 'ddsa'],
    "khyātaviruddhatā": ['mw'],
    "khyātavya": ['ap90', 'mw'],
    "khyāti": ['cae', 'ddsa', 'mw'],
    "khyātibodha": ['mw'],
    "khyātighna": ['mw'],
    "khyātijanaka": ['mw'],
    "khyātikara": ['mw'],
    "khyātimat": ['mw'],
    "khyātivijñāna": ['bhs'],
    "khyātiviruddhatā": ['mw'],
    "khyātiḥ": ['ap90'],
    "khā": ['ddsa', 'gra', 'mw'],
    "khād": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "khāda": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "khādagdat": ['mw'],
    "khādaka": ['ap90', 'cae', 'mw'],
    "khādamāna": ['cped'],
    "khādana": ['cae', 'cped', 'mw'],
    "khādanaḥ": ['ap90'],
    "khādanikā": ['bhs'],
    "khādanta": ['cped'],
    "khādanā": ['mw'],
    "khādanīya": ['bhs', 'cae', 'cped', 'mw'],
    "khādas": ['mw'],
    "khādasarṇas": ['gra'],
    "khādat": ['cped'],
    "khādata": ['mw'],
    "khādatamodatā": ['ap90', 'mw'],
    "khādatavamatā": ['mw'],
    "khādati": ['bhs', 'cped'],
    "khādatācamatā": ['mw'],
    "khādayati": ['cped'],
    "khādhvanīna": ['mw'],
    "khādhūyā": ['ddsa', 'mw'],
    "khādi": ['cae', 'cped', 'gra', 'mw'],
    "khādihasta": ['cae', 'gra', 'mw'],
    "khādikā": ['mw'],
    "khādin": ['cae', 'gra', 'mw'],
    "khādira": ['ap90', 'cae', 'ddsa', 'mw'],
    "khādiragṛhya": ['mw'],
    "khādiraka": ['mw'],
    "khādirasāra": ['mw'],
    "khādireya": ['mw'],
    "khādirāyaṇa": ['mw'],
    "khādirī": ['mw'],
    "khādita": ['cped', 'mw'],
    "khāditabba": ['cped'],
    "khāditaka": ['bhs'],
    "khāditavat": ['mw'],
    "khāditavya": ['cae', 'mw'],
    "khāditvā": ['cped'],
    "khāditṛ": ['cae', 'mw'],
    "khādiḥ": ['ap90'],
    "khādiṁsu": ['cped'],
    "khādoarṇa": ['mw'],
    "khādoarṇas": ['gra', 'mw'],
    "khāduka": ['ap90', 'mw'],
    "khādukatā": ['bhs'],
    "khādya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "khādyaka": ['bhs', 'mw'],
    "khādyakacāraka": ['bhs'],
    "khādyākhādya": ['mw'],
    "khādākya": ['mw'],
    "khādāpenta": ['cped'],
    "khādāpeti": ['cped'],
    "khādūraka": ['mw'],
    "khāgi": ['ddsa', 'mw'],
    "khāgikā": ['mw'],
    "khājika": ['mw'],
    "khājikaḥ": ['ap90'],
    "khākhasa": ['cae', 'mw'],
    "khākhasatila": ['mw'],
    "khālatya": ['cae', 'ddsa', 'mw'],
    "khālatyaṃ": ['ap90'],
    "khālika": ['ap90', 'mw'],
    "khālitya": ['cae', 'mw'],
    "khālyakāyani": ['mw'],
    "khālīya": ['mw'],
    "khāna": ['cae', 'ddsa', 'mw'],
    "khānaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "khānakhāna": ['mw'],
    "khānam": ['mw'],
    "khānaṃ": ['ap90'],
    "khāni": ['cae', 'ddsa', 'mw'],
    "khānika": ['mw'],
    "khānikaḥ": ['ap90'],
    "khānikā": ['mw'],
    "khānila": ['mw'],
    "khānilaḥ": ['ap90'],
    "khānina": ['mw'],
    "khāniḥ": ['ap90'],
    "khāniṣka": ['mw'],
    "khāniṣṭa": ['mw'],
    "khānodaka": ['mw'],
    "khāntasamācāra": ['bhs'],
    "khānu": ['cped'],
    "khānula": ['mw'],
    "khānya": ['mw'],
    "khānārāya": ['mw'],
    "khāpagā": ['mw'],
    "khāpara": ['mw'],
    "khāra": ['cae', 'cped', 'ddsa', 'mw'],
    "khāragrīvi": ['mw'],
    "khāraka": ['bhs'],
    "khāranādi": ['bhs', 'mw'],
    "khārapāyaṇa": ['mw'],
    "khārasahasrika": ['mw'],
    "khāraśatika": ['mw'],
    "khāraḥ": ['ap90'],
    "khārdabhīmukha": ['mw'],
    "khārdamāyana": ['mw'],
    "khārgali": ['mw'],
    "khāri": ['mw'],
    "khāribhāra": ['cped'],
    "khārigrīvi": ['mw'],
    "khārika": ['ap90', 'cped', 'mw'],
    "khārikā": ['mw'],
    "khārikāja": ['cped'],
    "khārividha": ['cped'],
    "khārivivadha": ['cped'],
    "khārivividha": ['cped'],
    "khāriya": ['cped'],
    "khāriṃ": ['mw'],
    "khāriṃdhama": ['mw'],
    "khāriṃdhaya": ['mw'],
    "khāriṃpaca": ['ap90', 'mw'],
    "khārjurakarṇa": ['mw'],
    "khārjūlāyana": ['mw'],
    "khārjūra": ['mw'],
    "khārjūrakarṇa": ['mw'],
    "khārjūrāyaṇa": ['mw'],
    "khārkhoṭa": ['mw'],
    "khārkāra": ['mw'],
    "khārkāraḥ": ['ap90'],
    "khārvā": ['ap90', 'cae', 'ddsa', 'mw'],
    "khārāpatacchika": ['cped'],
    "khārī": ['gra', 'mw'],
    "khārījaṅgha": ['mw'],
    "khārīka": ['ap90', 'mw'],
    "khārīkhaṇa": ['mw'],
    "khārīvāpa": ['mw'],
    "khāsatā": ['mw'],
    "khāsyalipi": ['mw'],
    "khāt": ['ap90', 'cae', 'mw'],
    "khāta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "khātabhū": ['mw'],
    "khātaka": ['mw'],
    "khātakaḥ": ['ap90'],
    "khātamūla": ['mw'],
    "khātana": ['mw'],
    "khātarūpakāra": ['bhs', 'mw'],
    "khāti": ['mw'],
    "khātikā": ['mw'],
    "khātiḥ": ['ap90'],
    "khātman": ['mw'],
    "khātra": ['cae', 'mw'],
    "khātrakhanana": ['mw'],
    "khātraṃ": ['ap90'],
    "khātā": ['mw'],
    "khātṛ": ['cae', 'mw'],
    "khāyati": ['bhs', 'cped'],
    "khāyita": ['cped'],
    "khāyitabba": ['cped'],
    "khāñjya": ['cae', 'ddsa', 'mw'],
    "khāñjāla": ['mw'],
    "khāñjāra": ['mw'],
    "khāñjārāyana": ['mw'],
    "khāśi": ['mw'],
    "khāśika": ['mw'],
    "khāśmarī": ['mw'],
    "khāśīra": ['mw'],
    "khā˚": ['ddsa'],
    "khāḍa": ['bhs'],
    "khāḍava": ['mw'],
    "khāḍaṇḍaka": ['mw'],
    "khāḍga": ['ap90', 'mw'],
    "khāḍgika": ['mw'],
    "khāḍika": ['mw'],
    "khāḍiki": ['mw'],
    "khāḍonmatteya": ['mw'],
    "khāḍāyana": ['mw'],
    "khāḍāyanabhakta": ['mw'],
    "khāḍāyanaka": ['mw'],
    "khāḍāyanin": ['mw'],
    "khāḍāyanīya": ['mw'],
    "khāḍī": ['mw'],
    "khāḍūreya": ['mw'],
    "khāṃḍavaḥ": ['ap90'],
    "khāṃḍavikaḥ": ['ap90'],
    "khāṃḍaṃ": ['ap90'],
    "khāṅka": ['mw'],
    "khāṇu": ['bhs', 'cped'],
    "khāṇḍa": ['bhs', 'mw'],
    "khāṇḍaka": ['mw'],
    "khāṇḍaparaśava": ['mw'],
    "khāṇḍava": ['cae', 'ddsa', 'mw'],
    "khāṇḍavaka": ['mw'],
    "khāṇḍavaprastha": ['mw'],
    "khāṇḍavarāga": ['mw'],
    "khāṇḍavika": ['mw'],
    "khāṇḍavāyana": ['mw'],
    "khāṇḍavī": ['mw'],
    "khāṇḍavīraṇa": ['mw'],
    "khāṇḍavīraṇaka": ['mw'],
    "khāṇḍika": ['mw'],
    "khāṇḍikeya": ['mw'],
    "khāṇḍikya": ['mw'],
    "khāṇḍikyajanaka": ['mw'],
    "khāṇḍikīya": ['mw'],
    "khāṇḍiti": ['mw'],
    "khāṇḍitya": ['mw'],
    "khāṇḍāyana": ['mw'],
    "khāṣya": ['bhs'],
    "khāṭ": ['ap90', 'mw'],
    "khāṭa": ['mw'],
    "khāṭaḥ": ['ap90'],
    "khāṭi": ['mw'],
    "khāṭikā": ['mw'],
    "khāṭiḥ": ['ap90'],
    "khāṭkṛ": ['cae', 'mw'],
    "khāṭvareya": ['mw'],
    "khāṭvika": ['mw'],
    "khāṭvābhārika": ['mw'],
    "khāṭā": ['mw'],
    "khāṭī": ['mw'],
    "khīla": ['cae', 'cped', 'mw'],
    "khīlaka": ['cped'],
    "khīlaṭṭhāyiṭhita": ['cped'],
    "khīra": ['cped', 'ddsa', 'mw'],
    "khīramatta": ['cped'],
    "khīranika": ['cped'],
    "khīrapaka": ['cped'],
    "khīrapaṇṇi": ['cped'],
    "khīrapaṇṇin": ['cped'],
    "khīrarukkha": ['cped'],
    "khīrodakībhūta": ['cped'],
    "khīrūpaka": ['cped'],
    "khīya": ['cped'],
    "khīyadhamma": ['cped'],
    "khīyanadhamma": ['cped'],
    "khīyanaka": ['cped'],
    "khīyanta": ['cped'],
    "khīyati": ['cped'],
    "khīyi": ['cped'],
    "khīyita": ['cped'],
    "khīyittha": ['cped'],
    "khīṇa": ['cped'],
    "khīṇabīja": ['cped'],
    "khīṇakolañña": ['cped'],
    "khīṇakulīna": ['cped'],
    "khīṇavyappatha": ['cped'],
    "khīṇaṁ": ['cped'],
    "khīṇāsava": ['cped'],
    "khūra": ['ddsa'],
    "khūrd": ['ap90', 'mw'],
    "khṛgala": ['cae', 'gra', 'mw'],
    "ki": ['cae', 'ddsa', 'gra', 'mw'],
    "kibbisa": ['cped'],
    "kibbisakāri": ['cped'],
    "kibbisakārin": ['cped'],
    "kibbisi": ['cped'],
    "kibbisin": ['cped'],
    "kicca": ['cped'],
    "kiccakara": ['cped'],
    "kiccakaraṇīya": ['cped'],
    "kiccakāri": ['cped'],
    "kiccakārin": ['cped'],
    "kiccayatā": ['cped'],
    "kiccha": ['cped'],
    "kicchalābhi": ['cped'],
    "kicchalābhin": ['cped'],
    "kicchanta": ['cped'],
    "kicchati": ['cped'],
    "kicchena": ['cped'],
    "kicchā": ['cped'],
    "kiccādhikaraṇa": ['cped'],
    "kiccākiccāni": ['cped'],
    "kidarbha": ['mw'],
    "kidvat": ['ddsa'],
    "kikhi": ['mw'],
    "kikhiḥ": ['ap90'],
    "kiki": ['mw'],
    "kikidiva": ['mw'],
    "kikidivi": ['mw'],
    "kikidīvi": ['cae', 'gra', 'mw'],
    "kikin": ['mw'],
    "kikirā": ['gra', 'mw'],
    "kikita": ['cped'],
    "kikivi": ['mw'],
    "kikiḥ": ['ap90'],
    "kikiṭa": ['cped'],
    "kikkisa": ['mw'],
    "kikkisāda": ['mw'],
    "kikkiśa": ['mw'],
    "kikkiśaḥ": ['ap90'],
    "kikkiṭā": ['mw'],
    "kikkiṭākāram": ['mw'],
    "kiknasa": ['ddsa', 'mw'],
    "kikviśa": ['mw'],
    "kikī": ['mw'],
    "kikīdiva": ['mw'],
    "kikīdivi": ['mw'],
    "kikīdīvi": ['mw'],
    "kil": ['ap90', 'mw'],
    "kila": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kilakila": ['cae', 'mw'],
    "kilakilaḥ": ['ap90'],
    "kilakilā": ['mw'],
    "kilakilāya": ['mw'],
    "kilakilāyati": ['ap90'],
    "kilakiñcita": ['mw'],
    "kilama": ['cped'],
    "kilamat": ['cped'],
    "kilamatha": ['bhs', 'cped'],
    "kilamati": ['bhs', 'cped'],
    "kilamaya": ['cped'],
    "kilamayat": ['cped'],
    "kilamayati": ['cped'],
    "kilameti": ['cped'],
    "kilammati": ['cped'],
    "kilanta": ['cped'],
    "kilantarūpa": ['cped'],
    "kilañja": ['cae', 'cped', 'ddsa', 'mw'],
    "kilañjachatta": ['cped'],
    "kilañjaka": ['bhs'],
    "kilaḥ": ['ap90'],
    "kilbiṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "kilbiṣaspṛt": ['cae', 'gra', 'mw'],
    "kilbiṣin": ['mw'],
    "kilbiṣī": ['mw'],
    "kilesa": ['cped'],
    "kileseti": ['cped'],
    "kileśa": ['bhs'],
    "kilijjati": ['cped'],
    "kilijjittha": ['cped'],
    "kilikila": ['bhs', 'mw'],
    "kilikilaya": ['mw'],
    "kilikilita": ['mw'],
    "kilikilā": ['mw'],
    "kilikilāya": ['mw'],
    "kilikīlate": ['bhs'],
    "kilima": ['mw'],
    "kilimaṃ": ['ap90'],
    "kilina": ['mw'],
    "kilinna": ['cped'],
    "kilisati": ['cped'],
    "kilisnāti": ['cped'],
    "kilissamāna": ['cped'],
    "kilissati": ['cped'],
    "kiliñca": ['mw'],
    "kiliñcana": ['mw'],
    "kiliñja": ['cae', 'ddsa', 'mw'],
    "kiliñjahastin": ['mw'],
    "kiliñjaka": ['mw'],
    "kiliṃjakaḥ": ['ap90'],
    "kiliṃjaṃ": ['ap90'],
    "kiliṣṭa": ['bhs'],
    "kilkin": ['mw'],
    "kilomaka": ['cped'],
    "kilvin": ['ap90', 'mw'],
    "kilviṣa": ['bhs'],
    "kilviṣaṃ": ['ap90'],
    "kilā": ['gra'],
    "kilāmapaya": ['cped'],
    "kilāmapayat": ['cped'],
    "kilāsa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kilāsabheṣaja": ['mw'],
    "kilāsaghna": ['mw'],
    "kilāsamaya": ['mw'],
    "kilāsanāśana": ['mw'],
    "kilāsatva": ['mw'],
    "kilāsi": ['cped'],
    "kilāsika": ['cped'],
    "kilāsin": ['bhs', 'mw'],
    "kilāsitā": ['bhs'],
    "kilāsiya": ['cped'],
    "kilāsu": ['cped'],
    "kilāsī": ['mw'],
    "kilāta": ['mw'],
    "kilātākulī": ['mw'],
    "kilāṭa": ['mw'],
    "kilāṭaḥ": ['ap90'],
    "kilāṭin": ['ap90', 'mw'],
    "kilāṭī": ['mw'],
    "kilīkṛta": ['bhs'],
    "kim": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kimabhidhāna": ['mw'],
    "kimadhikaraṇa": ['ddsa', 'mw'],
    "kimadyaka": ['mw'],
    "kimakkhāyi": ['cped'],
    "kimakkhāyin": ['cped'],
    "kimantara": ['mw'],
    "kimartha": ['cae', 'mw'],
    "kimartham": ['mw'],
    "kimarthiya": ['bhs'],
    "kimatthaṁ": ['cped'],
    "kimatthiya": ['cped'],
    "kimatthāya": ['cped'],
    "kimavastha": ['mw'],
    "kimba": ['mw'],
    "kimbala": ['mw'],
    "kimbharā": ['mw'],
    "kimbhūta": ['mw'],
    "kimbhūtam": ['mw'],
    "kimbhṛtya": ['mw'],
    "kimi": ['bhs', 'cped'],
    "kimicchaka": ['mw'],
    "kimina": ['cped'],
    "kimmantrin": ['mw'],
    "kimmaya": ['cae', 'gra', 'mw'],
    "kimmātra": ['mw'],
    "kimmūlaka": ['cped'],
    "kimogadha": ['cped'],
    "kimpaca": ['mw'],
    "kimpacāna": ['mw'],
    "kimpahotika": ['cped'],
    "kimpaka": ['bhs'],
    "kimpala": ['bhs', 'mw'],
    "kimparivāra": ['ddsa', 'mw'],
    "kimparyantam": ['mw'],
    "kimparākrama": ['mw'],
    "kimpavitra": ['mw'],
    "kimphala": ['bhs', 'cped', 'mw'],
    "kimpila": ['bhs'],
    "kimprabhu": ['mw'],
    "kimprabhāva": ['mw'],
    "kimprakāram": ['mw'],
    "kimpramāṇa": ['mw'],
    "kimpunā": ['mw'],
    "kimpurisa": ['cped'],
    "kimpurisī": ['cped'],
    "kimpuruṣa": ['mw'],
    "kimpuruṣeśa": ['mw'],
    "kimpuruṣeśvara": ['mw'],
    "kimpuruṣī": ['mw'],
    "kimpuruṣīkṛ": ['mw'],
    "kimpuruṣīya": ['mw'],
    "kimpāka": ['mw'],
    "kimpūruṣa": ['mw'],
    "kimutsedha": ['mw'],
    "kimuttara": ['cped'],
    "kimācāra": ['cae', 'mw'],
    "kimādhāra": ['mw'],
    "kimāhāra": ['mw'],
    "kimākhya": ['cae', 'mw'],
    "kimākāra": ['mw'],
    "kimātmaka": ['mw'],
    "kimāyus": ['mw'],
    "kimāśraya": ['mw'],
    "kimīdin": ['ddsa', 'gra', 'mw'],
    "kimīdinī": ['mw'],
    "kimīya": ['ddsa', 'mw'],
    "kin": ['ddsa'],
    "kindhin": ['mw'],
    "kindubilva": ['ddsa', 'mw'],
    "kinitvā": ['cped'],
    "kinnara": ['ap90', 'cped', 'ddsa'],
    "kinnarī": ['cped'],
    "kinnāma": ['cped'],
    "kinti": ['cped'],
    "kinārilipi": ['mw'],
    "kināti": ['cped'],
    "kināṭa": ['cae', 'mw'],
    "kināṭaṃ": ['ap90'],
    "kipala": ['bhs'],
    "kipillaka": ['cped'],
    "kipillika": ['cped'],
    "kippa": ['mw'],
    "kipīlika": ['cped'],
    "kipīlikā": ['cped'],
    "kir": ['cae', 'ddsa', 'gra', 'mw'],
    "kira": ['cped', 'mw'],
    "kiraka": ['mw'],
    "kirakaḥ": ['ap90'],
    "kirat": ['mw'],
    "kiraḥ": ['ap90'],
    "kiraṇa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kiraṇamaya": ['mw'],
    "kiraṇamālin": ['mw'],
    "kiraṇapati": ['mw'],
    "kiraṇapāṇi": ['mw'],
    "kiraṇaḥ": ['ap90'],
    "kiraṇā": ['mw'],
    "kiraṇākhyatantra": ['mw'],
    "kiraṇāvalī": ['mw'],
    "kiraṇāvalīprakāśa": ['mw'],
    "kiraṇāvalīprakāśavyākhyā": ['mw'],
    "kirbira": ['mw'],
    "kiri": ['cae', 'mw'],
    "kirika": ['cae', 'mw'],
    "kirikā": ['mw'],
    "kiriya": ['cped'],
    "kiriyavāda": ['cped'],
    "kiriyavādi": ['cped'],
    "kiriyavādin": ['cped'],
    "kiriyākiriya": ['cped'],
    "kiriśa": ['mw'],
    "kiriḥ": ['ap90'],
    "kiriṭa": ['mw'],
    "kiriṭi": ['mw'],
    "kiriṭiḥ": ['ap90'],
    "kirmira": ['cae', 'ddsa', 'mw'],
    "kirmiḥ": ['ap90'],
    "kirmī": ['mw'],
    "kirmīra": ['ap90', 'cae', 'mw'],
    "kirmīrajit": ['mw'],
    "kirmīraniṣūdanabhid": ['mw'],
    "kirmīrasūdana": ['mw'],
    "kirmīratvac": ['mw'],
    "kirmīrita": ['ap90', 'cae', 'mw'],
    "kirmīrāri": ['mw'],
    "kiroḍāṭya": ['mw'],
    "kirttiya": ['bhs'],
    "kiryāṇī": ['ap90', 'mw'],
    "kirāta": ['cae', 'ddsa', 'mw'],
    "kirātaka": ['mw'],
    "kirātakula": ['mw'],
    "kirātalipi": ['bhs'],
    "kirātatikta": ['mw'],
    "kirātatiktaka": ['mw'],
    "kirātavallabha": ['mw'],
    "kirātaḥ": ['ap90'],
    "kirāti": ['mw'],
    "kirātinī": ['mw'],
    "kirātiḥ": ['ap90'],
    "kirātārjunīya": ['cae', 'mw'],
    "kirātāśin": ['mw'],
    "kirātī": ['ap90', 'mw'],
    "kirāṭa": ['cae', 'ddsa', 'mw'],
    "kirīṭa": ['cae', 'ddsa', 'mw'],
    "kirīṭabhṛt": ['mw'],
    "kirīṭadhāraṇa": ['mw'],
    "kirīṭadhārin": ['mw'],
    "kirīṭaka": ['bhs'],
    "kirīṭamālin": ['mw'],
    "kirīṭavatsa": ['bhs'],
    "kirīṭaḥ": ['ap90'],
    "kirīṭin": ['ap90', 'cae', 'mw'],
    "kirīṭī": ['mw'],
    "kis": ['cae', 'ddsa', 'gra', 'mw'],
    "kisa": ['cped', 'mw'],
    "kisabalaka": ['cped'],
    "kisaka": ['cped'],
    "kisakovadāna": ['cped'],
    "kisala": ['mw'],
    "kisalay": ['cae'],
    "kisalaya": ['cae', 'ddsa', 'mw'],
    "kisalayakarā": ['mw'],
    "kisalayita": ['mw'],
    "kisalaḥ": ['ap90'],
    "kisara": ['bhs', 'mw'],
    "kisika": ['cped'],
    "kisiya": ['cped'],
    "kismiṁ viya": ['cped'],
    "kisora": ['cped'],
    "kissa": ['cped'],
    "kit": ['ap90', 'ddsa', 'mw'],
    "kita": ['mw'],
    "kitava": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kitavat": ['cped'],
    "kitavaḥ": ['ap90'],
    "kitavī": ['mw'],
    "kitavīya": ['mw'],
    "kittaka": ['cped'],
    "kittaya": ['cped'],
    "kittayamāna": ['cped'],
    "kittayat": ['cped'],
    "kittayati": ['cped'],
    "kittayissāmi": ['cped'],
    "kittetabba": ['cped'],
    "kitteti": ['cped'],
    "kittetvā": ['cped'],
    "kitti": ['cped'],
    "kittisadda": ['cped'],
    "kittita": ['cped'],
    "kittāvatā": ['cped'],
    "kiyacciram": ['cae', 'ddsa'],
    "kiyad": ['mw'],
    "kiyadadbhuta": ['cae'],
    "kiyaddūra": ['cae', 'ddsa', 'mw'],
    "kiyaddūram": ['mw'],
    "kiyaddūre": ['mw'],
    "kiyadehikā": ['mw'],
    "kiyadetikā": ['mw'],
    "kiyan": ['mw'],
    "kiyanmātra": ['cae', 'ddsa', 'mw'],
    "kiyant": ['cae'],
    "kiyat": ['ap90', 'bhs', 'ddsa', 'gra', 'mw'],
    "kiyatkālam": ['mw'],
    "kiyattama": ['bhs'],
    "kiyedhā": ['gra', 'mw'],
    "kiyāha": ['mw'],
    "kiyāhaḥ": ['ap90'],
    "kiyāmbu": ['cae', 'ddsa', 'gra', 'mw'],
    "kiñ carahi": ['cped'],
    "kiñcana": ['cped'],
    "kiñcanatā": ['cped'],
    "kiñcanaṁ": ['cped'],
    "kiñcanya": ['ddsa'],
    "kiñcikkhabhāvanā": ['cped'],
    "kiñcilika": ['mw'],
    "kiñcitka": ['ddsa'],
    "kiñculaka": ['mw'],
    "kiñculuka": ['mw'],
    "kiñcāpi": ['cped'],
    "kiñjakkha": ['cped'],
    "kiñjala": ['mw'],
    "kiñjalka": ['cae', 'ddsa', 'mw'],
    "kiñjalkin": ['mw'],
    "kiśala": ['bhs', 'mw'],
    "kiśalayaḥ": ['ap90'],
    "kiśalaṃ": ['ap90'],
    "kiśara": ['mw'],
    "kiśarika": ['mw'],
    "kiśarā": ['mw'],
    "kiśarādi": ['mw'],
    "kiśarāvat": ['mw'],
    "kiśora": ['cae', 'ddsa', 'mw'],
    "kiśoraka": ['mw'],
    "kiśoraḥ": ['ap90'],
    "kiśorikā": ['mw'],
    "kiśorī": ['mw'],
    "kiṁ": ['cped'],
    "kiṁ aññatra": ['cped'],
    "kiṁ aṅga": ['cped'],
    "kiṁ diṭṭhika": ['cped'],
    "kiṁ gatika": ['cped'],
    "kiṁ jacca": ['cped'],
    "kiṁ jātika": ['cped'],
    "kiṁ karaṇīya": ['cped'],
    "kiṁ kata": ['cped'],
    "kiṁ kayira": ['cped'],
    "kiṁ kusalagavesi": ['cped'],
    "kiṁ kusalagavesin": ['cped'],
    "kiṁ kusalānuesi": ['cped'],
    "kiṁ kusalānuesin": ['cped'],
    "kiṁ kārapaṭissāvi": ['cped'],
    "kiṁ kārapaṭissāvin": ['cped'],
    "kiṁ kāraṇaṁ": ['cped'],
    "kiṁ kāraṇā": ['cped'],
    "kiṁ vādi": ['cped'],
    "kiṁ vādin": ['cped'],
    "kiṁnāma": ['cped'],
    "kiṁsuka": ['cped'],
    "kiṃ": ['mw'],
    "kiṃbala": ['cae'],
    "kiṃbhūta": ['bhs'],
    "kiṃbhṛtya": ['cae'],
    "kiṃca": ['mw'],
    "kiṃcana": ['bhs', 'mw'],
    "kiṃcanaka": ['bhs', 'mw'],
    "kiṃcanatā": ['mw'],
    "kiṃcanin": ['bhs'],
    "kiṃcanya": ['cae', 'mw'],
    "kiṃchandas": ['mw'],
    "kiṃciccheṣa": ['mw'],
    "kiṃciccīritapattrikā": ['mw'],
    "kiṃcid": ['mw'],
    "kiṃcijjña": ['mw'],
    "kiṃcilikaḥ": ['ap90'],
    "kiṃcilukaḥ": ['ap90'],
    "kiṃcinmātra": ['mw'],
    "kiṃcitka": ['bhs', 'mw'],
    "kiṃcitkara": ['mw'],
    "kiṃcitkṣaṇāntara": ['mw'],
    "kiṃcitpare": ['mw'],
    "kiṃcitprāṇa": ['bhs', 'mw'],
    "kiṃcitpāṇi": ['mw'],
    "kiṃdama": ['mw'],
    "kiṃdarbha": ['mw'],
    "kiṃdatta": ['mw'],
    "kiṃdeva": ['mw'],
    "kiṃdevata": ['cae', 'mw'],
    "kiṃdevatya": ['cae', 'mw'],
    "kiṃdharmaka": ['mw'],
    "kiṃdhin": ['ap90'],
    "kiṃdāna": ['mw'],
    "kiṃdāsa": ['mw'],
    "kiṃgotra": ['mw'],
    "kiṃhetu": ['cae'],
    "kiṃja": ['mw'],
    "kiṃjapya": ['mw'],
    "kiṃjaṃ": ['ap90'],
    "kiṃjyotis": ['cae', 'mw'],
    "kiṃkala": ['mw'],
    "kiṃkanīkṛta": ['bhs'],
    "kiṃkara": ['bhs', 'cae', 'mw'],
    "kiṃkarapāṇi": ['mw'],
    "kiṃkaratva": ['mw'],
    "kiṃkaraṇī": ['bhs'],
    "kiṃkaraṇīya": ['bhs'],
    "kiṃkarman": ['mw'],
    "kiṃkartavyamūḍhatā": ['cae'],
    "kiṃkartavyatā": ['mw'],
    "kiṃkarā": ['mw'],
    "kiṃkarāla": ['mw'],
    "kiṃkarī": ['mw'],
    "kiṃkarībhū": ['mw'],
    "kiṃkarīya": ['mw'],
    "kiṃkaṇī": ['ap90'],
    "kiṃkaṇīkā": ['ap90'],
    "kiṃkiraḥ": ['ap90'],
    "kiṃkirāta": ['mw'],
    "kiṃkirātaḥ": ['ap90'],
    "kiṃkiṇikā": ['ap90'],
    "kiṃkiṇī": ['ap90'],
    "kiṃkiṇīkā": ['bhs'],
    "kiṃkiṇīyā": ['bhs'],
    "kiṃkāmya": ['mw'],
    "kiṃkāmyā": ['mw'],
    "kiṃkāraṇa": ['mw'],
    "kiṃkāryatā": ['mw'],
    "kiṃkṛte": ['mw'],
    "kiṃkṣaṇa": ['mw'],
    "kiṃlakṣaṇaka": ['mw'],
    "kiṃmātra": ['cae'],
    "kiṃnara": ['bhs', 'cae', 'mw'],
    "kiṃnarakaṇṭha": ['cae', 'mw'],
    "kiṃnaralipi": ['bhs'],
    "kiṃnaranagara": ['mw'],
    "kiṃnarapati": ['mw'],
    "kiṃnaravarṣa": ['mw'],
    "kiṃnareśa": ['mw'],
    "kiṃnareśvara": ['mw'],
    "kiṃnarā": ['mw'],
    "kiṃnarī": ['mw'],
    "kiṃnarījātaka": ['bhs'],
    "kiṃnimitta": ['cae', 'mw'],
    "kiṃnimittam": ['mw'],
    "kiṃnu": ['mw'],
    "kiṃnāmadheya": ['cae', 'mw'],
    "kiṃnāmaka": ['cae', 'mw'],
    "kiṃnāman": ['cae', 'mw'],
    "kiṃpara": ['cae'],
    "kiṃphala": ['cae'],
    "kiṃprabhu": ['cae'],
    "kiṃpratyaya": ['bhs'],
    "kiṃprāptin": ['bhs'],
    "kiṃpuruṣa": ['bhs', 'cae'],
    "kiṃpuruṣaparvata": ['cae'],
    "kiṃrāja": ['mw'],
    "kiṃrājan": ['mw'],
    "kiṃrūpa": ['cae', 'mw'],
    "kiṃsa": ['mw'],
    "kiṃsakhi": ['cae', 'mw'],
    "kiṃsamācāra": ['mw'],
    "kiṃsaṃniśraya": ['mw'],
    "kiṃstha": ['mw'],
    "kiṃstughna": ['mw'],
    "kiṃstya": ['mw'],
    "kiṃsuhṛd": ['cae', 'mw'],
    "kiṃsvarūpa": ['mw'],
    "kiṃsādhana": ['mw'],
    "kiṃtamām": ['mw'],
    "kiṃtanu": ['mw'],
    "kiṃtarām": ['mw'],
    "kiṃtayā": ['mw'],
    "kiṃtikara": ['bhs'],
    "kiṃtughna": ['mw'],
    "kiṃtva": ['mw'],
    "kiṃtā": ['mw'],
    "kiṃvadanta": ['cae', 'mw'],
    "kiṃvadanti": ['mw'],
    "kiṃvadantī": ['mw'],
    "kiṃvarāṭaka": ['mw'],
    "kiṃvarṇa": ['cae', 'mw'],
    "kiṃvat": ['ap90', 'mw'],
    "kiṃvibhāga": ['mw'],
    "kiṃvid": ['mw'],
    "kiṃvidha": ['mw'],
    "kiṃvidya": ['mw'],
    "kiṃviśeṣaṇa": ['mw'],
    "kiṃviṣayaka": ['mw'],
    "kiṃvyāpāra": ['cae', 'mw'],
    "kiṃvīrya": ['mw'],
    "kiṃvṛtta": ['mw'],
    "kiṃyu": ['cae', 'ddsa', 'gra', 'mw'],
    "kiṃśila": ['mw'],
    "kiṃśuka": ['cae', 'ddsa', 'gra', 'mw'],
    "kiṃśukaḥ": ['ap90'],
    "kiṃśukodaka": ['mw'],
    "kiṃśukādi": ['mw'],
    "kiṃśulaka": ['mw'],
    "kiṃśulakaḥ": ['ap90'],
    "kiṃśulakādi": ['mw'],
    "kiṃśulakāgiri": ['mw'],
    "kiṃśuluka": ['mw'],
    "kiṃśulukaḥ": ['ap90'],
    "kiṃśāru": ['mw'],
    "kiṃśāruḥ": ['ap90'],
    "kiṃśīla": ['mw'],
    "kiṅkara": ['ddsa'],
    "kiṅkaṇikā": ['cped'],
    "kiṅkaṇī": ['cped', 'mw'],
    "kiṅkira": ['mw'],
    "kiṅkirin": ['mw'],
    "kiṅkirā": ['mw'],
    "kiṅkirāla": ['mw'],
    "kiṅkirāta": ['cae', 'mw'],
    "kiṅkiṇa": ['mw'],
    "kiṅkiṇi": ['mw'],
    "kiṅkiṇikajāla": ['cped'],
    "kiṅkiṇikā": ['cped', 'mw'],
    "kiṅkiṇī": ['cae', 'cped', 'ddsa', 'mw'],
    "kiṅkiṇījālamālin": ['mw'],
    "kiṅkiṇīka": ['mw'],
    "kiṅkiṇīkin": ['mw'],
    "kiṅkiṇīkāśrama": ['mw'],
    "kiṅkiṇīsāyaka": ['mw'],
    "kiṇa": ['cae', 'ddsa', 'mw'],
    "kiṇajāta": ['mw'],
    "kiṇakṛta": ['mw'],
    "kiṇavat": ['mw'],
    "kiṇaḥ": ['ap90'],
    "kiṇha": ['cped'],
    "kiṇi": ['mw'],
    "kiṇihī": ['mw'],
    "kiṇikiṇāyamānā": ['bhs'],
    "kiṇitvā": ['cped'],
    "kiṇiṁsu": ['cped'],
    "kiṇva": ['cae', 'ddsa', 'mw'],
    "kiṇvaṃ": ['ap90'],
    "kiṇvin": ['ap90', 'mw'],
    "kiṇvya": ['mw'],
    "kiṇvīya": ['mw'],
    "kiṇāti": ['cped'],
    "kiṇīkṛta": ['bhs'],
    "kiṇṇa": ['cped'],
    "kiṇṇapakkhitta": ['cped'],
    "kiṣk": ['mw'],
    "kiṣkin": ['mw'],
    "kiṣkindha": ['cae', 'ddsa', 'mw'],
    "kiṣkindhagandika": ['mw'],
    "kiṣkindhaka": ['mw'],
    "kiṣkindhya": ['mw'],
    "kiṣkindhyā": ['mw'],
    "kiṣkindhā": ['mw'],
    "kiṣkindhādhipa": ['mw'],
    "kiṣkindhākāṇḍa": ['mw'],
    "kiṣkiśa": ['mw'],
    "kiṣkiṃdhaḥ": ['ap90'],
    "kiṣku": ['ap90', 'cae', 'ddsa', 'mw'],
    "kiṣkuparvan": ['mw'],
    "kiṣkuru": ['mw'],
    "kiṭ": ['ap90', 'mw'],
    "kiṭa": ['mw'],
    "kiṭaka": ['mw'],
    "kiṭakiṭāpaya": ['mw'],
    "kiṭakiṭāya": ['mw'],
    "kiṭi": ['bhs', 'cae', 'ddsa', 'mw'],
    "kiṭibha": ['mw'],
    "kiṭibhaka": ['bhs', 'mw'],
    "kiṭibhaḥ": ['ap90'],
    "kiṭika": ['bhs', 'cped', 'mw'],
    "kiṭima": ['mw'],
    "kiṭimaḥ": ['ap90'],
    "kiṭimūlaka": ['mw'],
    "kiṭimūlābha": ['mw'],
    "kiṭivaravadanā": ['mw'],
    "kiṭiḥ": ['ap90'],
    "kiṭāgiri": ['bhs'],
    "kiṭāgirīyaka": ['bhs'],
    "kiṭālapiṇḍa": ['bhs'],
    "kiṭṭa": ['cae', 'ddsa', 'mw'],
    "kiṭṭaka": ['bhs'],
    "kiṭṭavarjita": ['mw'],
    "kiṭṭaṃ": ['ap90'],
    "kiṭṭha": ['cped'],
    "kiṭṭhasambādha": ['cped'],
    "kiṭṭhāda": ['cped'],
    "kiṭṭhārakkha": ['cped'],
    "kiṭṭima": ['mw'],
    "kiṭṭāla": ['mw'],
    "kiṭṭālaḥ": ['ap90'],
    "klad": ['mw'],
    "kladīvat": ['mw'],
    "klaibya": ['cae', 'ddsa', 'mw'],
    "klaibyaṃ": ['ap90'],
    "klaitakika": ['mw'],
    "klaitakikaṃ": ['ap90'],
    "klaivyaṃ": ['ap90'],
    "klam": ['ap90', 'cae', 'ddsa', 'mw'],
    "klama": ['cae', 'ddsa', 'mw'],
    "klamatha": ['bhs', 'mw'],
    "klamathu": ['mw'],
    "klamaḥ": ['ap90'],
    "klamin": ['mw'],
    "klamitva": ['mw'],
    "klamitā": ['mw'],
    "klamāpaha": ['cae'],
    "kland": ['cae', 'ddsa', 'mw'],
    "klanda": ['mw'],
    "klap": ['mw'],
    "klapuṣa": ['mw'],
    "klath": ['ap90', 'cae', 'ddsa', 'mw'],
    "klathana": ['mw'],
    "klav": ['ap90', 'ddsa', 'mw'],
    "klavita": ['mw'],
    "klaṃd": ['ap90'],
    "kleda": ['cae', 'ddsa', 'mw'],
    "kledaka": ['ap90', 'mw'],
    "kledan": ['ap90', 'mw'],
    "kledana": ['ap90', 'cae', 'mw'],
    "kledanabhāva": ['mw'],
    "kledavat": ['mw'],
    "kledaḥ": ['ap90'],
    "kledin": ['mw'],
    "kledinī": ['mw'],
    "kledita": ['mw'],
    "kledu": ['mw'],
    "kleduḥ": ['ap90'],
    "kledya": ['mw'],
    "klesa": ['cped'],
    "kleś": ['ap90', 'mw'],
    "kleśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "kleśabhāgin": ['mw'],
    "kleśabhāj": ['mw'],
    "kleśada": ['mw'],
    "kleśajñeya": ['bhs'],
    "kleśaka": ['ap90', 'mw'],
    "kleśakārin": ['mw'],
    "kleśakṣama": ['mw'],
    "kleśala": ['mw'],
    "kleśamāra": ['bhs'],
    "kleśana": ['mw'],
    "kleśanāśana": ['mw'],
    "kleśaprahāṇa": ['mw'],
    "kleśaḥ": ['ap90'],
    "kleśin": ['ap90', 'cae', 'mw'],
    "kleśita": ['ap90', 'mw'],
    "kleśāpaha": ['mw'],
    "kleṣṭṛ": ['mw'],
    "klib": ['ap90', 'mw'],
    "klid": ['ap90', 'cae', 'ddsa', 'mw'],
    "klind": ['mw'],
    "klindant": ['cae'],
    "klindat": ['mw'],
    "klinna": ['ap90', 'cae', 'mw'],
    "klinnahṛd": ['mw'],
    "klinnaka": ['mw'],
    "klinnanetra": ['mw'],
    "klinnatva": ['mw'],
    "klinnavartman": ['mw'],
    "klinnā": ['mw'],
    "klinnākṣa": ['mw'],
    "klissati": ['cped'],
    "kliś": ['ap90', 'cae', 'ddsa', 'mw'],
    "kliśita": ['ap90', 'mw'],
    "kliśitavat": ['mw'],
    "kliśyamāna": ['mw'],
    "kliśyati": ['bhs'],
    "kliṃd": ['ap90'],
    "kliṣṭa": ['cae', 'mw'],
    "kliṣṭam": ['mw'],
    "kliṣṭatva": ['mw'],
    "kliṣṭavartman": ['mw'],
    "kliṣṭavṛtti": ['ddsa', 'mw'],
    "kliṣṭi": ['mw'],
    "kliṣṭiḥ": ['ap90'],
    "kloma": ['mw'],
    "klomahṛdaya": ['ddsa'],
    "klomaka": ['bhs'],
    "kloman": ['cae', 'ddsa', 'mw'],
    "klomanhṛdaya": ['mw'],
    "klomaṃ": ['ap90'],
    "klośa": ['cae', 'gra', 'mw'],
    "klośaḥ": ['ap90'],
    "klu": ['ap90', 'mw'],
    "klāmati": ['bhs'],
    "klānta": ['cae', 'mw'],
    "klāntamanas": ['mw'],
    "klāntavadana": ['mw'],
    "klānti": ['cae', 'ddsa', 'mw'],
    "klānticcheda": ['mw'],
    "klānticchid": ['mw'],
    "klāṃta": ['ap90'],
    "klāṃtiḥ": ['ap90'],
    "klīb": ['ap90', 'mw'],
    "klība": ['ap90', 'cae', 'ddsa', 'mw'],
    "klībaliṅga": ['mw'],
    "klībarūpa": ['mw'],
    "klībatva": ['mw'],
    "klībatā": ['cae', 'mw'],
    "klībavat": ['mw'],
    "klībayoga": ['mw'],
    "klībāya": ['mw'],
    "klīta": ['mw'],
    "klītaka": ['mw'],
    "klītakikā": ['mw'],
    "klītakā": ['mw'],
    "klītanaka": ['mw'],
    "klītanāyaka": ['mw'],
    "klītanī": ['mw'],
    "klīv": ['mw'],
    "klīva": ['ap90', 'mw'],
    "klṛp": ['ddsa'],
    "klṛpi": ['ddsa'],
    "klṛptakeśanakhaśmaśru": ['ddsa'],
    "klṛpti": ['ddsa'],
    "kmar": ['mw'],
    "kmiyaṭa, kaiyyaṭa": ['ddsa'],
    "knas": ['ap90', 'mw'],
    "knasa": ['mw'],
    "knath": ['ap90', 'cae', 'mw'],
    "knatha": ['ddsa'],
    "knaṃs": ['mw'],
    "knopam": ['mw'],
    "knopana": ['mw'],
    "knu": ['mw'],
    "knū": ['mw'],
    "knūta": ['mw'],
    "knūy": ['ap90', 'cae', 'ddsa', 'mw'],
    "knūyitṛ": ['mw'],
    "ko": ['cped', 'mw'],
    "ko ca": ['cped'],
    "ko ci": ['cped'],
    "ko pana vado": ['cped'],
    "koca": ['ap90', 'cae', 'ddsa', 'mw'],
    "kocava": ['bhs', 'mw'],
    "kocavaka": ['bhs', 'mw'],
    "kocca": ['bhs'],
    "koccaka": ['bhs'],
    "koccha": ['cped'],
    "kocid eva": ['cped'],
    "kodaṃḍaḥ": ['ap90'],
    "kodaṃḍin": ['ap90'],
    "kodaṇḍa": ['cae', 'cped', 'ddsa', 'mw'],
    "kodaṇḍin": ['mw'],
    "kodha": ['cped'],
    "kodhagaru": ['cped'],
    "kodhana": ['cped'],
    "kodhasammadasammatta": ['cped'],
    "kodhasāmanta": ['cped'],
    "kodhupāyāsi": ['cped'],
    "kodhupāyāsin": ['cped'],
    "kodrava": ['ddsa', 'mw'],
    "kodravaka": ['bhs'],
    "kodravaḥ": ['ap90'],
    "kodrā": ['mw'],
    "kodāra": ['mw'],
    "kodāraḥ": ['ap90'],
    "kohala": ['ap90', 'mw'],
    "kohaleśvaratīrtha": ['mw'],
    "kohalī": ['mw'],
    "kohalīya": ['mw'],
    "kohara": ['mw'],
    "kohaḍa": ['mw'],
    "kohin": ['mw'],
    "kohita": ['mw'],
    "kohlāsa": ['mw'],
    "kojava": ['cped'],
    "kojāgara": ['mw'],
    "kojāgaramāhātmya": ['mw'],
    "kojāgaraḥ": ['ap90'],
    "koka": ['cae', 'ddsa', 'gra', 'mw'],
    "kokabaka": ['mw'],
    "kokabandhu": ['mw'],
    "kokadatta": ['bhs'],
    "kokadeva": ['mw'],
    "kokalika": ['mw'],
    "kokalla": ['mw'],
    "kokalī": ['mw'],
    "kokamukha": ['mw'],
    "kokanada": ['bhs', 'cped', 'ddsa', 'mw'],
    "kokanadacchavi": ['mw'],
    "kokanadaya": ['mw'],
    "kokanadaṃ": ['ap90'],
    "kokanadinī": ['mw'],
    "kokanakha": ['mw'],
    "kokanāda": ['bhs'],
    "kokapitṛ": ['mw'],
    "kokaraka": ['mw'],
    "kokathu": ['mw'],
    "kokavighāsa": ['cped'],
    "kokavāca": ['mw'],
    "kokayātu": ['gra', 'mw'],
    "kokaśāstra": ['mw'],
    "kokaḍa": ['mw'],
    "kokaḥ": ['ap90'],
    "kokila": ['cae', 'cped', 'ddsa', 'mw'],
    "kokilahotra": ['mw'],
    "kokilaka": ['mw'],
    "kokilamaitrāvaruṇa": ['mw'],
    "kokilanayana": ['mw'],
    "kokilapriya": ['mw'],
    "kokilasmṛti": ['mw'],
    "kokilaḥ": ['ap90'],
    "kokilekṣu": ['mw'],
    "kokileṣṭā": ['mw'],
    "kokilotsava": ['mw'],
    "kokilā": ['mw'],
    "kokilābhivyāhārin": ['mw'],
    "kokilādevī": ['mw'],
    "kokilākṣa": ['mw'],
    "kokilākṣaka": ['mw'],
    "kokilāmāhātmya": ['mw'],
    "kokilārahasya": ['mw'],
    "kokilāvrata": ['mw'],
    "kokilāvāsa": ['mw'],
    "kokkala": ['mw'],
    "kokkaṭa": ['mw'],
    "kokkili": ['mw'],
    "kokkvoka": ['mw'],
    "kokovāca": ['mw'],
    "kokā": ['mw'],
    "kokāgra": ['mw'],
    "kokāha": ['mw'],
    "kokāhaḥ": ['ap90'],
    "kokākṣa": ['mw'],
    "kokālika": ['bhs'],
    "kokāmukha": ['mw'],
    "kokāsakajāta": ['cped'],
    "kokī": ['mw'],
    "kola": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "koladala": ['mw'],
    "kolagajinī": ['mw'],
    "kolagiri": ['mw'],
    "kolaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "kolakagrāma": ['mw'],
    "kolakanda": ['mw'],
    "kolakarkaṭikā": ['mw'],
    "kolakarkaṭī": ['mw'],
    "kolakila": ['mw'],
    "kolakuṇa": ['mw'],
    "kolakuṇaḥ": ['ap90'],
    "kolamba": ['cped'],
    "kolambaka": ['mw'],
    "kolambavarṣa": ['mw'],
    "kolambī": ['mw'],
    "kolamuktā": ['mw'],
    "kolamūla": ['mw'],
    "kolanāsikā": ['mw'],
    "kolapuccha": ['mw'],
    "kolaputti": ['cped'],
    "kolatā": ['mw'],
    "kolavallī": ['mw'],
    "kolaśimbī": ['mw'],
    "kolaḥ": ['ap90'],
    "kolaṃbakaḥ": ['ap90'],
    "kolaṅkola": ['cped'],
    "kolaṭṭhi": ['cped'],
    "kolekṣaṇa": ['mw'],
    "koleyyaka": ['cped'],
    "koli": ['mw'],
    "kolika": ['bhs'],
    "kolikagardabha": ['mw'],
    "kolikila": ['mw'],
    "kolisarpa": ['mw'],
    "kolisparśa": ['mw'],
    "kolita": ['bhs', 'mw'],
    "kolitagrāmaka": ['bhs'],
    "koliya": ['bhs'],
    "kollagireya": ['mw'],
    "kollagiri": ['mw'],
    "kollaka": ['mw'],
    "kollapura": ['mw'],
    "kolvagireya": ['mw'],
    "kolyā": ['ap90', 'mw'],
    "kolā": ['ap90', 'mw'],
    "kolāhala": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kolāhalaḥ": ['ap90'],
    "kolāhalin": ['mw'],
    "kolākhya": ['mw'],
    "kolākoli": ['mw'],
    "kolākṣa": ['mw'],
    "kolāpa": ['cped'],
    "kolāpura": ['mw'],
    "kolātmaja": ['mw'],
    "kolāvidhvaṃsin": ['mw'],
    "kolāñca": ['mw'],
    "kolīsovā": ['bhs'],
    "kolūka": ['mw'],
    "koma": ['mw'],
    "komala": ['ap90', 'cae', 'ddsa', 'mw'],
    "komalacchada": ['mw'],
    "komaladala": ['mw'],
    "komalagīta": ['mw'],
    "komalagītaka": ['mw'],
    "komalaka": ['mw'],
    "komalakaṃ": ['ap90'],
    "komalasvabhāva": ['mw'],
    "komalataṇḍula": ['mw'],
    "komalatva": ['mw'],
    "komalatā": ['mw'],
    "komalavalkalā": ['mw'],
    "komalā": ['mw'],
    "komalāṅga": ['mw'],
    "komia": ['gra'],
    "komudī": ['cped'],
    "komya": ['cae', 'gra', 'mw'],
    "komāra": ['cped'],
    "komārabrahmacariyā": ['cped'],
    "komāraka": ['cped'],
    "komārika": ['cped'],
    "komārikā": ['cped'],
    "komāriyā": ['cped'],
    "komārībrahmacariyā": ['cped'],
    "komāsikā": ['mw'],
    "koneritīrtha": ['mw'],
    "kontala": ['mw'],
    "konva": ['mw'],
    "konvaśira": ['mw'],
    "konāka": ['bhs'],
    "konālaka": ['mw'],
    "konālakaḥ": ['ap90'],
    "konāli": ['mw'],
    "konāmā": ['cped'],
    "konīla": ['mw'],
    "kopa": ['cae', 'cped', 'ddsa', 'mw'],
    "kopacchada": ['mw'],
    "kopadīpta": ['mw'],
    "kopajanman": ['mw'],
    "kopajvalita": ['mw'],
    "kopajña": ['mw'],
    "kopaka": ['mw'],
    "kopakrama": ['mw'],
    "kopakāraṇa": ['mw'],
    "kopalatā": ['mw'],
    "kopana": ['ap90', 'cae', 'ddsa', 'mw'],
    "kopanaka": ['ap90', 'mw'],
    "kopaneyya": ['cped'],
    "kopanā": ['mw'],
    "kopanīya": ['mw'],
    "kopapada": ['mw'],
    "kopaparīta": ['mw'],
    "kopasamanvita": ['mw'],
    "kopasaṃdhukṣaṇa": ['mw'],
    "kopatas": ['mw'],
    "kopavairin": ['mw'],
    "kopavat": ['mw'],
    "kopavatī": ['mw'],
    "kopavaśa": ['mw'],
    "kopavega": ['mw'],
    "kopayati": ['cped'],
    "kopayiṣṇu": ['ap90', 'mw'],
    "kopaḥ": ['ap90'],
    "kopaṇīya": ['cped'],
    "kopeti": ['cped'],
    "kopin": ['ap90', 'cae', 'mw'],
    "kopita": ['ap90', 'cped', 'mw'],
    "kopiyajña": ['mw'],
    "kopiyamāna": ['cped'],
    "kopya": ['bhs', 'mw'],
    "kopākopi": ['mw'],
    "kopākula": ['mw'],
    "kopāntara": ['cped'],
    "kopānubandha": ['cae'],
    "kopāviṣṭa": ['mw'],
    "kopāya": ['mw'],
    "kopīna": ['bhs', 'cped'],
    "kopīnanidaṁsana": ['cped'],
    "kora": ['cae', 'cped', 'ddsa', 'mw'],
    "koradūṣa": ['mw'],
    "koradūṣaka": ['mw'],
    "koradūṣaḥ": ['ap90'],
    "koraka": ['cae', 'ddsa', 'mw'],
    "korakaḥ": ['ap90'],
    "korakita": ['mw'],
    "koralī": ['mw'],
    "koravya": ['bhs'],
    "koraḥ": ['ap90'],
    "koraṅgī": ['mw'],
    "koraṇḍaka": ['bhs'],
    "korilā": ['mw'],
    "korita": ['ap90', 'mw'],
    "korpara": ['bhs'],
    "korpya": ['mw'],
    "kosa": ['cped'],
    "kosajja": ['cped'],
    "kosakāhāra": ['cped'],
    "kosakāraka": ['cped'],
    "kosala": ['cae', 'ddsa', 'mw'],
    "kosalajā": ['mw'],
    "kosalavideha": ['cae', 'mw'],
    "kosalaḥ": ['ap90'],
    "kosalla": ['cped'],
    "kosalya": ['cped'],
    "kosalā": ['ap90', 'mw'],
    "kosalānandinī": ['mw'],
    "kosalātmajā": ['mw'],
    "koseyya": ['cped'],
    "koseyyapāvāra": ['cped'],
    "koseyyasukhuma": ['cped'],
    "kosi": ['cped'],
    "kosida": ['mw'],
    "kosika": ['cped'],
    "kosikaṁsu": ['cped'],
    "kosikāraka": ['cped'],
    "kosiya": ['cped'],
    "kosohita": ['cped'],
    "kosāra": ['mw'],
    "kosārakkha": ['cped'],
    "kosātakībīja": ['cped'],
    "kotanā": ['mw'],
    "kotha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kotharī": ['mw'],
    "kotthali": ['cped'],
    "kotthaḷi": ['cped'],
    "kotthu": ['cped'],
    "kotthuka": ['cped'],
    "kotūhalamaṅgala": ['cped'],
    "kotūhalamaṅgalika": ['cped'],
    "kotūsālā": ['cped'],
    "kovida": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "kovidatva": ['mw'],
    "kovidāra": ['bhs', 'ddsa', 'mw'],
    "kovidāraḥ": ['ap90'],
    "koviḷāra": ['cped'],
    "koyaṣṭi": ['cae', 'ddsa', 'mw'],
    "koyaṣṭibha": ['mw'],
    "koyaṣṭika": ['cae', 'mw'],
    "koyaṣṭiḥ": ['ap90'],
    "koñca": ['cped', 'mw'],
    "koñja": ['mw'],
    "kośa": ['cae', 'ddsa', 'gra', 'mw'],
    "kośabhūta": ['mw'],
    "kośacañcu": ['mw'],
    "kośadaṇḍa": ['cae', 'mw'],
    "kośadhānya": ['mw'],
    "kośadhāvana": ['mw'],
    "kośadāsa": ['mw'],
    "kośagatavastiguhya": ['bhs'],
    "kośagatavastiguhyatā": ['mw'],
    "kośagrahaṇa": ['mw'],
    "kośagṛha": ['mw'],
    "kośahīna": ['cae', 'mw'],
    "kośaja": ['mw'],
    "kośajāta": ['mw'],
    "kośaka": ['mw'],
    "kośakaḥ": ['ap90'],
    "kośakālin": ['mw'],
    "kośakālī": ['mw'],
    "kośakāra": ['mw'],
    "kośakāraka": ['mw'],
    "kośakārakīṭa": ['mw'],
    "kośakāravasana": ['mw'],
    "kośakārikā": ['mw'],
    "kośakārī": ['mw'],
    "kośakṛt": ['mw'],
    "kośala": ['ap90', 'cae', 'ddsa', 'mw'],
    "kośalaḥ": ['ap90'],
    "kośalikaṃ": ['ap90'],
    "kośalā": ['ap90'],
    "kośamba": ['bhs'],
    "kośanāyaka": ['mw'],
    "kośapeṭaka": ['cae', 'mw'],
    "kośaphala": ['cae', 'mw'],
    "kośaphalā": ['mw'],
    "kośapāla": ['mw'],
    "kośapīthin": ['mw'],
    "kośarakṣin": ['cae', 'mw'],
    "kośarāṣṭra": ['cae'],
    "kośaskṛt": ['mw'],
    "kośastha": ['mw'],
    "kośavant": ['cae'],
    "kośavat": ['ddsa', 'mw'],
    "kośavatī": ['mw'],
    "kośaveśman": ['mw'],
    "kośavāhana": ['mw'],
    "kośavāri": ['mw'],
    "kośavāsin": ['mw'],
    "kośavṛddhi": ['mw'],
    "kośayī": ['gra', 'mw'],
    "kośaśuddhi": ['mw'],
    "kośaśāyikā": ['mw'],
    "kośaḥ": ['ap90'],
    "kośekṣaṇa": ['mw'],
    "kośeśa": ['mw'],
    "kośikā": ['ap90', 'mw'],
    "kośikāra": ['bhs'],
    "kośilā": ['mw'],
    "kośin": ['ap90', 'mw'],
    "kośopagatavastiguhya": ['bhs'],
    "kośya": ['mw'],
    "kośā": ['mw'],
    "kośādhipati": ['mw'],
    "kośādhyakṣa": ['cae', 'mw'],
    "kośādhīśa": ['mw'],
    "kośāgāra": ['cae', 'mw'],
    "kośāgārādhikārin": ['mw'],
    "kośāmra": ['mw'],
    "kośāpaharaṇa": ['mw'],
    "kośāpahartṛ": ['mw'],
    "kośātaka": ['mw'],
    "kośātakin": ['ap90', 'mw'],
    "kośātakī": ['ap90', 'mw'],
    "kośāvika": ['bhs'],
    "kośāṃśa": ['mw'],
    "kośāṅga": ['mw'],
    "kośāṇḍa": ['mw'],
    "kośī": ['mw'],
    "kośīdhānya": ['mw'],
    "ko˚": ['ddsa'],
    "koḍa": ['bhs'],
    "koḍhaka": ['bhs'],
    "koḍya": ['bhs', 'mw'],
    "koḍā": ['mw'],
    "koḷāpa": ['cped'],
    "koṃkaḥ": ['ap90'],
    "koṃkaṇā": ['ap90'],
    "koṃkāra": ['mw'],
    "koṅgi": ['mw'],
    "koṅka": ['mw'],
    "koṅkaṇa": ['cae', 'ddsa', 'mw'],
    "koṅkaṇaka": ['mw'],
    "koṅkaṇā": ['mw'],
    "koṅkaṇāsuta": ['mw'],
    "koṅkaṇāvatī": ['mw'],
    "koṅkaṭa": ['mw'],
    "koṅkāra": ['ddsa'],
    "koṅkāṇa": ['ddsa', 'mw'],
    "koṇa": ['cae', 'cped', 'ddsa', 'mw'],
    "koṇadeśa": ['mw'],
    "koṇadiś": ['mw'],
    "koṇakoṣṭha": ['mw'],
    "koṇakoṣṭhaka": ['mw'],
    "koṇakuṇa": ['mw'],
    "koṇanara": ['mw'],
    "koṇapa": ['cped', 'mw'],
    "koṇapaḥ": ['ap90'],
    "koṇaspṛgvṛtta": ['mw'],
    "koṇavādin": ['mw'],
    "koṇavṛtta": ['mw'],
    "koṇaśaṅku": ['mw'],
    "koṇaḥ": ['ap90'],
    "koṇepiśācaka": ['mw'],
    "koṇerabhaṭṭa": ['mw'],
    "koṇeya": ['mw'],
    "koṇeyana": ['mw'],
    "koṇi": ['ap90', 'mw'],
    "koṇāditya": ['mw'],
    "koṇāgamana": ['mw'],
    "koṇākamuni": ['bhs'],
    "koṇākoṇi": ['ap90', 'mw'],
    "koṇāla": ['bhs'],
    "koṇārka": ['mw'],
    "koṇḍabhaṭṭa": ['mw'],
    "koṣa": ['cae', 'ddsa', 'mw'],
    "koṣadhāvana": ['mw'],
    "koṣaṇa": ['mw'],
    "koṣaṇī": ['mw'],
    "koṣin": ['ap90'],
    "koṣā": ['mw'],
    "koṣṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "koṣṭha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "koṣṭhabheda": ['mw'],
    "koṣṭhaka": ['bhs', 'mw'],
    "koṣṭhakaḥ": ['ap90'],
    "koṣṭhakoṭi": ['mw'],
    "koṣṭhakīkṛ": ['ap90'],
    "koṣṭhakīkṛtya": ['mw'],
    "koṣṭhapāla": ['mw'],
    "koṣṭharoga": ['mw'],
    "koṣṭhasaṃtāpa": ['mw'],
    "koṣṭhatāpa": ['mw'],
    "koṣṭhavat": ['mw'],
    "koṣṭhaśuddhi": ['mw'],
    "koṣṭhekṣu": ['mw'],
    "koṣṭhikā": ['bhs', 'mw'],
    "koṣṭhila": ['bhs', 'mw'],
    "koṣṭhya": ['ap90', 'mw'],
    "koṣṭhāgni": ['mw'],
    "koṣṭhāgāra": ['cae', 'mw'],
    "koṣṭhāgārika": ['mw'],
    "koṣṭhāgārin": ['mw'],
    "koṣṭhānāha": ['mw'],
    "koṣṭhīkṛ": ['mw'],
    "koṣṭhīpradīpa": ['mw'],
    "koṣṭuka": ['bhs'],
    "koṭa": ['cae', 'ddsa', 'mw'],
    "koṭacakra": ['mw'],
    "koṭaka": ['ap90', 'bhs', 'cae', 'mw'],
    "koṭambaka": ['bhs'],
    "koṭana": ['mw'],
    "koṭanaka": ['bhs'],
    "koṭanī": ['bhs'],
    "koṭapa": ['mw'],
    "koṭaparāja": ['mw'],
    "koṭapāla": ['mw'],
    "koṭara": ['cae', 'ddsa', 'mw'],
    "koṭarapuṣpa": ['mw'],
    "koṭarasthā": ['mw'],
    "koṭaravant": ['cae'],
    "koṭaravat": ['mw'],
    "koṭaravāsinī": ['mw'],
    "koṭarayava": ['bhs'],
    "koṭaraḥ": ['ap90'],
    "koṭarohita": ['cped'],
    "koṭarā": ['mw'],
    "koṭarāvaṇa": ['mw'],
    "koṭarī": ['ap90', 'mw'],
    "koṭavika": ['mw'],
    "koṭavī": ['mw'],
    "koṭayati": ['bhs', 'cped'],
    "koṭayuddhanirṇaya": ['mw'],
    "koṭaśiras": ['mw'],
    "koṭaḥ": ['ap90'],
    "koṭeti": ['cped'],
    "koṭetvā": ['cped'],
    "koṭha": ['mw'],
    "koṭhaka": ['mw'],
    "koṭhara": ['mw'],
    "koṭharapuṣpī": ['mw'],
    "koṭhaḥ": ['ap90'],
    "koṭhī": ['mw'],
    "koṭi": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "koṭidhvaja": ['mw'],
    "koṭidvaya": ['mw'],
    "koṭihoma": ['mw'],
    "koṭihomavidhi": ['mw'],
    "koṭijit": ['mw'],
    "koṭijyā": ['mw'],
    "koṭijīvā": ['mw'],
    "koṭika": ['ap90', 'mw'],
    "koṭikā": ['mw'],
    "koṭikāsya": ['mw'],
    "koṭikṛt": ['mw'],
    "koṭilakṣākṣī": ['mw'],
    "koṭiliṅga": ['mw'],
    "koṭiliṅgeśvara": ['mw'],
    "koṭimant": ['cae'],
    "koṭimat": ['ap90', 'mw'],
    "koṭipura": ['mw'],
    "koṭipāla": ['mw'],
    "koṭipātra": ['mw'],
    "koṭira": ['mw'],
    "koṭiraḥ": ['ap90'],
    "koṭirā": ['mw'],
    "koṭisthā": ['mw'],
    "koṭitama": ['bhs'],
    "koṭitīrtha": ['mw'],
    "koṭivarṣa": ['bhs', 'mw'],
    "koṭivarṣā": ['mw'],
    "koṭivedhin": ['mw'],
    "koṭiśa": ['mw'],
    "koṭiśas": ['mw'],
    "koṭiśaḥ": ['ap90'],
    "koṭiśrī": ['mw'],
    "koṭiḥ": ['ap90'],
    "koṭu": ['bhs'],
    "koṭya": ['mw'],
    "koṭā": ['mw'],
    "koṭādri": ['ddsa', 'mw'],
    "koṭāpeti": ['cped'],
    "koṭāpetvā": ['cped'],
    "koṭāya": ['mw'],
    "koṭī": ['cae', 'mw'],
    "koṭīdhvaja": ['mw'],
    "koṭīkarṇa": ['bhs', 'mw'],
    "koṭīra": ['mw'],
    "koṭīraḥ": ['ap90'],
    "koṭīvarṣa": ['mw'],
    "koṭīviṃśa": ['bhs'],
    "koṭīśa": ['mw'],
    "koṭīśaḥ": ['ap90'],
    "koṭīśvara": ['ddsa', 'mw'],
    "koṭīśvaratīrtha": ['mw'],
    "koṭṭa": ['ddsa', 'mw'],
    "koṭṭabhañja": ['mw'],
    "koṭṭakāraka": ['mw'],
    "koṭṭamalla": ['bhs'],
    "koṭṭapura": ['mw'],
    "koṭṭapāla": ['mw'],
    "koṭṭarāja": ['mw'],
    "koṭṭarājan": ['bhs', 'mw'],
    "koṭṭavī": ['ap90', 'ddsa', 'mw'],
    "koṭṭavīpura": ['mw'],
    "koṭṭayati": ['cped'],
    "koṭṭaḥ": ['ap90'],
    "koṭṭesi": ['cped'],
    "koṭṭeti": ['cped'],
    "koṭṭetvā": ['cped'],
    "koṭṭha": ['cped'],
    "koṭṭhaka": ['cped'],
    "koṭṭhu": ['cped'],
    "koṭṭhuka": ['cped'],
    "koṭṭhāgāra": ['cped'],
    "koṭṭāpetabba": ['cped'],
    "koṭṭāpeti": ['cped'],
    "koṭṭāpetva": ['cped'],
    "koṭṭāra": ['mw'],
    "koṭṭāraḥ": ['ap90'],
    "koṭṭūra": ['mw'],
    "krad": ['mw'],
    "kradhiṣṭha": ['mw'],
    "kradhīyas": ['mw'],
    "kraivya": ['mw'],
    "kraiḍina": ['mw'],
    "kraiḍinīyā": ['mw'],
    "krakaca": ['cae', 'ddsa', 'mw'],
    "krakacacchada": ['mw'],
    "krakacapad": ['mw'],
    "krakacapattra": ['mw'],
    "krakacapṛṣṭhī": ['mw'],
    "krakacatvac": ['mw'],
    "krakacavyavahāra": ['mw'],
    "krakacaḥ": ['ap90'],
    "krakacā": ['mw'],
    "krakara": ['mw'],
    "krakaratva": ['mw'],
    "krakaraḥ": ['ap90'],
    "krakaraṭa": ['mw'],
    "krakarāṭa": ['mw'],
    "krakaṇa": ['mw'],
    "krakucchanda": ['mw'],
    "krakucchandaka": ['bhs'],
    "krakuchanda": ['bhs'],
    "krakūnikā": ['bhs'],
    "krakṣ": ['cae', 'ddsa', 'gra', 'mw'],
    "krakṣamāṇa": ['mw'],
    "kram": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "krama": ['cae', 'ddsa', 'gra', 'mw'],
    "kramabhaṅga": ['mw'],
    "kramabhraṣṭa": ['mw'],
    "kramabhāvin": ['mw'],
    "kramacandrikā": ['mw'],
    "kramacaṭa": ['mw'],
    "kramadaṇḍa": ['mw'],
    "kramadhvaja": ['mw'],
    "kramadīpikā": ['mw'],
    "kramadīśvara": ['cae', 'ddsa', 'mw'],
    "kramagata": ['cae', 'ddsa', 'mw'],
    "kramaghana": ['mw'],
    "kramaja": ['mw'],
    "kramajaṭā": ['mw'],
    "kramajit": ['mw'],
    "kramajyakā": ['mw'],
    "kramajyā": ['mw'],
    "kramaka": ['ap90', 'mw'],
    "kramakāla": ['mw'],
    "kramakālayoga": ['mw'],
    "kramakārikā": ['mw'],
    "kramakṛt": ['mw'],
    "kramalekhā": ['mw'],
    "kramamālā": ['mw'],
    "kramamāṇa": ['mw'],
    "kramapada": ['mw'],
    "kramapravaktṛ": ['mw'],
    "kramaprāpta": ['cae', 'mw'],
    "kramapāra": ['mw'],
    "kramapāṭha": ['cae', 'ddsa', 'mw'],
    "kramapūraka": ['mw'],
    "kramaratha": ['mw'],
    "kramaratnāvalī": ['mw'],
    "kramarājya": ['mw'],
    "kramasaras": ['mw'],
    "kramasaṃdarbhaprabhāsa": ['mw'],
    "kramasaṃgraha": ['mw'],
    "kramasaṃhitodāharaṇa": ['mw'],
    "kramasaṃhitā": ['mw'],
    "kramastuti": ['mw'],
    "kramasāra": ['mw'],
    "kramatas": ['mw'],
    "kramataḥ": ['ap90'],
    "kramatrairāśika": ['mw'],
    "kramavarta": ['mw'],
    "kramavat": ['mw'],
    "kramavattu": ['mw'],
    "kramavyatyaya": ['mw'],
    "kramavṛddhi": ['mw'],
    "kramayaugapadya": ['mw'],
    "kramayoga": ['cae', 'mw'],
    "kramayogena": ['mw'],
    "kramaśas": ['cae', 'mw'],
    "kramaśaḥ": ['ap90'],
    "kramaśaṭha": ['mw'],
    "kramaśikhā": ['mw'],
    "kramaśāstra": ['mw'],
    "kramaḥ": ['ap90'],
    "kramaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "kramaṇaḥ": ['ap90'],
    "kramaṇeṣṭakā": ['mw'],
    "kramaṇīya": ['mw'],
    "kramela": ['cae', 'mw'],
    "kramelaka": ['cae', 'ddsa', 'mw'],
    "kramelaḥ": ['ap90'],
    "krametara": ['mw'],
    "krameṇa": ['mw'],
    "krami": ['mw'],
    "kramika": ['ap90', 'cae', 'ddsa', 'mw'],
    "kramitṛ": ['mw'],
    "kramodvega": ['mw'],
    "kramokta": ['mw'],
    "kramoḍhā": ['mw'],
    "kramu": ['mw'],
    "kramuka": ['cae', 'ddsa', 'mw'],
    "kramukaphala": ['mw'],
    "kramukapuṣpaka": ['mw'],
    "kramukī": ['mw'],
    "kramuñja": ['mw'],
    "kramuḥ": ['ap90'],
    "kramya": ['mw'],
    "kramādhyayana": ['mw'],
    "kramādhyāyin": ['mw'],
    "kramāditya": ['mw'],
    "kramāgata": ['cae', 'mw'],
    "kramāgatatva": ['mw'],
    "kramākrama": ['mw'],
    "kramākrānta": ['ddsa', 'mw'],
    "kramānusāra": ['mw'],
    "kramānuyāyin": ['mw'],
    "kramānvaya": ['mw'],
    "kramāt": ['mw'],
    "kramāvasāna": ['mw'],
    "kramāyāta": ['cae', 'mw'],
    "krand": ['cae', 'ddsa', 'gra', 'mw'],
    "kranda": ['cae', 'ddsa', 'gra', 'mw'],
    "krandadiṣṭi": ['gra', 'mw'],
    "krandana": ['mw'],
    "krandanadhvani": ['cae', 'mw'],
    "krandanu": ['cae', 'gra', 'mw'],
    "krandanā": ['bhs'],
    "krandas": ['cae', 'gra', 'mw'],
    "krandita": ['bhs', 'mw'],
    "kranditṛ": ['mw'],
    "krandya": ['cae', 'mw'],
    "krap": ['ap90', 'ddsa', 'gra', 'mw'],
    "krath": ['ap90', 'cae', 'ddsa', 'mw'],
    "kratha": ['cae', 'ddsa', 'mw'],
    "krathakaiśika": ['cae', 'ddsa'],
    "krathakaiśikaḥ": ['ap90'],
    "krathana": ['mw'],
    "krathanaka": ['ddsa', 'mw'],
    "krathanaṃ": ['ap90'],
    "kratu": ['cae', 'ddsa', 'gra', 'mw'],
    "kratubhuj": ['mw'],
    "kratucchada": ['mw'],
    "kratudakṣiṇā": ['mw'],
    "kratudeva": ['ddsa', 'mw'],
    "kratudhvaja": ['mw'],
    "kratudhvaṃsin": ['mw'],
    "kratudruh": ['mw'],
    "kratudviṣ": ['mw'],
    "kratuhaya": ['mw'],
    "kratujit": ['mw'],
    "kratukaraṇa": ['mw'],
    "kratukarman": ['mw'],
    "kratukriyā": ['mw'],
    "kratumant": ['cae'],
    "kratumat": ['gra', 'mw'],
    "kratumaya": ['cae', 'mw'],
    "kratupati": ['mw'],
    "kratupaśu": ['mw'],
    "kratuphala": ['mw'],
    "kratuprā": ['gra', 'mw'],
    "kratuprāvan": ['gra', 'mw'],
    "kratupuruṣa": ['mw'],
    "kratupā": ['mw'],
    "kraturāj": ['cae', 'mw'],
    "kraturāja": ['mw'],
    "kraturāta": ['mw'],
    "kratusaṃgraha": ['mw'],
    "kratusaṃgrahapariśiṣṭa": ['mw'],
    "kratusaṃkhyā": ['mw'],
    "kratusiddhi": ['mw'],
    "kratuspṛś": ['mw'],
    "kratusthalā": ['mw'],
    "kratutulya": ['mw'],
    "kratuvid": ['gra', 'mw'],
    "kratuvikrayin": ['cae', 'mw'],
    "kratuvikrāyaka": ['mw'],
    "kratuyaṣṭi": ['mw'],
    "kratuśeṣa": ['mw'],
    "kratuḥ": ['ap90'],
    "kratvaṅga": ['mw'],
    "kratvāmagha": ['gra', 'mw'],
    "kratūdakṣau": ['mw'],
    "kratūttama": ['mw'],
    "kratūy": ['cae', 'gra'],
    "kratūya": ['ddsa', 'mw'],
    "kraulāyana": ['mw'],
    "kraurya": ['cae', 'ddsa', 'mw'],
    "krauryaṃ": ['ap90'],
    "krauñca": ['bhs', 'cae', 'ddsa', 'mw'],
    "krauñcabandham": ['mw'],
    "krauñcabradhna": ['mw'],
    "krauñcadvīpa": ['mw'],
    "krauñcadāraṇa": ['mw'],
    "krauñcaniṣadana": ['mw'],
    "krauñcaniṣūdana": ['mw'],
    "krauñcapadā": ['mw'],
    "krauñcapadī": ['mw'],
    "krauñcapakṣa": ['mw'],
    "krauñcapura": ['mw'],
    "krauñcarandhra": ['mw'],
    "krauñcaripu": ['cae', 'mw'],
    "krauñcasūdana": ['mw'],
    "krauñcavana": ['mw'],
    "krauñcavat": ['mw'],
    "krauñcayati": ['bhs'],
    "krauñcaśatru": ['cae', 'mw'],
    "krauñcikīputra": ['mw'],
    "krauñcā": ['mw'],
    "krauñcācala": ['mw'],
    "krauñcācaladveṣin": ['mw'],
    "krauñcādana": ['mw'],
    "krauñcādanī": ['mw'],
    "krauñcākṣi": ['mw'],
    "krauñcāna": ['bhs'],
    "krauñcāraṇya": ['mw'],
    "krauñcāri": ['cae', 'mw'],
    "krauñcāruṇa": ['mw'],
    "krauñcārāti": ['mw'],
    "krauñcī": ['mw'],
    "krauśaśatika": ['mw'],
    "krauśaśatikaḥ": ['ap90'],
    "krauśna": ['mw'],
    "krauḍa": ['cae', 'ddsa', 'mw'],
    "krauḍi": ['mw'],
    "krauḍya": ['bhs'],
    "krauḍyā": ['mw'],
    "krauṃcaḥ": ['ap90'],
    "krauṣita": ['bhs'],
    "krauṣṭra": ['mw'],
    "krauṣṭrāyaṇa": ['mw'],
    "krauṣṭrāyaṇaka": ['mw'],
    "krauṣṭukarṇa": ['mw'],
    "krauṣṭuki": ['mw'],
    "krauṣṭukīya": ['mw'],
    "krauṣṭāyana": ['mw'],
    "kravaṇa": ['ap90', 'gra', 'mw'],
    "kravi": ['gra', 'mw'],
    "kravihasta": ['gra'],
    "kravis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kraviṣṇu": ['cae', 'ddsa', 'gra', 'mw'],
    "kravya": ['cae', 'ddsa', 'gra', 'mw'],
    "kravyabhakṣin": ['mw'],
    "kravyabhojana": ['cae', 'mw'],
    "kravyabhuj": ['mw'],
    "kravyagandhin": ['cae'],
    "kravyaghātana": ['mw'],
    "kravyamukha": ['mw'],
    "kravyavāhana": ['gra', 'mw'],
    "kravyaṃ": ['ap90'],
    "kravyād": ['cae', 'ddsa', 'gra', 'mw'],
    "kravyāda": ['cae', 'mw'],
    "kravyādas": ['mw'],
    "kravyādā": ['mw'],
    "kravyākhya": ['mw'],
    "kravyāśin": ['mw'],
    "kraya": ['cae', 'ddsa', 'mw'],
    "krayadravya": ['mw'],
    "krayakrīta": ['mw'],
    "krayalekhya": ['mw'],
    "krayavikraya": ['cae', 'mw'],
    "krayavikrayika": ['mw'],
    "krayavikrayin": ['cae', 'mw'],
    "krayavikrayānuśaya": ['cae', 'mw'],
    "krayaśīrṣa": ['mw'],
    "krayaḥ": ['ap90'],
    "krayaṇa": ['cae', 'ddsa', 'mw'],
    "krayaṇaṃ": ['ap90'],
    "krayaṇīya": ['mw'],
    "krayika": ['bhs', 'cae', 'mw'],
    "krayikaḥ": ['ap90'],
    "krayin": ['cae', 'mw'],
    "krayya": ['ap90', 'cae', 'ddsa', 'mw'],
    "krayākraya": ['mw'],
    "krayākrayikā": ['mw'],
    "krayāroha": ['mw'],
    "krayāṇaka": ['mw'],
    "kraśaya": ['ddsa'],
    "kraśayati": ['ap90'],
    "kraśiman": ['ap90', 'ddsa', 'mw'],
    "kraśita": ['ap90', 'mw'],
    "kraśiṣṭha": ['mw'],
    "kraśīyas": ['mw'],
    "kraḍana": ['mw'],
    "kraṃd": ['ap90'],
    "kraṃdanaḥ": ['ap90'],
    "kraṃdas": ['ap90'],
    "kraṃdaḥ": ['ap90'],
    "kraṃdita": ['ap90'],
    "kraṃś": ['mw'],
    "kraṣṭavya": ['cae', 'ddsa', 'mw'],
    "kretavya": ['cae', 'mw'],
    "kretṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "kreya": ['ap90', 'cae', 'mw'],
    "kreyada": ['mw'],
    "kreṅkāra": ['ddsa', 'mw'],
    "kreṅkārava": ['mw'],
    "kreṅkṛti": ['mw'],
    "kreṇi": ['mw'],
    "kreṇiḥ": ['ap90'],
    "kreṇī": ['mw'],
    "krimi": ['cae', 'ddsa', 'mw'],
    "krimija": ['cae'],
    "krimila": ['bhs'],
    "krimiḥ": ['ap90'],
    "krimṇa": ['mw'],
    "krivi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "krivirdat": ['gra'],
    "krivirdatī": ['cae', 'mw'],
    "kriya": ['mw'],
    "kriyamāṇa": ['mw'],
    "kriyamāṇaka": ['mw'],
    "kriyaḥ": ['ap90'],
    "kriyendriya": ['mw'],
    "kriyā": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kriyābandha": ['bhs'],
    "kriyābhyupagama": ['cae', 'mw'],
    "kriyādvaita": ['mw'],
    "kriyādveṣin": ['cae', 'mw'],
    "kriyādīpaka": ['mw'],
    "kriyāgupta": ['mw'],
    "kriyāguptaka": ['mw'],
    "kriyāgupti": ['mw'],
    "kriyākalāpa": ['mw'],
    "kriyākara": ['mw'],
    "kriyākartṛ": ['mw'],
    "kriyākaumudī": ['mw'],
    "kriyākula": ['cae', 'ddsa'],
    "kriyākāra": ['bhs', 'mw'],
    "kriyākāṇḍa": ['mw'],
    "kriyālakṣaṇavinivṛttaṃ": ['bhs'],
    "kriyālopa": ['cae', 'mw'],
    "kriyālāghava": ['mw'],
    "kriyāmbudhi": ['mw'],
    "kriyānibandha": ['mw'],
    "kriyānirdeśa": ['mw'],
    "kriyāntara": ['cae', 'mw'],
    "kriyānurūpa": ['mw'],
    "kriyānvita": ['mw'],
    "kriyāpada": ['mw'],
    "kriyāpaddhati": ['mw'],
    "kriyāpara": ['mw'],
    "kriyāpatha": ['mw'],
    "kriyāpathamatikrānta": ['mw'],
    "kriyāpavarga": ['mw'],
    "kriyāpaṭu": ['mw'],
    "kriyāphala": ['mw'],
    "kriyāprabandha": ['cae', 'mw'],
    "kriyāprasaṅga": ['mw'],
    "kriyāpāda": ['mw'],
    "kriyāpātra": ['mw'],
    "kriyārambha": ['cae'],
    "kriyāratnasamuccaya": ['mw'],
    "kriyāroha": ['mw'],
    "kriyārtha": ['cae', 'mw'],
    "kriyārthatva": ['mw'],
    "kriyāsamabhihāra": ['mw'],
    "kriyāsamuccaya": ['mw'],
    "kriyāsamūha": ['mw'],
    "kriyāsaṃskāra": ['mw'],
    "kriyāsiddhi": ['mw'],
    "kriyāsthānakavicāra": ['mw'],
    "kriyāsāra": ['mw'],
    "kriyātantra": ['mw'],
    "kriyātipatti": ['mw'],
    "kriyātmaka": ['cae', 'mw'],
    "kriyātmakatva": ['mw'],
    "kriyāvant": ['cae'],
    "kriyāvasanna": ['mw'],
    "kriyāvat": ['ap90', 'mw'],
    "kriyāvaśa": ['mw'],
    "kriyāvidhi": ['cae', 'mw'],
    "kriyāvidhijña": ['mw'],
    "kriyāviśeṣaṇa": ['cae', 'mw'],
    "kriyāviśāla": ['mw'],
    "kriyāvyavadhāyaka": ['mw'],
    "kriyāvācaka": ['mw'],
    "kriyāvācin": ['mw'],
    "kriyāvādin": ['mw'],
    "kriyāyoga": ['mw'],
    "kriyāyogasāra": ['mw'],
    "kriyāyogya": ['cae'],
    "kriyāyukta": ['mw'],
    "kriyāśakti": ['cae', 'mw'],
    "kriyāśaktimant": ['cae'],
    "kriyāśaktimat": ['mw'],
    "kriyāśraya": ['cae'],
    "kriṇati": ['bhs'],
    "krodha": ['bhs', 'cae', 'ddsa', 'mw'],
    "krodhabhairava": ['mw'],
    "krodhacakṣus": ['cae', 'mw'],
    "krodhahantṛ": ['mw'],
    "krodhahāsa": ['mw'],
    "krodhaja": ['cae', 'mw'],
    "krodhamantra": ['mw'],
    "krodhamaya": ['mw'],
    "krodhamukha": ['mw'],
    "krodhamūrchita": ['mw'],
    "krodhana": ['ap90', 'cae', 'ddsa', 'mw'],
    "krodhanā": ['bhs', 'mw'],
    "krodhanīya": ['ap90', 'mw'],
    "krodharājan": ['bhs'],
    "krodhasamanvita": ['mw'],
    "krodhavardhana": ['mw'],
    "krodhavarjita": ['mw'],
    "krodhavaśa": ['cae', 'mw'],
    "krodhavaśaga": ['mw'],
    "krodhavaśā": ['mw'],
    "krodhavinayana": ['mw'],
    "krodhavivaśā": ['mw'],
    "krodhaśatru": ['mw'],
    "krodhaḥ": ['ap90'],
    "krodheśvara": ['mw'],
    "krodhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "krodhinī": ['mw'],
    "krodhitva": ['mw'],
    "krodhiṣṭha": ['mw'],
    "krodhodana": ['mw'],
    "krodhojjhita": ['mw'],
    "krodhā": ['mw'],
    "krodhālu": ['ap90', 'ddsa', 'mw'],
    "krodhāmarṣajihmabhrū": ['mw'],
    "krodhānvita": ['mw'],
    "krodhī": ['mw'],
    "krotha": ['mw'],
    "krothaḥ": ['ap90'],
    "kroñc": ['mw'],
    "kroñca": ['bhs', 'mw'],
    "kroñcadāraṇa": ['mw'],
    "kroñcakumārikā": ['bhs', 'mw'],
    "kroñcakuśa": ['bhs'],
    "kroñcapadī": ['mw'],
    "kroñcati": ['bhs'],
    "krośa": ['cae', 'ddsa', 'mw'],
    "krośadhvani": ['mw'],
    "krośamāna": ['mw'],
    "krośamātragata": ['mw'],
    "krośamātrasthita": ['mw'],
    "krośana": ['ap90', 'cae', 'gra', 'mw'],
    "krośanā": ['mw'],
    "krośat": ['mw'],
    "krośatāla": ['mw'],
    "krośayuga": ['mw'],
    "krośaḥ": ['ap90'],
    "krośika": ['bhs'],
    "krośin": ['mw'],
    "kroḍa": ['cae', 'ddsa', 'mw'],
    "kroḍacūḍā": ['mw'],
    "kroḍakanyā": ['mw'],
    "kroḍakaseruka": ['mw'],
    "kroḍakhorā": ['mw'],
    "kroḍakāntā": ['mw'],
    "kroḍaloman": ['mw'],
    "kroḍamalla": ['bhs', 'mw'],
    "kroḍamallaka": ['bhs', 'mw'],
    "kroḍaparṇī": ['mw'],
    "kroḍapattra": ['mw'],
    "kroḍapāda": ['mw'],
    "kroḍapālī": ['mw'],
    "kroḍatīrtha": ['mw'],
    "kroḍavallabhā": ['mw'],
    "kroḍavāla": ['cae', 'mw'],
    "kroḍaḥ": ['ap90'],
    "kroḍeṣṭā": ['mw'],
    "kroḍya": ['bhs'],
    "kroḍā": ['mw'],
    "kroḍāsya": ['mw'],
    "kroḍāṅghri": ['mw'],
    "kroḍāṅka": ['mw'],
    "kroḍī": ['mw'],
    "kroḍīkaraṇa": ['mw'],
    "kroḍīkaraṇaṃ": ['ap90'],
    "kroḍīkṛ": ['mw'],
    "kroḍīkṛti": ['mw'],
    "kroḍīmukha": ['mw'],
    "kroḍīmukhaḥ": ['ap90'],
    "kroṃcaḥ": ['ap90'],
    "kroṣṭa": ['mw'],
    "kroṣṭekṣu": ['mw'],
    "kroṣṭrī": ['mw'],
    "kroṣṭrīya": ['mw'],
    "kroṣṭu": ['ap90', 'cae', 'mw'],
    "kroṣṭuka": ['cae', 'mw'],
    "kroṣṭukamekhalā": ['mw'],
    "kroṣṭukamāna": ['mw'],
    "kroṣṭukapucchikā": ['mw'],
    "kroṣṭukarṇa": ['mw'],
    "kroṣṭukaśiras": ['mw'],
    "kroṣṭukī": ['mw'],
    "kroṣṭumāna": ['mw'],
    "kroṣṭumāya": ['mw'],
    "kroṣṭuphala": ['mw'],
    "kroṣṭupucchikā": ['mw'],
    "kroṣṭupucchī": ['mw'],
    "kroṣṭupāda": ['mw'],
    "kroṣṭuvinnā": ['mw'],
    "kroṣṭṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "kru": ['ddsa', 'gra', 'mw'],
    "krubbati": ['cped'],
    "krud": ['mw'],
    "kruddha": ['ap90', 'mw'],
    "krudh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "krudhmi": ['cae', 'gra', 'mw'],
    "krudhmin": ['ap90', 'cae'],
    "krudhyamāna": ['mw'],
    "krudhyana": ['bhs'],
    "krudhyat": ['mw'],
    "krudhā": ['mw'],
    "kruhi": ['bhs'],
    "krukta": ['mw'],
    "krumu": ['cae', 'ddsa', 'gra', 'mw'],
    "krumuka": ['cae', 'ddsa', 'mw'],
    "krumukaḥ": ['ap90'],
    "krunth": ['mw'],
    "kruth": ['ap90'],
    "kruñc": ['cae', 'mw'],
    "kruñca": ['cae', 'mw'],
    "kruñcakīya": ['mw'],
    "kruñcakīyā": ['mw'],
    "kruñcati": ['bhs'],
    "kruñcau": ['mw'],
    "kruñcā": ['mw'],
    "kruñcāmat": ['mw'],
    "kruñm, kruñca": ['ddsa'],
    "kruś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kruśika": ['mw'],
    "kruśvan": ['ap90', 'mw'],
    "kruḍ": ['ap90', 'mw'],
    "kruṃc": ['ap90'],
    "kruṃcaḥ": ['ap90'],
    "kruṃth": ['ap90'],
    "kruṣṭa": ['ap90', 'mw'],
    "kryādi": ['mw'],
    "krā": ['mw'],
    "krākacika": ['mw'],
    "krākacikaḥ": ['ap90'],
    "krākacya": ['mw'],
    "krākacyavyavahṛti": ['mw'],
    "krāmat": ['mw'],
    "krāmaṇa": ['mw'],
    "krāmetaraka": ['mw'],
    "krāmika": ['mw'],
    "krānta": ['cae', 'ddsa', 'mw'],
    "krānti": ['cae', 'mw'],
    "krāntibhujā": ['mw'],
    "krāntibhāga": ['mw'],
    "krāntijyakā": ['mw'],
    "krāntijyā": ['mw'],
    "krāntijīvā": ['mw'],
    "krāntikakṣā": ['mw'],
    "krāntikṣetra": ['mw'],
    "krāntimaurvī": ['mw'],
    "krāntimaṇḍala": ['mw'],
    "krāntipāta": ['mw'],
    "krāntipātagati": ['mw'],
    "krāntivalaya": ['mw'],
    "krāntivṛtta": ['mw'],
    "krāntiśiñjinī": ['mw'],
    "krāntu": ['mw'],
    "krāntvā": ['mw'],
    "krāntā": ['mw'],
    "krātha": ['mw'],
    "krāthana": ['mw'],
    "krāthaḥ": ['ap90'],
    "krātheśvara": ['mw'],
    "krāthin": ['mw'],
    "krāyaka": ['bhs', 'mw'],
    "krāyakaḥ": ['ap90'],
    "krāyika": ['bhs', 'mw'],
    "krāyikaḥ": ['ap90'],
    "krāṃta": ['ap90'],
    "krāṃtiḥ": ['ap90'],
    "krāṃtuḥ": ['ap90'],
    "krāṇa": ['cae'],
    "krāṇan": ['gra'],
    "krāṇā": ['ddsa', 'mw'],
    "krī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "krība": ['mw'],
    "krīli": ['mw'],
    "krīl̤i": ['mw'],
    "krīl̤u": ['mw'],
    "krīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "krītaka": ['ap90', 'cae', 'mw'],
    "krītatva": ['mw'],
    "krītānuśaya": ['mw'],
    "krītāpati": ['mw'],
    "krīḍ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "krīḍa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "krīḍaka": ['bhs', 'mw'],
    "krīḍakaḥ": ['ap90'],
    "krīḍamāna": ['mw'],
    "krīḍana": ['cae', 'mw'],
    "krīḍanaka": ['cae', 'mw'],
    "krīḍanakatayā": ['mw'],
    "krīḍanakatā": ['mw'],
    "krīḍanakaḥ": ['ap90'],
    "krīḍanaṃ": ['ap90'],
    "krīḍanikā": ['bhs', 'mw'],
    "krīḍanīya": ['mw'],
    "krīḍanīyaka": ['mw'],
    "krīḍanīyakasaṃnibha": ['mw'],
    "krīḍat": ['mw'],
    "krīḍi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "krīḍin": ['cae', 'mw'],
    "krīḍita": ['cae', 'mw'],
    "krīḍitaka": ['mw'],
    "krīḍitva": ['mw'],
    "krīḍitṛ": ['mw'],
    "krīḍoddeśa": ['mw'],
    "krīḍu": ['ap90', 'cae', 'gra', 'mw'],
    "krīḍumant": ['cae'],
    "krīḍumat": ['gra', 'mw'],
    "krīḍyaka": ['bhs'],
    "krīḍā": ['ap90', 'ddsa', 'mw'],
    "krīḍābiḍālikā": ['mw'],
    "krīḍācandra": ['mw'],
    "krīḍācaṅkramaṇa": ['mw'],
    "krīḍāgṛha": ['cae', 'mw'],
    "krīḍākapitva": ['mw'],
    "krīḍākautuka": ['mw'],
    "krīḍākauśala": ['mw'],
    "krīḍāketana": ['mw'],
    "krīḍākhaṇḍa": ['mw'],
    "krīḍākopa": ['mw'],
    "krīḍākumāra": ['mw'],
    "krīḍākānana": ['mw'],
    "krīḍākāsāra": ['mw'],
    "krīḍākūṭa": ['mw'],
    "krīḍāmahīdhra": ['cae', 'mw'],
    "krīḍāmarkaṭapota": ['cae', 'mw'],
    "krīḍāmaya": ['mw'],
    "krīḍāmayūra": ['cae', 'mw'],
    "krīḍāmud": ['cae'],
    "krīḍāmātra": ['cae'],
    "krīḍāmṛga": ['mw'],
    "krīḍānārī": ['mw'],
    "krīḍāpana": ['bhs'],
    "krīḍāpanaka": ['bhs'],
    "krīḍāpanika": ['bhs'],
    "krīḍāpanikā": ['mw'],
    "krīḍāparicchada": ['mw'],
    "krīḍāparvata": ['mw'],
    "krīḍāparvataka": ['mw'],
    "krīḍāpradeśa": ['mw'],
    "krīḍāpura": ['mw'],
    "krīḍārasa": ['cae', 'mw'],
    "krīḍārasamaya": ['mw'],
    "krīḍārasātala": ['mw'],
    "krīḍāratha": ['mw'],
    "krīḍāratna": ['mw'],
    "krīḍārudrāya": ['mw'],
    "krīḍārājatasudhāpātra": ['mw'],
    "krīḍāsaras": ['cae', 'mw'],
    "krīḍāsthāna": ['mw'],
    "krīḍātāla": ['mw'],
    "krīḍāvana": ['mw'],
    "krīḍāvat": ['mw'],
    "krīḍāveśman": ['cae', 'mw'],
    "krīḍāvāpī": ['mw'],
    "krīḍāyoga": ['cae', 'mw'],
    "krīḍāśaila": ['mw'],
    "krīḍāśakunta": ['mw'],
    "krūra": ['ap90', 'cae', 'ddsa', 'mw'],
    "krūrabuddhi": ['mw'],
    "krūracarita": ['mw'],
    "krūraceṣṭita": ['mw'],
    "krūradantī": ['mw'],
    "krūradhūrta": ['mw'],
    "krūradṛkpatha": ['mw'],
    "krūradṛś": ['mw'],
    "krūradṛṣṭi": ['mw'],
    "krūragandha": ['mw'],
    "krūragandhaka": ['mw'],
    "krūragandhā": ['mw'],
    "krūrakarmakṛt": ['cae', 'mw'],
    "krūrakarman": ['cae', 'mw'],
    "krūrakoṣṭha": ['mw'],
    "krūrakṛkara": ['mw'],
    "krūrakṛt": ['mw'],
    "krūralocana": ['mw'],
    "krūram": ['mw'],
    "krūramānasa": ['mw'],
    "krūraniścaya": ['mw'],
    "krūraprakṛtika": ['mw'],
    "krūrarava": ['mw'],
    "krūrarāvin": ['mw'],
    "krūrasamācāra": ['mw'],
    "krūrasarpavat": ['mw'],
    "krūrasvara": ['mw'],
    "krūratva": ['mw'],
    "krūratā": ['cae', 'mw'],
    "krūrca": ['mw'],
    "krūropasaṃhata": ['mw'],
    "krūrā": ['mw'],
    "krūrācāra": ['cae', 'mw'],
    "krūrācāravihāravant": ['cae'],
    "krūrācāravihāravat": ['mw'],
    "krūrākṛti": ['mw'],
    "krūrākṣa": ['ddsa', 'mw'],
    "krūrālāpin": ['mw'],
    "krūrātman": ['mw'],
    "krūrāśaya": ['mw'],
    "krūrīkṛ": ['mw'],
    "krūḍ": ['cae', 'ddsa', 'mw'],
    "kta": ['ddsa'],
    "ku": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kua": ['gra'],
    "kubandha": ['ddsa', 'mw'],
    "kubandhu": ['mw'],
    "kubbamāna": ['cped'],
    "kubbanaka": ['cped'],
    "kubbanā": ['cped'],
    "kubbara": ['cped'],
    "kubbati": ['cped'],
    "kubbaye": ['cped'],
    "kubbetha": ['cped'],
    "kubela": ['bhs'],
    "kubera": ['bhs', 'cae', 'ddsa', 'mw'],
    "kuberabāndhava": ['mw'],
    "kuberadatta": ['mw'],
    "kuberagiri": ['mw'],
    "kuberahṛdaya": ['mw'],
    "kuberahṛdya": ['mw'],
    "kuberaka": ['mw'],
    "kuberanalinī": ['mw'],
    "kuberasenā": ['mw'],
    "kuberatīrtha": ['mw'],
    "kuberavallabha": ['mw'],
    "kuberavana": ['mw'],
    "kuberaḥ": ['ap90'],
    "kuberikā": ['mw'],
    "kuberin": ['mw'],
    "kuberācala": ['mw'],
    "kuberādri": ['mw'],
    "kuberākṣa": ['mw'],
    "kuberākṣī": ['mw'],
    "kubh": ['gra'],
    "kubhanyu": ['cae', 'gra', 'mw'],
    "kubhartṛ": ['ddsa', 'mw'],
    "kubhikṣu": ['cae', 'mw'],
    "kubhoga": ['mw'],
    "kubhojana": ['mw'],
    "kubhojya": ['mw'],
    "kubhra": ['cae', 'mw'],
    "kubhrātṛ": ['mw'],
    "kubhukta": ['mw'],
    "kubhukti": ['mw'],
    "kubhā": ['cae', 'ddsa', 'gra', 'mw'],
    "kubhārya": ['mw'],
    "kubhāryā": ['mw'],
    "kubhūmi": ['mw'],
    "kubhṛt": ['ap90', 'mw'],
    "kubhṛtya": ['mw'],
    "kubimba": ['mw'],
    "kubja": ['ap90', 'cae', 'ddsa', 'mw'],
    "kubjaka": ['cae', 'mw'],
    "kubjakagulma": ['cae'],
    "kubjakaḥ": ['ap90'],
    "kubjakaṇṭaka": ['mw'],
    "kubjakirāta": ['mw'],
    "kubjalīḍha": ['mw'],
    "kubjapuṣpa": ['mw'],
    "kubjatā": ['mw'],
    "kubjavāmana": ['mw'],
    "kubji": ['mw'],
    "kubjikā": ['ap90', 'mw'],
    "kubjikātantra": ['mw'],
    "kubjimat": ['mw'],
    "kubjita": ['mw'],
    "kubjottarā": ['bhs'],
    "kubjā": ['mw'],
    "kubjālīḍha": ['mw'],
    "kubjāmra": ['mw'],
    "kubjāmraka": ['mw'],
    "kubjīkaraṇa": ['mw'],
    "kubm, kumbh": ['ddsa'],
    "kubra": ['ap90', 'mw'],
    "kubrahma": ['mw'],
    "kubrahman": ['ddsa', 'mw'],
    "kubrāhmaṇa": ['mw'],
    "kubuddhi": ['mw'],
    "kubāhula": ['mw'],
    "kuc": ['ap90', 'cae', 'ddsa', 'mw'],
    "kuca": ['cae', 'ddsa', 'mw'],
    "kucaharā": ['mw'],
    "kucaila": ['mw'],
    "kucailin": ['mw'],
    "kucakumbha": ['mw'],
    "kucamukha": ['mw'],
    "kucandana": ['cae', 'ddsa', 'mw'],
    "kucaphala": ['mw'],
    "kucara": ['ap90', 'cae', 'gra', 'mw'],
    "kucaritra": ['cae', 'mw'],
    "kucaryā": ['ap90', 'mw'],
    "kucataṭa": ['mw'],
    "kucataṭāgra": ['mw'],
    "kucaśataka": ['mw'],
    "kucaḥ": ['ap90'],
    "kucaṇḍikā": ['mw'],
    "kuccha": ['mw'],
    "kucchati": ['bhs'],
    "kucchaṃ": ['ap90'],
    "kucchi": ['cped'],
    "kucchilā": ['mw'],
    "kucchimatī": ['cped'],
    "kucchiparihārika": ['cped'],
    "kucchiparihāriya": ['cped'],
    "kucchisaya": ['cped'],
    "kucchivatī": ['cped'],
    "kucela": ['cae', 'mw'],
    "kucelaka": ['bhs'],
    "kucelā": ['mw'],
    "kucelī": ['mw'],
    "kuceṣṭā": ['mw'],
    "kucika": ['mw'],
    "kucikarṇa": ['mw'],
    "kucikā": ['mw'],
    "kucita": ['ap90', 'mw'],
    "kucodya": ['mw'],
    "kucumāra": ['mw'],
    "kucuṇṭaka": ['mw'],
    "kucāgra": ['mw'],
    "kucāru": ['mw'],
    "kucāṅgerī": ['mw'],
    "kucīrā": ['mw'],
    "kud": ['mw'],
    "kudarśana": ['mw'],
    "kudassu": ['cped'],
    "kudaṇḍa": ['bhs', 'mw'],
    "kuddala": ['mw'],
    "kuddha": ['cped'],
    "kuddiṭṭhi": ['cped'],
    "kuddiṭṭhin": ['cped'],
    "kuddāla": ['cae', 'cped', 'ddsa', 'mw'],
    "kuddālaka": ['mw'],
    "kuddālakakhāta": ['mw'],
    "kuddālakhāta": ['mw'],
    "kuddālapiṭaka": ['cped'],
    "kuddālapāda": ['mw'],
    "kuddāraḥ": ['ap90'],
    "kudeha": ['mw'],
    "kudeśa": ['mw'],
    "kudhara": ['mw'],
    "kudharma": ['mw'],
    "kudharman": ['mw'],
    "kudhi": ['mw'],
    "kudhra": ['mw'],
    "kudhraḥ": ['ap90'],
    "kudhriac": ['gra'],
    "kudhryac": ['gra'],
    "kudhānya": ['mw'],
    "kudhī": ['cae', 'mw'],
    "kudhṛti": ['mw'],
    "kudina": ['mw'],
    "kudiṣṭi": ['mw'],
    "kudiṭṭhi": ['cped'],
    "kudiṭṭhin": ['cped'],
    "kudmala": ['mw'],
    "kudmalaṃ": ['ap90'],
    "kudrava": ['mw'],
    "kudravya": ['ddsa', 'mw'],
    "kudraṃkaḥ": ['ap90'],
    "kudraṅga": ['mw'],
    "kudraṅka": ['mw'],
    "kudri": ['mw'],
    "kudryākṣi": ['mw'],
    "kudrīcī": ['mw'],
    "kudrūsaka": ['cped'],
    "kudvāra": ['mw'],
    "kudya": ['mw'],
    "kudācanaṁ": ['cped'],
    "kudāla": ['mw'],
    "kudāra": ['mw'],
    "kudāradāra": ['ddsa', 'mw'],
    "kudāssu": ['cped'],
    "kudṛśya": ['mw'],
    "kudṛṣṭa": ['mw'],
    "kudṛṣṭi": ['cae', 'mw'],
    "kudṛṣṭin": ['mw'],
    "kugati": ['mw'],
    "kugaṇin": ['bhs', 'mw'],
    "kugehinī": ['mw'],
    "kugo": ['mw'],
    "kugraha": ['mw'],
    "kugrāma": ['mw'],
    "kugṛha": ['ddsa'],
    "kuh": ['ap90', 'mw'],
    "kuha": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kuhacid": ['mw'],
    "kuhacidvid": ['gra', 'mw'],
    "kuhaka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kuhakacakita": ['mw'],
    "kuhakajña": ['mw'],
    "kuhakajīvaka": ['mw'],
    "kuhakajīvin": ['mw'],
    "kuhakakāra": ['mw'],
    "kuhakakāraka": ['mw'],
    "kuhakakārikā": ['mw'],
    "kuhakasvana": ['mw'],
    "kuhakasvara": ['mw'],
    "kuhakavṛtti": ['mw'],
    "kuhakaḥ": ['ap90'],
    "kuhakka": ['mw'],
    "kuhakuhārāva": ['mw'],
    "kuhakā": ['mw'],
    "kuhakārāva": ['mw'],
    "kuhali": ['mw'],
    "kuhaliḥ": ['ap90'],
    "kuhana": ['ap90', 'bhs', 'mw'],
    "kuhanikā": ['ap90', 'mw'],
    "kuhanā": ['cped', 'mw'],
    "kuhara": ['cae', 'ddsa', 'mw'],
    "kuharabhāj": ['cae', 'mw'],
    "kuharaṃ": ['ap90'],
    "kuharin": ['mw'],
    "kuharita": ['mw'],
    "kuharitaṃ": ['ap90'],
    "kuhayā": ['cae', 'gra', 'mw'],
    "kuhayākṛti": ['gra', 'mw'],
    "kuhaśrutīya": ['mw'],
    "kuhaḥ": ['ap90'],
    "kuhelikā": ['mw'],
    "kuheḍikā": ['ap90', 'mw'],
    "kuheḍī": ['mw'],
    "kuhiñcanaṁ": ['cped'],
    "kuhiñci": ['cped'],
    "kuhiṁ": ['cped'],
    "kuhu": ['ddsa', 'mw'],
    "kuhukuhāya": ['mw'],
    "kuhurava": ['mw'],
    "kuhuḥ": ['ap90'],
    "kuhuṃkāra": ['mw'],
    "kuhvāna": ['mw'],
    "kuhā": ['bhs', 'cae', 'ddsa', 'mw'],
    "kuhārīta": ['mw'],
    "kuhāvatī": ['mw'],
    "kuhī": ['mw'],
    "kuhū": ['cae', 'ddsa', 'mw'],
    "kuhūkaṇṭha": ['mw'],
    "kuhūla": ['mw'],
    "kuhūlaṃ": ['ap90'],
    "kuhūmukha": ['mw'],
    "kuhūpāla": ['mw'],
    "kuhūrava": ['mw'],
    "kuhūs": ['mw'],
    "kuj": ['mw'],
    "kuja": ['ddsa', 'mw'],
    "kujadina": ['mw'],
    "kujambha": ['mw'],
    "kujambhala": ['mw'],
    "kujana": ['mw'],
    "kujananī": ['mw'],
    "kujanman": ['mw'],
    "kujapa": ['mw'],
    "kujaḥ": ['ap90'],
    "kujaṃbhalaḥ": ['ap90'],
    "kujjha": ['cped'],
    "kujjhat": ['cped'],
    "kujjhati": ['cped'],
    "kujjhaṭi": ['mw'],
    "kujjhaṭikā": ['mw'],
    "kujjhaṭiḥ": ['ap90'],
    "kujjhaṭī": ['mw'],
    "kujjhi": ['cped'],
    "kujjhittha": ['cped'],
    "kujjiśa": ['mw'],
    "kujyā": ['mw'],
    "kujñāna": ['mw'],
    "kujā": ['mw'],
    "kujīvikā": ['cae', 'mw'],
    "kuk": ['ap90', 'mw'],
    "kuka": ['mw'],
    "kukabha": ['mw'],
    "kukabhaṃ": ['ap90'],
    "kukalatra": ['mw'],
    "kukanyakā": ['mw'],
    "kukara": ['mw'],
    "kukarmakārin": ['mw'],
    "kukarman": ['mw'],
    "kukathā": ['mw'],
    "kukavi": ['mw'],
    "kukhyāti": ['mw'],
    "kukhāṭi": ['mw'],
    "kukku": ['cped'],
    "kukkubha": ['mw'],
    "kukkubhaḥ": ['ap90'],
    "kukkucaya": ['cped'],
    "kukkucca": ['cped'],
    "kukkuccaka": ['cped'],
    "kukkuccāyanta": ['cped'],
    "kukkuccāyati": ['cped'],
    "kukkuccāyitabba": ['cped'],
    "kukkuciya": ['cped'],
    "kukkuha": ['mw'],
    "kukkukata": ['cped'],
    "kukkula": ['bhs', 'cped'],
    "kukkura": ['cae', 'cped', 'ddsa', 'mw'],
    "kukkuradru": ['mw'],
    "kukkuravatika": ['cped'],
    "kukkuravattika": ['cped'],
    "kukkuravratika": ['bhs'],
    "kukkuraḥ": ['ap90'],
    "kukkuri": ['bhs'],
    "kukkurī": ['mw'],
    "kukkusa": ['cped'],
    "kukkuvāc": ['mw'],
    "kukkuḷa": ['cped'],
    "kukkuḷaniraya": ['cped'],
    "kukkuṭ": ['mw'],
    "kukkuṭa": ['cae', 'cped', 'ddsa', 'mw'],
    "kukkuṭacchāpaka": ['cped'],
    "kukkuṭadhvaja": ['mw'],
    "kukkuṭadhvani": ['mw'],
    "kukkuṭaka": ['cae', 'cped', 'mw'],
    "kukkuṭakantha": ['mw'],
    "kukkuṭakaḥ": ['ap90'],
    "kukkuṭamardaka": ['mw'],
    "kukkuṭamardana": ['mw'],
    "kukkuṭamardikā": ['mw'],
    "kukkuṭamastaka": ['mw'],
    "kukkuṭamañjarī": ['mw'],
    "kukkuṭamaṇḍapa": ['mw'],
    "kukkuṭamiśra": ['mw'],
    "kukkuṭanāḍīyantra": ['mw'],
    "kukkuṭapakṣaka": ['bhs', 'mw'],
    "kukkuṭapotaka": ['cped'],
    "kukkuṭapāda": ['mw'],
    "kukkuṭasampāda": ['cped'],
    "kukkuṭasampāta": ['cped'],
    "kukkuṭasampātika": ['cped'],
    "kukkuṭavrata": ['mw'],
    "kukkuṭayuddha": ['cped'],
    "kukkuṭaśikha": ['mw'],
    "kukkuṭaḥ": ['ap90'],
    "kukkuṭeśvara": ['mw'],
    "kukkuṭeśvaratantra": ['mw'],
    "kukkuṭi": ['mw'],
    "kukkuṭikā": ['mw'],
    "kukkuṭiḥ": ['ap90'],
    "kukkuṭoraga": ['mw'],
    "kukkuṭyādi": ['mw'],
    "kukkuṭābha": ['mw'],
    "kukkuṭāgiri": ['mw'],
    "kukkuṭāgāra": ['bhs'],
    "kukkuṭāhi": ['mw'],
    "kukkuṭārma": ['mw'],
    "kukkuṭārāma": ['bhs', 'mw'],
    "kukkuṭāsana": ['mw'],
    "kukkuṭāṇḍa": ['mw'],
    "kukkuṭāṇḍaka": ['mw'],
    "kukkuṭāṇḍasama": ['mw'],
    "kukkuṭī": ['cped', 'mw'],
    "kukkuṭīmarkaṭīvrata": ['mw'],
    "kukkuṭīvrata": ['mw'],
    "kukola": ['mw'],
    "kukriya": ['mw'],
    "kukriyā": ['mw'],
    "kukubhā": ['mw'],
    "kukuda": ['mw'],
    "kukudaḥ": ['ap90'],
    "kukudru": ['mw'],
    "kukundanī": ['mw'],
    "kukundara": ['mw'],
    "kukundha": ['mw'],
    "kukundura": ['mw'],
    "kukura": ['cae', 'ddsa', 'mw'],
    "kukurajihvā": ['mw'],
    "kukurādhinātha": ['mw'],
    "kukurāḥ": ['ap90'],
    "kukustā": ['bhs'],
    "kukutthaka": ['cped'],
    "kukuvāc": ['mw'],
    "kukuṃdaraḥ": ['ap90'],
    "kukuṃduraḥ": ['ap90'],
    "kukuṇḍaka": ['mw'],
    "kukuṭa": ['mw'],
    "kukuṭasaṃpātamātra": ['bhs'],
    "kukuṭumbinī": ['mw'],
    "kukārya": ['mw'],
    "kukāvya": ['cae', 'mw'],
    "kukīla": ['mw'],
    "kukīlaḥ": ['ap90'],
    "kukīrti": ['mw'],
    "kukūdaḥ": ['ap90'],
    "kukūla": ['bhs', 'ddsa', 'mw'],
    "kukūlamurmura": ['mw'],
    "kukūlaḥ": ['ap90'],
    "kukūlāgni": ['mw'],
    "kukūnana": ['mw'],
    "kukūrabha": ['mw'],
    "kukūvāc": ['mw'],
    "kukūṇaka": ['mw'],
    "kukūṭī": ['mw'],
    "kukṛta": ['mw'],
    "kukṛtya": ['mw'],
    "kukṣa": ['mw'],
    "kukṣaḥ": ['ap90'],
    "kukṣeyu": ['mw'],
    "kukṣi": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kukṣibheda": ['mw'],
    "kukṣigata": ['mw'],
    "kukṣigatīkṛ": ['mw'],
    "kukṣija": ['mw'],
    "kukṣikūjita": ['mw'],
    "kukṣila": ['mw'],
    "kukṣimatī": ['mw'],
    "kukṣimbhari": ['mw'],
    "kukṣirandhra": ['mw'],
    "kukṣirandhraka": ['mw'],
    "kukṣiśūla": ['mw'],
    "kukṣiḥ": ['ap90'],
    "kukṣiṃbhari": ['ap90'],
    "kukṣyagni": ['mw'],
    "kukṣyāmaya": ['mw'],
    "kukṣī": ['ddsa', 'mw'],
    "kul": ['ap90', 'mw'],
    "kula": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kulabaddha": ['bhs'],
    "kulabha": ['mw'],
    "kulabhava": ['mw'],
    "kulabhavana": ['mw'],
    "kulabhaṭa": ['mw'],
    "kulabhedakara": ['mw'],
    "kulabhraṣṭa": ['mw'],
    "kulabhāryā": ['mw'],
    "kulabhūbhṛt": ['cae', 'mw'],
    "kulabhūta": ['cae'],
    "kulabhūṣaṇa": ['mw'],
    "kulabhṛtyā": ['mw'],
    "kulabālikā": ['mw'],
    "kulabīja": ['mw'],
    "kulacandra": ['mw'],
    "kulaccha": ['bhs'],
    "kulacyuta": ['mw'],
    "kulacūḍāmaṇi": ['mw'],
    "kuladaiva": ['cae', 'mw'],
    "kuladaivata": ['cae', 'mw'],
    "kuladamana": ['mw'],
    "kuladeva": ['cae', 'mw'],
    "kuladevatā": ['mw'],
    "kuladhara": ['mw'],
    "kuladharma": ['cae', 'mw'],
    "kuladhurya": ['mw'],
    "kuladhāraka": ['mw'],
    "kuladuhitṛ": ['mw'],
    "kuladīpa": ['mw'],
    "kuladīpikā": ['mw'],
    "kuladīpotsava": ['mw'],
    "kuladūsa": ['cped'],
    "kuladūsaka": ['cped'],
    "kuladūṣaka": ['bhs'],
    "kuladūṣaṇa": ['cae', 'mw'],
    "kulagariman": ['mw'],
    "kulagaurava": ['mw'],
    "kulaghna": ['cae', 'ddsa', 'mw'],
    "kulagiri": ['mw'],
    "kulagna": ['ddsa', 'mw'],
    "kulagopa": ['mw'],
    "kulagotra": ['cae', 'mw'],
    "kulaguru": ['cae', 'mw'],
    "kulagṛha": ['mw'],
    "kulahaṃḍakaḥ": ['ap90'],
    "kulahaṇḍaka": ['mw'],
    "kulahīna": ['mw'],
    "kulaja": ['cae', 'mw'],
    "kulajana": ['mw'],
    "kulajyeṣṭhāpacāyaka": ['bhs'],
    "kulajāta": ['mw'],
    "kulaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "kulakajjala": ['mw'],
    "kulakakarkaṭī": ['mw'],
    "kulakalaṅka": ['mw'],
    "kulakalaṅkakārin": ['mw'],
    "kulakalaṅkita": ['mw'],
    "kulakanyakā": ['cae', 'mw'],
    "kulakanyā": ['mw'],
    "kulakara": ['mw'],
    "kulakarkaṭī": ['mw'],
    "kulakarman": ['mw'],
    "kulakartṛ": ['mw'],
    "kulakauśika": ['mw'],
    "kulakaṇṭaka": ['mw'],
    "kulakka": ['mw'],
    "kulakkaḥ": ['ap90'],
    "kulakumārī": ['mw'],
    "kulakuṇḍalinī": ['mw'],
    "kulakūṇī": ['mw'],
    "kulakṣaya": ['cae', 'mw'],
    "kulakṣayā": ['mw'],
    "kulakṣaṇa": ['ddsa', 'mw'],
    "kulala": ['bhs', 'cped'],
    "kulamacchari": ['cped'],
    "kulamaccharin": ['cped'],
    "kulamacchariya": ['cped'],
    "kulamacchera": ['cped'],
    "kulamaryādā": ['mw'],
    "kulambhara": ['mw'],
    "kulamitra": ['cae', 'mw'],
    "kulampuna": ['mw'],
    "kulampunā": ['mw'],
    "kulamārga": ['mw'],
    "kulamārgatantra": ['mw'],
    "kulamātṛkā": ['mw'],
    "kulanakṣatra": ['mw'],
    "kulanandana": ['bhs', 'mw'],
    "kulanimnagā": ['mw'],
    "kulanindā": ['mw'],
    "kulanāga": ['mw'],
    "kulanārī": ['cae', 'mw'],
    "kulanāyikā": ['mw'],
    "kulanāśa": ['mw'],
    "kulanāśaka": ['cae'],
    "kulapaligedhi": ['cped'],
    "kulapaligedhin": ['cped'],
    "kulaparamparā": ['mw'],
    "kulaparivatta": ['cped'],
    "kulaparivaṭṭa": ['cped'],
    "kulaparvata": ['mw'],
    "kulapatana": ['ddsa', 'mw'],
    "kulapati": ['cae', 'mw'],
    "kulapañcāśikā": ['mw'],
    "kulappasādaka": ['cped'],
    "kulapradīpa": ['mw'],
    "kulaprakāśa": ['mw'],
    "kulaprasūta": ['mw'],
    "kulapratiṣṭhā": ['cae'],
    "kulapravāla": ['mw'],
    "kulapuruṣa": ['mw'],
    "kulapuruṣakeṇa": ['bhs'],
    "kulaputra": ['cae', 'mw'],
    "kulaputrajana": ['mw'],
    "kulaputraka": ['mw'],
    "kulaputrī": ['mw'],
    "kulaputta": ['cped'],
    "kulapā": ['cae', 'gra', 'mw'],
    "kulapālaka": ['mw'],
    "kulapāli": ['mw'],
    "kulapālikā": ['mw'],
    "kulapālin": ['mw'],
    "kulapālī": ['mw'],
    "kulapāta": ['mw'],
    "kulapāṃsana": ['cae', 'mw'],
    "kulapāṃsin": ['mw'],
    "kulapāṃsukā": ['mw'],
    "kulapāṃsula": ['mw'],
    "kulapūrvaga": ['mw'],
    "kulapūrvaka": ['mw'],
    "kulara": ['mw'],
    "kularakṣaka": ['mw'],
    "kularatnamālikā": ['mw'],
    "kularatnamālā": ['mw'],
    "kularddhika": ['mw'],
    "kularājadhānī": ['mw'],
    "kulasa": ['mw'],
    "kulasambhava": ['mw'],
    "kulasamudbhava": ['mw'],
    "kulasattra": ['mw'],
    "kulasaurabha": ['mw'],
    "kulasaṃgata": ['mw'],
    "kulasaṃkhyā": ['cae', 'mw'],
    "kulasaṃnidhi": ['cae', 'mw'],
    "kulasaṃtati": ['cae', 'mw'],
    "kulasevaka": ['mw'],
    "kulastamba": ['cae'],
    "kulastambha": ['mw'],
    "kulasthiti": ['mw'],
    "kulastrī": ['cae', 'mw'],
    "kulasundarī": ['mw'],
    "kulasāra": ['mw'],
    "kulasāṃpreya": ['bhs'],
    "kulasūtra": ['mw'],
    "kulatantu": ['cae', 'ddsa', 'mw'],
    "kulatas": ['mw'],
    "kulatattvavid": ['mw'],
    "kulataḥ": ['ap90'],
    "kulatilaka": ['mw'],
    "kulatithi": ['mw'],
    "kulattha": ['cae', 'mw'],
    "kulatthayūsa": ['cped'],
    "kulatthaḥ": ['ap90'],
    "kulatthikā": ['mw'],
    "kulatthā": ['mw'],
    "kulava": ['cped'],
    "kulavadhū": ['cae', 'mw'],
    "kulavadhūtā": ['mw'],
    "kulavaka": ['bhs'],
    "kulavardhana": ['cae', 'mw'],
    "kulavartman": ['mw'],
    "kulavarṇā": ['mw'],
    "kulavat": ['ap90', 'mw'],
    "kulavaṁsa": ['cped'],
    "kulavidyā": ['cae', 'mw'],
    "kulavipra": ['mw'],
    "kulavrata": ['cae', 'mw'],
    "kulavyāpin": ['mw'],
    "kulavāra": ['mw'],
    "kulavṛddha": ['mw'],
    "kulavṛddhi": ['mw'],
    "kulayoṣit": ['ddsa', 'mw'],
    "kulayukti": ['mw'],
    "kulañja": ['mw'],
    "kulañjana": ['mw'],
    "kulaśaila": ['mw'],
    "kulaśekhara": ['mw'],
    "kulaśekharadeva": ['mw'],
    "kulaśikharin": ['mw'],
    "kulaśreṣṭhin": ['mw'],
    "kulaśulka": ['bhs', 'mw'],
    "kulaśīla": ['mw'],
    "kulaśīlasamanvita": ['mw'],
    "kulaśīlavat": ['mw'],
    "kulaṃ": ['ap90'],
    "kulaṃbharaḥ": ['ap90'],
    "kulaṃdhara": ['ap90', 'mw'],
    "kulaṃkula": ['bhs', 'mw'],
    "kulaṅga": ['mw'],
    "kulaṅgapamarin": ['mw'],
    "kulaṅgāra": ['cped'],
    "kulaṅgī": ['mw'],
    "kulaṅkapādaka": ['cped'],
    "kulaṭa": ['mw'],
    "kulaṭaḥ": ['ap90'],
    "kulaṭā": ['ddsa', 'mw'],
    "kulaṭāpati": ['mw'],
    "kulaṭāpatī": ['mw'],
    "kulecara": ['mw'],
    "kuleya": ['mw'],
    "kuleśvara": ['mw'],
    "kuleśvarī": ['mw'],
    "kuleśvarītantra": ['mw'],
    "kuleśāna": ['mw'],
    "kulharikā": ['mw'],
    "kulharī": ['mw'],
    "kuli": ['mw'],
    "kulija": ['cae', 'ddsa', 'mw'],
    "kulijika": ['mw'],
    "kulijīna": ['mw'],
    "kulika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kulikavelā": ['mw'],
    "kulin": ['ap90', 'mw'],
    "kulina": ['bhs'],
    "kulinda": ['mw'],
    "kulindopatyaka": ['mw'],
    "kulinī": ['mw'],
    "kulira": ['mw'],
    "kuliraḥ": ['ap90'],
    "kulitthī": ['cped'],
    "kuliā": ['gra'],
    "kuliśa": ['cae', 'ddsa', 'gra', 'mw'],
    "kuliśabhṛt": ['cae', 'mw'],
    "kuliśadhara": ['cae', 'mw'],
    "kuliśadruma": ['mw'],
    "kuliśalepa": ['mw'],
    "kuliśanāyaka": ['mw'],
    "kuliśapāṇi": ['mw'],
    "kuliśaḥ": ['ap90'],
    "kuliśeśvarī": ['bhs'],
    "kuliśika": ['bhs'],
    "kuliśāsana": ['mw'],
    "kuliśāya": ['mw'],
    "kuliśāṅkuśā": ['mw'],
    "kuliśī": ['gra', 'mw'],
    "kuliḥ": ['ap90'],
    "kuliṃdaḥ": ['ap90'],
    "kuliṃgaḥ": ['ap90'],
    "kuliṅga": ['cae', 'ddsa', 'mw'],
    "kuliṅgaka": ['mw'],
    "kuliṅgā": ['mw'],
    "kuliṅgākṣī": ['mw'],
    "kuliṅgī": ['mw'],
    "kuliṅkaka": ['mw'],
    "kulla": ['cped'],
    "kullaka": ['cped'],
    "kullakavihāra": ['cped'],
    "kullūka": ['cae', 'ddsa', 'mw'],
    "kullūkabhaṭṭa": ['mw'],
    "kullūkā": ['mw'],
    "kulmala": ['cae', 'mw'],
    "kulmalabarhis": ['mw'],
    "kulmalabarhiṣa": ['mw'],
    "kulmalaṃ": ['ap90'],
    "kulmi": ['cae', 'mw'],
    "kulmāṣa": ['cae', 'ddsa', 'mw'],
    "kulmāṣakhāda": ['mw'],
    "kulmāṣaṃ": ['ap90'],
    "kulmāṣābhiṣuta": ['mw'],
    "kulmāṣī": ['mw'],
    "kulocita": ['mw'],
    "kulodbhava": ['mw'],
    "kulodbhūta": ['mw'],
    "kuloddeśa": ['mw'],
    "kulodgata": ['cae', 'ddsa', 'mw'],
    "kulodvaha": ['cae', 'mw'],
    "kulopadeśa": ['mw'],
    "kulopagata": ['bhs'],
    "kulopaka": ['bhs'],
    "kulopakula": ['mw'],
    "kulopi": ['bhs'],
    "kulotkarṣa": ['mw'],
    "kulotkaṭa": ['mw'],
    "kulotpanna": ['mw'],
    "kulpha": ['cae', 'gra', 'mw'],
    "kulphadaghna": ['mw'],
    "kulphaḥ": ['ap90'],
    "kuluka": ['mw'],
    "kulukaṃ": ['ap90'],
    "kulukkaguñjā": ['mw'],
    "kulukkaguṃjā": ['ap90'],
    "kulupaghātaṁ": ['cped'],
    "kulupaka": ['cped'],
    "kuluñca": ['mw'],
    "kuluṅga": ['mw'],
    "kulva": ['ap90', 'mw'],
    "kulvaka": ['mw'],
    "kulvakaṃ": ['ap90'],
    "kulya": ['ap90', 'cae', 'ddsa', 'mw'],
    "kulyā": ['cae', 'ddsa', 'gra', 'mw'],
    "kulyāya": ['ddsa', 'mw'],
    "kulā": ['mw'],
    "kulābha": ['bhs'],
    "kulābhi": ['mw'],
    "kulābhimāna": ['mw'],
    "kulābhimānin": ['mw'],
    "kulābhiḥ": ['ap90'],
    "kulācala": ['mw'],
    "kulācāra": ['mw'],
    "kulācārya": ['mw'],
    "kulādhāraka": ['mw'],
    "kulāditya": ['mw'],
    "kulādri": ['mw'],
    "kulādya": ['mw'],
    "kulāha": ['mw'],
    "kulāhaka": ['mw'],
    "kulāhakaḥ": ['ap90'],
    "kulāhala": ['mw'],
    "kulāhaḥ": ['ap90'],
    "kulākula": ['bhs', 'mw'],
    "kulākulanakṣatra": ['mw'],
    "kulākulatithi": ['mw'],
    "kulākulavāra": ['mw'],
    "kulākuli": ['mw'],
    "kulākṣutā": ['ap90', 'mw'],
    "kulāla": ['cae', 'ddsa', 'mw'],
    "kulālacakra": ['mw'],
    "kulālakukkuṭa": ['mw'],
    "kulālakṛta": ['mw'],
    "kulālambin": ['mw'],
    "kulālavat": ['mw'],
    "kulālaśālā": ['mw'],
    "kulālaḥ": ['ap90'],
    "kulālikā": ['ap90', 'mw'],
    "kulālī": ['mw'],
    "kulāmbā": ['mw'],
    "kulāmṛta": ['mw'],
    "kulānala": ['mw'],
    "kulānanda": ['mw'],
    "kulāntakaraṇa": ['cae', 'mw'],
    "kulānvaya": ['cae', 'mw'],
    "kulānvita": ['cae', 'mw'],
    "kulāpīḍa": ['mw'],
    "kulārṇava": ['mw'],
    "kulārṇavatantra": ['mw'],
    "kulāva": ['cped'],
    "kulāvaka": ['cped'],
    "kulāya": ['cae', 'ddsa', 'gra', 'mw'],
    "kulāyaka": ['bhs'],
    "kulāyana": ['mw'],
    "kulāyanilāya": ['mw'],
    "kulāyanilāyin": ['mw'],
    "kulāyanilāyitā": ['mw'],
    "kulāyastha": ['mw'],
    "kulāyay": ['gra'],
    "kulāyayat": ['mw'],
    "kulāyaḥ": ['ap90'],
    "kulāyikā": ['ap90', 'mw'],
    "kulāyin": ['cae', 'gra', 'mw'],
    "kulāyinī": ['mw'],
    "kulāṅganā": ['mw'],
    "kulāṅgāra": ['mw'],
    "kulāṅgārī": ['mw'],
    "kulāṅkura": ['cae', 'ddsa', 'mw'],
    "kulāṣṭamī": ['mw'],
    "kulāṭa": ['mw'],
    "kulī": ['ap90', 'mw'],
    "kulīkaya": ['cae', 'mw'],
    "kulīkā": ['cae', 'mw'],
    "kulīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "kulīnaka": ['ap90', 'mw'],
    "kulīnasa": ['mw'],
    "kulīnasaṃ": ['ap90'],
    "kulīnatva": ['mw'],
    "kulīnatā": ['mw'],
    "kulīnā": ['mw'],
    "kulīpaya": ['mw'],
    "kulīra": ['cae', 'ddsa', 'mw'],
    "kulīraka": ['cped', 'mw'],
    "kulīrapādaka": ['cped'],
    "kulīraviṣāṇikā": ['mw'],
    "kulīraśṛṅgī": ['mw'],
    "kulīraḥ": ['ap90'],
    "kulīrād": ['mw'],
    "kulīya": ['cae', 'mw'],
    "kulīśa": ['mw'],
    "kulīśaḥ": ['ap90'],
    "kulūna": ['mw'],
    "kulūpaghātaṁ": ['cped'],
    "kulūpaka": ['cped'],
    "kulūpika": ['cped'],
    "kulūta": ['ap90', 'cae', 'ddsa', 'mw'],
    "kulūtaka": ['mw'],
    "kulūtaḥ": ['ap90'],
    "kum": ['mw'],
    "kum, kuṇḍ": ['ddsa'],
    "kumagga": ['cped'],
    "kumanas": ['cae', 'mw'],
    "kumantra": ['mw'],
    "kumantrin": ['mw'],
    "kumanīṣa": ['mw'],
    "kumanīṣin": ['mw'],
    "kumata": ['mw'],
    "kumati": ['cae', 'mw'],
    "kumb": ['mw'],
    "kumba": ['cae', 'mw'],
    "kumbahaṇḍī": ['cped'],
    "kumbakurīra": ['mw'],
    "kumbh": ['gra', 'mw'],
    "kumbha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kumbhabhava": ['mw'],
    "kumbhabhū": ['mw'],
    "kumbhabila": ['mw'],
    "kumbhabāhu": ['mw'],
    "kumbhabījaka": ['mw'],
    "kumbhadhara": ['mw'],
    "kumbhadhānya": ['cae', 'mw'],
    "kumbhadhārikā": ['mw'],
    "kumbhadohanā": ['cped'],
    "kumbhadāsa": ['mw'],
    "kumbhadāsika": ['cped'],
    "kumbhadāsī": ['bhs', 'cae', 'cped', 'mw'],
    "kumbhadūhanā": ['cped'],
    "kumbhaghoṇatīrtha": ['mw'],
    "kumbhahanu": ['mw'],
    "kumbhajanman": ['mw'],
    "kumbhaka": ['bhs', 'cae', 'mw'],
    "kumbhakapaddhati": ['mw'],
    "kumbhakarṇa": ['cae', 'mw'],
    "kumbhakarṇavadha": ['mw'],
    "kumbhaketu": ['mw'],
    "kumbhakāmalā": ['mw'],
    "kumbhakāra": ['cae', 'cped', 'mw'],
    "kumbhakāraka": ['bhs', 'cped', 'mw'],
    "kumbhakārakabhājana": ['cped'],
    "kumbhakārakakukkuṭa": ['mw'],
    "kumbhakārapāka": ['cped'],
    "kumbhakārikā": ['cped', 'mw'],
    "kumbhakārī": ['bhs', 'mw'],
    "kumbhalagna": ['mw'],
    "kumbhalā": ['mw'],
    "kumbhamaṇḍūka": ['mw'],
    "kumbhamuṣka": ['mw'],
    "kumbhamūrdhan": ['mw'],
    "kumbhanābha": ['mw'],
    "kumbhapadī": ['mw'],
    "kumbhaphalā": ['mw'],
    "kumbhapāda": ['mw'],
    "kumbharetas": ['mw'],
    "kumbharāśi": ['mw'],
    "kumbharī": ['mw'],
    "kumbhasambhava": ['mw'],
    "kumbhasarpis": ['mw'],
    "kumbhasaṃdhi": ['mw'],
    "kumbhastanī": ['mw'],
    "kumbhathenaka": ['cped'],
    "kumbhathūna": ['cped'],
    "kumbhathūnika": ['cped'],
    "kumbhathūṇa": ['cped'],
    "kumbhathūṇika": ['cped'],
    "kumbhatthenaka": ['cped'],
    "kumbhatumbī": ['mw'],
    "kumbhatāla": ['mw'],
    "kumbhatūṇa": ['bhs'],
    "kumbhatūṇika": ['bhs'],
    "kumbhatūṇin": ['bhs'],
    "kumbhavaktra": ['mw'],
    "kumbhayoni": ['mw'],
    "kumbhaśālā": ['mw'],
    "kumbhaṇḍa": ['cped'],
    "kumbhaṭṭhānakthā": ['cped'],
    "kumbheśvaratīrtha": ['mw'],
    "kumbheṣṭakā": ['mw'],
    "kumbhi": ['cped', 'mw'],
    "kumbhikā": ['ddsa', 'mw'],
    "kumbhila": ['cae', 'mw'],
    "kumbhimada": ['mw'],
    "kumbhin": ['cae', 'gra', 'mw'],
    "kumbhinaraka": ['mw'],
    "kumbhinī": ['mw'],
    "kumbhinībīja": ['mw'],
    "kumbhodara": ['bhs', 'ddsa', 'mw'],
    "kumbhodbhava": ['mw'],
    "kumbhodbhūta": ['mw'],
    "kumbholūka": ['mw'],
    "kumbhya": ['mw'],
    "kumbhā": ['mw'],
    "kumbhānta": ['mw'],
    "kumbhāṇḍa": ['bhs', 'cae', 'ddsa', 'mw'],
    "kumbhāṇḍaka": ['bhs', 'mw'],
    "kumbhāṇḍī": ['bhs', 'mw'],
    "kumbhī": ['cped', 'ddsa', 'mw'],
    "kumbhībhagāla": ['mw'],
    "kumbhībīja": ['mw'],
    "kumbhīdhānya": ['mw'],
    "kumbhīdhānyaka": ['cae', 'mw'],
    "kumbhīka": ['mw'],
    "kumbhīkapiḍakā": ['mw'],
    "kumbhīkapāla": ['mw'],
    "kumbhīkin": ['mw'],
    "kumbhīkā": ['mw'],
    "kumbhīla": ['cae', 'mw'],
    "kumbhīlabhaya": ['cped'],
    "kumbhīlaka": ['cae'],
    "kumbhīmukha": ['mw'],
    "kumbhīmāhātmya": ['mw'],
    "kumbhīnadāla": ['mw'],
    "kumbhīnasa": ['cae', 'mw'],
    "kumbhīnasi": ['mw'],
    "kumbhīnasī": ['mw'],
    "kumbhīpāka": ['cae', 'mw'],
    "kumbhīpākya": ['mw'],
    "kumbhīra": ['bhs', 'cae', 'ddsa', 'mw'],
    "kumbhīraka": ['mw'],
    "kumbhīramakṣikā": ['mw'],
    "kumbyā": ['mw'],
    "kumbā": ['mw'],
    "kumedhas": ['mw'],
    "kumeru": ['mw'],
    "kumina": ['cped'],
    "kuminamukha": ['cped'],
    "kumināmukha": ['cped'],
    "kumitra": ['cae', 'mw'],
    "kumma": ['cped'],
    "kummagga": ['cped'],
    "kummāsa": ['cped'],
    "kumodaka": ['mw'],
    "kumodakaḥ": ['ap90'],
    "kump": ['mw'],
    "kumpa": ['mw'],
    "kumud": ['ap90', 'mw'],
    "kumuda": ['cae', 'cped', 'ddsa', 'mw'],
    "kumudabandhu": ['mw'],
    "kumudabāndhava": ['mw'],
    "kumudacandra": ['mw'],
    "kumudagandha": ['bhs'],
    "kumudaghnī": ['mw'],
    "kumudakhaṇḍa": ['mw'],
    "kumudamaya": ['mw'],
    "kumudanātha": ['mw'],
    "kumudapattrābha": ['mw'],
    "kumudapuṣpā": ['bhs', 'mw'],
    "kumudasakhī": ['mw'],
    "kumudasuhṛd": ['mw'],
    "kumudavana": ['mw'],
    "kumudavatī": ['ap90', 'mw'],
    "kumudaśyenī": ['mw'],
    "kumudaḥ": ['ap90'],
    "kumudaṇāla": ['cped'],
    "kumudeśa": ['mw'],
    "kumudika": ['ap90', 'mw'],
    "kumudikā": ['ddsa', 'mw'],
    "kumudinī": ['ap90', 'cae', 'ddsa', 'mw'],
    "kumudinīnāyaka": ['mw'],
    "kumudinīpati": ['mw'],
    "kumudinīvadhūvara": ['mw'],
    "kumudinīvanitā": ['mw'],
    "kumudotpalin": ['mw'],
    "kumudottara": ['mw'],
    "kumudvant": ['cae'],
    "kumudvat": ['ap90', 'ddsa', 'mw'],
    "kumudvatī": ['mw'],
    "kumudvatīśa": ['mw'],
    "kumudvin": ['mw'],
    "kumudā": ['mw'],
    "kumudādi": ['mw'],
    "kumudākara": ['cae', 'mw'],
    "kumudākarabāndhava": ['mw'],
    "kumudākaramati": ['bhs'],
    "kumudākṣa": ['mw'],
    "kumudāvāsa": ['mw'],
    "kumudī": ['mw'],
    "kumuhūrta": ['ddsa', 'mw'],
    "kumukha": ['mw'],
    "kumālaka": ['mw'],
    "kumālana": ['mw'],
    "kumālaya": ['mw'],
    "kumāra": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kumārabandhakī": ['mw'],
    "kumārabhaṭṭa": ['mw'],
    "kumārabhūta": ['bhs'],
    "kumārabhṛta": ['bhs'],
    "kumārabhṛtyā": ['mw'],
    "kumārabrahmacārin": ['cae', 'mw'],
    "kumāracapala": ['mw'],
    "kumāradarśana": ['bhs', 'mw'],
    "kumāradatta": ['mw'],
    "kumāradevī": ['mw'],
    "kumāradeṣṇa": ['cae', 'gra', 'mw'],
    "kumāradhārā": ['mw'],
    "kumāradāsa": ['mw'],
    "kumāradāsī": ['mw'],
    "kumāragarbhiṇī": ['mw'],
    "kumāraghātin": ['mw'],
    "kumāragupta": ['mw'],
    "kumārahārita": ['mw'],
    "kumārajīva": ['mw'],
    "kumāraka": ['cae', 'cped', 'gra', 'mw'],
    "kumārakaḥ": ['ap90'],
    "kumārakulaṭā": ['mw'],
    "kumārakuśala": ['mw'],
    "kumārakāśyapa": ['bhs'],
    "kumārakīlikā": ['cped'],
    "kumāralalitā": ['mw'],
    "kumāranipuṇa": ['mw'],
    "kumārapaṇḍita": ['mw'],
    "kumārapaṭu": ['mw'],
    "kumārapitṛmeṣa": ['mw'],
    "kumārapravrajitā": ['mw'],
    "kumārapāla": ['mw'],
    "kumārarāja": ['mw'],
    "kumārasambhava": ['mw'],
    "kumārasaṃbhava": ['cae'],
    "kumārasena": ['mw'],
    "kumārasiṃha": ['mw'],
    "kumārasvāmin": ['mw'],
    "kumārasū": ['mw'],
    "kumāratva": ['cae', 'mw'],
    "kumāratāpasī": ['mw'],
    "kumāravana": ['cae', 'mw'],
    "kumāravardhana": ['bhs'],
    "kumāravat": ['mw'],
    "kumāravrata": ['cae', 'mw'],
    "kumāravāhana": ['cped'],
    "kumāravāhin": ['mw'],
    "kumāravāridhārā": ['mw'],
    "kumāraya": ['mw'],
    "kumārayati": ['ap90'],
    "kumārayu": ['mw'],
    "kumārayuḥ": ['ap90'],
    "kumāraśiras": ['mw'],
    "kumāraśramaṇā": ['mw'],
    "kumāraḥ": ['ap90'],
    "kumāreśvaratīrtha": ['mw'],
    "kumārga": ['ddsa', 'mw'],
    "kumāri": ['mw'],
    "kumāridatta": ['ddsa', 'mw'],
    "kumāridā": ['mw'],
    "kumāridārā": ['mw'],
    "kumārika": ['ap90', 'mw'],
    "kumārikā": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "kumārikākhaṇḍa": ['mw'],
    "kumārikākṣetra": ['mw'],
    "kumārila": ['cae', 'mw'],
    "kumārilabhaṭṭa": ['cae', 'mw'],
    "kumārilasvāmin": ['cae', 'mw'],
    "kumārin": ['cae', 'gra', 'mw'],
    "kumāritamā": ['mw'],
    "kumāritarā": ['mw'],
    "kumāriyā": ['cped'],
    "kumārābhirūpaka": ['mw'],
    "kumārābhiṣeka": ['mw'],
    "kumārādhyāpaka": ['mw'],
    "kumārāgāra": ['mw'],
    "kumārākaragupta": ['bhs'],
    "kumārī": ['bhs', 'cped', 'ddsa', 'mw'],
    "kumārībhāga": ['cae'],
    "kumārībhāva": ['cae', 'mw'],
    "kumārīdākṣa": ['mw'],
    "kumārīkalpa": ['mw'],
    "kumārīkrīḍanaka": ['mw'],
    "kumārīpañha": ['cped'],
    "kumārīpura": ['mw'],
    "kumārīputra": ['mw'],
    "kumārīputraka": ['mw'],
    "kumārīpāla": ['mw'],
    "kumārīpūjā": ['mw'],
    "kumārītantra": ['mw'],
    "kumārīvāhana": ['cped'],
    "kumārīśvaśura": ['mw'],
    "kumārīśvaśuraka": ['mw'],
    "kunadikā": ['mw'],
    "kunadī": ['mw'],
    "kunaka": ['mw'],
    "kunakaḥ": ['ap90'],
    "kunakha": ['cae', 'mw'],
    "kunakhin": ['cae', 'mw'],
    "kunalin": ['mw'],
    "kunamnama": ['gra'],
    "kunannama": ['mw'],
    "kunaraka": ['mw'],
    "kunarendra": ['mw'],
    "kunaṭa": ['mw'],
    "kunaṭī": ['mw'],
    "kunda": ['cae', 'ddsa', 'mw'],
    "kundacaturthī": ['mw'],
    "kundaka": ['mw'],
    "kundakara": ['mw'],
    "kundalatā": ['cae'],
    "kundama": ['mw'],
    "kundamālā": ['mw'],
    "kundapuṣpa": ['mw'],
    "kundapuṣpagandha": ['bhs'],
    "kundara": ['mw'],
    "kundarikā": ['mw'],
    "kundasaka": ['bhs'],
    "kundasamadanta": ['mw'],
    "kundinī": ['mw'],
    "kundr": ['mw'],
    "kundu": ['mw'],
    "kundura": ['mw'],
    "kunduru": ['mw'],
    "kunduruka": ['mw'],
    "kundurukā": ['mw'],
    "kundurukī": ['mw'],
    "kundurūka": ['mw'],
    "kundācārya": ['mw'],
    "kundāparānta": ['mw'],
    "kunetraka": ['mw'],
    "kunikaṇṭha": ['bhs'],
    "kuniṣañja": ['mw'],
    "kunnadī": ['cped'],
    "kunta": ['bhs', 'cae', 'ddsa', 'mw'],
    "kuntadaṃṣṭrā": ['bhs'],
    "kuntala": ['bhs', 'cae', 'ddsa', 'mw'],
    "kuntalasvātikarṇa": ['mw'],
    "kuntalavardhana": ['mw'],
    "kuntalikā": ['mw'],
    "kuntalośīra": ['mw'],
    "kuntapalaka": ['bhs'],
    "kuntapipīlika": ['bhs'],
    "kuntaprāvaraṇa": ['mw'],
    "kuntara": ['mw'],
    "kuntavanamaya": ['ddsa', 'mw'],
    "kunth": ['mw'],
    "kuntha": ['mw'],
    "kunthakipillaka": ['cped'],
    "kunthakipillika": ['cped'],
    "kunthana": ['mw'],
    "kunthita": ['mw'],
    "kunthu": ['mw'],
    "kunti": ['cae', 'ddsa', 'mw'],
    "kuntibhoja": ['cae', 'mw'],
    "kuntijit": ['mw'],
    "kuntika": ['mw'],
    "kuntinandana": ['mw'],
    "kuntirājan": ['mw'],
    "kuntisurāṣṭra": ['mw'],
    "kuntākanti": ['mw'],
    "kuntāpa": ['cae', 'ddsa', 'mw'],
    "kuntī": ['bhs', 'cae', 'ddsa', 'mw'],
    "kuntībhoja": ['mw'],
    "kuntīmātṛ": ['mw'],
    "kuntīnagara": ['bhs'],
    "kuntīnandana": ['mw'],
    "kuntīsuta": ['cae', 'mw'],
    "kunābhi": ['mw'],
    "kunādīkā": ['mw'],
    "kunāla": ['bhs', 'mw'],
    "kunālika": ['mw'],
    "kunālikā": ['ap90'],
    "kunāman": ['mw'],
    "kunārī": ['mw'],
    "kunāsa": ['mw'],
    "kunātha": ['mw'],
    "kunāyaka": ['mw'],
    "kunāśaka": ['mw'],
    "kunīlī": ['mw'],
    "kunīta": ['mw'],
    "kunīti": ['mw'],
    "kunṛpa": ['mw'],
    "kunṛpati": ['mw'],
    "kup": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kupa": ['cae', 'ddsa', 'mw'],
    "kupana": ['mw'],
    "kupapa": ['mw'],
    "kupapi": ['mw'],
    "kupapī": ['mw'],
    "kuparijñāta": ['mw'],
    "kuparīkṣaka": ['mw'],
    "kuparīkṣita": ['mw'],
    "kupata": ['mw'],
    "kupatha": ['mw'],
    "kupathacara": ['mw'],
    "kupathaga": ['mw'],
    "kupathagāmin": ['mw'],
    "kupathya": ['mw'],
    "kupati": ['mw'],
    "kupaya": ['ap90', 'cae', 'gra', 'mw'],
    "kupaḥ": ['ap90'],
    "kupaṅka": ['mw'],
    "kupaṇḍita": ['mw'],
    "kupaṭa": ['ddsa', 'mw'],
    "kupaṭu": ['mw'],
    "kupina": ['bhs'],
    "kupinda": ['mw'],
    "kupinin": ['ap90', 'mw'],
    "kupinī": ['ap90', 'mw'],
    "kupita": ['cped', 'mw'],
    "kupitavāyu": ['mw'],
    "kupitāntaka": ['mw'],
    "kupitṛ": ['mw'],
    "kupiñjala": ['mw'],
    "kupiṃda": ['ap90'],
    "kupiṃdaḥ": ['ap90'],
    "kuplava": ['cae', 'mw'],
    "kuppa": ['cped'],
    "kuppaniya": ['cped'],
    "kuppati": ['cped'],
    "kuppi": ['cped'],
    "kuppita": ['cped'],
    "kuprabhu": ['ddsa', 'mw'],
    "kuprada": ['mw'],
    "kupriya": ['mw'],
    "kuprāvaraṇa": ['mw'],
    "kuprāvṛta": ['mw'],
    "kupsara": ['bhs'],
    "kuptu": ['mw'],
    "kupuruṣa": ['cae', 'mw'],
    "kupuruṣajanitā": ['mw'],
    "kuputra": ['cae', 'mw'],
    "kupya": ['cae', 'ddsa', 'mw'],
    "kupyadhauta": ['mw'],
    "kupyaka": ['bhs', 'mw'],
    "kupyavetanin": ['mw'],
    "kupyaśālā": ['mw'],
    "kupyaṃ": ['ap90'],
    "kupāka": ['mw'],
    "kupātra": ['mw'],
    "kupātraka": ['mw'],
    "kupāyu": ['cae', 'mw'],
    "kupāṇi": ['mw'],
    "kupīlu": ['mw'],
    "kupūya": ['ap90', 'mw'],
    "kur": ['ap90', 'mw'],
    "kuraba": ['mw'],
    "kurabaka": ['cae', 'ddsa', 'mw'],
    "kuracilla": ['mw'],
    "kuracillaḥ": ['ap90'],
    "kurahasya": ['ddsa'],
    "kurakā": ['mw'],
    "kurala": ['mw'],
    "kuralaprastha": ['mw'],
    "kuralaḥ": ['ap90'],
    "kuramaṁsa": ['cped'],
    "kurara": ['cae', 'ddsa', 'mw'],
    "kuraraḥ": ['ap90'],
    "kurarin": ['mw'],
    "kurarāva": ['mw'],
    "kurarāvaṃ": ['ap90'],
    "kurarāṅghri": ['mw'],
    "kurarī": ['ap90', 'mw'],
    "kurarīgaṇa": ['mw'],
    "kurasa": ['mw'],
    "kurasā": ['mw'],
    "kurava": ['mw'],
    "kuravaḥ": ['ap90'],
    "kuravī": ['mw'],
    "kurayāṇa": ['mw'],
    "kuraṃgakaḥ": ['ap90'],
    "kuraṃgamaḥ": ['ap90'],
    "kuraṃgaḥ": ['ap90'],
    "kuraṃkaraḥ": ['ap90'],
    "kuraṃḍakaḥ": ['ap90'],
    "kuraṃḍaḥ": ['ap90'],
    "kuraṃṭaḥ": ['ap90'],
    "kuraṅga": ['cae', 'ddsa', 'mw'],
    "kuraṅgaka": ['cae', 'mw'],
    "kuraṅgalocanā": ['cae', 'mw'],
    "kuraṅgalāñchana": ['mw'],
    "kuraṅgama": ['mw'],
    "kuraṅgamada": ['mw'],
    "kuraṅganayanā": ['cae', 'mw'],
    "kuraṅganetrā": ['cae', 'mw'],
    "kuraṅganābhi": ['mw'],
    "kuraṅgavadhū": ['mw'],
    "kuraṅgikā": ['mw'],
    "kuraṅgākṣī": ['cae', 'mw'],
    "kuraṅgāya": ['ddsa', 'mw'],
    "kuraṅgī": ['ddsa', 'mw'],
    "kuraṅkara": ['mw'],
    "kuraṅkura": ['mw'],
    "kuraṇḍa": ['mw'],
    "kuraṇḍaka": ['mw'],
    "kuraṇṭa": ['bhs', 'mw'],
    "kuraṇṭaka": ['mw'],
    "kuraṇṭikā": ['mw'],
    "kuraṭa": ['mw'],
    "kuraṭaḥ": ['ap90'],
    "kurcikā": ['ap90', 'mw'],
    "kurd": ['ap90', 'mw'],
    "kurdana": ['mw'],
    "kurkura": ['cae', 'ddsa', 'mw'],
    "kurkuraḥ": ['ap90'],
    "kurkurīya": ['mw'],
    "kurkuṭa": ['ddsa', 'mw'],
    "kurkuṭaḥ": ['ap90'],
    "kurkuṭāhi": ['mw'],
    "kurkuṭārāma": ['bhs'],
    "kurkuṭīvrata": ['mw'],
    "kurmala": ['mw'],
    "kurpara": ['mw'],
    "kurparaḥ": ['ap90'],
    "kurpāsa": ['mw'],
    "kurpāsaḥ": ['ap90'],
    "kuru": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kurubaka": ['ap90', 'ddsa'],
    "kurubilva": ['mw'],
    "kurubilvaka": ['mw'],
    "kurubāhu": ['mw'],
    "kurucara": ['mw'],
    "kurucilla": ['mw'],
    "kurugārhapata": ['mw'],
    "kuruha": ['mw'],
    "kuruhāra": ['mw'],
    "kurujāṅgala": ['mw'],
    "kuruka": ['mw'],
    "kurukandaka": ['mw'],
    "kurukata": ['mw'],
    "kurukuci": ['bhs'],
    "kurukulla": ['bhs'],
    "kurukullakā": ['bhs'],
    "kurukullā": ['mw'],
    "kurukurujāṅgala": ['mw'],
    "kurukurukṣetra": ['mw'],
    "kurukurāy": ['cae'],
    "kurukṣetra": ['ap90', 'cae', 'ddsa', 'mw'],
    "kurukṣetraka": ['mw'],
    "kurukṣetrin": ['mw'],
    "kurula": ['mw'],
    "kurulaḥ": ['ap90'],
    "kurumba": ['mw'],
    "kurumbikā": ['mw'],
    "kurumbā": ['mw'],
    "kurumbī": ['mw'],
    "kurumāna": ['cped'],
    "kurunadikā": ['mw'],
    "kurunandana": ['ddsa', 'mw'],
    "kurupatha": ['mw'],
    "kurupañcāla": ['cae', 'mw'],
    "kurupañcālatrā": ['mw'],
    "kurupiśaṅgila": ['mw'],
    "kurupuṃgava": ['mw'],
    "kurupāṇḍava": ['cae', 'mw'],
    "kururaṭṭharu": ['cped'],
    "kururāj": ['mw'],
    "kururāja": ['mw'],
    "kururājya": ['mw'],
    "kururī": ['ap90', 'mw'],
    "kurusattama": ['mw'],
    "kurusuti": ['mw'],
    "kuruta": ['mw'],
    "kurutapāda": ['mw'],
    "kurutaṁ": ['cped'],
    "kurute": ['cped'],
    "kurutā": ['ddsa', 'mw'],
    "kurutīrtha": ['mw'],
    "kuruvaka": ['mw'],
    "kuruvarṇaka": ['mw'],
    "kuruvatsa": ['mw'],
    "kuruvaśa": ['mw'],
    "kuruvaṃśa": ['mw'],
    "kuruvaṃśaka": ['mw'],
    "kuruvinda": ['bhs', 'ddsa', 'mw'],
    "kuruvindaka": ['cped', 'mw'],
    "kuruvindakacuṇṇa": ['cped'],
    "kuruvista": ['mw'],
    "kuruviṃdaḥ": ['ap90'],
    "kuruvājapeya": ['mw'],
    "kuruvṛddha": ['cae', 'mw'],
    "kuruśravaṇa": ['gra', 'mw'],
    "kuruśreṣṭha": ['mw'],
    "kuruḥ": ['ap90'],
    "kuruṃbaṃ": ['ap90'],
    "kuruṃḍa": ['ap90'],
    "kuruṃṭakaḥ": ['ap90'],
    "kuruṃṭaḥ": ['ap90'],
    "kuruṅga": ['gra', 'mw'],
    "kuruṇḍi": ['mw'],
    "kuruṇṭa": ['mw'],
    "kuruṇṭaka": ['mw'],
    "kuruṇṭha": ['mw'],
    "kuruṇṭikā": ['mw'],
    "kuruṇṭī": ['mw'],
    "kuruṭa": ['mw'],
    "kuruṭaḥ": ['ap90'],
    "kuruṭin": ['ap90', 'mw'],
    "kuruṭu": ['bhs'],
    "kurvadrūpa": ['mw'],
    "kurvat": ['ap90', 'ddsa', 'mw'],
    "kurvati": ['bhs'],
    "kurvāṇa": ['ddsa', 'mw'],
    "kurāhaḥ": ['ap90'],
    "kurājan": ['mw'],
    "kurājya": ['mw'],
    "kurālaḥ": ['ap90'],
    "kurī": ['ap90', 'mw'],
    "kurīra": ['cae', 'gra', 'mw'],
    "kurīraṃ": ['ap90'],
    "kurīrin": ['mw'],
    "kurūpa": ['cae', 'ddsa', 'mw'],
    "kurūpatva": ['mw'],
    "kurūpatā": ['mw'],
    "kurūpin": ['mw'],
    "kurūpya": ['mw'],
    "kurūra": ['cped'],
    "kurūrakammanta": ['cped'],
    "kurūru": ['cae', 'ddsa', 'mw'],
    "kurūṭin": ['mw'],
    "kurṇaja": ['mw'],
    "kus": ['ap90', 'mw'],
    "kusa": ['cped'],
    "kusaciva": ['mw'],
    "kusacīra": ['cped'],
    "kusagga": ['cped'],
    "kusahāya": ['mw'],
    "kusakhī": ['ddsa', 'mw'],
    "kusala": ['cped', 'mw'],
    "kusalabhāgiya": ['cped'],
    "kusalapakkha": ['cped'],
    "kusalapakkhika": ['cped'],
    "kusali": ['cped'],
    "kusalin": ['cped'],
    "kusalupasaṁhita": ['cped'],
    "kusalā dhammā": ['cped'],
    "kusalābhisanda": ['cped'],
    "kusalānuesi": ['cped'],
    "kusalānuesin": ['cped'],
    "kusalāyatika": ['cped'],
    "kusambandha": ['mw'],
    "kusapāta": ['cped'],
    "kusarit": ['mw'],
    "kusauhṛda": ['ddsa', 'mw'],
    "kusaṃgata": ['mw'],
    "kusi": ['cped'],
    "kusida": ['ap90', 'mw'],
    "kusidāyī": ['cae', 'mw'],
    "kusimbī": ['mw'],
    "kusindha": ['cae', 'mw'],
    "kusita": ['mw'],
    "kusitaḥ": ['ap90'],
    "kusitā": ['cae', 'mw'],
    "kusitāyī": ['cae', 'mw'],
    "kusmaya": ['mw'],
    "kusmayana": ['mw'],
    "kusmayate": ['ap90'],
    "kusmita": ['mw'],
    "kusobbha": ['cped'],
    "kussobbha": ['cped'],
    "kussubbha": ['cped'],
    "kusthalapura": ['mw'],
    "kusthāna": ['mw'],
    "kustrī": ['cae', 'mw'],
    "kustrīka": ['mw'],
    "kustubha": ['mw'],
    "kustubhaḥ": ['ap90'],
    "kustuka": ['mw'],
    "kustumbaru": ['mw'],
    "kustumbarī": ['mw'],
    "kustumburu": ['mw'],
    "kustā": ['mw'],
    "kusubbha": ['cped'],
    "kusulaka": ['bhs'],
    "kusuma": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kusumabāṇa": ['mw'],
    "kusumacita": ['mw'],
    "kusumacāpa": ['cae', 'mw'],
    "kusumacūḍa": ['bhs'],
    "kusumadanta": ['mw'],
    "kusumadeva": ['mw'],
    "kusumadhanus": ['mw'],
    "kusumadhanvan": ['cae', 'mw'],
    "kusumadhvaja": ['bhs', 'mw'],
    "kusumadruma": ['mw'],
    "kusumadāyin": ['cae', 'mw'],
    "kusumagarbha": ['bhs'],
    "kusumagupta": ['bhs'],
    "kusumahestha": ['bhs'],
    "kusumajaya": ['mw'],
    "kusumaketu": ['bhs', 'mw'],
    "kusumaketumaṇḍalin": ['bhs', 'mw'],
    "kusumakomala": ['cae', 'mw'],
    "kusumakuśa": ['bhs'],
    "kusumakārmuka": ['mw'],
    "kusumalakṣman": ['ddsa', 'mw'],
    "kusumalatā": ['mw'],
    "kusumalāvī": ['mw'],
    "kusumamadhya": ['mw'],
    "kusumamaya": ['cae', 'mw'],
    "kusumamālā": ['cae', 'mw'],
    "kusumamārgaṇa": ['mw'],
    "kusumanaga": ['mw'],
    "kusumanagara": ['mw'],
    "kusumaphala": ['mw'],
    "kusumaprabha": ['bhs', 'mw'],
    "kusumapura": ['mw'],
    "kusumaraja": ['cped'],
    "kusumarāśi": ['bhs'],
    "kusumasambhava": ['mw'],
    "kusumasanātha": ['mw'],
    "kusumasaṃbhava": ['bhs'],
    "kusumastabaka": ['mw'],
    "kusumasāra": ['mw'],
    "kusumasāyaka": ['mw'],
    "kusumavat": ['ap90', 'mw'],
    "kusumavatī": ['ap90', 'mw'],
    "kusumavicitra": ['mw'],
    "kusumavicitrā": ['mw'],
    "kusumavṛṣtyabhiprakīrṇa": ['mw'],
    "kusumavṛṣṭyabhiprakīrṇa": ['bhs'],
    "kusumay": ['cae'],
    "kusumaya": ['ddsa', 'mw'],
    "kusumaśara": ['cae', 'mw'],
    "kusumaśaratva": ['mw'],
    "kusumaśarāsana": ['mw'],
    "kusumaśayana": ['bhs', 'cae', 'mw'],
    "kusumaśekharavijaya": ['mw'],
    "kusumaśrī": ['bhs'],
    "kusumaśrīgarbha": ['bhs'],
    "kusumaṃ": ['ap90'],
    "kusumbaka": ['mw'],
    "kusumbha": ['bhs', 'cae', 'ddsa', 'mw'],
    "kusumbhakṣetra": ['cae'],
    "kusumbhalā": ['mw'],
    "kusumbharāga": ['mw'],
    "kusumbhavant": ['cae'],
    "kusumbhavat": ['mw'],
    "kusumbhī": ['mw'],
    "kusumeśvaratīrtha": ['mw'],
    "kusumeṣu": ['ddsa', 'mw'],
    "kusumita": ['ap90', 'cae', 'ddsa', 'mw'],
    "kusumitalatā": ['mw'],
    "kusumitalatāvellikā": ['mw'],
    "kusumitasikhara": ['cped'],
    "kusumoda": ['mw'],
    "kusumodgama": ['cae'],
    "kusumojjvala": ['mw'],
    "kusumotpala": ['bhs'],
    "kusumottama": ['bhs'],
    "kusumottarajñānin": ['bhs'],
    "kusumottarīya": ['bhs'],
    "kusumya": ['mw'],
    "kusumā": ['bhs'],
    "kusumābhijña": ['bhs', 'mw'],
    "kusumādhipa": ['mw'],
    "kusumādhirāj": ['mw'],
    "kusumākara": ['cae', 'ddsa', 'mw'],
    "kusumāla": ['mw'],
    "kusumālaḥ": ['ap90'],
    "kusumāpīḍa": ['cae', 'mw'],
    "kusumārcisāgarapradīpa": ['bhs'],
    "kusumāsava": ['mw'],
    "kusumāstaraṇa": ['cae'],
    "kusumāstra": ['mw'],
    "kusumātmaka": ['mw'],
    "kusumāvacaya": ['cae', 'mw'],
    "kusumāvalī": ['mw'],
    "kusumāvataṃsaka": ['mw'],
    "kusumāvatī": ['bhs'],
    "kusumāyudha": ['cae', 'mw'],
    "kusumāñjali": ['cae', 'mw'],
    "kusumāñjalikārikāvyākhyā": ['mw'],
    "kusumāñjalimakaraṇḍa": ['mw'],
    "kusumāñjaliprakāśa": ['mw'],
    "kusumāñjaliprakāśamakaraṇḍa": ['mw'],
    "kusumāñjalivyākhyā": ['mw'],
    "kusumāñjalivṛtti": ['mw'],
    "kusumāñjaliṭīkā": ['mw'],
    "kusumāñjana": ['mw'],
    "kusumāḍhya": ['cae'],
    "kusurubinda": ['mw'],
    "kusurubindadaśarātra": ['mw'],
    "kusurubindu": ['mw'],
    "kusurubindutrirātra": ['mw'],
    "kusuta": ['mw'],
    "kusuvā": ['bhs'],
    "kusuṃbhaḥ": ['ap90'],
    "kusvapna": ['mw'],
    "kusvāmin": ['mw'],
    "kusāpāta": ['cped'],
    "kusārathi": ['mw'],
    "kusāvahāra": ['cped'],
    "kusīda": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kusīdapatha": ['cae', 'mw'],
    "kusīdavṛddhi": ['cae', 'mw'],
    "kusīdika": ['mw'],
    "kusīdikaḥ": ['ap90'],
    "kusīdin": ['cae', 'ddsa', 'mw'],
    "kusīdā": ['ap90'],
    "kusīdāyī": ['ap90', 'mw'],
    "kusīta": ['cped'],
    "kusū": ['ap90', 'mw'],
    "kusūla": ['cae', 'ddsa', 'mw'],
    "kusūlabila": ['mw'],
    "kusūladhānya": ['mw'],
    "kusūladhānyaka": ['cae', 'mw'],
    "kusūlaka": ['bhs'],
    "kusūlapāda": ['mw'],
    "kusūlapūraṇāḍhaka": ['mw'],
    "kusūlaḥ": ['ap90'],
    "kusūtra": ['bhs'],
    "kusṛti": ['ddsa', 'mw'],
    "kusṛtiḥ": ['ap90'],
    "kut": ['mw'],
    "kuta": ['mw'],
    "kutalipi": ['bhs'],
    "kutanaya": ['ddsa', 'mw'],
    "kutantrī": ['mw'],
    "kutanu": ['mw'],
    "kutapa": ['cae', 'ddsa', 'mw'],
    "kutapahāra": ['mw'],
    "kutapasaptaka": ['mw'],
    "kutapasauśruta": ['mw'],
    "kutapasvin": ['ddsa', 'mw'],
    "kutapavinyāsa": ['mw'],
    "kutapaḥ": ['ap90'],
    "kutarka": ['mw'],
    "kutarkapatha": ['mw'],
    "kutarārkaka": ['bhs'],
    "kutas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kutasta": ['mw'],
    "kutastama": ['mw'],
    "kutastarām": ['mw'],
    "kutastya": ['ap90', 'ddsa', 'mw'],
    "kuth": ['ap90', 'cae', 'ddsa', 'mw'],
    "kutha": ['cae', 'ddsa', 'mw'],
    "kuthaka": ['mw'],
    "kuthaḥ": ['ap90'],
    "kuthita": ['cped', 'mw'],
    "kuthodarī": ['mw'],
    "kuthuma": ['mw'],
    "kuthumi": ['mw'],
    "kuthumin": ['mw'],
    "kutittiri": ['mw'],
    "kuto": ['cped', 'mw'],
    "kutoci": ['cped'],
    "kutomūla": ['mw'],
    "kutonimitta": ['mw'],
    "kutra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kutratya": ['ap90', 'ddsa', 'mw'],
    "kuts": ['ap90', 'mw'],
    "kutsa": ['cae', 'ddsa', 'gra', 'mw'],
    "kutsaka": ['bhs'],
    "kutsakuśikikā": ['mw'],
    "kutsalā": ['mw'],
    "kutsana": ['cae', 'mw'],
    "kutsanaṃ": ['ap90'],
    "kutsanā": ['mw'],
    "kutsanīya": ['bhs'],
    "kutsaputra": ['gra', 'mw'],
    "kutsava": ['mw'],
    "kutsavatsa": ['gra', 'mw'],
    "kutsay": ['cae'],
    "kutsayā": ['mw'],
    "kutsia": ['gra'],
    "kutsita": ['ap90', 'mw'],
    "kutsya": ['cae', 'gra', 'mw'],
    "kutsā": ['cae', 'mw'],
    "kutsāra": ['mw'],
    "kutsāyana": ['mw'],
    "kutsībhū": ['mw'],
    "kutta": ['cped'],
    "kuttaka": ['cped'],
    "kuttaṃ": ['bhs'],
    "kuttha": ['mw'],
    "kutuka": ['cae', 'ddsa', 'mw'],
    "kutukaṃ": ['ap90'],
    "kutukin": ['mw'],
    "kutukita": ['mw'],
    "kutumbuka": ['mw'],
    "kutumburu": ['mw'],
    "kutupa": ['bhs', 'mw'],
    "kutupaḥ": ['ap90'],
    "kutāpasa": ['ddsa', 'mw'],
    "kutāpasī": ['mw'],
    "kutārkika": ['mw'],
    "kutīpāda": ['mw'],
    "kutīrtha": ['mw'],
    "kutū": ['mw'],
    "kutūhala": ['ap90', 'cae', 'ddsa', 'mw'],
    "kutūhalakṛt": ['mw'],
    "kutūhalamaṅgala": ['cped'],
    "kutūhalavant": ['cae'],
    "kutūhalavat": ['mw'],
    "kutūhalaśālā": ['bhs', 'mw'],
    "kutūhalin": ['ap90', 'cae', 'ddsa', 'mw'],
    "kutūhalita": ['mw'],
    "kutūsālā": ['cped'],
    "kutūṇaka": ['mw'],
    "kutṛṇa": ['mw'],
    "kuva": ['mw'],
    "kuvaca": ['mw'],
    "kuvada": ['mw'],
    "kuvadhū": ['ddsa', 'mw'],
    "kuvaidya": ['mw'],
    "kuvaikaṭika": ['mw'],
    "kuvajraka": ['mw'],
    "kuvakra": ['mw'],
    "kuvakālukā": ['mw'],
    "kuvala": ['cae', 'ddsa', 'mw'],
    "kuvalakuṇa": ['mw'],
    "kuvalaprastha": ['mw'],
    "kuvalasaktu": ['mw'],
    "kuvalaya": ['cae', 'ddsa', 'mw'],
    "kuvalayadṛś": ['cae', 'mw'],
    "kuvalayamaya": ['mw'],
    "kuvalayamālā": ['mw'],
    "kuvalayanayanā": ['cae', 'mw'],
    "kuvalayapura": ['mw'],
    "kuvalayavatī": ['mw'],
    "kuvalayaṃ": ['ap90'],
    "kuvalayeśa": ['ddsa', 'mw'],
    "kuvalayin": ['ap90'],
    "kuvalayinī": ['ap90', 'mw'],
    "kuvalayita": ['ap90', 'cae', 'ddsa', 'mw'],
    "kuvalayā": ['bhs', 'mw'],
    "kuvalayāditya": ['ddsa', 'mw'],
    "kuvalayākṣi": ['cae'],
    "kuvalayānanda": ['cae', 'mw'],
    "kuvalayāpīḍa": ['mw'],
    "kuvalayāvalī": ['mw'],
    "kuvalayāśva": ['mw'],
    "kuvalayāśvacaritra": ['mw'],
    "kuvalayāśvaka": ['mw'],
    "kuvalayāśvīya": ['mw'],
    "kuvalaṃ": ['ap90'],
    "kuvaleśaya": ['mw'],
    "kuvalāśva": ['mw'],
    "kuvama": ['mw'],
    "kuvamaḥ": ['ap90'],
    "kuvapus": ['mw'],
    "kuvara": ['ap90', 'mw'],
    "kuvartman": ['mw'],
    "kuvarī": ['mw'],
    "kuvarṣa": ['mw'],
    "kuvastra": ['ddsa', 'mw'],
    "kuvaya": ['cae', 'mw'],
    "kuvaṁ": ['cped'],
    "kuvaṃ": ['ap90'],
    "kuvaṅga": ['mw'],
    "kuvaṇij": ['ddsa', 'mw'],
    "kuvedhas": ['mw'],
    "kuvela": ['mw'],
    "kuvelaṃ": ['ap90'],
    "kuvera": ['bhs', 'mw'],
    "kuveraḥ": ['ap90'],
    "kuveṇā": ['mw'],
    "kuveṇī": ['ap90', 'mw'],
    "kuvid": ['cae', 'ddsa', 'gra', 'mw'],
    "kuvikrama": ['mw'],
    "kuvinda": ['cae', 'ddsa', 'mw'],
    "kuvindaka": ['cae', 'mw'],
    "kuvitsa": ['cae', 'gra', 'mw'],
    "kuvivāha": ['cae', 'ddsa', 'mw'],
    "kuviḍambanā": ['mw'],
    "kuviṃdaḥ": ['ap90'],
    "kuvyāpāra": ['mw'],
    "kuvāc": ['mw'],
    "kuvāda": ['ap90', 'mw'],
    "kuvādika": ['mw'],
    "kuvāhulaḥ": ['ap90'],
    "kuvākya": ['mw'],
    "kuvāṭa": ['mw'],
    "kuvāṭaka": ['mw'],
    "kuvāṭaḥ": ['ap90'],
    "kuvīrā": ['mw'],
    "kuvīṇā": ['mw'],
    "kuvṛtti": ['mw'],
    "kuvṛttikṛt": ['mw'],
    "kuvṛṣala": ['mw'],
    "kuyajvin": ['mw'],
    "kuyava": ['cae', 'gra', 'mw'],
    "kuyavāc": ['cae', 'gra', 'mw'],
    "kuyoga": ['mw'],
    "kuyogin": ['mw'],
    "kuyoni": ['mw'],
    "kuñc": ['mw'],
    "kuñcana": ['cae', 'ddsa', 'mw'],
    "kuñcaphalā": ['mw'],
    "kuñci": ['cae', 'ddsa', 'mw'],
    "kuñcikā": ['cae', 'ddsa', 'mw'],
    "kuñcita": ['cae', 'mw'],
    "kuñcitā": ['mw'],
    "kuñcitāṅguli": ['mw'],
    "kuñcī": ['cae', 'ddsa', 'mw'],
    "kuñj": ['cae', 'ddsa', 'mw'],
    "kuñja": ['cae', 'ddsa', 'mw'],
    "kuñjakuṭīra": ['mw'],
    "kuñjala": ['mw'],
    "kuñjara": ['cae', 'cped', 'ddsa', 'mw'],
    "kuñjaradarī": ['mw'],
    "kuñjaragati": ['bhs'],
    "kuñjaragraha": ['mw'],
    "kuñjarakara": ['mw'],
    "kuñjarakṣāramūla": ['mw'],
    "kuñjarapippalī": ['mw'],
    "kuñjarapādapa": ['mw'],
    "kuñjararūpin": ['mw'],
    "kuñjaratva": ['mw'],
    "kuñjarā": ['mw'],
    "kuñjarābhiruda": ['cped'],
    "kuñjarāluka": ['mw'],
    "kuñjarānīka": ['mw'],
    "kuñjarāroha": ['mw'],
    "kuñjarārāti": ['mw'],
    "kuñjarāśana": ['mw'],
    "kuñjarī": ['mw'],
    "kuñjavallarī": ['mw'],
    "kuñjavallī": ['mw'],
    "kuñjikā": ['mw'],
    "kuñjādi": ['mw'],
    "kuś": ['ddsa', 'gra', 'mw'],
    "kuśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "kuśabhāra": ['mw'],
    "kuśabindu": ['mw'],
    "kuśacīra": ['mw'],
    "kuśacīrin": ['mw'],
    "kuśacīrā": ['mw'],
    "kuśadhvaja": ['mw'],
    "kuśadhārā": ['mw'],
    "kuśadruma": ['bhs'],
    "kuśadvīpa": ['mw'],
    "kuśadūrvāmaya": ['mw'],
    "kuśahasta": ['mw'],
    "kuśaja": ['mw'],
    "kuśaketu": ['mw'],
    "kuśakāśamaya": ['mw'],
    "kuśala": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kuśalabuddhi": ['mw'],
    "kuśalacampū": ['mw'],
    "kuśalakāma": ['mw'],
    "kuśalakāraṇa": ['ddsa'],
    "kuśalam": ['mw'],
    "kuśalamataprasaṅga": ['mw'],
    "kuśalamūla": ['bhs', 'mw'],
    "kuśalapakṣa": ['bhs'],
    "kuśalapraśna": ['cae', 'mw'],
    "kuśalapuṇya": ['bhs'],
    "kuśalasāgara": ['mw'],
    "kuśalatva": ['mw'],
    "kuśalatā": ['cae', 'mw'],
    "kuśalava": ['mw'],
    "kuśalavant": ['cae'],
    "kuśalavarta": ['bhs'],
    "kuśalavat": ['mw'],
    "kuśalavāc": ['cae', 'mw'],
    "kuśalena": ['mw'],
    "kuśaletara": ['mw'],
    "kuśalin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kuśalya": ['mw'],
    "kuśalā": ['mw'],
    "kuśalāvasānatā": ['cae', 'mw'],
    "kuśalī": ['mw'],
    "kuśalīkṛ": ['cae', 'ddsa', 'mw'],
    "kuśamuṣṭi": ['mw'],
    "kuśamālin": ['bhs', 'mw'],
    "kuśanagara": ['bhs', 'mw'],
    "kuśanetra": ['mw'],
    "kuśanābha": ['mw'],
    "kuśanāman": ['mw'],
    "kuśanāra": ['mw'],
    "kuśapa": ['mw'],
    "kuśapavitra": ['mw'],
    "kuśaplava": ['mw'],
    "kuśaplavana": ['mw'],
    "kuśaprasū": ['mw'],
    "kuśapuṣpa": ['mw'],
    "kuśapuṣpaka": ['mw'],
    "kuśara": ['cae', 'gra', 'mw'],
    "kuśarajju": ['mw'],
    "kuśarīra": ['mw'],
    "kuśarīrabhṛt": ['mw'],
    "kuśastamba": ['cae', 'mw'],
    "kuśasthala": ['mw'],
    "kuśasthalī": ['mw'],
    "kuśavat": ['ddsa', 'mw'],
    "kuśavatī": ['mw'],
    "kuśavāri": ['cae', 'mw'],
    "kuśavīrā": ['mw'],
    "kuśaya": ['mw'],
    "kuśayaḥ": ['ap90'],
    "kuśaḥ": ['ap90'],
    "kuśaṅku": ['mw'],
    "kuśaṇḍa": ['mw'],
    "kuśaṇḍikā": ['bhs', 'mw'],
    "kuśaṇḍī": ['mw'],
    "kuśeśaya": ['cae', 'ddsa', 'mw'],
    "kuśeśayabhū": ['mw'],
    "kuśeśayakara": ['mw'],
    "kuśeśayalocanā": ['mw'],
    "kuśeśayamaya": ['mw'],
    "kuśeśayaṃ": ['ap90'],
    "kuśeśayākṣa": ['mw'],
    "kuśeṇḍva": ['mw'],
    "kuśi": ['mw'],
    "kuśigrāmaka": ['bhs', 'mw'],
    "kuśika": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kuśikasūtra": ['mw'],
    "kuśikaṃdhara": ['mw'],
    "kuśikā": ['mw'],
    "kuśimbi": ['mw'],
    "kuśimbī": ['mw'],
    "kuśin": ['ap90', 'mw'],
    "kuśinagara": ['mw'],
    "kuśinagarī": ['bhs', 'mw'],
    "kuśita": ['mw'],
    "kuśiṃśapā": ['mw'],
    "kuśiṣya": ['ddsa', 'mw'],
    "kuśodaka": ['cae', 'mw'],
    "kuśodakā": ['mw'],
    "kuśorṇā": ['cae', 'mw'],
    "kuśri": ['cae', 'mw'],
    "kuśruta": ['ddsa', 'mw'],
    "kuśuṃbhaḥ": ['ap90'],
    "kuśvabhra": ['mw'],
    "kuśā": ['ap90', 'mw'],
    "kuśāgra": ['ddsa', 'mw'],
    "kuśāgrabuddhi": ['mw'],
    "kuśāgrīya": ['mw'],
    "kuśāgrīyamati": ['mw'],
    "kuśākara": ['mw'],
    "kuśākṣa": ['mw'],
    "kuśākṣī": ['bhs'],
    "kuśāla": ['mw'],
    "kuśālmalī": ['mw'],
    "kuśāmba": ['mw'],
    "kuśāmbu": ['mw'],
    "kuśāraṇi": ['mw'],
    "kuśāsana": ['mw'],
    "kuśāvaleha": ['mw'],
    "kuśāvarta": ['mw'],
    "kuśāvatī": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kuśāśva": ['mw'],
    "kuśāṅgurīya": ['mw'],
    "kuśāṅgurīyaka": ['mw'],
    "kuśāṅkura": ['mw'],
    "kuśī": ['mw'],
    "kuśīda": ['bhs', 'mw'],
    "kuśīdaṃ": ['ap90'],
    "kuśīla": ['ddsa', 'mw'],
    "kuśīlava": ['cae', 'mw'],
    "kuśīlavau": ['mw'],
    "kuśīlavaḥ": ['ap90'],
    "kuśīnagarī": ['bhs'],
    "kuśīraka": ['mw'],
    "kuśīti": ['mw'],
    "kuśīvaśa": ['mw'],
    "kuśūla": ['cae', 'ddsa', 'mw'],
    "kuśūladhānyaka": ['cae'],
    "kuśūlaḥ": ['ap90'],
    "kuḍ": ['ap90', 'mw'],
    "kuḍapa": ['mw'],
    "kuḍava": ['ddsa', 'mw'],
    "kuḍavaḥ": ['ap90'],
    "kuḍaṃgaḥ": ['ap90'],
    "kuḍaṅga": ['mw'],
    "kuḍi": ['mw'],
    "kuḍikā": ['ap90', 'mw'],
    "kuḍiśa": ['mw'],
    "kuḍiḥ": ['ap90'],
    "kuḍmala": ['ap90', 'cae', 'ddsa', 'mw'],
    "kuḍmaladantī": ['mw'],
    "kuḍmalaka": ['bhs'],
    "kuḍmalatā": ['mw'],
    "kuḍmalita": ['ap90', 'cae', 'mw'],
    "kuḍmalāgradanta": ['mw'],
    "kuḍmalāgradat": ['mw'],
    "kuḍmalāya": ['mw'],
    "kuḍukka": ['mw'],
    "kuḍumalaka": ['cped'],
    "kuḍupa": ['mw'],
    "kuḍupaḥ": ['ap90'],
    "kuḍya": ['cae', 'ddsa', 'mw'],
    "kuḍyacchedin": ['mw'],
    "kuḍyacchedya": ['mw'],
    "kuḍyaka": ['mw'],
    "kuḍyalepa": ['mw'],
    "kuḍyamatsya": ['mw'],
    "kuḍyamatsī": ['mw'],
    "kuḍyamūla": ['bhs'],
    "kuḍyapucchā": ['mw'],
    "kuḍyaṃ": ['ap90'],
    "kuḍyā": ['bhs', 'mw'],
    "kuḍālagācchi": ['mw'],
    "kuḍāyikā": ['mw'],
    "kuḍāyī": ['mw'],
    "kuḍī": ['ap90', 'mw'],
    "kuḍūhuñcī": ['mw'],
    "kuḍḍa": ['bhs', 'cped'],
    "kuḍḍamūla": ['cped'],
    "kuḍḍanagaraka": ['cped'],
    "kuḍḍarāja": ['cped'],
    "kuḍḍarājan": ['cped'],
    "kuḥ": ['ap90'],
    "kuḷīraka": ['cped'],
    "kuḷīrapādaka": ['cped'],
    "kuṃbaḥ": ['ap90'],
    "kuṃbhakaḥ": ['ap90'],
    "kuṃbhaḥ": ['ap90'],
    "kuṃbhikā": ['ap90'],
    "kuṃbhilaḥ": ['ap90'],
    "kuṃbhin": ['ap90'],
    "kuṃbhī": ['ap90'],
    "kuṃbhīkaḥ": ['ap90'],
    "kuṃbhīrakaḥ": ['ap90'],
    "kuṃbhīraḥ": ['ap90'],
    "kuṃc": ['ap90'],
    "kuṃcanaṃ": ['ap90'],
    "kuṃcikā": ['ap90'],
    "kuṃcita": ['ap90'],
    "kuṃciḥ": ['ap90'],
    "kuṃdamaḥ": ['ap90'],
    "kuṃdaraḥ": ['ap90'],
    "kuṃdaḥ": ['ap90'],
    "kuṃdinī": ['ap90'],
    "kuṃduḥ": ['ap90'],
    "kuṃj": ['ap90'],
    "kuṃjalaṃ": ['ap90'],
    "kuṃjaraḥ": ['ap90'],
    "kuṃjaḥ": ['ap90'],
    "kuṃkumaṃ": ['ap90'],
    "kuṃs": ['ap90', 'mw'],
    "kuṃsa": ['mw'],
    "kuṃsana": ['bhs'],
    "kuṃtala": ['ap90'],
    "kuṃtalaḥ": ['ap90'],
    "kuṃtalikā": ['ap90'],
    "kuṃtayaḥ": ['ap90'],
    "kuṃtaḥ": ['ap90'],
    "kuṃth": ['ap90'],
    "kuṃtiḥ": ['ap90'],
    "kuṃtī": ['ap90'],
    "kuṃś": ['ap90', 'mw'],
    "kuṃśa": ['mw'],
    "kuṃḍ": ['ap90'],
    "kuṃḍalanā": ['ap90'],
    "kuṃḍalaḥ": ['ap90'],
    "kuṃḍalin": ['ap90'],
    "kuṃḍalīkṛta": ['ap90'],
    "kuṃḍaḥ": ['ap90'],
    "kuṃḍikā": ['ap90'],
    "kuṃḍin": ['ap90'],
    "kuṃḍinaṃ": ['ap90'],
    "kuṃḍira": ['ap90'],
    "kuṃḍīra": ['ap90'],
    "kuṃṭaka": ['ap90'],
    "kuṃṭh": ['ap90'],
    "kuṃṭha": ['ap90'],
    "kuṃṭhakaḥ": ['ap90'],
    "kuṃṭhita": ['ap90'],
    "kuṅganī": ['mw'],
    "kuṅkuma": ['cae', 'ddsa', 'mw'],
    "kuṅkumapaṅka": ['mw'],
    "kuṅkumareṇu": ['mw'],
    "kuṅkumatāmra": ['mw'],
    "kuṅkumākta": ['mw'],
    "kuṅkumākṛti": ['mw'],
    "kuṅkumāruṇa": ['mw'],
    "kuṅkumāṅka": ['mw'],
    "kuṅkuṇa": ['mw'],
    "kuṇ": ['ap90', 'mw'],
    "kuṇa": ['mw'],
    "kuṇajī": ['mw'],
    "kuṇaka": ['mw'],
    "kuṇakaḥ": ['ap90'],
    "kuṇapa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kuṇapabhuj": ['cae', 'mw'],
    "kuṇapagandha": ['mw'],
    "kuṇapagandhi": ['mw'],
    "kuṇapāśana": ['mw'],
    "kuṇapāṇḍya": ['mw'],
    "kuṇapī": ['mw'],
    "kuṇaravāḍava": ['mw'],
    "kuṇañja": ['mw'],
    "kuṇañjara": ['mw'],
    "kuṇi": ['cae', 'cped', 'ddsa', 'mw'],
    "kuṇibāhu": ['mw'],
    "kuṇika": ['mw'],
    "kuṇin": ['mw'],
    "kuṇinda": ['mw'],
    "kuṇipadī": ['mw'],
    "kuṇitva": ['mw'],
    "kuṇitāhi": ['mw'],
    "kuṇiḥ": ['ap90'],
    "kuṇāla": ['bhs', 'cped', 'mw'],
    "kuṇāru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kuṇāvī": ['mw'],
    "kuṇḍ": ['mw'],
    "kuṇḍa": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kuṇḍabhedin": ['mw'],
    "kuṇḍadhāra": ['mw'],
    "kuṇḍagola": ['mw'],
    "kuṇḍagolaka": ['mw'],
    "kuṇḍaja": ['mw'],
    "kuṇḍajaṭhara": ['mw'],
    "kuṇḍaka": ['bhs', 'cae', 'mw'],
    "kuṇḍakalpadruma": ['mw'],
    "kuṇḍakalpalatā": ['mw'],
    "kuṇḍakamattika": ['cped'],
    "kuṇḍakarṇa": ['mw'],
    "kuṇḍakaumudī": ['mw'],
    "kuṇḍakīla": ['mw'],
    "kuṇḍakīṭa": ['mw'],
    "kuṇḍala": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kuṇḍaladhāraṇa": ['mw'],
    "kuṇḍalaka": ['bhs', 'mw'],
    "kuṇḍalanā": ['mw'],
    "kuṇḍalavardhana": ['bhs'],
    "kuṇḍali": ['cped'],
    "kuṇḍalikā": ['bhs', 'mw'],
    "kuṇḍalikāmata": ['mw'],
    "kuṇḍalikātva": ['mw'],
    "kuṇḍalin": ['cae', 'cped', 'mw'],
    "kuṇḍalinī": ['mw'],
    "kuṇḍalita": ['mw'],
    "kuṇḍaloddyotitānana": ['mw'],
    "kuṇḍalā": ['bhs', 'mw'],
    "kuṇḍalākāra": ['mw'],
    "kuṇḍalāvatta": ['cped'],
    "kuṇḍalāvaṭṭa": ['cped'],
    "kuṇḍalī": ['mw'],
    "kuṇḍalībhūta": ['mw'],
    "kuṇḍalīkaraṇa": ['mw'],
    "kuṇḍalīkā": ['mw'],
    "kuṇḍalīkṛta": ['mw'],
    "kuṇḍamaṇḍapakaumudī": ['mw'],
    "kuṇḍamaṇḍapasaṃgraha": ['mw'],
    "kuṇḍamaṇḍapasiddhi": ['mw'],
    "kuṇḍamārtaṇḍa": ['mw'],
    "kuṇḍana": ['bhs'],
    "kuṇḍanadī": ['mw'],
    "kuṇḍanī": ['mw'],
    "kuṇḍaprastha": ['mw'],
    "kuṇḍapāyia": ['gra'],
    "kuṇḍapāyin": ['mw'],
    "kuṇḍapāyya": ['gra', 'mw'],
    "kuṇḍaratnākara": ['mw'],
    "kuṇḍasiddhi": ['mw'],
    "kuṇḍavidhāna": ['mw'],
    "kuṇḍavāsinī": ['mw'],
    "kuṇḍaśriyārciścandra": ['bhs'],
    "kuṇḍaśrī": ['bhs'],
    "kuṇḍaśāyin": ['mw'],
    "kuṇḍeśvaratīrtha": ['mw'],
    "kuṇḍi": ['mw'],
    "kuṇḍika": ['bhs', 'mw'],
    "kuṇḍikā": ['ddsa', 'mw'],
    "kuṇḍin": ['mw'],
    "kuṇḍina": ['cae', 'ddsa', 'mw'],
    "kuṇḍinanagara": ['cae'],
    "kuṇḍinapura": ['cae'],
    "kuṇḍinī": ['mw'],
    "kuṇḍoda": ['mw'],
    "kuṇḍodara": ['mw'],
    "kuṇḍodareśvara": ['mw'],
    "kuṇḍoddyotadarśana": ['mw'],
    "kuṇḍodhnī": ['mw'],
    "kuṇḍoghnī": ['ddsa'],
    "kuṇḍopadhānīyaka": ['bhs', 'mw'],
    "kuṇḍoparatha": ['mw'],
    "kuṇḍā": ['mw'],
    "kuṇḍāgni": ['mw'],
    "kuṇḍārka": ['mw'],
    "kuṇḍāvṛṣa": ['mw'],
    "kuṇḍāśin": ['cae', 'ddsa', 'mw'],
    "kuṇḍī": ['mw'],
    "kuṇḍīra": ['mw'],
    "kuṇḍīraka": ['bhs'],
    "kuṇḍīviṣa": ['mw'],
    "kuṇḍīvṛṣa": ['mw'],
    "kuṇḍṛṇācī": ['gra', 'mw'],
    "kuṇṭ": ['mw'],
    "kuṇṭaka": ['mw'],
    "kuṇṭh": ['cae', 'ddsa', 'mw'],
    "kuṇṭha": ['bhs', 'cae', 'ddsa', 'mw'],
    "kuṇṭhadhī": ['mw'],
    "kuṇṭhaka": ['bhs', 'mw'],
    "kuṇṭhamanas": ['mw'],
    "kuṇṭharava": ['mw'],
    "kuṇṭhatva": ['mw'],
    "kuṇṭhatā": ['mw'],
    "kuṇṭhita": ['mw'],
    "kuṇṭhitāśri": ['mw'],
    "kuṇṭhā": ['bhs'],
    "kuṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "kuṣala": ['ap90', 'mw'],
    "kuṣapa": ['mw'],
    "kuṣavā": ['cae', 'gra', 'mw'],
    "kuṣaṇḍa": ['mw'],
    "kuṣika": ['mw'],
    "kuṣita": ['ap90', 'mw'],
    "kuṣmala": ['mw'],
    "kuṣmalaṃ": ['ap90'],
    "kuṣmāṃḍakaḥ": ['ap90'],
    "kuṣmāṃḍaḥ": ['ap90'],
    "kuṣmāṇḍa": ['cae', 'ddsa', 'mw'],
    "kuṣmāṇḍaka": ['mw'],
    "kuṣmāṇḍī": ['mw'],
    "kuṣubhya": ['mw'],
    "kuṣubhyati": ['ap90'],
    "kuṣumbha": ['ddsa', 'gra', 'mw'],
    "kuṣumbhaka": ['gra', 'mw'],
    "kuṣāku": ['ap90', 'mw'],
    "kuṣāru": ['mw'],
    "kuṣīda": ['ap90', 'mw'],
    "kuṣīdin": ['mw'],
    "kuṣītaka": ['cae', 'ddsa', 'mw'],
    "kuṣṭa": ['mw'],
    "kuṣṭacit": ['mw'],
    "kuṣṭha": ['cae', 'ddsa', 'mw'],
    "kuṣṭhacikitsita": ['mw'],
    "kuṣṭhagala": ['mw'],
    "kuṣṭhagandhi": ['mw'],
    "kuṣṭhaghna": ['mw'],
    "kuṣṭhaghnī": ['mw'],
    "kuṣṭhagrāmaka": ['bhs'],
    "kuṣṭhahantrī": ['mw'],
    "kuṣṭhahantṛ": ['mw'],
    "kuṣṭhahara": ['mw'],
    "kuṣṭhahṛt": ['mw'],
    "kuṣṭhaja": ['mw'],
    "kuṣṭhaka": ['mw'],
    "kuṣṭhakanda": ['mw'],
    "kuṣṭhakaṇṭaka": ['mw'],
    "kuṣṭhaketu": ['mw'],
    "kuṣṭhala": ['mw'],
    "kuṣṭhamaya": ['mw'],
    "kuṣṭhanodana": ['mw'],
    "kuṣṭhanāśana": ['mw'],
    "kuṣṭhanāśinī": ['mw'],
    "kuṣṭharoga": ['mw'],
    "kuṣṭhasūdana": ['mw'],
    "kuṣṭhavid": ['mw'],
    "kuṣṭhaḥ": ['ap90'],
    "kuṣṭhikā": ['cae', 'ddsa', 'mw'],
    "kuṣṭhila": ['bhs'],
    "kuṣṭhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "kuṣṭhita": ['cae', 'mw'],
    "kuṣṭhā": ['mw'],
    "kuṣṭhānvita": ['mw'],
    "kuṣṭhāri": ['mw'],
    "kuṣṭhāṅga": ['mw'],
    "kuṭ": ['ap90', 'ddsa', 'mw'],
    "kuṭa": ['gra', 'mw'],
    "kuṭaca": ['mw'],
    "kuṭahārikā": ['mw'],
    "kuṭaja": ['cae', 'ddsa', 'mw'],
    "kuṭajakasāva": ['cped'],
    "kuṭajamallī": ['mw'],
    "kuṭajīva": ['mw'],
    "kuṭaka": ['bhs', 'mw'],
    "kuṭakaṃ": ['ap90'],
    "kuṭakuñcaka": ['bhs'],
    "kuṭakācala": ['mw'],
    "kuṭakārikā": ['mw'],
    "kuṭala": ['mw'],
    "kuṭalaṃ": ['ap90'],
    "kuṭan": ['mw'],
    "kuṭannaka": ['mw'],
    "kuṭannaṭa": ['mw'],
    "kuṭapa": ['mw'],
    "kuṭapaḥ": ['ap90'],
    "kuṭapinī": ['mw'],
    "kuṭara": ['mw'],
    "kuṭaraḥ": ['ap90'],
    "kuṭaru": ['cae', 'ddsa', 'mw'],
    "kuṭaruḥ": ['ap90'],
    "kuṭaruṇā": ['mw'],
    "kuṭaḥ": ['ap90'],
    "kuṭaṃgakaḥ": ['ap90'],
    "kuṭaṃkaḥ": ['ap90'],
    "kuṭaṅga": ['mw'],
    "kuṭaṅgaka": ['mw'],
    "kuṭaṅka": ['mw'],
    "kuṭha": ['mw'],
    "kuṭhara": ['ap90', 'mw'],
    "kuṭhaḥ": ['ap90'],
    "kuṭhera": ['mw'],
    "kuṭheraja": ['mw'],
    "kuṭheraka": ['mw'],
    "kuṭheraḥ": ['ap90'],
    "kuṭheru": ['mw'],
    "kuṭheruḥ": ['ap90'],
    "kuṭhi": ['mw'],
    "kuṭhika": ['mw'],
    "kuṭhiḥ": ['ap90'],
    "kuṭhumi": ['mw'],
    "kuṭhāku": ['mw'],
    "kuṭhākuḥ": ['ap90'],
    "kuṭhāra": ['cae', 'ddsa', 'mw'],
    "kuṭhāraka": ['cae', 'mw'],
    "kuṭhārakaḥ": ['ap90'],
    "kuṭhāraḥ": ['ap90'],
    "kuṭhārika": ['cae', 'mw'],
    "kuṭhārikaḥ": ['ap90'],
    "kuṭhārikā": ['ap90', 'mw'],
    "kuṭhāru": ['mw'],
    "kuṭhāruḥ": ['ap90'],
    "kuṭhārī": ['bhs', 'cped', 'mw'],
    "kuṭhārīpāsa": ['cped'],
    "kuṭhāṭaṃkaḥ": ['ap90'],
    "kuṭhāṭaṅka": ['mw'],
    "kuṭi": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kuṭicara": ['mw'],
    "kuṭigrāmaka": ['bhs'],
    "kuṭika": ['ap90', 'mw'],
    "kuṭikoṣṭikā": ['mw'],
    "kuṭikuṭī": ['mw'],
    "kuṭikuṭīkṛ": ['mw'],
    "kuṭikā": ['bhs', 'cped', 'mw'],
    "kuṭila": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "kuṭilagati": ['mw'],
    "kuṭilageśa": ['mw'],
    "kuṭilagā": ['mw'],
    "kuṭilagāmin": ['cae', 'mw'],
    "kuṭilagāmitva": ['mw'],
    "kuṭilaka": ['ap90', 'cae', 'mw'],
    "kuṭilakarkaśa": ['cae'],
    "kuṭilakeśa": ['cae'],
    "kuṭilakīṭaka": ['mw'],
    "kuṭilamanas": ['mw'],
    "kuṭilamati": ['mw'],
    "kuṭilapakṣman": ['mw'],
    "kuṭilapuṣpikā": ['mw'],
    "kuṭilasvabhāva": ['mw'],
    "kuṭilatva": ['mw'],
    "kuṭilatā": ['mw'],
    "kuṭilikā": ['ap90', 'ddsa', 'mw'],
    "kuṭilā": ['bhs', 'mw'],
    "kuṭilāśaya": ['ddsa', 'mw'],
    "kuṭilāṅgī": ['mw'],
    "kuṭilīkṛ": ['cae', 'ddsa', 'mw'],
    "kuṭipārthiva": ['mw'],
    "kuṭira": ['bhs', 'mw'],
    "kuṭiraṃ": ['ap90'],
    "kuṭita": ['mw'],
    "kuṭitṛ": ['mw'],
    "kuṭiñjara": ['mw'],
    "kuṭiḥ": ['ap90'],
    "kuṭmala": ['ap90', 'mw'],
    "kuṭmalībhūta": ['bhs'],
    "kuṭuka": ['mw'],
    "kuṭukuñcaka": ['bhs'],
    "kuṭumba": ['cae', 'cped', 'ddsa', 'mw'],
    "kuṭumbabharaṇa": ['cae'],
    "kuṭumbaka": ['cae', 'mw'],
    "kuṭumbakalaha": ['mw'],
    "kuṭumbaukas": ['mw'],
    "kuṭumbavyāpṛta": ['mw'],
    "kuṭumbaya": ['mw'],
    "kuṭumbika": ['mw'],
    "kuṭumbin": ['cae', 'ddsa', 'mw'],
    "kuṭumbinī": ['mw'],
    "kuṭumbitva": ['mw'],
    "kuṭumbitā": ['mw'],
    "kuṭumbārtham": ['mw'],
    "kuṭunī": ['ap90'],
    "kuṭuṃbaṃ": ['ap90'],
    "kuṭuṃbikaḥ": ['ap90'],
    "kuṭuṃgakaḥ": ['ap90'],
    "kuṭuṅgaka": ['mw'],
    "kuṭvudī": ['mw'],
    "kuṭāmoda": ['mw'],
    "kuṭī": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kuṭīcaka": ['mw'],
    "kuṭīcara": ['mw'],
    "kuṭīgata": ['mw'],
    "kuṭīgu": ['mw'],
    "kuṭīkuṭa": ['mw'],
    "kuṭīkā": ['ap90', 'mw'],
    "kuṭīkṛta": ['mw'],
    "kuṭīmaha": ['mw'],
    "kuṭīmaya": ['mw'],
    "kuṭīmukha": ['mw'],
    "kuṭīnivātam": ['mw'],
    "kuṭīpraveśa": ['mw'],
    "kuṭīra": ['cae', 'ddsa', 'mw'],
    "kuṭīraka": ['mw'],
    "kuṭīraḥ": ['ap90'],
    "kuṭīya": ['mw'],
    "kuṭṭ": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kuṭṭa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "kuṭṭahārikā": ['mw'],
    "kuṭṭaka": ['cae', 'mw'],
    "kuṭṭakavyavahāra": ['mw'],
    "kuṭṭakaḥ": ['ap90'],
    "kuṭṭakādhyāya": ['mw'],
    "kuṭṭamita": ['mw'],
    "kuṭṭamitaṃ": ['ap90'],
    "kuṭṭana": ['bhs', 'cae', 'ddsa', 'mw'],
    "kuṭṭanaṃ": ['ap90'],
    "kuṭṭantī": ['mw'],
    "kuṭṭanī": ['ap90', 'mw'],
    "kuṭṭapracaraṇa": ['mw'],
    "kuṭṭaprāvaraṇa": ['mw'],
    "kuṭṭha": ['cped'],
    "kuṭṭhi": ['cped'],
    "kuṭṭhika": ['cped'],
    "kuṭṭhin": ['cped'],
    "kuṭṭhiya": ['cped'],
    "kuṭṭihārikā": ['ap90'],
    "kuṭṭima": ['ap90', 'cae', 'ddsa', 'mw'],
    "kuṭṭimita": ['ap90'],
    "kuṭṭin": ['mw'],
    "kuṭṭinī": ['ap90', 'cae', 'ddsa', 'mw'],
    "kuṭṭinīputra": ['cae'],
    "kuṭṭita": ['ap90', 'mw'],
    "kuṭṭitika": ['bhs'],
    "kuṭṭitā": ['mw'],
    "kuṭṭumita": ['mw'],
    "kuṭṭā": ['bhs'],
    "kuṭṭāka": ['ap90', 'cae', 'mw'],
    "kuṭṭākāra": ['mw'],
    "kuṭṭāparānta": ['mw'],
    "kuṭṭāra": ['ddsa', 'mw'],
    "kuṭṭāraḥ": ['ap90'],
    "kuṭṭī": ['bhs'],
    "kuṭṭīra": ['mw'],
    "kuṭṭīrakaṃ": ['ap90'],
    "kuṭṭīraḥ": ['ap90'],
    "kva": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kvacana": ['cped'],
    "kvacani": ['cped'],
    "kvaci": ['cped'],
    "kvacini": ['cped'],
    "kvadhastha": ['mw'],
    "kvadhaḥstha": ['mw'],
    "kvaha": ['mw'],
    "kvajanman": ['mw'],
    "kvala": ['cae', 'mw'],
    "kvanivāsa": ['mw'],
    "kvastha": ['cae', 'ddsa', 'mw'],
    "kvasu": ['ddsa'],
    "kvath": ['ap90', 'cae', 'ddsa', 'mw'],
    "kvatha": ['cae', 'ddsa', 'mw'],
    "kvathana": ['cae', 'mw'],
    "kvathanaṃ": ['ap90'],
    "kvathaḥ": ['ap90'],
    "kvathikā": ['mw'],
    "kvathita": ['ap90', 'mw'],
    "kvathitadrava": ['mw'],
    "kvathitā": ['mw'],
    "kvatya": ['ap90', 'mw'],
    "kvatyaka": ['mw'],
    "kvayi": ['cae', 'mw'],
    "kvaṁ": ['cped'],
    "kvaṅgu": ['mw'],
    "kvaṇ": ['ap90', 'cae', 'ddsa', 'mw'],
    "kvaṇa": ['mw'],
    "kvaṇana": ['mw'],
    "kvaṇaḥ": ['ap90'],
    "kvaṇita": ['cae', 'mw'],
    "kvaṇitaveṇu": ['mw'],
    "kvaṇitekṣaṇa": ['mw'],
    "kvel": ['ap90', 'mw'],
    "kvip": ['ddsa'],
    "kvācitka": ['ap90', 'ddsa', 'mw'],
    "kvāna": ['mw'],
    "kvāpi": ['mw'],
    "kvātha": ['bhs', 'cae', 'ddsa', 'mw'],
    "kvāthayitavya": ['mw'],
    "kvāthaḥ": ['ap90'],
    "kvāthi": ['mw'],
    "kvāthodbhava": ['mw'],
    "kvāṇa": ['cae', 'ddsa', 'mw'],
    "kya": ['cae', 'mw'],
    "kyant": ['bhs'],
    "kyat": ['mw'],
    "kyāku": ['cae', 'ddsa', 'mw'],
    "kyāmbū": ['mw'],
    "kā": ['cae', 'ddsa', 'gra', 'mw'],
    "kābandha": ['mw'],
    "kābandhya": ['ddsa', 'mw'],
    "kābava": ['mw'],
    "kābhartṛ": ['cae', 'mw'],
    "kāca": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kācabakayantra": ['mw'],
    "kācabhājana": ['mw'],
    "kācaghaṭī": ['mw'],
    "kācaka": ['bhs', 'mw'],
    "kācakaḥ": ['ap90'],
    "kācakāmala": ['mw'],
    "kācakāmalin": ['mw'],
    "kācakūpī": ['mw'],
    "kācalavaṇa": ['mw'],
    "kācalindi": ['mw'],
    "kācalindika": ['bhs'],
    "kācamala": ['mw'],
    "kācamaṇi": ['cae', 'mw'],
    "kācamaṇika": ['bhs'],
    "kācamācī": ['mw'],
    "kācamālī": ['mw'],
    "kācamāṣa": ['mw'],
    "kācana": ['ap90', 'mw'],
    "kācanaka": ['mw'],
    "kācanakin": ['ap90', 'mw'],
    "kācara": ['cae', 'mw'],
    "kācarā": ['bhs'],
    "kācasambhava": ['mw'],
    "kācasauvarcala": ['mw'],
    "kācasthālī": ['mw'],
    "kācatilaka": ['mw'],
    "kācavakayantra": ['mw'],
    "kācaḥ": ['ap90'],
    "kācaṅgalīya": ['bhs'],
    "kāccha": ['mw'],
    "kācchaka": ['mw'],
    "kācchakī": ['mw'],
    "kācchapa": ['mw'],
    "kācchika": ['mw'],
    "kācchima": ['mw'],
    "kācchī": ['mw'],
    "kācigha": ['mw'],
    "kācighaḥ": ['ap90'],
    "kācilindi": ['mw'],
    "kācilindika": ['bhs', 'mw'],
    "kācima": ['mw'],
    "kācita": ['ap90', 'mw'],
    "kācitkara": ['cae', 'gra', 'mw'],
    "kāciñcika": ['mw'],
    "kācākṣa": ['bhs', 'mw'],
    "kācī": ['bhs'],
    "kācūkaḥ": ['ap90'],
    "kādaleya": ['mw'],
    "kādamba": ['cae', 'ddsa', 'mw'],
    "kādambaka": ['mw'],
    "kādambara": ['ddsa', 'mw'],
    "kādambarya": ['mw'],
    "kādambarī": ['cae', 'mw'],
    "kādambarībīja": ['mw'],
    "kādambarīkathāsāra": ['mw'],
    "kādambarīlocanānanda": ['mw'],
    "kādambarīsagdhikā": ['cae'],
    "kādambinī": ['cae', 'ddsa', 'mw'],
    "kādambā": ['mw'],
    "kādaṃbakaḥ": ['ap90'],
    "kādaṃbaraṃ": ['ap90'],
    "kādaṃbaḥ": ['ap90'],
    "kādaṃbinī": ['ap90'],
    "kādikramastuti": ['mw'],
    "kādimata": ['mw'],
    "kādrava": ['cae', 'ddsa', 'mw'],
    "kādraveya": ['cae', 'ddsa', 'mw'],
    "kādraveyaḥ": ['ap90'],
    "kādācitka": ['ap90', 'mw'],
    "kādācitkatva": ['mw'],
    "kādācitkatā": ['mw'],
    "kāga": ['mw'],
    "kāgada": ['mw'],
    "kāgaḥ": ['ap90'],
    "kāgni": ['mw'],
    "kāhakā": ['ap90', 'mw'],
    "kāhala": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kāhali": ['mw'],
    "kāhalin": ['mw'],
    "kāhaliḥ": ['ap90'],
    "kāhalā": ['mw'],
    "kāhalāpuṣpa": ['mw'],
    "kāhalī": ['mw'],
    "kāhan": ['cae', 'mw'],
    "kāhas": ['cae', 'mw'],
    "kāhasi": ['cped'],
    "kāhaya": ['mw'],
    "kāhisi": ['cped'],
    "kāhiti": ['bhs'],
    "kāhlāra": ['cae', 'mw'],
    "kāhoḍa": ['mw'],
    "kāhoḍi": ['mw'],
    "kāhābāha": ['mw'],
    "kāhāmi": ['cped'],
    "kāhāraka": ['mw'],
    "kāhī": ['mw'],
    "kāhūjī": ['mw'],
    "kāhūya": ['mw'],
    "kāhūṣa": ['mw'],
    "kāja": ['cae', 'cped', 'ddsa', 'mw'],
    "kājala": ['mw'],
    "kājalaṃ": ['ap90'],
    "kāka": ['cae', 'cped', 'ddsa', 'mw'],
    "kākabali": ['mw'],
    "kākabandhyā": ['mw'],
    "kākabhāṇḍī": ['mw'],
    "kākabhīru": ['mw'],
    "kākabījaka": ['mw'],
    "kākacañcuka": ['bhs'],
    "kākacaṇḍeśvarī": ['mw'],
    "kākacaṇḍīśvara": ['mw'],
    "kākacchada": ['mw'],
    "kākacchadi": ['mw'],
    "kākacchamāna": ['cped'],
    "kākacchardi": ['mw'],
    "kākacchati": ['cped'],
    "kākaciñci": ['mw'],
    "kākaciñcika": ['bhs', 'mw'],
    "kākaciñcā": ['mw'],
    "kākaciñcī": ['mw'],
    "kākadanta": ['mw'],
    "kākadantaki": ['mw'],
    "kākadantakīya": ['mw'],
    "kākadantavicāra": ['mw'],
    "kākadanti": ['mw'],
    "kākadantīya": ['mw'],
    "kākadhvaja": ['mw'],
    "kākaghnī": ['mw'],
    "kākaguha": ['mw'],
    "kākahradatīrtha": ['mw'],
    "kākajambū": ['mw'],
    "kākajaṅghā": ['mw'],
    "kākajāta": ['mw'],
    "kākajātaka": ['bhs'],
    "kākakadalī": ['mw'],
    "kākakalā": ['mw'],
    "kākakarkaṭī": ['mw'],
    "kākakaṅgu": ['mw'],
    "kākakaṅgunī": ['mw'],
    "kākakhara": ['mw'],
    "kākakulāyagandhika": ['mw'],
    "kākakāyani": ['mw'],
    "kākakāṣṭha": ['mw'],
    "kākakūrmamṛgākhu": ['mw'],
    "kākakūrmādi": ['mw'],
    "kākala": ['mw'],
    "kākalaka": ['mw'],
    "kākalakaḥ": ['ap90'],
    "kākalaḥ": ['ap90'],
    "kākali": ['cae', 'ddsa', 'mw'],
    "kākalikā": ['mw'],
    "kākaliḥ": ['ap90'],
    "kākalī": ['cae', 'mw'],
    "kākalīdrākṣā": ['mw'],
    "kākalīka": ['mw'],
    "kākalīkaḥ": ['ap90'],
    "kākalīrava": ['mw'],
    "kākamadgu": ['mw'],
    "kākamarda": ['mw'],
    "kākamardaka": ['mw'],
    "kākambīra": ['gra', 'mw'],
    "kākameṣī": ['mw'],
    "kākamudgā": ['mw'],
    "kākamukha": ['mw'],
    "kākamācikā": ['mw'],
    "kākamācī": ['mw'],
    "kākamārin": ['mw'],
    "kākamātā": ['mw'],
    "kākamṛga": ['mw'],
    "kākamṛgagocarita": ['mw'],
    "kākanantī": ['mw'],
    "kākandaka": ['mw'],
    "kākandi": ['mw'],
    "kākandī": ['mw'],
    "kākandīya": ['mw'],
    "kākani": ['mw'],
    "kākanidrā": ['mw'],
    "kākanāman": ['mw'],
    "kākanāsa": ['mw'],
    "kākanāsikā": ['mw'],
    "kākanāsā": ['mw'],
    "kākanī": ['mw'],
    "kākanīlā": ['mw'],
    "kākapada": ['cae', 'mw'],
    "kākapadamastaśīrṣaka": ['cae'],
    "kākapakṣa": ['cae', 'mw'],
    "kākapakṣadhara": ['mw'],
    "kākapakṣaka": ['mw'],
    "kākaparṇī": ['mw'],
    "kākapeya": ['mw'],
    "kākapeyya": ['cped'],
    "kākaphala": ['mw'],
    "kākaphalā": ['mw'],
    "kākapuccha": ['mw'],
    "kākapuṣpa": ['mw'],
    "kākapuṣṭa": ['mw'],
    "kākapīlu": ['mw'],
    "kākapīluka": ['mw'],
    "kākarakta": ['mw'],
    "kākaranti": ['mw'],
    "kākarantīya": ['mw'],
    "kākarava": ['mw'],
    "kākarudrasaṃvāda": ['mw'],
    "kākaruhā": ['mw'],
    "kākaruka": ['ap90', 'mw'],
    "kākarūka": ['ap90', 'mw'],
    "kākasampāta": ['mw'],
    "kākasparśa": ['mw'],
    "kākasphūrja": ['mw'],
    "kākassaraka": ['cped'],
    "kākastrī": ['mw'],
    "kākasvara": ['mw'],
    "kākasīsa": ['cped'],
    "kākasūra": ['cped'],
    "kākati": ['mw'],
    "kākatiktā": ['mw'],
    "kākatindu": ['mw'],
    "kākatinduka": ['mw'],
    "kākatulya": ['mw'],
    "kākatuṇḍa": ['mw'],
    "kākatuṇḍaka": ['mw'],
    "kākatuṇḍikā": ['mw'],
    "kākatuṇḍī": ['mw'],
    "kākatva": ['mw'],
    "kākatā": ['mw'],
    "kākatālukin": ['mw'],
    "kākatālīya": ['cae', 'mw'],
    "kākatālīyam": ['mw'],
    "kākatālīyavat": ['mw'],
    "kākatīya": ['mw'],
    "kākatīyarudra": ['mw'],
    "kākauṣṭhaka": ['mw'],
    "kākavairin": ['mw'],
    "kākavaktra": ['mw'],
    "kākavaktrī": ['mw'],
    "kākavallabhā": ['mw'],
    "kākavallarī": ['mw'],
    "kākavandhyā": ['mw'],
    "kākavartaka": ['mw'],
    "kākavarṇa": ['mw'],
    "kākavarṇin": ['bhs', 'mw'],
    "kākavat": ['mw'],
    "kākavyāghragomāyu": ['mw'],
    "kākavāśika": ['mw'],
    "kākavāṇī": ['bhs'],
    "kākayava": ['mw'],
    "kākaśabda": ['mw'],
    "kākaśaṅkin": ['bhs'],
    "kākaśekikin": ['mw'],
    "kākaśimbī": ['mw'],
    "kākaśira": ['bhs'],
    "kākaśāva": ['mw'],
    "kākaśīrṣa": ['mw'],
    "kākaśīrṣi": ['mw'],
    "kākaḥ": ['ap90'],
    "kākaṇa": ['mw'],
    "kākaṇaka": ['mw'],
    "kākaṇantikā": ['mw'],
    "kākaṇaṃ": ['ap90'],
    "kākaṇi": ['bhs', 'mw'],
    "kākaṇiḥ": ['ap90'],
    "kākaṇāhvā": ['mw'],
    "kākaṇī": ['mw'],
    "kākecī": ['mw'],
    "kākekṣu": ['mw'],
    "kākendu": ['mw'],
    "kākesaparvata": ['mw'],
    "kākeṣṭa": ['mw'],
    "kākeṣṭaphalā": ['mw'],
    "kākhatīra": ['mw'],
    "kākhorda": ['bhs'],
    "kāki": ['mw'],
    "kākila": ['mw'],
    "kākilaḥ": ['ap90'],
    "kākinī": ['ap90', 'cae', 'mw'],
    "kākiṇi": ['mw'],
    "kākiṇika": ['mw'],
    "kākiṇikā": ['mw'],
    "kākiṇī": ['ap90', 'cae', 'ddsa', 'mw'],
    "kākiṇīka": ['mw'],
    "kākocchvāsa": ['mw'],
    "kākocika": ['mw'],
    "kākocin": ['mw'],
    "kākocī": ['mw'],
    "kākodara": ['mw'],
    "kākodumbara": ['mw'],
    "kākola": ['cae', 'ddsa', 'mw'],
    "kākolaḥ": ['ap90'],
    "kākoli": ['mw'],
    "kākolī": ['mw'],
    "kākolūka": ['cae', 'mw'],
    "kākolūkikā": ['mw'],
    "kākolūkīya": ['ddsa', 'mw'],
    "kākoravasadda": ['cped'],
    "kākoḍumbara": ['mw'],
    "kākoḍumbarikā": ['mw'],
    "kākoṣṭhaka": ['mw'],
    "kāku": ['cae', 'ddsa', 'mw'],
    "kākubh": ['mw'],
    "kākubha": ['mw'],
    "kākubhabārhata": ['mw'],
    "kākud": ['cae', 'ddsa', 'gra', 'mw'],
    "kākuda": ['mw'],
    "kākudaṃ": ['ap90'],
    "kākudra": ['mw'],
    "kākudākṣika": ['mw'],
    "kākudīka": ['mw'],
    "kākulīmṛga": ['mw'],
    "kākutstha": ['cae', 'ddsa', 'mw'],
    "kākutsthau": ['mw'],
    "kākutsthaḥ": ['ap90'],
    "kākuvakrokti": ['mw'],
    "kākuvāc": ['mw'],
    "kākuḍḍepaka": ['cped'],
    "kākuḥ": ['ap90'],
    "kākvaśeya": ['mw'],
    "kākā": ['cae', 'mw'],
    "kākādanī": ['mw'],
    "kākāhvānā": ['mw'],
    "kākākṛt": ['mw'],
    "kākākṣi": ['mw'],
    "kākākṣinyāya": ['ddsa'],
    "kākākṣinyāyena": ['mw'],
    "kākākṣinyāyāt": ['mw'],
    "kākākṣivat": ['mw'],
    "kākāla": ['mw'],
    "kākālaḥ": ['ap90'],
    "kākāra": ['ap90', 'mw'],
    "kākāri": ['mw'],
    "kākāsyaka": ['bhs'],
    "kākāsyā": ['mw'],
    "kākātanī": ['mw'],
    "kākātidāyi": ['cped'],
    "kākātidāyin": ['cped'],
    "kākāy": ['cae'],
    "kākāyu": ['mw'],
    "kākāñcī": ['mw'],
    "kākāṅgā": ['mw'],
    "kākāṅgī": ['mw'],
    "kākāṇḍa": ['mw'],
    "kākāṇḍaka": ['mw'],
    "kākāṇḍakā": ['mw'],
    "kākāṇḍolā": ['mw'],
    "kākāṇḍā": ['mw'],
    "kākāṇḍī": ['mw'],
    "kākī": ['bhs', 'mw'],
    "kākṣa": ['mw'],
    "kākṣaseni": ['mw'],
    "kākṣatava": ['mw'],
    "kākṣaḥ": ['ap90'],
    "kākṣi": ['mw'],
    "kākṣī": ['ap90', 'mw'],
    "kākṣīva": ['mw'],
    "kākṣīvaka": ['mw'],
    "kākṣīvat": ['mw'],
    "kākṣīvata": ['mw'],
    "kākṣīvatī": ['ddsa', 'mw'],
    "kāla": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kālabava": ['mw'],
    "kālabavin": ['mw'],
    "kālabdhī": ['mw'],
    "kālabhairava": ['mw'],
    "kālabhakṣa": ['mw'],
    "kālabheda": ['mw'],
    "kālabhogin": ['mw'],
    "kālabhāga": ['mw'],
    "kālabhāṇḍikā": ['mw'],
    "kālabhṛt": ['mw'],
    "kālabījaka": ['mw'],
    "kālacakra": ['cae', 'ddsa', 'mw'],
    "kālacakrajātaka": ['mw'],
    "kālacakraprakāśa": ['mw'],
    "kālacaryā": ['mw'],
    "kālacodita": ['mw'],
    "kālacoditakarman": ['mw'],
    "kālacāri": ['cped'],
    "kālacārin": ['cped'],
    "kālacīvara": ['cped'],
    "kālada": ['mw'],
    "kāladamanī": ['mw'],
    "kāladantaka": ['mw'],
    "kāladaṇḍa": ['cae', 'mw'],
    "kāladeśavibhāga": ['mw'],
    "kāladharma": ['cae', 'mw'],
    "kāladharman": ['cae', 'mw'],
    "kāladhāraṇā": ['mw'],
    "kāladivākara": ['mw'],
    "kāladāsa": ['mw'],
    "kāladūta": ['mw'],
    "kālagandha": ['mw'],
    "kālagata": ['mw'],
    "kālagati": ['mw'],
    "kālagaṅgā": ['mw'],
    "kālagaṇḍikā": ['mw'],
    "kālaghaṭa": ['mw'],
    "kālaghātin": ['mw'],
    "kālagranthi": ['mw'],
    "kālagupta": ['mw'],
    "kālaharaṇa": ['cae'],
    "kālahasta": ['mw'],
    "kālahastipura": ['mw'],
    "kālahastiśaila": ['mw'],
    "kālahastīśvara": ['mw'],
    "kālahorā": ['mw'],
    "kālahāra": ['mw'],
    "kālajihva": ['cae', 'mw'],
    "kālajoṣaka": ['mw'],
    "kālajña": ['bhs', 'cae', 'mw'],
    "kālajñāna": ['cae', 'mw'],
    "kālajñānin": ['mw'],
    "kālaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kālakacu": ['mw'],
    "kālakalpa": ['mw'],
    "kālakalāya": ['mw'],
    "kālakandaka": ['mw'],
    "kālakapṛṣṭha": ['bhs'],
    "kālakaraṇa": ['mw'],
    "kālakarman": ['cae', 'mw'],
    "kālakarṇikā": ['mw'],
    "kālakarṇin": ['bhs'],
    "kālakarṇī": ['mw'],
    "kālakastūrī": ['mw'],
    "kālakata": ['cped'],
    "kālakaumudī": ['mw'],
    "kālakavana": ['mw'],
    "kālakavi": ['mw'],
    "kālakavṛkṣīya": ['mw'],
    "kālakañja": ['cae', 'mw'],
    "kālakañjya": ['mw'],
    "kālakaṇī": ['mw'],
    "kālakaṇṭaka": ['mw'],
    "kālakaṇṭha": ['mw'],
    "kālakaṇṭhaka": ['cae', 'mw'],
    "kālakaṭaṅkaṭa": ['mw'],
    "kālakendra": ['mw'],
    "kālakeya": ['mw'],
    "kālakhañja": ['mw'],
    "kālakhañjana": ['mw'],
    "kālakhaṇḍa": ['mw'],
    "kālakhaṇḍahan": ['mw'],
    "kālakiriyā": ['cped'],
    "kālaklītaka": ['mw'],
    "kālakoṭi": ['mw'],
    "kālakrama": ['mw'],
    "kālakrameṇa": ['mw'],
    "kālakramāt": ['mw'],
    "kālakriyā": ['bhs', 'mw'],
    "kālakuñja": ['mw'],
    "kālakuṃcaḥ": ['ap90'],
    "kālakuṇṭha": ['mw'],
    "kālakuṣṭha": ['mw'],
    "kālakā": ['cped', 'mw'],
    "kālakācārya": ['mw'],
    "kālakākranda": ['mw'],
    "kālakākṣa": ['mw'],
    "kālakāleṣu": ['mw'],
    "kālakāra": ['mw'],
    "kālakārita": ['cae', 'mw'],
    "kālakāñja": ['mw'],
    "kālakīla": ['mw'],
    "kālakīrti": ['mw'],
    "kālakīṭa": ['mw'],
    "kālakūṭa": ['cae', 'mw'],
    "kālakūṭaka": ['mw'],
    "kālakūṭapati": ['mw'],
    "kālakūṭi": ['mw'],
    "kālakūṭīya": ['mw'],
    "kālakṛt": ['mw'],
    "kālakṛta": ['cae', 'mw'],
    "kālakṣama": ['cae', 'mw'],
    "kālakṣepa": ['cae', 'mw'],
    "kālala": ['mw'],
    "kālalauha": ['mw'],
    "kālalavaṇa": ['mw'],
    "kālalocana": ['mw'],
    "kālaloha": ['mw'],
    "kālam": ['mw'],
    "kālamahiman": ['mw'],
    "kālamahī": ['mw'],
    "kālamallikā": ['mw'],
    "kālamasī": ['mw'],
    "kālamayūkha": ['mw'],
    "kālambya": ['ddsa', 'mw'],
    "kālamegha": ['mw'],
    "kālameśikā": ['mw'],
    "kālameṣikā": ['mw'],
    "kālameṣī": ['mw'],
    "kālamukha": ['mw'],
    "kālamukhā": ['mw'],
    "kālamuṣkaka": ['mw'],
    "kālamādhava": ['mw'],
    "kālamādhavakārikā": ['mw'],
    "kālamāhātmya": ['mw'],
    "kālamāla": ['mw'],
    "kālamālaka": ['mw'],
    "kālamāna": ['mw'],
    "kālamārtāṇḍa": ['mw'],
    "kālamūla": ['mw'],
    "kālamūrti": ['mw'],
    "kālanara": ['mw'],
    "kālanemi": ['cae', 'mw'],
    "kālanemihan": ['mw'],
    "kālanemihara": ['mw'],
    "kālanemin": ['mw'],
    "kālanemipurāṇa": ['mw'],
    "kālanemiripu": ['mw'],
    "kālanemyari": ['mw'],
    "kālanetra": ['mw'],
    "kālanidhi": ['mw'],
    "kālanirvāha": ['mw'],
    "kālaniryāsa": ['mw'],
    "kālanirūpaṇa": ['mw'],
    "kālanirṇaya": ['mw'],
    "kālanirṇayacandrikā": ['mw'],
    "kālanirṇayadīpikā": ['mw'],
    "kālanirṇayaprakāśa": ['mw'],
    "kālanirṇayasiddhānta": ['mw'],
    "kālanirṇayaśikṣā": ['mw'],
    "kālaniyoga": ['mw'],
    "kālanābha": ['mw'],
    "kālanātha": ['mw'],
    "kālapakva": ['cae', 'ddsa', 'mw'],
    "kālapakvabhuj": ['cae'],
    "kālaparaśudhāra": ['cae', 'mw'],
    "kālaparipāka": ['mw'],
    "kālaparivāsa": ['mw'],
    "kālaparvata": ['bhs', 'mw'],
    "kālaparyaya": ['cae', 'mw'],
    "kālaparyayāt": ['mw'],
    "kālaparyāya": ['cae'],
    "kālaparṇa": ['mw'],
    "kālaparṇī": ['mw'],
    "kālapatha": ['mw'],
    "kālapeśikā": ['mw'],
    "kālapeśī": ['mw'],
    "kālappavedana": ['cped'],
    "kālaprabhāta": ['mw'],
    "kālaprabodhin": ['mw'],
    "kālaprakāśikā": ['mw'],
    "kālaprarūḍha": ['mw'],
    "kālapraṇālikā": ['mw'],
    "kālapriya": ['mw'],
    "kālapriyanātha": ['cae', 'mw'],
    "kālaprāpta": ['cae'],
    "kālapuccha": ['mw'],
    "kālapucchaka": ['mw'],
    "kālapuruṣa": ['mw'],
    "kālapuṣpa": ['mw'],
    "kālapālaka": ['mw'],
    "kālapātrika": ['bhs', 'mw'],
    "kālapāśa": ['cae', 'mw'],
    "kālapāśaparīta": ['mw'],
    "kālapāśasthita": ['cae'],
    "kālapāśika": ['mw'],
    "kālapīluka": ['mw'],
    "kālapūga": ['mw'],
    "kālapṛṣṭha": ['mw'],
    "kālarudra": ['mw'],
    "kālarātri": ['mw'],
    "kālarātrī": ['bhs', 'mw'],
    "kālarūpadhṛṣ": ['mw'],
    "kālarūpin": ['mw'],
    "kālasadṛśa": ['mw'],
    "kālasamanvita": ['mw'],
    "kālasampanna": ['mw'],
    "kālasamāyukta": ['mw'],
    "kālasarpa": ['cae', 'mw'],
    "kālasaṃgraha": ['mw'],
    "kālasaṃhitā": ['mw'],
    "kālasaṃkarṣin": ['mw'],
    "kālasaṃkarṣā": ['mw'],
    "kālasaṃkhyā": ['mw'],
    "kālasaṃrodha": ['cae', 'mw'],
    "kālasaṃvara": ['mw'],
    "kālasiddhānta": ['mw'],
    "kālasiṃha": ['mw'],
    "kālaskandha": ['mw'],
    "kālaskandhin": ['mw'],
    "kālasseva": ['cped'],
    "kālasvarūpa": ['mw'],
    "kālasya": ['mw'],
    "kālasāhvaya": ['mw'],
    "kālasāra": ['mw'],
    "kālasūkarikā": ['mw'],
    "kālasūkta": ['mw'],
    "kālasūrya": ['mw'],
    "kālasūtra": ['bhs', 'cae', 'mw'],
    "kālasūtraka": ['mw'],
    "kālatama": ['mw'],
    "kālatantrakavi": ['mw'],
    "kālatara": ['mw'],
    "kālataraṅga": ['mw'],
    "kālatas": ['mw'],
    "kālatattvārṇava": ['mw'],
    "kālatinduka": ['mw'],
    "kālatoyaka": ['mw'],
    "kālatraya": ['mw'],
    "kālatritaya": ['mw'],
    "kālatulya": ['mw'],
    "kālatā": ['ddsa', 'mw'],
    "kālatāla": ['mw'],
    "kālatīrtha": ['mw'],
    "kālava": ['mw'],
    "kālavadana": ['mw'],
    "kālavalla": ['bhs'],
    "kālavarāṭaka": ['mw'],
    "kālavarṣin": ['cae', 'mw'],
    "kālavastu": ['bhs'],
    "kālavat": ['mw'],
    "kālavato": ['cped'],
    "kālavatī": ['mw'],
    "kālavega": ['mw'],
    "kālavelā": ['mw'],
    "kālavelāyoga": ['mw'],
    "kālaveya": ['mw'],
    "kālaveṣin": ['bhs'],
    "kālavibhakti": ['cae', 'mw'],
    "kālavibhāga": ['mw'],
    "kālavid": ['cae', 'mw'],
    "kālavidhvaṃsana": ['mw'],
    "kālavidhāna": ['mw'],
    "kālavidhṛti": ['mw'],
    "kālavidvas": ['mw'],
    "kālavidyā": ['mw'],
    "kālavikrama": ['mw'],
    "kālaviprakarṣa": ['mw'],
    "kālavirodha": ['mw'],
    "kālaviveka": ['mw'],
    "kālaviṣa": ['mw'],
    "kālavrata": ['mw'],
    "kālavyāpin": ['mw'],
    "kālavādi": ['cped'],
    "kālavādin": ['cped'],
    "kālavāhana": ['mw'],
    "kālavāla": ['cae', 'mw'],
    "kālavāluka": ['mw'],
    "kālavṛddhi": ['cae', 'mw'],
    "kālavṛkṣa": ['mw'],
    "kālavṛkṣīya": ['mw'],
    "kālavṛnta": ['mw'],
    "kālavṛntikā": ['mw'],
    "kālavṛntī": ['mw'],
    "kālaya": ['mw'],
    "kālayavana": ['ddsa', 'mw'],
    "kālayoga": ['cae', 'mw'],
    "kālayogin": ['mw'],
    "kālayukta": ['mw'],
    "kālayuta": ['mw'],
    "kālayuttaṁ": ['cped'],
    "kālayāpa": ['mw'],
    "kālayāpana": ['mw'],
    "kālañjara": ['mw'],
    "kālañjaraka": ['mw'],
    "kālañjarā": ['mw'],
    "kālañjarī": ['mw'],
    "kālaññu": ['cped'],
    "kālaśaila": ['mw'],
    "kālaśakti": ['mw'],
    "kālaśambara": ['mw'],
    "kālaśeya": ['ddsa', 'mw'],
    "kālaśeyaṃ": ['ap90'],
    "kālaśibi": ['mw'],
    "kālaśāka": ['cae', 'ddsa', 'mw'],
    "kālaśāli": ['mw'],
    "kālaṁ karoti": ['cped'],
    "kālaṃjaraḥ": ['ap90'],
    "kālaṅkata": ['mw'],
    "kālaṇkata": ['cped'],
    "kālaṇkiriyā": ['cped'],
    "kāle": ['cped', 'mw'],
    "kālecaryā": ['ddsa'],
    "kālehikā": ['mw'],
    "kāleja": ['mw'],
    "kālena": ['cped', 'mw'],
    "kālena kālaṁ": ['cped'],
    "kāleya": ['ap90', 'ddsa', 'mw'],
    "kāleyaka": ['mw'],
    "kāleyakaḥ": ['ap90'],
    "kāleyaruḥ": ['ap90'],
    "kāleśvara": ['mw'],
    "kāleśvaramāhātmya": ['mw'],
    "kālhāra": ['ddsa'],
    "kāli": ['bhs'],
    "kālidāsa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kālidāsaka": ['mw'],
    "kālika": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kālikasūtra": ['bhs'],
    "kālikatva": ['mw'],
    "kālikatā": ['mw'],
    "kālikeya": ['mw'],
    "kālikopaniṣad": ['mw'],
    "kālikopapurāṇa": ['mw'],
    "kālikā": ['bhs', 'ddsa', 'mw'],
    "kālikācārya": ['mw'],
    "kālikāgrantha": ['mw'],
    "kālikāguru": ['mw'],
    "kālikākrama": ['mw'],
    "kālikāmukha": ['mw'],
    "kālikāpurāṇa": ['mw'],
    "kālikārahasya": ['mw'],
    "kālikārya": ['mw'],
    "kālikāstotra": ['mw'],
    "kālikātantra": ['mw'],
    "kālikāvrata": ['mw'],
    "kālikāvāta": ['bhs'],
    "kālikāśrama": ['mw'],
    "kālila": ['mw'],
    "kāliman": ['ap90', 'cae', 'ddsa', 'mw'],
    "kālin": ['mw'],
    "kālinda": ['cae', 'ddsa', 'mw'],
    "kālindaka": ['mw'],
    "kālindikā": ['mw'],
    "kālindī": ['mw'],
    "kālindībhedana": ['mw'],
    "kālindīkarṣaṇa": ['mw'],
    "kālindīmukunda": ['mw'],
    "kālindīmāhātmya": ['mw'],
    "kālindīpati": ['mw'],
    "kālindīsodara": ['mw'],
    "kālindīsū": ['mw'],
    "kālinī": ['ap90', 'mw'],
    "kālitarā": ['mw'],
    "kālivya": ['mw'],
    "kāliya": ['ap90', 'ddsa', 'mw'],
    "kāliyadamana": ['mw'],
    "kāliyajit": ['mw'],
    "kāliyaka": ['bhs', 'mw'],
    "kāliyaḥ": ['ap90'],
    "kāliyāri": ['mw'],
    "kāliñjara": ['ddsa', 'mw'],
    "kāliñjarī": ['mw'],
    "kāliṃda": ['ap90'],
    "kāliṃga": ['ap90'],
    "kāliṃmanyā": ['mw'],
    "kāliṅga": ['cae', 'ddsa', 'mw'],
    "kāliṅgaka": ['cae', 'mw'],
    "kāliṅgapravaraṇa": ['bhs'],
    "kāliṅgikā": ['mw'],
    "kāliṅgī": ['mw'],
    "kālodaka": ['mw'],
    "kālodayin": ['mw'],
    "kālodāyin": ['bhs', 'mw'],
    "kālola": ['mw'],
    "kālopta": ['mw'],
    "kāloraga": ['ddsa'],
    "kālotpādita": ['mw'],
    "kālottara": ['mw'],
    "kālottaraśaivaśāstra": ['mw'],
    "kālpa": ['ap90', 'mw'],
    "kālpaka": ['mw'],
    "kālpam": ['bhs'],
    "kālpanika": ['ap90', 'mw'],
    "kālpanikatva": ['mw'],
    "kālpanikatā": ['mw'],
    "kālpasūtra": ['mw'],
    "kālpya": ['mw'],
    "kāluṣa": ['bhs'],
    "kāluṣya": ['ddsa', 'mw'],
    "kāluṣyaṃ": ['ap90'],
    "kālvāla": ['mw'],
    "kālvālīkṛta": ['mw'],
    "kālya": ['ap90', 'cae', 'ddsa', 'mw'],
    "kālyaka": ['mw'],
    "kālyam": ['mw'],
    "kālyasya": ['bhs'],
    "kālye": ['mw'],
    "kālyupaniṣad": ['mw'],
    "kālyā": ['mw'],
    "kālyāṇaka": ['mw'],
    "kālyāṇakaṃ": ['ap90'],
    "kālyāṇineya": ['mw'],
    "kālā": ['mw'],
    "kālābhata": ['cped'],
    "kālābhyāgamana": ['mw'],
    "kālādarśa": ['mw'],
    "kālādhyakṣa": ['mw'],
    "kālādika": ['mw'],
    "kālāgata": ['cped'],
    "kālāgni": ['mw'],
    "kālāgnibhairava": ['mw'],
    "kālāgnirudra": ['mw'],
    "kālāgnirudratīrtha": ['mw'],
    "kālāgnirudropaniṣad": ['mw'],
    "kālāguru": ['cae', 'ddsa', 'mw'],
    "kālājina": ['mw'],
    "kālājājī": ['mw'],
    "kālākāle": ['bhs'],
    "kālākāṅkṣin": ['mw'],
    "kālākṛṣṭa": ['mw'],
    "kālākṣarika": ['mw'],
    "kālākṣuṇṇadharmavedhī": ['bhs'],
    "kālāma": ['bhs', 'mw'],
    "kālāmasūtra": ['bhs'],
    "kālāmra": ['mw'],
    "kālāmukha": ['mw'],
    "kālānala": ['mw'],
    "kālānalarasa": ['mw'],
    "kālānara": ['mw'],
    "kālānayana": ['mw'],
    "kālāntaka": ['mw'],
    "kālāntakayama": ['mw'],
    "kālāntara": ['cae', 'mw'],
    "kālāntarakṣama": ['cae', 'mw'],
    "kālāntaraviṣa": ['mw'],
    "kālāntareṇa": ['mw'],
    "kālāntarāt": ['mw'],
    "kālāntarāvṛta": ['mw'],
    "kālāntarāvṛttiśubhāśubha": ['mw'],
    "kālāntayama": ['mw'],
    "kālānukālam": ['bhs'],
    "kālānunādin": ['mw'],
    "kālānusāraka": ['mw'],
    "kālānusāri": ['bhs'],
    "kālānusārin": ['mw'],
    "kālānusārivā": ['mw'],
    "kālānusāriṇī": ['mw'],
    "kālānusārya": ['cae', 'mw'],
    "kālānusāryaka": ['mw'],
    "kālānusāryā": ['mw'],
    "kālāpa": ['bhs', 'mw'],
    "kālāpadeśa": ['bhs'],
    "kālāpahāra": ['mw'],
    "kālāpaka": ['ddsa', 'mw'],
    "kālāpakaṃ": ['ap90'],
    "kālāpaḥ": ['ap90'],
    "kālāsuhṛd": ['mw'],
    "kālāt": ['mw'],
    "kālātikramaṇa": ['mw'],
    "kālātipāta": ['cae', 'mw'],
    "kālātmaka": ['mw'],
    "kālātyaya": ['cae', 'mw'],
    "kālātyayāpadiṣṭa": ['mw'],
    "kālātīta": ['mw'],
    "kālāvadhi": ['mw'],
    "kālāvara": ['mw'],
    "kālāvyavāya": ['mw'],
    "kālāyana": ['mw'],
    "kālāyani": ['mw'],
    "kālāyanī": ['ap90', 'mw'],
    "kālāyasa": ['cae', 'ddsa', 'mw'],
    "kālāyasadṛḍha": ['cae'],
    "kālāyasamaya": ['mw'],
    "kālāyasūpika": ['mw'],
    "kālāñjana": ['mw'],
    "kālāñjanikā": ['bhs'],
    "kālāñjanī": ['mw'],
    "kālāśauca": ['mw'],
    "kālāśoka": ['ddsa', 'mw'],
    "kālāśuddhi": ['mw'],
    "kālāṃśa": ['mw'],
    "kālāṅga": ['mw'],
    "kālāṇḍaja": ['mw'],
    "kālī": ['bhs', 'ddsa', 'mw'],
    "kālīcaturdaśī": ['mw'],
    "kālīcī": ['ap90', 'mw'],
    "kālīghaṭṭa": ['mw'],
    "kālīhṛdaya": ['mw'],
    "kālīka": ['mw'],
    "kālīkaḥ": ['ap90'],
    "kālīkrama": ['mw'],
    "kālīkulasarvasva": ['mw'],
    "kālīkṛ": ['ddsa', 'mw'],
    "kālīmanu": ['mw'],
    "kālīmukha": ['mw'],
    "kālīmāhātmya": ['mw'],
    "kālīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "kālīpurāṇa": ['mw'],
    "kālīpūjā": ['mw'],
    "kālīrahasya": ['mw'],
    "kālīsahasranāman": ['mw'],
    "kālīsamastamantra": ['mw'],
    "kālīstava": ['mw'],
    "kālīstotra": ['mw'],
    "kālīsāratantra": ['mw'],
    "kālīsūkta": ['mw'],
    "kālītanaya": ['mw'],
    "kālītantra": ['mw'],
    "kālītattva": ['mw'],
    "kālīvilāsatantra": ['mw'],
    "kālīvilāsin": ['ddsa', 'mw'],
    "kālīya": ['mw'],
    "kālīyadamana": ['mw'],
    "kālīyaka": ['cae', 'ddsa', 'mw'],
    "kālīyakaḥ": ['ap90'],
    "kālīyamardana": ['mw'],
    "kālīyantra": ['mw'],
    "kālīyaṃ": ['ap90'],
    "kām": ['ap90', 'mw'],
    "kāma": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kāmabaddha": ['mw'],
    "kāmabala": ['mw'],
    "kāmabhakṣa": ['mw'],
    "kāmabhava": ['cped'],
    "kāmabhoga": ['mw'],
    "kāmabhogi": ['cped'],
    "kāmabhogin": ['cped'],
    "kāmabhāj": ['cae', 'mw'],
    "kāmabindu": ['mw'],
    "kāmabāṇa": ['mw'],
    "kāmacakra": ['mw'],
    "kāmacandra": ['mw'],
    "kāmacara": ['cae', 'mw'],
    "kāmacaratva": ['mw'],
    "kāmacaraṇa": ['cae', 'mw'],
    "kāmacarī": ['mw'],
    "kāmacchanda": ['bhs', 'cped'],
    "kāmacāgi": ['cped'],
    "kāmacāgin": ['cped'],
    "kāmacālana": ['mw'],
    "kāmacāra": ['cae', 'mw'],
    "kāmacāratas": ['mw'],
    "kāmacāravādabhakṣa": ['mw'],
    "kāmacāreṇa": ['mw'],
    "kāmacārin": ['cae', 'mw'],
    "kāmacāritva": ['mw'],
    "kāmacāriṇī": ['mw'],
    "kāmada": ['bhs', 'cae', 'mw'],
    "kāmadahana": ['mw'],
    "kāmadaminī": ['mw'],
    "kāmadantikā": ['mw'],
    "kāmadarśana": ['mw'],
    "kāmadattikā": ['mw'],
    "kāmadattā": ['mw'],
    "kāmadatva": ['mw'],
    "kāmadeva": ['bhs', 'cae', 'mw'],
    "kāmadevamaya": ['mw'],
    "kāmadevatva": ['mw'],
    "kāmadhara": ['mw'],
    "kāmadharaṇa": ['mw'],
    "kāmadharma": ['mw'],
    "kāmadhenu": ['cae', 'mw'],
    "kāmadhenugaṇita": ['mw'],
    "kāmadhenutantra": ['mw'],
    "kāmadhvaṃsin": ['mw'],
    "kāmadhātu": ['bhs', 'cped', 'mw'],
    "kāmadhātuka": ['bhs'],
    "kāmadohanā": ['mw'],
    "kāmadohinī": ['mw'],
    "kāmadugha": ['cae', 'mw'],
    "kāmadughā": ['mw'],
    "kāmadughākṣiti": ['mw'],
    "kāmaduh": ['cae', 'mw'],
    "kāmaduha": ['mw'],
    "kāmaduhā": ['mw'],
    "kāmadā": ['mw'],
    "kāmadāna": ['mw'],
    "kāmadūtikā": ['mw'],
    "kāmadūtī": ['mw'],
    "kāmaga": ['cae', 'mw'],
    "kāmagama": ['cae', 'mw'],
    "kāmagati": ['cae', 'mw'],
    "kāmagavesi": ['cped'],
    "kāmagavesin": ['cped'],
    "kāmagavī": ['mw'],
    "kāmagiri": ['mw'],
    "kāmago": ['mw'],
    "kāmaguṇa": ['bhs', 'cped', 'mw'],
    "kāmagā": ['mw'],
    "kāmagāmin": ['mw'],
    "kāmahaituka": ['cae', 'mw'],
    "kāmahetukaṁ": ['cped'],
    "kāmahāni": ['mw'],
    "kāmaja": ['cae', 'mw'],
    "kāmajananī": ['mw'],
    "kāmajani": ['mw'],
    "kāmajit": ['mw'],
    "kāmajyeṣṭha": ['mw'],
    "kāmajāla": ['mw'],
    "kāmajāna": ['mw'],
    "kāmakalikā": ['mw'],
    "kāmakalā": ['mw'],
    "kāmakalābīja": ['mw'],
    "kāmakalātantra": ['mw'],
    "kāmakalāṅganāvilāsa": ['mw'],
    "kāmakandalā": ['mw'],
    "kāmakara": ['cped'],
    "kāmakarśana": ['gra', 'mw'],
    "kāmakeli": ['mw'],
    "kāmakelirasa": ['mw'],
    "kāmakhaḍgadalā": ['mw'],
    "kāmakoṣṇī": ['mw'],
    "kāmakrodha": ['cae', 'mw'],
    "kāmakrīḍā": ['mw'],
    "kāmakuṇḍa": ['mw'],
    "kāmakākurava": ['mw'],
    "kāmakāma": ['cae', 'cped', 'ddsa', 'mw'],
    "kāmakāmi": ['cped'],
    "kāmakāmin": ['cae', 'cped', 'mw'],
    "kāmakānana": ['cae', 'mw'],
    "kāmakāntā": ['mw'],
    "kāmakāra": ['cae', 'cped', 'mw'],
    "kāmakāratas": ['mw'],
    "kāmakāraṃkṛ": ['mw'],
    "kāmakāreṇa": ['mw'],
    "kāmakārikatā": ['bhs'],
    "kāmakāriya": ['cped'],
    "kāmakārāt": ['mw'],
    "kāmakāti": ['gra', 'mw'],
    "kāmakūṭa": ['mw'],
    "kāmakḷpti": ['mw'],
    "kāmakṛta": ['mw'],
    "kāmala": ['ap90', 'mw'],
    "kāmalabhida": ['mw'],
    "kāmalakīkara": ['mw'],
    "kāmalakīṭa": ['mw'],
    "kāmalatā": ['mw'],
    "kāmalekhā": ['mw'],
    "kāmali": ['mw'],
    "kāmalika": ['mw'],
    "kāmalikā": ['ap90'],
    "kāmalin": ['ap90', 'mw'],
    "kāmalola": ['mw'],
    "kāmalubdha": ['cae', 'mw'],
    "kāmalā": ['mw'],
    "kāmalābhābhijappi": ['cped'],
    "kāmalābhābhijappin": ['cped'],
    "kāmalāpi": ['cped'],
    "kāmalāpin": ['cped'],
    "kāmalāyana": ['mw'],
    "kāmalāyani": ['mw'],
    "kāmalī": ['mw'],
    "kāmam": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāmamaha": ['mw'],
    "kāmamardana": ['mw'],
    "kāmamaya": ['mw'],
    "kāmamayika": ['cped'],
    "kāmamañjarī": ['mw'],
    "kāmamoha": ['mw'],
    "kāmamohita": ['mw'],
    "kāmamālin": ['mw'],
    "kāmamūta": ['cae', 'ddsa', 'gra', 'mw'],
    "kāmamūḍha": ['mw'],
    "kāmana": ['ap90', 'mw'],
    "kāmanda": ['mw'],
    "kāmandaka": ['ddsa', 'mw'],
    "kāmandaki": ['cae', 'mw'],
    "kāmandakī": ['cae', 'mw'],
    "kāmandakīya": ['mw'],
    "kāmandha": ['cped'],
    "kāmanā": ['ddsa', 'mw'],
    "kāmanāśaka": ['mw'],
    "kāmanīyaka": ['mw'],
    "kāmanīyaṃ": ['ap90'],
    "kāmanīḍā": ['mw'],
    "kāmaparṇikā": ['mw'],
    "kāmaparṇī": ['mw'],
    "kāmapati": ['mw'],
    "kāmapatnī": ['mw'],
    "kāmaphala": ['mw'],
    "kāmapra": ['cae', 'gra', 'mw'],
    "kāmaprada": ['mw'],
    "kāmapradīpa": ['mw'],
    "kāmaprastha": ['mw'],
    "kāmaprasthīya": ['mw'],
    "kāmapraśna": ['mw'],
    "kāmapri": ['mw'],
    "kāmapriyakarī": ['mw'],
    "kāmapuṣ": ['mw'],
    "kāmapāla": ['cae', 'ddsa', 'mw'],
    "kāmapālaka": ['mw'],
    "kāmapīḍita": ['mw'],
    "kāmapūra": ['cae', 'mw'],
    "kāmarasa": ['mw'],
    "kāmarasika": ['ddsa', 'mw'],
    "kāmarati": ['cped'],
    "kāmaratna": ['mw'],
    "kāmarekhā": ['mw'],
    "kāmarāga": ['cae', 'cped'],
    "kāmarāja": ['mw'],
    "kāmarūpa": ['ap90', 'cae', 'mw'],
    "kāmarūpadhara": ['mw'],
    "kāmarūpadharatva": ['mw'],
    "kāmarūpanibandha": ['mw'],
    "kāmarūpapati": ['mw'],
    "kāmarūpatīrtha": ['mw'],
    "kāmarūpayātrāpaddhati": ['mw'],
    "kāmarūpin": ['bhs', 'cae', 'mw'],
    "kāmarūpiṇī": ['bhs', 'mw'],
    "kāmarūpodbhavā": ['mw'],
    "kāmarūpīyanibandha": ['mw'],
    "kāmasakha": ['mw'],
    "kāmasamuttha": ['cae', 'mw'],
    "kāmasamūha": ['mw'],
    "kāmasani": ['mw'],
    "kāmasaṃkalpa": ['mw'],
    "kāmasaṃyoga": ['mw'],
    "kāmasena": ['mw'],
    "kāmasenā": ['mw'],
    "kāmasukhallikānuyoga": ['cped'],
    "kāmasuta": ['mw'],
    "kāmasū": ['mw'],
    "kāmasūkta": ['mw'],
    "kāmasūtra": ['cae', 'mw'],
    "kāmatantra": ['cae', 'mw'],
    "kāmataru": ['mw'],
    "kāmatas": ['cae', 'mw'],
    "kāmataḥ": ['ap90'],
    "kāmatāla": ['mw'],
    "kāmatīrtha": ['mw'],
    "kāmavaktavyahṛdaya": ['mw'],
    "kāmavallabha": ['mw'],
    "kāmavallabhā": ['mw'],
    "kāmavant": ['cae'],
    "kāmavara": ['mw'],
    "kāmavarṣa": ['mw'],
    "kāmavarṣin": ['mw'],
    "kāmavasati": ['mw'],
    "kāmavat": ['ap90', 'mw'],
    "kāmavatsa": ['mw'],
    "kāmavatī": ['mw'],
    "kāmavaśa": ['cae', 'mw'],
    "kāmavaśya": ['mw'],
    "kāmaveraṇi": ['mw'],
    "kāmaveraṇīya": ['mw'],
    "kāmaveśin": ['mw'],
    "kāmaviddha": ['mw'],
    "kāmavihantṛ": ['mw'],
    "kāmavihārin": ['cae', 'mw'],
    "kāmavitakka": ['cped'],
    "kāmavitarka": ['bhs'],
    "kāmavivarjita": ['mw'],
    "kāmavyāhārin": ['mw'],
    "kāmavāda": ['mw'],
    "kāmavādin": ['mw'],
    "kāmavāsin": ['cae', 'mw'],
    "kāmavīrya": ['mw'],
    "kāmavṛddhi": ['mw'],
    "kāmavṛkṣa": ['mw'],
    "kāmavṛntā": ['mw'],
    "kāmavṛtta": ['cae', 'mw'],
    "kāmavṛtti": ['ddsa'],
    "kāmayamāna": ['ap90', 'cped'],
    "kāmayati": ['cped'],
    "kāmayitṛ": ['mw'],
    "kāmayā": ['ddsa', 'mw'],
    "kāmayāna": ['cped', 'mw'],
    "kāmaśaila": ['mw'],
    "kāmaśalya": ['mw'],
    "kāmaśara": ['mw'],
    "kāmaśaronmādinī": ['mw'],
    "kāmaśreṣṭha": ['bhs'],
    "kāmaśāsana": ['mw'],
    "kāmaśāstra": ['cae', 'mw'],
    "kāmaḥ": ['ap90'],
    "kāmaṁ": ['cped'],
    "kāmaṃdada": ['bhs'],
    "kāmaṃdhamin": ['ap90', 'mw'],
    "kāmaṃgama": ['bhs'],
    "kāmaṃgāmin": ['mw'],
    "kāmaṇkara": ['cped'],
    "kāmaṇḍalava": ['mw'],
    "kāmaṇḍaleya": ['mw'],
    "kāmaṇḍaleyī": ['mw'],
    "kāmaṇḍaluka": ['cped'],
    "kāmaṭha": ['ap90', 'mw'],
    "kāmaṭhaka": ['mw'],
    "kāmbala": ['mw'],
    "kāmbalika": ['mw'],
    "kāmbalikāyana": ['mw'],
    "kāmbavika": ['mw'],
    "kāmboja": ['cae', 'ddsa', 'mw'],
    "kāmbojaka": ['bhs', 'mw'],
    "kāmboji": ['mw'],
    "kāmbojikā": ['mw'],
    "kāmbojinī": ['mw'],
    "kāmbojī": ['bhs', 'mw'],
    "kāmbukā": ['mw'],
    "kāmbuva": ['ddsa', 'mw'],
    "kāme": ['mw'],
    "kāmena": ['mw'],
    "kāmepsu": ['cae', 'mw'],
    "kāmerī": ['mw'],
    "kāmeti": ['cped'],
    "kāmeśvara": ['cae', 'ddsa', 'mw'],
    "kāmeśvaramodaka": ['mw'],
    "kāmeśvaratīrtha": ['mw'],
    "kāmeśvarī": ['mw'],
    "kāmeṣṭa": ['mw'],
    "kāmi": ['mw'],
    "kāmia": ['gra'],
    "kāmijana": ['cae', 'mw'],
    "kāmika": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāmikā": ['mw'],
    "kāmimaha": ['mw'],
    "kāmin": ['ap90', 'cae', 'gra', 'mw'],
    "kāminikā": ['bhs'],
    "kāminī": ['bhs', 'mw'],
    "kāminīkānta": ['mw'],
    "kāminīpriyā": ['mw'],
    "kāminīśa": ['mw'],
    "kāmita": ['ap90', 'cae', 'mw'],
    "kāmitthī": ['cped'],
    "kāmitva": ['mw'],
    "kāmitā": ['cae', 'mw'],
    "kāmivallabha": ['mw'],
    "kāmiḥ": ['ap90'],
    "kāmla": ['ap90', 'mw'],
    "kāmoda": ['mw'],
    "kāmodaka": ['mw'],
    "kāmodā": ['ap90'],
    "kāmodī": ['mw'],
    "kāmonmatta": ['ddsa', 'mw'],
    "kāmonmādinī": ['mw'],
    "kāmopabhoga": ['mw'],
    "kāmopahata": ['mw'],
    "kāmopahatacittāṅga": ['mw'],
    "kāmotthāpya": ['mw'],
    "kāmpila": ['cae', 'mw'],
    "kāmpilaka": ['cae'],
    "kāmpilla": ['mw'],
    "kāmpillaka": ['bhs', 'mw'],
    "kāmpillikā": ['mw'],
    "kāmpilya": ['ddsa', 'mw'],
    "kāmpilyaka": ['mw'],
    "kāmpilī": ['mw'],
    "kāmpīla": ['mw'],
    "kāmpīlavāsin": ['mw'],
    "kāmrā": ['mw'],
    "kāmuka": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāmukakāntā": ['mw'],
    "kāmukatva": ['mw'],
    "kāmukā": ['mw'],
    "kāmukāya": ['ddsa', 'mw'],
    "kāmukāyana": ['mw'],
    "kāmukāyita": ['mw'],
    "kāmukī": ['mw'],
    "kāmya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kāmyadāna": ['mw'],
    "kāmyagir": ['mw'],
    "kāmyaka": ['cae', 'mw'],
    "kāmyakarman": ['mw'],
    "kāmyamaraṇa": ['mw'],
    "kāmyatva": ['mw'],
    "kāmyatā": ['cae', 'mw'],
    "kāmyavrata": ['mw'],
    "kāmyaśrāddha": ['mw'],
    "kāmyeṣṭi": ['mw'],
    "kāmyeṣṭitantra": ['mw'],
    "kāmyā": ['cae', 'ddsa', 'mw'],
    "kāmyābhiprāya": ['mw'],
    "kāmyāṣṭamī": ['mw'],
    "kāmā": ['mw'],
    "kāmābhikāma": ['mw'],
    "kāmābhivarṣaṇa": ['mw'],
    "kāmābhiṣvaṅga": ['cae', 'mw'],
    "kāmādhikaraṇaṁ": ['cped'],
    "kāmādhikāra": ['mw'],
    "kāmādhiṣṭhita": ['mw'],
    "kāmāgni": ['mw'],
    "kāmāgnisaṃdīpana": ['mw'],
    "kāmāgāyin": ['mw'],
    "kāmākhya": ['mw'],
    "kāmākhyā": ['mw'],
    "kāmākuyatantra": ['mw'],
    "kāmākṣā": ['mw'],
    "kāmākṣātantra": ['mw'],
    "kāmākṣī": ['mw'],
    "kāmālikā": ['ap90'],
    "kāmānala": ['mw'],
    "kāmāndha": ['cae', 'mw'],
    "kāmāndhasaṃjña": ['mw'],
    "kāmāndhā": ['mw'],
    "kāmānnin": ['mw'],
    "kāmāpavādakasūtra": ['bhs'],
    "kāmāraṇya": ['mw'],
    "kāmāri": ['cae', 'mw'],
    "kāmārta": ['cae', 'mw'],
    "kāmārtha": ['cae', 'mw'],
    "kāmārthin": ['mw'],
    "kāmārthinagara": ['mw'],
    "kāmārṇava": ['mw'],
    "kāmāsakta": ['mw'],
    "kāmāsakti": ['mw'],
    "kāmāt": ['mw'],
    "kāmātman": ['cae', 'mw'],
    "kāmātmatā": ['mw'],
    "kāmātura": ['ddsa', 'mw'],
    "kāmāvacara": ['bhs', 'cped', 'mw'],
    "kāmāvasāya": ['mw'],
    "kāmāvasāyin": ['mw'],
    "kāmāvasāyitva": ['mw'],
    "kāmāvasāyitā": ['mw'],
    "kāmāvasāyitṛ": ['mw'],
    "kāmāvatāra": ['mw'],
    "kāmāya": ['mw'],
    "kāmāyanī": ['mw'],
    "kāmāyudha": ['mw'],
    "kāmāyus": ['mw'],
    "kāmāśana": ['mw'],
    "kāmāśaya": ['mw'],
    "kāmāśoka": ['cae', 'mw'],
    "kāmāśrama": ['mw'],
    "kāmāśramapada": ['mw'],
    "kāmāṅga": ['mw'],
    "kāmāṅgā": ['mw'],
    "kāmāṅkuśa": ['mw'],
    "kāmīla": ['mw'],
    "kāmīna": ['mw'],
    "kāmūpapatti": ['cped'],
    "kāmūpasaṁhita": ['cped'],
    "kāmūpādāna": ['cped'],
    "kāna": ['mw'],
    "kānac": ['ddsa', 'mw'],
    "kānada": ['mw'],
    "kānaka": ['ap90', 'mw'],
    "kānalaka": ['mw'],
    "kānana": ['cae', 'cped', 'ddsa', 'mw'],
    "kānanaukas": ['mw'],
    "kānanaṃ": ['ap90'],
    "kānanānta": ['mw'],
    "kānanāri": ['mw'],
    "kānaḍā": ['mw'],
    "kānda": ['mw'],
    "kāndaki": ['mw'],
    "kāndakāyana": ['mw'],
    "kāndarpa": ['mw'],
    "kāndarpika": ['mw'],
    "kāndava": ['mw'],
    "kāndavika": ['mw'],
    "kāndiśīka": ['ddsa'],
    "kāndulā": ['mw'],
    "kāndāviṣa": ['mw'],
    "kāndūrā": ['mw'],
    "kānerin": ['mw'],
    "kāniṣṭhika": ['mw'],
    "kāniṣṭhikaṃ": ['ap90'],
    "kāniṣṭhineya": ['mw'],
    "kāniṣṭhineyaḥ": ['ap90'],
    "kāniṣṭhya": ['mw'],
    "kānta": ['cae', 'ddsa', 'mw'],
    "kāntaka": ['mw'],
    "kāntakalikā": ['mw'],
    "kāntalaka": ['mw'],
    "kāntalauha": ['mw'],
    "kāntaloha": ['mw'],
    "kāntamiśra": ['mw'],
    "kāntapakṣin": ['mw'],
    "kāntapuṣpa": ['mw'],
    "kāntapāṣāṇa": ['mw'],
    "kāntatva": ['cae', 'mw'],
    "kānthaka": ['mw'],
    "kānthakya": ['mw'],
    "kānthakyāyanī": ['mw'],
    "kānthika": ['mw'],
    "kānti": ['cae', 'ddsa', 'mw'],
    "kāntida": ['mw'],
    "kāntidā": ['mw'],
    "kāntidāyaka": ['mw'],
    "kāntihara": ['mw'],
    "kāntika": ['mw'],
    "kāntikara": ['mw'],
    "kāntikosala": ['mw'],
    "kāntimant": ['cae'],
    "kāntimat": ['mw'],
    "kāntimattā": ['mw'],
    "kāntimatī": ['mw'],
    "kāntiprada": ['cae'],
    "kāntipura": ['mw'],
    "kāntipurī": ['mw'],
    "kāntirāja": ['mw'],
    "kāntisudhāmaya": ['ddsa'],
    "kāntivrata": ['mw'],
    "kāntotpīḍā": ['mw'],
    "kāntā": ['mw'],
    "kāntācaraṇadohada": ['mw'],
    "kāntānuvṛtta": ['mw'],
    "kāntāpurī": ['mw'],
    "kāntāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "kāntārabhava": ['cae', 'mw'],
    "kāntāraga": ['mw'],
    "kāntāraka": ['mw'],
    "kāntārapatha": ['mw'],
    "kāntārapathika": ['mw'],
    "kāntāravāsinī": ['mw'],
    "kāntārekṣu": ['mw'],
    "kāntārikā": ['mw'],
    "kāntārī": ['mw'],
    "kāntāya": ['ddsa', 'mw'],
    "kāntāyasa": ['mw'],
    "kāntāṅghridohada": ['mw'],
    "kāntī": ['mw'],
    "kāntīnagarī": ['mw'],
    "kānyajā": ['mw'],
    "kānyakubja": ['ddsa', 'mw'],
    "kānyakubjaḥ": ['ap90'],
    "kānyakubjī": ['mw'],
    "kānyakujja": ['cae'],
    "kānāmā": ['cped'],
    "kānāyana": ['mw'],
    "kānīna": ['cae', 'ddsa', 'mw'],
    "kānīnaḥ": ['ap90'],
    "kānīta": ['gra', 'mw'],
    "kānīyasa": ['mw'],
    "kāpatha": ['cae', 'ddsa', 'mw'],
    "kāpathaḥ": ['ap90'],
    "kāpaṭa": ['cae', 'ddsa', 'mw'],
    "kāpaṭava": ['mw'],
    "kāpaṭavaka": ['mw'],
    "kāpaṭavī": ['mw'],
    "kāpaṭika": ['ap90', 'mw'],
    "kāpaṭya": ['mw'],
    "kāpaṭyaṃ": ['ap90'],
    "kāpeya": ['mw'],
    "kāpeyaṃ": ['ap90'],
    "kāphala": ['mw'],
    "kāphalaḥ": ['ap90'],
    "kāpika": ['ap90', 'mw'],
    "kāpila": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāpilabali": ['mw'],
    "kāpilapurāṇa": ['mw'],
    "kāpilavastava": ['bhs'],
    "kāpileya": ['bhs', 'cae', 'mw'],
    "kāpileyabābhrava": ['cae', 'mw'],
    "kāpileśvaratīrtha": ['mw'],
    "kāpilika": ['mw'],
    "kāpilya": ['mw'],
    "kāpittha": ['mw'],
    "kāpitthaka": ['mw'],
    "kāpitthika": ['mw'],
    "kāpitthikā": ['mw'],
    "kāpivana": ['mw'],
    "kāpiñjala": ['mw'],
    "kāpiñjaleya": ['bhs'],
    "kāpiñjali": ['mw'],
    "kāpiñjalāda": ['mw'],
    "kāpiñjalādi": ['mw'],
    "kāpiñjalādya": ['mw'],
    "kāpiśa": ['mw'],
    "kāpiśaṃ": ['ap90'],
    "kāpiśeya": ['mw'],
    "kāpiśeyaḥ": ['ap90'],
    "kāpiśāyana": ['ddsa', 'mw'],
    "kāpiśāyanaṃ": ['ap90'],
    "kāpiśī": ['bhs', 'mw'],
    "kāpiṣṭhala": ['mw'],
    "kāpiṣṭhalakaṭha": ['mw'],
    "kāpiṣṭhali": ['mw'],
    "kāpiṣṭhalyā": ['mw'],
    "kāpiṣṭhalāyana": ['mw'],
    "kāpola": ['mw'],
    "kāpota": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāpotaka": ['bhs', 'cped', 'mw'],
    "kāpotapākya": ['mw'],
    "kāpotaretasa": ['mw'],
    "kāpotavṛtti": ['mw'],
    "kāpoti": ['mw'],
    "kāpotāñjana": ['mw'],
    "kāpotī": ['mw'],
    "kāpurisa": ['cped'],
    "kāpuruṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "kāpuruṣatva": ['mw'],
    "kāpuruṣatā": ['mw'],
    "kāpuruṣaḥ": ['ap90'],
    "kāpuruṣya": ['mw'],
    "kāpya": ['mw'],
    "kāpyakara": ['mw'],
    "kāpyakaraḥ": ['ap90'],
    "kāpyakāra": ['mw'],
    "kāpyakāraḥ": ['ap90'],
    "kāpyāyanī": ['mw'],
    "kāpā": ['gra', 'mw'],
    "kāpāla": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāpāli": ['mw'],
    "kāpālika": ['cae', 'mw'],
    "kāpālikatva": ['cae', 'mw'],
    "kāpālikatvaṃ": ['ap90'],
    "kāpālin": ['ap90', 'cae', 'mw'],
    "kāpālī": ['mw'],
    "kāpāṭika": ['mw'],
    "kāpī": ['mw'],
    "kāpīputra": ['mw'],
    "kāpīyakānika": ['mw'],
    "kāra": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kārabha": ['ap90', 'mw'],
    "kārabhedaka": ['cped'],
    "kāraja": ['ap90', 'mw'],
    "kāraka": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "kārakagupti": ['mw'],
    "kārakahetu": ['mw'],
    "kārakam": ['bhs'],
    "kārakaparīkṣā": ['mw'],
    "kārakara": ['mw'],
    "kārakasaṅgha": ['cped'],
    "kārakavat": ['ap90', 'mw'],
    "kārakavicāra": ['mw'],
    "kārakavāda": ['mw'],
    "kārakukṣīya": ['mw'],
    "kārakānvitā": ['mw'],
    "kārakāraka": ['cped'],
    "kāram": ['mw'],
    "kārambhā": ['mw'],
    "kāramihikā": ['ap90', 'mw'],
    "kārapacava": ['mw'],
    "kārapatha": ['mw'],
    "kāraskara": ['ddsa', 'mw'],
    "kāraskaraḥ": ['ap90'],
    "kāraskarāṭikā": ['mw'],
    "kārasūtra": ['bhs'],
    "kāratantavikā": ['mw'],
    "kāratantavikī": ['mw'],
    "kārava": ['gra', 'mw'],
    "kāravallī": ['mw'],
    "kāravaḥ": ['ap90'],
    "kāravella": ['mw'],
    "kāravellaka": ['mw'],
    "kāravellikā": ['mw'],
    "kāravellī": ['mw'],
    "kāraveya": ['mw'],
    "kāravya": ['mw'],
    "kāravyā": ['mw'],
    "kāravālika": ['bhs'],
    "kāravī": ['mw'],
    "kāraya": ['cped'],
    "kārayamāna": ['cped'],
    "kārayamāṇa": ['mw'],
    "kārayantrika": ['mw'],
    "kārayat": ['cped', 'mw'],
    "kārayati": ['bhs', 'cped'],
    "kāraye": ['cped'],
    "kārayitavya": ['ap90', 'cae', 'ddsa', 'mw'],
    "kārayitavyadakṣa": ['mw'],
    "kārayitṛ": ['ap90', 'cae', 'mw'],
    "kārayiṁ": ['cped'],
    "kārayiṣṇu": ['mw'],
    "kārañja": ['mw'],
    "kārañjī": ['mw'],
    "kāraṃbhā": ['ap90'],
    "kāraṃdhama": ['mw'],
    "kāraṃdhamin": ['ap90', 'mw'],
    "kāraṃḍavaḥ": ['ap90'],
    "kāraṇa": ['bhs', 'cae', 'cped', 'mw'],
    "kāraṇabhūta": ['mw'],
    "kāraṇadhvaṃsa": ['mw'],
    "kāraṇadhvaṃsaka": ['mw'],
    "kāraṇadhvaṃsin": ['mw'],
    "kāraṇagata": ['mw'],
    "kāraṇaguṇa": ['mw'],
    "kāraṇaguṇodbhavaguṇa": ['mw'],
    "kāraṇaka": ['ap90', 'mw'],
    "kāraṇakaraṇa": ['mw'],
    "kāraṇakopa": ['cae', 'ddsa'],
    "kāraṇakrudh": ['cae'],
    "kāraṇakāritam": ['mw'],
    "kāraṇamālā": ['mw'],
    "kāraṇatas": ['mw'],
    "kāraṇatva": ['mw'],
    "kāraṇatā": ['mw'],
    "kāraṇatāvāda": ['mw'],
    "kāraṇavat": ['mw'],
    "kāraṇavihīna": ['mw'],
    "kāraṇavādin": ['mw'],
    "kāraṇavāri": ['mw'],
    "kāraṇaśarīra": ['cae', 'mw'],
    "kāraṇaṃ": ['ap90'],
    "kāraṇdava": ['cped'],
    "kāraṇika": ['ap90', 'bhs', 'ddsa', 'mw'],
    "kāraṇottara": ['mw'],
    "kāraṇā": ['bhs', 'cped', 'ddsa', 'mw'],
    "kāraṇābhāva": ['mw'],
    "kāraṇākhyā": ['mw'],
    "kāraṇākṣepa": ['mw'],
    "kāraṇāntara": ['cae'],
    "kāraṇānvita": ['mw'],
    "kāraṇātman": ['cae', 'ddsa'],
    "kāraṇī": ['bhs'],
    "kāraṇīka": ['cped'],
    "kāraṇḍa": ['mw'],
    "kāraṇḍava": ['bhs', 'cae', 'ddsa', 'mw'],
    "kāraṇḍavaka": ['bhs'],
    "kāraṇḍavatī": ['mw'],
    "kāraṇḍavyūha": ['bhs', 'mw'],
    "kārdama": ['ap90', 'ddsa', 'mw'],
    "kārdameya": ['mw'],
    "kārdami": ['mw'],
    "kārdamika": ['mw'],
    "kārenta": ['cped'],
    "kāresi": ['cped'],
    "kāressati": ['cped'],
    "kāressaṁ": ['cped'],
    "kāreta": ['cped'],
    "kāretabba": ['cped'],
    "kāretar": ['cped'],
    "kāreti": ['cped'],
    "kāreyya": ['cped'],
    "kāreyyuṁ": ['cped'],
    "kāreyyāma": ['cped'],
    "kāreṇava": ['ap90', 'mw'],
    "kāreṇupāli": ['mw'],
    "kāreṇupālāyana": ['mw'],
    "kāri": ['mw'],
    "kārika": ['bhs'],
    "kārikā": ['ap90', 'ddsa', 'mw'],
    "kārikānibandha": ['mw'],
    "kārikāvalī": ['mw'],
    "kārin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kārita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "kāritaka": ['bhs'],
    "kāritakāraṇa": ['bhs'],
    "kāritavat": ['mw'],
    "kāritra": ['bhs'],
    "kāritā": ['mw'],
    "kāritānta": ['mw'],
    "kāriyamāna": ['cped'],
    "kāriḥ": ['ap90'],
    "kāriṇī": ['bhs'],
    "kārkalāseya": ['mw'],
    "kārkandhava": ['mw'],
    "kārkavākava": ['ap90', 'mw'],
    "kārkaśya": ['cae', 'ddsa', 'mw'],
    "kārkaśyaṃ": ['ap90'],
    "kārkaṇa": ['ap90', 'mw'],
    "kārkaṣa": ['mw'],
    "kārkaṭya": ['mw'],
    "kārkaṭyāyani": ['mw'],
    "kārkoṭa": ['mw'],
    "kārkoṭaka": ['ddsa', 'mw'],
    "kārkīka": ['ap90', 'mw'],
    "kārma": ['ap90', 'mw'],
    "kārmaraṅga": ['ddsa', 'mw'],
    "kārmaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kārmaṇatva": ['mw'],
    "kārmaṇeyaka": ['mw'],
    "kārmaṇika": ['cae'],
    "kārmika": ['ap90', 'ddsa', 'mw'],
    "kārmikya": ['mw'],
    "kārmikyaṃ": ['ap90'],
    "kārmuka": ['ap90', 'cae', 'ddsa', 'mw'],
    "kārmukabhṛt": ['mw'],
    "kārmukin": ['cae', 'ddsa', 'mw'],
    "kārmukopaniṣad": ['mw'],
    "kārmukāya": ['ddsa', 'mw'],
    "kārmāra": ['cae', 'ddsa', 'gra', 'mw'],
    "kārmāraka": ['mw'],
    "kārmārakaṃ": ['ap90'],
    "kārmāraḥ": ['ap90'],
    "kārmāryāyaṇi": ['mw'],
    "kārotamaḥ": ['ap90'],
    "kārotara": ['gra', 'mw'],
    "kārottama": ['mw'],
    "kārottara": ['mw'],
    "kārotī": ['mw'],
    "kārpaṇya": ['cae', 'ddsa', 'mw'],
    "kārpaṇyaṃ": ['ap90'],
    "kārpaṇī": ['mw'],
    "kārpaṭa": ['mw'],
    "kārpaṭaḥ": ['ap90'],
    "kārpaṭika": ['ddsa', 'mw'],
    "kārpaṭikaḥ": ['ap90'],
    "kārpāsa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kārpāsaka": ['bhs', 'cae', 'mw'],
    "kārpāsanāsikā": ['mw'],
    "kārpāsasautrika": ['mw'],
    "kārpāsatāntava": ['cae', 'mw'],
    "kārpāsika": ['ap90', 'bhs', 'ddsa', 'mw'],
    "kārpāsikā": ['ap90', 'mw'],
    "kārpāsāsthi": ['cae', 'ddsa', 'mw'],
    "kārpāsī": ['mw'],
    "kārpāṇa": ['ddsa', 'gra', 'mw'],
    "kārpāṇaṃ": ['ap90'],
    "kārpūra": ['mw'],
    "kārpūreya": ['mw'],
    "kārpūriṇa": ['mw'],
    "kārta": ['mw'],
    "kārtakaujapau": ['mw'],
    "kārtasvara": ['mw'],
    "kārtasvaramaya": ['ddsa'],
    "kārtasvaraṃ": ['ap90'],
    "kārtavīrya": ['ddsa', 'mw'],
    "kārtavīryacampū": ['mw'],
    "kārtavīryaḥ": ['ap90'],
    "kārtayaśa": ['mw'],
    "kārtayuga": ['ap90', 'mw'],
    "kārti": ['mw'],
    "kārtika": ['ap90'],
    "kārtikeyaḥ": ['ap90'],
    "kārtikikaḥ": ['ap90'],
    "kārtisiṃhadeva": ['mw'],
    "kārtsna": ['mw'],
    "kārtsnya": ['cae', 'mw'],
    "kārtsnyaṃ": ['ap90'],
    "kārtsnyena": ['mw'],
    "kārttika": ['cae', 'ddsa', 'mw'],
    "kārttikakuṇḍa": ['mw'],
    "kārttikamahiman": ['mw'],
    "kārttikamāhātmya": ['mw'],
    "kārttikapūrṇimā": ['mw'],
    "kārttikasiddhānta": ['mw'],
    "kārttikaśāli": ['mw'],
    "kārttikeya": ['cae', 'mw'],
    "kārttikeyaprasū": ['mw'],
    "kārttikika": ['mw'],
    "kārttikotsava": ['mw'],
    "kārttikī": ['mw'],
    "kārttikīvrata": ['mw'],
    "kārtāntika": ['ddsa', 'mw'],
    "kārtārthya": ['mw'],
    "kārtāṃtikaḥ": ['ap90'],
    "kāru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kārucaura": ['mw'],
    "kārudhāyas": ['gra', 'mw'],
    "kārudveṣin": ['mw'],
    "kāruhasta": ['mw'],
    "kāruja": ['mw'],
    "kāruka": ['cae', 'cped', 'mw'],
    "kārukasiddhāntin": ['mw'],
    "kārukaḥ": ['ap90'],
    "kārukānna": ['cae'],
    "kārupatha": ['mw'],
    "kāruvidā": ['mw'],
    "kāruvindu": ['mw'],
    "kāruñña": ['cped'],
    "kāruññata": ['cped'],
    "kāruṃḍikā": ['ap90'],
    "kāruṇa": ['bhs'],
    "kāruṇika": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "kāruṇikatā": ['mw'],
    "kāruṇya": ['cae', 'mw'],
    "kāruṇyadhenu": ['mw'],
    "kāruṇyalaharistava": ['mw'],
    "kāruṇyamaya": ['mw'],
    "kāruṇyasūtra": ['mw'],
    "kāruṇyatā": ['bhs'],
    "kāruṇyavedin": ['mw'],
    "kāruṇyaveditva": ['mw'],
    "kāruṇyaṃ": ['ap90'],
    "kāruṇḍikā": ['mw'],
    "kāruṇḍī": ['mw'],
    "kāruṣa": ['cae'],
    "kārvaṭika": ['bhs', 'mw'],
    "kārya": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāryabhraṣṭa": ['mw'],
    "kāryabhāj": ['mw'],
    "kāryabhājana": ['mw'],
    "kāryabhāktva": ['mw'],
    "kāryacintaka": ['mw'],
    "kāryacintā": ['mw'],
    "kāryacyuta": ['mw'],
    "kāryadarśana": ['cae', 'mw'],
    "kāryadarśin": ['cae', 'mw'],
    "kāryadhvaṃsa": ['cae'],
    "kāryagaurava": ['mw'],
    "kāryagurutva": ['mw'],
    "kāryagurutā": ['mw'],
    "kāryahantṛ": ['cae', 'mw'],
    "kāryakara": ['bhs', 'mw'],
    "kāryakaraṇa": ['cae', 'mw'],
    "kāryakaraṇāpekṣā": ['ddsa'],
    "kāryakartṛ": ['mw'],
    "kāryakuśala": ['mw'],
    "kāryakāla": ['cae', 'mw'],
    "kāryakāraṇa": ['cae', 'mw'],
    "kāryakāraṇabhāva": ['mw'],
    "kāryakāraṇatas": ['mw'],
    "kāryakāraṇatva": ['mw'],
    "kāryakārin": ['mw'],
    "kāryakṣama": ['mw'],
    "kāryanidhāna": ['cae'],
    "kāryanirvṛtti": ['mw'],
    "kāryanirṇaya": ['cae', 'mw'],
    "kāryapadavī": ['cae', 'mw'],
    "kāryapariccheda": ['mw'],
    "kāryapradveṣa": ['mw'],
    "kāryapreṣya": ['mw'],
    "kāryapuṭa": ['mw'],
    "kāryarūpa": ['cae', 'ddsa'],
    "kāryasama": ['mw'],
    "kāryasaṃdeha": ['mw'],
    "kāryasiddhi": ['cae', 'mw'],
    "kāryasthāna": ['mw'],
    "kāryasādhaka": ['mw'],
    "kāryasāgara": ['mw'],
    "kāryatama": ['mw'],
    "kāryatas": ['ddsa', 'mw'],
    "kāryataḥ": ['ap90'],
    "kāryatva": ['mw'],
    "kāryatā": ['cae', 'mw'],
    "kāryatāvicāra": ['bhs'],
    "kāryavant": ['cae'],
    "kāryavastu": ['mw'],
    "kāryavat": ['ddsa', 'mw'],
    "kāryavattva": ['mw'],
    "kāryavattā": ['cae', 'mw'],
    "kāryavaśa": ['mw'],
    "kāryavaśāt": ['cae', 'mw'],
    "kāryavinimaya": ['cae', 'mw'],
    "kāryavinirṇaya": ['mw'],
    "kāryavipatti": ['mw'],
    "kāryavyasana": ['cae', 'mw'],
    "kāryavṛttānta": ['cae', 'mw'],
    "kāryaśeṣa": ['cae', 'mw'],
    "kāryaśeṣajña": ['cae'],
    "kāryekṣaṇa": ['cae', 'mw'],
    "kāryeśa": ['mw'],
    "kāryeśvara": ['mw'],
    "kāryika": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāryin": ['ap90', 'cae', 'mw'],
    "kāryodyoga": ['mw'],
    "kāryodyukta": ['mw'],
    "kāryoparodha": ['cae'],
    "kāryopekṣā": ['cae', 'ddsa', 'mw'],
    "kāryā": ['mw'],
    "kāryādhikārin": ['cae', 'mw'],
    "kāryādhipa": ['mw'],
    "kāryākhyā": ['mw'],
    "kāryākārya": ['cae', 'ddsa', 'mw'],
    "kāryākāryavicāra": ['mw'],
    "kāryākṣama": ['mw'],
    "kāryākṣepa": ['mw'],
    "kāryānta": ['mw'],
    "kāryāntara": ['cae', 'mw'],
    "kāryāntarasaciva": ['cae', 'mw'],
    "kāryāpekṣin": ['mw'],
    "kāryārtha": ['cae', 'ddsa', 'mw'],
    "kāryārtham": ['mw'],
    "kāryārthasiddhi": ['mw'],
    "kāryārthin": ['cae', 'mw'],
    "kāryātipāta": ['cae', 'ddsa', 'mw'],
    "kāryātipātin": ['mw'],
    "kārā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "kārābhū": ['mw'],
    "kārādhunī": ['ap90', 'gra', 'mw'],
    "kārādvīpa": ['bhs', 'mw'],
    "kārāgupta": ['mw'],
    "kārāgāra": ['cae', 'mw'],
    "kārāgṛha": ['cae', 'mw'],
    "kārāhva": ['bhs'],
    "kārākāra": ['bhs'],
    "kārānusāri": ['bhs'],
    "kārāpaka": ['bhs', 'mw'],
    "kārāpana": ['cped'],
    "kārāpatha": ['mw'],
    "kārāpayati": ['bhs', 'cped'],
    "kārāpaṇa": ['bhs'],
    "kārāpesi": ['cped'],
    "kārāpetabba": ['cped'],
    "kārāpeti": ['cped'],
    "kārāpetvā": ['cped'],
    "kārāpita": ['cped'],
    "kārāpiyamāna": ['cped'],
    "kārāpāla": ['mw'],
    "kārāstha": ['mw'],
    "kārāvara": ['cae', 'ddsa', 'mw'],
    "kārāveśman": ['mw'],
    "kārāvāsa": ['mw'],
    "kārāvī": ['mw'],
    "kārāyikā": ['ap90', 'mw'],
    "kārī": ['mw'],
    "kārīra": ['ap90', 'mw'],
    "kārīrya": ['mw'],
    "kārīrādi": ['mw'],
    "kārīrī": ['mw'],
    "kārīṣa": ['mw'],
    "kārīṣaṃ": ['ap90'],
    "kārīṣi": ['bhs', 'mw'],
    "kārśa": ['mw'],
    "kārśakeyīputra": ['mw'],
    "kārśana": ['mw'],
    "kārśmarī": ['mw'],
    "kārśya": ['cae', 'ddsa', 'mw'],
    "kārśyaṃ": ['ap90'],
    "kārśānava": ['ap90', 'mw'],
    "kārśāśvīya": ['mw'],
    "kārūṣa": ['cae', 'ddsa', 'mw'],
    "kārūṣaka": ['mw'],
    "kārṇa": ['ap90', 'mw'],
    "kārṇacchidrika": ['mw'],
    "kārṇakharaki": ['mw'],
    "kārṇaveṣṭakika": ['mw'],
    "kārṇaśravasa": ['mw'],
    "kārṇi": ['mw'],
    "kārṇika": ['mw'],
    "kārṇāyani": ['mw'],
    "kārṇāṭabhāṣā": ['mw'],
    "kārṣa": ['bhs', 'mw'],
    "kārṣaka": ['ddsa', 'mw'],
    "kārṣaḥ": ['ap90'],
    "kārṣi": ['ap90', 'cae', 'mw'],
    "kārṣika": ['ap90', 'cae', 'ddsa', 'mw'],
    "kārṣikā": ['bhs'],
    "kārṣin": ['cae', 'mw'],
    "kārṣman": ['ap90', 'cae', 'gra', 'mw'],
    "kārṣmarya": ['cae', 'mw'],
    "kārṣmaryamaya": ['mw'],
    "kārṣuka": ['mw'],
    "kārṣya": ['mw'],
    "kārṣyavaṇa": ['mw'],
    "kārṣāpaṇa": ['cae', 'ddsa', 'mw'],
    "kārṣāpaṇachedikam": ['bhs'],
    "kārṣāpaṇaka": ['mw'],
    "kārṣāpaṇamāṃsika": ['bhs'],
    "kārṣāpaṇaḥ": ['ap90'],
    "kārṣāpaṇika": ['ap90', 'mw'],
    "kārṣāpaṇāvara": ['mw'],
    "kārṣī": ['bhs', 'mw'],
    "kārṣīvaṇa": ['cae', 'mw'],
    "kārṣīvaṇaḥ": ['ap90'],
    "kārṣṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kārṣṇakarṇa": ['mw'],
    "kārṣṇasundari": ['mw'],
    "kārṣṇi": ['cae', 'mw'],
    "kārṣṇiḥ": ['ap90'],
    "kārṣṇya": ['cae', 'ddsa', 'mw'],
    "kārṣṇyaṃ": ['ap90'],
    "kārṣṇājina": ['mw'],
    "kārṣṇājini": ['mw'],
    "kārṣṇāyana": ['mw'],
    "kārṣṇāyasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kārṣṇī": ['mw'],
    "kās": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāsa": ['cped', 'ddsa', 'mw'],
    "kāsaghna": ['mw'],
    "kāsaghnī": ['mw'],
    "kāsajit": ['mw'],
    "kāsaka": ['mw'],
    "kāsakanda": ['mw'],
    "kāsakara": ['mw'],
    "kāsaktika": ['mw'],
    "kāsakuṇṭha": ['mw'],
    "kāsamarda": ['mw'],
    "kāsamardaka": ['mw'],
    "kāsamardana": ['mw'],
    "kāsana": ['bhs'],
    "kāsanāśinī": ['mw'],
    "kāsara": ['mw'],
    "kāsaraḥ": ['ap90'],
    "kāsavant": ['cae'],
    "kāsavat": ['mw'],
    "kāsaḥ": ['ap90'],
    "kāsaṁ": ['cped'],
    "kāseruyajñika": ['mw'],
    "kāsi": ['bhs'],
    "kāsika": ['cped'],
    "kāsikacandana": ['cped'],
    "kāsikasukhuma": ['cped'],
    "kāsikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāsin": ['ap90', 'cae', 'mw'],
    "kāsiya": ['cped'],
    "kāstambara": ['mw'],
    "kāstīra": ['mw'],
    "kāstīrika": ['mw'],
    "kāstūrika": ['mw'],
    "kāsundīvaṭikā": ['mw'],
    "kāsā": ['mw'],
    "kāsālu": ['mw'],
    "kāsāra": ['cae', 'ddsa', 'mw'],
    "kāsāraḥ": ['ap90'],
    "kāsāri": ['mw'],
    "kāsāva": ['cped'],
    "kāsāvakaṇṭha": ['cped'],
    "kāsāvavattha": ['cped'],
    "kāsāvaṭa": ['cped'],
    "kāsāya": ['cped'],
    "kāsāyavasana": ['cped'],
    "kāsāyavattha": ['cped'],
    "kāsāyavatthavasana": ['cped'],
    "kāsāyavāsi": ['cped'],
    "kāsāyavāsin": ['cped'],
    "kāsī": ['bhs'],
    "kāsīsa": ['mw'],
    "kāsīsaṃ": ['ap90'],
    "kāsū": ['ap90', 'mw'],
    "kāsūtarī": ['mw'],
    "kāsṛti": ['mw'],
    "kāsṛtiḥ": ['ap90'],
    "kāt": ['ap90', 'mw'],
    "kātabba": ['cped'],
    "kātala": ['mw'],
    "kātalāyana": ['mw'],
    "kātantra": ['cae', 'ddsa', 'mw'],
    "kātantrakaumudī": ['mw'],
    "kātara": ['ap90', 'cae', 'ddsa', 'mw'],
    "kātaratva": ['mw'],
    "kātaratā": ['mw'],
    "kātarya": ['cae', 'ddsa', 'mw'],
    "kātaryaṃ": ['ap90'],
    "kātarākṣī": ['mw'],
    "kātarāyaṇa": ['mw'],
    "kātaṃtraṃ": ['ap90'],
    "kāthaka": ['mw'],
    "kāthakya": ['mw'],
    "kāthakyāyanī": ['mw'],
    "kāthañcitka": ['mw'],
    "kāthaṃcitka": ['ap90'],
    "kāthika": ['mw'],
    "kāthikaḥ": ['ap90'],
    "kāti": ['ap90', 'gra', 'mw'],
    "kātkṛ": ['cae', 'ddsa', 'mw'],
    "kātsn‍rya": ['ddsa'],
    "kātthaka": ['mw'],
    "kāttreyaka": ['mw'],
    "kātu": ['mw'],
    "kātuḥ": ['ap90'],
    "kātya": ['mw'],
    "kātyāyana": ['bhs', 'cae', 'ddsa', 'mw'],
    "kātyāyanamāhātmya": ['mw'],
    "kātyāyanasūtra": ['mw'],
    "kātyāyanasūtrabhāṣya": ['mw'],
    "kātyāyanasūtrapaddhati": ['mw'],
    "kātyāyanatantra": ['mw'],
    "kātyāyanaḥ": ['ap90'],
    "kātyāyaneśvara": ['mw'],
    "kātyāyanikā": ['mw'],
    "kātyāyanī": ['ap90', 'mw'],
    "kātyāyanīkalpa": ['mw'],
    "kātyāyanīputra": ['mw'],
    "kātyāyanīya": ['ap90', 'cae', 'mw'],
    "kātīra": ['mw'],
    "kātīya": ['ap90', 'mw'],
    "kātīyagṛhyasūtra": ['mw'],
    "kātīyakalpasūtra": ['mw'],
    "kātīyasūtra": ['mw'],
    "kātūna": ['cped'],
    "kātṛṇa": ['mw'],
    "kāva": ['mw'],
    "kāvacika": ['ap90', 'mw'],
    "kāvandha": ['ddsa', 'mw'],
    "kāvaṣa": ['mw'],
    "kāvaṣeya": ['mw'],
    "kāvaṭa": ['mw'],
    "kāvaṭikā": ['mw'],
    "kāvera": ['mw'],
    "kāveraka": ['mw'],
    "kāveraṃ": ['ap90'],
    "kāveraṇi": ['mw'],
    "kāveraṇīya": ['mw'],
    "kāverikā": ['mw'],
    "kāverī": ['ap90', 'ddsa', 'mw'],
    "kāveya": ['bhs'],
    "kāveyya": ['cped'],
    "kāveyyamatta": ['cped'],
    "kāvia": ['gra'],
    "kāvilya": ['mw'],
    "kāvirāj": ['mw'],
    "kāviya": ['cped'],
    "kāviśa": ['bhs'],
    "kāvya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kāvyabandha": ['cae', 'mw'],
    "kāvyacandrikā": ['mw'],
    "kāvyacaurya": ['mw'],
    "kāvyadevī": ['mw'],
    "kāvyagoṣṭhī": ['mw'],
    "kāvyahāsya": ['mw'],
    "kāvyakalpalatā": ['mw'],
    "kāvyakalpalatāvṛtti": ['mw'],
    "kāvyakalpalatāvṛttiparimala": ['mw'],
    "kāvyakartṛ": ['cae', 'mw'],
    "kāvyakāmadhenu": ['mw'],
    "kāvyalakṣaṇa": ['mw'],
    "kāvyaliṅga": ['mw'],
    "kāvyamīmāṃsaka": ['mw'],
    "kāvyamīmāṃsā": ['mw'],
    "kāvyapradīpa": ['mw'],
    "kāvyaprakāśa": ['cae', 'mw'],
    "kāvyaprakāśadīpikā": ['mw'],
    "kāvyaprakāśamañjarī": ['mw'],
    "kāvyaprakāśanidarśana": ['mw'],
    "kāvyaprakāśapradīpa": ['mw'],
    "kāvyaprakāśasaṃketa": ['mw'],
    "kāvyaprakāśaṭīkā": ['mw'],
    "kāvyarasa": ['cae', 'mw'],
    "kāvyarasika": ['mw'],
    "kāvyaratna": ['mw'],
    "kāvyarākṣasa": ['mw'],
    "kāvyasaṃgraha": ['mw'],
    "kāvyasaṃhāra": ['mw'],
    "kāvyasaṃjīvanī": ['mw'],
    "kāvyasudhā": ['mw'],
    "kāvyasārasaṃgraha": ['mw'],
    "kāvyatva": ['mw'],
    "kāvyatā": ['mw'],
    "kāvyavilāsa": ['mw'],
    "kāvyaśāstra": ['cae', 'mw'],
    "kāvyodaya": ['mw'],
    "kāvyā": ['mw'],
    "kāvyādarśa": ['cae', 'ddsa', 'mw'],
    "kāvyādarśamārjana": ['mw'],
    "kāvyālaṃkāra": ['cae', 'mw'],
    "kāvyālaṃkārasūtra": ['cae'],
    "kāvyālaṃkāravṛtti": ['mw'],
    "kāvyāloka": ['mw'],
    "kāvyālokalocana": ['mw'],
    "kāvyāmṛta": ['mw'],
    "kāvyāyana": ['mw'],
    "kāvyāṣṭaka": ['mw'],
    "kāvāra": ['mw'],
    "kāvāraṃ": ['ap90'],
    "kāvārī": ['mw'],
    "kāvṛka": ['mw'],
    "kāvṛkaḥ": ['ap90'],
    "kāya": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kāyabandhana": ['bhs', 'cped', 'mw'],
    "kāyabhāvanā": ['cped'],
    "kāyacikitsā": ['mw'],
    "kāyadaḍḍhibahula": ['cped'],
    "kāyadaḷhībahula": ['cped'],
    "kāyadaṇḍa": ['cae', 'mw'],
    "kāyadhātu": ['cped'],
    "kāyagata": ['cae', 'cped', 'mw'],
    "kāyagatāsati": ['cped'],
    "kāyaka": ['ap90', 'mw'],
    "kāyakalisaṃpramathana": ['bhs'],
    "kāyaklama": ['mw'],
    "kāyakleśa": ['cae', 'mw'],
    "kāyakāraṇakartṛtva": ['mw'],
    "kāyamāna": ['mw'],
    "kāyamānasika": ['cped'],
    "kāyamānaṃ": ['ap90'],
    "kāyamānikaniketana": ['mw'],
    "kāyanvaya": ['cped'],
    "kāyaparihārika": ['cped'],
    "kāyaparihāriya": ['cped'],
    "kāyapariyantika": ['cped'],
    "kāyapaṭibaddha": ['cped'],
    "kāyappacālaka": ['cped'],
    "kāyappacālakaṁ": ['cped'],
    "kāyappakopa": ['cped'],
    "kāyappaṭibaddha": ['cped'],
    "kāyasakkhi": ['cped'],
    "kāyasakkhin": ['cped'],
    "kāyasaṃsarga": ['bhs'],
    "kāyasaṅkhāra": ['cped'],
    "kāyastha": ['cae', 'mw'],
    "kāyasthikā": ['mw'],
    "kāyasthita": ['mw'],
    "kāyasthiti": ['mw'],
    "kāyasthā": ['mw'],
    "kāyasthālī": ['mw'],
    "kāyasthī": ['mw'],
    "kāyasākṣin": ['bhs'],
    "kāyavadha": ['mw'],
    "kāyavalana": ['mw'],
    "kāyavant": ['cae'],
    "kāyavat": ['ap90', 'mw'],
    "kāyaviññeyya": ['cped'],
    "kāyavya": ['mw'],
    "kāyavyūha": ['mw'],
    "kāyaśuddhi": ['mw'],
    "kāyaḥ": ['ap90'],
    "kāyeśa": ['bhs'],
    "kāyika": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kāyikā": ['ddsa', 'mw'],
    "kāyindriya": ['cped'],
    "kāyitāntya": ['bhs'],
    "kāyoddharṣaṇa": ['bhs'],
    "kāyotsarga": ['mw'],
    "kāyoḍhaja": ['cae', 'ddsa', 'mw'],
    "kāyura": ['cped'],
    "kāyuśa": ['bhs'],
    "kāyādhava": ['mw'],
    "kāyāgni": ['mw'],
    "kāyānupassana": ['cped'],
    "kāyānupassi": ['cped'],
    "kāyānupassin": ['cped'],
    "kāyārohaṇa": ['mw'],
    "kāyāvarohaṇa": ['mw'],
    "kāyāvatāra": ['mw'],
    "kāyāyatana": ['cped'],
    "kāyūpaga": ['cped'],
    "kāyūra": ['cped'],
    "kāñc": ['mw'],
    "kāñcana": ['bhs', 'cae', 'ddsa', 'mw'],
    "kāñcanabhū": ['mw'],
    "kāñcanabhūṣā": ['mw'],
    "kāñcanacakra": ['bhs'],
    "kāñcanacaya": ['mw'],
    "kāñcanadaṃṣṭra": ['mw'],
    "kāñcanagairika": ['mw'],
    "kāñcanagarbha": ['mw'],
    "kāñcanagiri": ['cae', 'mw'],
    "kāñcanaka": ['mw'],
    "kāñcanakadalī": ['mw'],
    "kāñcanakalaśa": ['cae'],
    "kāñcanakandara": ['mw'],
    "kāñcanakā": ['mw'],
    "kāñcanakānti": ['mw'],
    "kāñcanakāriṇī": ['mw'],
    "kāñcanakṣīrī": ['mw'],
    "kāñcanamaya": ['cae', 'mw'],
    "kāñcanamayībhūmi": ['bhs'],
    "kāñcanamālā": ['bhs', 'cae', 'mw'],
    "kāñcanaparvata": ['bhs'],
    "kāñcanaprabha": ['cae', 'mw'],
    "kāñcanaprabhā": ['mw'],
    "kāñcanapura": ['mw'],
    "kāñcanapurī": ['mw'],
    "kāñcanapuṣpaka": ['mw'],
    "kāñcanapuṣpī": ['mw'],
    "kāñcanaruci": ['mw'],
    "kāñcanasaṃdhi": ['mw'],
    "kāñcanasaṃnibha": ['mw'],
    "kāñcanavapra": ['mw'],
    "kāñcanavarman": ['mw'],
    "kāñcanavarṇa": ['bhs'],
    "kāñcanavega": ['mw'],
    "kāñcanaśṛṅga": ['mw'],
    "kāñcanaśṛṅgin": ['mw'],
    "kāñcaneṣudhi": ['mw'],
    "kāñcanikā": ['mw'],
    "kāñcanābhidhānasaṃdhi": ['mw'],
    "kāñcanābhā": ['mw'],
    "kāñcanācala": ['cae', 'mw'],
    "kāñcanācārya": ['mw'],
    "kāñcanādri": ['cae', 'mw'],
    "kāñcanāhva": ['mw'],
    "kāñcanākṣa": ['mw'],
    "kāñcanākṣī": ['mw'],
    "kāñcanāla": ['mw'],
    "kāñcanāra": ['mw'],
    "kāñcanāraka": ['mw'],
    "kāñcanāṅga": ['mw'],
    "kāñcanāṅgadin": ['mw'],
    "kāñcanī": ['mw'],
    "kāñcanīya": ['cae', 'ddsa', 'mw'],
    "kāñcanīyā": ['mw'],
    "kāñci": ['cae', 'mw'],
    "kāñcika": ['mw'],
    "kāñcipurī": ['mw'],
    "kāñcu": ['bhs'],
    "kāñcukin": ['mw'],
    "kāñcukīya": ['bhs', 'mw'],
    "kāñcī": ['cae', 'ddsa', 'mw'],
    "kāñcīguṇa": ['cae'],
    "kāñcīguṇasthāna": ['cae', 'mw'],
    "kāñcīkalāpa": ['mw'],
    "kāñcīkṣetra": ['mw'],
    "kāñcīnagara": ['mw'],
    "kāñcīpada": ['mw'],
    "kāñcīprastha": ['mw'],
    "kāñcīpura": ['mw'],
    "kāñcīpuraka": ['mw'],
    "kāñcīpurī": ['mw'],
    "kāñcīyamaka": ['mw'],
    "kāñjika": ['cae', 'ddsa', 'mw'],
    "kāñjikapūjā": ['mw'],
    "kāñjikavaṭaka": ['mw'],
    "kāñjikā": ['mw'],
    "kāñjī": ['mw'],
    "kāñjīka": ['mw'],
    "kāś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kāśa": ['cae', 'ddsa', 'gra', 'mw'],
    "kāśabda": ['mw'],
    "kāśaja": ['mw'],
    "kāśaka": ['mw'],
    "kāśakṛtsna": ['mw'],
    "kāśakṛtsnaka": ['mw'],
    "kāśakṛtsni": ['mw'],
    "kāśamaya": ['mw'],
    "kāśapauṇḍra": ['mw'],
    "kāśaphareya": ['mw'],
    "kāśapharī": ['mw'],
    "kāśaya": ['mw'],
    "kāśaḥ": ['ap90'],
    "kāśeruyajñika": ['mw'],
    "kāśeya": ['mw'],
    "kāśeyī": ['mw'],
    "kāśi": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kāśika": ['bhs', 'cae', 'mw'],
    "kāśikanyā": ['mw'],
    "kāśikasūkṣma": ['mw'],
    "kāśikavastra": ['mw'],
    "kāśikhaṇḍa": ['mw'],
    "kāśikosalīya": ['mw'],
    "kāśikośala": ['bhs'],
    "kāśikā": ['ap90', 'bhs', 'mw'],
    "kāśikānyāsa": ['mw'],
    "kāśikāpriya": ['mw'],
    "kāśikātilaka": ['mw'],
    "kāśikāvivaraṇapañjikā": ['mw'],
    "kāśila": ['ap90', 'mw'],
    "kāśimanuja": ['mw'],
    "kāśin": ['ap90', 'cae', 'mw'],
    "kāśinagara": ['mw'],
    "kāśinātha": ['mw'],
    "kāśipa": ['mw'],
    "kāśipati": ['mw'],
    "kāśipurī": ['mw'],
    "kāśirāja": ['cae', 'mw'],
    "kāśirājan": ['mw'],
    "kāśirāma": ['mw'],
    "kāśisundara": ['bhs'],
    "kāśisundarī": ['bhs'],
    "kāśisūkṣma": ['bhs'],
    "kāśivardhana": ['bhs', 'mw'],
    "kāśivilāsa": ['mw'],
    "kāśiḥ": ['ap90'],
    "kāśiṣṇu": ['ap90', 'mw'],
    "kāśmalya": ['ddsa', 'mw'],
    "kāśmarya": ['mw'],
    "kāśmarī": ['ap90', 'cae', 'mw'],
    "kāśmīra": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāśmīradeśa": ['mw'],
    "kāśmīraja": ['cae', 'mw'],
    "kāśmīrajanman": ['cae', 'mw'],
    "kāśmīrajā": ['mw'],
    "kāśmīrajīrakā": ['mw'],
    "kāśmīraka": ['ap90', 'mw'],
    "kāśmīraliṅga": ['mw'],
    "kāśmīramaṇḍala": ['mw'],
    "kāśmīrapura": ['bhs', 'mw'],
    "kāśmīrasambhava": ['mw'],
    "kāśmīravāṇija": ['mw'],
    "kāśmīravṛkṣa": ['mw'],
    "kāśmīrika": ['ap90', 'ddsa', 'mw'],
    "kāśmīrikanivāsa": ['mw'],
    "kāśmīrikā": ['mw'],
    "kāśmīrya": ['mw'],
    "kāśmīryaṃ": ['ap90'],
    "kāśmīrā": ['bhs', 'mw'],
    "kāśmīrī": ['mw'],
    "kāśvarī": ['mw'],
    "kāśya": ['cae', 'ddsa', 'mw'],
    "kāśyaka": ['mw'],
    "kāśyapa": ['bhs', 'cae', 'ddsa', 'mw'],
    "kāśyapadvīpa": ['mw'],
    "kāśyapaka": ['mw'],
    "kāśyapanandana": ['mw'],
    "kāśyapaparivarta": ['bhs', 'mw'],
    "kāśyapapūraṇa": ['bhs'],
    "kāśyapasmṛti": ['mw'],
    "kāśyapaḥ": ['ap90'],
    "kāśyapeya": ['mw'],
    "kāśyapeyaḥ": ['ap90'],
    "kāśyapi": ['mw'],
    "kāśyapin": ['mw'],
    "kāśyapiḥ": ['ap90'],
    "kāśyapāyana": ['mw'],
    "kāśyapī": ['mw'],
    "kāśyapībhuj": ['mw'],
    "kāśyapībālākyāmāṭharīputra": ['mw'],
    "kāśyapīya": ['bhs', 'mw'],
    "kāśyaṃ": ['ap90'],
    "kāśyā": ['mw'],
    "kāśyādi": ['mw'],
    "kāśyāyana": ['mw'],
    "kāśādi": ['mw'],
    "kāśālmali": ['mw'],
    "kāśī": ['ap90', 'bhs', 'mw'],
    "kāśīkhaṇḍa": ['mw'],
    "kāśīmokṣa": ['mw'],
    "kāśīmāhātmya": ['mw'],
    "kāśīnātha": ['mw'],
    "kāśīnāthabhaṭṭa": ['mw'],
    "kāśīpati": ['mw'],
    "kāśīpraghaṭṭaka": ['mw'],
    "kāśīprakāśa": ['mw'],
    "kāśīrāja": ['mw'],
    "kāśīsetu": ['mw'],
    "kāśīstotra": ['mw'],
    "kāśīta": ['mw'],
    "kāśīvilāsa": ['mw'],
    "kāśīya": ['mw'],
    "kāśīśa": ['mw'],
    "kāśīśvara": ['mw'],
    "kāśū": ['ap90', 'mw'],
    "kāśūkāra": ['mw'],
    "kāḍa": ['bhs'],
    "kāḍiśāma": ['bhs'],
    "kāḷa": ['cped'],
    "kāḷajallikā": ['cped'],
    "kāḷaka": ['cped'],
    "kāḷakā": ['cped'],
    "kāḷaloṇa": ['cped'],
    "kāḷapabba": ['cped'],
    "kāḷapakkha": ['cped'],
    "kāḷasāma": ['cped'],
    "kāḷasāmaka": ['cped'],
    "kāḷavaṇṇa": ['cped'],
    "kāḷavaṇṇakata": ['cped'],
    "kāḷānusāri": ['cped'],
    "kāḷānusārika": ['cped'],
    "kāḷānusārin": ['cped'],
    "kāḷānusāriya": ['cped'],
    "kāḷāpabba": ['cped'],
    "kāṃbalaḥ": ['ap90'],
    "kāṃbavikaḥ": ['ap90'],
    "kāṃboja": ['ap90'],
    "kāṃbojaḥ": ['ap90'],
    "kāṃc": ['ap90'],
    "kāṃcana": ['ap90'],
    "kāṃcanakaḥ": ['ap90'],
    "kāṃcanālaḥ": ['ap90'],
    "kāṃcanāraḥ": ['ap90'],
    "kāṃcanīya": ['ap90'],
    "kāṃcikaṃ": ['ap90'],
    "kāṃciḥ": ['ap90'],
    "kāṃcī": ['ap90'],
    "kāṃdama": ['mw'],
    "kāṃdavaṃ": ['ap90'],
    "kāṃdavikaḥ": ['ap90'],
    "kāṃdigbhūta": ['mw'],
    "kāṃdiś": ['mw'],
    "kāṃdiśī": ['mw'],
    "kāṃdiśīka": ['ap90', 'mw'],
    "kāṃjikaṃ": ['ap90'],
    "kāṃkṣ": ['ap90'],
    "kāṃkṣin": ['ap90'],
    "kāṃkṣita": ['ap90'],
    "kāṃkṣoruḥ": ['ap90'],
    "kāṃkṣā": ['ap90'],
    "kāṃpillaḥ": ['ap90'],
    "kāṃs": ['mw'],
    "kāṃsa": ['bhs', 'mw'],
    "kāṃsika": ['bhs'],
    "kāṃsikā": ['bhs', 'mw'],
    "kāṃsya": ['ap90', 'cae', 'ddsa', 'mw'],
    "kāṃsyabhājana": ['mw'],
    "kāṃsyadoha": ['mw'],
    "kāṃsyadohana": ['mw'],
    "kāṃsyaghana": ['mw'],
    "kāṃsyaja": ['mw'],
    "kāṃsyaka": ['mw'],
    "kāṃsyakaṃ": ['ap90'],
    "kāṃsyakośī": ['mw'],
    "kāṃsyakāra": ['mw'],
    "kāṃsyamakṣika": ['mw'],
    "kāṃsyamala": ['mw'],
    "kāṃsyamaya": ['mw'],
    "kāṃsyanīla": ['mw'],
    "kāṃsyanīlī": ['mw'],
    "kāṃsyapātra": ['cae', 'mw'],
    "kāṃsyapātrī": ['mw'],
    "kāṃsyatāla": ['cae', 'mw'],
    "kāṃsyopadoha": ['mw'],
    "kāṃsyopadohana": ['mw'],
    "kāṃsyābha": ['mw'],
    "kāṃsīkṛ": ['mw'],
    "kāṃsīya": ['mw'],
    "kāṃsīyaṃ": ['ap90'],
    "kāṃta": ['ap90'],
    "kāṃtimat": ['ap90'],
    "kāṃtiḥ": ['ap90'],
    "kāṃtā": ['ap90'],
    "kāṃtārakaḥ": ['ap90'],
    "kāṃtāraḥ": ['ap90'],
    "kāṃśi": ['cae', 'ddsa', 'mw'],
    "kāṃśiḥ": ['ap90'],
    "kāṃḍavat": ['ap90'],
    "kāṃḍaḥ": ['ap90'],
    "kāṃḍikā": ['ap90'],
    "kāṃḍolaḥ": ['ap90'],
    "kāṃḍālaḥ": ['ap90'],
    "kāṃḍīraḥ": ['ap90'],
    "kāṅguka": ['mw'],
    "kāṅgā": ['mw'],
    "kāṅgī": ['bhs'],
    "kāṅkata": ['mw'],
    "kāṅkāyana": ['mw'],
    "kāṅkṣ": ['cae', 'ddsa', 'mw'],
    "kāṅkṣamāṇa": ['mw'],
    "kāṅkṣat": ['mw'],
    "kāṅkṣati": ['bhs'],
    "kāṅkṣaṇīya": ['ddsa', 'mw'],
    "kāṅkṣin": ['cae', 'mw'],
    "kāṅkṣita": ['bhs', 'mw'],
    "kāṅkṣitā": ['mw'],
    "kāṅkṣoru": ['mw'],
    "kāṅkṣā": ['bhs', 'cae', 'mw'],
    "kāṅkṣāyitatā": ['bhs'],
    "kāṅkṣī": ['mw'],
    "kāṇa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kāṇabhuja": ['mw'],
    "kāṇabhūti": ['mw'],
    "kāṇadeva": ['mw'],
    "kāṇaka": ['bhs'],
    "kāṇakacchapa": ['cped'],
    "kāṇatva": ['cae', 'mw'],
    "kāṇelī": ['ap90'],
    "kāṇelīmātṛ": ['cae', 'ddsa', 'mw'],
    "kāṇelīsuta": ['mw'],
    "kāṇera": ['mw'],
    "kāṇeri": ['mw'],
    "kāṇerin": ['mw'],
    "kāṇeya": ['mw'],
    "kāṇeyavidha": ['mw'],
    "kāṇeyaḥ": ['ap90'],
    "kāṇikera": ['mw'],
    "kāṇuka": ['gra', 'mw'],
    "kāṇva": ['cae', 'ddsa', 'gra', 'mw'],
    "kāṇvadeva": ['mw'],
    "kāṇvaka": ['mw'],
    "kāṇvaśākhin": ['mw'],
    "kāṇvaśākhā": ['mw'],
    "kāṇvaḥ": ['ap90'],
    "kāṇvya": ['mw'],
    "kāṇvyāyana": ['mw'],
    "kāṇvyāyanīya": ['mw'],
    "kāṇvāyana": ['gra', 'mw'],
    "kāṇvāyani": ['mw'],
    "kāṇvīputra": ['mw'],
    "kāṇvīya": ['mw'],
    "kāṇāda": ['mw'],
    "kāṇūka": ['mw'],
    "kāṇūkaḥ": ['ap90'],
    "kāṇḍa": ['cae', 'ddsa', 'mw'],
    "kāṇḍabhagna": ['mw'],
    "kāṇḍabhagnatva": ['mw'],
    "kāṇḍadhāra": ['mw'],
    "kāṇḍagocara": ['mw'],
    "kāṇḍaguṇḍa": ['mw'],
    "kāṇḍahīna": ['mw'],
    "kāṇḍaka": ['bhs'],
    "kāṇḍakaṇṭa": ['mw'],
    "kāṇḍakaṭu": ['mw'],
    "kāṇḍakaṭuka": ['mw'],
    "kāṇḍakāra": ['mw'],
    "kāṇḍakāṇḍaka": ['mw'],
    "kāṇḍakāṇḍi": ['bhs'],
    "kāṇḍakīlaka": ['mw'],
    "kāṇḍalāva": ['mw'],
    "kāṇḍamaya": ['mw'],
    "kāṇḍamayī": ['mw'],
    "kāṇḍamāyana": ['mw'],
    "kāṇḍanāman": ['mw'],
    "kāṇḍanī": ['mw'],
    "kāṇḍanīla": ['mw'],
    "kāṇḍapatita": ['mw'],
    "kāṇḍapattra": ['mw'],
    "kāṇḍapaṭa": ['mw'],
    "kāṇḍapaṭaka": ['mw'],
    "kāṇḍapaṭī": ['mw'],
    "kāṇḍaphala": ['mw'],
    "kāṇḍapuṅkhā": ['mw'],
    "kāṇḍapuṣpa": ['mw'],
    "kāṇḍapuṣpā": ['mw'],
    "kāṇḍapāta": ['mw'],
    "kāṇḍapṛṣṭha": ['cae', 'mw'],
    "kāṇḍarika": ['bhs'],
    "kāṇḍaruhā": ['mw'],
    "kāṇḍarṣi": ['mw'],
    "kāṇḍasandhi": ['mw'],
    "kāṇḍaspṛṣṭa": ['mw'],
    "kāṇḍatikta": ['mw'],
    "kāṇḍatiktaka": ['mw'],
    "kāṇḍavastra": ['mw'],
    "kāṇḍavat": ['mw'],
    "kāṇḍavisarga": ['mw'],
    "kāṇḍavāraṇa": ['mw'],
    "kāṇḍavāriṇī": ['mw'],
    "kāṇḍavīṇā": ['mw'],
    "kāṇḍaśākhā": ['mw'],
    "kāṇḍaṛṣi": ['mw'],
    "kāṇḍekṣu": ['mw'],
    "kāṇḍera": ['mw'],
    "kāṇḍeruhā": ['mw'],
    "kāṇḍerī": ['mw'],
    "kāṇḍikā": ['mw'],
    "kāṇḍin": ['cae', 'mw'],
    "kāṇḍola": ['mw'],
    "kāṇḍopakaraṇa": ['mw'],
    "kāṇḍyāyana": ['bhs'],
    "kāṇḍāgnaka": ['mw'],
    "kāṇḍāgni": ['mw'],
    "kāṇḍāla": ['mw'],
    "kāṇḍānukrama": ['mw'],
    "kāṇḍānukramaṇikā": ['mw'],
    "kāṇḍānukramaṇī": ['mw'],
    "kāṇḍānusamaya": ['mw'],
    "kāṇḍāra": ['cae', 'ddsa', 'mw'],
    "kāṇḍī": ['ddsa', 'mw'],
    "kāṇḍīra": ['cae', 'ddsa', 'mw'],
    "kāṇṭaka": ['ddsa', 'mw'],
    "kāṇṭakamardanika": ['mw'],
    "kāṇṭakāra": ['mw'],
    "kāṇṭheviddhi": ['mw'],
    "kāṇṭheviddhyā": ['mw'],
    "kāṇṭheviddhī": ['mw'],
    "kāṣa": ['cae', 'ddsa', 'mw'],
    "kāṣaḥ": ['ap90'],
    "kāṣaṇa": ['mw'],
    "kāṣeya": ['mw'],
    "kāṣi": ['mw'],
    "kāṣin": ['mw'],
    "kāṣāya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kāṣāyadhvajā": ['bhs'],
    "kāṣāyadhāraṇa": ['mw'],
    "kāṣāyagrahaṇa": ['bhs', 'mw'],
    "kāṣāyavasana": ['mw'],
    "kāṣāyavasanā": ['mw'],
    "kāṣāyavāsas": ['mw'],
    "kāṣāyavāsika": ['mw'],
    "kāṣāyaṇa": ['mw'],
    "kāṣāyin": ['mw'],
    "kāṣāyī": ['mw'],
    "kāṣṭha": ['cae', 'ddsa', 'mw'],
    "kāṣṭhabhakṣaṇa": ['mw'],
    "kāṣṭhabheda": ['mw'],
    "kāṣṭhabhid": ['mw'],
    "kāṣṭhabhāra": ['cae', 'mw'],
    "kāṣṭhabhāraka": ['bhs'],
    "kāṣṭhabhārika": ['mw'],
    "kāṣṭhabhūta": ['mw'],
    "kāṣṭhabhṛt": ['cae', 'mw'],
    "kāṣṭhacitā": ['mw'],
    "kāṣṭhadhātrīphala": ['mw'],
    "kāṣṭhadru": ['mw'],
    "kāṣṭhadāru": ['mw'],
    "kāṣṭhagarbha": ['mw'],
    "kāṣṭhaghaṭana": ['mw'],
    "kāṣṭhaghaṭita": ['mw'],
    "kāṣṭhahāraka": ['bhs'],
    "kāṣṭhajambū": ['mw'],
    "kāṣṭhaka": ['mw'],
    "kāṣṭhakadalī": ['mw'],
    "kāṣṭhakalāpa": ['mw'],
    "kāṣṭhakaṃ": ['ap90'],
    "kāṣṭhakhaṇḍa": ['mw'],
    "kāṣṭhakuddāla": ['mw'],
    "kāṣṭhakuṭṭa": ['mw'],
    "kāṣṭhakīya": ['mw'],
    "kāṣṭhakīṭa": ['mw'],
    "kāṣṭhakūṭa": ['mw'],
    "kāṣṭhalekhaka": ['mw'],
    "kāṣṭhalohin": ['mw'],
    "kāṣṭhaloṣṭamaya": ['cae', 'mw'],
    "kāṣṭham": ['mw'],
    "kāṣṭhamalla": ['mw'],
    "kāṣṭhamaya": ['cae', 'mw'],
    "kāṣṭhamaṭhī": ['mw'],
    "kāṣṭhapattropajīvin": ['mw'],
    "kāṣṭhapaṭṭa": ['mw'],
    "kāṣṭhapradāna": ['mw'],
    "kāṣṭhaputtalikā": ['mw'],
    "kāṣṭhapuṣpa": ['bhs', 'mw'],
    "kāṣṭhapāṣāṇavāsas": ['mw'],
    "kāṣṭhapāṭalā": ['mw'],
    "kāṣṭharajanī": ['mw'],
    "kāṣṭharajju": ['mw'],
    "kāṣṭhastambha": ['cae', 'mw'],
    "kāṣṭhasārivā": ['mw'],
    "kāṣṭhatakṣ": ['mw'],
    "kāṣṭhatakṣaka": ['mw'],
    "kāṣṭhatantu": ['mw'],
    "kāṣṭhavallikā": ['mw'],
    "kāṣṭhavallī": ['mw'],
    "kāṣṭhavat": ['mw'],
    "kāṣṭhavivara": ['mw'],
    "kāṣṭhavāstuka": ['mw'],
    "kāṣṭhavāṭa": ['mw'],
    "kāṣṭhaśālika": ['mw'],
    "kāṣṭhaṃ": ['ap90'],
    "kāṣṭhekṣu": ['mw'],
    "kāṣṭhika": ['ddsa', 'mw'],
    "kāṣṭhikavitta": ['bhs'],
    "kāṣṭhikaḥ": ['ap90'],
    "kāṣṭhikā": ['ap90', 'mw'],
    "kāṣṭhin": ['mw'],
    "kāṣṭhā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kāṣṭhādhirohaṇa": ['mw'],
    "kāṣṭhādi": ['mw'],
    "kāṣṭhāgata": ['mw'],
    "kāṣṭhāguru": ['mw'],
    "kāṣṭhāgāra": ['mw'],
    "kāṣṭhāluka": ['mw'],
    "kāṣṭhāmbuvāhinī": ['mw'],
    "kāṣṭhībhū": ['mw'],
    "kāṣṭhīla": ['mw'],
    "kāṣṭhīlā": ['ap90', 'mw'],
    "kāṣṭhīrasa": ['mw'],
    "kāṣṭāyana": ['mw'],
    "kāṭa": ['cae', 'ddsa', 'gra', 'mw'],
    "kāṭaka": ['bhs'],
    "kāṭakoṭacikā": ['cped'],
    "kāṭava": ['cae', 'ddsa', 'mw'],
    "kāṭavema": ['cae', 'mw'],
    "kāṭayavema": ['cae', 'ddsa', 'mw'],
    "kāṭaḥ": ['ap90'],
    "kāṭha": ['cae', 'ddsa', 'mw'],
    "kāṭhaka": ['cae', 'mw'],
    "kāṭhakagṛhyasūtra": ['mw'],
    "kāṭhakopaniṣad": ['cae', 'mw'],
    "kāṭhaśāṭhin": ['mw'],
    "kāṭhaḥ": ['ap90'],
    "kāṭheraṇi": ['mw'],
    "kāṭheraṇīya": ['mw'],
    "kāṭhina": ['mw'],
    "kāṭhinaṃ": ['ap90'],
    "kāṭhinya": ['cae', 'ddsa', 'mw'],
    "kāṭhinyaphala": ['mw'],
    "kāṭipya": ['mw'],
    "kāṭuka": ['mw'],
    "kāṭukaṃ": ['ap90'],
    "kāṭya": ['cae', 'mw'],
    "kāṭākṣa": ['mw'],
    "kīcaka": ['cae', 'ddsa', 'mw'],
    "kīcakabhid": ['mw'],
    "kīcakajit": ['mw'],
    "kīcakaniṣūdana": ['mw'],
    "kīcakasūdana": ['mw'],
    "kīcakavadha": ['mw'],
    "kīcakaḥ": ['ap90'],
    "kīdisa": ['cped'],
    "kīdṛg": ['mw'],
    "kīdṛgrūpa": ['cae', 'mw'],
    "kīdṛgvarṇa": ['mw'],
    "kīdṛgvyāpāravant": ['cae'],
    "kīdṛgvyāpāravat": ['mw'],
    "kīdṛgākāra": ['cae', 'ddsa', 'mw'],
    "kīdṛkṣa": ['cae', 'ddsa', 'mw'],
    "kīdṛś": ['cae', 'ddsa', 'gra', 'mw'],
    "kīdṛśa": ['ap90', 'cae', 'mw'],
    "kīja": ['ap90', 'cae', 'gra', 'mw'],
    "kīkasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kīkasamukha": ['mw'],
    "kīkasā": ['gra', 'mw'],
    "kīkasāsthi": ['mw'],
    "kīkasāsya": ['mw'],
    "kīkaṭa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kīkaṭaka": ['mw'],
    "kīkaṭin": ['mw'],
    "kīki": ['mw'],
    "kīkita": ['cped'],
    "kīkiḥ": ['ap90'],
    "kīl": ['ap90', 'mw'],
    "kīla": ['cae', 'ddsa', 'mw'],
    "kīlaka": ['cae', 'mw'],
    "kīlakavivaraṇa": ['mw'],
    "kīlakaḥ": ['ap90'],
    "kīlana": ['mw'],
    "kīlanīya": ['mw'],
    "kīlapādikā": ['mw'],
    "kīlasaṃsparśa": ['mw'],
    "kīlayate": ['bhs'],
    "kīlaḥ": ['ap90'],
    "kīleśvara": ['mw'],
    "kīlikā": ['ap90', 'ddsa', 'mw'],
    "kīlinī": ['mw'],
    "kīlita": ['ap90', 'cae', 'mw'],
    "kīluṣa": ['mw'],
    "kīlā": ['mw'],
    "kīlāla": ['cae', 'gra', 'mw'],
    "kīlāladhi": ['mw'],
    "kīlālaja": ['mw'],
    "kīlālapa": ['mw'],
    "kīlālapeśas": ['mw'],
    "kīlālapā": ['gra', 'mw'],
    "kīlālauṣadhi": ['mw'],
    "kīlālaḥ": ['ap90'],
    "kīlālin": ['mw'],
    "kīlālodhan": ['mw'],
    "kīm": ['gra', 'mw'],
    "kīna": ['mw'],
    "kīnaṃ": ['ap90'],
    "kīnāra": ['cae', 'gra', 'mw'],
    "kīnāraḥ": ['ap90'],
    "kīnāśa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kīra": ['cae', 'ddsa', 'mw'],
    "kīraka": ['mw'],
    "kīrakaḥ": ['ap90'],
    "kīrati": ['cped'],
    "kīravarṇaka": ['mw'],
    "kīraḥ": ['ap90'],
    "kīreṣṭa": ['mw'],
    "kīri": ['cae', 'ddsa', 'gra', 'mw'],
    "kīricodana": ['gra', 'mw'],
    "kīrihiti": ['cped'],
    "kīrin": ['cae', 'gra', 'mw'],
    "kīrisa": ['cped'],
    "kīriḥ": ['ap90'],
    "kīrmī": ['mw'],
    "kīrodbhūta": ['mw'],
    "kīrt": ['mw'],
    "kīrtana": ['bhs', 'cae', 'ddsa', 'mw'],
    "kīrtanaṃ": ['ap90'],
    "kīrtanya": ['mw'],
    "kīrtanā": ['mw'],
    "kīrtanīya": ['bhs', 'mw'],
    "kīrtay": ['ap90', 'cae'],
    "kīrtaya": ['ddsa'],
    "kīrtayat": ['mw'],
    "kīrtenia": ['gra'],
    "kīrtenya": ['cae', 'gra', 'mw'],
    "kīrti": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kīrtibhaj": ['cae'],
    "kīrtibhāj": ['mw'],
    "kīrtidhara": ['mw'],
    "kīrtika": ['bhs'],
    "kīrtikara": ['mw'],
    "kīrtimant": ['bhs', 'cae'],
    "kīrtimat": ['mw'],
    "kīrtimatī": ['mw'],
    "kīrtimaya": ['mw'],
    "kīrtimālinī": ['mw'],
    "kīrtināśana": ['cae'],
    "kīrtināśin": ['mw'],
    "kīrtipratāpabalasahita": ['mw'],
    "kīrtiratha": ['mw'],
    "kīrtirāja": ['mw'],
    "kīrtirāta": ['mw'],
    "kīrtisena": ['mw'],
    "kīrtisiṃhadeva": ['mw'],
    "kīrtisoma": ['mw'],
    "kīrtistambha": ['mw'],
    "kīrtisāra": ['mw'],
    "kīrtita": ['ap90', 'mw'],
    "kīrtitaraṃgiṇī": ['mw'],
    "kīrtitavya": ['mw'],
    "kīrtivarman": ['mw'],
    "kīrtivāsa": ['mw'],
    "kīrtiyuta": ['cae', 'mw'],
    "kīrtiśeṣa": ['mw'],
    "kīrtiḥ": ['ap90'],
    "kīrtti": ['mw'],
    "kīrtya": ['mw'],
    "kīrvi": ['mw'],
    "kīrya": ['mw'],
    "kīryamāṇa": ['mw'],
    "kīrśā": ['mw'],
    "kīrṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kīrṇapuṣpa": ['mw'],
    "kīrṇi": ['mw'],
    "kīrṇiḥ": ['ap90'],
    "kīsta": ['cae', 'gra', 'mw'],
    "kīta": ['cped'],
    "kīva": ['cped'],
    "kīva ciraṁ": ['cped'],
    "kīva cirena": ['cped'],
    "kīvabahuka": ['cped'],
    "kīvadīgha": ['cped'],
    "kīvadūra": ['cped'],
    "kīvadūrato": ['cped'],
    "kīvadūre": ['cped'],
    "kīvant": ['bhs', 'cae'],
    "kīvat": ['cped', 'gra', 'mw'],
    "kīvatakaṁ": ['cped'],
    "kīvatika": ['cped'],
    "kīvaṁ": ['cped'],
    "kīśa": ['cae', 'ddsa', 'mw'],
    "kīśaparṇa": ['mw'],
    "kīśaparṇī": ['mw'],
    "kīśaḥ": ['ap90'],
    "kīśmīla": ['mw'],
    "kīḍera": ['mw'],
    "kīḷanaka": ['cped'],
    "kīḷanta": ['cped'],
    "kīḷati": ['cped'],
    "kīḷi": ['cped'],
    "kīḷita": ['cped'],
    "kīḷitvā": ['cped'],
    "kīḷādhippāya": ['cped'],
    "kīḷāpanaka": ['cped'],
    "kīḷāpanikā": ['cped'],
    "kīḷāpenta": ['cped'],
    "kīṇāti": ['cped'],
    "kīṭ": ['ap90', 'mw'],
    "kīṭa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "kīṭagardabhaka": ['mw'],
    "kīṭaghna": ['mw'],
    "kīṭaja": ['cae', 'mw'],
    "kīṭajā": ['mw'],
    "kīṭaka": ['ap90', 'cae', 'cped', 'mw'],
    "kīṭamaṇi": ['mw'],
    "kīṭamārī": ['mw'],
    "kīṭamātṛ": ['mw'],
    "kīṭanāman": ['mw'],
    "kīṭapakṣodbhava": ['mw'],
    "kīṭapakṣodgama": ['mw'],
    "kīṭapataṃga": ['mw'],
    "kīṭapāḍikā": ['mw'],
    "kīṭayoni": ['mw'],
    "kīṭaśatru": ['mw'],
    "kīṭikā": ['ap90'],
    "kīṭotkara": ['ddsa', 'mw'],
    "kīṭāri": ['mw'],
    "kīṭāvapanna": ['ddsa', 'mw'],
    "kīṭī": ['mw'],
    "kśā": ['mw'],
    "kū": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kūbara": ['ap90', 'cae', 'ddsa', 'mw'],
    "kūbarasthāna": ['mw'],
    "kūbarin": ['ap90', 'mw'],
    "kūbarī": ['mw'],
    "kūca": ['mw'],
    "kūcakra": ['gra', 'mw'],
    "kūcakā": ['mw'],
    "kūcavāra": ['mw'],
    "kūcaḥ": ['ap90'],
    "kūcchaliṅga": ['mw'],
    "kūcid": ['gra', 'mw'],
    "kūcidarthin": ['gra', 'mw'],
    "kūcikā": ['ap90', 'mw'],
    "kūcī": ['cae', 'ddsa', 'mw'],
    "kūcīkā": ['mw'],
    "kūdara": ['mw'],
    "kūdaraḥ": ['ap90'],
    "kūddāla": ['mw'],
    "kūddālaḥ": ['ap90'],
    "kūdī": ['ap90', 'cae', 'ddsa', 'mw'],
    "kūdīmaya": ['mw'],
    "kūhaka": ['bhs'],
    "kūhanā": ['bhs', 'mw'],
    "kūhā": ['ap90', 'mw'],
    "kūj": ['ap90', 'cae', 'ddsa', 'mw'],
    "kūja": ['cae', 'ddsa', 'mw'],
    "kūjaka": ['bhs', 'mw'],
    "kūjana": ['mw'],
    "kūjaḥ": ['ap90'],
    "kūjin": ['mw'],
    "kūjita": ['mw'],
    "kūjitavya": ['mw'],
    "kūjitavye": ['mw'],
    "kūjya": ['mw'],
    "kūkuda": ['mw'],
    "kūkudaḥ": ['ap90'],
    "kūl": ['ap90', 'cae', 'ddsa', 'mw'],
    "kūla": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kūlabhū": ['mw'],
    "kūlacara": ['mw'],
    "kūlahaṇḍa": ['mw'],
    "kūlahaṇḍaka": ['mw'],
    "kūlajāta": ['cae', 'ddsa', 'mw'],
    "kūlaka": ['bhs', 'mw'],
    "kūlakaḥ": ['ap90'],
    "kūlamudruja": ['ap90', 'ddsa', 'mw'],
    "kūlamudvaha": ['ap90', 'mw'],
    "kūlapalugga": ['cped'],
    "kūlataṇḍula": ['mw'],
    "kūlavat": ['mw'],
    "kūlavatī": ['ap90', 'cae', 'ddsa', 'mw'],
    "kūlaṃ": ['ap90'],
    "kūlaṃdhaya": ['ap90', 'mw'],
    "kūlaṃkaṣa": ['ap90', 'cae', 'mw'],
    "kūlaṃkaṣā": ['mw'],
    "kūlaṅkaṣa": ['ddsa'],
    "kūlbaja": ['mw'],
    "kūlecara": ['mw'],
    "kūli": ['mw'],
    "kūlika": ['mw'],
    "kūlikā": ['mw'],
    "kūlin": ['ap90', 'mw'],
    "kūlinī": ['cae', 'ddsa', 'mw'],
    "kūlita": ['mw'],
    "kūlva": ['cae', 'mw'],
    "kūlya": ['cae', 'mw'],
    "kūlyā": ['mw'],
    "kūlāsa": ['mw'],
    "kūma": ['mw'],
    "kūmanas": ['mw'],
    "kūmaṃ": ['ap90'],
    "kūp": ['ap90', 'mw'],
    "kūpa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kūpabila": ['mw'],
    "kūpacakra": ['cae', 'mw'],
    "kūpadanḍa": ['mw'],
    "kūpadardura": ['mw'],
    "kūpaja": ['mw'],
    "kūpajala": ['mw'],
    "kūpajalodvāhana": ['mw'],
    "kūpaka": ['mw'],
    "kūpakacchapa": ['mw'],
    "kūpakandara": ['mw'],
    "kūpakaḥ": ['ap90'],
    "kūpakhanana": ['cae'],
    "kūpakhā": ['mw'],
    "kūpakhānaka": ['mw'],
    "kūpakāra": ['mw'],
    "kūpakūrma": ['mw'],
    "kūpamaṇḍūka": ['mw'],
    "kūpamaṇḍūkī": ['mw'],
    "kūparājya": ['mw'],
    "kūpat": ['mw'],
    "kūpayantra": ['cae', 'mw'],
    "kūpayantraghaṭikānyāya": ['mw'],
    "kūpaśaya": ['mw'],
    "kūpaḥ": ['ap90'],
    "kūpepitācaka": ['mw'],
    "kūpepiśācaka": ['mw'],
    "kūpika": ['mw'],
    "kūpikā": ['ddsa', 'mw'],
    "kūpodaka": ['mw'],
    "kūpuṣa": ['mw'],
    "kūpuṣaṃ": ['ap90'],
    "kūpya": ['ap90', 'cae', 'mw'],
    "kūpāda": ['mw'],
    "kūpāra": ['cae', 'gra', 'mw'],
    "kūpāraḥ": ['ap90'],
    "kūpāya": ['ddsa', 'mw'],
    "kūpāṅga": ['mw'],
    "kūpāṅka": ['mw'],
    "kūpī": ['mw'],
    "kūra": ['bhs', 'cae', 'mw'],
    "kūraḥ": ['ap90'],
    "kūrca": ['cae', 'ddsa', 'mw'],
    "kūrcaka": ['cae', 'mw'],
    "kūrcakaḥ": ['ap90'],
    "kūrcakin": ['mw'],
    "kūrcala": ['cae', 'mw'],
    "kūrcaparṇī": ['mw'],
    "kūrcatā": ['cae'],
    "kūrcaśekhara": ['mw'],
    "kūrcaśiras": ['mw'],
    "kūrcaśīrṣa": ['mw'],
    "kūrcaśīrṣaka": ['mw'],
    "kūrcaḥ": ['ap90'],
    "kūrcikā": ['ap90', 'mw'],
    "kūrcin": ['ap90', 'mw'],
    "kūrcāmukha": ['mw'],
    "kūrcānata": ['cae'],
    "kūrd": ['ap90', 'cae', 'ddsa', 'mw'],
    "kūrda": ['cae', 'ddsa', 'mw'],
    "kūrdana": ['mw'],
    "kūrdanaṃ": ['ap90'],
    "kūrdanā": ['mw'],
    "kūrdanī": ['mw'],
    "kūrkura": ['mw'],
    "kūrma": ['cae', 'ddsa', 'mw'],
    "kūrmacakra": ['mw'],
    "kūrmadvādaśī": ['mw'],
    "kūrmakalpa": ['mw'],
    "kūrmalakṣaṇa": ['mw'],
    "kūrmanātha": ['mw'],
    "kūrmapati": ['cae', 'mw'],
    "kūrmapitta": ['mw'],
    "kūrmapurāṇa": ['mw'],
    "kūrmapṛṣṭha": ['mw'],
    "kūrmapṛṣṭhaka": ['mw'],
    "kūrmapṛṣṭhonnata": ['mw'],
    "kūrmapṛṣṭhāsthi": ['mw'],
    "kūrmaramaṇī": ['mw'],
    "kūrmarāja": ['mw'],
    "kūrmavibhāga": ['mw'],
    "kūrmaḥ": ['ap90'],
    "kūrmi": ['cae', 'gra', 'mw'],
    "kūrmikā": ['mw'],
    "kūrmin": ['gra', 'mw'],
    "kūrmāsana": ['mw'],
    "kūrmāvatāra": ['mw'],
    "kūrmāṅga": ['mw'],
    "kūrmī": ['mw'],
    "kūrpa": ['cae', 'ddsa', 'mw'],
    "kūrpadṛś": ['mw'],
    "kūrpaka": ['mw'],
    "kūrpara": ['cae', 'ddsa', 'mw'],
    "kūrparaka": ['bhs'],
    "kūrparaḥ": ['ap90'],
    "kūrparita": ['mw'],
    "kūrparā": ['mw'],
    "kūrpasa": ['mw'],
    "kūrpaḥ": ['ap90'],
    "kūrpāsa": ['ap90', 'mw'],
    "kūrpāsaka": ['cae', 'ddsa', 'mw'],
    "kūtanā": ['mw'],
    "kūvara": ['ap90', 'mw'],
    "kūvarin": ['ap90'],
    "kūvāra": ['mw'],
    "kūvāraḥ": ['ap90'],
    "kūyava": ['mw'],
    "kūśma": ['cae', 'mw'],
    "kūśmāṇḍa": ['mw'],
    "kūśmāṇḍaka": ['mw'],
    "kūśāmba": ['mw'],
    "kūḍ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kūḍya": ['mw'],
    "kūḍyaṃ": ['ap90'],
    "kūḥ": ['ap90'],
    "kūṇ": ['ap90', 'cae', 'ddsa', 'mw'],
    "kūṇakuccha": ['mw'],
    "kūṇi": ['ap90', 'mw'],
    "kūṇika": ['mw'],
    "kūṇikā": ['ap90', 'mw'],
    "kūṇita": ['ap90', 'mw'],
    "kūṇitekṣaṇa": ['mw'],
    "kūṣma": ['cae', 'mw'],
    "kūṣmāṃḍaḥ": ['ap90'],
    "kūṣmāṇḍa": ['cae', 'ddsa', 'mw'],
    "kūṣmāṇḍadīpikā": ['mw'],
    "kūṣmāṇḍaka": ['mw'],
    "kūṣmāṇḍarājaputra": ['mw'],
    "kūṣmāṇḍinī": ['mw'],
    "kūṣmāṇḍā": ['mw'],
    "kūṣmāṇḍī": ['mw'],
    "kūṭ": ['ap90', 'mw'],
    "kūṭa": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "kūṭabandha": ['mw'],
    "kūṭabandham": ['mw'],
    "kūṭacchadman": ['mw'],
    "kūṭadanta": ['mw'],
    "kūṭadantī": ['bhs'],
    "kūṭadaṃṣṭra": ['bhs'],
    "kūṭadharma": ['mw'],
    "kūṭaghaṭitalakṣaṇa": ['mw'],
    "kūṭagrantha": ['mw'],
    "kūṭagrāmaka": ['bhs'],
    "kūṭaheman": ['mw'],
    "kūṭaja": ['mw'],
    "kūṭaka": ['ap90', 'cae', 'mw'],
    "kūṭakarman": ['cae', 'mw'],
    "kūṭakhaḍga": ['mw'],
    "kūṭakākhyāna": ['mw'],
    "kūṭakāra": ['mw'],
    "kūṭakāraka": ['cae', 'mw'],
    "kūṭakṛt": ['cae', 'mw'],
    "kūṭalekha": ['mw'],
    "kūṭalekhya": ['mw'],
    "kūṭamohana": ['mw'],
    "kūṭamudgara": ['mw'],
    "kūṭamāna": ['mw'],
    "kūṭanā": ['bhs'],
    "kūṭaparva": ['mw'],
    "kūṭapākala": ['mw'],
    "kūṭapāla": ['cae'],
    "kūṭapālaka": ['cae', 'mw'],
    "kūṭapāśa": ['mw'],
    "kūṭapūrva": ['mw'],
    "kūṭapūrī": ['mw'],
    "kūṭaracanā": ['mw'],
    "kūṭasaṃdoha": ['mw'],
    "kūṭasaṃghaṭitalakṣaṇa": ['mw'],
    "kūṭasaṃkrānti": ['mw'],
    "kūṭasimbalī": ['cped'],
    "kūṭastha": ['cae', 'mw'],
    "kūṭasthadīpa": ['mw'],
    "kūṭasthatva": ['mw'],
    "kūṭasthatā": ['mw'],
    "kūṭasvarṇa": ['mw'],
    "kūṭasākṣin": ['cae', 'mw'],
    "kūṭasākṣya": ['mw'],
    "kūṭatakṣ": ['mw'],
    "kūṭatulā": ['mw'],
    "kūṭatva": ['mw'],
    "kūṭatā": ['mw'],
    "kūṭatāpasa": ['cae', 'mw'],
    "kūṭavyavahārin": ['mw'],
    "kūṭavāgurā": ['cae'],
    "kūṭayantra": ['mw'],
    "kūṭayodhin": ['mw'],
    "kūṭayuddha": ['mw'],
    "kūṭaśaila": ['mw'],
    "kūṭaśas": ['mw'],
    "kūṭaśaḥ": ['ap90'],
    "kūṭaśālmali": ['mw'],
    "kūṭaśālmalika": ['mw'],
    "kūṭaśālmalī": ['mw'],
    "kūṭaśāsana": ['cae', 'mw'],
    "kūṭaṭṭha": ['cped'],
    "kūṭeyya": ['cped'],
    "kūṭopāya": ['mw'],
    "kūṭāgāra": ['bhs', 'cae', 'cped', 'mw'],
    "kūṭāgāraśālā": ['bhs', 'mw'],
    "kūṭākhyāna": ['mw'],
    "kūṭākṣa": ['cae', 'ddsa', 'mw'],
    "kūṭārtha": ['mw'],
    "kūṭārthabhāṣitā": ['mw'],
    "kūṭāsakkhi": ['cped'],
    "kūṭāyu": ['mw'],
    "kūṭī": ['mw'],
    "kūṭīkṛ": ['mw'],
    "kḷp": ['ap90', 'cae', 'mw'],
    "kḷpta": ['ap90', 'cae', 'mw'],
    "kḷptadhūpa": ['mw'],
    "kḷptakeśanakhaśmaśru": ['mw'],
    "kḷptakīlā": ['mw'],
    "kḷptanakha": ['mw'],
    "kḷpti": ['cae', 'mw'],
    "kḷptika": ['ap90', 'mw'],
    "kḷptiḥ": ['ap90'],
    "kṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛcchra": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṛcchrabhojin": ['mw'],
    "kṛcchrabhāj": ['mw'],
    "kṛcchradvitīya": ['mw'],
    "kṛcchradvādaśarātra": ['mw'],
    "kṛcchragata": ['cae', 'mw'],
    "kṛcchrakarman": ['cae', 'ddsa', 'mw'],
    "kṛcchrakāla": ['cae', 'mw'],
    "kṛcchrakṛt": ['mw'],
    "kṛcchram": ['mw'],
    "kṛcchramūtrapurīṣatva": ['mw'],
    "kṛcchrapatita": ['cae', 'mw'],
    "kṛcchraprāṇa": ['mw'],
    "kṛcchrarūpa": ['mw'],
    "kṛcchrasaṃvatsara": ['mw'],
    "kṛcchrasādhya": ['mw'],
    "kṛcchratas": ['mw'],
    "kṛcchratā": ['cae', 'mw'],
    "kṛcchravartin": ['mw'],
    "kṛcchraśas": ['mw'],
    "kṛcchreśrit": ['mw'],
    "kṛcchreṇa": ['mw'],
    "kṛcchrin": ['mw'],
    "kṛcchrodya": ['mw'],
    "kṛcchronmīla": ['mw'],
    "kṛcchrābda": ['ddsa', 'mw'],
    "kṛcchrānmukta": ['mw'],
    "kṛcchrāpta": ['mw'],
    "kṛcchrārdha": ['mw'],
    "kṛcchrāri": ['mw'],
    "kṛcchrāt": ['mw'],
    "kṛcchrātikṛcchra": ['cae', 'ddsa', 'mw'],
    "kṛcchrātikṛcchrau": ['mw'],
    "kṛcchrāya": ['mw'],
    "kṛcchrāyate": ['ap90'],
    "kṛcchrībhū": ['mw'],
    "kṛchra": ['gra'],
    "kṛchreśrit": ['gra'],
    "kṛdanta": ['cae', 'ddsa', 'mw'],
    "kṛdara": ['cae', 'mw'],
    "kṛdaraṃ": ['ap90'],
    "kṛdhu": ['ap90', 'cae', 'gra', 'mw'],
    "kṛdhuka": ['mw'],
    "kṛdhukarṇa": ['gra', 'mw'],
    "kṛka": ['mw'],
    "kṛkadāśū": ['gra', 'mw'],
    "kṛkala": ['mw'],
    "kṛkalā": ['ap90', 'mw'],
    "kṛkalāsa": ['cae', 'ddsa', 'mw'],
    "kṛkalāsadīpikā": ['mw'],
    "kṛkalāsaka": ['mw'],
    "kṛkalāsatva": ['mw'],
    "kṛkalāsatīrtha": ['mw'],
    "kṛkalāsaḥ": ['ap90'],
    "kṛkara": ['cae', 'ddsa', 'mw'],
    "kṛkarā": ['mw'],
    "kṛkavāku": ['cae', 'ddsa', 'mw'],
    "kṛkavākudhvaja": ['mw'],
    "kṛkavākuḥ": ['ap90'],
    "kṛkaḥ": ['ap90'],
    "kṛkaṇa": ['mw'],
    "kṛkaṇaḥ": ['ap90'],
    "kṛkaṇeyu": ['mw'],
    "kṛkaṇīya": ['mw'],
    "kṛkaṇṭhaka": ['mw'],
    "kṛkaṣā": ['cae', 'ddsa', 'mw'],
    "kṛkin": ['bhs', 'mw'],
    "kṛkulāsa": ['mw'],
    "kṛkālika": ['ddsa'],
    "kṛkālikā": ['cae', 'mw'],
    "kṛkāṭa": ['cae', 'mw'],
    "kṛkāṭaka": ['mw'],
    "kṛkāṭakaṃ": ['ap90'],
    "kṛkāṭikā": ['ap90', 'cae', 'mw'],
    "kṛkāṭī": ['cae', 'mw'],
    "kṛllopa": ['mw'],
    "kṛmi": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kṛmibhakṣa": ['mw'],
    "kṛmibhojana": ['mw'],
    "kṛmicaṇḍeśvara": ['mw'],
    "kṛmidantaka": ['mw'],
    "kṛmidrava": ['mw'],
    "kṛmighna": ['mw'],
    "kṛmighnā": ['mw'],
    "kṛmighnī": ['mw'],
    "kṛmighātin": ['mw'],
    "kṛmigranthi": ['mw'],
    "kṛmihantṛ": ['mw'],
    "kṛmihara": ['mw'],
    "kṛmihā": ['mw'],
    "kṛmija": ['cae', 'mw'],
    "kṛmijagdha": ['mw'],
    "kṛmijalaja": ['mw'],
    "kṛmijit": ['mw'],
    "kṛmijā": ['mw'],
    "kṛmika": ['cae', 'mw'],
    "kṛmikara": ['mw'],
    "kṛmikarṇa": ['mw'],
    "kṛmikarṇaka": ['mw'],
    "kṛmikaḥ": ['ap90'],
    "kṛmikaṇṭaka": ['mw'],
    "kṛmikośa": ['cae', 'mw'],
    "kṛmikośaja": ['cae', 'mw'],
    "kṛmikośottha": ['cae', 'mw'],
    "kṛmikṛt": ['mw'],
    "kṛmila": ['mw'],
    "kṛmilika": ['bhs'],
    "kṛmilikā": ['ap90', 'mw'],
    "kṛmilohaka": ['mw'],
    "kṛmilā": ['ap90', 'mw'],
    "kṛmilāśva": ['mw'],
    "kṛmimat": ['mw'],
    "kṛmin": ['mw'],
    "kṛmiparvata": ['mw'],
    "kṛmiphala": ['mw'],
    "kṛmipurīṣakā": ['mw'],
    "kṛmipūyavaha": ['mw'],
    "kṛmiripu": ['mw'],
    "kṛmiroga": ['mw'],
    "kṛmirāga": ['mw'],
    "kṛmisarārī": ['mw'],
    "kṛmisena": ['mw'],
    "kṛmisū": ['mw'],
    "kṛmisūtra": ['mw'],
    "kṛmitantujāla": ['mw'],
    "kṛmitā": ['mw'],
    "kṛmivarṇa": ['mw'],
    "kṛmivarṇā": ['bhs'],
    "kṛmivāriruha": ['mw'],
    "kṛmivṛkṣa": ['mw'],
    "kṛmiśa": ['bhs', 'mw'],
    "kṛmiśaila": ['mw'],
    "kṛmiśailaka": ['mw'],
    "kṛmiśatru": ['mw'],
    "kṛmiśaṅkha": ['mw'],
    "kṛmiśukti": ['mw'],
    "kṛmiśātrava": ['mw'],
    "kṛmiṇa": ['ap90', 'mw'],
    "kṛmuka": ['cae', 'ddsa', 'mw'],
    "kṛmī": ['mw'],
    "kṛmīlaka": ['mw'],
    "kṛmīlakaḥ": ['ap90'],
    "kṛnddhivicakṣaṇā": ['mw'],
    "kṛntana": ['cae', 'ddsa', 'mw'],
    "kṛntas": ['bhs'],
    "kṛntatra": ['cae', 'ddsa', 'gra', 'mw'],
    "kṛnttavicakṣaṇā": ['mw'],
    "kṛp": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛpa": ['cae', 'ddsa', 'gra', 'mw'],
    "kṛpanīl̤a": ['mw'],
    "kṛpanīḍa": ['gra'],
    "kṛpanīḷa": ['ddsa'],
    "kṛpay": ['cae', 'gra'],
    "kṛpaya": ['ddsa', 'mw'],
    "kṛpaḥ": ['ap90'],
    "kṛpaṇ": ['gra'],
    "kṛpaṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛpaṇabuddhi": ['mw'],
    "kṛpaṇadhī": ['mw'],
    "kṛpaṇakāśin": ['mw'],
    "kṛpaṇam": ['mw'],
    "kṛpaṇanindā": ['mw'],
    "kṛpaṇatva": ['mw'],
    "kṛpaṇavarṇa": ['mw'],
    "kṛpaṇavatsala": ['mw'],
    "kṛpaṇin": ['ap90', 'mw'],
    "kṛpaṇy": ['gra'],
    "kṛpaṇya": ['mw'],
    "kṛpaṇyati": ['ap90'],
    "kṛpaṇyu": ['mw'],
    "kṛpaṇāya": ['mw'],
    "kṛpaṭa": ['bhs'],
    "kṛptu": ['mw'],
    "kṛpā": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṛpācārya": ['mw'],
    "kṛpādvaita": ['mw'],
    "kṛpādṛṣṭi": ['mw'],
    "kṛpāhīna": ['mw'],
    "kṛpākara": ['mw'],
    "kṛpālava": ['bhs'],
    "kṛpālu": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṛpālutā": ['mw'],
    "kṛpāmaya": ['mw'],
    "kṛpāmiśra": ['mw'],
    "kṛpānvita": ['mw'],
    "kṛpānīla": ['mw'],
    "kṛpāsindhu": ['mw'],
    "kṛpāsāgara": ['mw'],
    "kṛpātman": ['mw'],
    "kṛpāvant": ['cae'],
    "kṛpāvat": ['mw'],
    "kṛpāviṣṭa": ['mw'],
    "kṛpāy": ['cae'],
    "kṛpāya": ['ddsa', 'mw'],
    "kṛpāyate": ['ap90'],
    "kṛpāyita": ['mw'],
    "kṛpāyitavat": ['mw'],
    "kṛpāṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "kṛpāṇaka": ['mw'],
    "kṛpāṇakaḥ": ['ap90'],
    "kṛpāṇaketu": ['mw'],
    "kṛpāṇaputrī": ['mw'],
    "kṛpāṇapāta": ['cae', 'mw'],
    "kṛpāṇapāṇi": ['cae', 'mw'],
    "kṛpāṇayaṣṭi": ['mw'],
    "kṛpāṇaḥ": ['ap90'],
    "kṛpāṇi": ['mw'],
    "kṛpāṇikā": ['ddsa', 'mw'],
    "kṛpāṇī": ['ap90', 'mw'],
    "kṛpī": ['ap90', 'mw'],
    "kṛpīpati": ['mw'],
    "kṛpīputra": ['mw'],
    "kṛpīsuta": ['mw'],
    "kṛpīṭa": ['cae', 'gra', 'mw'],
    "kṛpīṭapāla": ['mw'],
    "kṛpīṭayoni": ['mw'],
    "kṛpīṭaṃ": ['ap90'],
    "kṛsara": ['cae', 'ddsa', 'mw'],
    "kṛsaraḥ": ['ap90'],
    "kṛsarā": ['mw'],
    "kṛt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛta": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛtabandhu": ['mw'],
    "kṛtabhaga": ['mw'],
    "kṛtabhaya": ['mw'],
    "kṛtabhojana": ['mw'],
    "kṛtabhāva": ['mw'],
    "kṛtabhūmi": ['mw'],
    "kṛtabhūtamaitra": ['mw'],
    "kṛtabrahman": ['gra', 'mw'],
    "kṛtabuddhi": ['cae', 'mw'],
    "kṛtabāhu": ['mw'],
    "kṛtacchandas": ['mw'],
    "kṛtacchidra": ['mw'],
    "kṛtacchidrā": ['mw'],
    "kṛtacetas": ['mw'],
    "kṛtacihna": ['mw'],
    "kṛtacūḍa": ['cae', 'mw'],
    "kṛtadeśa": ['mw'],
    "kṛtadhanvan": ['mw'],
    "kṛtadharma": ['mw'],
    "kṛtadharman": ['mw'],
    "kṛtadhvaj": ['cae', 'gra', 'mw'],
    "kṛtadhvaja": ['mw'],
    "kṛtadhvasta": ['mw'],
    "kṛtadhvaṃsa": ['mw'],
    "kṛtadhī": ['mw'],
    "kṛtadvasu": ['gra', 'mw'],
    "kṛtadviṣṭa": ['mw'],
    "kṛtadyuti": ['mw'],
    "kṛtadāra": ['cae', 'mw'],
    "kṛtadāsa": ['mw'],
    "kṛtaghna": ['cae', 'mw'],
    "kṛtaghnatva": ['mw'],
    "kṛtaghnatā": ['mw'],
    "kṛtaghnīkṛti": ['mw'],
    "kṛtaghātayatna": ['mw'],
    "kṛtahasta": ['cae', 'mw'],
    "kṛtahastatā": ['mw'],
    "kṛtahastavat": ['mw'],
    "kṛtajanman": ['mw'],
    "kṛtajijñāsa": ['mw'],
    "kṛtajña": ['bhs', 'cae', 'mw'],
    "kṛtajñatva": ['mw'],
    "kṛtajñatā": ['mw'],
    "kṛtajñaśīla": ['mw'],
    "kṛtaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kṛtakalpa": ['mw'],
    "kṛtakalpataru": ['mw'],
    "kṛtakam": ['mw'],
    "kṛtakapaṭa": ['mw'],
    "kṛtakara": ['mw'],
    "kṛtakarman": ['mw'],
    "kṛtakartavya": ['cae', 'mw'],
    "kṛtakautuka": ['cae', 'mw'],
    "kṛtakopa": ['mw'],
    "kṛtakoṭi": ['mw'],
    "kṛtakraya": ['mw'],
    "kṛtakriya": ['cae', 'mw'],
    "kṛtakrudha": ['mw'],
    "kṛtakāla": ['mw'],
    "kṛtakāma": ['mw'],
    "kṛtakārin": ['mw'],
    "kṛtakārya": ['cae', 'mw'],
    "kṛtakāryatva": ['mw'],
    "kṛtakūrcaka": ['mw'],
    "kṛtakṛtya": ['cae', 'mw'],
    "kṛtakṛtyabhāva": ['mw'],
    "kṛtakṛtyatā": ['mw'],
    "kṛtakṣaṇa": ['cae', 'mw'],
    "kṛtalakṣaṇa": ['cae', 'mw'],
    "kṛtalavaṇa": ['mw'],
    "kṛtamaitra": ['mw'],
    "kṛtamandāra": ['mw'],
    "kṛtamanoratha": ['mw'],
    "kṛtamanyu": ['mw'],
    "kṛtamati": ['cae', 'mw'],
    "kṛtamaṅgala": ['mw'],
    "kṛtamukha": ['mw'],
    "kṛtamāla": ['cae', 'mw'],
    "kṛtamālaka": ['mw'],
    "kṛtamālā": ['mw'],
    "kṛtamārga": ['cae', 'mw'],
    "kṛtamūlya": ['mw'],
    "kṛtanakha": ['mw'],
    "kṛtanandana": ['mw'],
    "kṛtanirṇejana": ['cae', 'mw'],
    "kṛtanityakriya": ['mw'],
    "kṛtaniścaya": ['cae', 'mw'],
    "kṛtaniścayin": ['mw'],
    "kṛtanāmaka": ['mw'],
    "kṛtanāśaka": ['mw'],
    "kṛtanāśana": ['mw'],
    "kṛtapada": ['ddsa', 'mw'],
    "kṛtaparva": ['mw'],
    "kṛtapauruṣa": ['mw'],
    "kṛtapaścāttāpa": ['mw'],
    "kṛtapaṇa": ['mw'],
    "kṛtaphala": ['mw'],
    "kṛtaphalā": ['mw'],
    "kṛtapraharaṇa": ['mw'],
    "kṛtaprajña": ['mw'],
    "kṛtapratijña": ['mw'],
    "kṛtapratikṛta": ['mw'],
    "kṛtaprayatna": ['mw'],
    "kṛtaprayojana": ['mw'],
    "kṛtapraṇaya": ['cae'],
    "kṛtapraṇāma": ['mw'],
    "kṛtapriya": ['mw'],
    "kṛtapuṅkha": ['mw'],
    "kṛtapuṇya": ['cae', 'mw'],
    "kṛtapūrva": ['cae', 'mw'],
    "kṛtapūrvanāśana": ['mw'],
    "kṛtapūrvin": ['cae', 'mw'],
    "kṛtaratha": ['mw'],
    "kṛtarava": ['mw'],
    "kṛtaruc": ['mw'],
    "kṛtaruṣa": ['mw'],
    "kṛtasambandha": ['mw'],
    "kṛtasampuṭa": ['mw'],
    "kṛtasapatnikā": ['mw'],
    "kṛtasavya": ['mw'],
    "kṛtasaṃdhāna": ['cae'],
    "kṛtasaṃjña": ['cae', 'mw'],
    "kṛtasaṃkalpa": ['mw'],
    "kṛtasaṃketa": ['mw'],
    "kṛtasaṃnidhāna": ['mw'],
    "kṛtasaṃnāha": ['mw'],
    "kṛtasaṃsarga": ['mw'],
    "kṛtasaṃskāra": ['cae', 'mw'],
    "kṛtasmara": ['mw'],
    "kṛtasmaracarita": ['mw'],
    "kṛtasmaya": ['mw'],
    "kṛtasmita": ['cae'],
    "kṛtasneha": ['mw'],
    "kṛtaspṛha": ['mw'],
    "kṛtasthalā": ['mw'],
    "kṛtasthiti": ['mw'],
    "kṛtastoma": ['mw'],
    "kṛtasvara": ['mw'],
    "kṛtasvastyayana": ['mw'],
    "kṛtasvecchāhāra": ['mw'],
    "kṛtasāpatnikā": ['mw'],
    "kṛtasāpatnī": ['mw'],
    "kṛtasāpatnīkā": ['mw'],
    "kṛtatanutrāṇa": ['mw'],
    "kṛtatrāṇā": ['mw'],
    "kṛtatva": ['mw'],
    "kṛtatvara": ['cae', 'mw'],
    "kṛtatīrtha": ['ddsa', 'mw'],
    "kṛtaujas": ['mw'],
    "kṛtavadhyacihna": ['cae', 'mw'],
    "kṛtavaira": ['cae', 'mw'],
    "kṛtavarman": ['mw'],
    "kṛtavasati": ['cae', 'mw'],
    "kṛtavat": ['mw'],
    "kṛtavatī": ['mw'],
    "kṛtavedhaka": ['mw'],
    "kṛtavedhana": ['mw'],
    "kṛtavedhanā": ['mw'],
    "kṛtavedin": ['mw'],
    "kṛtavega": ['mw'],
    "kṛtavepathu": ['mw'],
    "kṛtavetana": ['mw'],
    "kṛtaveṣa": ['mw'],
    "kṛtavidya": ['cae', 'mw'],
    "kṛtavikrama": ['mw'],
    "kṛtavikriya": ['mw'],
    "kṛtavikāra": ['mw'],
    "kṛtavilāsa": ['mw'],
    "kṛtavismaya": ['mw'],
    "kṛtavivāha": ['mw'],
    "kṛtaviśeṣaka": ['cae'],
    "kṛtavrata": ['mw'],
    "kṛtavyadhana": ['mw'],
    "kṛtavyalīka": ['mw'],
    "kṛtavāgdvāra": ['mw'],
    "kṛtavāpa": ['cae', 'mw'],
    "kṛtavāpana": ['cae', 'mw'],
    "kṛtavīrya": ['mw'],
    "kṛtavṛddhi": ['mw'],
    "kṛtaya": ['mw'],
    "kṛtayajus": ['mw'],
    "kṛtayajña": ['mw'],
    "kṛtayatna": ['ddsa'],
    "kṛtayaśas": ['mw'],
    "kṛtayogya": ['mw'],
    "kṛtayuga": ['mw'],
    "kṛtayugāya": ['mw'],
    "kṛtayāma": ['mw'],
    "kṛtayūṣa": ['mw'],
    "kṛtaśakti": ['mw'],
    "kṛtaśarman": ['mw'],
    "kṛtaśas": ['bhs'],
    "kṛtaśastraniḥśrama": ['mw'],
    "kṛtaśauca": ['cae', 'mw'],
    "kṛtaśilpa": ['ddsa', 'mw'],
    "kṛtaśobha": ['mw'],
    "kṛtaśrama": ['mw'],
    "kṛtaśrāma": ['mw'],
    "kṛtaṃ": ['ap90', 'bhs'],
    "kṛtaṃjaya": ['mw'],
    "kṛte": ['ap90', 'ddsa', 'mw'],
    "kṛtena": ['mw'],
    "kṛterṣya": ['mw'],
    "kṛteyu": ['mw'],
    "kṛteyuka": ['mw'],
    "kṛtha": ['cae', 'gra', 'mw'],
    "kṛti": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛtikara": ['mw'],
    "kṛtimat": ['mw'],
    "kṛtin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kṛtiratha": ['mw'],
    "kṛtiroman": ['mw'],
    "kṛtirāta": ['mw'],
    "kṛtisādhyatva": ['mw'],
    "kṛtitva": ['mw'],
    "kṛtiḥ": ['ap90'],
    "kṛtnu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛto": ['bhs'],
    "kṛtoccais": ['mw'],
    "kṛtodaka": ['ddsa', 'mw'],
    "kṛtodvāha": ['mw'],
    "kṛtonmāda": ['mw'],
    "kṛtopabhoga": ['mw'],
    "kṛtopacāra": ['mw'],
    "kṛtopakāra": ['cae', 'mw'],
    "kṛtopanayana": ['cae', 'mw'],
    "kṛtopavāsa": ['cae', 'mw'],
    "kṛtotsāha": ['mw'],
    "kṛtoṃkāra": ['mw'],
    "kṛtpaṭala": ['mw'],
    "kṛtrima": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛtrimabhūmi": ['mw'],
    "kṛtrimadhūpa": ['mw'],
    "kṛtrimadhūpaka": ['cae', 'mw'],
    "kṛtrimaka": ['bhs', 'mw'],
    "kṛtrimamitra": ['mw'],
    "kṛtrimaputra": ['mw'],
    "kṛtrimaputraka": ['mw'],
    "kṛtrimaputrikā": ['mw'],
    "kṛtrimaratna": ['mw'],
    "kṛtrimatva": ['mw'],
    "kṛtrimatā": ['mw'],
    "kṛtrimavana": ['mw'],
    "kṛtrimaśatru": ['mw'],
    "kṛtrimodāsīna": ['mw'],
    "kṛtrimā": ['mw'],
    "kṛtrimāri": ['mw'],
    "kṛtrimārti": ['mw'],
    "kṛtsa": ['mw'],
    "kṛtsaṃ": ['ap90'],
    "kṛtsna": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kṛtsnagata": ['mw'],
    "kṛtsnahṛdaya": ['mw'],
    "kṛtsnaka": ['mw'],
    "kṛtsnakarmakṛt": ['cae'],
    "kṛtsnakāraka": ['mw'],
    "kṛtsnatara": ['mw'],
    "kṛtsnatva": ['mw'],
    "kṛtsnatā": ['mw'],
    "kṛtsnavid": ['cae', 'mw'],
    "kṛtsnavīta": ['mw'],
    "kṛtsnavṛta": ['mw'],
    "kṛtsnaśas": ['mw'],
    "kṛtsnāgata": ['bhs', 'mw'],
    "kṛtsnākarā": ['bhs', 'mw'],
    "kṛtsnāyata": ['mw'],
    "kṛtsnāyatana": ['bhs'],
    "kṛtta": ['ap90', 'mw'],
    "kṛttaruhā": ['mw'],
    "kṛttas": ['bhs'],
    "kṛttattvabodhinī": ['mw'],
    "kṛtti": ['ddsa', 'gra', 'mw'],
    "kṛttikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṛttikābhava": ['mw'],
    "kṛttikāpiñjara": ['mw'],
    "kṛttikāsambhava": ['mw'],
    "kṛttikāsuta": ['mw'],
    "kṛttikāñji": ['mw'],
    "kṛttima": ['bhs'],
    "kṛttipattrī": ['mw'],
    "kṛttiratha": ['mw'],
    "kṛttivāsa": ['mw'],
    "kṛttivāsas": ['cae', 'mw'],
    "kṛttivāseśvaraliṅga": ['mw'],
    "kṛttiḥ": ['ap90'],
    "kṛttyadhīvāsa": ['mw'],
    "kṛttāvaśeṣa": ['cae', 'ddsa'],
    "kṛtvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛtvarī": ['mw'],
    "kṛtvas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛtvia": ['gra'],
    "kṛtvya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛtvā": ['bhs', 'mw'],
    "kṛtvāya": ['mw'],
    "kṛtvāym, kṛtvī": ['ddsa'],
    "kṛtvī": ['mw'],
    "kṛtya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kṛtyacintā": ['mw'],
    "kṛtyacintāmaṇi": ['mw'],
    "kṛtyajña": ['mw'],
    "kṛtyaka": ['bhs'],
    "kṛtyakalpadruma": ['mw'],
    "kṛtyakalpalatā": ['mw'],
    "kṛtyakalpataru": ['mw'],
    "kṛtyakaumudī": ['mw'],
    "kṛtyakā": ['ap90', 'mw'],
    "kṛtyam": ['mw'],
    "kṛtyamahārṇava": ['mw'],
    "kṛtyamañjarī": ['mw'],
    "kṛtyapradīpa": ['mw'],
    "kṛtyaratna": ['mw'],
    "kṛtyaratnākara": ['mw'],
    "kṛtyaratnāvalī": ['mw'],
    "kṛtyarāja": ['mw'],
    "kṛtyasāra": ['mw'],
    "kṛtyatama": ['mw'],
    "kṛtyatattva": ['mw'],
    "kṛtyatā": ['mw'],
    "kṛtyavant": ['cae'],
    "kṛtyavartman": ['mw'],
    "kṛtyavat": ['mw'],
    "kṛtyavid": ['mw'],
    "kṛtyavidhi": ['mw'],
    "kṛtyaśeṣa": ['mw'],
    "kṛtyo": ['bhs'],
    "kṛtyā": ['bhs', 'gra', 'mw'],
    "kṛtyādūṣaṇa": ['mw'],
    "kṛtyādūṣi": ['mw'],
    "kṛtyāhata": ['cae', 'mw'],
    "kṛtyākṛt": ['cae', 'mw'],
    "kṛtyākṛtya": ['bhs', 'mw'],
    "kṛtyānuṣṭhānajñāna": ['bhs'],
    "kṛtyāpratiharaṇa": ['mw'],
    "kṛtyārāvaṇa": ['mw'],
    "kṛtyārūpa": ['cae', 'ddsa', 'mw'],
    "kṛtyāstra": ['mw'],
    "kṛtā": ['cae', 'gra', 'mw'],
    "kṛtābharaṇa": ['mw'],
    "kṛtābhaya": ['mw'],
    "kṛtābhisaraṇaveṣa": ['mw'],
    "kṛtābhiyoga": ['cae', 'mw'],
    "kṛtābhiṣeka": ['mw'],
    "kṛtābhiṣekā": ['mw'],
    "kṛtābhyanujña": ['mw'],
    "kṛtābhyāsa": ['mw'],
    "kṛtādara": ['mw'],
    "kṛtādhikāra": ['bhs', 'mw'],
    "kṛtādhipatya": ['mw'],
    "kṛtāgada": ['bhs'],
    "kṛtāgama": ['mw'],
    "kṛtāgas": ['ddsa', 'mw'],
    "kṛtāgaska": ['mw'],
    "kṛtāgni": ['mw'],
    "kṛtāgnikārya": ['mw'],
    "kṛtāhaka": ['mw'],
    "kṛtāhvāna": ['mw'],
    "kṛtāhāra": ['mw'],
    "kṛtāhāraka": ['cae', 'mw'],
    "kṛtākṛta": ['cae', 'ddsa', 'mw'],
    "kṛtākṛtaprasaṅgin": ['mw'],
    "kṛtākṛtyasama": ['mw'],
    "kṛtālaka": ['mw'],
    "kṛtālaya": ['ddsa', 'mw'],
    "kṛtāloka": ['mw'],
    "kṛtānana": ['mw'],
    "kṛtānati": ['mw'],
    "kṛtānna": ['cae', 'mw'],
    "kṛtānta": ['cae', 'mw'],
    "kṛtāntajanaka": ['mw'],
    "kṛtāntakālāsura": ['mw'],
    "kṛtāntanagarī": ['cae'],
    "kṛtāntara": ['mw'],
    "kṛtāntasaṃtrāsa": ['mw'],
    "kṛtāntā": ['mw'],
    "kṛtānukara": ['mw'],
    "kṛtānukūlya": ['mw'],
    "kṛtānukṛtakārin": ['mw'],
    "kṛtānusāra": ['cae', 'mw'],
    "kṛtānuvyādha": ['mw'],
    "kṛtānuyātra": ['mw'],
    "kṛtāpadāna": ['mw'],
    "kṛtāpakāra": ['mw'],
    "kṛtāpakṛta": ['mw'],
    "kṛtāparādha": ['cae', 'mw'],
    "kṛtārgha": ['mw'],
    "kṛtārtanāda": ['mw'],
    "kṛtārtha": ['cae', 'mw'],
    "kṛtārthanīya": ['mw'],
    "kṛtārthatva": ['mw'],
    "kṛtārthatā": ['mw'],
    "kṛtārthay": ['cae'],
    "kṛtārthaya": ['ddsa', 'mw'],
    "kṛtārthībhū": ['mw'],
    "kṛtārthībhūta": ['mw'],
    "kṛtārthīkaraṇa": ['ddsa', 'mw'],
    "kṛtārthīkṛ": ['mw'],
    "kṛtārthīkṛta": ['mw'],
    "kṛtāsanaparigraha": ['mw'],
    "kṛtāskandana": ['mw'],
    "kṛtāspada": ['mw'],
    "kṛtāstra": ['cae', 'mw'],
    "kṛtāstratā": ['mw'],
    "kṛtātithya": ['mw'],
    "kṛtātman": ['mw'],
    "kṛtāvadhi": ['mw'],
    "kṛtāvadhāna": ['mw'],
    "kṛtāvaguṇṭhana": ['cae'],
    "kṛtāvamarṣa": ['mw'],
    "kṛtāvasakthika": ['mw'],
    "kṛtāvastha": ['cae', 'mw'],
    "kṛtāvaśyaka": ['mw'],
    "kṛtāvin": ['bhs', 'mw'],
    "kṛtāvāsa": ['mw'],
    "kṛtāvṛtti": ['cae', 'mw'],
    "kṛtāya": ['mw'],
    "kṛtāyāsa": ['mw'],
    "kṛtāñjali": ['cae', 'mw'],
    "kṛtāñjalipuṭa": ['mw'],
    "kṛtāśa": ['mw'],
    "kṛtāśana": ['mw'],
    "kṛtāśaṃsa": ['mw'],
    "kṛtāśraya": ['mw'],
    "kṛtāṅka": ['cae', 'ddsa', 'mw'],
    "kṛtī": ['mw'],
    "kṛtīsuta": ['mw'],
    "kṛv": ['ap90', 'mw'],
    "kṛvi": ['mw'],
    "kṛvī": ['mw'],
    "kṛñ": ['ddsa'],
    "kṛś": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṛśa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛśabhṛtya": ['mw'],
    "kṛśabuddhi": ['mw'],
    "kṛśacañcu": ['mw'],
    "kṛśadhana": ['mw'],
    "kṛśagava": ['mw'],
    "kṛśagu": ['mw'],
    "kṛśaka": ['mw'],
    "kṛśakūṭa": ['mw'],
    "kṛśalaka": ['bhs'],
    "kṛśalā": ['ap90', 'mw'],
    "kṛśana": ['cae', 'gra', 'mw'],
    "kṛśanaṃ": ['ap90'],
    "kṛśanin": ['cae', 'gra', 'mw'],
    "kṛśanāsa": ['mw'],
    "kṛśanāvant": ['cae'],
    "kṛśanāvat": ['gra', 'mw'],
    "kṛśanāśa": ['mw'],
    "kṛśapaśu": ['mw'],
    "kṛśara": ['mw'],
    "kṛśaraḥ": ['ap90'],
    "kṛśatva": ['mw'],
    "kṛśatā": ['cae', 'mw'],
    "kṛśavṛtti": ['mw'],
    "kṛśaśākha": ['mw'],
    "kṛśikā": ['mw'],
    "kṛśita": ['mw'],
    "kṛśodara": ['cae', 'ddsa', 'mw'],
    "kṛśāku": ['mw'],
    "kṛśākṣa": ['mw'],
    "kṛśāluka": ['mw'],
    "kṛśānavaka": ['mw'],
    "kṛśānu": ['cae', 'ddsa', 'gra', 'mw'],
    "kṛśānuga": ['mw'],
    "kṛśānuka": ['mw'],
    "kṛśānuretas": ['mw'],
    "kṛśānuśakala": ['mw'],
    "kṛśānuḥ": ['ap90'],
    "kṛśārtha": ['ddsa', 'mw'],
    "kṛśātithi": ['mw'],
    "kṛśāśa": ['mw'],
    "kṛśāśva": ['mw'],
    "kṛśāśvin": ['ap90', 'mw'],
    "kṛśāṅga": ['cae', 'ddsa', 'mw'],
    "kṛśāṅgī": ['mw'],
    "kṛśī": ['mw'],
    "kṛśībhū": ['mw'],
    "kṛśīkṛ": ['cae', 'ddsa', 'mw'],
    "kṛśīkṛta": ['mw'],
    "kṛḍ": ['mw'],
    "kṛṃtanaṃ": ['ap90'],
    "kṛṃtatraṃ": ['ap90'],
    "kṛṇañja": ['mw'],
    "kṛṇotana": ['ddsa'],
    "kṛṇu": ['mw'],
    "kṛṇuḥ": ['ap90'],
    "kṛṇuṣvapājavatī": ['mw'],
    "kṛṇuṣvapājīyā": ['mw'],
    "kṛṇvat": ['gra'],
    "kṛṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṛṣa": ['mw'],
    "kṛṣaka": ['cae', 'ddsa', 'mw'],
    "kṛṣakaḥ": ['ap90'],
    "kṛṣi": ['cae', 'ddsa', 'gra', 'mw'],
    "kṛṣibhāgin": ['mw'],
    "kṛṣidviṣṭa": ['mw'],
    "kṛṣigrāma": ['bhs', 'mw'],
    "kṛṣijīvin": ['cae', 'mw'],
    "kṛṣika": ['mw'],
    "kṛṣikara": ['cae', 'mw'],
    "kṛṣikarman": ['cae', 'mw'],
    "kṛṣikarmānta": ['mw'],
    "kṛṣikā": ['mw'],
    "kṛṣikṛt": ['cae', 'mw'],
    "kṛṣiloha": ['mw'],
    "kṛṣimant": ['bhs'],
    "kṛṣiphala": ['mw'],
    "kṛṣirata": ['mw'],
    "kṛṣisaṃgraha": ['mw'],
    "kṛṣisaṃśita": ['mw'],
    "kṛṣisevā": ['mw'],
    "kṛṣitantra": ['mw'],
    "kṛṣiḥ": ['ap90'],
    "kṛṣkara": ['mw'],
    "kṛṣkaraḥ": ['ap90'],
    "kṛṣya": ['ddsa', 'mw'],
    "kṛṣyakāra": ['mw'],
    "kṛṣāku": ['mw'],
    "kṛṣāyu": ['mw'],
    "kṛṣāṇa": ['bhs', 'mw'],
    "kṛṣāṇaḥ": ['ap90'],
    "kṛṣāṇu": ['mw'],
    "kṛṣī": ['mw'],
    "kṛṣībala": ['mw'],
    "kṛṣīvala": ['cae', 'ddsa', 'gra', 'mw'],
    "kṛṣīvalaḥ": ['ap90'],
    "kṛṣīṭa": ['mw'],
    "kṛṣṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kṛṣṇaadhvan": ['gra'],
    "kṛṣṇabalakṣa": ['mw'],
    "kṛṣṇabandhu": ['bhs', 'mw'],
    "kṛṣṇabarbaraka": ['mw'],
    "kṛṣṇabhaginī": ['mw'],
    "kṛṣṇabhakta": ['mw'],
    "kṛṣṇabhakti": ['mw'],
    "kṛṣṇabhakticandrikā": ['mw'],
    "kṛṣṇabhakṣa": ['mw'],
    "kṛṣṇabhasman": ['mw'],
    "kṛṣṇabhaṭṭa": ['mw'],
    "kṛṣṇabhaṭṭī": ['mw'],
    "kṛṣṇabhaṭṭīya": ['mw'],
    "kṛṣṇabhedā": ['mw'],
    "kṛṣṇabhogin": ['mw'],
    "kṛṣṇabhujaṃga": ['mw'],
    "kṛṣṇabhū": ['mw'],
    "kṛṣṇabhūma": ['cae', 'mw'],
    "kṛṣṇabhūmijā": ['mw'],
    "kṛṣṇabhūmika": ['mw'],
    "kṛṣṇabhūṣaṇa": ['mw'],
    "kṛṣṇabīja": ['mw'],
    "kṛṣṇacaitanya": ['mw'],
    "kṛṣṇacaitanyapurī": ['mw'],
    "kṛṣṇacandra": ['mw'],
    "kṛṣṇacandradevaśarman": ['mw'],
    "kṛṣṇacara": ['mw'],
    "kṛṣṇacaturdaśī": ['cae', 'mw'],
    "kṛṣṇacañcuka": ['mw'],
    "kṛṣṇacchavi": ['mw'],
    "kṛṣṇacūrṇa": ['mw'],
    "kṛṣṇacūḍikā": ['mw'],
    "kṛṣṇacūḍā": ['mw'],
    "kṛṣṇadaivajña": ['mw'],
    "kṛṣṇadanta": ['mw'],
    "kṛṣṇadantā": ['mw'],
    "kṛṣṇadarśana": ['mw'],
    "kṛṣṇadatta": ['mw'],
    "kṛṣṇadaśa": ['mw'],
    "kṛṣṇadeha": ['mw'],
    "kṛṣṇadeva": ['mw'],
    "kṛṣṇadhattūra": ['mw'],
    "kṛṣṇadhattūraka": ['mw'],
    "kṛṣṇadhānya": ['mw'],
    "kṛṣṇadhūrjaṭidīkṣita": ['mw'],
    "kṛṣṇadhṛti": ['mw'],
    "kṛṣṇadra": ['mw'],
    "kṛṣṇadvaipāyana": ['mw'],
    "kṛṣṇadvādaśī": ['mw'],
    "kṛṣṇadāsa": ['mw'],
    "kṛṣṇadīkṣita": ['mw'],
    "kṛṣṇagala": ['mw'],
    "kṛṣṇagandhā": ['mw'],
    "kṛṣṇagarbha": ['gra', 'mw'],
    "kṛṣṇagarbhā": ['mw'],
    "kṛṣṇagati": ['ddsa', 'mw'],
    "kṛṣṇagautama": ['bhs'],
    "kṛṣṇagava": ['mw'],
    "kṛṣṇagaṅgā": ['mw'],
    "kṛṣṇagiri": ['mw'],
    "kṛṣṇagodhā": ['mw'],
    "kṛṣṇagotamaka": ['bhs'],
    "kṛṣṇagrīva": ['mw'],
    "kṛṣṇagulma": ['mw'],
    "kṛṣṇagupta": ['mw'],
    "kṛṣṇahārita": ['mw'],
    "kṛṣṇaita": ['mw'],
    "kṛṣṇaja": ['mw'],
    "kṛṣṇajanaka": ['mw'],
    "kṛṣṇajanmakhaṇḍa": ['mw'],
    "kṛṣṇajanmāṣṭamī": ['cae', 'mw'],
    "kṛṣṇajaṃhas": ['gra', 'mw'],
    "kṛṣṇajaṭā": ['mw'],
    "kṛṣṇajyotirvid": ['mw'],
    "kṛṣṇajī": ['mw'],
    "kṛṣṇajīra": ['mw'],
    "kṛṣṇajīraka": ['mw'],
    "kṛṣṇajīvanī": ['mw'],
    "kṛṣṇaka": ['bhs', 'mw'],
    "kṛṣṇakali": ['mw'],
    "kṛṣṇakanda": ['mw'],
    "kṛṣṇakaravīra": ['mw'],
    "kṛṣṇakarburavarṇa": ['mw'],
    "kṛṣṇakarkaṭaka": ['mw'],
    "kṛṣṇakarman": ['mw'],
    "kṛṣṇakarṇa": ['mw'],
    "kṛṣṇakarṇāmṛta": ['mw'],
    "kṛṣṇakavaca": ['mw'],
    "kṛṣṇakaṃ": ['ap90'],
    "kṛṣṇakaṭukā": ['mw'],
    "kṛṣṇakeli": ['mw'],
    "kṛṣṇakeśa": ['mw'],
    "kṛṣṇakhaṇḍa": ['mw'],
    "kṛṣṇakhura": ['mw'],
    "kṛṣṇakiṃkaraprakriyā": ['mw'],
    "kṛṣṇakohala": ['mw'],
    "kṛṣṇakrīḍita": ['mw'],
    "kṛṣṇakutūhala": ['mw'],
    "kṛṣṇakāka": ['mw'],
    "kṛṣṇakāpotī": ['mw'],
    "kṛṣṇakāṣṭha": ['mw'],
    "kṛṣṇakīrtana": ['mw'],
    "kṛṣṇala": ['cae', 'ddsa', 'mw'],
    "kṛṣṇalaka": ['mw'],
    "kṛṣṇalalāma": ['mw'],
    "kṛṣṇalavaṇa": ['mw'],
    "kṛṣṇalaḥ": ['ap90'],
    "kṛṣṇaloha": ['mw'],
    "kṛṣṇalohita": ['mw'],
    "kṛṣṇalā": ['mw'],
    "kṛṣṇalīlātaraṃgiṇī": ['mw'],
    "kṛṣṇamallikā": ['mw'],
    "kṛṣṇamasūra": ['mw'],
    "kṛṣṇamatsya": ['mw'],
    "kṛṣṇamaunin": ['mw'],
    "kṛṣṇamaṇḍala": ['mw'],
    "kṛṣṇamitra": ['mw'],
    "kṛṣṇamiśra": ['mw'],
    "kṛṣṇamudga": ['mw'],
    "kṛṣṇamukha": ['bhs', 'cae', 'mw'],
    "kṛṣṇamukhataṇḍula": ['mw'],
    "kṛṣṇamāhātmya": ['mw'],
    "kṛṣṇamāluka": ['mw'],
    "kṛṣṇamārga": ['mw'],
    "kṛṣṇamārgaṇa": ['mw'],
    "kṛṣṇamūlī": ['mw'],
    "kṛṣṇamṛd": ['mw'],
    "kṛṣṇamṛga": ['mw'],
    "kṛṣṇamṛttika": ['mw'],
    "kṛṣṇamṛttikā": ['mw'],
    "kṛṣṇanagara": ['mw'],
    "kṛṣṇanandana": ['mw'],
    "kṛṣṇanandin": ['mw'],
    "kṛṣṇanayana": ['cae', 'mw'],
    "kṛṣṇanetra": ['cae', 'mw'],
    "kṛṣṇapadāmṛta": ['mw'],
    "kṛṣṇapadī": ['mw'],
    "kṛṣṇapakṣa": ['bhs', 'cae', 'mw'],
    "kṛṣṇapakṣika": ['bhs', 'mw'],
    "kṛṣṇapakṣīya": ['mw'],
    "kṛṣṇaparṇī": ['mw'],
    "kṛṣṇapavi": ['gra', 'mw'],
    "kṛṣṇapaṇḍita": ['mw'],
    "kṛṣṇaphala": ['mw'],
    "kṛṣṇaphalā": ['mw'],
    "kṛṣṇapilla": ['mw'],
    "kṛṣṇapipīlī": ['mw'],
    "kṛṣṇapiṅgala": ['mw'],
    "kṛṣṇapiṅgalā": ['mw'],
    "kṛṣṇapiṅgā": ['mw'],
    "kṛṣṇapiṇḍīra": ['mw'],
    "kṛṣṇapiṇḍītaka": ['mw'],
    "kṛṣṇapremāmṛta": ['mw'],
    "kṛṣṇaprut": ['gra', 'mw'],
    "kṛṣṇapuccha": ['mw'],
    "kṛṣṇapucchaka": ['mw'],
    "kṛṣṇapuruṣottamasiddhāntopaniṣad": ['mw'],
    "kṛṣṇapuṣpa": ['mw'],
    "kṛṣṇapuṣpī": ['mw'],
    "kṛṣṇapāda": ['bhs'],
    "kṛṣṇapāka": ['mw'],
    "kṛṣṇapākaphala": ['mw'],
    "kṛṣṇapāṃsu": ['mw'],
    "kṛṣṇapāṇḍura": ['mw'],
    "kṛṣṇarakta": ['mw'],
    "kṛṣṇaruhā": ['mw'],
    "kṛṣṇarāja": ['bhs', 'mw'],
    "kṛṣṇarāma": ['mw'],
    "kṛṣṇarāmāya": ['mw'],
    "kṛṣṇarāya": ['mw'],
    "kṛṣṇarūpya": ['mw'],
    "kṛṣṇasaireyaka": ['mw'],
    "kṛṣṇasakha": ['mw'],
    "kṛṣṇasakhī": ['mw'],
    "kṛṣṇasamudbhavā": ['mw'],
    "kṛṣṇasaras": ['mw'],
    "kṛṣṇasarpa": ['cae', 'mw'],
    "kṛṣṇasarpā": ['mw'],
    "kṛṣṇasarṣapa": ['mw'],
    "kṛṣṇasevāhnika": ['mw'],
    "kṛṣṇasiṃha": ['mw'],
    "kṛṣṇaskandha": ['mw'],
    "kṛṣṇastotra": ['mw'],
    "kṛṣṇastuti": ['mw'],
    "kṛṣṇasundara": ['mw'],
    "kṛṣṇasvasṛ": ['mw'],
    "kṛṣṇasāra": ['cae', 'mw'],
    "kṛṣṇasāramukha": ['mw'],
    "kṛṣṇasārathi": ['mw'],
    "kṛṣṇasāraṅga": ['mw'],
    "kṛṣṇasāraṅgī": ['mw'],
    "kṛṣṇasārivā": ['mw'],
    "kṛṣṇasārvabhauma": ['mw'],
    "kṛṣṇasārā": ['mw'],
    "kṛṣṇasīta": ['gra', 'mw'],
    "kṛṣṇasū": ['mw'],
    "kṛṣṇasūnu": ['mw'],
    "kṛṣṇasūtra": ['mw'],
    "kṛṣṇatarkālaṃkāra": ['mw'],
    "kṛṣṇataṇḍulā": ['mw'],
    "kṛṣṇatila": ['mw'],
    "kṛṣṇatilya": ['mw'],
    "kṛṣṇatrivṛtā": ['mw'],
    "kṛṣṇatuṇḍa": ['mw'],
    "kṛṣṇatva": ['mw'],
    "kṛṣṇatā": ['cae', 'mw'],
    "kṛṣṇatāla": ['mw'],
    "kṛṣṇatāmra": ['mw'],
    "kṛṣṇatāra": ['mw'],
    "kṛṣṇatārā": ['mw'],
    "kṛṣṇatīrtha": ['mw'],
    "kṛṣṇatūṣa": ['mw'],
    "kṛṣṇau": ['mw'],
    "kṛṣṇaujas": ['mw'],
    "kṛṣṇavaktra": ['mw'],
    "kṛṣṇavallikā": ['mw'],
    "kṛṣṇavallī": ['mw'],
    "kṛṣṇavartani": ['gra', 'mw'],
    "kṛṣṇavartman": ['cae', 'mw'],
    "kṛṣṇavarṇa": ['cae', 'mw'],
    "kṛṣṇavarṇā": ['mw'],
    "kṛṣṇavastra": ['mw'],
    "kṛṣṇavetra": ['mw'],
    "kṛṣṇaveṇvā": ['mw'],
    "kṛṣṇaveṇyā": ['mw'],
    "kṛṣṇaveṇā": ['mw'],
    "kṛṣṇaveṇī": ['mw'],
    "kṛṣṇaveṇṇā": ['mw'],
    "kṛṣṇavinnā": ['mw'],
    "kṛṣṇavinoda": ['mw'],
    "kṛṣṇaviṣāṇa": ['mw'],
    "kṛṣṇaviṣāṇā": ['mw'],
    "kṛṣṇavrīhi": ['mw'],
    "kṛṣṇavyathis": ['gra', 'mw'],
    "kṛṣṇavyāla": ['mw'],
    "kṛṣṇavāla": ['cae', 'mw'],
    "kṛṣṇavānara": ['mw'],
    "kṛṣṇavāsa": ['mw'],
    "kṛṣṇavāsas": ['mw'],
    "kṛṣṇavātamaṇḍalī": ['bhs'],
    "kṛṣṇavṛntikā": ['mw'],
    "kṛṣṇavṛntā": ['mw'],
    "kṛṣṇayajurveda": ['cae', 'mw'],
    "kṛṣṇayajurvedīya": ['mw'],
    "kṛṣṇayamāritantra": ['bhs'],
    "kṛṣṇayoni": ['gra', 'mw'],
    "kṛṣṇayudhiṣṭhiradharmagoṣṭhī": ['mw'],
    "kṛṣṇayāma": ['gra', 'mw'],
    "kṛṣṇayāmala": ['mw'],
    "kṛṣṇaśa": ['ap90', 'cae', 'mw'],
    "kṛṣṇaśabala": ['mw'],
    "kṛṣṇaśakti": ['mw'],
    "kṛṣṇaśakuna": ['mw'],
    "kṛṣṇaśakuni": ['mw'],
    "kṛṣṇaśalkin": ['mw'],
    "kṛṣṇaśapha": ['mw'],
    "kṛṣṇaśarman": ['mw'],
    "kṛṣṇaśaṃkaraśarman": ['mw'],
    "kṛṣṇaśigru": ['mw'],
    "kṛṣṇaśilā": ['mw'],
    "kṛṣṇaśimbikā": ['mw'],
    "kṛṣṇaśimbī": ['mw'],
    "kṛṣṇaśiṃśapā": ['mw'],
    "kṛṣṇaśāli": ['mw'],
    "kṛṣṇaśīrṣan": ['mw'],
    "kṛṣṇaśṛta": ['mw'],
    "kṛṣṇaśṛṅga": ['mw'],
    "kṛṣṇaṣaṣṭika": ['mw'],
    "kṛṣṇaṣaṣṭikā": ['mw'],
    "kṛṣṇekṣu": ['mw'],
    "kṛṣṇeya": ['mw'],
    "kṛṣṇikā": ['ap90', 'ddsa', 'mw'],
    "kṛṣṇila": ['bhs'],
    "kṛṣṇiman": ['ap90', 'cae', 'mw'],
    "kṛṣṇiya": ['gra', 'mw'],
    "kṛṣṇodara": ['mw'],
    "kṛṣṇodaraśiras": ['mw'],
    "kṛṣṇodumbarikā": ['mw'],
    "kṛṣṇopaniṣad": ['mw'],
    "kṛṣṇoraga": ['mw'],
    "kṛṣṇosyākhareṣṭhaka": ['mw'],
    "kṛṣṇukta": ['bhs'],
    "kṛṣṇā": ['bhs', 'mw'],
    "kṛṣṇābhra": ['mw'],
    "kṛṣṇābhraka": ['mw'],
    "kṛṣṇābhā": ['mw'],
    "kṛṣṇācala": ['mw'],
    "kṛṣṇādhvan": ['gra', 'mw'],
    "kṛṣṇāgarukāṣṭha": ['mw'],
    "kṛṣṇāgata": ['mw'],
    "kṛṣṇāgraja": ['mw'],
    "kṛṣṇāguru": ['ddsa', 'mw'],
    "kṛṣṇāgurumaya": ['mw'],
    "kṛṣṇāhi": ['mw'],
    "kṛṣṇāhvaya": ['mw'],
    "kṛṣṇājina": ['cae', 'mw'],
    "kṛṣṇājinagrīva": ['mw'],
    "kṛṣṇājinin": ['mw'],
    "kṛṣṇājinā": ['bhs'],
    "kṛṣṇākṣa": ['mw'],
    "kṛṣṇākṣi": ['mw'],
    "kṛṣṇālaṃkāra": ['mw'],
    "kṛṣṇālpaka": ['mw'],
    "kṛṣṇālu": ['mw'],
    "kṛṣṇāmiṣa": ['mw'],
    "kṛṣṇāmṛtamahārṇava": ['mw'],
    "kṛṣṇāmṛtataraṃgikā": ['mw'],
    "kṛṣṇānadī": ['mw'],
    "kṛṣṇānanda": ['mw'],
    "kṛṣṇānandasvāmin": ['mw'],
    "kṛṣṇāntara": ['mw'],
    "kṛṣṇārcanavidhi": ['mw'],
    "kṛṣṇārcis": ['mw'],
    "kṛṣṇārjaka": ['mw'],
    "kṛṣṇātreya": ['mw'],
    "kṛṣṇāvadāta": ['mw'],
    "kṛṣṇāvatāra": ['mw'],
    "kṛṣṇāvāsa": ['mw'],
    "kṛṣṇāy": ['cae'],
    "kṛṣṇāya": ['ddsa', 'mw'],
    "kṛṣṇāyas": ['cae', 'mw'],
    "kṛṣṇāyasa": ['cae', 'mw'],
    "kṛṣṇāyate": ['ap90'],
    "kṛṣṇāñjanagiri": ['mw'],
    "kṛṣṇāñjanī": ['mw'],
    "kṛṣṇāñji": ['mw'],
    "kṛṣṇāśraya": ['mw'],
    "kṛṣṇāśrita": ['mw'],
    "kṛṣṇāṅga": ['mw'],
    "kṛṣṇāṅghri": ['mw'],
    "kṛṣṇāṅgī": ['mw'],
    "kṛṣṇāṣṭamirata": ['mw'],
    "kṛṣṇāṣṭamī": ['mw'],
    "kṛṣṇī": ['ddsa', 'gra', 'mw'],
    "kṛṣṇīas": ['mw'],
    "kṛṣṇībhū": ['mw'],
    "kṛṣṇīkaraṇa": ['mw'],
    "kṛṣṇīkaraṇaṃ": ['ap90'],
    "kṛṣṇīkṛ": ['mw'],
    "kṛṣṭa": ['ap90', 'cae', 'mw'],
    "kṛṣṭabhūmijā": ['mw'],
    "kṛṣṭaja": ['cae', 'ddsa', 'mw'],
    "kṛṣṭamatīkṛ": ['mw'],
    "kṛṣṭapacya": ['mw'],
    "kṛṣṭaphala": ['mw'],
    "kṛṣṭapākya": ['mw'],
    "kṛṣṭarādhi": ['mw'],
    "kṛṣṭasamīkṛ": ['ddsa', 'mw'],
    "kṛṣṭasamīkṛta": ['mw'],
    "kṛṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "kṛṣṭihan": ['gra', 'mw'],
    "kṛṣṭiojas": ['gra'],
    "kṛṣṭiprā": ['gra', 'mw'],
    "kṛṣṭiḥ": ['ap90'],
    "kṛṣṭopta": ['mw'],
    "kṛṣṭyojas": ['cae', 'gra', 'mw'],
    "kṝ": ['ap90', 'mw'],
    "kṝt": ['ap90', 'mw'],
    "kṣa": ['gra', 'mw'],
    "kṣad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣadana": ['mw'],
    "kṣadanaṃ": ['ap90'],
    "kṣadman": ['ap90', 'cae', 'gra', 'mw'],
    "kṣai": ['ap90', 'mw'],
    "kṣaimavṛddhi": ['mw'],
    "kṣaimavṛddhīya": ['mw'],
    "kṣaipra": ['cae', 'ddsa', 'mw'],
    "kṣaipravarṇa": ['mw'],
    "kṣaiprayukta": ['mw'],
    "kṣaipraṃ": ['ap90'],
    "kṣaiprya": ['mw'],
    "kṣaiprībhāvya": ['mw'],
    "kṣairahrada": ['mw'],
    "kṣairakalambhi": ['mw'],
    "kṣaireya": ['ap90', 'mw'],
    "kṣaireyī": ['mw'],
    "kṣaita": ['cae', 'gra', 'mw'],
    "kṣaitavat": ['gra', 'mw'],
    "kṣaiti": ['mw'],
    "kṣaitra": ['cae', 'ddsa', 'gra', 'mw'],
    "kṣaitrajitya": ['mw'],
    "kṣaitrajña": ['mw'],
    "kṣaitrajñaṃ": ['ap90'],
    "kṣaitrajñya": ['mw'],
    "kṣaitrapata": ['ddsa', 'mw'],
    "kṣaitrapatya": ['gra', 'mw'],
    "kṣaitraṃ": ['ap90'],
    "kṣaiṇya": ['cae', 'ddsa', 'mw'],
    "kṣaiṇyaṃ": ['ap90'],
    "kṣaj": ['mw'],
    "kṣal": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣama": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣamam": ['bhs'],
    "kṣamasya": ['mw'],
    "kṣamati": ['bhs'],
    "kṣamatva": ['mw'],
    "kṣamatā": ['cae', 'mw'],
    "kṣamavat": ['mw'],
    "kṣamaṇa": ['bhs'],
    "kṣamaṇīya": ['ap90', 'bhs', 'mw'],
    "kṣamia": ['gra'],
    "kṣamin": ['cae', 'ddsa', 'mw'],
    "kṣamita": ['mw'],
    "kṣamitavya": ['mw'],
    "kṣamitṛ": ['ap90', 'mw'],
    "kṣamottara": ['bhs'],
    "kṣamp": ['mw'],
    "kṣampana": ['bhs'],
    "kṣamuda": ['bhs', 'mw'],
    "kṣamya": ['cae', 'ddsa', 'gra', 'mw'],
    "kṣamā": ['ap90', 'ddsa', 'mw'],
    "kṣamābhuj": ['mw'],
    "kṣamābhṛt": ['mw'],
    "kṣamācara": ['mw'],
    "kṣamācārya": ['mw'],
    "kṣamādaṃśa": ['mw'],
    "kṣamākalyāṇa": ['mw'],
    "kṣamākara": ['mw'],
    "kṣamāliṅgātmapīḍāvat": ['mw'],
    "kṣamāmaṇḍala": ['mw'],
    "kṣamānvita": ['cae', 'mw'],
    "kṣamāpanna": ['mw'],
    "kṣamāpara": ['mw'],
    "kṣamāpati": ['mw'],
    "kṣamāpaya": ['mw'],
    "kṣamāpayati": ['ap90', 'bhs'],
    "kṣamāpaṇa": ['mw'],
    "kṣamātala": ['mw'],
    "kṣamātanaya": ['mw'],
    "kṣamāvant": ['cae'],
    "kṣamāvarta": ['mw'],
    "kṣamāvat": ['ap90', 'mw'],
    "kṣamāvatī": ['mw'],
    "kṣamāyukta": ['mw'],
    "kṣamāśipha": ['mw'],
    "kṣamāśramaṇa": ['mw'],
    "kṣamāśīla": ['cae', 'mw'],
    "kṣamāṣoḍaśī": ['mw'],
    "kṣamībhū": ['mw'],
    "kṣan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣantavya": ['cae', 'ddsa', 'mw'],
    "kṣantṛ": ['mw'],
    "kṣap": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣapa": ['mw'],
    "kṣapaka": ['mw'],
    "kṣapayiṣṇu": ['mw'],
    "kṣapaḥ": ['ap90', 'mw'],
    "kṣapaṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "kṣapaṇaka": ['cae', 'ddsa', 'mw'],
    "kṣapaṇakavihāra": ['mw'],
    "kṣapaṇakaḥ": ['ap90'],
    "kṣapaṇaḥ": ['ap90'],
    "kṣapaṇika": ['ddsa'],
    "kṣapaṇyu": ['mw'],
    "kṣapaṇyuḥ": ['ap90'],
    "kṣapaṇā": ['mw'],
    "kṣapaṇī": ['ap90', 'mw'],
    "kṣapaṇībhūta": ['mw'],
    "kṣapeśa": ['ddsa', 'mw'],
    "kṣapita": ['mw'],
    "kṣapitavya": ['ddsa', 'mw'],
    "kṣapā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣapācara": ['cae', 'mw'],
    "kṣapāghana": ['mw'],
    "kṣapāha": ['cae', 'mw'],
    "kṣapājala": ['mw'],
    "kṣapākara": ['cae', 'mw'],
    "kṣapākṛt": ['cae', 'mw'],
    "kṣapākṣaya": ['cae', 'mw'],
    "kṣapāndhya": ['mw'],
    "kṣapānātha": ['mw'],
    "kṣapāpaha": ['mw'],
    "kṣapāpati": ['mw'],
    "kṣapāramaṇa": ['mw'],
    "kṣapāramaṇaśekhara": ['mw'],
    "kṣapārdha": ['mw'],
    "kṣapātyaya": ['mw'],
    "kṣapāvasāna": ['mw'],
    "kṣapāvasāne": ['mw'],
    "kṣapāvat": ['gra', 'mw'],
    "kṣapāvyapāya": ['mw'],
    "kṣapāvṛtti": ['mw'],
    "kṣapāśaya": ['mw'],
    "kṣapāṭa": ['mw'],
    "kṣar": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣara": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣarabhāva": ['mw'],
    "kṣaraja": ['mw'],
    "kṣaraka": ['mw'],
    "kṣarapattrā": ['mw'],
    "kṣaraṇa": ['mw'],
    "kṣaraṇaṃ": ['ap90'],
    "kṣareja": ['mw'],
    "kṣarin": ['ap90', 'mw'],
    "kṣarita": ['ap90', 'mw'],
    "kṣarya": ['mw'],
    "kṣarātmaka": ['mw'],
    "kṣat": ['ap90'],
    "kṣata": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣataghna": ['mw'],
    "kṣatahara": ['mw'],
    "kṣataja": ['mw'],
    "kṣatajanman": ['mw'],
    "kṣatajapāta": ['mw'],
    "kṣatajaṣṭhīvin": ['mw'],
    "kṣatakāsa": ['mw'],
    "kṣatakṛt": ['mw'],
    "kṣatakṛta": ['mw'],
    "kṣatapuṇyaleśa": ['mw'],
    "kṣatarohaṇa": ['mw'],
    "kṣatasarpaṇa": ['mw'],
    "kṣatatejas": ['mw'],
    "kṣataujas": ['mw'],
    "kṣatavidhvaṃsin": ['mw'],
    "kṣatavikṣata": ['mw'],
    "kṣatavrata": ['mw'],
    "kṣatavraṇa": ['mw'],
    "kṣatavṛtti": ['mw'],
    "kṣatayoni": ['mw'],
    "kṣati": ['cae', 'ddsa', 'mw'],
    "kṣatimat": ['mw'],
    "kṣatin": ['mw'],
    "kṣatiḥ": ['ap90'],
    "kṣatodara": ['mw'],
    "kṣatodbhava": ['mw'],
    "kṣatottha": ['mw'],
    "kṣatra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣatrabandhu": ['cae', 'mw'],
    "kṣatrabheda": ['mw'],
    "kṣatrabhṛt": ['mw'],
    "kṣatradeva": ['mw'],
    "kṣatradharma": ['cae', 'ddsa', 'mw'],
    "kṣatradharman": ['cae', 'mw'],
    "kṣatradharmānuga": ['mw'],
    "kṣatradhṛti": ['mw'],
    "kṣatrajāta": ['cae', 'mw'],
    "kṣatramātra": ['mw'],
    "kṣatrapa": ['mw'],
    "kṣatrapati": ['mw'],
    "kṣatrarūpa": ['mw'],
    "kṣatrasava": ['mw'],
    "kṣatrasaṃgrahītṛ": ['mw'],
    "kṣatrasāman": ['mw'],
    "kṣatraujas": ['mw'],
    "kṣatravani": ['mw'],
    "kṣatravardhana": ['mw'],
    "kṣatravat": ['mw'],
    "kṣatraveda": ['mw'],
    "kṣatravidyā": ['cae', 'mw'],
    "kṣatravṛddha": ['mw'],
    "kṣatravṛddhi": ['mw'],
    "kṣatravṛdh": ['mw'],
    "kṣatravṛkṣa": ['mw'],
    "kṣatrayoga": ['mw'],
    "kṣatrayoni": ['cae', 'mw'],
    "kṣatraśrī": ['gra', 'mw'],
    "kṣatraḥ": ['ap90'],
    "kṣatrin": ['ap90', 'mw'],
    "kṣatriya": ['cae', 'ddsa', 'gra', 'mw'],
    "kṣatriyabruva": ['mw'],
    "kṣatriyadharma": ['mw'],
    "kṣatriyadharman": ['mw'],
    "kṣatriyahaṇa": ['mw'],
    "kṣatriyajāti": ['mw'],
    "kṣatriyakā": ['ap90', 'mw'],
    "kṣatriyamardana": ['mw'],
    "kṣatriyaprāya": ['mw'],
    "kṣatriyarāja": ['mw'],
    "kṣatriyarṣabha": ['mw'],
    "kṣatriyatva": ['mw'],
    "kṣatriyatā": ['mw'],
    "kṣatriyavarā": ['mw'],
    "kṣatriyayajña": ['mw'],
    "kṣatriyayoni": ['mw'],
    "kṣatriyayuvan": ['mw'],
    "kṣatriyaḥ": ['ap90'],
    "kṣatriyikā": ['mw'],
    "kṣatriyā": ['mw'],
    "kṣatriyāntakara": ['mw'],
    "kṣatriyāri": ['mw'],
    "kṣatriyāṇī": ['ap90', 'bhs', 'mw'],
    "kṣatriyī": ['ap90', 'mw'],
    "kṣatrānvaya": ['mw'],
    "kṣatrāyatanīya": ['mw'],
    "kṣatrī": ['mw'],
    "kṣattaṃ": ['bhs'],
    "kṣattṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣattṛjāti": ['cae'],
    "kṣatā": ['mw'],
    "kṣatābhyaṅga": ['mw'],
    "kṣatāri": ['mw'],
    "kṣaudra": ['bhs', 'cae', 'ddsa', 'mw'],
    "kṣaudradhātu": ['mw'],
    "kṣaudrajā": ['mw'],
    "kṣaudraka": ['mw'],
    "kṣaudrakamālava": ['mw'],
    "kṣaudrakamālavaka": ['mw'],
    "kṣaudrakya": ['mw'],
    "kṣaudrakī": ['mw'],
    "kṣaudrameha": ['mw'],
    "kṣaudramehin": ['mw'],
    "kṣaudrapaṭala": ['mw'],
    "kṣaudrapriya": ['mw'],
    "kṣaudraśarkarā": ['mw'],
    "kṣaudraḥ": ['ap90'],
    "kṣaudreya": ['mw'],
    "kṣaudreyaṃ": ['ap90'],
    "kṣauma": ['cae', 'ddsa', 'mw'],
    "kṣaumadaśā": ['mw'],
    "kṣaumaka": ['bhs', 'mw'],
    "kṣaumamaya": ['mw'],
    "kṣaumayugala": ['cae'],
    "kṣaumaḥ": ['ap90'],
    "kṣaumika": ['mw'],
    "kṣaumī": ['mw'],
    "kṣaura": ['cae', 'ddsa', 'mw'],
    "kṣaurakaraṇa": ['cae', 'mw'],
    "kṣaurakarman": ['cae', 'mw'],
    "kṣauramantra": ['mw'],
    "kṣauranakṣatra": ['mw'],
    "kṣauranirṇaya": ['mw'],
    "kṣaurapavya": ['mw'],
    "kṣaurarkṣa": ['mw'],
    "kṣauravidhi": ['mw'],
    "kṣauraṃ": ['ap90'],
    "kṣaurika": ['mw'],
    "kṣaurikaḥ": ['ap90'],
    "kṣaurī": ['mw'],
    "kṣauṇiḥ": ['ap90'],
    "kṣauṇī": ['cae', 'ddsa', 'mw'],
    "kṣauṇībhuj": ['mw'],
    "kṣauṇībhṛt": ['cae', 'mw'],
    "kṣauṇīdhara": ['cae', 'mw'],
    "kṣauṇīnātha": ['cae', 'mw'],
    "kṣauṇīprācīra": ['mw'],
    "kṣauṇītala": ['mw'],
    "kṣava": ['cae', 'ddsa', 'mw'],
    "kṣavaka": ['mw'],
    "kṣavakaṃ": ['ap90'],
    "kṣavakṛt": ['mw'],
    "kṣavathu": ['cae', 'mw'],
    "kṣavathuḥ": ['ap90'],
    "kṣavaḥ": ['ap90'],
    "kṣavikā": ['mw'],
    "kṣaya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣayadivasa": ['ddsa', 'mw'],
    "kṣayadvira": ['mw'],
    "kṣayadvīra": ['cae', 'gra', 'mw'],
    "kṣayaja": ['mw'],
    "kṣayakara": ['cae', 'mw'],
    "kṣayakartṛ": ['cae', 'mw'],
    "kṣayakāla": ['mw'],
    "kṣayakāsa": ['mw'],
    "kṣayakāsin": ['mw'],
    "kṣayakṛt": ['cae', 'mw'],
    "kṣayamāsa": ['mw'],
    "kṣayanāśinī": ['mw'],
    "kṣayapakṣa": ['mw'],
    "kṣayapravṛtta": ['mw'],
    "kṣayaroga": ['cae', 'mw'],
    "kṣayarogin": ['cae', 'mw'],
    "kṣayarogitva": ['mw'],
    "kṣayarogitā": ['mw'],
    "kṣayas": ['ap90', 'mw'],
    "kṣayasampad": ['mw'],
    "kṣayataru": ['mw'],
    "kṣayathu": ['mw'],
    "kṣayathuḥ": ['ap90'],
    "kṣayavāyu": ['mw'],
    "kṣayayitavya": ['mw'],
    "kṣayayoga": ['mw'],
    "kṣayayukta": ['mw'],
    "kṣayayukti": ['mw'],
    "kṣayaḥ": ['ap90'],
    "kṣayaṃkara": ['cae', 'mw'],
    "kṣayaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣayi": ['mw'],
    "kṣayika": ['mw'],
    "kṣayikala": ['mw'],
    "kṣayin": ['ap90', 'cae', 'mw'],
    "kṣayita": ['mw'],
    "kṣayitatā": ['mw'],
    "kṣayitva": ['mw'],
    "kṣayitā": ['ddsa'],
    "kṣayiṣṇu": ['ap90', 'cae', 'mw'],
    "kṣayopaśama": ['mw'],
    "kṣayya": ['mw'],
    "kṣayā": ['mw'],
    "kṣayāha": ['mw'],
    "kṣayāpagata": ['bhs'],
    "kṣañj": ['mw'],
    "kṣaḥ": ['ap90'],
    "kṣaṃj": ['ap90'],
    "kṣaṃtavya": ['ap90'],
    "kṣaṃtṛ": ['ap90'],
    "kṣaṇ": ['ap90', 'ddsa', 'mw'],
    "kṣaṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "kṣaṇabhaṅga": ['mw'],
    "kṣaṇabhaṅgavāda": ['mw'],
    "kṣaṇabhaṅgavādin": ['mw'],
    "kṣaṇabhaṅgin": ['mw'],
    "kṣaṇabhaṅgura": ['mw'],
    "kṣaṇabhūta": ['mw'],
    "kṣaṇada": ['mw'],
    "kṣaṇadeśa": ['mw'],
    "kṣaṇadyuti": ['mw'],
    "kṣaṇadā": ['cae', 'ddsa', 'mw'],
    "kṣaṇadācara": ['cae', 'mw'],
    "kṣaṇadādhinātha": ['mw'],
    "kṣaṇadākara": ['cae', 'mw'],
    "kṣaṇadākṛt": ['mw'],
    "kṣaṇadāndhya": ['mw'],
    "kṣaṇadṛṣṭa": ['mw'],
    "kṣaṇadṛṣṭanaṣṭa": ['mw'],
    "kṣaṇakleśa": ['mw'],
    "kṣaṇakṣapā": ['mw'],
    "kṣaṇakṣaṇam": ['mw'],
    "kṣaṇakṣepa": ['mw'],
    "kṣaṇam": ['mw'],
    "kṣaṇamaṅgala": ['cae'],
    "kṣaṇamātra": ['ddsa', 'mw'],
    "kṣaṇamātram": ['mw'],
    "kṣaṇamātreṇa": ['mw'],
    "kṣaṇamātrānurāgin": ['mw'],
    "kṣaṇana": ['cae', 'ddsa', 'mw'],
    "kṣaṇanaṃ": ['ap90'],
    "kṣaṇanaṣṭadṛṣṭa": ['mw'],
    "kṣaṇaniśvāsa": ['mw'],
    "kṣaṇanu": ['mw'],
    "kṣaṇaprabha": ['mw'],
    "kṣaṇaprabhā": ['mw'],
    "kṣaṇaprakāśā": ['mw'],
    "kṣaṇarajanī": ['mw'],
    "kṣaṇarāmin": ['mw'],
    "kṣaṇatuḥ": ['ap90'],
    "kṣaṇavidhvaṃsin": ['mw'],
    "kṣaṇavighna": ['mw'],
    "kṣaṇavighnita": ['mw'],
    "kṣaṇavīrya": ['mw'],
    "kṣaṇavṛṣṭi": ['mw'],
    "kṣaṇaśas": ['mw'],
    "kṣaṇaḥ": ['ap90'],
    "kṣaṇekṣaṇā": ['bhs'],
    "kṣaṇena": ['mw'],
    "kṣaṇepāka": ['mw'],
    "kṣaṇeṣu": ['mw'],
    "kṣaṇika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "kṣaṇikatva": ['mw'],
    "kṣaṇikatā": ['mw'],
    "kṣaṇikavāda": ['mw'],
    "kṣaṇikā": ['mw'],
    "kṣaṇin": ['ap90', 'mw'],
    "kṣaṇinī": ['mw'],
    "kṣaṇita": ['mw'],
    "kṣaṇitu": ['mw'],
    "kṣaṇā": ['bhs'],
    "kṣaṇāntara": ['cae', 'ddsa', 'mw'],
    "kṣaṇāntare": ['mw'],
    "kṣaṇārdha": ['mw'],
    "kṣaṇāt": ['mw'],
    "kṣaṇāṃśu": ['mw'],
    "kṣeda": ['mw'],
    "kṣema": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣemabhūmi": ['mw'],
    "kṣemadarśin": ['mw'],
    "kṣemadarśīya": ['mw'],
    "kṣemadhanvan": ['mw'],
    "kṣemadharman": ['mw'],
    "kṣemadhūrta": ['mw'],
    "kṣemadhūrti": ['mw'],
    "kṣemadhṛtvan": ['mw'],
    "kṣemagupta": ['mw'],
    "kṣemais": ['mw'],
    "kṣemajit": ['mw'],
    "kṣemaka": ['bhs', 'mw'],
    "kṣemakara": ['cae', 'ddsa', 'mw'],
    "kṣemakarman": ['mw'],
    "kṣemakarī": ['mw'],
    "kṣemakarṇa": ['mw'],
    "kṣemakutūhala": ['mw'],
    "kṣemakāma": ['gra', 'mw'],
    "kṣemakāra": ['mw'],
    "kṣemakāraka": ['mw'],
    "kṣemakṛt": ['cae', 'mw'],
    "kṣemamūrti": ['mw'],
    "kṣemamūrtitīrtha": ['mw'],
    "kṣemaphalā": ['mw'],
    "kṣemarāja": ['mw'],
    "kṣemasiṃha": ['mw'],
    "kṣematara": ['mw'],
    "kṣemataru": ['mw'],
    "kṣemavarman": ['mw'],
    "kṣemavat": ['mw'],
    "kṣemavatī": ['mw'],
    "kṣemavid": ['mw'],
    "kṣemavāha": ['mw'],
    "kṣemavṛddhi": ['mw'],
    "kṣemavṛddhin": ['mw'],
    "kṣemavṛkṣa": ['mw'],
    "kṣemay": ['cae', 'gra'],
    "kṣemaya": ['ddsa'],
    "kṣemayat": ['mw'],
    "kṣemayoga": ['cae', 'ddsa', 'mw'],
    "kṣemayuktam": ['mw'],
    "kṣemaśarman": ['mw'],
    "kṣemaśūra": ['mw'],
    "kṣemaṃgama": ['bhs'],
    "kṣemaṃkara": ['bhs', 'cae', 'mw'],
    "kṣemaṃkarin": ['mw'],
    "kṣemaṃkarī": ['mw'],
    "kṣemaṇīyapṛccha": ['bhs'],
    "kṣemaṇīyatara": ['bhs', 'mw'],
    "kṣemendra": ['cae', 'ddsa', 'mw'],
    "kṣemeśvara": ['mw'],
    "kṣemeṃdra": ['ap90'],
    "kṣemeṇa": ['mw'],
    "kṣemia": ['gra'],
    "kṣemin": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣemu": ['bhs'],
    "kṣemya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣemyā": ['mw'],
    "kṣemā": ['bhs', 'mw'],
    "kṣemādhi": ['mw'],
    "kṣemāditya": ['mw'],
    "kṣemānanda": ['mw'],
    "kṣemāphalā": ['mw'],
    "kṣemārcis": ['mw'],
    "kṣemāri": ['mw'],
    "kṣemāvatī": ['bhs', 'mw'],
    "kṣemīśvara": ['cae', 'ddsa', 'mw'],
    "kṣepa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣepadina": ['mw'],
    "kṣepaka": ['ap90', 'cae', 'mw'],
    "kṣepan": ['cae', 'ddsa', 'mw'],
    "kṣepapāta": ['mw'],
    "kṣepavṛtta": ['mw'],
    "kṣepayati": ['bhs'],
    "kṣepaḥ": ['ap90'],
    "kṣepaṇa": ['bhs', 'cae', 'mw'],
    "kṣepaṇasāra": ['mw'],
    "kṣepaṇaṃ": ['ap90'],
    "kṣepaṇi": ['mw'],
    "kṣepaṇika": ['cae', 'mw'],
    "kṣepaṇī": ['mw'],
    "kṣepaṇīya": ['ap90', 'mw'],
    "kṣepiman": ['ap90', 'mw'],
    "kṣepiṣṭha": ['cae', 'ddsa', 'mw'],
    "kṣepnu": ['cae', 'mw'],
    "kṣeptavya": ['mw'],
    "kṣeptṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣepu": ['bhs'],
    "kṣepya": ['ap90', 'mw'],
    "kṣepāya": ['mw'],
    "kṣepīyas": ['mw'],
    "kṣepīyaṃs": ['cae'],
    "kṣepṇā": ['mw'],
    "kṣetivat": ['mw'],
    "kṣetra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣetrabhakti": ['mw'],
    "kṣetrabhāga": ['mw'],
    "kṣetrabhūmi": ['mw'],
    "kṣetracirbhiṭā": ['mw'],
    "kṣetrada": ['mw'],
    "kṣetradevatā": ['mw'],
    "kṣetradharman": ['mw'],
    "kṣetradūtikā": ['mw'],
    "kṣetradūtī": ['mw'],
    "kṣetragata": ['mw'],
    "kṣetragatopapatti": ['mw'],
    "kṣetragaṇita": ['mw'],
    "kṣetragṛha": ['cae', 'mw'],
    "kṣetraja": ['cae', 'mw'],
    "kṣetrajeṣa": ['gra', 'mw'],
    "kṣetrajña": ['cae', 'mw'],
    "kṣetrajñā": ['mw'],
    "kṣetrajā": ['mw'],
    "kṣetrajāta": ['mw'],
    "kṣetrakara": ['mw'],
    "kṣetrakarkaṭī": ['mw'],
    "kṣetrakarmakṛt": ['mw'],
    "kṣetrakarman": ['ddsa', 'mw'],
    "kṣetrakarṣaka": ['mw'],
    "kṣetraliptā": ['mw'],
    "kṣetraliptīkaraṇa": ['mw'],
    "kṣetrapa": ['cae', 'mw'],
    "kṣetrapada": ['mw'],
    "kṣetraparpaṭa": ['mw'],
    "kṣetraparpaṭī": ['mw'],
    "kṣetrapati": ['cae', 'mw'],
    "kṣetraphala": ['mw'],
    "kṣetrapāla": ['cae', 'mw'],
    "kṣetrapālarasa": ['mw'],
    "kṣetrarakṣa": ['mw'],
    "kṣetraruhā": ['mw'],
    "kṣetrarāśi": ['mw'],
    "kṣetrasambhava": ['mw'],
    "kṣetrasambhavā": ['mw'],
    "kṣetrasambhūta": ['mw'],
    "kṣetrasamāsa": ['mw'],
    "kṣetrasaṃhitā": ['mw'],
    "kṣetrasiṃha": ['mw'],
    "kṣetrastha": ['mw'],
    "kṣetrasādhas": ['gra', 'mw'],
    "kṣetrasāti": ['gra', 'mw'],
    "kṣetrasīmā": ['mw'],
    "kṣetratara": ['cae', 'mw'],
    "kṣetratattva": ['mw'],
    "kṣetratā": ['mw'],
    "kṣetravasudhā": ['mw'],
    "kṣetravid": ['cae', 'gra', 'mw'],
    "kṣetravitṛṇṇī": ['mw'],
    "kṣetravyavahāra": ['mw'],
    "kṣetrayamānikā": ['mw'],
    "kṣetraṃ": ['ap90'],
    "kṣetraṃjaya": ['mw'],
    "kṣetrekṣu": ['mw'],
    "kṣetrika": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣetrin": ['ap90', 'cae', 'mw'],
    "kṣetriya": ['ap90', 'cae', 'mw'],
    "kṣetriyanāśana": ['mw'],
    "kṣetriṇī": ['mw'],
    "kṣetropekṣa": ['mw'],
    "kṣetrādhidevatā": ['mw'],
    "kṣetrādhipa": ['mw'],
    "kṣetrājīva": ['mw'],
    "kṣetrāmalakī": ['mw'],
    "kṣetrāsā": ['gra', 'mw'],
    "kṣetrāṃśa": ['mw'],
    "kṣetrī": ['mw'],
    "kṣetrīkṛ": ['ap90', 'ddsa', 'mw'],
    "kṣetrīya": ['ddsa', 'mw'],
    "kṣetrīyati": ['ap90'],
    "kṣev": ['mw'],
    "kṣeya": ['mw'],
    "kṣeḍa": ['mw'],
    "kṣeḍita": ['mw'],
    "kṣeṇa": ['mw'],
    "kṣeṣṇu": ['cae', 'mw'],
    "kṣeṭa": ['bhs'],
    "kṣi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣidra": ['mw'],
    "kṣidraḥ": ['ap90'],
    "kṣillikā": ['ddsa', 'mw'],
    "kṣip": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣipa": ['ap90', 'mw'],
    "kṣipaka": ['mw'],
    "kṣipakaḥ": ['ap90'],
    "kṣipakin": ['mw'],
    "kṣipakā": ['mw'],
    "kṣipasti": ['mw'],
    "kṣipastiḥ": ['ap90'],
    "kṣipati": ['mw'],
    "kṣipatiḥ": ['ap90'],
    "kṣipaṇa": ['mw'],
    "kṣipaṇaṃ": ['ap90'],
    "kṣipaṇi": ['cae', 'gra', 'mw'],
    "kṣipaṇiḥ": ['ap90'],
    "kṣipaṇu": ['cae', 'gra', 'mw'],
    "kṣipaṇuḥ": ['ap90'],
    "kṣipaṇyu": ['ap90', 'mw'],
    "kṣipnu": ['ap90', 'mw'],
    "kṣipra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣipradhanvan": ['gra', 'mw'],
    "kṣipragarbha": ['mw'],
    "kṣipragati": ['mw'],
    "kṣiprahasta": ['mw'],
    "kṣiprahoma": ['mw'],
    "kṣipraiṣu": ['gra'],
    "kṣiprakāma": ['mw'],
    "kṣiprakārin": ['mw'],
    "kṣiprakāritā": ['mw'],
    "kṣipram": ['mw'],
    "kṣipramūtratā": ['mw'],
    "kṣipraniścaya": ['cae', 'mw'],
    "kṣipraprasavana": ['mw'],
    "kṣiprapākin": ['mw'],
    "kṣiprasaṃdhi": ['mw'],
    "kṣipraśyena": ['mw'],
    "kṣipraṃsuvana": ['mw'],
    "kṣipre": ['mw'],
    "kṣipreṣu": ['cae', 'gra', 'mw'],
    "kṣiprā": ['mw'],
    "kṣiprārtha": ['mw'],
    "kṣiprāt": ['mw'],
    "kṣipta": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣiptabheṣaja": ['mw'],
    "kṣiptacitta": ['mw'],
    "kṣiptadeha": ['mw'],
    "kṣiptalaguḍa": ['mw'],
    "kṣiptatā": ['mw'],
    "kṣiptayoni": ['mw'],
    "kṣipti": ['mw'],
    "kṣiptikā": ['mw'],
    "kṣiptiḥ": ['ap90'],
    "kṣiptottara": ['mw'],
    "kṣiptā": ['mw'],
    "kṣipyamāṇa": ['mw'],
    "kṣipyat": ['mw'],
    "kṣipā": ['cae', 'gra', 'mw'],
    "kṣit": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣita": ['ap90', 'cae', 'mw'],
    "kṣiti": ['cae', 'ddsa', 'gra', 'mw'],
    "kṣitibadarī": ['mw'],
    "kṣitibhartṛ": ['mw'],
    "kṣitibhuj": ['cae', 'mw'],
    "kṣitibhū": ['mw'],
    "kṣitibhṛt": ['cae', 'mw'],
    "kṣitibhṛttā": ['mw'],
    "kṣiticalana": ['mw'],
    "kṣitideva": ['mw'],
    "kṣitidevatā": ['mw'],
    "kṣitidhara": ['cae', 'mw'],
    "kṣitidharaguru": ['cae'],
    "kṣitidhenu": ['mw'],
    "kṣitidhārin": ['mw'],
    "kṣitidina": ['mw'],
    "kṣitigarbha": ['bhs', 'mw'],
    "kṣitigarbhasūtra": ['bhs'],
    "kṣitija": ['mw'],
    "kṣitijantu": ['mw'],
    "kṣitijatva": ['mw'],
    "kṣitijyā": ['mw'],
    "kṣitijā": ['mw'],
    "kṣitijīvā": ['mw'],
    "kṣitikampa": ['cae', 'ddsa', 'mw'],
    "kṣitikampana": ['mw'],
    "kṣitikaṇa": ['mw'],
    "kṣitikhaṇḍa": ['mw'],
    "kṣitikā": ['mw'],
    "kṣitikṣama": ['mw'],
    "kṣitikṣamāvat": ['mw'],
    "kṣitikṣit": ['mw'],
    "kṣitikṣoda": ['mw'],
    "kṣitilavabhuj": ['mw'],
    "kṣitimaṇḍala": ['mw'],
    "kṣitinanda": ['mw'],
    "kṣitinandana": ['mw'],
    "kṣitināga": ['mw'],
    "kṣitinātha": ['mw'],
    "kṣitipa": ['cae', 'mw'],
    "kṣitipati": ['cae', 'mw'],
    "kṣitipratiṣṭha": ['mw'],
    "kṣitipuruhūta": ['mw'],
    "kṣitiputra": ['mw'],
    "kṣitipāla": ['mw'],
    "kṣitipīṭha": ['mw'],
    "kṣitirasa": ['cae', 'mw'],
    "kṣitiruh": ['mw'],
    "kṣitiruha": ['mw'],
    "kṣitirāja": ['mw'],
    "kṣitispṛś": ['mw'],
    "kṣitisura": ['mw'],
    "kṣitisuta": ['mw'],
    "kṣititala": ['cae', 'mw'],
    "kṣititalāpsaras": ['mw'],
    "kṣititanaya": ['mw'],
    "kṣititanayadina": ['mw'],
    "kṣititanayadivasavāra": ['mw'],
    "kṣititanayā": ['mw'],
    "kṣititrāṇa": ['mw'],
    "kṣitivardhana": ['mw'],
    "kṣitivyudāsa": ['mw'],
    "kṣitivṛttimat": ['mw'],
    "kṣitivṛṣan": ['mw'],
    "kṣitiśa": ['bhs'],
    "kṣitiśacīpati": ['mw'],
    "kṣitiśatakratu": ['mw'],
    "kṣitiśiñjinī": ['mw'],
    "kṣitiḥ": ['ap90'],
    "kṣitvan": ['ap90', 'mw'],
    "kṣitvarī": ['mw'],
    "kṣity": ['mw'],
    "kṣityadhipa": ['mw'],
    "kṣityaditi": ['mw'],
    "kṣityutkara": ['mw'],
    "kṣitā": ['ap90', 'mw'],
    "kṣitāyus": ['gra', 'mw'],
    "kṣitīgarbha": ['mw'],
    "kṣitīndra": ['cae', 'mw'],
    "kṣitīśa": ['cae', 'mw'],
    "kṣitīśavaṃśāvalīcarita": ['mw'],
    "kṣitīśvara": ['cae', 'mw'],
    "kṣiv": ['ap90', 'mw'],
    "kṣiyā": ['ap90', 'mw'],
    "kṣiḥ": ['ap90'],
    "kṣiṇ": ['ap90', 'mw'],
    "kṣmayā": ['mw'],
    "kṣmeśa": ['mw'],
    "kṣmā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣmābhartṛ": ['cae', 'mw'],
    "kṣmābhuj": ['cae', 'mw'],
    "kṣmābhṛt": ['cae', 'mw'],
    "kṣmācakra": ['mw'],
    "kṣmādhara": ['cae', 'ddsa', 'mw'],
    "kṣmādhṛti": ['mw'],
    "kṣmāja": ['mw'],
    "kṣmānta": ['mw'],
    "kṣmāpa": ['cae', 'mw'],
    "kṣmāpati": ['cae', 'mw'],
    "kṣmāpāla": ['mw'],
    "kṣmāruh": ['mw'],
    "kṣmātala": ['mw'],
    "kṣmāvalaya": ['mw'],
    "kṣmāvṛṣan": ['mw'],
    "kṣmāy": ['ap90', 'mw'],
    "kṣmāyita": ['mw'],
    "kṣmāyitṛ": ['mw'],
    "kṣmāśayana": ['mw'],
    "kṣmāṃśa": ['mw'],
    "kṣmīl": ['ap90', 'mw'],
    "kṣobha": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣobhaka": ['mw'],
    "kṣobhayitṛ": ['mw'],
    "kṣobhaḥ": ['ap90'],
    "kṣobhaṇa": ['cae', 'gra', 'mw'],
    "kṣobhaṇaṃ": ['ap90'],
    "kṣobhiṇī": ['mw'],
    "kṣobhya": ['mw'],
    "kṣoda": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣodakṣama": ['mw'],
    "kṣodaraja": ['mw'],
    "kṣodas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣodaḥ": ['ap90'],
    "kṣodhuka": ['mw'],
    "kṣodiman": ['ap90', 'mw'],
    "kṣodita": ['ap90', 'mw'],
    "kṣodiṣṭha": ['cae', 'ddsa', 'mw'],
    "kṣodya": ['mw'],
    "kṣodīyas": ['mw'],
    "kṣodīyaṃs": ['cae'],
    "kṣoma": ['mw'],
    "kṣomaka": ['bhs', 'mw'],
    "kṣomaḥ": ['ap90'],
    "kṣora": ['mw'],
    "kṣottavya": ['mw'],
    "kṣottṛ": ['ap90', 'mw'],
    "kṣotṛ": ['mw'],
    "kṣoḍa": ['mw'],
    "kṣoḍaka": ['bhs'],
    "kṣoḍaḥ": ['ap90'],
    "kṣoṇa": ['gra', 'mw'],
    "kṣoṇi": ['cae', 'ddsa', 'gra', 'mw'],
    "kṣoṇipati": ['cae', 'ddsa', 'mw'],
    "kṣoṇipāla": ['cae', 'mw'],
    "kṣoṇiḥ": ['ap90'],
    "kṣoṇī": ['cae', 'ddsa', 'gra', 'mw'],
    "kṣoṇīdeva": ['mw'],
    "kṣoṇīdharamiśra": ['mw'],
    "kṣoṇīmaya": ['mw'],
    "kṣoṇīmaṇḍala": ['mw'],
    "kṣoṇīndra": ['cae', 'mw'],
    "kṣoṇīpati": ['cae', 'mw'],
    "kṣoṇīramaṇa": ['mw'],
    "kṣoṇīruh": ['mw'],
    "kṣoṭ": ['mw'],
    "kṣraum": ['mw'],
    "kṣu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣubdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣubdhatā": ['mw'],
    "kṣubdhārṇava": ['mw'],
    "kṣubh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣubha": ['ap90'],
    "kṣubhita": ['ap90', 'mw'],
    "kṣubhā": ['mw'],
    "kṣud": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣuda": ['mw'],
    "kṣudaḥ": ['ap90'],
    "kṣudh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣudhi": ['mw'],
    "kṣudhita": ['ap90', 'mw'],
    "kṣudhuna": ['mw'],
    "kṣudhunaḥ": ['ap90'],
    "kṣudhā": ['cae', 'ddsa', 'mw'],
    "kṣudhābhijanana": ['mw'],
    "kṣudhādhvaṃsa": ['mw'],
    "kṣudhākara": ['mw'],
    "kṣudhākuśala": ['mw'],
    "kṣudhālu": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣudhāmāra": ['mw'],
    "kṣudhānvita": ['mw'],
    "kṣudhānāśana": ['mw'],
    "kṣudhāpīḍita": ['mw'],
    "kṣudhārdita": ['mw'],
    "kṣudhārta": ['cae', 'mw'],
    "kṣudhāru": ['mw'],
    "kṣudhāsāgara": ['mw'],
    "kṣudhāvat": ['mw'],
    "kṣudhāviṣṭa": ['mw'],
    "kṣudhāśānti": ['mw'],
    "kṣudra": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣudrabaka": ['mw'],
    "kṣudrabalā": ['mw'],
    "kṣudrabha": ['mw'],
    "kṣudrabhaṇṭākī": ['mw'],
    "kṣudrabhṛt": ['mw'],
    "kṣudrabuddhi": ['cae', 'mw'],
    "kṣudracampaka": ['mw'],
    "kṣudracandana": ['mw'],
    "kṣudracañcu": ['mw'],
    "kṣudracirbhitā": ['mw'],
    "kṣudracūḍa": ['mw'],
    "kṣudradaṃśikā": ['mw'],
    "kṣudradaṃśī": ['mw'],
    "kṣudradhānya": ['mw'],
    "kṣudradhātrī": ['mw'],
    "kṣudradurālabhā": ['mw'],
    "kṣudraduḥsparśā": ['mw'],
    "kṣudraghaṇṭikā": ['cae', 'mw'],
    "kṣudraghaṇṭī": ['mw'],
    "kṣudragholī": ['mw'],
    "kṣudragokṣuraka": ['mw'],
    "kṣudraguḍa": ['mw'],
    "kṣudrahan": ['mw'],
    "kṣudrahiṅgulikā": ['mw'],
    "kṣudrahiṅgulī": ['mw'],
    "kṣudrailā": ['mw'],
    "kṣudrajantu": ['cae', 'ddsa', 'mw'],
    "kṣudrajātīphala": ['mw'],
    "kṣudrajīra": ['mw'],
    "kṣudrajīvā": ['mw'],
    "kṣudraka": ['mw'],
    "kṣudrakalpa": ['mw'],
    "kṣudrakambu": ['mw'],
    "kṣudrakamānasa": ['mw'],
    "kṣudrakarman": ['mw'],
    "kṣudrakaṇṭakārī": ['mw'],
    "kṣudrakaṇṭakī": ['mw'],
    "kṣudrakaṇṭikā": ['mw'],
    "kṣudrakaṇṭārikā": ['mw'],
    "kṣudrakuliśa": ['mw'],
    "kṣudrakuṣṭha": ['mw'],
    "kṣudrakānukṣudraka": ['bhs'],
    "kṣudrakāralikā": ['mw'],
    "kṣudrakāravellī": ['mw'],
    "kṣudrakḷpti": ['mw'],
    "kṣudrakṣura": ['mw'],
    "kṣudrala": ['ap90', 'mw'],
    "kṣudramahā": ['mw'],
    "kṣudramiśra": ['mw'],
    "kṣudramustā": ['mw'],
    "kṣudramīna": ['mw'],
    "kṣudranadī": ['mw'],
    "kṣudranāsika": ['mw'],
    "kṣudrapada": ['mw'],
    "kṣudrapakṣika": ['mw'],
    "kṣudrapanasa": ['mw'],
    "kṣudraparṇa": ['mw'],
    "kṣudrapattrā": ['mw'],
    "kṣudrapattrī": ['mw'],
    "kṣudrapaśu": ['mw'],
    "kṣudrapaśumat": ['mw'],
    "kṣudraphalaka": ['mw'],
    "kṣudraphalā": ['mw'],
    "kṣudrapippalī": ['mw'],
    "kṣudrapotikā": ['mw'],
    "kṣudraputrā": ['bhs'],
    "kṣudrapāka": ['bhs'],
    "kṣudrapāṣāṇabhedaka": ['mw'],
    "kṣudrapāṣāṇabhedā": ['mw'],
    "kṣudrapāṣāṇabhedī": ['mw'],
    "kṣudrapṛṣatī": ['mw'],
    "kṣudrarasa": ['mw'],
    "kṣudrarasā": ['mw'],
    "kṣudraroga": ['mw'],
    "kṣudrarogika": ['mw'],
    "kṣudraruhā": ['mw'],
    "kṣudrasahā": ['mw'],
    "kṣudrasamācāra": ['mw'],
    "kṣudrasphoṭa": ['mw'],
    "kṣudrasuvarṇa": ['mw'],
    "kṣudrasvarṇa": ['mw'],
    "kṣudrasūkta": ['mw'],
    "kṣudrasūtra": ['mw'],
    "kṣudrataṇḍula": ['mw'],
    "kṣudratulasī": ['mw'],
    "kṣudratva": ['mw'],
    "kṣudratā": ['ap90', 'mw'],
    "kṣudratāta": ['mw'],
    "kṣudravaidehī": ['mw'],
    "kṣudravajra": ['mw'],
    "kṣudravallī": ['mw'],
    "kṣudravarvaṇā": ['mw'],
    "kṣudravaṃśā": ['mw'],
    "kṣudravārtākinī": ['mw'],
    "kṣudravārtākī": ['mw'],
    "kṣudravāstukī": ['mw'],
    "kṣudraśarkarikā": ['mw'],
    "kṣudraśarkarā": ['mw'],
    "kṣudraśatru": ['cae'],
    "kṣudraśaṅkha": ['mw'],
    "kṣudraśaṇapuṣpikā": ['mw'],
    "kṣudraśleṣmāntaka": ['mw'],
    "kṣudraśukti": ['mw'],
    "kṣudraśuktikā": ['mw'],
    "kṣudraśvetā": ['mw'],
    "kṣudraśvāsa": ['mw'],
    "kṣudraśyāmā": ['mw'],
    "kṣudraśārdūla": ['mw'],
    "kṣudraśīla": ['mw'],
    "kṣudraśīrṣa": ['mw'],
    "kṣudraṃcara": ['mw'],
    "kṣudrekṣa": ['mw'],
    "kṣudrervāru": ['mw'],
    "kṣudreṅgudī": ['mw'],
    "kṣudri": ['mw'],
    "kṣudrikā": ['ap90', 'bhs', 'mw'],
    "kṣudrodumbarikā": ['mw'],
    "kṣudroga": ['mw'],
    "kṣudrolūka": ['mw'],
    "kṣudropodakanāmnī": ['mw'],
    "kṣudropodakī": ['mw'],
    "kṣudropāya": ['mw'],
    "kṣudrā": ['mw'],
    "kṣudrācarita": ['mw'],
    "kṣudrāgnimantha": ['mw'],
    "kṣudrākṣa": ['ddsa', 'mw'],
    "kṣudrāmalaka": ['mw'],
    "kṣudrāmalakasaṃjña": ['mw'],
    "kṣudrāmbupanasa": ['mw'],
    "kṣudrāmlapanasa": ['mw'],
    "kṣudrāmlikā": ['mw'],
    "kṣudrāmlā": ['mw'],
    "kṣudrāmra": ['mw'],
    "kṣudrāntra": ['mw'],
    "kṣudrānukṣudra": ['bhs', 'mw'],
    "kṣudrāpāmārga": ['mw'],
    "kṣudrāpāmārgaka": ['mw'],
    "kṣudrātman": ['mw'],
    "kṣudrāñjana": ['mw'],
    "kṣudrāṇḍa": ['mw'],
    "kṣudrāṇḍamatsyasaṃghāta": ['mw'],
    "kṣudrīya": ['mw'],
    "kṣudvat": ['mw'],
    "kṣudvibodhana": ['mw'],
    "kṣujjanikā": ['mw'],
    "kṣulika": ['mw'],
    "kṣulla": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣullaka": ['ap90', 'cae', 'mw'],
    "kṣullakakāleya": ['mw'],
    "kṣullakatāpaścitta": ['mw'],
    "kṣullakavaiśvadeva": ['mw'],
    "kṣullakavaiṣṭambha": ['mw'],
    "kṣullakavātsapra": ['mw'],
    "kṣullatāta": ['mw'],
    "kṣullatātaka": ['mw'],
    "kṣumant": ['cae'],
    "kṣumat": ['ddsa', 'gra', 'mw'],
    "kṣump": ['mw'],
    "kṣumpa": ['cae', 'gra', 'mw'],
    "kṣumā": ['ap90', 'mw'],
    "kṣun": ['mw'],
    "kṣunmant": ['cae'],
    "kṣunmat": ['mw'],
    "kṣunnirodha": ['ddsa'],
    "kṣunnivṛtti": ['mw'],
    "kṣunto": ['bhs'],
    "kṣup": ['mw'],
    "kṣupa": ['cae', 'ddsa', 'mw'],
    "kṣupaka": ['mw'],
    "kṣupaḍoḍamuṣṭi": ['mw'],
    "kṣupaḥ": ['ap90'],
    "kṣupā": ['mw'],
    "kṣupālu": ['mw'],
    "kṣur": ['ap90', 'mw'],
    "kṣura": ['cae', 'ddsa', 'gra', 'mw'],
    "kṣurabhaṭṭa": ['mw'],
    "kṣurabhāṇḍa": ['mw'],
    "kṣurabhṛṣṭi": ['mw'],
    "kṣuracatuṣṭaya": ['mw'],
    "kṣuradhāna": ['cae', 'mw'],
    "kṣuradhāra": ['mw'],
    "kṣuradhārā": ['mw'],
    "kṣuraka": ['bhs', 'cae', 'mw'],
    "kṣurakarman": ['cae', 'mw'],
    "kṣurakarṇī": ['mw'],
    "kṣurakriyā": ['mw'],
    "kṣurakḷpta": ['mw'],
    "kṣurakṛtya": ['cae', 'mw'],
    "kṣuramardin": ['mw'],
    "kṣuranakṣatra": ['mw'],
    "kṣurapattra": ['mw'],
    "kṣurapattrikā": ['mw'],
    "kṣurapavi": ['mw'],
    "kṣurapra": ['mw'],
    "kṣurapraga": ['mw'],
    "kṣurapravārin": ['bhs'],
    "kṣuraḥ": ['ap90'],
    "kṣurikopaniṣad": ['mw'],
    "kṣurikā": ['ap90', 'ddsa', 'mw'],
    "kṣurikāpattra": ['mw'],
    "kṣurikāphala": ['mw'],
    "kṣurin": ['ap90', 'mw'],
    "kṣuriṇī": ['ap90', 'mw'],
    "kṣurābhraka": ['mw'],
    "kṣurārpaṇa": ['mw'],
    "kṣurāṅga": ['mw'],
    "kṣurāṅgaka": ['mw'],
    "kṣurī": ['mw'],
    "kṣut": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣuta": ['cae', 'mw'],
    "kṣutaka": ['mw'],
    "kṣutavat": ['mw'],
    "kṣuti": ['mw'],
    "kṣutkarī": ['mw'],
    "kṣutkṣāma": ['ddsa', 'mw'],
    "kṣutkṣāmakaṇṭha": ['mw'],
    "kṣutpara": ['mw'],
    "kṣutparīta": ['mw'],
    "kṣutpipāsita": ['mw'],
    "kṣutpipāsāpariśrānta": ['mw'],
    "kṣutpipāsāparītāṅga": ['mw'],
    "kṣutpipāsārta": ['mw'],
    "kṣutpratīkāra": ['mw'],
    "kṣutsambādha": ['mw'],
    "kṣuttaṃ": ['bhs'],
    "kṣuttṛḍudbhava": ['mw'],
    "kṣuttṛṣānvita": ['mw'],
    "kṣuttṛṣṇopapīḍita": ['mw'],
    "kṣuttṛṭparīta": ['mw'],
    "kṣutābhijanana": ['mw'],
    "kṣuvat": ['mw'],
    "kṣuḍḍīka": ['bhs'],
    "kṣuḥ": ['ap90'],
    "kṣuṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "kṣuṇaka": ['bhs'],
    "kṣuṇṇa": ['ap90', 'bhs', 'mw'],
    "kṣuṇṇaka": ['mw'],
    "kṣuṇṇakaḥ": ['ap90'],
    "kṣuṇṇamanas": ['mw'],
    "kṣvel": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣvela": ['mw'],
    "kṣvelana": ['cae', 'ddsa', 'mw'],
    "kṣveli": ['mw'],
    "kṣvelikā": ['mw'],
    "kṣvelita": ['cae', 'mw'],
    "kṣvelā": ['ap90'],
    "kṣveḍa": ['ap90', 'mw'],
    "kṣveḍana": ['ddsa', 'mw'],
    "kṣveḍanaṃ": ['ap90'],
    "kṣveḍikā": ['mw'],
    "kṣveḍin": ['mw'],
    "kṣveḍita": ['mw'],
    "kṣveḍitaḥ": ['ap90'],
    "kṣveḍā": ['mw'],
    "kṣvid": ['cae', 'ddsa', 'mw'],
    "kṣviḍ": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣviṅkā": ['cae', 'gra', 'mw'],
    "kṣviṇṇa": ['ap90', 'mw'],
    "kṣā": ['cae', 'ddsa', 'gra', 'mw'],
    "kṣāla": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣālana": ['cae', 'mw'],
    "kṣālanaṃ": ['ap90'],
    "kṣālanīya": ['mw'],
    "kṣālita": ['ap90', 'mw'],
    "kṣālitavya": ['mw'],
    "kṣāma": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣāmakarṣamiśra": ['mw'],
    "kṣāmakukṣitā": ['mw'],
    "kṣāmakṣāma": ['cae', 'mw'],
    "kṣāman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣāmatva": ['mw'],
    "kṣāmatā": ['mw'],
    "kṣāmavat": ['ap90', 'mw'],
    "kṣāmavatī": ['mw'],
    "kṣāmi": ['mw'],
    "kṣāmimat": ['mw'],
    "kṣāmin": ['mw'],
    "kṣāmodara": ['bhs'],
    "kṣāmya": ['ap90', 'mw'],
    "kṣāmāprastha": ['mw'],
    "kṣāmāsya": ['mw'],
    "kṣāmāṅga": ['cae', 'mw'],
    "kṣāmīkṛ": ['cae', 'ddsa', 'mw'],
    "kṣānta": ['cae', 'ddsa', 'mw'],
    "kṣānti": ['bhs', 'cae', 'ddsa', 'mw'],
    "kṣāntika": ['bhs'],
    "kṣāntimat": ['mw'],
    "kṣāntimaṇḍalapradīpa": ['bhs'],
    "kṣāntipradīpaśri": ['bhs'],
    "kṣāntipriyā": ['bhs', 'mw'],
    "kṣāntipāla": ['mw'],
    "kṣāntipāramitā": ['mw'],
    "kṣāntivarṇavādin": ['mw'],
    "kṣāntivādin": ['bhs', 'mw'],
    "kṣāntiśīla": ['cae', 'mw'],
    "kṣāntu": ['mw'],
    "kṣāntā": ['mw'],
    "kṣāntāyana": ['mw'],
    "kṣāntāyanti": ['mw'],
    "kṣāntāyantu": ['mw'],
    "kṣāntāyantīya": ['mw'],
    "kṣāntīya": ['mw'],
    "kṣāpavitra": ['mw'],
    "kṣāpaya": ['mw'],
    "kṣāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣārabhūmi": ['mw'],
    "kṣāradalā": ['mw'],
    "kṣāradru": ['mw'],
    "kṣāradvaya": ['mw'],
    "kṣāraka": ['bhs', 'mw'],
    "kṣārakajāta": ['mw'],
    "kṣārakardama": ['mw'],
    "kṣārakarman": ['mw'],
    "kṣārakaḥ": ['ap90'],
    "kṣārakīṭa": ['mw'],
    "kṣārakṛtya": ['mw'],
    "kṣārakṣata": ['mw'],
    "kṣārakṣīṇa": ['mw'],
    "kṣāralavaṇa": ['cae', 'mw'],
    "kṣāralavaṇavarjana": ['mw'],
    "kṣāralavaṇāvarānnasaṃsṛṣṭa": ['mw'],
    "kṣāramadhya": ['mw'],
    "kṣārameha": ['mw'],
    "kṣāramehin": ['mw'],
    "kṣāramelaka": ['mw'],
    "kṣāramṛttikā": ['mw'],
    "kṣāranadī": ['mw'],
    "kṣārapattra": ['mw'],
    "kṣārapattraka": ['mw'],
    "kṣārapattrikā": ['mw'],
    "kṣārapayas": ['mw'],
    "kṣārapayobhū": ['mw'],
    "kṣārapāla": ['mw'],
    "kṣārapāta": ['mw'],
    "kṣārapāṇi": ['mw'],
    "kṣārapūrvadaśaka": ['mw'],
    "kṣārarasa": ['mw'],
    "kṣārasamudra": ['mw'],
    "kṣārasindhu": ['mw'],
    "kṣārasūtra": ['mw'],
    "kṣārataila": ['mw'],
    "kṣāratantra": ['mw'],
    "kṣāratraya": ['mw'],
    "kṣāratritaya": ['mw'],
    "kṣāravṛkṣa": ['mw'],
    "kṣārayati": ['ap90'],
    "kṣārayitṛ": ['ddsa'],
    "kṣāraśreṣṭha": ['mw'],
    "kṣāraḥ": ['ap90'],
    "kṣāraṇa": ['mw'],
    "kṣāraṇaṃ": ['ap90'],
    "kṣāraṇā": ['mw'],
    "kṣāraṣaṭka": ['mw'],
    "kṣārikā": ['ap90', 'mw'],
    "kṣārita": ['ap90', 'mw'],
    "kṣāroda": ['mw'],
    "kṣārodadhi": ['mw'],
    "kṣārodaka": ['mw'],
    "kṣārāccha": ['mw'],
    "kṣārāgada": ['mw'],
    "kṣārākṣa": ['mw'],
    "kṣārāmbu": ['mw'],
    "kṣārāmbudhi": ['mw'],
    "kṣārāñjana": ['mw'],
    "kṣārīya": ['mw'],
    "kṣās": ['mw'],
    "kṣāti": ['cae', 'gra', 'mw'],
    "kṣātra": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣātravidya": ['mw'],
    "kṣātri": ['mw'],
    "kṣātriḥ": ['ap90'],
    "kṣātrāṇa": ['mw'],
    "kṣāttra": ['mw'],
    "kṣāttrasaṃgrahītṛ": ['mw'],
    "kṣāyika": ['mw'],
    "kṣāṃta": ['ap90'],
    "kṣāṃtiḥ": ['ap90'],
    "kṣāṃtu": ['ap90'],
    "kṣī": ['ap90', 'mw'],
    "kṣīb": ['ap90', 'mw'],
    "kṣība": ['cae', 'mw'],
    "kṣīban": ['mw'],
    "kṣībatva": ['mw'],
    "kṣībatā": ['mw'],
    "kṣībika": ['mw'],
    "kṣībm, kṣīva": ['ddsa'],
    "kṣīj": ['ap90', 'mw'],
    "kṣījana": ['mw'],
    "kṣījanaṃ": ['ap90'],
    "kṣīra": ['cae', 'ddsa', 'gra', 'mw'],
    "kṣīrabhaṭṭa": ['mw'],
    "kṣīrabhṛta": ['cae', 'mw'],
    "kṣīracchada": ['mw'],
    "kṣīrada": ['mw'],
    "kṣīradala": ['mw'],
    "kṣīradhara": ['mw'],
    "kṣīradhenu": ['mw'],
    "kṣīradhi": ['cae', 'mw'],
    "kṣīradhātrī": ['bhs', 'mw'],
    "kṣīradruma": ['mw'],
    "kṣīradāru": ['mw'],
    "kṣīradātrī": ['mw'],
    "kṣīragarbha": ['mw'],
    "kṣīraghṛta": ['mw'],
    "kṣīragucchaphala": ['mw'],
    "kṣīrahomin": ['mw'],
    "kṣīrahotṛ": ['mw'],
    "kṣīrahrada": ['mw'],
    "kṣīraja": ['mw'],
    "kṣīrajāla": ['mw'],
    "kṣīraka": ['bhs', 'mw'],
    "kṣīrakalambha": ['mw'],
    "kṣīrakanda": ['mw'],
    "kṣīrakandā": ['mw'],
    "kṣīrakañcukin": ['mw'],
    "kṣīrakaṇṭha": ['mw'],
    "kṣīrakaṇṭhaka": ['mw'],
    "kṣīrakharjūra": ['mw'],
    "kṣīrakuṇḍa": ['ddsa', 'mw'],
    "kṣīrakākolikā": ['mw'],
    "kṣīrakākolī": ['mw'],
    "kṣīrakāṇḍaka": ['mw'],
    "kṣīrakāṣṭhā": ['mw'],
    "kṣīrakīṭa": ['mw'],
    "kṣīrakṣava": ['mw'],
    "kṣīrakṣaya": ['cae', 'mw'],
    "kṣīralatā": ['mw'],
    "kṣīraleham": ['mw'],
    "kṣīramadhurā": ['mw'],
    "kṣīramahārṇava": ['mw'],
    "kṣīramaya": ['mw'],
    "kṣīramocaka": ['mw'],
    "kṣīramoraṭa": ['mw'],
    "kṣīramṛtsna": ['mw'],
    "kṣīranadī": ['mw'],
    "kṣīranidhi": ['cae', 'mw'],
    "kṣīranāśa": ['mw'],
    "kṣīranīra": ['cae', 'mw'],
    "kṣīranīranidhi": ['mw'],
    "kṣīrapa": ['cae', 'mw'],
    "kṣīrapaka": ['bhs'],
    "kṣīrapalāṇḍu": ['mw'],
    "kṣīraparṇin": ['mw'],
    "kṣīraphala": ['mw'],
    "kṣīrapuṣpikā": ['mw'],
    "kṣīrapuṣpī": ['mw'],
    "kṣīrapāka": ['gra', 'mw'],
    "kṣīrapākavidhi": ['mw'],
    "kṣīrapāna": ['mw'],
    "kṣīrapāyin": ['mw'],
    "kṣīrapāṇa": ['mw'],
    "kṣīrapāṇi": ['mw'],
    "kṣīrapūrṇāmbha": ['bhs'],
    "kṣīrasa": ['mw'],
    "kṣīrasambhava": ['mw'],
    "kṣīrasamudra": ['cae', 'mw'],
    "kṣīrasarpis": ['mw'],
    "kṣīrasaṃtānikā": ['mw'],
    "kṣīrasindhu": ['mw'],
    "kṣīrasnigdha": ['cae'],
    "kṣīrasphaṭika": ['mw'],
    "kṣīrasrāva": ['mw'],
    "kṣīrasvāmin": ['cae', 'mw'],
    "kṣīrasya": ['mw'],
    "kṣīrasāgara": ['cae', 'mw'],
    "kṣīrasāgarasutā": ['mw'],
    "kṣīrasāra": ['mw'],
    "kṣīrataila": ['mw'],
    "kṣīrataraṃgiṇī": ['mw'],
    "kṣīrataru": ['mw'],
    "kṣīratoyadhi": ['mw'],
    "kṣīratumbī": ['mw'],
    "kṣīraudana": ['mw'],
    "kṣīravaha": ['mw'],
    "kṣīravallikā": ['mw'],
    "kṣīravallī": ['mw'],
    "kṣīravanaspati": ['mw'],
    "kṣīravant": ['cae'],
    "kṣīravat": ['mw'],
    "kṣīravatī": ['mw'],
    "kṣīravidārikā": ['mw'],
    "kṣīravidārī": ['mw'],
    "kṣīravikṛti": ['mw'],
    "kṣīraviṣāṇikā": ['mw'],
    "kṣīravrata": ['mw'],
    "kṣīravāri": ['mw'],
    "kṣīravāridhi": ['mw'],
    "kṣīravṛkṣa": ['cae', 'mw'],
    "kṣīrayati": ['ap90'],
    "kṣīrayava": ['mw'],
    "kṣīrayaṣṭika": ['mw'],
    "kṣīrayājin": ['mw'],
    "kṣīraśara": ['mw'],
    "kṣīraśarā": ['mw'],
    "kṣīraśrī": ['mw'],
    "kṣīraśukla": ['mw'],
    "kṣīraśuklā": ['mw'],
    "kṣīraśāka": ['mw'],
    "kṣīraśīrṣa": ['mw'],
    "kṣīraśīrṣaka": ['mw'],
    "kṣīraśṛṅgī": ['mw'],
    "kṣīraḥ": ['ap90'],
    "kṣīraṣāṣṭika": ['mw'],
    "kṣīreyī": ['ap90', 'mw'],
    "kṣīrika": ['mw'],
    "kṣīrikā": ['ap90', 'bhs', 'mw'],
    "kṣīrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣīriṇī": ['mw'],
    "kṣīroda": ['bhs', 'cae', 'ddsa', 'mw'],
    "kṣīrodadhi": ['mw'],
    "kṣīrodajā": ['mw'],
    "kṣīrodaka": ['mw'],
    "kṣīrodamathana": ['mw'],
    "kṣīrodanandana": ['mw'],
    "kṣīrodanvat": ['mw'],
    "kṣīrodatanayā": ['mw'],
    "kṣīrodhi": ['cae'],
    "kṣīrodārṇava": ['mw'],
    "kṣīrodīya": ['mw'],
    "kṣīropasecana": ['mw'],
    "kṣīrormi": ['mw'],
    "kṣīrottarā": ['mw'],
    "kṣīrottha": ['mw'],
    "kṣīrā": ['mw'],
    "kṣīrābdhi": ['cae', 'mw'],
    "kṣīrābdhija": ['mw'],
    "kṣīrābdhijā": ['mw'],
    "kṣīrābdhimandira": ['mw'],
    "kṣīrābdhimānuṣī": ['mw'],
    "kṣīrābdhiputrī": ['mw'],
    "kṣīrābdhitanayā": ['mw'],
    "kṣīrāda": ['mw'],
    "kṣīrāhva": ['mw'],
    "kṣīrāhvaya": ['mw'],
    "kṣīrāmbudhi": ['cae', 'mw'],
    "kṣīrānna": ['cae', 'ddsa', 'mw'],
    "kṣīrānnāda": ['mw'],
    "kṣīrārṇava": ['cae', 'mw'],
    "kṣīrāvikā": ['mw'],
    "kṣīrāvī": ['mw'],
    "kṣīrāya": ['ddsa', 'mw'],
    "kṣīrī": ['mw'],
    "kṣīrībhū": ['mw'],
    "kṣīrīya": ['mw'],
    "kṣīrīśa": ['mw'],
    "kṣīv": ['ap90', 'mw'],
    "kṣīva": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣīvan": ['mw'],
    "kṣīvika": ['mw'],
    "kṣīyamāṇa": ['mw'],
    "kṣīyati": ['bhs'],
    "kṣīṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "kṣīṇadhana": ['mw'],
    "kṣīṇagati": ['mw'],
    "kṣīṇajīvita": ['mw'],
    "kṣīṇakalmaṣa": ['cae', 'mw'],
    "kṣīṇakarman": ['mw'],
    "kṣīṇakośa": ['mw'],
    "kṣīṇamadhya": ['mw'],
    "kṣīṇamohaka": ['mw'],
    "kṣīṇapuṇya": ['mw'],
    "kṣīṇapāpa": ['mw'],
    "kṣīṇasukṛta": ['mw'],
    "kṣīṇasāra": ['mw'],
    "kṣīṇatamas": ['mw'],
    "kṣīṇatva": ['mw'],
    "kṣīṇatā": ['mw'],
    "kṣīṇavat": ['mw'],
    "kṣīṇavikrānta": ['mw'],
    "kṣīṇavāsin": ['mw'],
    "kṣīṇavṛtti": ['cae', 'mw'],
    "kṣīṇaśakti": ['mw'],
    "kṣīṇaśarīra": ['mw'],
    "kṣīṇopāya": ['mw'],
    "kṣīṇādhi": ['mw'],
    "kṣīṇājyakarman": ['mw'],
    "kṣīṇārtha": ['mw'],
    "kṣīṇāsrava": ['mw'],
    "kṣīṇāyus": ['cae', 'mw'],
    "kṣīṇāśrava": ['mw'],
    "kṣīṇāṅga": ['mw'],
    "kṣīṇāṣṭakarman": ['mw'],
    "kṣūṇa": ['bhs', 'mw'],
    "kṣṇotra": ['cae', 'gra', 'mw'],
    "kṣṇotraṃ": ['ap90'],
    "kṣṇu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "kṣṇut": ['mw'],
    "kṣṇuta": ['ap90', 'mw'],
    "kṣṇū": ['mw'],
    "la": ['cae', 'ddsa', 'mw'],
    "laba": ['cae', 'ddsa', 'mw'],
    "labasūkta": ['mw'],
    "labaḥ": ['ap90'],
    "labbhamāna": ['cped'],
    "labbhati": ['cped'],
    "labbhā": ['cped'],
    "labdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "labdhacetas": ['mw'],
    "labdhadatta": ['mw'],
    "labdhadhana": ['mw'],
    "labdhajanman": ['mw'],
    "labdhaka": ['bhs', 'mw'],
    "labdhakāma": ['mw'],
    "labdhakīrti": ['mw'],
    "labdhalakṣa": ['cae', 'mw'],
    "labdhalakṣaṇa": ['mw'],
    "labdhalakṣya": ['mw'],
    "labdhalābha": ['mw'],
    "labdhanidrāsukha": ['mw'],
    "labdhanāman": ['cae', 'mw'],
    "labdhanāśa": ['mw'],
    "labdhaparabhāga": ['mw'],
    "labdhaprasara": ['cae', 'mw'],
    "labdhapratiṣṭha": ['mw'],
    "labdhapratyaya": ['cae', 'mw'],
    "labdhapratyayatā": ['mw'],
    "labdhapraśamana": ['mw'],
    "labdhapraśamanasvastha": ['mw'],
    "labdhapraṇāśa": ['mw'],
    "labdhapūrvāpara": ['bhs'],
    "labdhasambhāra": ['mw'],
    "labdhasaṃhāra": ['mw'],
    "labdhasaṃjña": ['mw'],
    "labdhasiddhi": ['mw'],
    "labdhatīrtha": ['mw'],
    "labdhavara": ['mw'],
    "labdhavarṇa": ['cae', 'mw'],
    "labdhavarṇabhāj": ['mw'],
    "labdhavat": ['mw'],
    "labdhavidya": ['mw'],
    "labdhavya": ['cae', 'ddsa', 'mw'],
    "labdhaśabda": ['ddsa', 'mw'],
    "labdhi": ['cae', 'ddsa', 'mw'],
    "labdhiḥ": ['ap90'],
    "labdhodaya": ['ddsa', 'mw'],
    "labdhrima": ['ap90'],
    "labdhā": ['mw'],
    "labdhāmitābhagarbhatantra": ['bhs'],
    "labdhāntara": ['cae', 'mw'],
    "labdhāntaratva": ['mw'],
    "labdhānujña": ['mw'],
    "labdhāspada": ['cae', 'mw'],
    "labdhātiśaya": ['mw'],
    "labdhāvakāśa": ['cae', 'mw'],
    "labdhāvasara": ['cae', 'mw'],
    "labdhṛ": ['cae', 'mw'],
    "labh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "labha": ['cae', 'ddsa', 'mw'],
    "labhana": ['cae', 'mw'],
    "labhanaṃ": ['ap90'],
    "labhanta": ['cped'],
    "labhasa": ['mw'],
    "labhasaḥ": ['ap90'],
    "labhati": ['cped'],
    "labhi": ['cped'],
    "labhissati": ['cped'],
    "labhituṁ": ['cped'],
    "labhitvā": ['cped'],
    "labhya": ['ap90', 'cae', 'mw'],
    "labhā": ['bhs'],
    "labuja": ['cped'],
    "lacchati": ['cped'],
    "lach": ['ap90', 'mw'],
    "lachimā": ['mw'],
    "ladanī": ['mw'],
    "laddha": ['cped'],
    "laddhabba": ['cped'],
    "laddhabhāva": ['cped'],
    "laddhaguṇa": ['cped'],
    "laddhaka": ['cped'],
    "laddhanadeva": ['mw'],
    "laddhi": ['cped'],
    "laddhika": ['cped'],
    "laddhuṁ": ['cped'],
    "laddhā": ['cped', 'mw'],
    "laddhāna": ['cped'],
    "laddhāssāda": ['cped'],
    "laddī": ['bhs', 'mw'],
    "ladūṣaka": ['mw'],
    "lag": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "laga": ['mw'],
    "lagadha": ['mw'],
    "laganīya": ['cae', 'mw'],
    "lagata": ['mw'],
    "lagaḍa": ['ap90', 'mw'],
    "lagaḍācārya": ['mw'],
    "lagaṇa": ['mw'],
    "lagaṇā": ['mw'],
    "lagga": ['cped'],
    "laggana": ['cped'],
    "laggati": ['bhs', 'cped'],
    "laggesi": ['cped'],
    "laggeti": ['cped'],
    "laggetvā": ['cped'],
    "laggi": ['cped'],
    "laggita": ['cped'],
    "laghantī": ['mw'],
    "laghaya": ['cae', 'ddsa', 'mw'],
    "laghayati": ['ap90'],
    "laghaṭ": ['ap90', 'mw'],
    "laghaṭi": ['mw'],
    "laghiman": ['ap90', 'cae', 'ddsa', 'mw'],
    "laghiṣṭha": ['ap90', 'cae', 'mw'],
    "laghu": ['ap90', 'cae', 'ddsa', 'mw'],
    "laghubadara": ['mw'],
    "laghubhava": ['mw'],
    "laghubhojana": ['mw'],
    "laghubhrātṛ": ['cae', 'mw'],
    "laghubhuj": ['mw'],
    "laghubhāgavata": ['mw'],
    "laghubhāskarīya": ['mw'],
    "laghubhāva": ['cae', 'mw'],
    "laghubhāvaprakāśikā": ['mw'],
    "laghubhūtadruma": ['mw'],
    "laghubhūṣaṇakānti": ['mw'],
    "laghubinduśekhara": ['mw'],
    "laghubodha": ['mw'],
    "laghubodhinī": ['mw'],
    "laghubrahmavaivarta": ['mw'],
    "laghubrāhmī": ['mw'],
    "laghubuddhapurāṇa": ['mw'],
    "laghucaccarī": ['mw'],
    "laghucandrikā": ['mw'],
    "laghucandrikāpaddhati": ['mw'],
    "laghucchadā": ['mw'],
    "laghucchedya": ['cae', 'mw'],
    "laghucetas": ['cae', 'mw'],
    "laghucintana": ['mw'],
    "laghucintāmaṇi": ['mw'],
    "laghucintāmaṇirasa": ['mw'],
    "laghucirbhiṭā": ['mw'],
    "laghucitrahasta": ['mw'],
    "laghucitrālaṃkāra": ['mw'],
    "laghucitta": ['cae', 'mw'],
    "laghucittatā": ['mw'],
    "laghucāṇakyarājanīti": ['mw'],
    "laghudantī": ['mw'],
    "laghudrākṣā": ['mw'],
    "laghudrāvin": ['mw'],
    "laghudundubhi": ['mw'],
    "laghudvāravatī": ['mw'],
    "laghudīpikā": ['mw'],
    "laghuga": ['mw'],
    "laghugarga": ['mw'],
    "laghugati": ['cae', 'mw'],
    "laghugaṅgādhara": ['mw'],
    "laghugodhūma": ['mw'],
    "laghugrahamañjari": ['mw'],
    "laghugītā": ['mw'],
    "laghuhasta": ['cae', 'mw'],
    "laghuhastatva": ['mw'],
    "laghuhastatā": ['cae', 'mw'],
    "laghuhastavat": ['mw'],
    "laghuhemadugdhā": ['mw'],
    "laghuhomapaddhati": ['mw'],
    "laghuhorā": ['mw'],
    "laghuhārīta": ['mw'],
    "laghuhārītasmṛti": ['mw'],
    "laghuhṛdaya": ['cae', 'mw'],
    "laghujaṅgala": ['mw'],
    "laghujñānavāsiṣṭha": ['mw'],
    "laghujānakīya": ['mw'],
    "laghujātaka": ['mw'],
    "laghujātiviveka": ['mw'],
    "laghuka": ['mw'],
    "laghukarkandhu": ['mw'],
    "laghukarṇikā": ['mw'],
    "laghukarṇī": ['mw'],
    "laghukaumudī": ['cae', 'mw'],
    "laghukaṅkola": ['mw'],
    "laghukaṇṭakā": ['mw'],
    "laghukhartara": ['mw'],
    "laghukhaṭvikā": ['mw'],
    "laghukoṣṭha": ['ddsa', 'mw'],
    "laghukrama": ['cae', 'mw'],
    "laghukramam": ['mw'],
    "laghukriyā": ['mw'],
    "laghukālanirṇaya": ['mw'],
    "laghukārikā": ['mw'],
    "laghukāya": ['mw'],
    "laghukāśmarya": ['mw'],
    "laghukāṣṭha": ['mw'],
    "laghulakṣahoma": ['mw'],
    "laghulalitavistara": ['mw'],
    "laghulaya": ['mw'],
    "laghumanas": ['mw'],
    "laghumantha": ['mw'],
    "laghumañjūṣā": ['mw'],
    "laghumeru": ['mw'],
    "laghumitra": ['mw'],
    "laghumānasa": ['mw'],
    "laghumātra": ['mw'],
    "laghumāṃsa": ['mw'],
    "laghumāṃsī": ['mw'],
    "laghumīmāṃsāvārttikaṭīkā": ['mw'],
    "laghumūla": ['mw'],
    "laghumūlaka": ['mw'],
    "laghunidāna": ['mw'],
    "laghunyāsa": ['mw'],
    "laghunyāyasudhā": ['mw'],
    "laghunābhamaṇḍala": ['mw'],
    "laghunālika": ['mw'],
    "laghunāman": ['mw'],
    "laghunāradīya": ['mw'],
    "laghunārāyaṇopaniṣad": ['mw'],
    "laghupaddhati": ['mw'],
    "laghuparibhāṣāvṛtti": ['mw'],
    "laghuparikrama": ['mw'],
    "laghuparākrama": ['mw'],
    "laghuparāmarśa": ['mw'],
    "laghuparāśara": ['mw'],
    "laghuparṇikā": ['mw'],
    "laghuparṇī": ['mw'],
    "laghupatanaka": ['cae', 'mw'],
    "laghupattraka": ['mw'],
    "laghupattraphalā": ['mw'],
    "laghupattrī": ['mw'],
    "laghupañcamūla": ['mw'],
    "laghupaṇḍita": ['mw'],
    "laghupaṇḍitīya": ['mw'],
    "laghupicchila": ['mw'],
    "laghupramāṇa": ['mw'],
    "laghuprayatna": ['mw'],
    "laghuprayatnatara": ['mw'],
    "laghuprāyaścitta": ['mw'],
    "laghupulastya": ['mw'],
    "laghupuṣpa": ['mw'],
    "laghupāka": ['mw'],
    "laghupākin": ['mw'],
    "laghupārāśarya": ['mw'],
    "laghupātin": ['cae', 'mw'],
    "laghupūjāprakāra": ['mw'],
    "laghuratnākara": ['mw'],
    "laghurāśi": ['mw'],
    "laghusadāphalā": ['mw'],
    "laghusahasranāmastotra": ['mw'],
    "laghusamudīraṇa": ['mw'],
    "laghusamudīraṇatva": ['mw'],
    "laghusamutthāna": ['mw'],
    "laghusaptaśatikāstava": ['mw'],
    "laghusaptaśatikāstotra": ['mw'],
    "laghusaptaśatī": ['mw'],
    "laghusaptaśatīstotra": ['mw'],
    "laghusaralā": ['mw'],
    "laghusattva": ['cae', 'mw'],
    "laghusattvatā": ['mw'],
    "laghusaṃdeśapada": ['mw'],
    "laghusaṃgraha": ['mw'],
    "laghusaṃgrahaṇīsūtra": ['mw'],
    "laghusaṃtāpa": ['mw'],
    "laghusiddhāntacandrikā": ['mw'],
    "laghusiddhāntakaumudī": ['mw'],
    "laghustava": ['mw'],
    "laghustavaṭippaṇaka": ['mw'],
    "laghusthānatā": ['mw'],
    "laghustotra": ['mw'],
    "laghusudarśana": ['mw'],
    "laghusyada": ['mw'],
    "laghusāra": ['mw'],
    "laghusārāvalī": ['mw'],
    "laghusāṃkhyasūtravṛtti": ['mw'],
    "laghusāṃkhyavṛtti": ['mw'],
    "laghusūtravṛtti": ['mw'],
    "laghutara": ['mw'],
    "laghutva": ['mw'],
    "laghutā": ['ap90', 'cae', 'mw'],
    "laghutāla": ['mw'],
    "laghuvaiyākaraṇabhūṣaṇa": ['mw'],
    "laghuvaiyākaraṇabhūṣaṇasiddhāntamañjūṣā": ['mw'],
    "laghuvasiṣṭhasiddhānta": ['mw'],
    "laghuvedhin": ['mw'],
    "laghuvikrama": ['cae', 'mw'],
    "laghuvimarśinī": ['mw'],
    "laghuvivaratva": ['mw'],
    "laghuviṣṇu": ['mw'],
    "laghuvyākaraṇabhūṣaṇasāra": ['mw'],
    "laghuvyāsa": ['mw'],
    "laghuvādārtha": ['mw'],
    "laghuvākyavṛtti": ['mw'],
    "laghuvākyavṛttiprakāśikā": ['mw'],
    "laghuvārttika": ['mw'],
    "laghuvāsas": ['cae', 'mw'],
    "laghuvāsiṣṭha": ['mw'],
    "laghuvāsiṣṭhasiddhānta": ['mw'],
    "laghuvāyustuti": ['mw'],
    "laghuvṛtti": ['mw'],
    "laghuvṛttikārikā": ['mw'],
    "laghuvṛttitā": ['mw'],
    "laghuvṛttyavacūrikā": ['mw'],
    "laghuyama": ['mw'],
    "laghuyogaratnāvalī": ['mw'],
    "laghuśabdaratna": ['mw'],
    "laghuśabdenduśekhara": ['mw'],
    "laghuśamī": ['mw'],
    "laghuśaunaka": ['mw'],
    "laghuśaunakī": ['mw'],
    "laghuśaṅkha": ['mw'],
    "laghuśekhara": ['mw'],
    "laghuśikharatāla": ['mw'],
    "laghuśivapurāṇa": ['mw'],
    "laghuśāntipurāṇa": ['mw'],
    "laghuśāntividhāna": ['mw'],
    "laghuśīta": ['mw'],
    "laghv": ['mw'],
    "laghvakṣara": ['mw'],
    "laghvakṣaraka": ['mw'],
    "laghvamara": ['mw'],
    "laghvatri": ['mw'],
    "laghvañjīra": ['mw'],
    "laghvaṣṭavarga": ['mw'],
    "laghvācārya": ['mw'],
    "laghvādyuḍumbarāhvā": ['mw'],
    "laghvāhnika": ['mw'],
    "laghvāhāra": ['cae', 'mw'],
    "laghvāryabhaṭasiddhānta": ['mw'],
    "laghvāśin": ['cae', 'ddsa', 'mw'],
    "laghvī": ['ap90', 'mw'],
    "laghīyas": ['ap90', 'cae', 'mw'],
    "laghīyastva": ['mw'],
    "laghū": ['mw'],
    "laghūcchedya": ['cae'],
    "laghūdumbarikā": ['mw'],
    "laghūkaraṇa": ['mw'],
    "laghūkti": ['ddsa', 'mw'],
    "laghūkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "laghūkṛta": ['ap90', 'mw'],
    "laghūtthita": ['mw'],
    "laghūtthāna": ['mw'],
    "laghūtthānatā": ['bhs', 'mw'],
    "laghūy": ['cae'],
    "laghūya": ['mw'],
    "lagita": ['ap90', 'mw'],
    "lagna": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "lagnabhuja": ['mw'],
    "lagnacandrikā": ['mw'],
    "lagnacintā": ['mw'],
    "lagnadarpaṇa": ['mw'],
    "lagnadevī": ['mw'],
    "lagnadina": ['mw'],
    "lagnadivasa": ['mw'],
    "lagnadvādaśabhāva": ['mw'],
    "lagnagraha": ['mw'],
    "lagnagrahaṇa": ['mw'],
    "lagnahorāprakāśa": ['mw'],
    "lagnaka": ['mw'],
    "lagnakaḥ": ['ap90'],
    "lagnakāla": ['cae', 'mw'],
    "lagnamaṇḍala": ['mw'],
    "lagnamuhūrta": ['mw'],
    "lagnamāsa": ['mw'],
    "lagnanakṣatra": ['mw'],
    "lagnapattrikā": ['mw'],
    "lagnapañcāṅgabhāṣya": ['mw'],
    "lagnasamaya": ['mw'],
    "lagnasāriṇī": ['mw'],
    "lagnati": ['bhs'],
    "lagnavelā": ['cae', 'mw'],
    "lagnavāda": ['mw'],
    "lagnavāsara": ['mw'],
    "lagnayāna": ['mw'],
    "lagnaśuddhi": ['mw'],
    "lagnikā": ['ap90', 'mw'],
    "lagnoddyota": ['mw'],
    "lagnāha": ['mw'],
    "lagnāsu": ['mw'],
    "lagnāṅka": ['mw'],
    "lagudin": ['ddsa'],
    "lagura": ['mw'],
    "lagurahasta": ['mw'],
    "laguḍa": ['cae', 'ddsa', 'mw'],
    "laguḍahasta": ['cae', 'mw'],
    "laguḍaprahāra": ['cae'],
    "laguḍavaṃśikā": ['mw'],
    "laguḍaḥ": ['ap90'],
    "laguḍin": ['mw'],
    "laguḷa": ['cped'],
    "lagālikā": ['mw'],
    "lahakā": ['mw'],
    "lahalahāya": ['mw'],
    "lahara": ['cae', 'ddsa', 'mw'],
    "lahari": ['cae', 'ddsa', 'mw'],
    "lahariḥ": ['ap90'],
    "laharī": ['cae', 'mw'],
    "lahaḍa": ['mw'],
    "lahika": ['mw'],
    "lahoḍa": ['mw'],
    "lahu": ['bhs', 'cped'],
    "lahuka": ['cped'],
    "lahukaṁ": ['cped'],
    "lahuparivatta": ['cped'],
    "lahuso": ['cped'],
    "lahutā": ['cped'],
    "lahuṁ": ['cped'],
    "lahvā": ['mw'],
    "lahya": ['mw'],
    "laigavya": ['mw'],
    "laigavyāyanī": ['mw'],
    "laigavāyana": ['mw'],
    "laikha": ['mw'],
    "laikhābhreya": ['mw'],
    "laiśika": ['bhs', 'mw'],
    "laiṃgaṃ": ['ap90'],
    "laiṃgika": ['ap90'],
    "laiṅagodbhava": ['ddsa'],
    "laiṅga": ['ddsa', 'mw'],
    "laiṅgadhūma": ['mw'],
    "laiṅgika": ['mw'],
    "laiṅgikabhāvavāda": ['mw'],
    "laiṅgodbhava": ['mw'],
    "laiṅgī": ['mw'],
    "laiṅgīka": ['mw'],
    "laiṇ": ['ap90', 'mw'],
    "laj": ['ap90', 'mw'],
    "lajakārikā": ['mw'],
    "lajj": ['ap90', 'cae', 'ddsa', 'mw'],
    "lajja": ['mw'],
    "lajjakā": ['ap90', 'mw'],
    "lajjamāna": ['cped'],
    "lajjana": ['cped'],
    "lajjanta": ['cped'],
    "lajjarī": ['ap90', 'mw'],
    "lajjati": ['cped'],
    "lajji": ['cped'],
    "lajjin": ['bhs'],
    "lajjinī": ['mw'],
    "lajjirī": ['mw'],
    "lajjita": ['ap90', 'cae', 'cped', 'ddsa'],
    "lajjitabbaka": ['cped'],
    "lajjitavya": ['bhs'],
    "lajjitvā": ['cped'],
    "lajjodvahana": ['mw'],
    "lajjodvahanākṣama": ['mw'],
    "lajjojjhita": ['mw'],
    "lajjā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "lajjādhāra": ['mw'],
    "lajjāhīna": ['mw'],
    "lajjākara": ['cae', 'mw'],
    "lajjākārin": ['mw'],
    "lajjākṛti": ['mw'],
    "lajjālu": ['ap90', 'cae', 'mw'],
    "lajjāluka": ['cae', 'ddsa'],
    "lajjānvita": ['mw'],
    "lajjāpana": ['cped'],
    "lajjāpayitṛ": ['cae', 'mw'],
    "lajjāpayitṛka": ['cae'],
    "lajjāpesi": ['cped'],
    "lajjāpeti": ['cped'],
    "lajjāpita": ['cped'],
    "lajjārahita": ['mw'],
    "lajjāvaha": ['cae', 'mw'],
    "lajjāvant": ['cae'],
    "lajjāvat": ['ap90', 'ddsa', 'mw'],
    "lajjāvattva": ['mw'],
    "lajjāvinamrānana": ['mw'],
    "lajjāy": ['cae'],
    "lajjāya": ['mw'],
    "lajjāyita": ['ddsa', 'mw'],
    "lajjāśīla": ['mw'],
    "lajjāśīlatva": ['mw'],
    "lajjāśūnya": ['mw'],
    "lajjī": ['cped'],
    "lajyā": ['ap90', 'mw'],
    "lak": ['ap90', 'mw'],
    "laka": ['mw'],
    "lakaca": ['mw'],
    "lakacaḥ": ['ap90'],
    "lakaḥ": ['ap90'],
    "lakh": ['ap90', 'mw'],
    "lakhamādevī": ['mw'],
    "lakhimādevī": ['mw'],
    "lakkaka": ['ddsa', 'mw'],
    "lakkha": ['cped'],
    "lakkhaṇa": ['cped'],
    "lakkhaṇapāṭhaka": ['cped'],
    "lakkhaṇasampanna": ['cped'],
    "lakkhaṇasampatti": ['cped'],
    "lakkhesi": ['cped'],
    "lakkheti": ['cped'],
    "lakkhetvā": ['cped'],
    "lakkhika": ['cped'],
    "lakkhita": ['cped'],
    "lakkhī": ['cped'],
    "lakta": ['mw'],
    "laktaka": ['mw'],
    "laktakarman": ['mw'],
    "laktakaḥ": ['ap90'],
    "laktikā": ['ap90'],
    "lakuca": ['cae', 'mw'],
    "lakula": ['mw'],
    "lakulin": ['mw'],
    "lakulya": ['mw'],
    "lakuṇṭaka": ['cped'],
    "lakuṭa": ['bhs', 'cae', 'ddsa', 'mw'],
    "lakuṭaḥ": ['ap90'],
    "lakuṭin": ['mw'],
    "lakvanacandra": ['mw'],
    "lakāra": ['cae', 'cped', 'mw'],
    "lakāraviśeṣārthanirūpaṇa": ['mw'],
    "lakāravāda": ['mw'],
    "lakārārthaprakriyā": ['mw'],
    "lakārārthavāda": ['mw'],
    "lakṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "lakṣa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "lakṣabhūta": ['mw'],
    "lakṣadatta": ['ddsa', 'mw'],
    "lakṣadīpakalpa": ['mw'],
    "lakṣadīpavratodyāpana": ['mw'],
    "lakṣahoma": ['mw'],
    "lakṣahomapaddhati": ['mw'],
    "lakṣahomavidhi": ['mw'],
    "lakṣaka": ['ap90', 'cae', 'mw'],
    "lakṣanamaskāravidhi": ['mw'],
    "lakṣanamaskāravrata": ['mw'],
    "lakṣapadmavratodyāpana": ['mw'],
    "lakṣapradakṣiṇavidhi": ['mw'],
    "lakṣapradakṣiṇavratavidhi": ['mw'],
    "lakṣapura": ['mw'],
    "lakṣapuṣpapūjodyāpana": ['mw'],
    "lakṣapuṣpavrata": ['mw'],
    "lakṣapuṣpavratodyāpanavidhi": ['mw'],
    "lakṣapuṣpodhyāpana": ['mw'],
    "lakṣapārthivaliṅgavratodyāpana": ['mw'],
    "lakṣapūjodyāpana": ['mw'],
    "lakṣapūjāmāhātmya": ['mw'],
    "lakṣarāmanāmalekhanavrata": ['mw'],
    "lakṣasupta": ['ddsa', 'mw'],
    "lakṣasvastikavratakalpa": ['mw'],
    "lakṣasvastikavratodyāpana": ['mw'],
    "lakṣatulasyudyāpanavidhi": ['mw'],
    "lakṣatulasīvratodyāpana": ['mw'],
    "lakṣatā": ['mw'],
    "lakṣavartidīpavratakalpa": ['mw'],
    "lakṣavartikathā": ['mw'],
    "lakṣavartikodyāpanavidhi": ['mw'],
    "lakṣavartivrata": ['mw'],
    "lakṣavartyudyāpana": ['mw'],
    "lakṣavartyudyāpanavidhāna": ['mw'],
    "lakṣavedhin": ['cae', 'mw'],
    "lakṣay": ['cae'],
    "lakṣaya": ['ddsa'],
    "lakṣaśas": ['ap90', 'mw'],
    "lakṣaśloka": ['mw'],
    "lakṣaṃ": ['ap90'],
    "lakṣaṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "lakṣaṇabhraṣṭa": ['mw'],
    "lakṣaṇabhūṣitagātra": ['bhs'],
    "lakṣaṇadīpikā": ['mw'],
    "lakṣaṇagrantha": ['mw'],
    "lakṣaṇajña": ['mw'],
    "lakṣaṇaka": ['mw'],
    "lakṣaṇakarman": ['ddsa', 'mw'],
    "lakṣaṇakāṇḍa": ['mw'],
    "lakṣaṇalakṣaṇā": ['mw'],
    "lakṣaṇamerumegharutaghoṣa": ['bhs'],
    "lakṣaṇamātreṇa": ['bhs'],
    "lakṣaṇapariśodhana": ['bhs'],
    "lakṣaṇaparvatavairocana": ['bhs'],
    "lakṣaṇaprakāśa": ['mw'],
    "lakṣaṇapraśasta": ['mw'],
    "lakṣaṇaratna": ['mw'],
    "lakṣaṇaratnamālikā": ['mw'],
    "lakṣaṇarucirasupuṣpitāṅga": ['bhs'],
    "lakṣaṇaruciravairocanā": ['bhs'],
    "lakṣaṇarājī": ['mw'],
    "lakṣaṇasampad": ['mw'],
    "lakṣaṇasamuccaya": ['mw'],
    "lakṣaṇasaṃgraha": ['mw'],
    "lakṣaṇasaṃnipāta": ['cae', 'mw'],
    "lakṣaṇasaṃniveśa": ['cae', 'mw'],
    "lakṣaṇasumeru": ['bhs'],
    "lakṣaṇasārasamuccaya": ['mw'],
    "lakṣaṇasūryacakrasamantaprabha": ['bhs'],
    "lakṣaṇasūtra": ['bhs'],
    "lakṣaṇatva": ['mw'],
    "lakṣaṇavant": ['cae'],
    "lakṣaṇavat": ['mw'],
    "lakṣaṇavibhūṣitadhvajacandra": ['bhs'],
    "lakṣaṇavāda": ['mw'],
    "lakṣaṇavṛtti": ['mw'],
    "lakṣaṇaśataka": ['mw'],
    "lakṣaṇaśrīparvata": ['bhs'],
    "lakṣaṇaṃ": ['ap90'],
    "lakṣaṇeya": ['bhs'],
    "lakṣaṇin": ['mw'],
    "lakṣaṇoru": ['mw'],
    "lakṣaṇottamā": ['bhs', 'mw'],
    "lakṣaṇya": ['ap90', 'bhs', 'cae', 'mw'],
    "lakṣaṇā": ['ddsa', 'mw'],
    "lakṣaṇāhata": ['bhs'],
    "lakṣaṇālakṣaṇatas": ['mw'],
    "lakṣaṇāmṛta": ['mw'],
    "lakṣaṇānvita": ['cae', 'mw'],
    "lakṣaṇāvalī": ['mw'],
    "lakṣaṇāvāda": ['mw'],
    "lakṣaṇāvādarahasya": ['mw'],
    "lakṣaṇāvṛttiprakaraṇa": ['mw'],
    "lakṣaṇīya": ['cae', 'mw'],
    "lakṣeśa": ['ddsa', 'mw'],
    "lakṣin": ['cae', 'mw'],
    "lakṣita": ['ap90', 'cae', 'mw'],
    "lakṣitalakṣaṇa": ['mw'],
    "lakṣitatva": ['ddsa', 'mw'],
    "lakṣitavya": ['cae', 'mw'],
    "lakṣma": ['mw'],
    "lakṣmaka": ['ddsa', 'mw'],
    "lakṣmakaṇikā": ['mw'],
    "lakṣman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "lakṣmaṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "lakṣmaṇabhaṭṭīya": ['mw'],
    "lakṣmaṇacampū": ['mw'],
    "lakṣmaṇacandra": ['mw'],
    "lakṣmaṇacūrṇikā": ['mw'],
    "lakṣmaṇadeva": ['mw'],
    "lakṣmaṇadāsa": ['mw'],
    "lakṣmaṇakavaca": ['mw'],
    "lakṣmaṇakhaṇḍapraśasti": ['mw'],
    "lakṣmaṇakuṇḍaka": ['mw'],
    "lakṣmaṇapati": ['mw'],
    "lakṣmaṇaprasū": ['mw'],
    "lakṣmaṇarājadeva": ['mw'],
    "lakṣmaṇasena": ['mw'],
    "lakṣmaṇasiṃha": ['mw'],
    "lakṣmaṇasvāmin": ['mw'],
    "lakṣmaṇia": ['gra'],
    "lakṣmaṇoru": ['mw'],
    "lakṣmaṇotsava": ['mw'],
    "lakṣmaṇya": ['cae', 'gra', 'mw'],
    "lakṣmaṇā": ['mw'],
    "lakṣmaṇābharaṇīya": ['mw'],
    "lakṣmaṇāditya": ['mw'],
    "lakṣmi": ['cae', 'mw'],
    "lakṣmisampanna": ['mw'],
    "lakṣmitā": ['bhs'],
    "lakṣmivardhana": ['mw'],
    "lakṣmy": ['mw'],
    "lakṣmyaṣṭottaraśatanāman": ['mw'],
    "lakṣmyaṣṭottaraśatastotra": ['mw'],
    "lakṣmyārāma": ['mw'],
    "lakṣmī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "lakṣmībahiṣkṛta": ['mw'],
    "lakṣmīcandramiśra": ['mw'],
    "lakṣmīcaritra": ['mw'],
    "lakṣmīdatta": ['mw'],
    "lakṣmīdeva": ['mw'],
    "lakṣmīdevī": ['mw'],
    "lakṣmīdhara": ['mw'],
    "lakṣmīdharakāvya": ['mw'],
    "lakṣmīdharasena": ['mw'],
    "lakṣmīdvādaśanāmamahiman": ['mw'],
    "lakṣmīdvādaśanāmamahimastotra": ['mw'],
    "lakṣmīdāsa": ['mw'],
    "lakṣmīgṛha": ['mw'],
    "lakṣmīhṛdaya": ['mw'],
    "lakṣmīhṛdayastotra": ['mw'],
    "lakṣmījanārdana": ['mw'],
    "lakṣmīka": ['cae', 'mw'],
    "lakṣmīkalpa": ['mw'],
    "lakṣmīkavaca": ['mw'],
    "lakṣmīkhaṇḍa": ['mw'],
    "lakṣmīkulatantra": ['mw'],
    "lakṣmīkulārṇava": ['mw'],
    "lakṣmīkumāratātācārya": ['mw'],
    "lakṣmīkānta": ['mw'],
    "lakṣmīkāntaśikṣā": ['mw'],
    "lakṣmīlahari": ['mw'],
    "lakṣmīmandira": ['mw'],
    "lakṣmīmantra": ['mw'],
    "lakṣmīnarasiṃha": ['mw'],
    "lakṣmīniketana": ['mw'],
    "lakṣmīnivāsa": ['mw'],
    "lakṣmīnivāsābhidhāna": ['mw'],
    "lakṣmīnāmāmṛta": ['mw'],
    "lakṣmīnārāyaṇa": ['mw'],
    "lakṣmīnārāyaṇahṛdaya": ['mw'],
    "lakṣmīnārāyaṇapañcāṅga": ['mw'],
    "lakṣmīnārāyaṇapūjāvidhāna": ['mw'],
    "lakṣmīnārāyaṇasahasranāman": ['mw'],
    "lakṣmīnārāyaṇasaṃvāda": ['mw'],
    "lakṣmīnārāyaṇastava": ['mw'],
    "lakṣmīnārāyaṇastotra": ['mw'],
    "lakṣmīnārāyaṇavrata": ['mw'],
    "lakṣmīnārāyaṇavratakalpa": ['mw'],
    "lakṣmīnārāyaṇārcākaumudī": ['mw'],
    "lakṣmīnātha": ['mw'],
    "lakṣmīnṛsiṃha": ['mw'],
    "lakṣmīnṛsiṃhakavaca": ['mw'],
    "lakṣmīnṛsiṃhamahāṣṭottara": ['mw'],
    "lakṣmīnṛsiṃhamahāṣṭottarabhāṣya": ['mw'],
    "lakṣmīnṛsiṃhapañcaratnamālikā": ['mw'],
    "lakṣmīnṛsiṃhasahasranāman": ['mw'],
    "lakṣmīnṛsiṃhastavarāja": ['mw'],
    "lakṣmīnṛsiṃhastotra": ['mw'],
    "lakṣmīpati": ['mw'],
    "lakṣmīpatī": ['bhs'],
    "lakṣmīpañcāśat": ['mw'],
    "lakṣmīphala": ['mw'],
    "lakṣmīpraṇayin": ['mw'],
    "lakṣmīpura": ['mw'],
    "lakṣmīpuramāhātmya": ['mw'],
    "lakṣmīpuruṣakāra": ['mw'],
    "lakṣmīputra": ['bhs', 'mw'],
    "lakṣmīpuṣpa": ['mw'],
    "lakṣmīpūjana": ['mw'],
    "lakṣmīpūjā": ['mw'],
    "lakṣmīpūjāviveka": ['mw'],
    "lakṣmīramaṇa": ['mw'],
    "lakṣmīsahaja": ['mw'],
    "lakṣmīsahasranāman": ['mw'],
    "lakṣmīsahasranāmastotra": ['mw'],
    "lakṣmīsahodara": ['mw'],
    "lakṣmīsakha": ['mw'],
    "lakṣmīsamāhvayā": ['mw'],
    "lakṣmīsanātha": ['mw'],
    "lakṣmīsaparyāsāra": ['mw'],
    "lakṣmīsarasvatī": ['mw'],
    "lakṣmīsarasvatīsaṃvāda": ['mw'],
    "lakṣmīsaṃhitā": ['mw'],
    "lakṣmīsena": ['mw'],
    "lakṣmīstava": ['mw'],
    "lakṣmīstotra": ['mw'],
    "lakṣmīstuti": ['mw'],
    "lakṣmīsvayaṃvaranāṭaka": ['mw'],
    "lakṣmīsūkta": ['mw'],
    "lakṣmītantra": ['mw'],
    "lakṣmītva": ['mw'],
    "lakṣmītāla": ['mw'],
    "lakṣmīvallabha": ['mw'],
    "lakṣmīvant": ['cae'],
    "lakṣmīvarmadeva": ['mw'],
    "lakṣmīvasati": ['mw'],
    "lakṣmīvat": ['ap90', 'mw'],
    "lakṣmīvatī": ['mw'],
    "lakṣmīveṣṭa": ['mw'],
    "lakṣmīvilāsa": ['mw'],
    "lakṣmīvinaya": ['mw'],
    "lakṣmīvivarta": ['mw'],
    "lakṣmīvratapūjā": ['mw'],
    "lakṣmīvākya": ['mw'],
    "lakṣmīvāra": ['mw'],
    "lakṣmīyajus": ['mw'],
    "lakṣmīśa": ['mw'],
    "lakṣmīśreṣṭhā": ['mw'],
    "lakṣmīśvarasiṃha": ['mw'],
    "lakṣmīṃdadā": ['bhs', 'mw'],
    "lakṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "lakṣyabheda": ['mw'],
    "lakṣyabhūta": ['mw'],
    "lakṣyagraha": ['mw'],
    "lakṣyahan": ['mw'],
    "lakṣyajñatva": ['mw'],
    "lakṣyakrama": ['mw'],
    "lakṣyalakṣaṇabhāva": ['mw'],
    "lakṣyanirṇaya": ['mw'],
    "lakṣyasiddhi": ['mw'],
    "lakṣyasupta": ['mw'],
    "lakṣyatva": ['mw'],
    "lakṣyatā": ['cae', 'mw'],
    "lakṣyavedha": ['mw'],
    "lakṣyavedhin": ['mw'],
    "lakṣyavīthī": ['mw'],
    "lakṣyābhiharaṇa": ['mw'],
    "lakṣyālakṣya": ['cae', 'mw'],
    "lakṣyārtha": ['cae', 'mw'],
    "lakṣyī": ['mw'],
    "lakṣyībhū": ['mw'],
    "lakṣyīkṛ": ['cae', 'ddsa', 'mw'],
    "lakṣādhīśa": ['mw'],
    "lakṣāntapurī": ['mw'],
    "lakṣāntara": ['cae', 'mw'],
    "lakṣāvatāra": ['mw'],
    "lakṣī": ['mw'],
    "lakṣībhū": ['mw'],
    "lakṣīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "lakṣīkṛta": ['mw'],
    "lakṣīkṛtanāsa": ['mw'],
    "lakṣṇāvalī": ['mw'],
    "lal": ['ap90', 'cae', 'ddsa', 'mw'],
    "lala": ['ap90', 'mw'],
    "laladambu": ['mw'],
    "lalaha": ['mw'],
    "lalajjihva": ['ddsa', 'mw'],
    "lalalla": ['ddsa', 'mw'],
    "lalana": ['cae', 'ddsa', 'mw'],
    "lalanaṃ": ['ap90'],
    "lalanikā": ['ap90', 'cae', 'mw'],
    "lalantikā": ['cae', 'mw'],
    "lalanā": ['ap90', 'bhs', 'cped', 'mw'],
    "lalanākṣa": ['mw'],
    "lalanāpriya": ['mw'],
    "lalanāvarūthin": ['mw'],
    "lalat": ['ap90'],
    "lalaṃtikā": ['ap90'],
    "lalita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "lalitacaitya": ['mw'],
    "lalitagupta": ['bhs'],
    "lalitaka": ['mw'],
    "lalitalalita": ['cae', 'mw'],
    "lalitalocana": ['cae', 'mw'],
    "lalitalocanā": ['mw'],
    "lalitam": ['mw'],
    "lalitamādhava": ['mw'],
    "lalitapada": ['mw'],
    "lalitapadabandhana": ['mw'],
    "lalitaprahāra": ['mw'],
    "lalitapriya": ['mw'],
    "lalitapura": ['mw'],
    "lalitapurāṇa": ['mw'],
    "lalitaratnamālā": ['mw'],
    "lalitasvacchanda": ['mw'],
    "lalitatribhaṅga": ['mw'],
    "lalitatāla": ['mw'],
    "lalitavanitā": ['mw'],
    "lalitavigraharāja": ['mw'],
    "lalitavikrama": ['bhs'],
    "lalitavistara": ['bhs', 'cae', 'mw'],
    "lalitavistarapurāṇa": ['mw'],
    "lalitavyūha": ['bhs', 'mw'],
    "lalitoka": ['mw'],
    "lalitopākhyāna": ['mw'],
    "lalittha": ['cae', 'mw'],
    "lalitā": ['ap90', 'mw'],
    "lalitābhaṭṭabhāskara": ['mw'],
    "lalitābhinaya": ['mw'],
    "lalitābhāṣya": ['mw'],
    "lalitādikīrti": ['mw'],
    "lalitādipūjāvidhi": ['mw'],
    "lalitāditya": ['mw'],
    "lalitādityapura": ['mw'],
    "lalitāgadyanirūpaṇa": ['mw'],
    "lalitāhṛdaya": ['mw'],
    "lalitākhaṇḍa": ['mw'],
    "lalitākramadīpikā": ['mw'],
    "lalitāmādhava": ['mw'],
    "lalitāmāhātmya": ['mw'],
    "lalitānurāga": ['mw'],
    "lalitāpaddhati": ['mw'],
    "lalitāpañcamī": ['mw'],
    "lalitāpañcaśatī": ['mw'],
    "lalitāpañcāṅga": ['mw'],
    "lalitāpīḍa": ['mw'],
    "lalitāpūjākhaṇḍa": ['mw'],
    "lalitāpūjāvidhāna": ['mw'],
    "lalitārahasya": ['mw'],
    "lalitārcanacandrikā": ['mw'],
    "lalitārcanadīpikā": ['mw'],
    "lalitārcanavidhi": ['mw'],
    "lalitārtha": ['mw'],
    "lalitārthabandha": ['mw'],
    "lalitāryādviśatī": ['mw'],
    "lalitāsahasra": ['mw'],
    "lalitāsahasranāmabhāṣya": ['mw'],
    "lalitāsahasranāman": ['mw'],
    "lalitāsaparyāpaddhati": ['mw'],
    "lalitāsaptamī": ['mw'],
    "lalitāsiddhānta": ['mw'],
    "lalitāstavaratna": ['mw'],
    "lalitātantra": ['mw'],
    "lalitātriśatī": ['mw'],
    "lalitātṛtīyā": ['mw'],
    "lalitātṛtīyāvrata": ['mw'],
    "lalitāvrata": ['mw'],
    "lalitāṅga": ['mw'],
    "lalitāṅganareśvaracarita": ['mw'],
    "lalitāṅgī": ['ddsa', 'mw'],
    "lalitāṣaṣṭhī": ['mw'],
    "lalitāṣaṣṭhīvrata": ['mw'],
    "lalitāṣṭottaraśatanāman": ['mw'],
    "lalla": ['bhs', 'cae', 'ddsa', 'mw'],
    "lallara": ['mw'],
    "lallavārāhasuta": ['mw'],
    "lalliya": ['mw'],
    "lallujīlāla": ['mw'],
    "lallā": ['mw'],
    "lallādīkṣita": ['mw'],
    "lalyāna": ['ddsa', 'mw'],
    "lalākaḥ": ['ap90'],
    "lalāma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "lalāmagu": ['mw'],
    "lalāmaka": ['cae', 'mw'],
    "lalāmakarūpaka": ['mw'],
    "lalāmakaṃ": ['ap90'],
    "lalāman": ['ap90', 'cae', 'mw'],
    "lalāmavat": ['mw'],
    "lalāmī": ['mw'],
    "lalāṭa": ['cae', 'ddsa', 'mw'],
    "lalāṭadeśa": ['mw'],
    "lalāṭaka": ['cae', 'mw'],
    "lalāṭakaṃ": ['ap90'],
    "lalāṭalekhā": ['mw'],
    "lalāṭalikhita": ['cae', 'mw'],
    "lalāṭapaṭṭa": ['cae', 'mw'],
    "lalāṭapaṭṭaka": ['cae', 'mw'],
    "lalāṭapaṭṭikā": ['mw'],
    "lalāṭaphalaka": ['cae', 'mw'],
    "lalāṭapura": ['mw'],
    "lalāṭarekhā": ['mw'],
    "lalāṭataṭa": ['mw'],
    "lalāṭaṃ": ['ap90'],
    "lalāṭaṃtapa": ['ap90', 'cae', 'mw'],
    "lalāṭe": ['mw'],
    "lalāṭika": ['cae', 'mw'],
    "lalāṭikā": ['ap90', 'ddsa', 'mw'],
    "lalāṭikāya": ['mw'],
    "lalāṭya": ['mw'],
    "lalāṭākṣa": ['cae', 'mw'],
    "lalāṭūla": ['ap90', 'mw'],
    "lalītikā": ['mw'],
    "lam": ['cae', 'ddsa', 'mw'],
    "lamaka": ['mw'],
    "lamakaḥ": ['ap90'],
    "lamb": ['cae', 'ddsa', 'mw'],
    "lamba": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "lambabījā": ['mw'],
    "lambadantā": ['mw'],
    "lambadāma": ['bhs'],
    "lambaguṇa": ['mw'],
    "lambajaṭhara": ['mw'],
    "lambajihva": ['mw'],
    "lambajyakā": ['mw'],
    "lambajyā": ['mw'],
    "lambaka": ['bhs', 'cped', 'mw'],
    "lambakarṇa": ['cae', 'mw'],
    "lambakeśa": ['mw'],
    "lambakeśaka": ['mw'],
    "lambamāla": ['mw'],
    "lambamāna": ['cped'],
    "lambana": ['bhs', 'cae', 'ddsa', 'mw'],
    "lambanavidhi": ['mw'],
    "lambanta": ['cped'],
    "lambapayodharā": ['mw'],
    "lambara": ['mw'],
    "lambarekhā": ['mw'],
    "lambasaṭa": ['mw'],
    "lambasphic": ['mw'],
    "lambasraj": ['mw'],
    "lambastanī": ['mw'],
    "lambati": ['cped'],
    "lambauṣṭha": ['mw'],
    "lambesi": ['cped'],
    "lambeti": ['cped'],
    "lambetvā": ['cped'],
    "lambh": ['mw'],
    "lambha": ['cae', 'ddsa', 'mw'],
    "lambhaka": ['mw'],
    "lambhana": ['mw'],
    "lambhanīya": ['cae', 'mw'],
    "lambhayitavya": ['cae', 'mw'],
    "lambhita": ['mw'],
    "lambhitakānti": ['mw'],
    "lambhitalobha": ['mw'],
    "lambhuka": ['cae', 'mw'],
    "lambhā": ['mw'],
    "lambi": ['cped'],
    "lambika": ['bhs', 'mw'],
    "lambikā": ['bhs', 'mw'],
    "lambikākokilā": ['mw'],
    "lambin": ['cae', 'ddsa', 'mw'],
    "lambinī": ['mw'],
    "lambita": ['cae', 'cped', 'mw'],
    "lambitvā": ['cped'],
    "lambodara": ['bhs', 'cae', 'ddsa', 'mw'],
    "lambodaraprahasana": ['mw'],
    "lambodaratā": ['mw'],
    "lambodarī": ['mw'],
    "lambodarīnadīmāhātmya": ['mw'],
    "lamboṣṭha": ['mw'],
    "lambuka": ['bhs', 'mw'],
    "lambuṣā": ['mw'],
    "lambā": ['bhs', 'mw'],
    "lambākṣa": ['mw'],
    "lambālaka": ['mw'],
    "lambālakatva": ['mw'],
    "lambāpaṭaha": ['ddsa', 'mw'],
    "lambāviśvavayasau": ['mw'],
    "lambī": ['mw'],
    "lamna": ['ddsa', 'mw'],
    "lampa": ['bhs'],
    "lampaka": ['bhs', 'mw'],
    "lampaṭa": ['cae', 'ddsa', 'mw'],
    "lampaṭatva": ['mw'],
    "lampaṭatā": ['mw'],
    "lampaṭā": ['mw'],
    "lampha": ['mw'],
    "lamphana": ['mw'],
    "lampuṭa": ['bhs'],
    "lampā": ['cae', 'ddsa', 'mw'],
    "lampāka": ['ddsa', 'mw'],
    "lampākī": ['mw'],
    "lampāpaṭaha": ['mw'],
    "lap": ['ap90', 'cae', 'ddsa', 'mw'],
    "lapa": ['bhs'],
    "lapaka": ['bhs'],
    "lapana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "lapanaja": ['cped'],
    "lapanaṃ": ['ap90'],
    "lapanā": ['cped'],
    "lapati": ['cped'],
    "lapayati": ['bhs'],
    "lapeta": ['ddsa', 'mw'],
    "lapeṭikā": ['mw'],
    "lapi": ['cped'],
    "lapita": ['ap90', 'cae', 'cped', 'mw'],
    "lapitvā": ['cped'],
    "lapitā": ['mw'],
    "lapsikā": ['ap90', 'mw'],
    "lapsuda": ['mw'],
    "lapsudin": ['cae', 'ddsa', 'mw'],
    "larb": ['mw'],
    "lard": ['mw'],
    "lardayati": ['bhs'],
    "larv": ['ap90'],
    "las": ['ap90', 'cae', 'ddsa', 'mw'],
    "lasa": ['bhs', 'ddsa', 'mw'],
    "lasadaṃśu": ['mw'],
    "lasaka": ['mw'],
    "lasakaḥ": ['ap90'],
    "lasati": ['cped'],
    "lasi": ['cped'],
    "lasikā": ['ap90', 'cped', 'ddsa', 'mw'],
    "lasita": ['ap90', 'mw'],
    "lasj": ['ap90'],
    "lasopharañja": ['mw'],
    "laspūjanī": ['cae', 'mw'],
    "lasta": ['ap90', 'mw'],
    "lastaka": ['mw'],
    "lastakagraha": ['mw'],
    "lastakaḥ": ['ap90'],
    "lastakin": ['ap90', 'mw'],
    "lasuṇa": ['cped'],
    "lasā": ['ap90', 'mw'],
    "lasī": ['cped'],
    "lasīkā": ['ap90', 'mw'],
    "latikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "latodgama": ['mw'],
    "lattikā": ['ap90', 'mw'],
    "lattādinirṇaya": ['mw'],
    "latu": ['mw'],
    "latā": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "latābhadrā": ['mw'],
    "latābhavana": ['mw'],
    "latābāṇa": ['mw'],
    "latābṛhatī": ['mw'],
    "latādruma": ['mw'],
    "latāgahanavat": ['mw'],
    "latāgṛha": ['cae', 'mw'],
    "latājihva": ['mw'],
    "latākamma": ['cped'],
    "latākara": ['mw'],
    "latākarañja": ['mw'],
    "latākastūrikā": ['mw'],
    "latākastūrī": ['mw'],
    "latākoli": ['mw'],
    "latākuśa": ['mw'],
    "latālaka": ['mw'],
    "latālaya": ['cae', 'mw'],
    "latāliṅga": ['mw'],
    "latāmarut": ['mw'],
    "latāmaṇi": ['mw'],
    "latāmaṇḍapa": ['cae', 'mw'],
    "latāmbuja": ['mw'],
    "latāmādhavī": ['mw'],
    "latāmāriṣa": ['mw'],
    "latāmṛga": ['mw'],
    "latānana": ['mw'],
    "latānta": ['mw'],
    "latāntabāṇa": ['mw'],
    "latāpanasa": ['mw'],
    "latāparṇa": ['mw'],
    "latāparṇī": ['mw'],
    "latāphala": ['mw'],
    "latāpratāna": ['mw'],
    "latāpuṭakī": ['mw'],
    "latāpāśa": ['cae', 'mw'],
    "latāpūga": ['mw'],
    "latāpṛkkā": ['mw'],
    "latārada": ['mw'],
    "latārasana": ['mw'],
    "latārka": ['bhs', 'mw'],
    "latātaru": ['mw'],
    "latāvalaya": ['cae', 'mw'],
    "latāvalayavat": ['mw'],
    "latāveṣṭa": ['mw'],
    "latāveṣṭana": ['mw'],
    "latāveṣṭita": ['mw'],
    "latāveṣṭitaka": ['mw'],
    "latāvitāna": ['cae', 'mw'],
    "latāvṛkṣa": ['mw'],
    "latāya": ['mw'],
    "latāyaṣṭi": ['mw'],
    "latāyāvaka": ['mw'],
    "latāśaṅkha": ['mw'],
    "latāśaṅkutaru": ['mw'],
    "latāṅguli": ['mw'],
    "latāṅgī": ['mw'],
    "latāṅkura": ['mw'],
    "laugākṣi": ['mw'],
    "laugākṣibhāskara": ['mw'],
    "laugākṣimīmāṃsā": ['mw'],
    "laugākṣismṛti": ['mw'],
    "lauha": ['ap90', 'cae', 'ddsa', 'mw'],
    "lauhabandha": ['mw'],
    "lauhabhāṇḍa": ['mw'],
    "lauhabhū": ['mw'],
    "lauhacāraka": ['mw'],
    "lauhaja": ['mw'],
    "lauhakāra": ['mw'],
    "lauhamala": ['mw'],
    "lauhapradīpa": ['mw'],
    "lauhasāra": ['mw'],
    "lauhaśaṅku": ['mw'],
    "lauhaśāstra": ['mw'],
    "lauheyī": ['mw'],
    "lauheṣa": ['mw'],
    "lauhi": ['mw'],
    "lauhita": ['mw'],
    "lauhitadhvaja": ['mw'],
    "lauhitaḥ": ['ap90'],
    "lauhitika": ['ap90'],
    "lauhitya": ['cae', 'ddsa', 'mw'],
    "lauhityabhaṭṭagopāla": ['mw'],
    "lauhityaḥ": ['ap90'],
    "lauhityāyanī": ['mw'],
    "lauhitāsva": ['mw'],
    "lauhitīka": ['mw'],
    "lauhā": ['mw'],
    "lauhābhisārikāprayoga": ['mw'],
    "lauhācārya": ['mw'],
    "lauhāsava": ['mw'],
    "lauhātman": ['mw'],
    "lauhāyana": ['mw'],
    "lauhāyasa": ['cae', 'mw'],
    "laukika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "laukikabhānavādarahasya": ['mw'],
    "laukikajña": ['mw'],
    "laukikanyāya": ['mw'],
    "laukikanyāyamuktāvalī": ['mw'],
    "laukikanyāyaratnākara": ['mw'],
    "laukikanyāyasaṃgraha": ['mw'],
    "laukikatva": ['mw'],
    "laukikaviṣayatāvicāra": ['mw'],
    "laukikaviṣayatāvāda": ['mw'],
    "laukikeṣu": ['mw'],
    "laukikāgra": ['bhs'],
    "laukya": ['ap90', 'cae', 'ddsa', 'mw'],
    "laukākṣa": ['bhs', 'mw'],
    "laukāyatika": ['ddsa', 'mw'],
    "laukāyatikaḥ": ['ap90'],
    "laulaka": ['mw'],
    "laulika": ['mw'],
    "laulya": ['cae', 'ddsa', 'mw'],
    "laulyatā": ['mw'],
    "laulyavat": ['mw'],
    "laulyaṃ": ['ap90'],
    "laulāha": ['ddsa', 'mw'],
    "lauma": ['mw'],
    "laumaharṣaṇaka": ['mw'],
    "laumaharṣaṇi": ['mw'],
    "laumakāyana": ['mw'],
    "laumakāyani": ['mw'],
    "laumakīya": ['mw'],
    "laumana": ['mw'],
    "laumanya": ['mw'],
    "laumaśīya": ['mw'],
    "laumi": ['mw'],
    "laumāyana": ['mw'],
    "laumāyanya": ['mw'],
    "laupsa": ['mw'],
    "lauyamāni": ['mw'],
    "lauśa": ['mw'],
    "lauḍ": ['ap90', 'mw'],
    "lauṭharatha": ['ddsa', 'mw'],
    "lava": ['cae', 'cped', 'ddsa', 'mw'],
    "lavaka": ['mw'],
    "lavali": ['cae', 'mw'],
    "lavalī": ['ap90', 'cae', 'ddsa', 'mw'],
    "lavalīpariṇaya": ['mw'],
    "lavalīphalapāṇḍura": ['mw'],
    "lavam": ['mw'],
    "lavana": ['cae', 'cped', 'ddsa', 'mw'],
    "lavanakalāyī": ['mw'],
    "lavanakartṛ": ['mw'],
    "lavanasādhikā": ['mw'],
    "lavanaṃ": ['ap90'],
    "lavanya": ['ddsa', 'mw'],
    "lavanī": ['mw'],
    "lavanīya": ['mw'],
    "lavarāja": ['ddsa', 'mw'],
    "lavavat": ['mw'],
    "lavaya": ['mw'],
    "lavaśas": ['cae', 'ddsa', 'mw'],
    "lavaḥ": ['ap90'],
    "lavaṃga": ['mw'],
    "lavaṃgaka": ['mw'],
    "lavaṃgakalikā": ['mw'],
    "lavaṃgakaṃ": ['ap90'],
    "lavaṃgalatā": ['mw'],
    "lavaṃgapuṣpa": ['mw'],
    "lavaṃgaḥ": ['ap90'],
    "lavaṃgikā": ['mw'],
    "lavaṃgī": ['mw'],
    "lavaṅga": ['cae', 'cped', 'ddsa'],
    "lavaṅgikā": ['cae'],
    "lavaṇa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "lavaṇabhadrika": ['bhs'],
    "lavaṇadhenu": ['mw'],
    "lavaṇadānaratna": ['mw'],
    "lavaṇajala": ['cae', 'mw'],
    "lavaṇajaladhi": ['cae', 'mw'],
    "lavaṇajalanidhi": ['cae', 'mw'],
    "lavaṇajalodbhava": ['mw'],
    "lavaṇakalāyī": ['mw'],
    "lavaṇakaṣāya": ['mw'],
    "lavaṇakaṭuka": ['mw'],
    "lavaṇakhāni": ['mw'],
    "lavaṇakiṃśukā": ['mw'],
    "lavaṇakrītaka": ['mw'],
    "lavaṇakṣāra": ['mw'],
    "lavaṇalāyikā": ['mw'],
    "lavaṇamada": ['mw'],
    "lavaṇamantra": ['mw'],
    "lavaṇameha": ['mw'],
    "lavaṇamehin": ['mw'],
    "lavaṇaparvata": ['mw'],
    "lavaṇapragāḍha": ['mw'],
    "lavaṇapura": ['mw'],
    "lavaṇapāṭalikā": ['mw'],
    "lavaṇasamudra": ['mw'],
    "lavaṇasindhu": ['mw'],
    "lavaṇasthāna": ['mw'],
    "lavaṇasya": ['mw'],
    "lavaṇasyati": ['ap90'],
    "lavaṇasādhikā": ['mw'],
    "lavaṇatikta": ['mw'],
    "lavaṇatoya": ['cae', 'mw'],
    "lavaṇatva": ['mw'],
    "lavaṇatā": ['cae', 'mw'],
    "lavaṇatṛṇa": ['mw'],
    "lavaṇavāri": ['cae', 'mw'],
    "lavaṇaya": ['mw'],
    "lavaṇayati": ['ap90'],
    "lavaṇaśrāddha": ['mw'],
    "lavaṇiman": ['ap90', 'cae', 'ddsa', 'mw'],
    "lavaṇita": ['cae', 'mw'],
    "lavaṇoda": ['cae', 'mw'],
    "lavaṇodadhi": ['cae', 'mw'],
    "lavaṇodaka": ['cae', 'mw'],
    "lavaṇodakamiśra": ['mw'],
    "lavaṇotkaṭa": ['mw'],
    "lavaṇotsa": ['ddsa', 'mw'],
    "lavaṇottama": ['mw'],
    "lavaṇottha": ['mw'],
    "lavaṇā": ['ap90', 'ddsa', 'mw'],
    "lavaṇābdhi": ['cae', 'mw'],
    "lavaṇābdhija": ['mw'],
    "lavaṇācala": ['mw'],
    "lavaṇākara": ['ddsa', 'mw'],
    "lavaṇālaya": ['cae', 'mw'],
    "lavaṇāmbhas": ['cae', 'mw'],
    "lavaṇāmburāśi": ['cae', 'mw'],
    "lavaṇāntaka": ['mw'],
    "lavaṇāpaṇa": ['mw'],
    "lavaṇārṇava": ['cae', 'mw'],
    "lavaṇāsura": ['mw'],
    "lavaṇāsuraja": ['mw'],
    "lavaṇāśva": ['mw'],
    "lavaṇī": ['mw'],
    "lavaṇīya": ['mw'],
    "lavaṭa": ['ddsa', 'mw'],
    "lavepsu": ['mw'],
    "laveraṇi": ['mw'],
    "laveṭikā": ['mw'],
    "lavi": ['ap90', 'mw'],
    "lavitavya": ['cae', 'mw'],
    "lavitavyatva": ['mw'],
    "lavitra": ['mw'],
    "lavitraṃ": ['ap90'],
    "lavuruka": ['bhs'],
    "lavya": ['cae', 'mw'],
    "lavāka": ['mw'],
    "lavākaḥ": ['ap90'],
    "lavānaka": ['mw'],
    "lavāpavāha": ['mw'],
    "lavāpayati": ['bhs'],
    "lavāṇakaḥ": ['ap90'],
    "lay": ['ap90', 'mw'],
    "laya": ['cae', 'cped', 'ddsa', 'mw'],
    "layagata": ['mw'],
    "layakāla": ['mw'],
    "layamadhya": ['cae', 'mw'],
    "layana": ['cae', 'ddsa', 'mw'],
    "layanaka": ['bhs'],
    "layanaṃ": ['ap90'],
    "layanālika": ['mw'],
    "layaputrī": ['mw'],
    "layasthāna": ['cae', 'ddsa', 'mw'],
    "layayoga": ['mw'],
    "layaśuddha": ['cae', 'mw'],
    "layaḥ": ['ap90'],
    "layā": ['mw'],
    "layālamba": ['mw'],
    "layālaya": ['mw'],
    "layārambha": ['mw'],
    "layārka": ['mw'],
    "lañca": ['cped'],
    "lañcadāna": ['cped'],
    "lañcaka": ['bhs'],
    "lañcakhādaka": ['cped'],
    "lañcha": ['cped'],
    "lañchaka": ['cped'],
    "lañchana": ['cped', 'mw'],
    "lañchati": ['cped'],
    "lañchesi": ['cped'],
    "lañcheti": ['cped'],
    "lañchetvā": ['cped'],
    "lañchi": ['cped'],
    "lañchita": ['cped'],
    "lañchitvā": ['cped'],
    "lañcā": ['cae', 'mw'],
    "lañj": ['mw'],
    "lañja": ['mw'],
    "lañjikā": ['mw'],
    "lañjā": ['mw'],
    "laś": ['ap90', 'mw'],
    "laśa": ['mw'],
    "laśuna": ['cae', 'ddsa', 'mw'],
    "laśunaḥ": ['ap90'],
    "laśunīya": ['mw'],
    "laḍ": ['ap90', 'ddsa', 'mw'],
    "laḍaha": ['ap90', 'cae', 'ddsa', 'mw'],
    "laḍahacandra": ['mw'],
    "laḍaka": ['mw'],
    "laḍarthavāda": ['mw'],
    "laḍita": ['bhs', 'mw'],
    "laḍitamaheśvara": ['mw'],
    "laḍuka": ['mw'],
    "laḍvā": ['ddsa', 'mw'],
    "laḍvākā": ['mw'],
    "laḍḍa": ['ap90', 'mw'],
    "laḍḍu": ['cae', 'ddsa', 'mw'],
    "laḍḍuka": ['cae', 'mw'],
    "laḍḍuḥ": ['ap90'],
    "laḍḍī": ['bhs'],
    "laḥ": ['ap90'],
    "laṃb": ['ap90'],
    "laṃba": ['ap90'],
    "laṃbakaḥ": ['ap90'],
    "laṃbanaḥ": ['ap90'],
    "laṃbhanaṃ": ['ap90'],
    "laṃbhaḥ": ['ap90'],
    "laṃbhita": ['ap90'],
    "laṃbikā": ['ap90'],
    "laṃbita": ['ap90'],
    "laṃbuṣā": ['ap90'],
    "laṃbā": ['ap90'],
    "laṃcā": ['ap90'],
    "laṃg": ['ap90'],
    "laṃgakaḥ": ['ap90'],
    "laṃgalaṃ": ['ap90'],
    "laṃgaḥ": ['ap90'],
    "laṃgh": ['ap90'],
    "laṃghaka": ['ap90'],
    "laṃghanaṃ": ['ap90'],
    "laṃghanīya": ['ap90'],
    "laṃghita": ['ap90'],
    "laṃgūlaṃ": ['ap90'],
    "laṃj": ['ap90'],
    "laṃjaḥ": ['ap90'],
    "laṃjikā": ['ap90'],
    "laṃjā": ['ap90'],
    "laṃkhanī": ['ap90'],
    "laṃkā": ['ap90'],
    "laṃpaṭa": ['ap90'],
    "laṃphanaṃ": ['ap90'],
    "laṃphaḥ": ['ap90'],
    "laṃḍ": ['ap90'],
    "laṃḍaṃ": ['ap90'],
    "laṃḍraḥ": ['ap90'],
    "laṅ": ['ap90', 'cae', 'ddsa', 'mw'],
    "laṅg": ['mw'],
    "laṅga": ['cae', 'ddsa', 'mw'],
    "laṅgadatta": ['mw'],
    "laṅgaka": ['bhs'],
    "laṅgala": ['ddsa', 'mw'],
    "laṅgana": ['mw'],
    "laṅganī": ['mw'],
    "laṅgh": ['cae', 'ddsa', 'mw'],
    "laṅghaka": ['bhs', 'cae', 'cped', 'mw'],
    "laṅghana": ['cae', 'cped', 'ddsa', 'mw'],
    "laṅghanaka": ['bhs', 'mw'],
    "laṅghanapathyanirṇaya": ['mw'],
    "laṅghanīya": ['cae', 'mw'],
    "laṅghanīyatva": ['mw'],
    "laṅghanīyatā": ['mw'],
    "laṅghati": ['cped'],
    "laṅghatī": ['mw'],
    "laṅghayati": ['bhs'],
    "laṅghesi": ['cped'],
    "laṅgheti": ['cped'],
    "laṅghetvā": ['cped'],
    "laṅghi": ['cped'],
    "laṅghiman": ['mw'],
    "laṅghita": ['bhs', 'cped', 'mw'],
    "laṅghitavya": ['mw'],
    "laṅghitvā": ['cped'],
    "laṅghya": ['cae', 'mw'],
    "laṅghī": ['cped'],
    "laṅgiman": ['mw'],
    "laṅgin": ['mw'],
    "laṅgula": ['cped'],
    "laṅgurā": ['mw'],
    "laṅgī": ['cped'],
    "laṅgūlā": ['mw'],
    "laṅka": ['mw'],
    "laṅkaka": ['mw'],
    "laṅkataṅkaṭā": ['mw'],
    "laṅkaśāntamukha": ['mw'],
    "laṅkendra": ['mw'],
    "laṅkeśa": ['mw'],
    "laṅkeśavanāriketu": ['mw'],
    "laṅkeśvara": ['bhs', 'mw'],
    "laṅkeśvarī": ['bhs', 'mw'],
    "laṅkh": ['mw'],
    "laṅkhanī": ['mw'],
    "laṅkodaya": ['mw'],
    "laṅkopikā": ['mw'],
    "laṅkoyikā": ['mw'],
    "laṅkoṭikā": ['mw'],
    "laṅkā": ['cae', 'ddsa', 'mw'],
    "laṅkādeśa": ['mw'],
    "laṅkādhipati": ['mw'],
    "laṅkādhirāja": ['mw'],
    "laṅkādāhin": ['mw'],
    "laṅkākāṇḍa": ['mw'],
    "laṅkānagarī": ['mw'],
    "laṅkānila": ['mw'],
    "laṅkānātha": ['mw'],
    "laṅkāpatha": ['bhs'],
    "laṅkāpati": ['mw'],
    "laṅkāpikā": ['mw'],
    "laṅkāpurī": ['mw'],
    "laṅkāri": ['mw'],
    "laṅkārikā": ['mw'],
    "laṅkāsthāyin": ['mw'],
    "laṅkāvatāra": ['bhs', 'mw'],
    "laṅkāyikā": ['mw'],
    "laṇḍ": ['mw'],
    "laṇḍa": ['cae', 'cped', 'ddsa', 'mw'],
    "laṇḍaka": ['bhs'],
    "laṇḍikā": ['cped'],
    "laṇḍra": ['ddsa', 'mw'],
    "laṇḍraja": ['mw'],
    "laṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "laṣamaṇa": ['mw'],
    "laṣamādevī": ['mw'],
    "laṣaṇa": ['mw'],
    "laṣaṇāvatī": ['mw'],
    "laṣita": ['ap90', 'mw'],
    "laṣmideva": ['mw'],
    "laṣva": ['mw'],
    "laṣvaḥ": ['ap90'],
    "laṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "laṭa": ['mw'],
    "laṭabha": ['ap90', 'cae', 'ddsa', 'mw'],
    "laṭabhā": ['mw'],
    "laṭaha": ['cae', 'mw'],
    "laṭaka": ['mw'],
    "laṭakamelanaprahasana": ['mw'],
    "laṭakana": ['mw'],
    "laṭakaḥ": ['ap90'],
    "laṭaparṇa": ['mw'],
    "laṭaḥ": ['ap90'],
    "laṭikā": ['bhs'],
    "laṭukikā": ['cped'],
    "laṭva": ['mw'],
    "laṭvaḥ": ['ap90'],
    "laṭvā": ['mw'],
    "laṭvākā": ['mw'],
    "laṭya": ['mw'],
    "laṭūṣaka": ['mw'],
    "laṭṭa": ['mw'],
    "laṭṭana": ['mw'],
    "laṭṭaḥ": ['ap90'],
    "laṭṭhi": ['cped'],
    "laṭṭhikā": ['cped'],
    "lecchavi": ['bhs'],
    "lecchavika": ['bhs'],
    "ledarī": ['ddsa', 'mw'],
    "leha": ['cae', 'ddsa', 'mw'],
    "lehacintāmaṇi": ['mw'],
    "lehaka": ['mw'],
    "leham": ['mw'],
    "lehana": ['cae', 'mw'],
    "lehanaṃ": ['ap90'],
    "lehanīya": ['mw'],
    "lehari": ['bhs'],
    "lehaḥ": ['ap90'],
    "lehin": ['mw'],
    "lehina": ['mw'],
    "lehinaḥ": ['ap90'],
    "lehya": ['ap90', 'cae', 'mw'],
    "lehī": ['mw'],
    "leka": ['mw'],
    "lekha": ['cae', 'ddsa', 'mw'],
    "lekhahāra": ['cae', 'mw'],
    "lekhahāraka": ['cae', 'mw'],
    "lekhahārika": ['bhs'],
    "lekhahārin": ['mw'],
    "lekhahāritva": ['mw'],
    "lekhaka": ['cae', 'cped', 'mw'],
    "lekhakamuktāmaṇi": ['mw'],
    "lekhakapramāda": ['mw'],
    "lekhakaḥ": ['ap90'],
    "lekhalipi": ['bhs'],
    "lekhamukha": ['cped'],
    "lekhana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "lekhanasādhana": ['cae', 'mw'],
    "lekhanavasti": ['mw'],
    "lekhani": ['mw'],
    "lekhanika": ['mw'],
    "lekhanikaḥ": ['ap90'],
    "lekhanikā": ['mw'],
    "lekhanā": ['bhs'],
    "lekhanī": ['cped', 'mw'],
    "lekhanīya": ['cae', 'mw'],
    "lekhapattra": ['cae', 'mw'],
    "lekhapattrikā": ['mw'],
    "lekhapat‍tra": ['ddsa'],
    "lekhapañcāśikā": ['mw'],
    "lekhapratilekhalipi": ['mw'],
    "lekharṣabha": ['mw'],
    "lekhasaṃdeśahārin": ['mw'],
    "lekhasādhana": ['cae', 'mw'],
    "lekhaśālika": ['mw'],
    "lekhaśālā": ['mw'],
    "lekhaḥ": ['ap90'],
    "lekheśa": ['mw'],
    "lekhikā": ['cped', 'ddsa', 'mw'],
    "lekhin": ['cae', 'mw'],
    "lekhinī": ['ap90'],
    "lekhita": ['mw'],
    "lekhiṇī": ['mw'],
    "lekhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "lekhyacūrṇikā": ['mw'],
    "lekhyadala": ['mw'],
    "lekhyagata": ['cae', 'mw'],
    "lekhyaka": ['mw'],
    "lekhyakṛta": ['mw'],
    "lekhyamaya": ['mw'],
    "lekhyapadma": ['mw'],
    "lekhyapattra": ['mw'],
    "lekhyapattraka": ['mw'],
    "lekhyaprasaṅga": ['mw'],
    "lekhyarūpa": ['mw'],
    "lekhyasthāna": ['mw'],
    "lekhyārūḍha": ['mw'],
    "lekhā": ['ap90', 'cped', 'ddsa', 'mw'],
    "lekhābhra": ['mw'],
    "lekhābhru": ['mw'],
    "lekhābhrummanya": ['mw'],
    "lekhābhrū": ['mw'],
    "lekhādhikārin": ['mw'],
    "lekhākṣara": ['mw'],
    "lekhārambha": ['mw'],
    "lekhārha": ['mw'],
    "lekhārhya": ['mw'],
    "lekhāsaṃdhi": ['mw'],
    "lekhāsthavṛtta": ['mw'],
    "lekhāvalaya": ['mw'],
    "lekhāvidhi": ['cae', 'mw'],
    "lekhāya": ['mw'],
    "lekhāyati": ['ap90'],
    "lekhīlaka": ['mw'],
    "lekuñcika": ['bhs', 'mw'],
    "lelayā": ['cae'],
    "leliha": ['cae', 'mw'],
    "lelihaḥ": ['ap90'],
    "lelihā": ['mw'],
    "lelihāna": ['cae', 'ddsa', 'mw'],
    "lelihānaḥ": ['ap90'],
    "lelihānā": ['mw'],
    "lelitaka": ['mw'],
    "lelohita": ['bhs'],
    "lelya": ['mw'],
    "lelā": ['mw'],
    "lelāya": ['mw'],
    "lelāyamānā": ['ap90', 'mw'],
    "lelītaka": ['mw'],
    "lena": ['bhs'],
    "lep": ['ap90', 'mw'],
    "lepa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "lepabhuj": ['mw'],
    "lepabhāgin": ['cae', 'mw'],
    "lepaka": ['bhs', 'mw'],
    "lepakara": ['mw'],
    "lepakaḥ": ['ap90'],
    "lepakāminī": ['mw'],
    "lepana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "lepanaḥ": ['ap90'],
    "lepanīya": ['mw'],
    "lepaḥ": ['ap90'],
    "lepenta": ['cped'],
    "lepesi": ['cped'],
    "lepeti": ['cped'],
    "lepetvā": ['cped'],
    "lepin": ['ap90', 'cae', 'mw'],
    "lepita": ['cped'],
    "lepya": ['ap90', 'cae', 'mw'],
    "lepyakāra": ['mw'],
    "lepyakṛt": ['mw'],
    "lepyamaya": ['mw'],
    "lepyamayī": ['ap90', 'mw'],
    "lepyanārī": ['mw'],
    "lepyastrī": ['mw'],
    "lepyayoṣit": ['mw'],
    "lesa": ['cped'],
    "lesaka": ['mw'],
    "lesika": ['mw'],
    "lesikaḥ": ['ap90'],
    "leta": ['mw'],
    "letaḥ": ['ap90'],
    "levāra": ['ddsa', 'mw'],
    "leya": ['bhs', 'mw'],
    "leyaḥ": ['ap90'],
    "leyya": ['cped'],
    "leśa": ['cae', 'ddsa', 'mw'],
    "leśaḥ": ['ap90'],
    "leśi": ['bhs'],
    "leśika": ['ddsa', 'mw'],
    "leśin": ['mw'],
    "leśokta": ['mw'],
    "leśya": ['cae', 'ddsa', 'mw'],
    "leśyā": ['ap90', 'cae'],
    "leḍhṛ": ['mw'],
    "leḍu": ['bhs'],
    "leḍḍu": ['cped'],
    "leḍḍupāta": ['cped'],
    "leṃḍaṃ": ['ap90'],
    "leṇa": ['cped'],
    "leṇḍa": ['cae', 'ddsa', 'mw'],
    "leṣṭavya": ['mw'],
    "leṣṭaḥ": ['ap90'],
    "leṣṭu": ['cae', 'ddsa', 'mw'],
    "leṣṭubhedana": ['mw'],
    "leṣṭughna": ['mw'],
    "leṣṭukā": ['cae', 'mw'],
    "leṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "leṭa": ['cae', 'mw'],
    "leṭya": ['mw'],
    "leṭyati": ['ap90'],
    "li": ['mw'],
    "libi": ['mw'],
    "libiḥ": ['ap90'],
    "libiṃkaraḥ": ['ap90'],
    "libujā": ['cae', 'ddsa', 'gra', 'mw'],
    "licchavi": ['bhs', 'mw'],
    "licchivi": ['cae', 'mw'],
    "lidhu": ['ap90', 'mw'],
    "ligu": ['mw'],
    "liguḥ": ['ap90'],
    "ligī": ['mw'],
    "lih": ['ap90', 'cae', 'ddsa', 'mw'],
    "liha": ['cae', 'mw'],
    "lihamāna": ['cped'],
    "lihati": ['cped'],
    "lihi": ['cped'],
    "lihimāna": ['cped'],
    "lihitvā": ['cped'],
    "likh": ['ap90', 'cae', 'ddsa', 'mw'],
    "likha": ['mw'],
    "likhana": ['cae', 'cped', 'ddsa', 'mw'],
    "likhanaṃ": ['ap90'],
    "likhanta": ['cped'],
    "likhati": ['cped'],
    "likhi": ['cped'],
    "likhikhilla": ['mw'],
    "likhita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "likhitaka": ['bhs', 'cped'],
    "likhitapāṭha": ['mw'],
    "likhitapāṭhaka": ['mw'],
    "likhitarudra": ['mw'],
    "likhitasmṛti": ['mw'],
    "likhitatva": ['cae', 'mw'],
    "likhitavya": ['ddsa', 'mw'],
    "likhituṁ": ['cped'],
    "likhitvā": ['cped'],
    "likhitṛ": ['cae', 'mw'],
    "likhya": ['cae', 'mw'],
    "likhyaḥ": ['ap90'],
    "likhāpesi": ['cped'],
    "likhāpeti": ['cped'],
    "likhāpetvā": ['cped'],
    "likkhā": ['cped'],
    "likuca": ['cped', 'mw'],
    "likucaḥ": ['ap90'],
    "likuci": ['mw'],
    "likṣa": ['cae'],
    "likṣikā": ['ap90', 'mw'],
    "likṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "lilakṣayiṣita": ['mw'],
    "limbabhaṭṭa": ['mw'],
    "limpa": ['mw'],
    "limpana": ['cped'],
    "limpati": ['cped'],
    "limpaṭa": ['mw'],
    "limpenta": ['cped'],
    "limpesi": ['cped'],
    "limpeti": ['cped'],
    "limpetvā": ['cped'],
    "limpi": ['cae', 'cped', 'ddsa', 'mw'],
    "limpita": ['cped'],
    "limpitvā": ['cped'],
    "limpāka": ['mw'],
    "limpāpeti": ['cped'],
    "lindu": ['cae', 'mw'],
    "linduma": ['mw'],
    "lip": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "lipa": ['mw'],
    "lipaḥ": ['ap90'],
    "lipi": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "lipijña": ['mw'],
    "lipijñāna": ['mw'],
    "lipika": ['bhs', 'mw'],
    "lipikara": ['cae', 'ddsa', 'mw'],
    "lipikarman": ['mw'],
    "lipikarmanirmita": ['mw'],
    "lipikā": ['ap90', 'mw'],
    "lipikāra": ['cped', 'mw'],
    "lipinyāsa": ['cae', 'mw'],
    "lipiphalaka": ['mw'],
    "lipisajjā": ['mw'],
    "lipisaṃkhyā": ['mw'],
    "lipisaṃnāha": ['mw'],
    "lipitva": ['mw'],
    "lipiviveka": ['mw'],
    "lipiśālā": ['mw'],
    "lipiśāstra": ['mw'],
    "lipiḥ": ['ap90'],
    "lipsita": ['mw'],
    "lipsitavya": ['mw'],
    "lipsu": ['ap90', 'cae', 'mw'],
    "lipsutā": ['mw'],
    "lipsya": ['mw'],
    "lipsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "lipta": ['ap90', 'cae', 'mw'],
    "liptahasta": ['mw'],
    "liptaka": ['mw'],
    "liptakaḥ": ['ap90'],
    "liptavat": ['mw'],
    "liptavāsita": ['mw'],
    "lipti": ['cae', 'ddsa', 'mw'],
    "liptikā": ['mw'],
    "liptā": ['ap90', 'mw'],
    "liptāṅga": ['mw'],
    "liptīkṛ": ['mw'],
    "litta": ['cped'],
    "livi": ['mw'],
    "livikara": ['mw'],
    "liviṃkara": ['mw'],
    "liś": ['ap90', 'cae', 'ddsa', 'mw'],
    "liśa": ['mw'],
    "liḥ": ['ap90'],
    "liṃdu": ['ap90'],
    "liṃg": ['ap90'],
    "liṃgakaḥ": ['ap90'],
    "liṃganaṃ": ['ap90'],
    "liṃgavat": ['ap90'],
    "liṃgaṃ": ['ap90'],
    "liṃgin": ['ap90'],
    "liṃkh": ['ap90'],
    "liṃpaḥ": ['ap90'],
    "liṃpaṭa": ['ap90'],
    "liṃpiḥ": ['ap90'],
    "liṃpākaḥ": ['ap90'],
    "liṅ": ['ap90', 'cae', 'ddsa', 'mw'],
    "liṅarthavicāra": ['mw'],
    "liṅarthavāda": ['mw'],
    "liṅg": ['cae', 'ddsa', 'mw'],
    "liṅga": ['cae', 'cped', 'ddsa', 'mw'],
    "liṅgabhaṭṭa": ['mw'],
    "liṅgabhaṭṭīya": ['mw'],
    "liṅgabhāṣāpurāṇa": ['mw'],
    "liṅgacaraṇabhāṣya": ['mw'],
    "liṅgadeha": ['cae', 'mw'],
    "liṅgadhara": ['cae', 'mw'],
    "liṅgadhāraṇa": ['cae', 'mw'],
    "liṅgadhāraṇacandrikā": ['mw'],
    "liṅgadhāraṇadīpikā": ['mw'],
    "liṅgadhārin": ['mw'],
    "liṅgadhāriṇī": ['mw'],
    "liṅgadurbheda": ['mw'],
    "liṅgadvādaśavrata": ['mw'],
    "liṅgaguṇṭamarāma": ['mw'],
    "liṅgahanī": ['mw'],
    "liṅgaja": ['mw'],
    "liṅgajyeṣṭha": ['mw'],
    "liṅgajā": ['mw'],
    "liṅgaka": ['mw'],
    "liṅgakāraṇatāpūrvapakṣarahasya": ['mw'],
    "liṅgakāraṇatāsiddhāntarahasya": ['mw'],
    "liṅgakāraṇatāvāda": ['mw'],
    "liṅgakāraṇavāda": ['mw'],
    "liṅgakārikā": ['mw'],
    "liṅgakārikāvṛtti": ['mw'],
    "liṅgakḷpta": ['mw'],
    "liṅgalepa": ['mw'],
    "liṅgalīlāvilāsacaritra": ['mw'],
    "liṅgamāhātmya": ['mw'],
    "liṅgamāhātmyadīpikā": ['mw'],
    "liṅgamātra": ['mw'],
    "liṅgamūrti": ['mw'],
    "liṅgana": ['mw'],
    "liṅganirṇaya": ['mw'],
    "liṅganirṇayabhūṣaṇa": ['mw'],
    "liṅganāśa": ['mw'],
    "liṅgaparivattana": ['cped'],
    "liṅgaparāmarśa": ['mw'],
    "liṅgaprakāśa": ['mw'],
    "liṅgapratiṣṭhā": ['mw'],
    "liṅgapratiṣṭhāpaddhati": ['mw'],
    "liṅgapratiṣṭhāvidhi": ['mw'],
    "liṅgapurāṇa": ['cae', 'mw'],
    "liṅgapīṭha": ['mw'],
    "liṅgapūjodyāpana": ['mw'],
    "liṅgapūjāpaddhati": ['mw'],
    "liṅgapūjāphala": ['mw'],
    "liṅgasambhūtā": ['mw'],
    "liṅgastha": ['cae', 'mw'],
    "liṅgatas": ['mw'],
    "liṅgatobhadra": ['mw'],
    "liṅgatobhadrakārikā": ['mw'],
    "liṅgatobhadralakṣaṇa": ['mw'],
    "liṅgatobhadraprayoga": ['mw'],
    "liṅgatva": ['mw'],
    "liṅgavant": ['cae'],
    "liṅgavardhana": ['mw'],
    "liṅgavardhin": ['mw'],
    "liṅgavardhiṇī": ['mw'],
    "liṅgavarti": ['mw'],
    "liṅgavat": ['ddsa', 'mw'],
    "liṅgavedī": ['mw'],
    "liṅgavidhi": ['mw'],
    "liṅgavipallāsa": ['cped'],
    "liṅgaviparyaya": ['mw'],
    "liṅgaviśeṣavidhi": ['mw'],
    "liṅgaviśeṣaṇa": ['mw'],
    "liṅgavāda": ['mw'],
    "liṅgavṛtti": ['mw'],
    "liṅgaya": ['ddsa'],
    "liṅgayasūri": ['mw'],
    "liṅgaśarīra": ['cae', 'mw'],
    "liṅgaśopha": ['mw'],
    "liṅgaśāstra": ['mw'],
    "liṅgika": ['cped', 'mw'],
    "liṅgikā": ['mw'],
    "liṅgin": ['cae', 'ddsa', 'mw'],
    "liṅginī": ['mw'],
    "liṅgita": ['bhs', 'mw'],
    "liṅgiveṣa": ['cae', 'mw'],
    "liṅgiya": ['cped'],
    "liṅgoddhāra": ['ddsa', 'mw'],
    "liṅgopadaṃśa": ['mw'],
    "liṅgopadhānavādārtha": ['mw'],
    "liṅgopahitalaiṅgikabhānanirāsarahasya": ['mw'],
    "liṅgopahitalaiṅgikabhānavicāra": ['mw'],
    "liṅgopahitalaiṅgikavādārtha": ['mw'],
    "liṅgopaniṣad": ['mw'],
    "liṅgotpatti": ['mw'],
    "liṅgya": ['mw'],
    "liṅgābhaṭṭīya": ['mw'],
    "liṅgādipratiṣṭhāvidhi": ['mw'],
    "liṅgāgamatantra": ['mw'],
    "liṅgāgra": ['mw'],
    "liṅgālikā": ['mw'],
    "liṅgānuśāsana": ['cae', 'mw'],
    "liṅgānuśāsanavṛtti": ['mw'],
    "liṅgārcana": ['mw'],
    "liṅgārcanacandrikā": ['mw'],
    "liṅgārcanatantra": ['mw'],
    "liṅgārcāpratiṣṭhāvidhi": ['mw'],
    "liṅgārśas": ['mw'],
    "liṅgāṣṭaka": ['mw'],
    "liṅkavārāhatīrtha": ['mw'],
    "liṅkh": ['mw'],
    "liṣva": ['mw'],
    "liṣvaḥ": ['ap90'],
    "liṣṭa": ['ap90', 'mw'],
    "liṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "liṭya": ['mw'],
    "lo": ['mw'],
    "lobha": ['cae', 'cped', 'ddsa', 'mw'],
    "lobhamañjarī": ['ddsa', 'mw'],
    "lobhamohita": ['mw'],
    "lobhamūlaka": ['cped'],
    "lobhana": ['ap90', 'cae', 'mw'],
    "lobhanī": ['mw'],
    "lobhanīya": ['ap90', 'cae', 'cped', 'mw'],
    "lobhanīyatama": ['mw'],
    "lobhanīyatamākṛti": ['mw'],
    "lobhatas": ['mw'],
    "lobhaviraha": ['cae', 'mw'],
    "lobhayāna": ['mw'],
    "lobhaśūnya": ['mw'],
    "lobhaśūnyatva": ['mw'],
    "lobhaḥ": ['ap90'],
    "lobhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "lobhita": ['ap90', 'mw'],
    "lobhitavat": ['mw'],
    "lobhitā": ['mw'],
    "lobhopahatacetas": ['ddsa'],
    "lobhotkarṣa": ['mw'],
    "lobhya": ['mw'],
    "lobhābhipātin": ['mw'],
    "lobhākṛṣṭa": ['mw'],
    "lobhānvita": ['mw'],
    "lobhātman": ['mw'],
    "lobhāyana": ['mw'],
    "loc": ['ap90', 'cae', 'ddsa', 'mw'],
    "loca": ['mw'],
    "locaka": ['cped', 'ddsa', 'mw'],
    "locakaḥ": ['ap90'],
    "locamarkaṭa": ['mw'],
    "locamastaka": ['mw'],
    "locamālaka": ['mw'],
    "locana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "locanagocara": ['cae', 'mw'],
    "locanahita": ['mw'],
    "locanahitā": ['mw'],
    "locanaka": ['bhs'],
    "locanakāra": ['mw'],
    "locanamaya": ['mw'],
    "locanamārga": ['mw'],
    "locanaparuṣa": ['mw'],
    "locanapatha": ['cae', 'mw'],
    "locanapāta": ['mw'],
    "locanatrayapatha": ['cae', 'mw'],
    "locanotsa": ['mw'],
    "locanoḍḍāraka": ['mw'],
    "locanā": ['bhs'],
    "locanāmaya": ['mw'],
    "locanānanda": ['cae', 'mw'],
    "locanāpāta": ['mw'],
    "locanāñcala": ['cae', 'mw'],
    "locanī": ['mw'],
    "locaṃ": ['ap90'],
    "locikā": ['mw'],
    "lodha": ['cae', 'gra', 'mw'],
    "lodhaḥ": ['ap90'],
    "lodhra": ['cae', 'ddsa', 'mw'],
    "lodhraka": ['mw'],
    "lodhraprasavarajas": ['mw'],
    "lodhrapuṣpa": ['mw'],
    "lodhratilaka": ['mw'],
    "lodī": ['mw'],
    "loga": ['cae', 'ddsa', 'gra', 'mw'],
    "logaḥ": ['ap90'],
    "logeṣṭakā": ['mw'],
    "logākṣa": ['mw'],
    "loha": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "lohabaddha": ['mw'],
    "lohabhaṇḍa": ['cped'],
    "lohabhāraka": ['mw'],
    "lohacarmavat": ['mw'],
    "lohacumbakanyāya": ['mw'],
    "lohacāraka": ['cae', 'mw'],
    "lohacāriṇī": ['mw'],
    "lohacūrṇa": ['mw'],
    "lohadaṇḍa": ['cae', 'mw'],
    "lohadhātu": ['cae'],
    "lohadrāvin": ['mw'],
    "lohadāraka": ['mw'],
    "lohaghātaka": ['mw'],
    "lohagiri": ['mw'],
    "lohagolakhaṇḍana": ['mw'],
    "lohaguḷa": ['cped'],
    "lohaja": ['cae', 'mw'],
    "lohajaṅgha": ['mw'],
    "lohajit": ['mw'],
    "lohajāla": ['cped', 'mw'],
    "lohaka": ['mw'],
    "lohakaṇṭaka": ['mw'],
    "lohakaṭaka": ['mw'],
    "lohakaṭāha": ['cped'],
    "lohakiṭṭa": ['mw'],
    "lohakumbhī": ['cped'],
    "lohakānta": ['mw'],
    "lohakāntaka": ['mw'],
    "lohakāra": ['cped', 'mw'],
    "lohakārabhastrā": ['mw'],
    "lohakāraka": ['mw'],
    "lohakārī": ['mw'],
    "lohakārṣāpaṇa": ['mw'],
    "lohakīla": ['mw'],
    "lohala": ['ap90', 'mw'],
    "lohalekhya": ['mw'],
    "lohaliṅga": ['bhs', 'mw'],
    "lohamala": ['mw'],
    "lohamaya": ['cae', 'cped', 'mw'],
    "lohamekhala": ['mw'],
    "lohamekhalā": ['mw'],
    "lohamukha": ['mw'],
    "lohamuktikā": ['mw'],
    "lohamālaka": ['mw'],
    "lohamāraka": ['mw'],
    "lohamāsaka": ['cped'],
    "lohamātra": ['mw'],
    "lohanagara": ['mw'],
    "lohanāla": ['mw'],
    "lohapaṭṭikā": ['mw'],
    "lohapiṇḍa": ['cped'],
    "lohapratimā": ['mw'],
    "lohapura": ['mw'],
    "lohapāsāda": ['cped'],
    "lohapāśa": ['mw'],
    "lohapṛṣṭha": ['mw'],
    "lohara": ['ddsa', 'mw'],
    "loharajas": ['ddsa', 'mw'],
    "loharatnākara": ['mw'],
    "lohari": ['bhs'],
    "loharājaka": ['mw'],
    "lohasalakā": ['cped'],
    "lohasaṃkara": ['mw'],
    "lohasaṃśleṣaka": ['mw'],
    "lohasiṃhānikā": ['mw'],
    "lohastha": ['mw'],
    "lohatatuppādaka": ['cped'],
    "lohathālaka": ['cped'],
    "lohatāraṇī": ['mw'],
    "lohatāriṇī": ['mw'],
    "lohavant": ['cae'],
    "lohavara": ['mw'],
    "lohavarman": ['mw'],
    "lohavat": ['mw'],
    "lohavāla": ['mw'],
    "lohayaṣṭī": ['mw'],
    "lohaśayana": ['mw'],
    "lohaśaṅku": ['cae', 'mw'],
    "lohaśleṣaṇa": ['mw'],
    "lohaśuddhikara": ['mw'],
    "lohaśāstra": ['mw'],
    "lohaśṛṅkhala": ['mw'],
    "lohi": ['mw'],
    "lohikā": ['ap90', 'mw'],
    "lohinikā": ['mw'],
    "lohinya": ['mw'],
    "lohinī": ['ap90', 'cae', 'ddsa', 'mw'],
    "lohinīkā": ['mw'],
    "lohita": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "lohitabhakkha": ['cped'],
    "lohitabinducitra": ['mw'],
    "lohitacandana": ['cped', 'mw'],
    "lohitadalā": ['mw'],
    "lohitadarśana": ['mw'],
    "lohitadhvaja": ['mw'],
    "lohitadrapsa": ['mw'],
    "lohitagaṅga": ['mw'],
    "lohitagaṅgaka": ['mw'],
    "lohitagaṅgam": ['mw'],
    "lohitagrīva": ['cae', 'mw'],
    "lohitagātra": ['mw'],
    "lohitaita": ['mw'],
    "lohitajahnu": ['mw'],
    "lohitaka": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "lohitakalmāṣa": ['mw'],
    "lohitakkha": ['cped'],
    "lohitakopadhāna": ['bhs'],
    "lohitakā": ['bhs'],
    "lohitakūṭa": ['mw'],
    "lohitakṛtsna": ['mw'],
    "lohitakṛṣṇa": ['cae', 'mw'],
    "lohitakṛṣṇavarṇa": ['mw'],
    "lohitakṣaya": ['mw'],
    "lohitakṣayaka": ['mw'],
    "lohitakṣīra": ['mw'],
    "lohitalavaṇa": ['mw'],
    "lohitamaya": ['mw'],
    "lohitamiśra": ['mw'],
    "lohitamukti": ['mw'],
    "lohitamuktā": ['bhs'],
    "lohitamṛttikā": ['mw'],
    "lohitanayana": ['mw'],
    "lohitanyāyatana": ['bhs'],
    "lohitapacanīya": ['mw'],
    "lohitapakkhandikā": ['cped'],
    "lohitapittin": ['mw'],
    "lohitapiṇḍa": ['mw'],
    "lohitapravāṇa": ['mw'],
    "lohitapura": ['mw'],
    "lohitapuṣpa": ['mw'],
    "lohitapuṣpaka": ['mw'],
    "lohitapuṣpī": ['mw'],
    "lohitapādaka": ['mw'],
    "lohitapāddeśa": ['mw'],
    "lohitapātra": ['mw'],
    "lohitapāṃsu": ['mw'],
    "lohitarasa": ['mw'],
    "lohitarāga": ['mw'],
    "lohitasmṛti": ['mw'],
    "lohitastoka": ['mw'],
    "lohitasāraṅga": ['mw'],
    "lohitati": ['ap90'],
    "lohitatva": ['mw'],
    "lohitatā": ['mw'],
    "lohitatūla": ['mw'],
    "lohitavant": ['cae'],
    "lohitavarṣa": ['mw'],
    "lohitavastuka": ['bhs'],
    "lohitavat": ['mw'],
    "lohitavāsas": ['cae', 'mw'],
    "lohitaśabala": ['mw'],
    "lohitaśatapattra": ['mw'],
    "lohitaśuklakṛṣṇa": ['mw'],
    "lohitaṅka": ['cped'],
    "lohitekṣaṇa": ['mw'],
    "lohitekṣu": ['mw'],
    "lohitikā": ['bhs'],
    "lohitiman": ['ap90', 'ddsa', 'mw'],
    "lohitoda": ['ddsa', 'mw'],
    "lohitorṇa": ['cae', 'mw'],
    "lohitotpala": ['mw'],
    "lohitoṣṇīṣa": ['mw'],
    "lohitoṣṇīṣatā": ['mw'],
    "lohituppādaka": ['cped'],
    "lohitya": ['mw'],
    "lohityaḥ": ['ap90'],
    "lohityā": ['mw'],
    "lohitā": ['mw'],
    "lohitāda": ['mw'],
    "lohitādhipa": ['mw'],
    "lohitāgiri": ['mw'],
    "lohitāhi": ['mw'],
    "lohitāja": ['mw'],
    "lohitājā": ['mw'],
    "lohitākṣa": ['bhs', 'cae', 'mw'],
    "lohitākṣaka": ['mw'],
    "lohitākṣasaṃjñā": ['mw'],
    "lohitākṣī": ['bhs', 'mw'],
    "lohitālaṃkṛta": ['mw'],
    "lohitālu": ['mw'],
    "lohitāmukhī": ['mw'],
    "lohitānana": ['mw'],
    "lohitāraṇī": ['mw'],
    "lohitārcis": ['mw'],
    "lohitārdra": ['ddsa', 'mw'],
    "lohitārman": ['mw'],
    "lohitārṇa": ['mw'],
    "lohitāsya": ['mw'],
    "lohitāvabhāsa": ['mw'],
    "lohitāy": ['cae'],
    "lohitāya": ['ddsa', 'mw'],
    "lohitāyana": ['mw'],
    "lohitāyani": ['mw'],
    "lohitāyas": ['mw'],
    "lohitāyasa": ['cae', 'mw'],
    "lohitāśoka": ['mw'],
    "lohitāśva": ['mw'],
    "lohitāśvattha": ['mw'],
    "lohitāṅga": ['cae', 'mw'],
    "lohitībhū": ['mw'],
    "lohitīka": ['mw'],
    "lohottama": ['mw'],
    "lohya": ['mw'],
    "lohābhihāra": ['mw'],
    "lohābhisāra": ['mw'],
    "lohācala": ['mw'],
    "lohācalamāhātmya": ['mw'],
    "lohācārya": ['mw'],
    "lohāja": ['ddsa', 'mw'],
    "lohājavaktra": ['mw'],
    "lohākara": ['mw'],
    "lohākhya": ['mw'],
    "lohāmiṣa": ['mw'],
    "lohārgala": ['mw'],
    "lohārya": ['mw'],
    "lohārṇava": ['mw'],
    "lohāsava": ['mw'],
    "lohāsuramāhātmya": ['mw'],
    "lohāyasa": ['cae', 'mw'],
    "lohāṅgāraka": ['mw'],
    "lohāṇḍa": ['mw'],
    "lohāṣṭhīlā": ['cae'],
    "lohī": ['bhs', 'mw'],
    "lok": ['ap90', 'cae', 'ddsa', 'mw'],
    "loka": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "lokabandhu": ['mw'],
    "lokabhartṛ": ['mw'],
    "lokabhāj": ['mw'],
    "lokabhāskara": ['mw'],
    "lokabhāvana": ['cae', 'mw'],
    "lokabhāvin": ['mw'],
    "lokabindusāra": ['mw'],
    "lokabāhya": ['mw'],
    "lokabāndhava": ['mw'],
    "lokacakṣus": ['mw'],
    "lokacara": ['cae', 'mw'],
    "lokacarita": ['cae'],
    "lokacārin": ['cae', 'mw'],
    "lokacāritra": ['cae', 'mw'],
    "lokadambhaka": ['cae', 'mw'],
    "lokadhara": ['bhs'],
    "lokadharma": ['bhs', 'mw'],
    "lokadhāriṇī": ['mw'],
    "lokadhātu": ['bhs', 'cped', 'mw'],
    "lokadhātvīśvarī": ['mw'],
    "lokadhātṛ": ['cae', 'mw'],
    "lokadvaya": ['cae', 'mw'],
    "lokadvāra": ['cae', 'mw'],
    "lokadvārīya": ['mw'],
    "lokadūṣaṇa": ['mw'],
    "lokagati": ['bhs', 'mw'],
    "lokagga": ['cped'],
    "lokaguru": ['bhs', 'mw'],
    "lokagāthā": ['mw'],
    "lokahita": ['cae', 'mw'],
    "lokahāsya": ['mw'],
    "lokahāsyatā": ['mw'],
    "lokaikabandhu": ['mw'],
    "lokaiṣaṇā": ['cae', 'mw'],
    "lokajananī": ['mw'],
    "lokaji": ['bhs'],
    "lokajit": ['cae', 'mw'],
    "lokajyeṣṭha": ['bhs', 'mw'],
    "lokajña": ['cae', 'mw'],
    "lokajñatā": ['mw'],
    "lokakalpa": ['mw'],
    "lokakartṛ": ['cae', 'mw'],
    "lokakathā": ['mw'],
    "lokakaṇṭaka": ['cae', 'ddsa', 'mw'],
    "lokakāma": ['cae', 'mw'],
    "lokakāmyā": ['mw'],
    "lokakānta": ['cae', 'mw'],
    "lokakāntā": ['mw'],
    "lokakāra": ['cae', 'mw'],
    "lokakāraṇakaraṇa": ['mw'],
    "lokakṛt": ['cae', 'gra', 'mw'],
    "lokakṛtnu": ['gra', 'mw'],
    "lokakṣetriya": ['bhs'],
    "lokakṣit": ['cae', 'mw'],
    "lokalekha": ['mw'],
    "lokalocana": ['mw'],
    "lokalocanāpāta": ['mw'],
    "lokamaheśvara": ['mw'],
    "lokamahādevī": ['mw'],
    "lokamanoramā": ['mw'],
    "lokamaryādā": ['mw'],
    "lokamaya": ['cae', 'mw'],
    "lokampṛṇa": ['ddsa', 'mw'],
    "lokampṛṇā": ['mw'],
    "lokamārga": ['cae', 'mw'],
    "lokamātṛ": ['mw'],
    "lokamātṛkā": ['mw'],
    "lokana": ['mw'],
    "lokanaṃ": ['ap90'],
    "lokanetṛ": ['mw'],
    "lokanindita": ['mw'],
    "lokanirodha": ['cped'],
    "lokaniṣṭha": ['bhs'],
    "lokanta": ['cped'],
    "lokantagū": ['cped'],
    "lokantara": ['cped'],
    "lokantarika": ['cped'],
    "lokanyāyāmṛta": ['mw'],
    "lokanātha": ['bhs', 'cae', 'cped', 'mw'],
    "lokanāthabhaṭṭa": ['mw'],
    "lokanāthacakravartin": ['mw'],
    "lokanātharasa": ['mw'],
    "lokanāthavyākaraṇa": ['bhs'],
    "lokanāthaśarman": ['mw'],
    "lokanāyaka": ['cped', 'mw'],
    "lokanīya": ['mw'],
    "lokapa": ['cae', 'mw'],
    "lokapaddhati": ['mw'],
    "lokapadma": ['bhs'],
    "lokapakti": ['mw'],
    "lokaparitrātar": ['bhs'],
    "lokaparokṣa": ['mw'],
    "lokapatha": ['mw'],
    "lokapati": ['bhs', 'cae', 'mw'],
    "lokapaṅkti": ['mw'],
    "lokapitāmaha": ['mw'],
    "lokapradīpa": ['bhs', 'mw'],
    "lokapradīpānvayacandrikānidāna": ['mw'],
    "lokaprakāśa": ['mw'],
    "lokaprakāśaka": ['mw'],
    "lokaprakāśana": ['mw'],
    "lokaprasiddha": ['mw'],
    "lokaprasiddhi": ['mw'],
    "lokaprasiddhyā": ['mw'],
    "lokapratyaya": ['mw'],
    "lokapravāda": ['cae', 'mw'],
    "lokapravāhin": ['mw'],
    "lokapriya": ['bhs'],
    "lokapuruṣa": ['mw'],
    "lokapuṇya": ['mw'],
    "lokapāla": ['cae', 'cped', 'mw'],
    "lokapālaka": ['mw'],
    "lokapālarājan": ['bhs'],
    "lokapālatva": ['mw'],
    "lokapālatā": ['mw'],
    "lokapālinī": ['mw'],
    "lokapālāṣṭakadāna": ['mw'],
    "lokapārya": ['mw'],
    "lokapūjita": ['bhs', 'mw'],
    "lokarakṣa": ['mw'],
    "lokarakṣādhirāja": ['mw'],
    "lokarava": ['mw'],
    "lokarañjana": ['cae', 'mw'],
    "lokasampanna": ['mw'],
    "lokasani": ['mw'],
    "lokasaṃgraha": ['cae', 'mw'],
    "lokasaṃgrāhin": ['mw'],
    "lokasaṃkara": ['mw'],
    "lokasaṃkṣaya": ['mw'],
    "lokasaṃskṛta": ['mw'],
    "lokasaṃsṛti": ['mw'],
    "lokasaṃvyavahāra": ['mw'],
    "lokasaṃvyavahāranāmakāṅka": ['mw'],
    "lokasaṃvṛtti": ['mw'],
    "lokasiddha": ['mw'],
    "lokasmṛt": ['mw'],
    "lokaspṛt": ['mw'],
    "lokasthala": ['mw'],
    "lokasthiti": ['mw'],
    "lokasundara": ['bhs', 'mw'],
    "lokasādhaka": ['mw'],
    "lokasādhāraṇa": ['mw'],
    "lokasāgara": ['mw'],
    "lokasākṣi": ['mw'],
    "lokasākṣika": ['cae', 'mw'],
    "lokasākṣikam": ['mw'],
    "lokasākṣin": ['mw'],
    "lokasāman": ['mw'],
    "lokasāraṅga": ['mw'],
    "lokasāt": ['mw'],
    "lokasātkṛ": ['ddsa'],
    "lokasātkṛta": ['mw'],
    "lokasīmānurodhin": ['mw'],
    "lokasīmātivartin": ['mw'],
    "lokatantra": ['cae', 'mw'],
    "lokatas": ['cae', 'mw'],
    "lokatattva": ['mw'],
    "lokatraya": ['cae', 'mw'],
    "lokatuṣāra": ['mw'],
    "lokatā": ['mw'],
    "lokavacana": ['cae', 'mw'],
    "lokavajja": ['cped'],
    "lokavant": ['cae'],
    "lokavartana": ['mw'],
    "lokavat": ['mw'],
    "lokavid": ['bhs', 'cae', 'mw'],
    "lokavidhi": ['mw'],
    "lokavidviṣṭa": ['cae', 'mw'],
    "lokavijita": ['bhs'],
    "lokavijñāta": ['cae', 'mw'],
    "lokavikruṣṭa": ['mw'],
    "lokavindu": ['mw'],
    "lokavināyaka": ['mw'],
    "lokavirodha": ['mw'],
    "lokavirodhin": ['mw'],
    "lokaviruddha": ['mw'],
    "lokavisarga": ['mw'],
    "lokavisargika": ['mw'],
    "lokavisargin": ['mw'],
    "lokavistāra": ['mw'],
    "lokavivaraṇa": ['cped'],
    "lokaviśruta": ['cae', 'mw'],
    "lokaviśruti": ['mw'],
    "lokavohāra": ['cped'],
    "lokavrata": ['mw'],
    "lokavyavahāra": ['cae', 'mw'],
    "lokavāda": ['mw'],
    "lokavādhin": ['mw'],
    "lokavārttā": ['mw'],
    "lokavīra": ['mw'],
    "lokavṛtta": ['cae', 'mw'],
    "lokavṛttānta": ['mw'],
    "lokayātrika": ['mw'],
    "lokayātrā": ['cae', 'ddsa', 'mw'],
    "lokaśabda": ['mw'],
    "lokaśreṣṭha": ['cae', 'mw'],
    "lokaśruti": ['mw'],
    "lokaḥ": ['ap90'],
    "lokaṃdhara": ['bhs'],
    "lokaṃpṛṇa": ['ap90', 'cae'],
    "lokendra": ['bhs', 'mw'],
    "lokendraghoṣa": ['bhs'],
    "lokendrakāyapratibhāsaprabha": ['bhs'],
    "lokendrapravaraprabhaghoṣa": ['bhs'],
    "lokendrarāja": ['bhs'],
    "lokendrateja": ['bhs'],
    "lokesa": ['cped'],
    "lokeśa": ['cae', 'ddsa', 'mw'],
    "lokeśakara": ['mw'],
    "lokeśaprabhavāpyaya": ['mw'],
    "lokeśvara": ['bhs', 'cae', 'mw'],
    "lokeśvararāja": ['bhs'],
    "lokeśvaraśataka": ['mw'],
    "lokeśvarātmajā": ['mw'],
    "lokeṣṭakā": ['mw'],
    "lokeṣṭi": ['mw'],
    "lokika": ['bhs', 'cped'],
    "lokin": ['cae', 'mw'],
    "lokinī": ['bhs'],
    "lokita": ['mw'],
    "lokiya": ['cped'],
    "lokoddhāra": ['mw'],
    "lokoktamuktāvalī": ['mw'],
    "lokokti": ['cae', 'mw'],
    "lokopakāra": ['mw'],
    "lokopakārin": ['mw'],
    "lokottara": ['bhs', 'cae', 'mw'],
    "lokottaraparivarta": ['bhs', 'mw'],
    "lokottaravādin": ['bhs', 'mw'],
    "lokuttara": ['cped'],
    "lokya": ['ap90', 'cae', 'ddsa', 'mw'],
    "lokyatā": ['mw'],
    "lokābharaṇa": ['bhs'],
    "lokābhibhāvin": ['mw'],
    "lokābhidhāna": ['mw'],
    "lokābhilaṣita": ['mw'],
    "lokābhilāṣin": ['bhs', 'mw'],
    "lokābhilāṣita": ['bhs', 'mw'],
    "lokābhyudaya": ['mw'],
    "lokācāra": ['cae', 'ddsa', 'mw'],
    "lokācārya": ['mw'],
    "lokācāryasiddhānta": ['mw'],
    "lokādhika": ['mw'],
    "lokādhipa": ['cae', 'mw'],
    "lokādhipacca": ['cped'],
    "lokādhipateya": ['mw'],
    "lokādhipati": ['cae', 'mw'],
    "lokādhāra": ['mw'],
    "lokādi": ['cae', 'mw'],
    "lokākhyānakathā": ['bhs'],
    "lokākāśa": ['mw'],
    "lokākṣa": ['bhs'],
    "lokākṣi": ['mw'],
    "lokākṣin": ['mw'],
    "lokāloka": ['cae', 'mw'],
    "lokālokanihitamalla": ['bhs'],
    "lokālokin": ['mw'],
    "lokānanda": ['mw'],
    "lokāntara": ['cae', 'mw'],
    "lokāntaragata": ['mw'],
    "lokāntaraprāpta": ['mw'],
    "lokāntarastha": ['cae', 'mw'],
    "lokāntarika": ['mw'],
    "lokāntarikā": ['bhs'],
    "lokāntarita": ['mw'],
    "lokāntādri": ['mw'],
    "lokānugraha": ['cae', 'mw'],
    "lokānugrahapravṛtta": ['mw'],
    "lokānujñā": ['bhs'],
    "lokānukampaka": ['mw'],
    "lokānukampā": ['cped'],
    "lokānurāga": ['mw'],
    "lokānuvartanā": ['bhs'],
    "lokānuvṛtta": ['mw'],
    "lokānuvṛtti": ['mw'],
    "lokāpavāda": ['cae', 'mw'],
    "lokāryapañcāśat": ['mw'],
    "lokātiga": ['mw'],
    "lokātiśaya": ['mw'],
    "lokātman": ['cae', 'mw'],
    "lokātīta": ['mw'],
    "lokāvekṣaṇa": ['mw'],
    "lokāyana": ['mw'],
    "lokāyata": ['mw'],
    "lokāyatana": ['bhs', 'mw'],
    "lokāyatika": ['cped', 'mw'],
    "lokāyatikapakṣanirāsa": ['mw'],
    "lola": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "lolacakṣus": ['mw'],
    "lolad": ['mw'],
    "loladbhuja": ['mw'],
    "lolaghaṭa": ['mw'],
    "lolajihva": ['mw'],
    "lolakarṇa": ['ddsa', 'mw'],
    "lolakuṇḍala": ['mw'],
    "lolalocana": ['mw'],
    "lolalola": ['mw'],
    "lolalāṅgūla": ['mw'],
    "lolamba": ['mw'],
    "lolana": ['mw'],
    "lolanayana": ['mw'],
    "lolanetra": ['mw'],
    "lolat": ['mw'],
    "lolatkarāṅguli": ['mw'],
    "lolatva": ['mw'],
    "lolatā": ['cped', 'mw'],
    "lolekṣaṇa": ['cae', 'ddsa', 'mw'],
    "loleti": ['cped'],
    "lolikā": ['mw'],
    "lolimbarāja": ['mw'],
    "lolita": ['ap90', 'mw'],
    "lollaṭa": ['mw'],
    "lolora": ['ddsa', 'mw'],
    "loloṣṭha": ['mw'],
    "lolubha": ['ap90', 'cae', 'ddsa', 'mw'],
    "lolupa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "lolupatva": ['mw'],
    "lolupatā": ['mw'],
    "loluppa": ['cped'],
    "lolupā": ['mw'],
    "loluva": ['mw'],
    "lolā": ['mw'],
    "lolākṣikā": ['mw'],
    "lolākṣī": ['mw'],
    "lolāpāṅga": ['mw'],
    "lolārka": ['mw'],
    "lolī": ['mw'],
    "lolūya": ['mw'],
    "lolūyā": ['mw'],
    "lolūyāvat": ['mw'],
    "loma": ['cae', 'cped', 'mw'],
    "lomadhi": ['mw'],
    "lomadvīpa": ['mw'],
    "lomagarta": ['cae', 'mw'],
    "lomaghna": ['mw'],
    "lomaharṣa": ['cae', 'ddsa', 'mw'],
    "lomaharṣaṇa": ['cae', 'mw'],
    "lomaharṣaṇaka": ['mw'],
    "lomaharṣin": ['mw'],
    "lomahaṁsa": ['cped'],
    "lomahaṁsana": ['cped'],
    "lomahaṭṭha": ['cped'],
    "lomahārin": ['mw'],
    "lomahṛt": ['mw'],
    "lomaka": ['cae', 'ddsa', 'mw'],
    "lomakaraṇī": ['mw'],
    "lomakarṇa": ['mw'],
    "lomakin": ['ap90', 'mw'],
    "lomakāgṛha": ['mw'],
    "lomakākhaṇḍa": ['mw'],
    "lomakīṭa": ['cae', 'mw'],
    "lomakūpa": ['cae', 'cped', 'mw'],
    "lomalatādhāra": ['mw'],
    "lomamaṇi": ['mw'],
    "loman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "lomana": ['mw'],
    "lomaphala": ['mw'],
    "lomapravāhin": ['mw'],
    "lomapāda": ['cae', 'mw'],
    "lomapādapur": ['mw'],
    "lomapādapurī": ['mw'],
    "lomarandhra": ['mw'],
    "lomaruha": ['mw'],
    "lomarāji": ['mw'],
    "lomasa": ['cped'],
    "lomasapāṇaka": ['cped'],
    "lomasaṃharṣaṇa": ['mw'],
    "lomasāra": ['mw'],
    "lomasātana": ['mw'],
    "lomatas": ['mw'],
    "lomavant": ['cae'],
    "lomavat": ['mw'],
    "lomavetāla": ['mw'],
    "lomavivara": ['mw'],
    "lomaviṣa": ['mw'],
    "lomavāhana": ['mw'],
    "lomavāhin": ['mw'],
    "lomayūka": ['mw'],
    "lomaśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "lomaśakarṇa": ['mw'],
    "lomaśakāṇḍā": ['mw'],
    "lomaśamārjāra": ['mw'],
    "lomaśaparṇinī": ['mw'],
    "lomaśaparṇī": ['mw'],
    "lomaśapattrikā": ['mw'],
    "lomaśapuṣpaka": ['mw'],
    "lomaśasaktha": ['mw'],
    "lomaśasakthi": ['mw'],
    "lomaśasaṃhitā": ['mw'],
    "lomaśavakṣaṇa": ['mw'],
    "lomaśaśikṣā": ['mw'],
    "lomaśya": ['mw'],
    "lomaśyaṃ": ['ap90'],
    "lomaśā": ['mw'],
    "lomaśātana": ['mw'],
    "lomaśī": ['mw'],
    "lomaḥ": ['ap90'],
    "lomaṁ pāteti": ['cped'],
    "lomaṭaka": ['mw'],
    "lomāda": ['mw'],
    "lomāli": ['mw'],
    "lomālikā": ['mw'],
    "lomālī": ['mw'],
    "lomāvali": ['mw'],
    "lomāvalī": ['mw'],
    "lomāyayaṇi": ['mw'],
    "lomāñca": ['mw'],
    "lomāśa": ['mw'],
    "lomāśaḥ": ['ap90'],
    "lomāśikā": ['ap90', 'mw'],
    "lopa": ['cae', 'cped', 'ddsa', 'mw'],
    "lopaka": ['cae', 'mw'],
    "lopana": ['cae', 'mw'],
    "lopanaṃ": ['ap90'],
    "lopaḥ": ['ap90'],
    "lopikā": ['mw'],
    "lopin": ['ap90', 'cae', 'ddsa', 'mw'],
    "loptra": ['cae', 'mw'],
    "loptraṃ": ['ap90'],
    "loptrī": ['mw'],
    "loptṛ": ['cae', 'mw'],
    "lopya": ['cae', 'mw'],
    "lopā": ['ap90', 'mw'],
    "lopāka": ['ddsa', 'mw'],
    "lopākaḥ": ['ap90'],
    "lopāmudrā": ['ddsa', 'gra', 'mw'],
    "lopāmudrākavi": ['mw'],
    "lopāmudrāpati": ['mw'],
    "lopāmudrāsahacara": ['mw'],
    "lopāpaka": ['mw'],
    "lopāpatti": ['mw'],
    "lopāyikā": ['mw'],
    "lopāśa": ['cae', 'ddsa', 'gra', 'mw'],
    "lopāśaka": ['mw'],
    "lopāśaḥ": ['ap90'],
    "lopāśikā": ['mw'],
    "lorāya": ['mw'],
    "lostonī": ['mw'],
    "lostānī": ['mw'],
    "lota": ['mw'],
    "lotaḥ": ['ap90'],
    "lothaka": ['bhs'],
    "lotra": ['mw'],
    "lotraṃ": ['ap90'],
    "lośaśarāyaṇi": ['mw'],
    "loḍ": ['ap90', 'mw'],
    "loḍana": ['cae', 'ddsa', 'mw'],
    "loḍanaṃ": ['ap90'],
    "loḍayati": ['bhs'],
    "loḍhaka": ['bhs'],
    "loḍita": ['mw'],
    "loḍya": ['mw'],
    "loṇa": ['bhs', 'cped', 'mw'],
    "loṇadhūpana": ['cped'],
    "loṇakāra": ['cped'],
    "loṇaphala": ['cped'],
    "loṇasakkharā": ['cped'],
    "loṇatṛṇa": ['mw'],
    "loṇika": ['cped'],
    "loṇikā": ['mw'],
    "loṇitaka": ['mw'],
    "loṇā": ['mw'],
    "loṇāmlā": ['mw'],
    "loṇāra": ['mw'],
    "loṇāraḥ": ['ap90'],
    "loṇī": ['cped', 'mw'],
    "loṇīkā": ['mw'],
    "loṣṭ": ['ap90', 'mw'],
    "loṣṭa": ['cae', 'ddsa', 'mw'],
    "loṣṭabhañjana": ['mw'],
    "loṣṭabhedana": ['mw'],
    "loṣṭacayana": ['mw'],
    "loṣṭaciti": ['mw'],
    "loṣṭacitiprayoga": ['mw'],
    "loṣṭadeva": ['mw'],
    "loṣṭadhara": ['mw'],
    "loṣṭaghna": ['mw'],
    "loṣṭaghāta": ['mw'],
    "loṣṭaguṭikā": ['cae', 'mw'],
    "loṣṭaka": ['cae', 'mw'],
    "loṣṭakapāla": ['mw'],
    "loṣṭakaḥ": ['ap90'],
    "loṣṭamardin": ['cae', 'mw'],
    "loṣṭamaya": ['cae', 'mw'],
    "loṣṭan": ['mw'],
    "loṣṭasarvajña": ['mw'],
    "loṣṭavat": ['mw'],
    "loṣṭaśa": ['ddsa', 'mw'],
    "loṣṭaḥ": ['ap90'],
    "loṣṭha": ['cae', 'mw'],
    "loṣṭhaka": ['mw'],
    "loṣṭra": ['cae', 'ddsa', 'mw'],
    "loṣṭu": ['bhs', 'mw'],
    "loṣṭuḥ": ['ap90'],
    "loṣṭākṣa": ['mw'],
    "loṣṭāya": ['mw'],
    "loṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "loṭa": ['mw'],
    "loṭana": ['mw'],
    "loṭanaṃ": ['ap90'],
    "loṭanā": ['mw'],
    "loṭha": ['mw'],
    "loṭhabhū": ['mw'],
    "loṭhaka": ['mw'],
    "loṭhakā": ['bhs'],
    "loṭhana": ['cae', 'ddsa', 'mw'],
    "loṭhaḥ": ['ap90'],
    "loṭhitaka": ['mw'],
    "loṭikā": ['ddsa', 'mw'],
    "loṭula": ['mw'],
    "loṭya": ['mw'],
    "loṭā": ['ap90', 'mw'],
    "lpī": ['ap90', 'mw'],
    "lubbhana": ['cped'],
    "lubbhati": ['cped'],
    "lubbhi": ['cped'],
    "lubdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "lubdhajana": ['mw'],
    "lubdhajātakevarṣavardhāpanavidhāna": ['mw'],
    "lubdhaka": ['cae', 'mw'],
    "lubdhakaḥ": ['ap90'],
    "lubdham": ['mw'],
    "lubdhatva": ['mw'],
    "lubdhatā": ['cae', 'mw'],
    "lubh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "lubhita": ['ap90', 'mw'],
    "luc": ['mw'],
    "lucana": ['bhs'],
    "ludda": ['cped'],
    "luddaka": ['cped'],
    "luddha": ['cped'],
    "lugga": ['cped'],
    "lugi": ['mw'],
    "lugna": ['bhs'],
    "luh": ['ap90', 'mw'],
    "lujjana": ['cped'],
    "lujjati": ['bhs', 'cped'],
    "lujji": ['cped'],
    "lujjitvā": ['cped'],
    "luk": ['ap90', 'cae', 'ddsa', 'mw'],
    "lukeśvara": ['mw'],
    "lul": ['ap90', 'cae', 'ddsa', 'mw'],
    "lulita": ['ap90', 'cae', 'ddsa', 'mw'],
    "lulitakuṇḍala": ['mw'],
    "lulitamakaranda": ['mw'],
    "lulitamaṇḍana": ['mw'],
    "lulitapallava": ['mw'],
    "lulitasragākula": ['mw'],
    "lulitākulakeśānta": ['mw'],
    "lulitālakakeśānta": ['mw'],
    "lulāpa": ['cae', 'ddsa', 'mw'],
    "lulāpakanda": ['mw'],
    "lulāpakāntā": ['mw'],
    "lulāpaḥ": ['ap90'],
    "lulāya": ['cae', 'ddsa', 'mw'],
    "lulāyaketu": ['mw'],
    "lulāyalakṣman": ['mw'],
    "lumat": ['mw'],
    "lumb": ['mw'],
    "lumba": ['bhs'],
    "lumbikā": ['mw'],
    "lumbini": ['mw'],
    "lumbinī": ['bhs'],
    "lumbinīya": ['mw'],
    "lumbinīśreṣṭha": ['bhs'],
    "lumbī": ['cae'],
    "lumpana": ['cped'],
    "lumpati": ['cped'],
    "lumpi": ['cped'],
    "lumpita": ['cped'],
    "lumpitvā": ['cped'],
    "luni": ['cped'],
    "lunth": ['mw'],
    "lunāti": ['cped'],
    "lup": ['ap90', 'cae', 'ddsa', 'mw'],
    "lupta": ['ap90', 'cae', 'mw'],
    "luptadaṇḍaka": ['cae', 'mw'],
    "luptadharmakriya": ['mw'],
    "luptapada": ['mw'],
    "luptapiṇḍodakakriya": ['mw'],
    "luptapratibha": ['mw'],
    "luptatā": ['mw'],
    "luptavisarga": ['ddsa', 'mw'],
    "luptavisargaka": ['mw'],
    "luptavisargatā": ['mw'],
    "luptopama": ['mw'],
    "luptopamā": ['cae', 'mw'],
    "luptopamāna": ['mw'],
    "luptāhatavisarga": ['mw'],
    "luptāhatavisargatā": ['mw'],
    "lusta": ['mw'],
    "luta": ['cped'],
    "lutta": ['cped'],
    "luñc": ['cae', 'ddsa', 'mw'],
    "luñca": ['mw'],
    "luñcaka": ['cae', 'mw'],
    "luñcana": ['cae', 'ddsa', 'mw'],
    "luñcanā": ['mw'],
    "luñcati": ['cped'],
    "luñci": ['cped'],
    "luñcita": ['cped', 'mw'],
    "luñcitakeśa": ['mw'],
    "luñcitamūrdhaja": ['mw'],
    "luñcitvā": ['cped'],
    "luñj": ['mw'],
    "luśa": ['cae', 'mw'],
    "luśākapi": ['cae', 'mw'],
    "luḍ": ['ap90', 'cae', 'ddsa', 'mw'],
    "luḍati": ['bhs'],
    "luḍita": ['bhs'],
    "luḷita": ['cped'],
    "luṃb": ['ap90'],
    "luṃbikā": ['ap90'],
    "luṃc": ['ap90'],
    "luṃcaḥ": ['ap90'],
    "luṃcita": ['ap90'],
    "luṃth": ['ap90'],
    "luṃḍ": ['ap90'],
    "luṃḍikā": ['ap90'],
    "luṃḍī": ['ap90'],
    "luṃṭ": ['ap90'],
    "luṃṭh": ['ap90'],
    "luṃṭhakaḥ": ['ap90'],
    "luṃṭhanaṃ": ['ap90'],
    "luṃṭhiḥ": ['ap90'],
    "luṃṭhā": ['ap90'],
    "luṃṭhākaḥ": ['ap90'],
    "luṃṭā": ['ap90'],
    "luṃṭāka": ['ap90'],
    "luṅ": ['ap90', 'cae', 'ddsa', 'mw'],
    "luṅga": ['bhs', 'mw'],
    "luṇiga": ['mw'],
    "luṇḍ": ['mw'],
    "luṇḍikā": ['cae', 'ddsa', 'mw'],
    "luṇḍī": ['mw'],
    "luṇḍīkṛ": ['cae', 'ddsa'],
    "luṇḍīkṛta": ['mw'],
    "luṇṭ": ['ddsa', 'mw'],
    "luṇṭaka": ['mw'],
    "luṇṭh": ['cae', 'ddsa', 'mw'],
    "luṇṭha": ['cae', 'ddsa', 'mw'],
    "luṇṭhaka": ['cae', 'mw'],
    "luṇṭhana": ['cae', 'mw'],
    "luṇṭhanadī": ['mw'],
    "luṇṭhi": ['cae', 'mw'],
    "luṇṭhita": ['mw'],
    "luṇṭhā": ['mw'],
    "luṇṭhāka": ['mw'],
    "luṇṭhākatā": ['mw'],
    "luṇṭhī": ['mw'],
    "luṇṭita": ['mw'],
    "luṇṭā": ['mw'],
    "luṇṭāka": ['ddsa', 'mw'],
    "luṣ": ['ap90', 'mw'],
    "luṣa": ['mw'],
    "luṣabha": ['mw'],
    "luṣabhaḥ": ['ap90'],
    "luṭ": ['ap90', 'ddsa', 'mw'],
    "luṭh": ['ap90', 'cae', 'ddsa', 'mw'],
    "luṭhana": ['ddsa', 'mw'],
    "luṭhanaṃ": ['ap90'],
    "luṭhaneśvaratīrtha": ['mw'],
    "luṭhat": ['mw'],
    "luṭheśvara": ['mw'],
    "luṭhita": ['ap90', 'mw'],
    "luṭṭaka": ['mw'],
    "lvī": ['ap90', 'mw'],
    "lvīna": ['mw'],
    "lyap": ['ddsa', 'mw'],
    "lyuṭ": ['ddsa', 'mw'],
    "lyī": ['mw'],
    "lā": ['ap90', 'cae', 'ddsa', 'mw'],
    "lāba": ['cae', 'ddsa', 'mw'],
    "lābaka": ['cae', 'mw'],
    "lābaḥ": ['ap90'],
    "lābh": ['mw'],
    "lābha": ['cae', 'cped', 'ddsa', 'mw'],
    "lābhagga": ['cped'],
    "lābhaka": ['mw'],
    "lābhakamyatā": ['cped'],
    "lābhakara": ['mw'],
    "lābhakaḥ": ['ap90'],
    "lābhakāraṇāt": ['mw'],
    "lābhakṛt": ['mw'],
    "lābhalipsā": ['cae', 'mw'],
    "lābham": ['mw'],
    "lābhamacchariya": ['cped'],
    "lābhaniścikīrṣā": ['bhs'],
    "lābhasakkāra": ['cped'],
    "lābhatās": ['mw'],
    "lābhavant": ['cae'],
    "lābhavat": ['mw'],
    "lābhaḥ": ['ap90'],
    "lābhika": ['bhs', 'gra'],
    "lābhin": ['bhs', 'cae', 'ddsa', 'mw'],
    "lābhya": ['mw'],
    "lābhā": ['bhs', 'cped'],
    "lābhālābha": ['cae', 'mw'],
    "lābhī": ['cped'],
    "lābu": ['cped', 'mw'],
    "lābukaṭāha": ['cped'],
    "lābukāyana": ['mw'],
    "lābukī": ['ap90', 'mw'],
    "lābuḥ": ['ap90'],
    "lābākṣa": ['mw'],
    "lābākṣaka": ['mw'],
    "lābū": ['mw'],
    "lābūḥ": ['ap90'],
    "lāganṛtta": ['mw'],
    "lāgh": ['ap90', 'mw'],
    "lāgharakolasa": ['mw'],
    "lāghava": ['bhs', 'cae', 'ddsa', 'mw'],
    "lāghavagauravavicāra": ['mw'],
    "lāghavakārin": ['mw'],
    "lāghavaṃ": ['ap90'],
    "lāghavika": ['mw'],
    "lāghavin": ['mw'],
    "lāghavānvita": ['mw'],
    "lāghavāyana": ['mw'],
    "lāguḍika": ['ap90', 'mw'],
    "lāhala": ['mw'],
    "lāharimalla": ['mw'],
    "lāhya": ['mw'],
    "lāhyāyani": ['mw'],
    "lāj": ['ap90', 'mw'],
    "lāja": ['cae', 'cped', 'ddsa', 'mw'],
    "lājamaṇḍa": ['mw'],
    "lājapañcamaka": ['cped'],
    "lājapeyā": ['mw'],
    "lājasphoṭam": ['mw'],
    "lājaḥ": ['ap90'],
    "lāji": ['mw'],
    "lājāhuti": ['mw'],
    "lājāya": ['ddsa', 'mw'],
    "lājī": ['mw'],
    "lākh": ['ap90', 'mw'],
    "lākhā": ['cped'],
    "lākhārasa": ['cped'],
    "lākinī": ['mw'],
    "lākuca": ['mw'],
    "lākuci": ['mw'],
    "lākuṭika": ['ap90', 'mw'],
    "lākṣakī": ['ap90', 'mw'],
    "lākṣaṇa": ['cae', 'mw'],
    "lākṣaṇi": ['mw'],
    "lākṣaṇika": ['ap90', 'cae', 'ddsa', 'mw'],
    "lākṣaṇikatva": ['mw'],
    "lākṣaṇya": ['ap90', 'cae', 'mw'],
    "lākṣeya": ['mw'],
    "lākṣika": ['ap90', 'mw'],
    "lākṣma": ['mw'],
    "lākṣmaṇa": ['mw'],
    "lākṣmaṇeya": ['mw'],
    "lākṣmaṇi": ['mw'],
    "lākṣyika": ['mw'],
    "lākṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "lākṣābhavana": ['mw'],
    "lākṣācūrṇa": ['mw'],
    "lākṣāgṛha": ['mw'],
    "lākṣāprasāda": ['mw'],
    "lākṣāprasādana": ['mw'],
    "lākṣāpura": ['mw'],
    "lākṣārakta": ['mw'],
    "lākṣārasa": ['mw'],
    "lākṣātaila": ['mw'],
    "lākṣātaru": ['mw'],
    "lākṣāvāṇijya": ['mw'],
    "lākṣāvṛkṣa": ['mw'],
    "lāla": ['cae', 'mw'],
    "lālabhāratakāvya": ['mw'],
    "lālacandra": ['mw'],
    "lālaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "lālamatī": ['mw'],
    "lālamaṇi": ['mw'],
    "lālamiśra": ['mw'],
    "lālana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "lālanīya": ['cae', 'mw'],
    "lālapati": ['cped'],
    "lālapi": ['cped'],
    "lālapita": ['cped'],
    "lālapya": ['bhs'],
    "lālapyana": ['bhs'],
    "lālasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "lālasaka": ['bhs', 'cae', 'mw'],
    "lālasatā": ['mw'],
    "lālasiṃha": ['mw'],
    "lālasya": ['bhs'],
    "lālasā": ['ap90', 'mw'],
    "lālasīka": ['mw'],
    "lālasīkaṃ": ['ap90'],
    "lālavat": ['mw'],
    "lālayita": ['bhs'],
    "lālayitavya": ['mw'],
    "lālesi": ['cped'],
    "lāleti": ['cped'],
    "lāletvā": ['cped'],
    "lālika": ['mw'],
    "lālikaḥ": ['ap90'],
    "lālikā": ['mw'],
    "lālin": ['ap90', 'cae', 'ddsa', 'mw'],
    "lālinī": ['ap90', 'mw'],
    "lālita": ['ap90', 'cped', 'ddsa', 'mw'],
    "lālitaka": ['mw'],
    "lālitakaḥ": ['ap90'],
    "lālitya": ['cae', 'ddsa', 'mw'],
    "lālityaṃ": ['ap90'],
    "lālukā": ['ap90', 'mw'],
    "lālya": ['mw'],
    "lālā": ['ap90', 'cae', 'ddsa', 'mw'],
    "lālābhakṣa": ['mw'],
    "lālādha": ['mw'],
    "lālāklinna": ['mw'],
    "lālālu": ['mw'],
    "lālāmeha": ['mw'],
    "lālāmika": ['mw'],
    "lālāpāna": ['cae', 'mw'],
    "lālāpūrṇārṇava": ['mw'],
    "lālāsrava": ['mw'],
    "lālāsrāva": ['mw'],
    "lālāsrāvin": ['mw'],
    "lālāviṣa": ['mw'],
    "lālāy": ['cae'],
    "lālāya": ['ddsa', 'mw'],
    "lālāyate": ['ap90'],
    "lālāyita": ['mw'],
    "lālāṭa": ['cae', 'ddsa', 'mw'],
    "lālāṭi": ['mw'],
    "lālāṭika": ['ap90', 'mw'],
    "lālāṭikā": ['bhs'],
    "lālāṭī": ['ap90', 'mw'],
    "lālī": ['mw'],
    "lālīla": ['mw'],
    "lāmagāyana": ['mw'],
    "lāmagāyani": ['mw'],
    "lāmajjaka": ['ddsa', 'mw'],
    "lāmajjakaṃ": ['ap90'],
    "lāmaka": ['cped'],
    "lāmakāyana": ['mw'],
    "lāmakāyani": ['mw'],
    "lāmakāyanin": ['mw'],
    "lāmpaṭya": ['mw'],
    "lāmā": ['bhs'],
    "lāndra": ['mw'],
    "lāndraka": ['mw'],
    "lānta": ['mw'],
    "lāntakaja": ['mw'],
    "lāntava": ['mw'],
    "lāpa": ['cped', 'mw'],
    "lāpana": ['bhs'],
    "lāpaya": ['ddsa'],
    "lāpaḥ": ['ap90'],
    "lāpika": ['bhs'],
    "lāpikā": ['ap90', 'mw'],
    "lāpin": ['cae', 'ddsa', 'mw'],
    "lāpinikā": ['mw'],
    "lāpu": ['cae', 'cped', 'mw'],
    "lāpya": ['mw'],
    "lāsa": ['cae', 'cped', 'ddsa', 'mw'],
    "lāsaka": ['ap90', 'cae', 'mw'],
    "lāsakayuvan": ['mw'],
    "lāsakī": ['ap90', 'mw'],
    "lāsana": ['cped', 'mw'],
    "lāsavatī": ['mw'],
    "lāsaḥ": ['ap90'],
    "lāsika": ['ddsa', 'mw'],
    "lāsikā": ['ap90', 'mw'],
    "lāsin": ['mw'],
    "lāsphoṭanī": ['ap90', 'mw'],
    "lāsya": ['cae', 'mw'],
    "lāsyaka": ['mw'],
    "lāsyaṃ": ['ap90'],
    "lāsyā": ['bhs', 'mw'],
    "lāsyāṅga": ['mw'],
    "lāta": ['ap90', 'mw'],
    "lātaka": ['mw'],
    "lātavya": ['cae', 'ddsa', 'mw'],
    "lāti": ['mw'],
    "lātiḥ": ['ap90'],
    "lātvā": ['mw'],
    "lāva": ['ap90', 'cae', 'ddsa', 'mw'],
    "lāvaka": ['cae', 'mw'],
    "lāvakaḥ": ['ap90'],
    "lāvalī": ['mw'],
    "lāvam": ['ddsa'],
    "lāvaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "lāvaṇaka": ['cae', 'mw'],
    "lāvaṇasaindhava": ['mw'],
    "lāvaṇika": ['ap90', 'cae', 'ddsa', 'mw'],
    "lāvaṇya": ['cae', 'ddsa', 'mw'],
    "lāvaṇyakalita": ['mw'],
    "lāvaṇyalaharī": ['mw'],
    "lāvaṇyalakṣmī": ['mw'],
    "lāvaṇyamaya": ['ap90', 'cae', 'mw'],
    "lāvaṇyamañjarī": ['mw'],
    "lāvaṇyavant": ['cae'],
    "lāvaṇyavat": ['mw'],
    "lāvaṇyavatī": ['mw'],
    "lāvaṇyaśarman": ['mw'],
    "lāvaṇyaśeṣa": ['mw'],
    "lāvaṇyaśeṣatā": ['mw'],
    "lāvaṇyaśrī": ['mw'],
    "lāvaṇyaṃ": ['ap90'],
    "lāvaṇyārjita": ['mw'],
    "lāveraṇi": ['mw'],
    "lāveraṇīya": ['mw'],
    "lāveriṇi": ['mw'],
    "lāvika": ['mw'],
    "lāvikaḥ": ['ap90'],
    "lāvin": ['mw'],
    "lāvu": ['ap90', 'mw'],
    "lāvya": ['mw'],
    "lāvāṇaka": ['cae', 'ddsa', 'mw'],
    "lāvāṇakaḥ": ['ap90'],
    "lāya": ['gra', 'mw'],
    "lāyaka": ['cped', 'mw'],
    "lāyati": ['cped'],
    "lāyi": ['cped'],
    "lāyita": ['cped'],
    "lāyitvā": ['cped'],
    "lāñch": ['cae', 'ddsa', 'mw'],
    "lāñchana": ['cae', 'ddsa', 'mw'],
    "lāñchanatā": ['mw'],
    "lāñchanāya": ['mw'],
    "lāñchita": ['mw'],
    "lāñci": ['mw'],
    "lāñj": ['mw'],
    "lāḍ": ['ap90', 'mw'],
    "lāḍa": ['bhs', 'ddsa', 'mw'],
    "lāḍakhāna": ['mw'],
    "lāḍama": ['mw'],
    "lāḍana": ['mw'],
    "lāḍhācārya": ['mw'],
    "lāḍi": ['mw'],
    "lāḍika": ['bhs', 'mw'],
    "lāḍita": ['bhs'],
    "lāḍyate": ['bhs'],
    "lāḍyā": ['mw'],
    "lāḍīka": ['mw'],
    "lāṃch": ['ap90'],
    "lāṃchanaṃ": ['ap90'],
    "lāṃchita": ['ap90'],
    "lāṃgalaṃ": ['ap90'],
    "lāṃgalika": ['ap90'],
    "lāṃgalin": ['ap90'],
    "lāṃgalī": ['ap90'],
    "lāṃgalīṣā": ['ap90'],
    "lāṃgulaṃ": ['ap90'],
    "lāṃgūlaṃ": ['ap90'],
    "lāṃgūlin": ['ap90'],
    "lāṃpaṭyaṃ": ['ap90'],
    "lāṃṭhanī": ['ap90'],
    "lāṅgala": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "lāṅgalacakra": ['mw'],
    "lāṅgaladaṇḍa": ['mw'],
    "lāṅgaladaṇḍaka": ['mw'],
    "lāṅgaladhvaja": ['cae', 'mw'],
    "lāṅgalagraha": ['mw'],
    "lāṅgalagrahaṇa": ['mw'],
    "lāṅgalaka": ['mw'],
    "lāṅgalakamārga": ['mw'],
    "lāṅgalapaddhati": ['mw'],
    "lāṅgalaphāla": ['mw'],
    "lāṅgalegṛhya": ['mw'],
    "lāṅgaleṣā": ['mw'],
    "lāṅgali": ['mw'],
    "lāṅgalika": ['mw'],
    "lāṅgalikā": ['ddsa'],
    "lāṅgalikī": ['mw'],
    "lāṅgalin": ['cae', 'mw'],
    "lāṅgalinī": ['mw'],
    "lāṅgalāhvā": ['mw'],
    "lāṅgalākhya": ['mw'],
    "lāṅgalāpakarṣin": ['mw'],
    "lāṅgalāyana": ['mw'],
    "lāṅgalī": ['mw'],
    "lāṅgalīṣā": ['mw'],
    "lāṅgula": ['bhs', 'cae', 'ddsa', 'mw'],
    "lāṅgulegṛhya": ['mw'],
    "lāṅgulikā": ['mw'],
    "lāṅgulinī": ['mw'],
    "lāṅgūla": ['cae', 'mw'],
    "lāṅgūlacālana": ['mw'],
    "lāṅgūlagṛhya": ['mw'],
    "lāṅgūlavikṣepa": ['mw'],
    "lāṅgūlikā": ['mw'],
    "lāṅgūlikī": ['mw'],
    "lāṅgūlin": ['mw'],
    "lāṅgūlinī": ['mw'],
    "lāṅgūlī": ['mw'],
    "lāṅkākāyani": ['mw'],
    "lāṅkāyana": ['mw'],
    "lāṣuka": ['ap90', 'mw'],
    "lāṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "lāṭabhāṣā": ['mw'],
    "lāṭadeśa": ['mw'],
    "lāṭadiṇḍīra": ['mw'],
    "lāṭajana": ['mw'],
    "lāṭaka": ['ap90', 'mw'],
    "lāṭanārī": ['mw'],
    "lāṭaviṣaya": ['mw'],
    "lāṭeśvara": ['mw'],
    "lāṭikā": ['ap90', 'mw'],
    "lāṭyāya": ['mw'],
    "lāṭyāyana": ['mw'],
    "lāṭyāyanaśrautasūtra": ['mw'],
    "lāṭācārya": ['ddsa', 'mw'],
    "lāṭānuprāsa": ['mw'],
    "lāṭānvaya": ['mw'],
    "lāṭāyana": ['mw'],
    "lāṭī": ['mw'],
    "lāṭīya": ['mw'],
    "lī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "līkkā": ['ap90', 'mw'],
    "līkā": ['cae', 'mw'],
    "līkṣā": ['mw'],
    "līleśvaradeva": ['mw'],
    "līlin": ['bhs'],
    "līlodyāna": ['cae', 'mw'],
    "līlopavatī": ['mw'],
    "līlā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "līlābharaṇa": ['cae', 'mw'],
    "līlābja": ['cae', 'mw'],
    "līlācala": ['mw'],
    "līlācandra": ['mw'],
    "līlācatura": ['mw'],
    "līlādagdha": ['mw'],
    "līlādevī": ['mw'],
    "līlādharabhaṭṭa": ['mw'],
    "līlādri": ['mw'],
    "līlāgeha": ['cae', 'mw'],
    "līlāgāra": ['cae', 'mw'],
    "līlāgṛha": ['cae', 'mw'],
    "līlākalaha": ['mw'],
    "līlākamala": ['cae', 'mw'],
    "līlākara": ['mw'],
    "līlākhela": ['mw'],
    "līlāmadhukara": ['mw'],
    "līlāmandira": ['mw'],
    "līlāmanuṣya": ['mw'],
    "līlāmaya": ['mw'],
    "līlāmbuja": ['mw'],
    "līlāmānuṣavigraha": ['mw'],
    "līlāmātreṇa": ['mw'],
    "līlānaṭana": ['mw'],
    "līlānṛtya": ['cae', 'mw'],
    "līlāpadma": ['cae', 'mw'],
    "līlāparvata": ['mw'],
    "līlāpura": ['mw'],
    "līlārasakramastotra": ['mw'],
    "līlārati": ['ddsa', 'mw'],
    "līlāravinda": ['cae', 'mw'],
    "līlāsampādanakrama": ['mw'],
    "līlāsvātmapriya": ['mw'],
    "līlāsādhya": ['mw'],
    "līlātanu": ['mw'],
    "līlātāla": ['mw'],
    "līlātāmarasa": ['mw'],
    "līlātāṇḍavapaṇḍita": ['mw'],
    "līlāvadhūta": ['mw'],
    "līlāvajra": ['mw'],
    "līlāvant": ['cae'],
    "līlāvat": ['ap90', 'ddsa', 'mw'],
    "līlāvatāra": ['mw'],
    "līlāvatī": ['mw'],
    "līlāvatīprakāśa": ['mw'],
    "līlāvatīrahasya": ['mw'],
    "līlāvatīsāra": ['mw'],
    "līlāvatīvyākhyā": ['mw'],
    "līlāveśman": ['mw'],
    "līlāvāpī": ['cae', 'mw'],
    "līlāy": ['cae'],
    "līlāya": ['ddsa', 'mw'],
    "līlāyati": ['ap90'],
    "līlāyita": ['mw'],
    "līlāyitatva": ['bhs'],
    "līlāyitaṃ": ['ap90'],
    "līlāyudha": ['mw'],
    "līlāśuka": ['mw'],
    "līlāṅga": ['mw'],
    "līna": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "līnatta": ['cped'],
    "līnatva": ['mw'],
    "līnatā": ['bhs', 'cped', 'mw'],
    "līnaya": ['mw'],
    "līnāli": ['mw'],
    "līpsitavya": ['ddsa', 'mw'],
    "līpyase": ['bhs'],
    "līsuṣa": ['mw'],
    "līyamāna": ['cped'],
    "līyana": ['cped'],
    "līyanā": ['bhs'],
    "līyati": ['bhs', 'cped'],
    "līyi": ['cped'],
    "līyitvā": ['cped'],
    "līḍa": ['bhs'],
    "līḍha": ['ap90', 'mw'],
    "līḍhamukta": ['mw'],
    "līḥ": ['ap90'],
    "lū": ['ap90', 'cae', 'ddsa', 'mw'],
    "lūha": ['bhs', 'mw'],
    "lūhasudatta": ['bhs', 'mw'],
    "lūkha": ['bhs', 'cped'],
    "lūkhacīvara": ['cped'],
    "lūkhappasanna": ['cped'],
    "lūkhatā": ['bhs', 'cped'],
    "lūkhājīvī": ['cped'],
    "lūkṣa": ['cae', 'mw'],
    "lūluka": ['mw'],
    "lūma": ['mw'],
    "lūman": ['mw'],
    "lūmaviṣa": ['mw'],
    "lūmaṃ": ['ap90'],
    "lūna": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "lūnabāhu": ['mw'],
    "lūnados": ['mw'],
    "lūnaduṣkṛta": ['mw'],
    "lūnaka": ['ap90', 'mw'],
    "lūnalipi": ['bhs'],
    "lūnamāṃsa": ['mw'],
    "lūnapakṣa": ['mw'],
    "lūnaviṣa": ['mw'],
    "lūnayavam": ['mw'],
    "lūni": ['mw'],
    "lūnāti": ['bhs'],
    "lūnī": ['mw'],
    "lūnīya": ['mw'],
    "lūta": ['mw'],
    "lūtikā": ['ap90', 'mw'],
    "lūtā": ['ap90', 'cae', 'ddsa', 'mw'],
    "lūtāmarkaṭaka": ['mw'],
    "lūtāmaya": ['mw'],
    "lūtāpaṭṭa": ['mw'],
    "lūtāri": ['mw'],
    "lūtāta": ['mw'],
    "lūtātantu": ['mw'],
    "lūyamāna": ['mw'],
    "lūyamānayavam": ['mw'],
    "lūyati": ['cped'],
    "lūṇa": ['cped'],
    "lūṣ": ['ap90', 'mw'],
    "lūṣa": ['mw'],
    "lṛ": ['mw'],
    "lṛṭ": ['cae', 'ddsa', 'mw'],
    "ma": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "mab": ['ap90'],
    "mabhr": ['ap90', 'mw'],
    "mac": ['ap90', 'mw'],
    "macakacātanī": ['mw'],
    "macakruka": ['mw'],
    "macarcikā": ['ap90', 'mw'],
    "macca": ['cped'],
    "maccha": ['bhs', 'cped', 'mw'],
    "macchabandha": ['cped'],
    "macchagumba": ['cped'],
    "macchamaṁsa": ['cped'],
    "macchara": ['bhs', 'cped'],
    "macchariya": ['cped'],
    "maccharāyati": ['cped'],
    "maccharī": ['bhs', 'cped'],
    "maccharīra": ['ddsa', 'mw'],
    "macchaḥ": ['ap90'],
    "macchaṇḍa": ['cped'],
    "macchaṇḍī": ['cped'],
    "macchera": ['cped'],
    "macchākṣāṅka": ['mw'],
    "macchī": ['cped'],
    "maccitta": ['cae', 'mw'],
    "maccu": ['cped'],
    "maccudheyya": ['cped'],
    "maccuhāyī": ['cped'],
    "maccumukha": ['cped'],
    "maccupareta": ['cped'],
    "maccuparāyaṇa": ['cped'],
    "maccupāsa": ['cped'],
    "maccurāja": ['cped'],
    "maccutara": ['cped'],
    "maccuvasa": ['cped'],
    "mad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mada": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "madabhañjinī": ['mw'],
    "madabhaṅga": ['mw'],
    "madacyut": ['cae', 'gra', 'mw'],
    "madacyuta": ['cae', 'gra', 'mw'],
    "madadhāra": ['mw'],
    "madadin": ['mw'],
    "madadurdina": ['mw'],
    "madadvipa": ['mw'],
    "madagamana": ['mw'],
    "madagandha": ['mw'],
    "madagandhā": ['mw'],
    "madaghnī": ['mw'],
    "madagurupakṣa": ['mw'],
    "madahastinī": ['mw'],
    "madahetu": ['mw'],
    "madajala": ['mw'],
    "madajvara": ['mw'],
    "madakala": ['cae', 'mw'],
    "madakalakokilakūjita": ['mw'],
    "madakalayuvati": ['mw'],
    "madakara": ['ddsa', 'mw'],
    "madakarin": ['mw'],
    "madakhela": ['cae'],
    "madakohala": ['mw'],
    "madakāraṇa": ['mw'],
    "madakārin": ['mw'],
    "madakṛt": ['mw'],
    "madalekhā": ['cae', 'ddsa', 'mw'],
    "madamattaka": ['mw'],
    "madamattā": ['mw'],
    "madamohita": ['mw'],
    "madamuc": ['mw'],
    "madana": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "madanabhavana": ['mw'],
    "madanabhūṣaṇa": ['mw'],
    "madanabādhā": ['mw'],
    "madanacaturdaśī": ['mw'],
    "madanadahana": ['mw'],
    "madanadamana": ['mw'],
    "madanadaṃṣṭrā": ['mw'],
    "madanadhvajā": ['mw'],
    "madanadviṣ": ['mw'],
    "madanadvādaśī": ['mw'],
    "madanagopāla": ['mw'],
    "madanagopālavilāsa": ['mw'],
    "madanagopālavādaprabandha": ['mw'],
    "madanagṛha": ['mw'],
    "madanaharā": ['mw'],
    "madanaka": ['mw'],
    "madanakalaha": ['mw'],
    "madanakaḥ": ['ap90'],
    "madanakaṇṭaka": ['mw'],
    "madanakliṣṭa": ['mw'],
    "madanakākurava": ['mw'],
    "madanakīrti": ['mw'],
    "madanalalita": ['mw'],
    "madanalalitā": ['mw'],
    "madanalekha": ['cae', 'mw'],
    "madanalekhā": ['cae', 'mw'],
    "madanamaha": ['cae', 'mw'],
    "madanamahotsava": ['mw'],
    "madanamahārṇava": ['mw'],
    "madanamanohara": ['mw'],
    "madanamaya": ['mw'],
    "madanamañcukā": ['mw'],
    "madanamañjarī": ['mw'],
    "madanamiśra": ['mw'],
    "madanamodaka": ['mw'],
    "madanamohana": ['mw'],
    "madanamohanī": ['mw'],
    "madanamukhacapeṭā": ['mw'],
    "madanamālinī": ['mw'],
    "madanamālā": ['mw'],
    "madananālikā": ['mw'],
    "madananṛpa": ['mw'],
    "madanapakṣin": ['mw'],
    "madanaparājaya": ['mw'],
    "madanapaṭṭikā": ['mw'],
    "madanaphala": ['mw'],
    "madanaprabha": ['mw'],
    "madanaprabhā": ['mw'],
    "madanapura": ['mw'],
    "madanapāla": ['mw'],
    "madanapālavinodanighaṇṭu": ['mw'],
    "madanapārijāta": ['mw'],
    "madanapāthaka": ['mw'],
    "madanapīḍā": ['mw'],
    "madanaratna": ['mw'],
    "madanaratnanighaṇṭu": ['mw'],
    "madanaratnapradīpa": ['mw'],
    "madanarekhā": ['mw'],
    "madanaripu": ['mw'],
    "madanarāja": ['mw'],
    "madanasaṃdeśa": ['cae', 'mw'],
    "madanasaṃjīvana": ['mw'],
    "madanasaṃjīvanī": ['mw'],
    "madanasenā": ['mw'],
    "madanasiṃha": ['mw'],
    "madanasundarī": ['mw'],
    "madanasārikā": ['cae', 'mw'],
    "madanatantra": ['mw'],
    "madanatrayodaśī": ['mw'],
    "madanatṛṣṇā": ['mw'],
    "madanavahniśikhāvalī": ['mw'],
    "madanavatī": ['mw'],
    "madanavaśa": ['mw'],
    "madanavega": ['mw'],
    "madanaviklava": ['mw'],
    "madanavinoda": ['mw'],
    "madanayaṣṭiketu": ['mw'],
    "madanaśalākā": ['mw'],
    "madanaśikhipīḍā": ['mw'],
    "madanecchāphala": ['mw'],
    "madanikā": ['cae', 'ddsa', 'mw'],
    "madanirmadana": ['bhs'],
    "madanodaya": ['mw'],
    "madanodyāna": ['cae', 'ddsa', 'mw'],
    "madanotsava": ['cae', 'mw'],
    "madanotsavā": ['mw'],
    "madanotsuka": ['mw'],
    "madantikā": ['mw'],
    "madantī": ['cae', 'mw'],
    "madanā": ['bhs', 'mw'],
    "madanābhirāma": ['mw'],
    "madanācārya": ['mw'],
    "madanāditya": ['ddsa', 'mw'],
    "madanāgraka": ['mw'],
    "madanālaya": ['mw'],
    "madanāndhamiśra": ['mw'],
    "madanāntaka": ['mw'],
    "madanāri": ['mw'],
    "madanārṇava": ['mw'],
    "madanātapatra": ['mw'],
    "madanātura": ['cae', 'mw'],
    "madanāvastha": ['cae', 'mw'],
    "madanāvasthā": ['mw'],
    "madanāya": ['mw'],
    "madanāyudha": ['mw'],
    "madanāyuṣa": ['mw'],
    "madanāśaya": ['mw'],
    "madanāṅkuśa": ['mw'],
    "madanī": ['bhs', 'mw'],
    "madanīya": ['cped', 'mw'],
    "madapati": ['cae', 'gra', 'mw'],
    "madapaṭu": ['cae', 'ddsa', 'mw'],
    "madaprada": ['mw'],
    "madapraseka": ['cae', 'mw'],
    "madaprasravaṇa": ['mw'],
    "madaprayoga": ['mw'],
    "madarpatapura": ['ddsa', 'mw'],
    "madarpaṇa": ['cae'],
    "madarpitapura": ['mw'],
    "madartha": ['ddsa', 'mw'],
    "madartham": ['cae', 'mw'],
    "madarudradatta": ['mw'],
    "madarāga": ['mw'],
    "madasrāvin": ['mw'],
    "madasthala": ['mw'],
    "madasthāna": ['mw'],
    "madasāra": ['mw'],
    "madavallabha": ['mw'],
    "madavihvala": ['mw'],
    "madavihvalita": ['mw'],
    "madavikṣipta": ['mw'],
    "madavyādhi": ['mw'],
    "madavāraṇa": ['mw'],
    "madavāri": ['mw'],
    "madavīrya": ['mw'],
    "madavṛddha": ['gra', 'mw'],
    "madayantikā": ['cae', 'mw'],
    "madayantī": ['cae', 'ddsa', 'mw'],
    "madayat": ['mw'],
    "madayaṃtikā": ['ap90'],
    "madayitnu": ['ap90', 'mw'],
    "madayitṛ": ['cae', 'mw'],
    "madaśauṇḍaka": ['mw'],
    "madaśāka": ['mw'],
    "madaḥ": ['ap90'],
    "madbandhanasamudbhava": ['mw'],
    "madbhakta": ['cae', 'mw'],
    "madbhāva": ['cae', 'mw'],
    "madbhū": ['mw'],
    "maddana": ['cped'],
    "maddanta": ['cped'],
    "maddati": ['cped'],
    "maddava": ['cped'],
    "maddeha": ['ddsa', 'mw'],
    "maddhaka": ['mw'],
    "maddi": ['cped'],
    "maddita": ['cped'],
    "madditvā": ['cped'],
    "maddiya": ['cped'],
    "maderaghu": ['gra', 'mw'],
    "maderu": ['gra', 'mw'],
    "madga": ['mw'],
    "madgata": ['cae'],
    "madgu": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "madgubhūta": ['mw'],
    "madgura": ['bhs', 'cae', 'mw'],
    "madguraka": ['mw'],
    "madgurapriyā": ['mw'],
    "madgurasī": ['mw'],
    "madguraḥ": ['ap90'],
    "madguśa": ['mw'],
    "madguḥ": ['ap90'],
    "madgībhūta": ['bhs'],
    "madhavya": ['ddsa', 'mw'],
    "madhavyaḥ": ['ap90'],
    "madhu": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "madhuad": ['gra'],
    "madhuarṇas": ['gra'],
    "madhubahulā": ['mw'],
    "madhubbata": ['cped'],
    "madhubhadra": ['mw'],
    "madhubhakṣaṇa": ['mw'],
    "madhubhid": ['mw'],
    "madhubhuj": ['mw'],
    "madhubhāga": ['mw'],
    "madhubhāva": ['mw'],
    "madhubhāṇḍa": ['mw'],
    "madhubhūmika": ['mw'],
    "madhubrāhmaṇa": ['mw'],
    "madhubīja": ['mw'],
    "madhubījapūra": ['mw'],
    "madhucchada": ['mw'],
    "madhucchanda": ['cae', 'mw'],
    "madhucchandas": ['cae', 'mw'],
    "madhucchattra": ['mw'],
    "madhucyut": ['cae', 'mw'],
    "madhucyuta": ['cae', 'mw'],
    "madhudalā": ['mw'],
    "madhudha": ['gra'],
    "madhudhenu": ['mw'],
    "madhudhvaja": ['mw'],
    "madhudhā": ['cae', 'gra', 'mw'],
    "madhudhāna": ['mw'],
    "madhudhāra": ['gra'],
    "madhudhārā": ['mw'],
    "madhudhātu": ['mw'],
    "madhudhūli": ['mw'],
    "madhudogha": ['gra', 'mw'],
    "madhudoham": ['mw'],
    "madhudra": ['mw'],
    "madhudrava": ['mw'],
    "madhudruma": ['mw'],
    "madhudugha": ['gra', 'mw'],
    "madhudviṣ": ['cae', 'mw'],
    "madhudātar": ['bhs'],
    "madhudīpa": ['mw'],
    "madhudūta": ['mw'],
    "madhudūtī": ['mw'],
    "madhugandhika": ['mw'],
    "madhugaṇḍa": ['cped'],
    "madhughoṣa": ['mw'],
    "madhugluntha": ['mw'],
    "madhugraha": ['cae', 'mw'],
    "madhuguñjana": ['mw'],
    "madhugāyana": ['mw'],
    "madhuhan": ['cae', 'mw'],
    "madhuhantṛ": ['cae', 'mw'],
    "madhuhastia": ['gra'],
    "madhuhastya": ['gra', 'mw'],
    "madhuja": ['mw'],
    "madhujambha": ['mw'],
    "madhujambhala": ['mw'],
    "madhujambīra": ['mw'],
    "madhujihva": ['cae', 'gra', 'mw'],
    "madhujit": ['mw'],
    "madhujā": ['mw'],
    "madhujālaka": ['mw'],
    "madhujāta": ['cae', 'mw'],
    "madhuka": ['ap90', 'cped', 'ddsa', 'mw'],
    "madhukaiṭasasūdana": ['mw'],
    "madhukara": ['cae', 'cped', 'mw'],
    "madhukaragaṇa": ['mw'],
    "madhukaramaya": ['mw'],
    "madhukararājan": ['mw'],
    "madhukarasāha": ['mw'],
    "madhukarasāhi": ['mw'],
    "madhukaraśreṇi": ['mw'],
    "madhukarikā": ['cae', 'mw'],
    "madhukarin": ['mw'],
    "madhukarkaṭikā": ['mw'],
    "madhukarkaṭī": ['mw'],
    "madhukarāya": ['ddsa', 'mw'],
    "madhukarī": ['mw'],
    "madhukarṇa": ['mw'],
    "madhukaśā": ['cae', 'mw'],
    "madhukaṇṭha": ['mw'],
    "madhukeśaṭa": ['mw'],
    "madhukharjūrikā": ['mw'],
    "madhukharjūrī": ['mw'],
    "madhukirī": ['mw'],
    "madhukośa": ['mw'],
    "madhukrama": ['mw'],
    "madhukroḍa": ['mw'],
    "madhukukkuṭikā": ['mw'],
    "madhukukkuṭī": ['mw'],
    "madhukulyā": ['mw'],
    "madhukumbhā": ['mw'],
    "madhukā": ['cped', 'mw'],
    "madhukānana": ['mw'],
    "madhukāra": ['cae', 'mw'],
    "madhukārin": ['mw'],
    "madhukārī": ['mw'],
    "madhukāṇḍa": ['mw'],
    "madhukūla": ['mw'],
    "madhukūṭa": ['mw'],
    "madhukṛt": ['cae', 'mw'],
    "madhukṣīra": ['mw'],
    "madhukṣīraka": ['mw'],
    "madhula": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "madhulagna": ['mw'],
    "madhulatā": ['mw'],
    "madhulaṭṭhikā": ['cped'],
    "madhuleha": ['mw'],
    "madhulehin": ['mw'],
    "madhulih": ['cae', 'ddsa', 'mw'],
    "madhulikā": ['ap90', 'mw'],
    "madhulolupa": ['mw'],
    "madhulāja": ['cped'],
    "madhulīha": ['cped'],
    "madhumada": ['cae', 'mw'],
    "madhumadya": ['mw'],
    "madhumaireya": ['mw'],
    "madhumajjan": ['mw'],
    "madhumakkhita": ['cped'],
    "madhumakṣa": ['mw'],
    "madhumakṣikā": ['mw'],
    "madhumakṣā": ['mw'],
    "madhumallī": ['mw'],
    "madhumant": ['cae'],
    "madhumanta": ['mw'],
    "madhumantha": ['mw'],
    "madhumastaka": ['mw'],
    "madhumat": ['ap90', 'gra', 'mw'],
    "madhumath": ['mw'],
    "madhumathana": ['mw'],
    "madhumathanavijaya": ['mw'],
    "madhumati": ['mw'],
    "madhumatigaṇeśa": ['mw'],
    "madhumatta": ['cae', 'mw'],
    "madhumattama": ['mw'],
    "madhumattā": ['mw'],
    "madhumatī": ['mw'],
    "madhumatīsaṃgameśvaratīrtha": ['mw'],
    "madhumaya": ['cae', 'mw'],
    "madhumeha": ['cped', 'mw'],
    "madhumehatva": ['mw'],
    "madhumehin": ['mw'],
    "madhumiśra": ['cae', 'mw'],
    "madhumuranarakavināśana": ['mw'],
    "madhumādhava": ['bhs', 'cae', 'mw'],
    "madhumādhavamāsa": ['mw'],
    "madhumādhavasahāya": ['mw'],
    "madhumādhavī": ['cae', 'mw'],
    "madhumādhvīka": ['mw'],
    "madhumālapattrikā": ['mw'],
    "madhumālatīnāṭaka": ['mw'],
    "madhumāraka": ['mw'],
    "madhumāsa": ['cae', 'mw'],
    "madhumāsamahotsava": ['mw'],
    "madhumāsāvatāra": ['mw'],
    "madhumāṃsa": ['cae', 'mw'],
    "madhumūla": ['mw'],
    "madhunandi": ['mw'],
    "madhunetṛ": ['mw'],
    "madhunighātin": ['mw'],
    "madhunihan": ['mw'],
    "madhunihantṛ": ['mw'],
    "madhunirgama": ['mw'],
    "madhuniṣūdana": ['mw'],
    "madhuntama": ['cae', 'mw'],
    "madhunālikeraka": ['mw'],
    "madhunālikerika": ['mw'],
    "madhunārikeraka": ['mw'],
    "madhunāḍī": ['cae', 'mw'],
    "madhunī": ['mw'],
    "madhupa": ['cae', 'cped', 'gra', 'mw'],
    "madhupadhvaja": ['mw'],
    "madhuparka": ['cae', 'mw'],
    "madhuparkadāna": ['mw'],
    "madhuparkamantra": ['mw'],
    "madhuparkanirṇaya": ['mw'],
    "madhuparkaprayoga": ['mw'],
    "madhuparkapāṇi": ['mw'],
    "madhuparkika": ['mw'],
    "madhuparkya": ['mw'],
    "madhuparkācamana": ['mw'],
    "madhuparṇi": ['cae', 'mw'],
    "madhuparṇikā": ['cae', 'mw'],
    "madhuparṇī": ['cae', 'mw'],
    "madhupati": ['mw'],
    "madhupavana": ['cae', 'mw'],
    "madhupaṭala": ['cae', 'cped', 'mw'],
    "madhupeya": ['cae', 'gra', 'mw'],
    "madhuphala": ['mw'],
    "madhuphalikā": ['mw'],
    "madhuphalā": ['mw'],
    "madhupiṅga": ['cae'],
    "madhupiṅgākṣa": ['mw'],
    "madhupiṇḍikā": ['cped'],
    "madhupluta": ['mw'],
    "madhuprameha": ['mw'],
    "madhuprapāta": ['mw'],
    "madhuprasaṅgamadhu": ['mw'],
    "madhupratīka": ['gra', 'mw'],
    "madhupratīkā": ['mw'],
    "madhupraṇaya": ['mw'],
    "madhupraṇayavat": ['mw'],
    "madhupriya": ['mw'],
    "madhuprāśana": ['mw'],
    "madhupsaras": ['cae', 'gra', 'mw'],
    "madhupura": ['mw'],
    "madhupuraripu": ['mw'],
    "madhupurī": ['mw'],
    "madhupuṣpa": ['mw'],
    "madhupuṣpā": ['mw'],
    "madhupā": ['cae', 'gra', 'mw'],
    "madhupākā": ['mw'],
    "madhupāla": ['mw'],
    "madhupālikā": ['mw'],
    "madhupāna": ['cae', 'mw'],
    "madhupānakala": ['mw'],
    "madhupārī": ['mw'],
    "madhupātama": ['mw'],
    "madhupātra": ['mw'],
    "madhupāyin": ['mw'],
    "madhupāṇi": ['gra', 'mw'],
    "madhupīlu": ['mw'],
    "madhupū": ['mw'],
    "madhupṛc": ['gra', 'mw'],
    "madhupṛṣṭha": ['gra', 'mw'],
    "madhura": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "madhurabhāṣin": ['cae', 'mw'],
    "madhurabhāṣitṛ": ['mw'],
    "madhurabījapūra": ['mw'],
    "madhuracārumañjusvaratā": ['mw'],
    "madhuragātra": ['mw'],
    "madhurajambīra": ['mw'],
    "madhuraka": ['ap90', 'ddsa', 'mw'],
    "madhurakajāta": ['cped'],
    "madhurakaṇṭaka": ['mw'],
    "madhurakaṇṭhin": ['mw'],
    "madhurakharjūrikā": ['mw'],
    "madhurakharjūrī": ['mw'],
    "madhuralatā": ['mw'],
    "madhuram": ['mw'],
    "madhuramaya": ['cae', 'mw'],
    "madhuranirghoṣa": ['bhs', 'mw'],
    "madhuranisvana": ['mw'],
    "madhurapaṭolī": ['mw'],
    "madhuraphala": ['mw'],
    "madhuraphalā": ['mw'],
    "madhurapragīta": ['mw'],
    "madhurapralāpin": ['cae', 'mw'],
    "madhurapriyadarśana": ['mw'],
    "madhurarāvin": ['cae', 'mw'],
    "madhurasa": ['cae', 'ddsa', 'mw'],
    "madhurasamaya": ['mw'],
    "madhurasambhāṣa": ['mw'],
    "madhurasravā": ['mw'],
    "madhurassara": ['cped'],
    "madhurasvana": ['mw'],
    "madhurasvara": ['bhs', 'cae', 'ddsa', 'mw'],
    "madhurasvaram": ['mw'],
    "madhurasā": ['mw'],
    "madhuratraya": ['mw'],
    "madhuratta": ['cped'],
    "madhuratva": ['mw'],
    "madhuratvaca": ['mw'],
    "madhuratā": ['ap90', 'cped', 'mw'],
    "madhuravacana": ['mw'],
    "madhuravadana": ['bhs'],
    "madhuravallī": ['mw'],
    "madhuravipāka": ['mw'],
    "madhuravāc": ['mw'],
    "madhuraya": ['mw'],
    "madhurayati": ['ap90'],
    "madhuraśuklamūtra": ['mw'],
    "madhuraśuklamūtratā": ['mw'],
    "madhuraśīla": ['mw'],
    "madhureṇa": ['mw'],
    "madhureṇu": ['mw'],
    "madhurikā": ['mw'],
    "madhurila": ['mw'],
    "madhuriman": ['ap90', 'cae', 'ddsa', 'mw'],
    "madhuripu": ['ddsa', 'mw'],
    "madhurita": ['ap90', 'ddsa'],
    "madhurodaka": ['mw'],
    "madhuropanyāsa": ['cae', 'mw'],
    "madhuruha": ['mw'],
    "madhurā": ['ddsa', 'mw'],
    "madhurākṣara": ['cae', 'ddsa', 'mw'],
    "madhurākṣaram": ['mw'],
    "madhurālābunī": ['mw'],
    "madhurālāpa": ['mw'],
    "madhurālāpanisargapaṇḍita": ['mw'],
    "madhurālāpā": ['mw'],
    "madhurāmla": ['mw'],
    "madhurāmlaka": ['mw'],
    "madhurāmlakaṣāya": ['mw'],
    "madhurāmlakaṭuka": ['mw'],
    "madhurāmlakāvya": ['mw'],
    "madhurāmlalavaṇa": ['mw'],
    "madhurāmlaphala": ['mw'],
    "madhurāmlatikta": ['mw'],
    "madhurāniruddha": ['mw'],
    "madhurāntaka": ['mw'],
    "madhurāsvāda": ['cae', 'mw'],
    "madhurāvaṭṭa": ['mw'],
    "madhurāṅgaka": ['mw'],
    "madhurāṣṭaka": ['mw'],
    "madhurī": ['mw'],
    "madhus": ['cae', 'ddsa', 'mw'],
    "madhusahāya": ['mw'],
    "madhusakha": ['mw'],
    "madhusambhava": ['mw'],
    "madhusammiśra": ['mw'],
    "madhusandṛśa": ['ddsa'],
    "madhusarpis": ['cae', 'mw'],
    "madhusaṃbhava": ['bhs'],
    "madhusaṃdhāna": ['mw'],
    "madhusaṃdṛśa": ['mw'],
    "madhusaṃkāśa": ['mw'],
    "madhusaṃśliṣṭa": ['mw'],
    "madhusena": ['mw'],
    "madhusiktha": ['bhs'],
    "madhusikthaka": ['mw'],
    "madhuskanda": ['mw'],
    "madhuskandha": ['bhs'],
    "madhusrava": ['cae', 'mw'],
    "madhusravas": ['mw'],
    "madhusravā": ['mw'],
    "madhussava": ['cped'],
    "madhusthāna": ['mw'],
    "madhustoka": ['cae', 'mw'],
    "madhusuhṛd": ['mw'],
    "madhusvara": ['mw'],
    "madhusya": ['mw'],
    "madhusyanda": ['mw'],
    "madhusyandin": ['mw'],
    "madhusyati": ['ap90'],
    "madhusārathi": ['mw'],
    "madhusāt": ['mw'],
    "madhusūdana": ['cae', 'mw'],
    "madhusūdanaśikṣā": ['mw'],
    "madhusūdanāyatana": ['mw'],
    "madhusūdanī": ['mw'],
    "madhusūkta": ['mw'],
    "madhutama": ['ap90'],
    "madhutaru": ['mw'],
    "madhutraya": ['mw'],
    "madhutva": ['cae', 'mw'],
    "madhutṛṇa": ['mw'],
    "madhuvacas": ['cae', 'gra', 'mw'],
    "madhuvallī": ['mw'],
    "madhuvana": ['cae', 'mw'],
    "madhuvanavrajavāsigosvāmiguṇaleśāṣṭaka": ['mw'],
    "madhuvarṇa": ['cae', 'gra', 'mw'],
    "madhuvarṇana": ['mw'],
    "madhuvat": ['cae', 'mw'],
    "madhuvaṭī": ['mw'],
    "madhuvidhvaṃsabhāskara": ['mw'],
    "madhuvidviṣ": ['mw'],
    "madhuvidyā": ['mw'],
    "madhuvilā": ['mw'],
    "madhuvrata": ['cae', 'gra', 'mw'],
    "madhuvratapati": ['mw'],
    "madhuvratavarūtha": ['mw'],
    "madhuvratī": ['mw'],
    "madhuvāc": ['mw'],
    "madhuvāhana": ['cae', 'gra', 'mw'],
    "madhuvāhin": ['cae', 'mw'],
    "madhuvāhinī": ['mw'],
    "madhuvāra": ['mw'],
    "madhuvāsava": ['bhs'],
    "madhuvātīya": ['mw'],
    "madhuvṛdh": ['gra', 'mw'],
    "madhuvṛkṣa": ['mw'],
    "madhuvṛṣa": ['mw'],
    "madhuyakṣī": ['bhs'],
    "madhuyaṣṭi": ['mw'],
    "madhuyaṣṭikā": ['mw'],
    "madhuyaṣṭī": ['mw'],
    "madhuśarkarā": ['mw'],
    "madhuścut": ['cae', 'gra', 'mw'],
    "madhuścyunnidhana": ['mw'],
    "madhuścyut": ['mw'],
    "madhuścyuta": ['cae', 'mw'],
    "madhuśeṣa": ['mw'],
    "madhuśigru": ['mw'],
    "madhuśigruka": ['mw'],
    "madhuśira": ['bhs'],
    "madhuśiṣṭa": ['mw'],
    "madhuśrava": ['mw'],
    "madhuśravā": ['mw'],
    "madhuśreṇi": ['mw'],
    "madhuśrī": ['cae', 'mw'],
    "madhuśukta": ['mw'],
    "madhuśvāsā": ['mw'],
    "madhuśākha": ['mw'],
    "madhuśīrṣaka": ['mw'],
    "madhuṣpanda": ['mw'],
    "madhuṣut": ['cae', 'gra', 'mw'],
    "madhuṣuttama": ['mw'],
    "madhuṣyanda": ['mw'],
    "madhuṣṭhāla": ['cae', 'mw'],
    "madhuṣṭhāna": ['mw'],
    "madhuṣṭhīla": ['mw'],
    "madhv": ['mw'],
    "madhva": ['cae', 'ddsa', 'mw'],
    "madhvad": ['cae', 'gra', 'mw'],
    "madhvaguru": ['mw'],
    "madhvaka": ['cae', 'ddsa', 'mw'],
    "madhvakaḥ": ['ap90'],
    "madhvakṣa": ['mw'],
    "madhvala": ['mw'],
    "madhvamata": ['mw'],
    "madhvamatakhaṇḍana": ['mw'],
    "madhvamatapradarśana": ['mw'],
    "madhvamataprakaraṇa": ['mw'],
    "madhvamatasaṃgrahaṭīkā": ['mw'],
    "madhvamatavidhvaṃsana": ['mw'],
    "madhvamukhabhaṅga": ['mw'],
    "madhvamukhamardana": ['mw'],
    "madhvamuktāvali": ['mw'],
    "madhvamāhātmya": ['mw'],
    "madhvarṇas": ['gra'],
    "madhvarṇaś": ['mw'],
    "madhvasahasranāmabhāṣya": ['mw'],
    "madhvasiddhānta": ['mw'],
    "madhvasiddhāntabhañjana": ['mw'],
    "madhvasiddhāntasāra": ['mw'],
    "madhvastuti": ['mw'],
    "madhvasya": ['mw'],
    "madhvatantracapeṭāpradīpa": ['mw'],
    "madhvatantradūṣaṇa": ['mw'],
    "madhvavaṃśāvalī": ['mw'],
    "madhvavedānta": ['mw'],
    "madhvavidhvaṃsana": ['mw'],
    "madhvavijaya": ['mw'],
    "madhvañc": ['mw'],
    "madhvaśva": ['mw'],
    "madhvaḥ": ['ap90'],
    "madhvaṣṭaka": ['mw'],
    "madhvaṣṭhīlā": ['mw'],
    "madhvijā": ['ap90', 'mw'],
    "madhvācārya": ['mw'],
    "madhvādhāra": ['mw'],
    "madhvāhuti": ['mw'],
    "madhvāhṇika": ['mw'],
    "madhvālopa": ['mw'],
    "madhvālu": ['mw'],
    "madhvāluka": ['mw'],
    "madhvāmra": ['mw'],
    "madhvāpāta": ['cae', 'ddsa', 'mw'],
    "madhvārthadhvaṃsinī": ['mw'],
    "madhvāsava": ['cae', 'cped', 'mw'],
    "madhvāsavakṣība": ['mw'],
    "madhvāsavanika": ['mw'],
    "madhvāsvāda": ['mw'],
    "madhvāvāsa": ['mw'],
    "madhvāśin": ['cae', 'mw'],
    "madhvṛc": ['mw'],
    "madhya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "madhyabha": ['mw'],
    "madhyabhakta": ['mw'],
    "madhyabhāga": ['cae', 'mw'],
    "madhyabhāva": ['mw'],
    "madhyacchāyā": ['mw'],
    "madhyacārin": ['cae', 'mw'],
    "madhyadanta": ['mw'],
    "madhyadeha": ['mw'],
    "madhyadeśa": ['cae', 'mw'],
    "madhyadeśika": ['bhs'],
    "madhyadeśya": ['mw'],
    "madhyadeśīya": ['mw'],
    "madhyadina": ['mw'],
    "madhyadīpaka": ['mw'],
    "madhyaga": ['cae', 'mw'],
    "madhyagandha": ['mw'],
    "madhyagata": ['cae', 'mw'],
    "madhyagrahaṇa": ['mw'],
    "madhyajainendravyākaraṇa": ['mw'],
    "madhyajihva": ['mw'],
    "madhyajyā": ['mw'],
    "madhyakarṇa": ['mw'],
    "madhyakaumudī": ['ddsa', 'mw'],
    "madhyakuru": ['mw'],
    "madhyakṣāmā": ['mw'],
    "madhyalagna": ['mw'],
    "madhyaloka": ['mw'],
    "madhyalokeśa": ['mw'],
    "madhyalīlā": ['mw'],
    "madhyam": ['mw'],
    "madhyama": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "madhyamabhṛtaka": ['mw'],
    "madhyamadhyā": ['mw'],
    "madhyamagati": ['mw'],
    "madhyamagrāma": ['mw'],
    "madhyamajāta": ['cae', 'mw'],
    "madhyamaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "madhyamakakṣā": ['mw'],
    "madhyamakavṛtti": ['mw'],
    "madhyamakeya": ['mw'],
    "madhyamakhaṇḍa": ['mw'],
    "madhyamakālaṃkāra": ['mw'],
    "madhyamakāloka": ['mw'],
    "madhyamakāṇḍa": ['mw'],
    "madhyamakīya": ['bhs'],
    "madhyamaloka": ['cae', 'mw'],
    "madhyamalokapāla": ['mw'],
    "madhyamalokendu": ['mw'],
    "madhyamandira": ['ddsa', 'mw'],
    "madhyamanoramā": ['mw'],
    "madhyamapada": ['mw'],
    "madhyamapadalopa": ['mw'],
    "madhyamapadalopin": ['ddsa', 'mw'],
    "madhyamaparṇa": ['mw'],
    "madhyamapuruṣa": ['cae', 'mw'],
    "madhyamapāṇḍava": ['mw'],
    "madhyamapūruṣa": ['mw'],
    "madhyamarekhā": ['mw'],
    "madhyamarātra": ['cae', 'mw'],
    "madhyamasaṃgraha": ['mw'],
    "madhyamastha": ['mw'],
    "madhyamastheya": ['mw'],
    "madhyamasthā": ['cae', 'mw'],
    "madhyamasvabhāva": ['mw'],
    "madhyamasvara": ['cae', 'mw'],
    "madhyamasāhasa": ['mw'],
    "madhyamavah": ['gra'],
    "madhyamavayas": ['mw'],
    "madhyamavayasa": ['cae'],
    "madhyamavayaska": ['mw'],
    "madhyamavāh": ['mw'],
    "madhyamayāna": ['mw'],
    "madhyamaśī": ['cae', 'gra', 'mw'],
    "madhyamaṇi": ['mw'],
    "madhyamaṭīkā": ['mw'],
    "madhyameśvara": ['mw'],
    "madhyameṣā": ['cae', 'mw'],
    "madhyameṣṭha": ['cae', 'mw'],
    "madhyameṣṭheya": ['mw'],
    "madhyameṣṭhā": ['cae', 'mw'],
    "madhyamika": ['mw'],
    "madhyamikavṛtti": ['mw'],
    "madhyamikā": ['ap90', 'mw'],
    "madhyamoccaistara": ['mw'],
    "madhyamotkhāta": ['mw'],
    "madhyamā": ['ddsa', 'mw'],
    "madhyamādhikāra": ['mw'],
    "madhyamādi": ['mw'],
    "madhyamādī": ['mw'],
    "madhyamāgama": ['bhs', 'mw'],
    "madhyamāharaṇa": ['mw'],
    "madhyamātreya": ['mw'],
    "madhyamāṅgiras": ['mw'],
    "madhyamāṅguli": ['mw'],
    "madhyamīya": ['mw'],
    "madhyanagara": ['mw'],
    "madhyandina": ['ddsa'],
    "madhyanihita": ['mw'],
    "madhyantika": ['bhs'],
    "madhyanya": ['ap90', 'mw'],
    "madhyaparimāṇa": ['mw'],
    "madhyapatita": ['ddsa', 'mw'],
    "madhyaprasūtā": ['mw'],
    "madhyapraviṣṭa": ['mw'],
    "madhyapāta": ['mw'],
    "madhyarekhā": ['mw'],
    "madhyarātra": ['cae', 'ddsa', 'mw'],
    "madhyarātrau": ['mw'],
    "madhyarātri": ['mw'],
    "madhyasiddhāntakaumudī": ['mw'],
    "madhyastha": ['cae', 'mw'],
    "madhyasthala": ['mw'],
    "madhyasthatā": ['cae', 'mw'],
    "madhyasthita": ['cae', 'mw'],
    "madhyasthityardha": ['mw'],
    "madhyasthitā": ['mw'],
    "madhyasthāna": ['cae', 'mw'],
    "madhyasthānadevatā": ['mw'],
    "madhyastrī": ['bhs'],
    "madhyasvarita": ['mw'],
    "madhyasūtra": ['mw'],
    "madhyatamas": ['mw'],
    "madhyatas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "madhyataḥkārin": ['mw'],
    "madhyatva": ['mw'],
    "madhyatā": ['cae', 'mw'],
    "madhyatāpinī": ['mw'],
    "madhyavallī": ['mw'],
    "madhyavartin": ['cae', 'mw'],
    "madhyavayas": ['cae', 'mw'],
    "madhyavidaraṇa": ['mw'],
    "madhyavivartin": ['mw'],
    "madhyavivekin": ['mw'],
    "madhyavṛtta": ['mw'],
    "madhyayava": ['mw'],
    "madhyayogin": ['mw'],
    "madhyaśarīra": ['mw'],
    "madhyaśāyin": ['mw'],
    "madhyaṃdina": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "madhyaṃdinagata": ['mw'],
    "madhyaṃdinasamaya": ['mw'],
    "madhyaṃdinārkasaṃtapta": ['mw'],
    "madhyaṃdinīya": ['mw'],
    "madhye": ['ap90', 'mw'],
    "madhyebhabandhana": ['mw'],
    "madhyecchandas": ['mw'],
    "madhyegaṅgam": ['mw'],
    "madhyeguru": ['mw'],
    "madhyejalāt": ['mw'],
    "madhyejaṭharam": ['mw'],
    "madhyejyotis": ['mw'],
    "madhyekṛtya": ['mw'],
    "madhyemadhyamāṅgulikarpūram": ['mw'],
    "madhyena": ['bhs', 'mw'],
    "madhyenadi": ['cae', 'mw'],
    "madhyenagaram": ['ddsa', 'mw'],
    "madhyenareśvarasabham": ['mw'],
    "madhyenidhana": ['mw'],
    "madhyepadmam": ['cae', 'mw'],
    "madhyepṛṣṭa": ['mw'],
    "madhyepṛṣṭham": ['cae', 'mw'],
    "madhyerathyam": ['mw'],
    "madhyeraṇam": ['cae', 'mw'],
    "madhyesabham": ['mw'],
    "madhyesamudram": ['cae', 'mw'],
    "madhyevindhyāntar": ['mw'],
    "madhyevindhyāṭavi": ['mw'],
    "madhyevyoma": ['mw'],
    "madhyevārdhi": ['mw'],
    "madhyevāri": ['mw'],
    "madhyeyajñam": ['mw'],
    "madhyeśmaśānam": ['mw'],
    "madhyima": ['bhs'],
    "madhyodātta": ['mw'],
    "madhyā": ['cae', 'ddsa', 'gra', 'mw'],
    "madhyādhidevana": ['mw'],
    "madhyāditya": ['ddsa', 'mw'],
    "madhyāhna": ['cae', 'mw'],
    "madhyāhnakriyā": ['mw'],
    "madhyāhnakāla": ['mw'],
    "madhyāhnakṛtya": ['mw'],
    "madhyāhnasamaya": ['mw'],
    "madhyāhnasavana": ['mw'],
    "madhyāhnasaṃdhyā": ['mw'],
    "madhyāhnasnānavidhi": ['mw'],
    "madhyāhnavelā": ['mw'],
    "madhyāhnenduprabhākarṇa": ['mw'],
    "madhyāhnika": ['mw'],
    "madhyāhāriṇīlipi": ['bhs', 'mw'],
    "madhyākṣaravistaralipi": ['bhs', 'mw'],
    "madhyāmlakesara": ['mw'],
    "madhyānta": ['mw'],
    "madhyāntavibhaṅgaśāstra": ['mw'],
    "madhyāntavibhāgaśāstra": ['mw'],
    "madhyāntayamaka": ['mw'],
    "madhyāntika": ['mw'],
    "madhyārjuna": ['mw'],
    "madhyārjunakṣetramāhātmya": ['mw'],
    "madhyārjunatīrtha": ['mw'],
    "madhyāsthi": ['mw'],
    "madhyāt": ['mw'],
    "madhyāvarṣa": ['cae', 'mw'],
    "madhyāyin": ['mw'],
    "madhyāyu": ['gra', 'mw'],
    "madhyāṅguli": ['mw'],
    "madhyāṅgulī": ['mw'],
    "madhūcchiṣṭa": ['cae', 'ddsa', 'mw'],
    "madhūcchiṣṭasthita": ['mw'],
    "madhūdaka": ['mw'],
    "madhūdakaprasravaṇa": ['mw'],
    "madhūdaśvita": ['mw'],
    "madhūdvāpa": ['mw'],
    "madhūdyuta": ['mw'],
    "madhūdyāna": ['cae', 'mw'],
    "madhūka": ['cae', 'ddsa', 'mw'],
    "madhūkacchavi": ['mw'],
    "madhūkamālā": ['mw'],
    "madhūkapuṣpa": ['mw'],
    "madhūkarasa": ['mw'],
    "madhūkasāra": ['mw'],
    "madhūkavrata": ['mw'],
    "madhūkaḥ": ['ap90'],
    "madhūla": ['mw'],
    "madhūlaka": ['cae', 'ddsa', 'mw'],
    "madhūlaḥ": ['ap90'],
    "madhūlika": ['mw'],
    "madhūlikā": ['ap90', 'mw'],
    "madhūlī": ['cae', 'mw'],
    "madhūpaghna": ['mw'],
    "madhūtsava": ['cae', 'mw'],
    "madhūttha": ['mw'],
    "madhūtthita": ['mw'],
    "madhūya": ['mw'],
    "madhūyu": ['cae', 'gra', 'mw'],
    "madhūṣita": ['mw'],
    "madi": ['cae', 'mw'],
    "madia": ['gra'],
    "madikā": ['cae', 'mw'],
    "madin": ['cae', 'ddsa', 'gra', 'mw'],
    "madira": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "madiradṛś": ['cae', 'mw'],
    "madiranayana": ['cae', 'mw'],
    "madirekṣaṇa": ['mw'],
    "madirekṣaṇavallabhā": ['mw'],
    "madironmatta": ['mw'],
    "madirotkaṭa": ['mw'],
    "madirā": ['ap90', 'cped', 'mw'],
    "madirāgṛha": ['mw'],
    "madirākṣa": ['cae', 'mw'],
    "madirāmadāndha": ['mw'],
    "madirāmaya": ['mw'],
    "madirārṇava": ['mw'],
    "madirāsakha": ['mw'],
    "madirāsava": ['mw'],
    "madirāsālā": ['mw'],
    "madirāvatī": ['mw'],
    "madirāvaśaga": ['mw'],
    "madirāyatanayanā": ['mw'],
    "madirāśva": ['mw'],
    "madiḥ": ['ap90'],
    "madiṣṇu": ['mw'],
    "madiṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "madiṣṭhā": ['ap90', 'mw'],
    "madodagra": ['cae', 'mw'],
    "madodarkā": ['mw'],
    "madoddhata": ['cae', 'mw'],
    "madodreka": ['mw'],
    "madollāpin": ['mw'],
    "madonmatta": ['cae', 'mw'],
    "madorjita": ['mw'],
    "madotkaṭa": ['cae', 'ddsa', 'mw'],
    "madotkaṭā": ['bhs', 'mw'],
    "madra": ['cae', 'ddsa', 'mw'],
    "madragāra": ['mw'],
    "madragāri": ['mw'],
    "madrahrada": ['mw'],
    "madraja": ['mw'],
    "madraka": ['ap90', 'mw'],
    "madrakagīti": ['mw'],
    "madrakapati": ['mw'],
    "madrakādhama": ['mw'],
    "madrakāra": ['mw'],
    "madrakūla": ['mw'],
    "madranagara": ['mw'],
    "madranābha": ['mw'],
    "madrapa": ['mw'],
    "madrarāja": ['mw'],
    "madrasadeśa": ['mw'],
    "madrasamaryāda": ['mw'],
    "madrasanīḍa": ['mw'],
    "madrasaveśa": ['mw'],
    "madrasavidha": ['mw'],
    "madrastrī": ['mw'],
    "madrasutā": ['mw'],
    "madravāṇija": ['mw'],
    "madraḥ": ['ap90'],
    "madraṃkara": ['mw'],
    "madreśa": ['mw'],
    "madreśvara": ['mw'],
    "madriac": ['gra'],
    "madriadrik": ['gra'],
    "madrik": ['cae', 'ddsa', 'gra', 'mw'],
    "madrikā": ['mw'],
    "madrikābhārya": ['mw'],
    "madrikākalpa": ['mw'],
    "madrikāmānin": ['mw'],
    "madrikāya": ['mw'],
    "madrukasthalī": ['mw'],
    "madrumarakantha": ['mw'],
    "madryac": ['gra'],
    "madryadrik": ['gra', 'mw'],
    "madryak": ['mw'],
    "madryañc": ['cae', 'ddsa', 'mw'],
    "madrā": ['ddsa', 'mw'],
    "madrākṛ": ['mw'],
    "madrārma": ['mw'],
    "madrāya": ['mw'],
    "madrāyate": ['ap90'],
    "madrāśmārma": ['mw'],
    "madrī": ['bhs', 'mw'],
    "madugha": ['cae', 'ddsa', 'mw'],
    "madura": ['mw'],
    "madvacana": ['mw'],
    "madvacanāt": ['mw'],
    "madvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "madvant": ['cae'],
    "madvargya": ['mw'],
    "madvargīya": ['mw'],
    "madvargīṇa": ['mw'],
    "madvat": ['cae', 'ddsa', 'mw'],
    "madvidha": ['cae', 'ddsa', 'mw'],
    "madvihīna": ['mw'],
    "madviyoga": ['mw'],
    "madya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "madyabhājana": ['mw'],
    "madyabhāṇḍa": ['cae', 'mw'],
    "madyabīja": ['mw'],
    "madyadruma": ['mw'],
    "madyakumbha": ['mw'],
    "madyakīṭa": ['mw'],
    "madyalālasa": ['mw'],
    "madyamaya": ['mw'],
    "madyamaṇḍa": ['mw'],
    "madyapa": ['cae', 'mw'],
    "madyapaṅka": ['mw'],
    "madyapura": ['bhs', 'mw'],
    "madyapuṣpā": ['mw'],
    "madyapuṣpī": ['mw'],
    "madyapāna": ['cae', 'mw'],
    "madyapāśana": ['mw'],
    "madyapīta": ['mw'],
    "madyasaṃdhāna": ['mw'],
    "madyavikraya": ['mw'],
    "madyavāsinī": ['mw'],
    "madyavīja": ['mw'],
    "madyājin": ['cae'],
    "madyākṣepa": ['mw'],
    "madyāmoda": ['mw'],
    "madyānnavikraya": ['cae'],
    "madyāsattaka": ['mw'],
    "madā": ['bhs'],
    "madāgha": ['mw'],
    "madāhva": ['mw'],
    "madākula": ['mw'],
    "madālasa": ['cae', 'mw'],
    "madālasacampū": ['mw'],
    "madālasanāṭaka": ['mw'],
    "madālasā": ['mw'],
    "madālasākhyāyikā": ['mw'],
    "madālasāpariṇaya": ['mw'],
    "madālāpin": ['mw'],
    "madāmada": ['ap90', 'cae', 'mw'],
    "madāmbara": ['mw'],
    "madāmbhas": ['cae', 'mw'],
    "madāmbu": ['cae', 'mw'],
    "madāmnāta": ['mw'],
    "madāndha": ['cae', 'mw'],
    "madāndhā": ['mw'],
    "madāpanaya": ['mw'],
    "madāra": ['mw'],
    "madāraḥ": ['ap90'],
    "madārmada": ['mw'],
    "madātaṅka": ['mw'],
    "madātmānanda": ['mw'],
    "madātyaya": ['ddsa', 'mw'],
    "madātyayita": ['mw'],
    "madāvant": ['cae'],
    "madāvasthā": ['cae', 'mw'],
    "madāvat": ['mw'],
    "madāśraya": ['cae'],
    "madāḍhya": ['mw'],
    "madī": ['mw'],
    "madīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "madīṇu": ['mw'],
    "maga": ['cae', 'cped', 'ddsa', 'mw'],
    "magadha": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "magadhadeśa": ['cae', 'mw'],
    "magadhaka": ['mw'],
    "magadhalipi": ['bhs', 'mw'],
    "magadhaparibhāṣā": ['mw'],
    "magadhapratiṣṭha": ['mw'],
    "magadhapurī": ['mw'],
    "magadhavaṃśaja": ['mw'],
    "magadhaḥ": ['ap90'],
    "magadheśvara": ['mw'],
    "magadhodbhava": ['mw'],
    "magadhodbhavā": ['mw'],
    "magadhya": ['mw'],
    "magadhyati": ['ap90'],
    "magadhā": ['mw'],
    "magadhājira": ['mw'],
    "magadhīya": ['ap90', 'mw'],
    "magadin": ['mw'],
    "magala": ['mw'],
    "maganda": ['cae', 'ddsa', 'gra', 'mw'],
    "magara": ['bhs'],
    "magasa": ['mw'],
    "magasira": ['cped'],
    "magava": ['bhs', 'mw'],
    "magavyakti": ['mw'],
    "magaḥ": ['ap90'],
    "magga": ['cped'],
    "maggabhāvanā": ['cped'],
    "maggadesaka": ['cped'],
    "maggadūsī": ['cped'],
    "maggakilanta": ['cped'],
    "maggakkhāyī": ['cped'],
    "maggakusala": ['cped'],
    "maggamūḷha": ['cped'],
    "maggana": ['cped'],
    "magganā": ['cped'],
    "maggapaṭipanna": ['cped'],
    "maggasacca": ['cped'],
    "maggati": ['cped'],
    "maggavidū": ['cped'],
    "maggaññū": ['cped'],
    "maggañāṇa": ['cped'],
    "maggaṅga": ['cped'],
    "maggaṭṭha": ['cped'],
    "maggeti": ['cped'],
    "maggi": ['cped'],
    "maggika": ['cped'],
    "maggita": ['cped'],
    "maggitvā": ['cped'],
    "magha": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "maghadeya": ['cae', 'gra', 'mw'],
    "maghagandha": ['mw'],
    "magharava": ['mw'],
    "maghasvāmin": ['mw'],
    "maghatti": ['cae', 'ddsa', 'gra', 'mw'],
    "maghava": ['cae', 'mw'],
    "maghavan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "maghavanmuktakuliśa": ['mw'],
    "maghavannagara": ['mw'],
    "maghavant": ['cae', 'cped'],
    "maghavat": ['gra', 'mw'],
    "maghavattva": ['cae', 'ddsa', 'gra', 'mw'],
    "maghavaḥ": ['ap90'],
    "maghaḥ": ['ap90'],
    "maghaṣṭu": ['mw'],
    "maghnīprastha": ['mw'],
    "maghā": ['ap90', 'bhs', 'ddsa', 'mw'],
    "maghābhava": ['mw'],
    "maghābhū": ['mw'],
    "maghātrayodaśī": ['mw'],
    "maghātrayodaśīśrāddha": ['mw'],
    "maghī": ['bhs'],
    "maghīprastha": ['mw'],
    "magna": ['ap90', 'cae', 'ddsa', 'mw'],
    "magu": ['mw'],
    "maguli": ['bhs'],
    "magundī": ['cae', 'mw'],
    "mah": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "maha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mahabbala": ['cped'],
    "mahabbhaya": ['cped'],
    "mahac": ['mw'],
    "mahacchabda": ['ddsa', 'mw'],
    "mahad": ['mw'],
    "mahada": ['mw'],
    "mahadabhikhya": ['ddsa', 'mw'],
    "mahadbhaya": ['cae', 'mw'],
    "mahadbhū": ['mw'],
    "mahadbhūta": ['mw'],
    "mahadbhūtādhipati": ['mw'],
    "mahadbila": ['mw'],
    "mahaddhana": ['cped'],
    "mahadgata": ['bhs', 'mw'],
    "mahadgaurava": ['mw'],
    "mahadguṇa": ['mw'],
    "mahadguṇatva": ['mw'],
    "mahadvat": ['mw'],
    "mahadvyatikrama": ['mw'],
    "mahadvāruṇī": ['mw'],
    "mahadyuman": ['mw'],
    "mahadāvāsa": ['mw'],
    "mahadāyudha": ['mw'],
    "mahadāścaryam": ['mw'],
    "mahadāśraya": ['mw'],
    "mahadāśā": ['mw'],
    "mahaggata": ['cped'],
    "mahaggha": ['cped'],
    "mahagghasa": ['cped'],
    "mahagghatā": ['cped'],
    "mahaikoddiṣṭa": ['mw'],
    "mahailā": ['mw'],
    "mahairaṇḍa": ['mw'],
    "mahaitareya": ['ddsa', 'mw'],
    "mahaiśvarya": ['mw'],
    "mahaka": ['mw'],
    "mahakaḥ": ['ap90'],
    "mahakka": ['mw'],
    "mahakkaḥ": ['ap90'],
    "mahalla": ['bhs', 'cae', 'mw'],
    "mahallaka": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "mahallakatara": ['cped'],
    "mahallaḥ": ['ap90'],
    "mahallika": ['mw'],
    "mahallikā": ['cped', 'mw'],
    "mahamadaedala": ['mw'],
    "mahammada": ['mw'],
    "mahan": ['cae', 'ddsa', 'gra', 'mw'],
    "mahana": ['cae', 'ddsa'],
    "mahant": ['cae'],
    "mahanta": ['cped', 'mw'],
    "mahantabhāva": ['cped'],
    "mahantaka": ['bhs'],
    "mahantara": ['cped'],
    "mahantī": ['cped'],
    "mahanīya": ['ap90', 'cae', 'cped', 'mw'],
    "mahanīyakīrti": ['mw'],
    "mahanīyamūrti": ['mw'],
    "mahanīyaśāsana": ['mw'],
    "mahapphala": ['cped'],
    "mahapphalatara": ['cped'],
    "mahar": ['ap90', 'cae', 'ddsa', 'mw'],
    "maharddhi": ['cae', 'mw'],
    "maharddhika": ['bhs', 'cae'],
    "maharddhimat": ['mw'],
    "maharddhin": ['cae'],
    "maharddhiprāpta": ['bhs', 'mw'],
    "mahareṇu": ['mw'],
    "maharjagat": ['mw'],
    "maharloka": ['cae', 'ddsa', 'mw'],
    "mahartvij": ['cae', 'ddsa', 'mw'],
    "mahartviktva": ['mw'],
    "maharṣabha": ['cae', 'mw'],
    "maharṣi": ['cae', 'ddsa', 'mw'],
    "mahas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mahasa": ['mw'],
    "mahasena": ['mw'],
    "mahasenanareśvara": ['mw'],
    "mahasoṇa": ['mw'],
    "mahastva": ['mw'],
    "mahasvant": ['cae'],
    "mahasvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "mahasvin": ['cae', 'ddsa', 'mw'],
    "mahat": ['ap90', 'bhs', 'ddsa', 'gra', 'mw'],
    "mahati": ['cped'],
    "mahatkatha": ['mw'],
    "mahatkula": ['ddsa', 'mw'],
    "mahatkāṇḍa": ['mw'],
    "mahatkṣetra": ['mw'],
    "mahatpati": ['mw'],
    "mahatsena": ['mw'],
    "mahatsevā": ['mw'],
    "mahatsthāna": ['mw'],
    "mahatta": ['cped'],
    "mahattama": ['cae', 'mw'],
    "mahattamapada": ['mw'],
    "mahattara": ['ap90', 'cae', 'mw'],
    "mahattaraka": ['mw'],
    "mahattarakaḥ": ['ap90'],
    "mahattarakā": ['bhs'],
    "mahattarikā": ['mw'],
    "mahattarā": ['mw'],
    "mahattarī": ['mw'],
    "mahattarītārā": ['bhs'],
    "mahattattva": ['mw'],
    "mahattva": ['mw'],
    "mahattvarahita": ['mw'],
    "mahattvaṃ": ['ap90'],
    "mahattā": ['cae', 'mw'],
    "mahatā": ['ddsa', 'mw'],
    "mahatī": ['ap90', 'bhs', 'cped', 'mw'],
    "mahaudanī": ['mw'],
    "mahaudavāhi": ['mw'],
    "mahaugha": ['ddsa', 'mw'],
    "mahaujas": ['cae', 'mw'],
    "mahaujasa": ['mw'],
    "mahaujaska": ['bhs', 'mw'],
    "mahaujasī": ['mw'],
    "mahauṣadha": ['bhs', 'cae', 'mw'],
    "mahauṣadhi": ['bhs', 'cae', 'mw'],
    "mahauṣadhisūkta": ['mw'],
    "mahauṣadhī": ['cae', 'mw'],
    "mahavihāravāsin": ['bhs'],
    "mahavīrya": ['mw'],
    "mahaye": ['cae', 'mw'],
    "mahayya": ['cae', 'mw'],
    "mahayāyia": ['gra'],
    "mahayāyya": ['gra', 'mw'],
    "mahaḥ": ['ap90'],
    "mahaṃgata": ['bhs'],
    "mahaṃkāla": ['mw'],
    "mahaṃtaḥ": ['ap90'],
    "mahaṇṇava": ['cped'],
    "mahaṛṣi": ['mw'],
    "mahe": ['cae', 'ddsa'],
    "mahebhya": ['mw'],
    "maheccha": ['ddsa', 'mw'],
    "mahecchatā": ['mw'],
    "mahelikā": ['bhs', 'mw'],
    "mahelā": ['ddsa', 'mw'],
    "mahelāpāda": ['mw'],
    "mahemate": ['cae', 'gra'],
    "mahemati": ['mw'],
    "mahenadi": ['cae', 'gra', 'mw'],
    "mahenda": ['ddsa'],
    "mahendra": ['bhs', 'cae', 'mw'],
    "mahendracāpa": ['cae', 'mw'],
    "mahendradeva": ['bhs'],
    "mahendradevī": ['mw'],
    "mahendradhvaja": ['mw'],
    "mahendragupta": ['mw'],
    "mahendraguru": ['mw'],
    "mahendrajit": ['mw'],
    "mahendraka": ['bhs'],
    "mahendrakadalī": ['mw'],
    "mahendraketu": ['mw'],
    "mahendramahotsava": ['mw'],
    "mahendramandira": ['cae', 'mw'],
    "mahendramantrin": ['mw'],
    "mahendranagarī": ['mw'],
    "mahendranātha": ['mw'],
    "mahendrapāla": ['mw'],
    "mahendrasiṃha": ['mw'],
    "mahendratva": ['mw'],
    "mahendravarman": ['mw'],
    "mahendravāruṇī": ['mw'],
    "mahendrayāgaprayoga": ['mw'],
    "mahendrayājin": ['mw'],
    "mahendraśakti": ['mw'],
    "mahendriya": ['mw'],
    "mahendrotsava": ['mw'],
    "mahendrā": ['mw'],
    "mahendrācāryaśiṣya": ['mw'],
    "mahendrāditya": ['mw'],
    "mahendrādri": ['mw'],
    "mahendrāṇī": ['mw'],
    "mahendrī": ['mw'],
    "mahendrīya": ['mw'],
    "maheraṇā": ['mw'],
    "maheruṇā": ['mw'],
    "mahesakkha": ['cped'],
    "mahesi": ['cped'],
    "mahesī": ['cped'],
    "mahettha": ['mw'],
    "mahevṛdh": ['mw'],
    "maheśa": ['cae', 'ddsa', 'mw'],
    "maheśabandhu": ['mw'],
    "maheśacandra": ['mw'],
    "maheśaliṅga": ['mw'],
    "maheśanandin": ['mw'],
    "maheśanetra": ['mw'],
    "maheśanārāyaṇa": ['mw'],
    "maheśasaṃhitā": ['mw'],
    "maheśatīrtha": ['mw'],
    "maheśitṛ": ['mw'],
    "maheśvara": ['bhs', 'cae', 'mw'],
    "maheśvarabhaṭṭa": ['mw'],
    "maheśvarabhaṭṭīya": ['mw'],
    "maheśvaradatta": ['bhs', 'mw'],
    "maheśvaradharmādharma": ['mw'],
    "maheśvaradīkṣita": ['mw'],
    "maheśvaradīkṣitīya": ['mw'],
    "maheśvaradīpa": ['mw'],
    "maheśvarakaracyutā": ['mw'],
    "maheśvaraliṅga": ['mw'],
    "maheśvaranyāyālaṃkāra": ['mw'],
    "maheśvarasiddhānta": ['mw'],
    "maheśvarasiṃha": ['mw'],
    "maheśvaratva": ['mw'],
    "maheśvaratīrtha": ['mw'],
    "maheśvaravaidya": ['mw'],
    "maheśvarānanda": ['mw'],
    "maheśvarī": ['mw'],
    "maheśvarīya": ['mw'],
    "maheśākhya": ['bhs', 'mw'],
    "maheśākhyatā": ['bhs'],
    "maheśāna": ['mw'],
    "maheśānabandhu": ['mw'],
    "maheśānī": ['mw'],
    "maheṃdra": ['ap90'],
    "maheṣu": ['cae', 'ddsa', 'mw'],
    "maheṣudhi": ['cae', 'mw'],
    "maheṣvāsa": ['cae', 'mw'],
    "mahi": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mahiccha": ['cped'],
    "mahicchatā": ['cped'],
    "mahidatta": ['mw'],
    "mahiddhika": ['cped'],
    "mahidāsa": ['mw'],
    "mahidāsabudha": ['mw'],
    "mahikeru": ['cae', 'gra', 'mw'],
    "mahikā": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "mahikāṃśu": ['mw'],
    "mahikṣatra": ['gra', 'mw'],
    "mahilā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "mahilāhvayā": ['mw'],
    "mahilākhyā": ['mw'],
    "mahilāpāda": ['mw'],
    "mahilāropya": ['mw'],
    "mahilāropyaṃ": ['ap90'],
    "mahima": ['mw'],
    "mahimabhaṭṭa": ['mw'],
    "mahimagha": ['gra', 'mw'],
    "mahiman": ['ap90', 'cae', 'gra', 'mw'],
    "mahimant": ['cae'],
    "mahimasiṃhagaṇi": ['mw'],
    "mahimastava": ['mw'],
    "mahimasundara": ['mw'],
    "mahimat": ['mw'],
    "mahimataraṃgaṭīkā": ['mw'],
    "mahimati": ['gra', 'mw'],
    "mahimna": ['mw'],
    "mahimnā": ['mw'],
    "mahimnāra": ['mw'],
    "mahimodaya": ['mw'],
    "mahimā": ['mw'],
    "mahimātaraṃga": ['mw'],
    "mahimāvat": ['mw'],
    "mahin": ['cae', 'ddsa', 'gra', 'mw'],
    "mahina": ['cae', 'gra', 'mw'],
    "mahinadī": ['gra', 'mw'],
    "mahinasa": ['mw'],
    "mahinda": ['cped'],
    "mahindhaka": ['mw'],
    "mahintama": ['mw'],
    "mahinā": ['cae', 'mw'],
    "mahipa": ['mw'],
    "mahipati": ['mw'],
    "mahira": ['mw'],
    "mahirakula": ['mw'],
    "mahiratna": ['cae', 'gra', 'mw'],
    "mahiraḥ": ['ap90'],
    "mahisa": ['cped'],
    "mahisamaṇḍala": ['cped'],
    "mahissara": ['cped'],
    "mahita": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mahitva": ['gra', 'mw'],
    "mahitvana": ['gra', 'mw'],
    "mahitvanā": ['mw'],
    "mahitvā": ['cped'],
    "mahitā": ['cae', 'ddsa', 'mw'],
    "mahitāmbhas": ['mw'],
    "mahivrata": ['cae', 'gra', 'mw'],
    "mahivṛdh": ['gra', 'mw'],
    "mahiṃdhakaḥ": ['ap90'],
    "mahiṃdhara": ['bhs'],
    "mahiṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "mahiṣacara": ['mw'],
    "mahiṣadhvaja": ['mw'],
    "mahiṣaga": ['mw'],
    "mahiṣaghnī": ['mw'],
    "mahiṣaka": ['mw'],
    "mahiṣakanda": ['mw'],
    "mahiṣamardinī": ['mw'],
    "mahiṣamardinītantra": ['mw'],
    "mahiṣapāla": ['mw'],
    "mahiṣapālaka": ['mw'],
    "mahiṣasūdanī": ['mw'],
    "mahiṣatva": ['ddsa', 'mw'],
    "mahiṣavallī": ['mw'],
    "mahiṣavāhana": ['mw'],
    "mahiṣayamana": ['mw'],
    "mahiṣaśataka": ['mw'],
    "mahiṣaḥ": ['ap90'],
    "mahiṣi": ['mw'],
    "mahiṣita": ['mw'],
    "mahiṣmat": ['ap90', 'mw'],
    "mahiṣmatī": ['mw'],
    "mahiṣotsargavidhi": ['mw'],
    "mahiṣvani": ['mw'],
    "mahiṣvanta": ['mw'],
    "mahiṣvat": ['gra'],
    "mahiṣvaṇi": ['gra'],
    "mahiṣākṣa": ['mw'],
    "mahiṣākṣaka": ['mw'],
    "mahiṣānanā": ['mw'],
    "mahiṣārdana": ['mw'],
    "mahiṣāsura": ['mw'],
    "mahiṣāsuraghātinī": ['mw'],
    "mahiṣāsuramajjothā": ['mw'],
    "mahiṣāsuramardinī": ['mw'],
    "mahiṣāsuramardinīstotra": ['mw'],
    "mahiṣāsurasambhava": ['mw'],
    "mahiṣāsurasūdanī": ['mw'],
    "mahiṣāsurāpahā": ['mw'],
    "mahiṣāsurārdinī": ['mw'],
    "mahiṣī": ['ap90', 'bhs', 'ddsa', 'gra', 'mw'],
    "mahiṣībhāva": ['mw'],
    "mahiṣīdāna": ['mw'],
    "mahiṣīdānamantra": ['mw'],
    "mahiṣīdānaprayoga": ['mw'],
    "mahiṣīdānavidhi": ['mw'],
    "mahiṣīgoṣṭha": ['mw'],
    "mahiṣīkanda": ['mw'],
    "mahiṣīpa": ['mw'],
    "mahiṣīpriyā": ['mw'],
    "mahiṣīpāla": ['mw'],
    "mahiṣīstambha": ['mw'],
    "mahiṣīśataka": ['mw'],
    "mahiṣṭha": ['ap90', 'cae', 'ddsa', 'mw'],
    "mahlaṇa": ['mw'],
    "mahlaṇasvāmin": ['mw'],
    "mahlāṇapura": ['mw'],
    "mahmadakhāna": ['mw'],
    "mahman": ['cae', 'ddsa', 'mw'],
    "mahna": ['mw'],
    "mahnyā": ['mw'],
    "mahocchraya": ['mw'],
    "mahocchrāyavat": ['mw'],
    "mahodadhi": ['bhs', 'cae', 'cped', 'mw'],
    "mahodadhija": ['mw'],
    "mahodara": ['cae', 'cped', 'mw'],
    "mahodaramukha": ['mw'],
    "mahodareśvara": ['mw'],
    "mahodarya": ['mw'],
    "mahodarī": ['mw'],
    "mahodaya": ['ap90', 'cae', 'mw'],
    "mahodayasvāmin": ['mw'],
    "mahodayā": ['mw'],
    "mahodhas": ['mw'],
    "mahodreka": ['mw'],
    "mahodyama": ['mw'],
    "mahodyoga": ['mw'],
    "mahodāra": ['mw'],
    "mahogha": ['cped'],
    "mahogratantra": ['mw'],
    "mahokṣa": ['cae', 'ddsa', 'mw'],
    "mahokṣatā": ['mw'],
    "maholkā": ['cae', 'mw'],
    "maholkādhārin": ['bhs'],
    "maholūkhalamekhalā": ['bhs'],
    "mahonmada": ['mw'],
    "mahonmāna": ['mw'],
    "mahonnata": ['mw'],
    "mahonnati": ['mw'],
    "mahopakāra": ['mw'],
    "mahopamā": ['mw'],
    "mahopaniṣad": ['mw'],
    "mahopaniṣada": ['mw'],
    "mahopaniṣaddīpikā": ['mw'],
    "mahopasthānaprayoga": ['mw'],
    "mahopekṣā": ['mw'],
    "mahopādhyāya": ['cae', 'mw'],
    "mahopāsaka": ['mw'],
    "mahoraga": ['cae', 'cped', 'mw'],
    "mahoragadaṣṭa": ['mw'],
    "mahoragaka": ['bhs'],
    "mahoragalipi": ['bhs', 'mw'],
    "mahoraska": ['cae', 'mw'],
    "mahormimat": ['mw'],
    "mahormin": ['mw'],
    "mahotkā": ['mw'],
    "mahotpala": ['mw'],
    "mahotpāta": ['mw'],
    "mahotpātaprāyaścitta": ['mw'],
    "mahotsava": ['cae', 'mw'],
    "mahotsavamaya": ['mw'],
    "mahotsavavidhi": ['mw'],
    "mahotsavin": ['mw'],
    "mahotsaṅga": ['bhs', 'mw'],
    "mahotsāha": ['cae', 'mw'],
    "mahottama": ['mw'],
    "mahoviśīya": ['mw'],
    "mahoṣṭha": ['cae', 'mw'],
    "mahoṭikā": ['mw'],
    "mahoṭī": ['mw'],
    "mahya": ['ddsa', 'mw'],
    "mahyam": ['ddsa'],
    "mahyuttara": ['mw'],
    "mahyā": ['mw'],
    "mahā": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mahā-upāsaka": ['cped'],
    "mahā-upāsikā": ['cped'],
    "mahābabhru": ['mw'],
    "mahābala": ['bhs', 'cae', 'mw'],
    "mahābalakavi": ['mw'],
    "mahābalaparākrama": ['mw'],
    "mahābalarāsa": ['mw'],
    "mahābalasūtra": ['bhs', 'mw'],
    "mahābalavegasthāma": ['bhs'],
    "mahābalaśākya": ['mw'],
    "mahābaleśvara": ['mw'],
    "mahābali": ['mw'],
    "mahābalā": ['bhs', 'mw'],
    "mahābalākṣa": ['bhs', 'mw'],
    "mahābandha": ['mw'],
    "mahābandhana": ['cped'],
    "mahābhadra": ['mw'],
    "mahābhadrā": ['mw'],
    "mahābhairava": ['mw'],
    "mahābhairavatantra": ['mw'],
    "mahābhairavā": ['bhs'],
    "mahābharī": ['mw'],
    "mahābhauma": ['mw'],
    "mahābhaya": ['cae', 'mw'],
    "mahābhaṭa": ['mw'],
    "mahābhaṭṭārikā": ['mw'],
    "mahābhaṭṭārikārcāratna": ['mw'],
    "mahābhaṭṭīvyākaraṇa": ['mw'],
    "mahābherīhāraka": ['mw'],
    "mahābherīhārakaparivarta": ['mw'],
    "mahābhijana": ['cae', 'mw'],
    "mahābhijanajāta": ['mw'],
    "mahābhijñājñānābhibhū": ['bhs', 'mw'],
    "mahābhikṣu": ['mw'],
    "mahābhimāna": ['mw'],
    "mahābhiniṣkramaṇa": ['mw'],
    "mahābhisyandin": ['mw'],
    "mahābhisyanditamatva": ['mw'],
    "mahābhisyanditva": ['mw'],
    "mahābhiyoga": ['cae', 'mw'],
    "mahābhiṣa": ['mw'],
    "mahābhiṣava": ['mw'],
    "mahābhiṣeka": ['mw'],
    "mahābhiṣekaprayoga": ['mw'],
    "mahābhiṣekavidhi": ['mw'],
    "mahābhoga": ['cae', 'cped', 'mw'],
    "mahābhogavat": ['mw'],
    "mahābhogin": ['mw'],
    "mahābhogā": ['mw'],
    "mahābhoja": ['cae', 'mw'],
    "mahābhoṭa": ['mw'],
    "mahābhoṭadeśa": ['mw'],
    "mahābhra": ['cae', 'mw'],
    "mahābhraghoṣa": ['mw'],
    "mahābhuja": ['bhs', 'cae', 'mw'],
    "mahābhāga": ['bhs', 'cae', 'mw'],
    "mahābhāgadheya": ['cae'],
    "mahābhāgatva": ['mw'],
    "mahābhāgatā": ['mw'],
    "mahābhāgavata": ['mw'],
    "mahābhāgin": ['cae', 'mw'],
    "mahābhāgya": ['cae', 'mw'],
    "mahābhāgyatā": ['mw'],
    "mahābhāgā": ['bhs', 'mw'],
    "mahābhāra": ['mw'],
    "mahābhārata": ['cae', 'mw'],
    "mahābhāratadarpaṇa": ['mw'],
    "mahābhāratakūṭoddāra": ['mw'],
    "mahābhāratamañjarī": ['mw'],
    "mahābhāratamīmāṃsā": ['mw'],
    "mahābhāratapañcaratna": ['mw'],
    "mahābhāratasamuccaya": ['mw'],
    "mahābhāratasaptatiśloka": ['mw'],
    "mahābhāratasaṃgraha": ['mw'],
    "mahābhāratasaṃgrahadīpikā": ['mw'],
    "mahābhāratasphuṭaśloka": ['mw'],
    "mahābhāratasāra": ['mw'],
    "mahābhāratasārasaṃgraha": ['mw'],
    "mahābhāratasūci": ['mw'],
    "mahābhāratatātparya": ['mw'],
    "mahābhāratatātparyanirṇaya": ['mw'],
    "mahābhāratatātparyanirṇayapramāṇasaṃgraha": ['mw'],
    "mahābhāratatātparyaprakāśasaṃketa": ['mw'],
    "mahābhāratatātparyarakṣā": ['mw'],
    "mahābhāratatātparyasaṃgraha": ['mw'],
    "mahābhāratavivaraṇastotra": ['mw'],
    "mahābhāratavyākhyāna": ['mw'],
    "mahābhārataślokopanyāsa": ['mw'],
    "mahābhārataśravaṇavidhi": ['mw'],
    "mahābhāratika": ['mw'],
    "mahābhāratoddhṛtasāraśloka": ['mw'],
    "mahābhāratādhyāyānukramaṇī": ['mw'],
    "mahābhāratādiśloka": ['mw'],
    "mahābhāskaraṭīkā": ['mw'],
    "mahābhāsura": ['mw'],
    "mahābhāsvara": ['mw'],
    "mahābhāṇḍa": ['mw'],
    "mahābhāṇḍāgāra": ['mw'],
    "mahābhāṣya": ['cae', 'mw'],
    "mahābhāṣyadīpikā": ['mw'],
    "mahābhāṣyakāra": ['mw'],
    "mahābhāṣyapradīpa": ['mw'],
    "mahābhāṣyaprakāśikā": ['mw'],
    "mahābhāṣyaratnāvalī": ['mw'],
    "mahābhāṣyasphūrti": ['mw'],
    "mahābhāṣyatripadī": ['mw'],
    "mahābhāṣyatripadīvyākhyāna": ['mw'],
    "mahābhāṣyavyākhyā": ['mw'],
    "mahābhāṣyavārttika": ['mw'],
    "mahābhāṣyaṭīkā": ['mw'],
    "mahābhīma": ['mw'],
    "mahābhīru": ['mw'],
    "mahābhīta": ['mw'],
    "mahābhīti": ['mw'],
    "mahābhītā": ['mw'],
    "mahābhīśu": ['cae', 'mw'],
    "mahābhīṣaṇaka": ['cae', 'mw'],
    "mahābhīṣma": ['bhs', 'mw'],
    "mahābhūmi": ['cae', 'mw'],
    "mahābhūmika": ['mw'],
    "mahābhūta": ['cae', 'cped', 'mw'],
    "mahābhūtadāna": ['mw'],
    "mahābhūtaghaṭa": ['mw'],
    "mahābhūtasamatāsādhana": ['bhs'],
    "mahābhūṣaṇa": ['mw'],
    "mahābhṛṅga": ['mw'],
    "mahābila": ['cae', 'mw'],
    "mahābimbara": ['bhs', 'mw'],
    "mahābja": ['mw'],
    "mahābodhi": ['bhs', 'mw'],
    "mahābodhisaṃghārāma": ['mw'],
    "mahābodhyaṅgavatī": ['bhs', 'mw'],
    "mahābrahma": ['bhs', 'mw'],
    "mahābrahman": ['mw'],
    "mahābrahmapurohita": ['bhs'],
    "mahābrāhmaṇa": ['cae', 'mw'],
    "mahābrāhmaṇabhāgya": ['mw'],
    "mahābuddha": ['mw'],
    "mahābuddharūpa": ['mw'],
    "mahābuddhi": ['cae', 'mw'],
    "mahābudhna": ['mw'],
    "mahābuśa": ['mw'],
    "mahābādha": ['mw'],
    "mahābāhu": ['cae', 'mw'],
    "mahābārhata": ['mw'],
    "mahābīja": ['mw'],
    "mahābījya": ['mw'],
    "mahābṛhatī": ['cae', 'mw'],
    "mahācaitanya": ['mw'],
    "mahācaitya": ['bhs'],
    "mahācakra": ['ddsa', 'mw'],
    "mahācakrapraveśajñānamudrā": ['mw'],
    "mahācakravartin": ['mw'],
    "mahācakravartitā": ['mw'],
    "mahācakravāla": ['mw'],
    "mahācakravāḍa": ['bhs', 'mw'],
    "mahācala": ['cae', 'mw'],
    "mahācamasa": ['mw'],
    "mahācampā": ['mw'],
    "mahācamū": ['mw'],
    "mahācandra": ['bhs', 'mw'],
    "mahācapalā": ['cae', 'mw'],
    "mahācaryā": ['mw'],
    "mahācaturaka": ['mw'],
    "mahācañcū": ['mw'],
    "mahācaṇḍa": ['mw'],
    "mahācaṇḍā": ['mw'],
    "mahācaṇḍī": ['mw'],
    "mahāchada": ['mw'],
    "mahāchidrā": ['mw'],
    "mahāchāya": ['mw'],
    "mahāchāyā": ['bhs'],
    "mahācit": ['mw'],
    "mahācitrapāṭala": ['bhs', 'mw'],
    "mahācitta": ['mw'],
    "mahācittva": ['mw'],
    "mahācittā": ['mw'],
    "mahācunda": ['bhs', 'mw'],
    "mahācārya": ['mw'],
    "mahācārī": ['mw'],
    "mahācīna": ['mw'],
    "mahācīnakramā": ['bhs'],
    "mahācūta": ['mw'],
    "mahācūḍā": ['mw'],
    "mahācūṣaka": ['bhs'],
    "mahādairghatamasa": ['mw'],
    "mahādaitya": ['mw'],
    "mahādamatra": ['mw'],
    "mahādambha": ['mw'],
    "mahādanta": ['mw'],
    "mahādaridra": ['mw'],
    "mahādaśā": ['mw'],
    "mahādaṃṣṭra": ['mw'],
    "mahādaṇḍa": ['mw'],
    "mahādaṇḍadhara": ['mw'],
    "mahādbhuta": ['mw'],
    "mahādeha": ['mw'],
    "mahādeva": ['bhs', 'cae', 'mw'],
    "mahādevabhaṭṭa": ['mw'],
    "mahādevabhaṭṭadinakara": ['mw'],
    "mahādevadaivajña": ['mw'],
    "mahādevadvivedin": ['mw'],
    "mahādevadīkṣita": ['mw'],
    "mahādevagiri": ['mw'],
    "mahādevagṛha": ['mw'],
    "mahādevahata": ['mw'],
    "mahādevahārivaṃśa": ['mw'],
    "mahādevajosī": ['mw'],
    "mahādevakavīśācāryasarasvatī": ['mw'],
    "mahādevakṛtyā": ['cae', 'mw'],
    "mahādevamaṇi": ['mw'],
    "mahādevapaṇḍita": ['mw'],
    "mahādevapura": ['mw'],
    "mahādevapuṇatāmakara": ['mw'],
    "mahādevapuṇyastambhakara": ['mw'],
    "mahādevasahasranāman": ['mw'],
    "mahādevasahasranāmastotra": ['mw'],
    "mahādevasarasvatī": ['mw'],
    "mahādevasarasvatīvedāntin": ['mw'],
    "mahādevasarvajñavādīndra": ['mw'],
    "mahādevastotra": ['mw'],
    "mahādevasūtra": ['bhs'],
    "mahādevatantra": ['mw'],
    "mahādevatva": ['mw'],
    "mahādevatīrtha": ['mw'],
    "mahādevavedāntavāgīśa": ['mw'],
    "mahādevavedāntin": ['mw'],
    "mahādevavid": ['mw'],
    "mahādevavidyāvāgīśa": ['mw'],
    "mahādevavādīndra": ['mw'],
    "mahādevavājapeyin": ['mw'],
    "mahādevaśarman": ['mw'],
    "mahādevaśāstrin": ['mw'],
    "mahādevendrasarasvatī": ['mw'],
    "mahādevā": ['mw'],
    "mahādevāhata": ['mw'],
    "mahādevānanda": ['mw'],
    "mahādevāśrama": ['mw'],
    "mahādevāṣṭottaraśatanāman": ['mw'],
    "mahādevī": ['mw'],
    "mahādevītva": ['mw'],
    "mahādevīya": ['mw'],
    "mahādhana": ['bhs', 'cae', 'cped', 'gra', 'mw'],
    "mahādhanapati": ['mw'],
    "mahādhanika": ['mw'],
    "mahādhanurdhara": ['mw'],
    "mahādhanus": ['mw'],
    "mahādhanuṣmat": ['mw'],
    "mahādharma": ['bhs', 'mw'],
    "mahādharmadhvaja": ['mw'],
    "mahādharmadundubhi": ['mw'],
    "mahādhavalapurāṇa": ['mw'],
    "mahādhipati": ['bhs', 'mw'],
    "mahādhur": ['mw'],
    "mahādhura": ['mw'],
    "mahādhurya": ['mw'],
    "mahādhvaja": ['bhs', 'mw'],
    "mahādhvani": ['mw'],
    "mahādhvanika": ['mw'],
    "mahādhvara": ['mw'],
    "mahādhvāna": ['mw'],
    "mahādhātu": ['mw'],
    "mahādhī": ['mw'],
    "mahādhṛti": ['mw'],
    "mahādikaṭabhī": ['mw'],
    "mahādivākīrtya": ['mw'],
    "mahādiś": ['mw'],
    "mahādoṣa": ['cae'],
    "mahādroṇā": ['mw'],
    "mahādroṇī": ['mw'],
    "mahādruma": ['mw'],
    "mahādrāvaka": ['mw'],
    "mahādundu": ['mw'],
    "mahādurga": ['mw'],
    "mahāduḥkha": ['cae', 'mw'],
    "mahādvandva": ['mw'],
    "mahādvādaśīvicāra": ['mw'],
    "mahādvāra": ['mw'],
    "mahādvārā": ['mw'],
    "mahādyotā": ['bhs', 'mw'],
    "mahādyuti": ['cae', 'mw'],
    "mahādyutika": ['bhs'],
    "mahādyutikara": ['mw'],
    "mahādāna": ['mw'],
    "mahādānanirṇaya": ['mw'],
    "mahādānapaddhati": ['mw'],
    "mahādānapati": ['mw'],
    "mahādānaprayogapaddhati": ['mw'],
    "mahādānavākyāvalī": ['mw'],
    "mahādānānukramaṇikā": ['mw'],
    "mahādāru": ['mw'],
    "mahādīpadānavidhi": ['mw'],
    "mahādūta": ['mw'],
    "mahādūtī": ['bhs'],
    "mahādūṣaka": ['mw'],
    "mahādṛti": ['mw'],
    "mahāga": ['bhs', 'mw'],
    "mahāgada": ['cae', 'mw'],
    "mahāgaja": ['mw'],
    "mahāgajalakṣaṇa": ['mw'],
    "mahāgala": ['cae', 'mw'],
    "mahāgandha": ['mw'],
    "mahāgandhahastin": ['mw'],
    "mahāgandharājanirbhāsa": ['bhs'],
    "mahāgandhā": ['mw'],
    "mahāgarbha": ['mw'],
    "mahāgarta": ['mw'],
    "mahāgastyasaṃhitā": ['mw'],
    "mahāgati": ['bhs', 'mw'],
    "mahāgaurī": ['mw'],
    "mahāgaurīvita": ['mw'],
    "mahāgava": ['mw'],
    "mahāgaya": ['gra', 'mw'],
    "mahāgaṅgā": ['mw'],
    "mahāgaṇa": ['cae', 'cped', 'mw'],
    "mahāgaṇapati": ['mw'],
    "mahāgaṇapatikalpepañcatriṃśatpīṭhikā": ['mw'],
    "mahāgaṇapatisahasranāmastotra": ['mw'],
    "mahāgaṇapatistavarāja": ['mw'],
    "mahāgaṇapatistotra": ['mw'],
    "mahāgaṇapatividyā": ['mw'],
    "mahāgaṇeśa": ['mw'],
    "mahāgaṇeśapurāṇegaṇeśagītā": ['mw'],
    "mahāgaṇin": ['bhs'],
    "mahāgaṇī": ['cped'],
    "mahāghasa": ['mw'],
    "mahāghaṇṭādhara": ['mw'],
    "mahāghaṭa": ['mw'],
    "mahāghora": ['cae', 'mw'],
    "mahāghoṇṭā": ['mw'],
    "mahāghoṣa": ['cae', 'mw'],
    "mahāghoṣasvararāja": ['bhs', 'mw'],
    "mahāghoṣeśvara": ['bhs', 'mw'],
    "mahāghoṣā": ['mw'],
    "mahāghoṣānugā": ['bhs', 'mw'],
    "mahāghāsa": ['mw'],
    "mahāghūrṇā": ['mw'],
    "mahāghṛta": ['mw'],
    "mahāgiri": ['bhs', 'cae', 'mw'],
    "mahāgni": ['mw'],
    "mahāgnicayana": ['mw'],
    "mahāgnicayanakārikā": ['mw'],
    "mahāgnicayanaprayoga": ['mw'],
    "mahāgnicayanasūtra": ['mw'],
    "mahāgnicayanavyākhyā": ['mw'],
    "mahāgnisarvasva": ['mw'],
    "mahāgodhūma": ['mw'],
    "mahāgovinda": ['bhs'],
    "mahāgovindīyasūtra": ['bhs'],
    "mahāgraha": ['mw'],
    "mahāgrahāyaṇī": ['mw'],
    "mahāgranthika": ['mw'],
    "mahāgrāha": ['mw'],
    "mahāgrāma": ['cae', 'gra', 'mw'],
    "mahāgrāsa": ['bhs'],
    "mahāgrīva": ['cae', 'mw'],
    "mahāgrīvin": ['mw'],
    "mahāguha": ['mw'],
    "mahāguhā": ['mw'],
    "mahāgulmā": ['mw'],
    "mahāguru": ['cae', 'mw'],
    "mahāguṇa": ['cae', 'mw'],
    "mahāguṇadhara": ['bhs'],
    "mahāguṇadharabuddhiprāptābhijña": ['bhs'],
    "mahāguṇatva": ['mw'],
    "mahāgīta": ['mw'],
    "mahāgṛha": ['cae', 'mw'],
    "mahāgṛṣṭi": ['mw'],
    "mahāhailihila": ['mw'],
    "mahāhanu": ['cae', 'mw'],
    "mahāharmya": ['mw'],
    "mahāharṣacūḍa": ['bhs'],
    "mahāhasta": ['cae', 'mw'],
    "mahāhastin": ['cae', 'gra', 'mw'],
    "mahāhatamanda": ['bhs'],
    "mahāhava": ['cae', 'mw'],
    "mahāhavis": ['cae', 'mw'],
    "mahāhaya": ['mw'],
    "mahāhaṃsa": ['mw'],
    "mahāhemavat": ['mw'],
    "mahāhetu": ['bhs', 'mw'],
    "mahāhi": ['cae', 'mw'],
    "mahāhigandhā": ['mw'],
    "mahāhimavat": ['mw'],
    "mahāhivalaya": ['mw'],
    "mahāhiśayana": ['mw'],
    "mahāhna": ['cae', 'mw'],
    "mahāhrada": ['cae', 'mw'],
    "mahāhrasva": ['mw'],
    "mahāhrasvā": ['mw'],
    "mahāhāsa": ['mw'],
    "mahāja": ['cae', 'mw'],
    "mahājajñu": ['mw'],
    "mahājambha": ['mw'],
    "mahājambu": ['mw'],
    "mahājambū": ['mw'],
    "mahājana": ['cae', 'cped', 'mw'],
    "mahājanakāya": ['cped'],
    "mahājane": ['mw'],
    "mahājanīya": ['mw'],
    "mahājapa": ['mw'],
    "mahājatru": ['mw'],
    "mahājava": ['cae', 'mw'],
    "mahājavā": ['mw'],
    "mahājaya": ['mw'],
    "mahājayā": ['mw'],
    "mahājaṅgha": ['mw'],
    "mahājaṭa": ['mw'],
    "mahājaṭā": ['mw'],
    "mahājhaṣa": ['mw'],
    "mahājihva": ['mw'],
    "mahājvara": ['cae', 'mw'],
    "mahājvarāṅkuśa": ['mw'],
    "mahājvāla": ['cae', 'mw'],
    "mahājvālā": ['mw'],
    "mahājyaiṣṭhī": ['mw'],
    "mahājyotis": ['mw'],
    "mahājyotiṣmatī": ['mw'],
    "mahājñānagītā": ['bhs', 'mw'],
    "mahājñānayutā": ['mw'],
    "mahājñānin": ['mw'],
    "mahājābāla": ['mw'],
    "mahājālini": ['mw'],
    "mahājālī": ['mw'],
    "mahājānu": ['cae', 'mw'],
    "mahājātaka": ['mw'],
    "mahājāti": ['mw'],
    "mahājātīya": ['mw'],
    "mahākaccha": ['mw'],
    "mahākadambaka": ['mw'],
    "mahākailāsadaṇḍaka": ['mw'],
    "mahākalopa": ['mw'],
    "mahākalpa": ['bhs', 'cae', 'mw'],
    "mahākalyāṇa": ['mw'],
    "mahākalyāṇaka": ['mw'],
    "mahākalā": ['mw'],
    "mahākambu": ['mw'],
    "mahākanda": ['mw'],
    "mahākanya": ['mw'],
    "mahākaparda": ['mw'],
    "mahākapi": ['mw'],
    "mahākapilapañcarātra": ['mw'],
    "mahākapittha": ['mw'],
    "mahākapola": ['mw'],
    "mahākapota": ['mw'],
    "mahākapphiṇa": ['bhs'],
    "mahākapāla": ['mw'],
    "mahākapāṭa": ['cae'],
    "mahākara": ['bhs', 'mw'],
    "mahākarabha": ['bhs', 'mw'],
    "mahākarambha": ['mw'],
    "mahākarañja": ['mw'],
    "mahākarkarava": ['bhs'],
    "mahākarkāru": ['mw'],
    "mahākarman": ['mw'],
    "mahākarmavibhaṅga": ['bhs'],
    "mahākaruṇa": ['mw'],
    "mahākaruṇacandri": ['mw'],
    "mahākaruṇameghaśrī": ['bhs'],
    "mahākaruṇapuṇḍarīka": ['mw'],
    "mahākaruṇatā": ['mw'],
    "mahākaruṇā": ['bhs', 'cped', 'mw'],
    "mahākaruṇācandri": ['mw'],
    "mahākaruṇācandrin": ['bhs'],
    "mahākaruṇācintin": ['bhs'],
    "mahākaruṇāciti": ['bhs'],
    "mahākaruṇāmeghadhvaja": ['bhs'],
    "mahākaruṇānayameghanigarjitaghoṣa": ['bhs'],
    "mahākaruṇāpuṇḍarīka": ['bhs'],
    "mahākaruṇāsiṃha": ['bhs'],
    "mahākaruṇāsūtra": ['bhs'],
    "mahākarṇa": ['bhs', 'mw'],
    "mahākarṇi": ['mw'],
    "mahākarṇikāra": ['mw'],
    "mahākarṇī": ['mw'],
    "mahākathahacakra": ['mw'],
    "mahākathā": ['cae', 'ddsa'],
    "mahākathāna": ['cped'],
    "mahākauṣītaka": ['mw'],
    "mahākauṣītaki": ['mw'],
    "mahākauṣītakibrāhmaṇa": ['mw'],
    "mahākauṣṭhila": ['bhs', 'mw'],
    "mahākauṣṭhilya": ['mw'],
    "mahākavi": ['cae', 'mw'],
    "mahākaṅkara": ['bhs', 'mw'],
    "mahākaṇṭakinī": ['mw'],
    "mahākaṭitaṭaśroṇī": ['mw'],
    "mahākelin": ['bhs'],
    "mahāketu": ['bhs', 'mw'],
    "mahākeśa": ['mw'],
    "mahākhallava": ['mw'],
    "mahākhalvala": ['mw'],
    "mahākharva": ['mw'],
    "mahākhaṇḍana": ['mw'],
    "mahākhyāta": ['mw'],
    "mahākhāta": ['mw'],
    "mahākimpaka": ['bhs'],
    "mahākośa": ['bhs', 'mw'],
    "mahākośalī": ['bhs'],
    "mahākośaphalā": ['mw'],
    "mahākośātakī": ['mw'],
    "mahākośī": ['mw'],
    "mahākoṣṭhila": ['bhs'],
    "mahākrama": ['mw'],
    "mahākrandanā": ['bhs'],
    "mahākratu": ['cae', 'mw'],
    "mahākrodha": ['bhs', 'cae', 'mw'],
    "mahākrūrā": ['mw'],
    "mahākuha": ['mw'],
    "mahākula": ['cae', 'gra', 'mw'],
    "mahākulodbhava": ['mw'],
    "mahākulotpanna": ['mw'],
    "mahākulīna": ['cae', 'mw'],
    "mahākulīnatā": ['mw'],
    "mahākumbhī": ['mw'],
    "mahākumudā": ['mw'],
    "mahākumāra": ['mw'],
    "mahākusumikā": ['mw'],
    "mahākuśa": ['bhs', 'mw'],
    "mahākuṇḍa": ['mw'],
    "mahākuṣṭha": ['mw'],
    "mahākāla": ['bhs', 'cae', 'mw'],
    "mahākālabhairavatantreśarabhakavaca": ['mw'],
    "mahākālakavaca": ['mw'],
    "mahākālakhaṇḍa": ['mw'],
    "mahākālamata": ['mw'],
    "mahākālapura": ['mw'],
    "mahākālarudroditastotra": ['mw'],
    "mahākālasahasranāman": ['mw'],
    "mahākālasaṃhitā": ['mw'],
    "mahākālasaṃhitākūṭa": ['mw'],
    "mahākālastotra": ['mw'],
    "mahākālatantra": ['mw'],
    "mahākālatva": ['mw'],
    "mahākālaveya": ['mw'],
    "mahākālayogaśāstrekhecarīvidyā": ['mw'],
    "mahākāleta": ['mw'],
    "mahākāleya": ['mw'],
    "mahākāleśvara": ['mw'],
    "mahākālikā": ['bhs'],
    "mahākālopa": ['mw'],
    "mahākālī": ['mw'],
    "mahākālīmata": ['mw'],
    "mahākālīsūkta": ['mw'],
    "mahākālītantra": ['mw'],
    "mahākālīyantra": ['mw'],
    "mahākānta": ['mw'],
    "mahākāntā": ['mw'],
    "mahākāpola": ['mw'],
    "mahākāra": ['mw'],
    "mahākāraṇa": ['mw'],
    "mahākāraṇaprakaraṇa": ['mw'],
    "mahākārtayaśa": ['mw'],
    "mahākārttikī": ['mw'],
    "mahākāruṇika": ['bhs', 'mw'],
    "mahākātyāyana": ['bhs', 'mw'],
    "mahākāvya": ['cae', 'mw'],
    "mahākāya": ['bhs', 'cae', 'cped', 'mw'],
    "mahākāyatva": ['mw'],
    "mahākāyaśirodhara": ['mw'],
    "mahākāyika": ['mw'],
    "mahākāyā": ['mw'],
    "mahākāśa": ['mw'],
    "mahākāśabhairavakalpeśarabheśvarakavaca": ['mw'],
    "mahākāśamātar": ['bhs'],
    "mahākāśyapa": ['bhs', 'mw'],
    "mahākāśī": ['mw'],
    "mahākīrtana": ['mw'],
    "mahākīrti": ['mw'],
    "mahākīṭaparvata": ['mw'],
    "mahākūla": ['mw'],
    "mahākūpa": ['mw'],
    "mahākūrma": ['mw'],
    "mahākṛcchra": ['mw'],
    "mahākṛtyāparimala": ['mw'],
    "mahākṛṣṇa": ['mw'],
    "mahākṛṣṇameghavātamaṇḍalī": ['bhs'],
    "mahākṣa": ['mw'],
    "mahākṣapaṇaka": ['mw'],
    "mahākṣapaṭalika": ['mw'],
    "mahākṣatrapa": ['mw'],
    "mahākṣauhiṇī": ['mw'],
    "mahākṣobhya": ['bhs', 'mw'],
    "mahākṣāra": ['mw'],
    "mahākṣīra": ['mw'],
    "mahākṣīrā": ['mw'],
    "mahālakuṭa": ['bhs'],
    "mahālakṣmyaṣṭaka": ['mw'],
    "mahālakṣmī": ['mw'],
    "mahālakṣmīhṛdaya": ['mw'],
    "mahālakṣmīhṛdayastotra": ['mw'],
    "mahālakṣmīkalpa": ['mw'],
    "mahālakṣmīnāmavidhi": ['mw'],
    "mahālakṣmīpaddhati": ['mw'],
    "mahālakṣmīratnakośa": ['mw'],
    "mahālakṣmīstotra": ['mw'],
    "mahālakṣmīsūkta": ['mw'],
    "mahālakṣmītīrtha": ['mw'],
    "mahālakṣmīvilāsa": ['mw'],
    "mahālakṣmīvrata": ['mw'],
    "mahālakṣmīvratapūjā": ['mw'],
    "mahālalāṭa": ['mw'],
    "mahālasā": ['mw'],
    "mahālatāpasādhana": ['cped'],
    "mahālaya": ['mw'],
    "mahālayaprayoga": ['mw'],
    "mahālayaśrāddhapaddhati": ['mw'],
    "mahālayā": ['mw'],
    "mahālikaṭabhī": ['mw'],
    "mahāliṅga": ['mw'],
    "mahāliṅgayogin": ['mw'],
    "mahāliṅgaśāstrin": ['mw'],
    "mahālodha": ['mw'],
    "mahālodhra": ['mw'],
    "mahāloha": ['mw'],
    "mahālola": ['mw'],
    "mahāloman": ['mw'],
    "mahālugi": ['mw'],
    "mahālugipaddhati": ['mw'],
    "mahālīlāsarasvatī": ['mw'],
    "mahāmacca": ['cped'],
    "mahāmada": ['mw'],
    "mahāmagga": ['cped'],
    "mahāmagna": ['mw'],
    "mahāmaha": ['cae', 'gra', 'mw'],
    "mahāmahas": ['mw'],
    "mahāmaheśvarakavi": ['mw'],
    "mahāmaheśvarāyatana": ['bhs', 'mw'],
    "mahāmahiman": ['mw'],
    "mahāmahimatva": ['mw'],
    "mahāmahimaśālin": ['mw'],
    "mahāmahivrata": ['gra', 'mw'],
    "mahāmahopādhyāya": ['mw'],
    "mahāmahā": ['bhs', 'mw'],
    "mahāmahārgha": ['cae'],
    "mahāmaitra": ['mw'],
    "mahāmaitryudgata": ['bhs'],
    "mahāmaitrī": ['mw'],
    "mahāmaitrīmahākaruṇāmukhodyotana": ['bhs'],
    "mahāmaitrīsamādhi": ['mw'],
    "mahāmakha": ['cae', 'mw'],
    "mahāmalaharī": ['mw'],
    "mahāmalayapura": ['mw'],
    "mahāmalla": ['mw'],
    "mahāmanas": ['cae', 'gra', 'mw'],
    "mahāmanaska": ['mw'],
    "mahāmanasvin": ['bhs', 'mw'],
    "mahāmandāra": ['bhs'],
    "mahāmandārava": ['bhs', 'mw'],
    "mahāmani": ['mw'],
    "mahāmantra": ['mw'],
    "mahāmantrin": ['cae', 'mw'],
    "mahāmantrādisevāprakāra": ['mw'],
    "mahāmantrānusāriṇī": ['bhs', 'mw'],
    "mahāmanuṣya": ['cae', 'mw'],
    "mahāmarakata": ['mw'],
    "mahāmarutvatīya": ['mw'],
    "mahāmarṣa": ['mw'],
    "mahāmata": ['mw'],
    "mahāmati": ['bhs', 'cae', 'cped', 'mw'],
    "mahāmatsya": ['cae', 'mw'],
    "mahāmatta": ['cped', 'mw'],
    "mahāmatī": ['bhs', 'mw'],
    "mahāmaudgalyāyana": ['bhs', 'mw'],
    "mahāmayūrarājan": ['bhs'],
    "mahāmayūrī": ['mw'],
    "mahāmañjuṣaka": ['mw'],
    "mahāmañjūṣaka": ['bhs', 'mw'],
    "mahāmaṅgala": ['mw'],
    "mahāmaṇi": ['cae', 'mw'],
    "mahāmaṇicūḍa": ['bhs', 'mw'],
    "mahāmaṇidhara": ['bhs', 'mw'],
    "mahāmaṇiratna": ['bhs', 'mw'],
    "mahāmaṇḍala": ['mw'],
    "mahāmaṇḍaleśvara": ['mw'],
    "mahāmaṇḍalika": ['bhs', 'mw'],
    "mahāmaṇḍapa": ['mw'],
    "mahāmaṇḍarava": ['bhs'],
    "mahāmaṇḍūka": ['mw'],
    "mahāmbuja": ['mw'],
    "mahāmbuka": ['mw'],
    "mahāmeda": ['mw'],
    "mahāmedha": ['mw'],
    "mahāmedhā": ['mw'],
    "mahāmegha": ['bhs', 'cae', 'cped', 'mw'],
    "mahāmeghagiri": ['mw'],
    "mahāmeghanibhasvana": ['mw'],
    "mahāmeghanivāsin": ['mw'],
    "mahāmeghasvana": ['mw'],
    "mahāmeghaughanirghoṣa": ['mw'],
    "mahāmeghaśrīteja": ['bhs'],
    "mahāmekhalā": ['bhs'],
    "mahāmeru": ['bhs', 'cae', 'mw'],
    "mahāmerudhara": ['mw'],
    "mahāmla": ['mw'],
    "mahāmoda": ['mw'],
    "mahāmoha": ['mw'],
    "mahāmohamantra": ['mw'],
    "mahāmohamantratva": ['mw'],
    "mahāmohana": ['mw'],
    "mahāmohasvarottaratantra": ['mw'],
    "mahāmohin": ['mw'],
    "mahāmohā": ['mw'],
    "mahāmucilinda": ['bhs', 'mw'],
    "mahāmucilindaparvata": ['mw'],
    "mahāmudrā": ['bhs', 'mw'],
    "mahāmukha": ['cae', 'mw'],
    "mahāmuni": ['bhs', 'cae', 'cped', 'mw'],
    "mahāmunisvādhyāya": ['mw'],
    "mahāmuṇḍanikā": ['mw'],
    "mahāmuṇḍī": ['mw'],
    "mahāmāghī": ['mw'],
    "mahāmāheśvara": ['mw'],
    "mahāmāla": ['mw'],
    "mahāmālikā": ['mw'],
    "mahāmānasikā": ['mw'],
    "mahāmānasī": ['mw'],
    "mahāmāndāra": ['bhs', 'mw'],
    "mahāmānin": ['mw'],
    "mahāmānya": ['mw'],
    "mahāmārakata": ['mw'],
    "mahāmārga": ['mw'],
    "mahāmārgapati": ['mw'],
    "mahāmārī": ['mw'],
    "mahāmātra": ['cae', 'mw'],
    "mahāmātrī": ['mw'],
    "mahāmātya": ['cae', 'mw'],
    "mahāmātṛ": ['mw'],
    "mahāmātṛgaṇeśvara": ['mw'],
    "mahāmāya": ['bhs', 'cae', 'mw'],
    "mahāmāyā": ['bhs', 'cae', 'mw'],
    "mahāmāyādhara": ['mw'],
    "mahāmāyātantra": ['bhs'],
    "mahāmāyāśambara": ['mw'],
    "mahāmāyī": ['mw'],
    "mahāmāyūra": ['mw'],
    "mahāmāyūrī": ['bhs', 'mw'],
    "mahāmāyūrīstotra": ['mw'],
    "mahāmāṃsa": ['cae', 'mw'],
    "mahāmāṃsavikraya": ['mw'],
    "mahāmāṃsī": ['mw'],
    "mahāmāṣa": ['mw'],
    "mahāmīna": ['mw'],
    "mahāmūla": ['mw'],
    "mahāmūlya": ['mw'],
    "mahāmūrdhan": ['cae', 'mw'],
    "mahāmūrkha": ['mw'],
    "mahāmūrti": ['mw'],
    "mahāmūḍha": ['mw'],
    "mahāmūṣaka": ['mw'],
    "mahāmūṣika": ['mw'],
    "mahāmṛdha": ['cae', 'mw'],
    "mahāmṛga": ['cae', 'mw'],
    "mahāmṛtyu": ['mw'],
    "mahāmṛtyuharastotra": ['mw'],
    "mahāmṛtyuṃjaya": ['mw'],
    "mahāmṛtyuṃjayahoma": ['mw'],
    "mahāmṛtyuṃjayakalpa": ['mw'],
    "mahāmṛtyuṃjayamantra": ['mw'],
    "mahāmṛtyuṃjayavidhi": ['mw'],
    "mahānada": ['cae', 'mw'],
    "mahānadī": ['mw'],
    "mahānadīsāgarasaṃgama": ['mw'],
    "mahānagara": ['mw'],
    "mahānagna": ['bhs', 'cae', 'mw'],
    "mahānagnin": ['bhs'],
    "mahānagnā": ['mw'],
    "mahānaka": ['mw'],
    "mahānakha": ['mw'],
    "mahānala": ['mw'],
    "mahānana": ['mw'],
    "mahānanda": ['bhs', 'mw'],
    "mahānandadhīra": ['mw'],
    "mahānandatva": ['mw'],
    "mahānandi": ['mw'],
    "mahānandin": ['mw'],
    "mahānandā": ['mw'],
    "mahānaraka": ['cae', 'cped', 'mw'],
    "mahānarendra": ['mw'],
    "mahānarman": ['mw'],
    "mahānasa": ['cae', 'cped', 'mw'],
    "mahānasādhyakṣa": ['mw'],
    "mahānasī": ['mw'],
    "mahānavamī": ['mw'],
    "mahānavamīpūjā": ['mw'],
    "mahānayaprakāśa": ['mw'],
    "mahānayuta": ['bhs'],
    "mahānaṭa": ['mw'],
    "mahāndhakāra": ['mw'],
    "mahāndhra": ['mw'],
    "mahāndhraka": ['mw'],
    "mahānemi": ['mw'],
    "mahānetra": ['mw'],
    "mahānidhi": ['mw'],
    "mahānidhikumāra": ['mw'],
    "mahānidra": ['mw'],
    "mahānidrā": ['mw'],
    "mahānila": ['mw'],
    "mahānimba": ['mw'],
    "mahānimbarajas": ['bhs', 'mw'],
    "mahānimitta": ['mw'],
    "mahānimna": ['mw'],
    "mahānināda": ['mw'],
    "mahāniraya": ['cped', 'mw'],
    "mahāniraṣṭa": ['mw'],
    "mahānirnādin": ['bhs'],
    "mahānirvāṇa": ['mw'],
    "mahānirvāṇatantra": ['mw'],
    "mahānirṇayatantra": ['mw'],
    "mahāniyama": ['mw'],
    "mahāniyuta": ['mw'],
    "mahāniś": ['cae', 'mw'],
    "mahāniśā": ['cae', 'mw'],
    "mahāniśītha": ['mw'],
    "mahānta": ['cae', 'mw'],
    "mahāntaka": ['bhs', 'mw'],
    "mahānubbāva": ['cped'],
    "mahānubhāva": ['cae', 'mw'],
    "mahānubhāvatva": ['mw'],
    "mahānubhāvatā": ['mw'],
    "mahānurāga": ['mw'],
    "mahānuśaṃsaka": ['mw'],
    "mahānvaya": ['mw'],
    "mahānyāsa": ['mw'],
    "mahānyāsavidhi": ['mw'],
    "mahānyāya": ['mw'],
    "mahānābha": ['mw'],
    "mahānāda": ['cae', 'mw'],
    "mahānāga": ['bhs', 'cae', 'cped', 'mw'],
    "mahānāgahana": ['mw'],
    "mahānāma": ['bhs'],
    "mahānāman": ['mw'],
    "mahānāmnika": ['mw'],
    "mahānāmnī": ['cae', 'mw'],
    "mahānāmnīvrata": ['mw'],
    "mahānānātva": ['mw'],
    "mahānārāyaṇa": ['bhs', 'mw'],
    "mahānārāyaṇopaniṣad": ['mw'],
    "mahānāsa": ['mw'],
    "mahānāyaka": ['mw'],
    "mahānāśā": ['bhs'],
    "mahānāḍī": ['mw'],
    "mahānāṭaka": ['cae', 'mw'],
    "mahānīca": ['mw'],
    "mahānīla": ['cae', 'mw'],
    "mahānīlamaya": ['mw'],
    "mahānīlatantra": ['mw'],
    "mahānīlopala": ['mw'],
    "mahānīlā": ['mw'],
    "mahānīlābhrajālīya": ['mw'],
    "mahānīlī": ['mw'],
    "mahānūpa": ['mw'],
    "mahānṛtya": ['mw'],
    "mahāpada": ['gra', 'mw'],
    "mahāpadapaṅkti": ['mw'],
    "mahāpadeśa": ['bhs'],
    "mahāpadma": ['bhs', 'mw'],
    "mahāpadmapati": ['mw'],
    "mahāpadmasalila": ['mw'],
    "mahāpadmasaras": ['mw'],
    "mahāpadmā": ['bhs'],
    "mahāpadyaṣaṭka": ['mw'],
    "mahāpagā": ['mw'],
    "mahāpaiśācika": ['mw'],
    "mahāpaiṅgya": ['mw'],
    "mahāpaiṭhīnasi": ['mw'],
    "mahāpaka": ['bhs'],
    "mahāpakṣa": ['cae', 'ddsa', 'mw'],
    "mahāpakṣin": ['mw'],
    "mahāpakṣī": ['mw'],
    "mahāpanthaka": ['bhs', 'mw'],
    "mahāparibhava": ['cae'],
    "mahāparidevita": ['bhs'],
    "mahāparinirvāṇa": ['bhs', 'mw'],
    "mahāparinirvāṇasūtra": ['mw'],
    "mahāparvata": ['mw'],
    "mahāparādha": ['cae', 'mw'],
    "mahāparāhṇa": ['mw'],
    "mahāparāka": ['mw'],
    "mahāpatha": ['cae', 'cped', 'mw'],
    "mahāpathagama": ['mw'],
    "mahāpathagamana": ['mw'],
    "mahāpathagiri": ['mw'],
    "mahāpathika": ['mw'],
    "mahāpathikṛdiṣṭi": ['mw'],
    "mahāpattra": ['mw'],
    "mahāpattrā": ['mw'],
    "mahāpaurava": ['mw'],
    "mahāpaurṇamāsī": ['mw'],
    "mahāpavitra": ['mw'],
    "mahāpavitreṣṭi": ['mw'],
    "mahāpañcamūla": ['mw'],
    "mahāpañcaviṣa": ['mw'],
    "mahāpañña": ['cped'],
    "mahāpaśu": ['cae', 'mw'],
    "mahāpaṅka": ['cae', 'mw'],
    "mahāpaṅkti": ['cae', 'mw'],
    "mahāpaṇḍita": ['cae', 'mw'],
    "mahāpaṭa": ['mw'],
    "mahāphala": ['cae', 'mw'],
    "mahāphalā": ['mw'],
    "mahāphaṇaka": ['bhs', 'mw'],
    "mahāpheṇā": ['mw'],
    "mahāpheṭkārīya": ['mw'],
    "mahāpitar": ['cped'],
    "mahāpiṇḍītaka": ['mw'],
    "mahāpiṇḍītaru": ['mw'],
    "mahāplava": ['mw'],
    "mahāpoṭagala": ['mw'],
    "mahāprabandha": ['mw'],
    "mahāprabha": ['bhs', 'cae', 'mw'],
    "mahāprabhu": ['cae', 'mw'],
    "mahāprabhutva": ['mw'],
    "mahāprabhā": ['mw'],
    "mahāprabhāmaṇḍalavyūhajñānamudrā": ['mw'],
    "mahāprabhāsa": ['mw'],
    "mahāprabhāsotpattivarṇana": ['mw'],
    "mahāprabhāva": ['cae', 'mw'],
    "mahāpradāna": ['mw'],
    "mahāpradīpa": ['bhs', 'mw'],
    "mahāprajñā": ['bhs'],
    "mahāprajñāpāramitāsūtra": ['mw'],
    "mahāprajāpati": ['cae', 'mw'],
    "mahāprajāpatī": ['bhs', 'mw'],
    "mahāprajāvatī": ['mw'],
    "mahāprakaraṇa": ['cae', 'mw'],
    "mahāprakāśa": ['mw'],
    "mahāpralaya": ['mw'],
    "mahāpramāṇa": ['cae', 'mw'],
    "mahāprapañca": ['cae', 'mw'],
    "mahāprasthāna": ['cae', 'mw'],
    "mahāprasthānaparvan": ['mw'],
    "mahāprasthānika": ['mw'],
    "mahāprasthānikaparvan": ['mw'],
    "mahāprasuta": ['bhs', 'mw'],
    "mahāprasāda": ['bhs', 'mw'],
    "mahāpratibhāna": ['bhs', 'mw'],
    "mahāpratisarā": ['bhs'],
    "mahāpratyaṅgirā": ['bhs'],
    "mahāpratāpa": ['mw'],
    "mahāpratīhāra": ['mw'],
    "mahāpravarabhāṣya": ['mw'],
    "mahāpravaranirṇaya": ['mw'],
    "mahāpravṛddha": ['mw'],
    "mahāprayogasāra": ['mw'],
    "mahāpraśna": ['cae', 'mw'],
    "mahāpraṇidhivegaśri": ['bhs'],
    "mahāpraṇidhāna": ['mw'],
    "mahāpraṇāda": ['bhs', 'mw'],
    "mahāpraṇālin": ['bhs'],
    "mahāpreta": ['mw'],
    "mahāpreṣaka": ['bhs'],
    "mahāprājña": ['bhs', 'cae', 'mw'],
    "mahāprāsthānika": ['mw'],
    "mahāprātihārika": ['bhs'],
    "mahāprātihārya": ['bhs'],
    "mahāprāvrājya": ['mw'],
    "mahāprāṇa": ['cae', 'mw'],
    "mahāprītiharṣā": ['bhs', 'mw'],
    "mahāprītivegasambhavamudrā": ['mw'],
    "mahāpura": ['bhs', 'cae', 'mw'],
    "mahāpuraścaraṇaprayoga": ['mw'],
    "mahāpurisa": ['cped'],
    "mahāpuruṣa": ['cae', 'mw'],
    "mahāpuruṣadantikā": ['mw'],
    "mahāpuruṣadantā": ['mw'],
    "mahāpuruṣalakṣaṇa": ['mw'],
    "mahāpuruṣapāvanakavaca": ['mw'],
    "mahāpuruṣastava": ['mw'],
    "mahāpuruṣastotra": ['mw'],
    "mahāpuruṣatā": ['mw'],
    "mahāpuruṣavidyā": ['mw'],
    "mahāpurāṇa": ['mw'],
    "mahāpurī": ['mw'],
    "mahāputra": ['mw'],
    "mahāputrīya": ['mw'],
    "mahāpuṃs": ['mw'],
    "mahāpuṃsa": ['mw'],
    "mahāpuṇya": ['cae', 'mw'],
    "mahāpuṇyā": ['mw'],
    "mahāpuṣpa": ['mw'],
    "mahāpuṣpā": ['mw'],
    "mahāpāda": ['mw'],
    "mahāpākajānī": ['mw'],
    "mahāpāla": ['mw'],
    "mahāpāna": ['mw'],
    "mahāpāpa": ['cae', 'mw'],
    "mahāpāpman": ['cae', 'mw'],
    "mahāpāra": ['mw'],
    "mahāpāraṇika": ['bhs', 'mw'],
    "mahāpārevata": ['mw'],
    "mahāpāriṣad": ['mw'],
    "mahāpāruṣaka": ['bhs', 'mw'],
    "mahāpārśva": ['cae', 'mw'],
    "mahāpāsaka": ['mw'],
    "mahāpāta": ['cae', 'mw'],
    "mahāpātaka": ['cae', 'mw'],
    "mahāpātakin": ['mw'],
    "mahāpātra": ['mw'],
    "mahāpāśa": ['bhs', 'mw'],
    "mahāpāśupata": ['mw'],
    "mahāpāṭala": ['bhs', 'mw'],
    "mahāpīlu": ['mw'],
    "mahāpīlupati": ['mw'],
    "mahāpīṭha": ['mw'],
    "mahāpūjā": ['mw'],
    "mahāpūjāvidhi": ['mw'],
    "mahāpūruṣa": ['mw'],
    "mahāpūrṇa": ['bhs', 'mw'],
    "mahāpūta": ['mw'],
    "mahāpṛthivī": ['mw'],
    "mahāpṛthivītva": ['mw'],
    "mahāpṛṣṭha": ['cae', 'mw'],
    "mahāpṛṣṭhagalaskandha": ['mw'],
    "mahāpṛṣṭhya": ['mw'],
    "mahāraha": ['cped'],
    "mahārajana": ['cae', 'mw'],
    "mahārajanagandhi": ['mw'],
    "mahārajanagandhin": ['mw'],
    "mahārajata": ['mw'],
    "mahārakṣas": ['mw'],
    "mahārakṣita": ['mw'],
    "mahārakṣā": ['bhs', 'mw'],
    "mahārambha": ['bhs', 'mw'],
    "mahārasa": ['mw'],
    "mahārasavatī": ['mw'],
    "mahārasā": ['mw'],
    "mahārasāyanavidhi": ['mw'],
    "mahāratha": ['bhs', 'cae', 'mw'],
    "mahārathamañjarī": ['mw'],
    "mahārathatva": ['mw'],
    "mahārathyā": ['cae', 'mw'],
    "mahāratna": ['cae', 'mw'],
    "mahāratnahetu": ['mw'],
    "mahāratnaketu": ['bhs'],
    "mahāratnakūṭa": ['bhs'],
    "mahāratnamaya": ['mw'],
    "mahāratnapratimaṇḍita": ['bhs', 'mw'],
    "mahāratnavarṣā": ['bhs', 'mw'],
    "mahāratnavat": ['mw'],
    "mahāratnābhiṣekarāmadhyāna": ['mw'],
    "mahāraudra": ['mw'],
    "mahāraudrī": ['mw'],
    "mahārauhiṇa": ['mw'],
    "mahāraurava": ['bhs', 'cae', 'mw'],
    "mahārava": ['cae', 'mw'],
    "mahārañjana": ['mw'],
    "mahāraśmijālāvabhāsagarbha": ['bhs', 'mw'],
    "mahāraṅga": ['bhs', 'mw'],
    "mahāraṇa": ['cae', 'mw'],
    "mahāraṇya": ['cae', 'mw'],
    "mahārbuda": ['mw'],
    "mahārcis": ['mw'],
    "mahārciskandha": ['bhs'],
    "mahārciskandhin": ['bhs'],
    "mahārdha": ['mw'],
    "mahārdraka": ['mw'],
    "mahāretas": ['mw'],
    "mahārgha": ['cae', 'mw'],
    "mahārgharūpa": ['mw'],
    "mahārghatā": ['mw'],
    "mahārha": ['cae', 'mw'],
    "mahāriṣṭa": ['mw'],
    "mahārma": ['mw'],
    "mahāroca": ['bhs', 'mw'],
    "mahārocamāna": ['bhs'],
    "mahāroga": ['mw'],
    "mahārogin": ['mw'],
    "mahārohi": ['mw'],
    "mahāroman": ['mw'],
    "mahāromaśa": ['mw'],
    "mahārtha": ['cae', 'mw'],
    "mahārthaka": ['mw'],
    "mahārthamañjarī": ['mw'],
    "mahārthaprakāśa": ['mw'],
    "mahārthatā": ['mw'],
    "mahārthavat": ['mw'],
    "mahārudra": ['mw'],
    "mahārudrajapavidhi": ['mw'],
    "mahārudrakarmakalāpapaddhati": ['mw'],
    "mahārudranyāsapaddhati": ['mw'],
    "mahārudrapaddhati": ['mw'],
    "mahārudraprayoga": ['mw'],
    "mahārudraprayogapaddhati": ['mw'],
    "mahārudrapīṭhadevatā": ['mw'],
    "mahārudrasiṃha": ['mw'],
    "mahārudravidhi": ['mw'],
    "mahārudrā": ['mw'],
    "mahārudrī": ['mw'],
    "mahāruj": ['mw'],
    "mahāruja": ['mw'],
    "mahāruru": ['mw'],
    "mahāruṇa": ['mw'],
    "mahārya": ['mw'],
    "mahāryasiddhānta": ['mw'],
    "mahārāja": ['bhs', 'cae', 'cped', 'mw'],
    "mahārājacūta": ['mw'],
    "mahārājadruma": ['mw'],
    "mahārājaka": ['mw'],
    "mahārājakulīna": ['mw'],
    "mahārājakāyika": ['bhs'],
    "mahārājamiśra": ['mw'],
    "mahārājanighaṇṭu": ['mw'],
    "mahārājaphala": ['mw'],
    "mahārājika": ['bhs', 'mw'],
    "mahārājikadeva": ['mw'],
    "mahārājya": ['mw'],
    "mahārājñī": ['cae', 'mw'],
    "mahārājñīstava": ['mw'],
    "mahārājā": ['bhs'],
    "mahārājādhirāja": ['mw'],
    "mahārājāṅgana": ['mw'],
    "mahārājāṅgaṇa": ['mw'],
    "mahārāmāyaṇa": ['mw'],
    "mahārātra": ['cae', 'mw'],
    "mahārātri": ['mw'],
    "mahārātricaṇḍikāvidhāna": ['mw'],
    "mahārātrī": ['mw'],
    "mahārāva": ['cae', 'mw'],
    "mahārāṣṭra": ['cae', 'mw'],
    "mahārāṣṭraka": ['mw'],
    "mahārāṣṭravariṣṭhabhāṣāmaya": ['mw'],
    "mahārāṣṭrī": ['mw'],
    "mahārāṣṭrīya": ['mw'],
    "mahārūpa": ['bhs', 'mw'],
    "mahārūpaka": ['mw'],
    "mahārūpin": ['mw'],
    "mahārūpiṇī": ['bhs'],
    "mahārūpā": ['mw'],
    "mahārṇava": ['cae', 'mw'],
    "mahārṇavakarmavipāka": ['mw'],
    "mahārṇavanipānavid": ['mw'],
    "mahārṇavaprakāśa": ['mw'],
    "mahārṇavavratārka": ['mw'],
    "mahārṣacūḍa": ['bhs'],
    "mahāsabhā": ['mw'],
    "mahāsaha": ['mw'],
    "mahāsahasranāman": ['mw'],
    "mahāsahasrapramardana": ['bhs', 'mw'],
    "mahāsahasrapramardanī": ['mw'],
    "mahāsahasrapramardinī": ['mw'],
    "mahāsahā": ['mw'],
    "mahāsama": ['bhs', 'mw'],
    "mahāsamantagandha": ['bhs'],
    "mahāsamaya": ['mw'],
    "mahāsamaṅgā": ['mw'],
    "mahāsamaṇa": ['cped'],
    "mahāsambhava": ['mw'],
    "mahāsammata": ['mw'],
    "mahāsammatīya": ['mw'],
    "mahāsammohana": ['mw'],
    "mahāsammohanatantra": ['mw'],
    "mahāsamsṛṣṭa": ['bhs'],
    "mahāsamudda": ['cped'],
    "mahāsamudra": ['bhs', 'mw'],
    "mahāsamājasūtra": ['bhs'],
    "mahāsamājīya": ['bhs'],
    "mahāsamāpta": ['bhs', 'mw'],
    "mahāsana": ['cae', 'mw'],
    "mahāsanaparicchada": ['mw'],
    "mahāsanna": ['mw'],
    "mahāsanni": ['mw'],
    "mahāsanārcis": ['bhs'],
    "mahāsaptamī": ['mw'],
    "mahāsara": ['cped'],
    "mahāsarasvatī": ['mw'],
    "mahāsarasvatīdvādaśanāmastotra": ['mw'],
    "mahāsarasvatīstavarāja": ['mw'],
    "mahāsarasvatīstotra": ['mw'],
    "mahāsarasvatīsūkta": ['mw'],
    "mahāsarga": ['mw'],
    "mahāsarja": ['mw'],
    "mahāsaroja": ['mw'],
    "mahāsarpa": ['mw'],
    "mahāsatobṛhatī": ['cae', 'mw'],
    "mahāsatomukhā": ['mw'],
    "mahāsatta": ['cped'],
    "mahāsattra": ['cae', 'mw'],
    "mahāsattva": ['bhs', 'cae', 'mw'],
    "mahāsattvatā": ['mw'],
    "mahāsattvavadha": ['mw'],
    "mahāsattā": ['mw'],
    "mahāsatya": ['mw'],
    "mahāsatī": ['cae', 'mw'],
    "mahāsaukhya": ['mw'],
    "mahāsaura": ['mw'],
    "mahāsauṣira": ['mw'],
    "mahāsaṃbhava": ['bhs'],
    "mahāsaṃbhavā": ['bhs'],
    "mahāsaṃdhivigraha": ['mw'],
    "mahāsaṃghika": ['mw'],
    "mahāsaṃhitā": ['mw'],
    "mahāsaṃjñā": ['bhs', 'mw'],
    "mahāsaṃkalpa": ['mw'],
    "mahāsaṃkaṭa": ['mw'],
    "mahāsaṃkrānti": ['mw'],
    "mahāsaṃmata": ['bhs'],
    "mahāsaṃnipātasūtra": ['bhs'],
    "mahāsaṃsṛṣṭa": ['mw'],
    "mahāsaṃvidhāna": ['bhs'],
    "mahāsena": ['bhs', 'cae', 'gra', 'mw'],
    "mahāsenanareśvara": ['mw'],
    "mahāsenā": ['cae', 'mw'],
    "mahāsenāvyūhaparākrama": ['bhs', 'mw'],
    "mahāsetu": ['mw'],
    "mahāsi": ['mw'],
    "mahāsiddha": ['mw'],
    "mahāsiddhi": ['mw'],
    "mahāsiddhānta": ['mw'],
    "mahāsitavatī": ['bhs'],
    "mahāsitā": ['mw'],
    "mahāsiṃha": ['cae', 'mw'],
    "mahāsiṃhagati": ['mw'],
    "mahāsiṃhanādika": ['bhs'],
    "mahāsiṃhatejas": ['bhs', 'mw'],
    "mahāskandha": ['mw'],
    "mahāskandhin": ['mw'],
    "mahāskandhā": ['mw'],
    "mahāsmṛti": ['bhs', 'mw'],
    "mahāsmṛtimaya": ['mw'],
    "mahāsmṛtyupasthāna": ['bhs', 'mw'],
    "mahāsneha": ['mw'],
    "mahāsnāna": ['mw'],
    "mahāsnāyu": ['mw'],
    "mahāsoma": ['mw'],
    "mahāspada": ['mw'],
    "mahāsragvin": ['mw'],
    "mahāsrotas": ['mw'],
    "mahāsthalī": ['mw'],
    "mahāsthavira": ['mw'],
    "mahāsthāla": ['bhs', 'mw'],
    "mahāsthāma": ['bhs'],
    "mahāsthāmaprāpta": ['bhs', 'mw'],
    "mahāsthāna": ['mw'],
    "mahāsthānaprāpta": ['mw'],
    "mahāsthūla": ['mw'],
    "mahāstoma": ['mw'],
    "mahāstotra": ['mw'],
    "mahāstra": ['cae', 'mw'],
    "mahāstūpa": ['mw'],
    "mahāsubhikṣa": ['mw'],
    "mahāsudarśa": ['mw'],
    "mahāsudarśana": ['bhs', 'mw'],
    "mahāsudatta": ['bhs'],
    "mahāsugandha": ['mw'],
    "mahāsugandhi": ['mw'],
    "mahāsugandhā": ['mw'],
    "mahāsuhaya": ['mw'],
    "mahāsukha": ['mw'],
    "mahāsundarītantra": ['mw'],
    "mahāsuparṇa": ['mw'],
    "mahāsura": ['mw'],
    "mahāsurī": ['mw'],
    "mahāsvana": ['cae', 'mw'],
    "mahāsvanam": ['mw'],
    "mahāsvapna": ['mw'],
    "mahāsvara": ['cae', 'mw'],
    "mahāsvāda": ['mw'],
    "mahāsvāmin": ['mw'],
    "mahāsya": ['cae', 'mw'],
    "mahāsādhanabhāga": ['mw'],
    "mahāsādhanika": ['mw'],
    "mahāsādhu": ['cae', 'mw'],
    "mahāsādhvī": ['mw'],
    "mahāsāgara": ['bhs'],
    "mahāsāgaraprabhāgambhīradhara": ['mw'],
    "mahāsāhasa": ['mw'],
    "mahāsāhasapramardanī": ['bhs'],
    "mahāsāhasika": ['mw'],
    "mahāsāhasikatayā": ['mw'],
    "mahāsāhasikatā": ['mw'],
    "mahāsāhasin": ['mw'],
    "mahāsāhasrikā": ['bhs'],
    "mahāsāla": ['cped'],
    "mahāsāman": ['mw'],
    "mahāsāmanta": ['mw'],
    "mahāsāmarāja": ['mw'],
    "mahāsāmānya": ['mw'],
    "mahāsāra": ['cae', 'cped', 'mw'],
    "mahāsārathi": ['mw'],
    "mahāsārtha": ['mw'],
    "mahāsāvaka": ['cped'],
    "mahāsāvetasa": ['mw'],
    "mahāsāṃdhivigrahika": ['mw'],
    "mahāsāṃghika": ['bhs', 'mw'],
    "mahāsāṃkhyāyana": ['mw'],
    "mahāsāṃtapana": ['mw'],
    "mahāsūci": ['mw'],
    "mahāsūkta": ['mw'],
    "mahāsūktavidhāna": ['mw'],
    "mahāsūkṣma": ['mw'],
    "mahāsūkṣmā": ['mw'],
    "mahāsūta": ['mw'],
    "mahātaila": ['mw'],
    "mahātala": ['cae', 'cped', 'mw'],
    "mahātamas": ['mw'],
    "mahātamaḥprabhā": ['mw'],
    "mahātamālapattracandanakardama": ['bhs'],
    "mahātantra": ['mw'],
    "mahātantrarāja": ['mw'],
    "mahātapa": ['mw'],
    "mahātapamanda": ['bhs'],
    "mahātapana": ['mw'],
    "mahātapas": ['cae', 'mw'],
    "mahātapasvin": ['cae', 'mw'],
    "mahātapaḥsaptamī": ['mw'],
    "mahātaru": ['mw'],
    "mahātattva": ['ddsa', 'mw'],
    "mahātattvā": ['mw'],
    "mahātaṇha": ['cped'],
    "mahāteja": ['bhs', 'mw'],
    "mahātejas": ['cae', 'mw'],
    "mahātejaḥparākrama": ['bhs'],
    "mahātejogarbha": ['bhs', 'mw'],
    "mahātighora": ['cae'],
    "mahātikta": ['mw'],
    "mahātiktaka": ['mw'],
    "mahātiktā": ['mw'],
    "mahātithi": ['mw'],
    "mahātiṭibha": ['mw'],
    "mahātman": ['cae', 'mw'],
    "mahātmavat": ['mw'],
    "mahātmya": ['mw'],
    "mahātodya": ['mw'],
    "mahātrikakubh": ['mw'],
    "mahātrikakud": ['mw'],
    "mahātripurasundaryuttaratāpanī": ['mw'],
    "mahātripurasundarīkavaca": ['mw'],
    "mahātripurasundarīmantranāmasahasra": ['mw'],
    "mahātripurasundarītāpanīyopaniṣad": ['mw'],
    "mahātriśūla": ['mw'],
    "mahāturuṣka": ['bhs'],
    "mahātuṣita": ['mw'],
    "mahātuṣṭijñānamudrā": ['mw'],
    "mahātyaya": ['cae', 'mw'],
    "mahātyayika": ['mw'],
    "mahātyāga": ['cae', 'mw'],
    "mahātyāgacitta": ['mw'],
    "mahātyāgamaya": ['mw'],
    "mahātyāgin": ['cae', 'mw'],
    "mahātāleśvara": ['mw'],
    "mahātālī": ['mw'],
    "mahātāpana": ['bhs'],
    "mahātāpaścita": ['mw'],
    "mahātārā": ['mw'],
    "mahātīkṣṇa": ['mw'],
    "mahātīkṣṇā": ['mw'],
    "mahāvada": ['cae', 'mw'],
    "mahāvadha": ['cae', 'gra', 'mw'],
    "mahāvailastha": ['gra', 'mw'],
    "mahāvaipulya": ['bhs', 'mw'],
    "mahāvaipulyasūtra": ['mw'],
    "mahāvaira": ['mw'],
    "mahāvairāja": ['mw'],
    "mahāvairājī": ['mw'],
    "mahāvaistāra": ['bhs'],
    "mahāvaiśvadeva": ['mw'],
    "mahāvaiśvāmitra": ['mw'],
    "mahāvaiśvānaravrata": ['mw'],
    "mahāvaiṣṭambha": ['mw'],
    "mahāvajraka": ['mw'],
    "mahāvaktra": ['mw'],
    "mahāvakāśa": ['mw'],
    "mahāvakṣas": ['mw'],
    "mahāvallī": ['mw'],
    "mahāvana": ['bhs', 'cae', 'mw'],
    "mahāvanasaṃghārāma": ['mw'],
    "mahāvandhyā": ['mw'],
    "mahāvapa": ['mw'],
    "mahāvaroha": ['mw'],
    "mahāvartana": ['mw'],
    "mahāvarti": ['mw'],
    "mahāvarā": ['mw'],
    "mahāvarāha": ['mw'],
    "mahāvasa": ['mw'],
    "mahāvastu": ['bhs', 'mw'],
    "mahāvasu": ['cae', 'gra', 'mw'],
    "mahāvaṃśa": ['mw'],
    "mahāvaṃśasamudbhava": ['mw'],
    "mahāvaṃśya": ['mw'],
    "mahāvaṃśāvalī": ['mw'],
    "mahāvaṇij": ['mw'],
    "mahāvaṭūrin": ['gra', 'mw'],
    "mahāvedha": ['mw'],
    "mahāvedi": ['mw'],
    "mahāvedāntaṣaṭka": ['mw'],
    "mahāvega": ['cae', 'mw'],
    "mahāvegalabdhasthāma": ['mw'],
    "mahāvegavatī": ['mw'],
    "mahāvegā": ['mw'],
    "mahāvela": ['mw'],
    "mahāvibhāṣā": ['mw'],
    "mahāvibhāṣāśāstra": ['mw'],
    "mahāvibhūta": ['bhs', 'mw'],
    "mahāvibhūti": ['mw'],
    "mahāvidagdha": ['mw'],
    "mahāvideha": ['mw'],
    "mahāvidehā": ['mw'],
    "mahāvidyeśvarī": ['mw'],
    "mahāvidyutprabha": ['bhs', 'mw'],
    "mahāvidyā": ['mw'],
    "mahāvidyādīpakalpa": ['mw'],
    "mahāvidyāprakaraṇa": ['mw'],
    "mahāvidyāprayoga": ['mw'],
    "mahāvidyāstava": ['mw'],
    "mahāvidyāstotra": ['mw'],
    "mahāvidyāsāracandrodaya": ['mw'],
    "mahāvighna": ['mw'],
    "mahāvihāra": ['mw'],
    "mahāvihāravāsin": ['mw'],
    "mahāvijaya": ['bhs'],
    "mahāvijña": ['mw'],
    "mahāvikrama": ['bhs', 'cae', 'mw'],
    "mahāvikramin": ['mw'],
    "mahāvikrāmin": ['bhs'],
    "mahāvimāna": ['bhs'],
    "mahāvipulā": ['cae', 'mw'],
    "mahāviraha": ['mw'],
    "mahāvirāva": ['mw'],
    "mahāvistara": ['mw'],
    "mahāvitānadharma": ['bhs'],
    "mahāvivāha": ['bhs', 'mw'],
    "mahāviśiṣṭa": ['mw'],
    "mahāviḍa": ['mw'],
    "mahāviṣa": ['mw'],
    "mahāviṣuva": ['mw'],
    "mahāviṣuvasaṃkrānti": ['mw'],
    "mahāviṣṇormahāstuti": ['mw'],
    "mahāviṣṇu": ['mw'],
    "mahāviṣṇupūjāpaddhati": ['mw'],
    "mahāviṣṇustutiṭīkā": ['mw'],
    "mahāvrata": ['cae', 'mw'],
    "mahāvratabhāṣya": ['mw'],
    "mahāvratadhara": ['mw'],
    "mahāvratahautra": ['mw'],
    "mahāvratapaddhati": ['mw'],
    "mahāvrataprayoga": ['mw'],
    "mahāvrataprayogānukrama": ['mw'],
    "mahāvratavat": ['mw'],
    "mahāvrataveṣabhṛt": ['mw'],
    "mahāvratika": ['mw'],
    "mahāvratikaveṣa": ['mw'],
    "mahāvratin": ['mw'],
    "mahāvratīya": ['mw'],
    "mahāvraṇa": ['mw'],
    "mahāvrāta": ['gra', 'mw'],
    "mahāvrīhi": ['mw'],
    "mahāvrīhimaya": ['mw'],
    "mahāvyasanasaptaka": ['mw'],
    "mahāvyutpatti": ['bhs', 'mw'],
    "mahāvyādhi": ['mw'],
    "mahāvyāhṛti": ['cae', 'mw'],
    "mahāvyūha": ['bhs', 'mw'],
    "mahāvādin": ['bhs', 'mw'],
    "mahāvāhana": ['bhs', 'mw'],
    "mahāvākya": ['cae', 'mw'],
    "mahāvākyadarpaṇa": ['mw'],
    "mahāvākyamantropadeśapaddhati": ['mw'],
    "mahāvākyamuktāvalī": ['mw'],
    "mahāvākyanirṇaya": ['mw'],
    "mahāvākyanyāsa": ['mw'],
    "mahāvākyapañcīkaraṇa": ['mw'],
    "mahāvākyarahasya": ['mw'],
    "mahāvākyaratnāvali": ['mw'],
    "mahāvākyaratnāvalī": ['mw'],
    "mahāvākyasiddhānta": ['mw'],
    "mahāvākyatva": ['mw'],
    "mahāvākyavicāra": ['mw'],
    "mahāvākyavivaraṇa": ['mw'],
    "mahāvākyaviveka": ['mw'],
    "mahāvākyavivekārthasākṣivivaraṇa": ['mw'],
    "mahāvākyavyākhyā": ['mw'],
    "mahāvākyaṭippaṇa": ['mw'],
    "mahāvākyopaniṣad": ['mw'],
    "mahāvākyārtha": ['mw'],
    "mahāvākyārthadarpaṇa": ['mw'],
    "mahāvākyārthaprabandha": ['mw'],
    "mahāvākyārthaprabodha": ['mw'],
    "mahāvākyārthavicāra": ['mw'],
    "mahāvālabhid": ['mw'],
    "mahāvāmadevya": ['mw'],
    "mahāvārttika": ['mw'],
    "mahāvāruṇī": ['mw'],
    "mahāvārāha": ['mw'],
    "mahāvārṣikā": ['mw'],
    "mahāvārṣikī": ['bhs'],
    "mahāvāstu": ['mw'],
    "mahāvāta": ['cae', 'mw'],
    "mahāvātasamūha": ['mw'],
    "mahāvātavyādhi": ['mw'],
    "mahāvātsapra": ['mw'],
    "mahāvāyu": ['mw'],
    "mahāvīci": ['bhs', 'cae', 'mw'],
    "mahāvīra": ['cae', 'cped', 'gra', 'mw'],
    "mahāvīracarita": ['cae', 'mw'],
    "mahāvīracaritra": ['mw'],
    "mahāvīrya": ['cae', 'mw'],
    "mahāvīryaparākrama": ['mw'],
    "mahāvīryā": ['bhs', 'mw'],
    "mahāvīrā": ['mw'],
    "mahāvīrānanda": ['mw'],
    "mahāvīta": ['mw'],
    "mahāvīṇā": ['mw'],
    "mahāvṛddha": ['mw'],
    "mahāvṛkṣa": ['cae', 'mw'],
    "mahāvṛkṣagalaskandha": ['mw'],
    "mahāvṛkṣakṣīra": ['mw'],
    "mahāvṛnda": ['mw'],
    "mahāvṛṣa": ['cae', 'mw'],
    "mahāyajña": ['cae', 'mw'],
    "mahāyajñabhāgahara": ['mw'],
    "mahāyajñakratu": ['mw'],
    "mahāyakṣa": ['mw'],
    "mahāyakṣasenāpati": ['mw'],
    "mahāyakṣī": ['mw'],
    "mahāyama": ['mw'],
    "mahāyamaka": ['mw'],
    "mahāyantra": ['mw'],
    "mahāyantrapravartana": ['mw'],
    "mahāyasa": ['cped', 'mw'],
    "mahāyati": ['mw'],
    "mahāyaudhājaya": ['mw'],
    "mahāyava": ['mw'],
    "mahāyañña": ['cped'],
    "mahāyaśas": ['bhs', 'cae', 'mw'],
    "mahāyaśaska": ['mw'],
    "mahāyaśākhya": ['bhs'],
    "mahāyia": ['gra'],
    "mahāyogapañcaratneāśvalāyanopayogyādhānaprakaraṇa": ['mw'],
    "mahāyogeśvara": ['cae', 'mw'],
    "mahāyogin": ['cae', 'mw'],
    "mahāyoni": ['mw'],
    "mahāyuddha": ['cae', 'mw'],
    "mahāyudha": ['mw'],
    "mahāyuga": ['cae', 'mw'],
    "mahāyuta": ['bhs', 'mw'],
    "mahāyya": ['cae', 'gra'],
    "mahāyāga": ['cped'],
    "mahāyāgika": ['bhs', 'mw'],
    "mahāyāma": ['mw'],
    "mahāyāmya": ['mw'],
    "mahāyāna": ['bhs', 'mw'],
    "mahāyānadeva": ['mw'],
    "mahāyānaparigrahaka": ['mw'],
    "mahāyānaprabhāsa": ['mw'],
    "mahāyānaprasādaprabhāvana": ['bhs'],
    "mahāyānasamparigrahaśāstra": ['mw'],
    "mahāyānasaṃgraha": ['bhs', 'mw'],
    "mahāyānasūtra": ['mw'],
    "mahāyānasūtraratnarāja": ['mw'],
    "mahāyānayogaśāstra": ['mw'],
    "mahāyānika": ['bhs'],
    "mahāyānopadeśa": ['bhs'],
    "mahāyānābhidharmasaṃgītiśāstra": ['mw'],
    "mahāyātrika": ['mw'],
    "mahāyātrā": ['mw'],
    "mahāñjana": ['mw'],
    "mahāñji": ['mw'],
    "mahāśa": ['mw'],
    "mahāśabda": ['cae', 'mw'],
    "mahāśaila": ['cae', 'mw'],
    "mahāśairīṣa": ['mw'],
    "mahāśaivatantra": ['mw'],
    "mahāśakti": ['bhs', 'mw'],
    "mahāśaktinyāsa": ['mw'],
    "mahāśakuni": ['bhs', 'mw'],
    "mahāśakya": ['bhs', 'mw'],
    "mahāśalka": ['cae', 'mw'],
    "mahāśalkalin": ['mw'],
    "mahāśalkā": ['mw'],
    "mahāśambhu": ['mw'],
    "mahāśamī": ['mw'],
    "mahāśana": ['cae', 'mw'],
    "mahāśanidhvaja": ['cae', 'mw'],
    "mahāśaphara": ['mw'],
    "mahāśara": ['cae', 'mw'],
    "mahāśarman": ['mw'],
    "mahāśarīra": ['cae', 'mw'],
    "mahāśastra": ['mw'],
    "mahāśatakoṭi": ['mw'],
    "mahāśatā": ['mw'],
    "mahāśatāvarī": ['mw'],
    "mahāśauṇḍī": ['mw'],
    "mahāśauṣira": ['mw'],
    "mahāśaya": ['cae', 'mw'],
    "mahāśayana": ['mw'],
    "mahāśayyā": ['mw'],
    "mahāśaṅkha": ['cae', 'mw'],
    "mahāśaṅkhamaya": ['mw'],
    "mahāśaṅkhamālāsaṃskāra": ['mw'],
    "mahāśaṅku": ['mw'],
    "mahāśaṇapuṣpikā": ['mw'],
    "mahāśaṭha": ['mw'],
    "mahāśetavatī": ['mw'],
    "mahāśeṣa": ['bhs'],
    "mahāśilā": ['mw'],
    "mahāśimbī": ['mw'],
    "mahāśiras": ['cae', 'mw'],
    "mahāśiraḥsamudbhava": ['mw'],
    "mahāśirodhara": ['mw'],
    "mahāśiva": ['cae', 'mw'],
    "mahāśivarātri": ['mw'],
    "mahāśivarātrinirṇaya": ['mw'],
    "mahāśivarātrivrata": ['mw'],
    "mahāśivarātrivratanirṇaya": ['mw'],
    "mahāśivarātryudyāpana": ['mw'],
    "mahāślakṣṇā": ['mw'],
    "mahāśman": ['cae', 'mw'],
    "mahāśmaśāna": ['cae', 'mw'],
    "mahāśoṇa": ['mw'],
    "mahāśrama": ['mw'],
    "mahāśramaṇa": ['mw'],
    "mahāśrotriya": ['mw'],
    "mahāśruti": ['mw'],
    "mahāśrāvaka": ['bhs', 'mw'],
    "mahāśrāvaṇikā": ['mw'],
    "mahāśrāvaṇī": ['mw'],
    "mahāśrī": ['mw'],
    "mahāśubhra": ['mw'],
    "mahāśuklā": ['mw'],
    "mahāśukti": ['mw'],
    "mahāśva": ['mw'],
    "mahāśvaśālā": ['mw'],
    "mahāśveta": ['mw'],
    "mahāśvetaghaṇṭī": ['mw'],
    "mahāśvetā": ['mw'],
    "mahāśvāsa": ['bhs', 'mw'],
    "mahāśvāsasārin": ['mw'],
    "mahāśyāmā": ['mw'],
    "mahāśāka": ['mw'],
    "mahāśākha": ['mw'],
    "mahāśākhā": ['mw'],
    "mahāśākya": ['mw'],
    "mahāśāla": ['cae', 'mw'],
    "mahāśāli": ['mw'],
    "mahāśālikā": ['bhs'],
    "mahāśālvaṇa": ['mw'],
    "mahāśālīna": ['mw'],
    "mahāśāmbavaka": ['mw'],
    "mahāśānti": ['mw'],
    "mahāśāntinirūpaṇa": ['mw'],
    "mahāśāntipaddhati": ['mw'],
    "mahāśāntiviniyogamālā": ['mw'],
    "mahāśārīrakopaniṣad": ['mw'],
    "mahāśāsana": ['mw'],
    "mahāśīla": ['mw'],
    "mahāśīrṣa": ['mw'],
    "mahāśītavatī": ['mw'],
    "mahāśītā": ['mw'],
    "mahāśūdra": ['mw'],
    "mahāśūdrā": ['mw'],
    "mahāśūdrī": ['mw'],
    "mahāśūnya": ['mw'],
    "mahāśūnyatā": ['mw'],
    "mahāśṛṅga": ['mw'],
    "mahāḍakara": ['mw'],
    "mahāḍhya": ['cae', 'mw'],
    "mahāḍimphika": ['bhs'],
    "mahāḍīna": ['mw'],
    "mahāṅga": ['mw'],
    "mahāṇagnī": ['mw'],
    "mahāṣaṣṭhī": ['mw'],
    "mahāṣaṭtakrataila": ['mw'],
    "mahāṣoḍhānyāsa": ['mw'],
    "mahāṣṭamī": ['mw'],
    "mahāṣṭamīnirṇaya": ['mw'],
    "mahāṣṭamīsaṃdhipūjā": ['mw'],
    "mahāṭavi": ['mw'],
    "mahāṭavī": ['mw'],
    "mahāṭiṭibha": ['bhs'],
    "mahī": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mahībhartṛ": ['cae', 'mw'],
    "mahībhaṭṭa": ['mw'],
    "mahībhuj": ['cae', 'mw'],
    "mahībhāra": ['mw'],
    "mahībhṛt": ['cae', 'mw'],
    "mahīcandra": ['mw'],
    "mahīcara": ['cae', 'mw'],
    "mahīcārin": ['cae', 'mw'],
    "mahīdhara": ['bhs', 'cae', 'cped', 'mw'],
    "mahīdharadatta": ['mw'],
    "mahīdhra": ['cae', 'mw'],
    "mahīdhraka": ['mw'],
    "mahīdurga": ['cae', 'mw'],
    "mahīdāsa": ['mw'],
    "mahīja": ['cae', 'mw'],
    "mahījā": ['mw'],
    "mahījīvā": ['mw'],
    "mahīkampa": ['cae', 'ddsa', 'mw'],
    "mahīkṛ": ['ddsa', 'mw'],
    "mahīkṣit": ['cae', 'mw'],
    "mahīlatā": ['mw'],
    "mahīlukā": ['cae', 'mw'],
    "mahīlā": ['ap90', 'mw'],
    "mahīmaghavan": ['mw'],
    "mahīmahendra": ['mw'],
    "mahīmahikāṃśu": ['mw'],
    "mahīmaya": ['cae', 'mw'],
    "mahīmayī": ['mw'],
    "mahīmaṇḍala": ['mw'],
    "mahīmṛga": ['mw'],
    "mahīna": ['mw'],
    "mahīndra": ['cae', 'mw'],
    "mahīndrendra": ['cae', 'mw'],
    "mahīnātha": ['cae', 'mw'],
    "mahīpa": ['cae', 'mw'],
    "mahīpatana": ['mw'],
    "mahīpati": ['cae', 'cped', 'mw'],
    "mahīpatitva": ['mw'],
    "mahīpradāna": ['mw'],
    "mahīprakampa": ['mw'],
    "mahīpraroha": ['mw'],
    "mahīpraśāsana": ['mw'],
    "mahīprācīra": ['mw'],
    "mahīprāvara": ['mw'],
    "mahīputra": ['mw'],
    "mahīputrī": ['mw'],
    "mahīpāla": ['cae', 'cped', 'mw'],
    "mahīpālaputra": ['mw'],
    "mahīpṛṣṭha": ['cae', 'mw'],
    "mahīrajas": ['ddsa', 'mw'],
    "mahīrandhra": ['mw'],
    "mahīrata": ['mw'],
    "mahīraṇa": ['mw'],
    "mahīruh": ['cae', 'mw'],
    "mahīruha": ['cae', 'cped', 'mw'],
    "mahīsaha": ['mw'],
    "mahīsaṃgama": ['mw'],
    "mahīsthāma": ['bhs'],
    "mahīsura": ['mw'],
    "mahīsuta": ['mw'],
    "mahīsutā": ['mw'],
    "mahīsvāmin": ['mw'],
    "mahīsūnu": ['mw'],
    "mahītala": ['cae', 'cped', 'mw'],
    "mahītalavisarpin": ['mw'],
    "mahītaṭa": ['mw'],
    "mahīvallabha": ['mw'],
    "mahīy": ['cae', 'gra'],
    "mahīya": ['ddsa', 'mw'],
    "mahīyas": ['ap90', 'ddsa', 'mw'],
    "mahīyate": ['ap90'],
    "mahīyatva": ['mw'],
    "mahīyaṃs": ['cae'],
    "mahīyu": ['cae', 'gra', 'mw'],
    "mahīyā": ['cae', 'ddsa', 'mw'],
    "mahīśvara": ['cae', 'mw'],
    "mahīśākhya": ['bhs'],
    "mahīśāsaka": ['bhs', 'mw'],
    "maidhātitha": ['mw'],
    "maidhāva": ['mw'],
    "maidhāvaka": ['mw'],
    "maidhāvakaṃ": ['ap90'],
    "maigha": ['cae', 'mw'],
    "maihika": ['mw'],
    "mailinda": ['ddsa', 'mw'],
    "mailiṃdaḥ": ['ap90'],
    "maimata": ['mw'],
    "maimatāyana": ['mw'],
    "maimatāyani": ['mw'],
    "mainavī": ['mw'],
    "mainda": ['cae', 'mw'],
    "maindahan": ['mw'],
    "maindamardana": ['mw'],
    "maineya": ['bhs', 'mw'],
    "mainika": ['cae', 'mw'],
    "maināka": ['cae', 'ddsa', 'mw'],
    "mainākabhaginī": ['mw'],
    "mainākaprabhava": ['mw'],
    "mainākasvasṛ": ['mw'],
    "mainākaḥ": ['ap90'],
    "maināla": ['cae', 'ddsa', 'mw'],
    "mainālaḥ": ['ap90'],
    "mairava": ['cae', 'ddsa', 'mw'],
    "maireya": ['cae', 'ddsa', 'mw'],
    "maireyaka": ['mw'],
    "maireyaḥ": ['ap90'],
    "mairāla": ['mw'],
    "mairāvaṇa": ['mw'],
    "mairāvaṇacaritra": ['mw'],
    "maithila": ['cae', 'ddsa', 'mw'],
    "maithilakāyastha": ['mw'],
    "maithilapaddhati": ['mw'],
    "maithilasaṃgraha": ['mw'],
    "maithilavācaspati": ['mw'],
    "maithilaśrīdatta": ['mw'],
    "maithilaḥ": ['ap90'],
    "maithileya": ['mw'],
    "maithilika": ['mw'],
    "maithilī": ['mw'],
    "maithilīnāṭaka": ['mw'],
    "maithilīpariṇaya": ['mw'],
    "maithilīśaraṇa": ['mw'],
    "maithuna": ['ap90', 'cae', 'ddsa', 'mw'],
    "maithunadharmin": ['mw'],
    "maithunagamana": ['mw'],
    "maithunagata": ['mw'],
    "maithunajvara": ['mw'],
    "maithunavairāgya": ['mw'],
    "maithunika": ['mw'],
    "maithunikā": ['ap90', 'mw'],
    "maithunin": ['ap90', 'cae', 'ddsa', 'mw'],
    "maithunopagamana": ['mw'],
    "maithunya": ['ap90', 'cae', 'mw'],
    "maithunābhighāta": ['mw'],
    "maithunābhāṣaṇa": ['bhs', 'mw'],
    "maithunībhāva": ['mw'],
    "maitra": ['ap90', 'cae', 'ddsa', 'mw'],
    "maitrabala": ['bhs', 'mw'],
    "maitrabha": ['mw'],
    "maitracitta": ['mw'],
    "maitraka": ['bhs', 'cae', 'mw'],
    "maitrakanya": ['bhs'],
    "maitrakanyaka": ['mw'],
    "maitrakaṃ": ['ap90'],
    "maitranakṣatra": ['mw'],
    "maitranāma": ['bhs'],
    "maitranātha": ['bhs'],
    "maitrasūtra": ['mw'],
    "maitratā": ['mw'],
    "maitravardhaka": ['mw'],
    "maitravardhraka": ['mw'],
    "maitraśrī": ['bhs'],
    "maitraśākhā": ['mw'],
    "maitreya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "maitreyaka": ['cae', 'mw'],
    "maitreyakaḥ": ['ap90'],
    "maitreyarakṣita": ['mw'],
    "maitreyasūtra": ['mw'],
    "maitreyavana": ['mw'],
    "maitreyavimokṣa": ['bhs'],
    "maitreyikā": ['ap90', 'mw'],
    "maitreyopaniṣad": ['mw'],
    "maitreyyupaniṣad": ['mw'],
    "maitreyī": ['mw'],
    "maitreyībrāhmaṇa": ['mw'],
    "maitreyīśākhopaniṣad": ['mw'],
    "maitri": ['mw'],
    "maitrika": ['mw'],
    "maitrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "maitriya": ['bhs'],
    "maitrya": ['cae', 'ddsa', 'mw'],
    "maitryaṃ": ['ap90'],
    "maitryupaniṣad": ['mw'],
    "maitryā": ['bhs'],
    "maitryābhimukha": ['mw'],
    "maitrā": ['bhs'],
    "maitrābārhaspatya": ['mw'],
    "maitrākṣajyotika": ['cae', 'ddsa', 'mw'],
    "maitrāsatā": ['bhs'],
    "maitrāvant": ['bhs'],
    "maitrāvaruṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "maitrāvaruṇacamasīya": ['mw'],
    "maitrāvaruṇahautra": ['mw'],
    "maitrāvaruṇaprayoga": ['mw'],
    "maitrāvaruṇasomaprayoga": ['mw'],
    "maitrāvaruṇaśastra": ['mw'],
    "maitrāvaruṇaśruti": ['mw'],
    "maitrāvaruṇaḥ": ['ap90'],
    "maitrāvaruṇi": ['ddsa', 'mw'],
    "maitrāvaruṇiḥ": ['ap90'],
    "maitrāvaruṇīya": ['mw'],
    "maitrāya": ['mw'],
    "maitrāyajña": ['bhs'],
    "maitrāyana": ['bhs'],
    "maitrāyati": ['bhs'],
    "maitrāyaṇa": ['cae', 'ddsa', 'mw'],
    "maitrāyaṇagṛhyapaddhati": ['mw'],
    "maitrāyaṇaka": ['mw'],
    "maitrāyaṇi": ['mw'],
    "maitrāyaṇopaniṣad": ['mw'],
    "maitrāyaṇyupaniṣad": ['mw'],
    "maitrāyaṇī": ['bhs', 'mw'],
    "maitrāyaṇībrāhmaṇabhāṣyadīpikā": ['mw'],
    "maitrāyaṇībrāhmaṇopaniṣad": ['mw'],
    "maitrāyaṇīpariśiṣṭa": ['mw'],
    "maitrāyaṇīputra": ['mw'],
    "maitrāyaṇīsaṃhitā": ['cae', 'mw'],
    "maitrāyaṇīya": ['mw'],
    "maitrāyaṇīyasaṃhitā": ['mw'],
    "maitrāyaṇīyaurdhvadehikapaddhati": ['mw'],
    "maitrāyaṇīyaśākhā": ['mw'],
    "maitrāyaṇīyopaniṣad": ['mw'],
    "maitrāyaṇīśākhā": ['mw'],
    "maitrī": ['bhs', 'ddsa', 'mw'],
    "maitrībala": ['mw'],
    "maitrībhāva": ['cae'],
    "maitrīdāna": ['mw'],
    "maitrīkaruṇāmudita": ['mw'],
    "maitrīmaya": ['mw'],
    "maitrīnātha": ['mw'],
    "maitrīpakṣapāta": ['mw'],
    "maitrīpūrva": ['mw'],
    "maitrīvyākaraṇa": ['bhs'],
    "maitrīya": ['bhs'],
    "maitrīyaśa": ['bhs'],
    "maiśradhānya": ['mw'],
    "maiṃdaḥ": ['ap90'],
    "maiṇmiṇya": ['mw'],
    "maj": ['gra', 'mw'],
    "majamudāra": ['mw'],
    "majiraka": ['mw'],
    "majj": ['cae', 'ddsa', 'gra', 'mw'],
    "majja": ['cped', 'mw'],
    "majjaka": ['mw'],
    "majjakṛt": ['mw'],
    "majjala": ['mw'],
    "majjan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "majjana": ['cae', 'cped', 'ddsa', 'mw'],
    "majjanagata": ['mw'],
    "majjanamaṇḍapa": ['mw'],
    "majjanaṃ": ['ap90'],
    "majjanonmajjana": ['mw'],
    "majjanta": ['cped'],
    "majjanvat": ['mw'],
    "majjanā": ['cped'],
    "majjapa": ['cped'],
    "majjapāna": ['cped'],
    "majjapāyī": ['cped'],
    "majjara": ['mw'],
    "majjarasa": ['mw'],
    "majjas": ['cae', 'ddsa', 'mw'],
    "majjasamudbhava": ['mw'],
    "majjatas": ['mw'],
    "majjati": ['cped'],
    "majjavikkayī": ['cped'],
    "majjayitṛ": ['cae', 'mw'],
    "majjha": ['cped'],
    "majjhadesa": ['cped'],
    "majjhantika": ['cped'],
    "majjhantikasamaya": ['cped'],
    "majjhatta": ['cped'],
    "majjhattatā": ['cped'],
    "majjhaṇha": ['cped'],
    "majjhaṭṭha": ['cped'],
    "majjhima": ['cped'],
    "majjhimadesa": ['cped'],
    "majjhimapurisa": ['cped'],
    "majjhimavaya": ['cped'],
    "majjhimayāma": ['cped'],
    "majji": ['cped'],
    "majjikā": ['ap90', 'mw'],
    "majjita": ['cped'],
    "majjitvā": ['cped'],
    "majjā": ['ap90', 'ddsa', 'mw'],
    "majjāgata": ['bhs'],
    "majjāja": ['mw'],
    "majjākara": ['mw'],
    "majjāmeha": ['mw'],
    "majjāna": ['mw'],
    "majjāra": ['cped'],
    "majjārajas": ['mw'],
    "majjārasa": ['mw'],
    "majjārī": ['cped'],
    "majjāsāra": ['mw'],
    "majjāṭīkā": ['mw'],
    "majjūka": ['mw'],
    "majjūṣā": ['ap90', 'mw'],
    "majman": ['cae', 'gra'],
    "majmana": ['ddsa', 'mw'],
    "majmanā": ['mw'],
    "majra": ['mw'],
    "mak": ['mw'],
    "maka": ['mw'],
    "makaci": ['cped'],
    "makacivattha": ['cped'],
    "makacivāka": ['cped'],
    "makadatta": ['mw'],
    "makaka": ['mw'],
    "makamakāy": ['cae'],
    "makamakāya": ['ddsa', 'mw'],
    "makandikā": ['mw'],
    "makara": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "makaradantaka": ['cped'],
    "makaradaṃṣṭrā": ['mw'],
    "makaradhvaja": ['bhs', 'cae', 'mw'],
    "makarakaṭī": ['ddsa', 'mw'],
    "makaraketana": ['cae', 'mw'],
    "makaraketu": ['cae', 'mw'],
    "makaraketumat": ['mw'],
    "makarakuṇḍala": ['mw'],
    "makaralāñchana": ['mw'],
    "makaramukha": ['mw'],
    "makaramāsa": ['mw'],
    "makaranda": ['cae', 'cped', 'ddsa', 'mw'],
    "makarandadīpikā": ['mw'],
    "makarandakaṇāya": ['mw'],
    "makarandakārikā": ['mw'],
    "makarandapañcāṅgavidhi": ['mw'],
    "makarandaprakāśa": ['mw'],
    "makarandapāla": ['mw'],
    "makarandavat": ['mw'],
    "makarandavatī": ['mw'],
    "makarandavivaraṇa": ['mw'],
    "makarandavivṛti": ['mw'],
    "makarandavāsa": ['mw'],
    "makarandaśarman": ['mw'],
    "makarandikā": ['mw'],
    "makarandodyāna": ['cae', 'mw'],
    "makaraputra": ['bhs'],
    "makarapāṭaka": ['mw'],
    "makararāśi": ['mw'],
    "makarasaptamī": ['mw'],
    "makarasaṃkramaṇa": ['mw'],
    "makarasaṃkrānti": ['mw'],
    "makarasaṃkrāntidānaprayoga": ['mw'],
    "makarasaṃkrāntitiladāna": ['mw'],
    "makaravibhūṣaṇaketana": ['mw'],
    "makaravāhana": ['mw'],
    "makaravāhinī": ['mw'],
    "makaraḥ": ['ap90'],
    "makaraṃdama": ['bhs'],
    "makaraṃdavat": ['ap90'],
    "makaraṃdaḥ": ['ap90'],
    "makarikā": ['ddsa', 'mw'],
    "makarin": ['ap90', 'mw'],
    "makarākara": ['mw'],
    "makarākāra": ['mw'],
    "makarākṣa": ['mw'],
    "makarālaya": ['cae', 'mw'],
    "makarānana": ['mw'],
    "makarāvāsa": ['cae', 'mw'],
    "makarāyaṇa": ['mw'],
    "makarāśva": ['mw'],
    "makarāṅka": ['mw'],
    "makarī": ['ap90', 'ddsa', 'mw'],
    "makarīlekhā": ['mw'],
    "makarīpattra": ['mw'],
    "makarīprastha": ['mw'],
    "makasa": ['cped'],
    "makasavāraṇa": ['cped'],
    "makat": ['mw'],
    "makatpitṛka": ['mw'],
    "makaṣṭu": ['mw'],
    "makeruka": ['mw'],
    "makh": ['ap90', 'mw'],
    "makha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "makhadveṣin": ['mw'],
    "makhadviṣ": ['cae', 'mw'],
    "makhahan": ['cae', 'mw'],
    "makhakriyā": ['mw'],
    "makhamathana": ['cae', 'mw'],
    "makhamaya": ['mw'],
    "makhamukha": ['mw'],
    "makhas": ['ddsa', 'gra', 'mw'],
    "makhasvāmin": ['mw'],
    "makhasy": ['cae', 'gra'],
    "makhasya": ['mw'],
    "makhasyu": ['ap90', 'cae', 'gra', 'mw'],
    "makhatrayavidhāna": ['mw'],
    "makhatrātṛ": ['mw'],
    "makhavahni": ['mw'],
    "makhavat": ['mw'],
    "makhavedī": ['mw'],
    "makhaviṣaya": ['mw'],
    "makheśa": ['mw'],
    "makhya": ['mw'],
    "makhāgni": ['mw'],
    "makhālaya": ['mw'],
    "makhānala": ['mw'],
    "makhānna": ['mw'],
    "makhāpeta": ['mw'],
    "makhāsuhṛd": ['mw'],
    "makhāṃśabhāj": ['cae', 'ddsa', 'mw'],
    "makk": ['ap90', 'mw'],
    "makkalaḥ": ['ap90'],
    "makkalla": ['mw'],
    "makkaṭa": ['cped'],
    "makkaṭaka": ['cped'],
    "makkaṭasutta": ['cped'],
    "makkaṭī": ['cped'],
    "makkha": ['cped'],
    "makkhaṇa": ['cped'],
    "makkhesi": ['cped'],
    "makkheti": ['cped'],
    "makkhetvā": ['cped'],
    "makkhikā": ['cped'],
    "makkhita": ['cped'],
    "makkhī": ['cped'],
    "makkola": ['mw'],
    "makkolaḥ": ['ap90'],
    "makkoṭaka": ['bhs'],
    "makkula": ['mw'],
    "makkulaḥ": ['ap90'],
    "makula": ['cped', 'mw'],
    "makulaḥ": ['ap90'],
    "makunda": ['bhs'],
    "makura": ['mw'],
    "makuraḥ": ['ap90'],
    "makurāṇa": ['mw'],
    "makuti": ['mw'],
    "makutiḥ": ['ap90'],
    "makuāṇa": ['mw'],
    "makuṣṭa": ['mw'],
    "makuṣṭaka": ['mw'],
    "makuṣṭaḥ": ['ap90'],
    "makuṣṭha": ['ap90', 'ddsa', 'mw'],
    "makuṭa": ['bhs', 'cped', 'mw'],
    "makuṭabandha": ['bhs'],
    "makuṭabandhana": ['bhs', 'mw'],
    "makuṭadantī": ['bhs'],
    "makuṭaṃ": ['ap90'],
    "makuṭāgama": ['mw'],
    "makvaṇa": ['mw'],
    "makāra": ['cae', 'ddsa', 'mw'],
    "makārapañcaka": ['mw'],
    "makāravipulā": ['mw'],
    "makārādisahasranāman": ['mw'],
    "makūlaka": ['mw'],
    "makūlakaḥ": ['ap90'],
    "makṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "makṣa": ['mw'],
    "makṣavīrya": ['mw'],
    "makṣaḥ": ['ap90'],
    "makṣika": ['cae'],
    "makṣikaḥ": ['ap90'],
    "makṣikā": ['cae', 'ddsa', 'gra', 'mw'],
    "makṣikāmala": ['mw'],
    "makṣikāśraya": ['mw'],
    "makṣita": ['bhs'],
    "makṣu": ['cae', 'ddsa', 'gra', 'mw'],
    "makṣuṃgama": ['gra', 'mw'],
    "makṣuṇa": ['mw'],
    "makṣā": ['cae', 'ddsa', 'gra', 'mw'],
    "makṣī": ['bhs'],
    "makṣīkā": ['mw'],
    "makṣū": ['cae', 'gra', 'mw'],
    "makṣūjavas": ['gra', 'mw'],
    "makṣūtama": ['mw'],
    "makṣūyu": ['cae', 'gra', 'mw'],
    "mal": ['ap90', 'mw'],
    "mala": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "malabhedinī": ['mw'],
    "malabhuj": ['mw'],
    "malabāra": ['mw'],
    "malabāradeśa": ['mw'],
    "malada": ['bhs', 'mw'],
    "maladhārin": ['mw'],
    "maladhātrī": ['bhs', 'mw'],
    "maladigdhāṅga": ['mw'],
    "maladrava": ['mw'],
    "maladrāvin": ['mw'],
    "maladā": ['mw'],
    "maladāyaka": ['mw'],
    "maladūṣita": ['mw'],
    "malaga": ['cae', 'mw'],
    "malaghna": ['mw'],
    "malaghnī": ['mw'],
    "malagrahi": ['mw'],
    "malahantṛ": ['mw'],
    "malahā": ['mw'],
    "malahāraka": ['mw'],
    "malaja": ['mw'],
    "malajñu": ['mw'],
    "malaka": ['mw'],
    "malakarṣaṇa": ['mw'],
    "malakoṣṭhaka": ['mw'],
    "malakūṭa": ['mw'],
    "malamallaka": ['mw'],
    "malamallakaśeṣa": ['mw'],
    "malamāsa": ['mw'],
    "malamāsakathā": ['mw'],
    "malamāsamāhātmya": ['mw'],
    "malamāsanirūpaṇa": ['mw'],
    "malamāsanirṇaya": ['mw'],
    "malamāsanirṇayatantrasāra": ['mw'],
    "malamāsapūjā": ['mw'],
    "malamāsasāriṇī": ['mw'],
    "malamāsatattva": ['mw'],
    "malamāsavicāra": ['mw'],
    "malamāsavrata": ['mw'],
    "malamāsāghamarṣaṇī": ['mw'],
    "malamūtraparityāga": ['mw'],
    "malana": ['mw'],
    "malanaṃ": ['ap90'],
    "malanā": ['mw'],
    "malapaṅka": ['cae', 'mw'],
    "malapaṅkin": ['mw'],
    "malaprāladeśa": ['mw'],
    "malaprāladeśīya": ['mw'],
    "malapu": ['mw'],
    "malapū": ['mw'],
    "malapṛṣṭha": ['mw'],
    "malara": ['bhs', 'mw'],
    "malarodha": ['mw'],
    "malarodhana": ['mw'],
    "malasruti": ['mw'],
    "malatara": ['cped'],
    "malatva": ['mw'],
    "malavadeśa": ['mw'],
    "malavadvāsas": ['mw'],
    "malavaiśamya": ['mw'],
    "malavant": ['cae'],
    "malavat": ['ap90', 'ddsa', 'mw'],
    "malavega": ['mw'],
    "malavināśinī": ['mw'],
    "malavisarga": ['mw'],
    "malavisarjana": ['mw'],
    "malaviśodhana": ['mw'],
    "malaviṣṭambha": ['mw'],
    "malavāhin": ['mw'],
    "malavānara": ['mw'],
    "malavārin": ['mw'],
    "malaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "malayabhūbhṛt": ['cae', 'mw'],
    "malayabhūmi": ['mw'],
    "malayadeśa": ['mw'],
    "malayadhvaja": ['mw'],
    "malayadhvajanarapati": ['mw'],
    "malayadruma": ['cae', 'mw'],
    "malayadvīpa": ['mw'],
    "malayagandhinī": ['mw'],
    "malayagiri": ['mw'],
    "malayaja": ['cae', 'mw'],
    "malayajarajas": ['mw'],
    "malayajarasa": ['mw'],
    "malayajālepa": ['mw'],
    "malayaketu": ['mw'],
    "malayamarut": ['mw'],
    "malayamālin": ['mw'],
    "malayaparvata": ['cae', 'mw'],
    "malayaprabha": ['mw'],
    "malayapura": ['mw'],
    "malayaruha": ['mw'],
    "malayarāja": ['mw'],
    "malayarājastotra": ['mw'],
    "malayasamīra": ['mw'],
    "malayasiṃha": ['mw'],
    "malayavatī": ['mw'],
    "malayavāsinī": ['mw'],
    "malayavāta": ['mw'],
    "malayaḥ": ['ap90'],
    "malayendu": ['mw'],
    "malayodbhava": ['mw'],
    "malayā": ['mw'],
    "malayācala": ['cae', 'mw'],
    "malayācalakhaṇḍa": ['mw'],
    "malayādri": ['cae', 'mw'],
    "malayādrivāyu": ['mw'],
    "malayānila": ['cae', 'mw'],
    "malayāvatī": ['mw'],
    "malayū": ['mw'],
    "malaśuddhi": ['mw'],
    "malha": ['cae', 'mw'],
    "malhaṇa": ['ddsa', 'mw'],
    "malhaṇastotra": ['mw'],
    "malhaṇīya": ['mw'],
    "malhāṇapura": ['ddsa'],
    "mali": ['mw'],
    "maliha": ['mw'],
    "malika": ['mw'],
    "malikaḥ": ['ap90'],
    "malimlu": ['cae', 'mw'],
    "malimluc": ['cae', 'ddsa', 'mw'],
    "malimluca": ['cae', 'mw'],
    "malimlucatattva": ['mw'],
    "malimlucaḥ": ['ap90'],
    "malimlusenā": ['cae', 'mw'],
    "malina": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "malinaka": ['cped'],
    "malinamanas": ['mw'],
    "malinamukha": ['mw'],
    "malinaprabha": ['mw'],
    "malinatva": ['mw'],
    "malinatā": ['ap90', 'mw'],
    "malinavasana": ['ddsa'],
    "malinay": ['cae'],
    "malinaya": ['ddsa', 'mw'],
    "malinayati": ['ap90'],
    "maliniman": ['ap90', 'cae', 'ddsa', 'mw'],
    "malinita": ['ap90', 'mw'],
    "malināmbu": ['mw'],
    "malināsya": ['mw'],
    "malinātman": ['mw'],
    "malinī": ['mw'],
    "malinībhū": ['ap90', 'mw'],
    "malinīkara": ['mw'],
    "malinīkaraṇa": ['cae', 'ddsa', 'mw'],
    "malinīkaraṇīya": ['cae', 'mw'],
    "malinīkṛ": ['ap90', 'cae', 'mw'],
    "maliḥ": ['ap90'],
    "maliṣṭha": ['mw'],
    "maliṣṭhā": ['ap90', 'mw'],
    "mall": ['ap90', 'mw'],
    "malla": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mallabandhāntara": ['mw'],
    "mallabhaṭītūrya": ['mw'],
    "mallabhaṭṭa": ['mw'],
    "mallabhāvana": ['mw'],
    "mallabhū": ['mw'],
    "mallabhūmi": ['mw'],
    "malladeva": ['mw'],
    "malladvādaśī": ['mw'],
    "malladvādaśīvrata": ['mw'],
    "mallaga": ['mw'],
    "mallaghaṭī": ['cae', 'mw'],
    "mallaja": ['mw'],
    "mallaka": ['bhs', 'cped', 'mw'],
    "mallakasampuṭa": ['mw'],
    "mallakaḥ": ['ap90'],
    "mallakoṣṭa": ['mw'],
    "mallakoṣṭaka": ['mw'],
    "mallakrīḍā": ['mw'],
    "mallakūṭa": ['mw'],
    "mallamalla": ['mw'],
    "mallanāga": ['mw'],
    "mallanātha": ['mw'],
    "mallaprakāśa": ['mw'],
    "mallapriya": ['mw'],
    "mallapura": ['mw'],
    "mallarāja": ['mw'],
    "mallarāṣṭra": ['mw'],
    "mallatāla": ['mw'],
    "mallatūrya": ['mw'],
    "mallava": ['mw'],
    "mallavena": ['mw'],
    "mallaveśa": ['mw'],
    "mallavidyā": ['mw'],
    "mallavāstu": ['mw'],
    "mallayuddha": ['cae', 'cped', 'mw'],
    "mallayārya": ['mw'],
    "mallayātrā": ['mw'],
    "mallaśilāyuddha": ['mw'],
    "mallaśālā": ['mw'],
    "mallaṭasūtraṭīkā": ['mw'],
    "malli": ['mw'],
    "mallibhūṣaṇadeva": ['mw'],
    "malligandhi": ['cae', 'mw'],
    "mallika": ['mw'],
    "mallikapūrva": ['mw'],
    "mallikā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "mallikāchad": ['mw'],
    "mallikāchadana": ['mw'],
    "mallikāgandha": ['mw'],
    "mallikākhya": ['ddsa', 'mw'],
    "mallikākusumapriyā": ['mw'],
    "mallikākṣa": ['cae', 'mw'],
    "mallikākṣī": ['mw'],
    "mallikāmoda": ['mw'],
    "mallikāmāruta": ['mw'],
    "mallikāpuṣpa": ['mw'],
    "mallikāpīḍa": ['mw'],
    "mallikārjuna": ['mw'],
    "mallikārjunaśṛṅga": ['mw'],
    "mallikārjunīya": ['mw'],
    "mallinātha": ['cae', 'ddsa', 'mw'],
    "mallināthacaritra": ['mw'],
    "mallinī": ['mw'],
    "mallipattra": ['mw'],
    "mallivāra": ['mw'],
    "malliḥ": ['ap90'],
    "malliṣeṇasūri": ['mw'],
    "mallu": ['mw'],
    "malluḥ": ['ap90'],
    "mallā": ['ddsa', 'mw'],
    "mallādarśa": ['mw'],
    "mallādi": ['mw'],
    "mallānakagrāma": ['mw'],
    "mallāpura": ['mw'],
    "mallāpuramāhātmya": ['mw'],
    "mallāra": ['mw'],
    "mallāraḥ": ['ap90'],
    "mallāri": ['ddsa', 'mw'],
    "mallāribhujaṃga": ['mw'],
    "mallārihṛdaya": ['mw'],
    "mallārikavaca": ['mw'],
    "mallārimāhātmya": ['mw'],
    "mallāripaddhatiṭīkā": ['mw'],
    "mallāripratiṣṭhā": ['mw'],
    "mallārisahasranāman": ['mw'],
    "mallāriṣṭā": ['mw'],
    "mallārjuna": ['mw'],
    "mallāryaṣṭaka": ['mw'],
    "mallāryaṣṭottaraśataka": ['mw'],
    "mallāryaṣṭottaraśatanāmāvalī": ['mw'],
    "mallārī": ['mw'],
    "mallāsomayājin": ['mw'],
    "mallāsura": ['mw'],
    "mallī": ['cae', 'mw'],
    "mallīkara": ['mw'],
    "mallīkaraḥ": ['ap90'],
    "mallūra": ['mw'],
    "mallūraḥ": ['ap90'],
    "malmalābhavat": ['mw'],
    "malodvāsas": ['mw'],
    "malopahata": ['mw'],
    "malotsarga": ['mw'],
    "maluda": ['bhs', 'mw'],
    "maluka": ['mw'],
    "maluma": ['bhs', 'mw'],
    "malva": ['cae', 'ddsa', 'mw'],
    "malā": ['mw'],
    "malābha": ['mw'],
    "malākarṣin": ['mw'],
    "malākā": ['ap90', 'mw'],
    "malāpahā": ['mw'],
    "malāpakarṣaṇa": ['mw'],
    "malāri": ['mw'],
    "malāvaha": ['cae', 'mw'],
    "malāvarodha": ['mw'],
    "malāyana": ['mw'],
    "malāśaya": ['mw'],
    "malīmasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "malīyas": ['mw'],
    "malūka": ['ddsa', 'mw'],
    "malūkacandrikā": ['mw'],
    "mama": ['ap90', 'bhs', 'ddsa', 'mw'],
    "mamaka": ['cae', 'ddsa', 'gra', 'mw'],
    "mamakāra": ['ddsa', 'mw'],
    "mamakṛtya": ['mw'],
    "mamasatya": ['gra', 'mw'],
    "mamat": ['cae', 'gra', 'mw'],
    "mamatta": ['cped'],
    "mamattara": ['mw'],
    "mamatva": ['mw'],
    "mamatvaṃ": ['ap90'],
    "mamatā": ['ap90', 'cae', 'gra', 'mw'],
    "mamatāyukta": ['mw'],
    "mamatāśūnya": ['mw'],
    "mamaṅkāra": ['cped'],
    "mamb": ['mw'],
    "mamma": ['cae', 'cped', 'ddsa', 'mw'],
    "mammacchedaka": ['cped'],
    "mammaka": ['cae', 'mw'],
    "mammana": ['cped'],
    "mammasvāmin": ['mw'],
    "mammaṭa": ['ap90', 'cae', 'mw'],
    "mammaṭaḥ": ['ap90'],
    "mammaṭṭhāna": ['cped'],
    "mamri": ['mw'],
    "mamāpatāla": ['mw'],
    "mamāpatālaḥ": ['ap90'],
    "mamātha": ['mw'],
    "mamāy": ['cae'],
    "mamāya": ['ddsa', 'mw'],
    "mamāyanta": ['cped'],
    "mamāyanā": ['cped'],
    "mamāyati": ['bhs', 'cped'],
    "mamāyi": ['cped'],
    "mamāyita": ['cped'],
    "mamāyitvā": ['cped'],
    "mamṛvas": ['cae', 'ddsa'],
    "man": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mana": ['bhs', 'cae', 'cped', 'mw'],
    "manahaṃsa": ['mw'],
    "manaka": ['mw'],
    "manakkāra": ['cped'],
    "manana": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mananagrantha": ['mw'],
    "mananaprakaraṇa": ['mw'],
    "mananavat": ['mw'],
    "mananayukta": ['mw'],
    "mananya": ['mw'],
    "mananā": ['bhs', 'cae', 'gra', 'mw'],
    "mananādinighaṇṭu": ['mw'],
    "mananī": ['gra', 'mw'],
    "mananīya": ['mw'],
    "manarañjana": ['mw'],
    "manas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "manasa": ['cae', 'ddsa', 'gra', 'mw'],
    "manasaspati": ['mw'],
    "manasi": ['bhs', 'mw'],
    "manasija": ['ap90', 'cae', 'ddsa', 'mw'],
    "manasijabṛsī": ['mw'],
    "manasijaruj": ['cae'],
    "manasijataru": ['cae', 'mw'],
    "manasikari": ['cped'],
    "manasikaritvā": ['cped'],
    "manasikaronta": ['cped'],
    "manasikaroti": ['cped'],
    "manasikata": ['cped'],
    "manasikatvā": ['cped'],
    "manasikāra": ['bhs', 'cped', 'mw'],
    "manasikātabba": ['cped'],
    "manasikātuṁ": ['cped'],
    "manasimanda": ['mw'],
    "manasimandaruj": ['mw'],
    "manasin": ['mw'],
    "manasiśaya": ['mw'],
    "manasiśayaḥ": ['ap90'],
    "manaska": ['cae', 'ddsa', 'mw'],
    "manasketa": ['cae', 'mw'],
    "manaskānta": ['mw'],
    "manaskāra": ['bhs', 'mw'],
    "manaskāravidhi": ['mw'],
    "manasmaya": ['cae', 'gra', 'mw'],
    "manaspāpa": ['mw'],
    "manastaḥ": ['ap90'],
    "manastejas": ['cae', 'mw'],
    "manastokā": ['mw'],
    "manastuṣṭi": ['mw'],
    "manastva": ['mw'],
    "manastāla": ['mw'],
    "manastāpa": ['cae', 'mw'],
    "manasvant": ['cae'],
    "manasvat": ['ddsa', 'gra', 'mw'],
    "manasvatī": ['mw'],
    "manasvi": ['mw'],
    "manasvigarhita": ['mw'],
    "manasvin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "manasvinī": ['mw'],
    "manasvipraśaṃsā": ['mw'],
    "manasvitara": ['mw'],
    "manasvitā": ['ap90', 'mw'],
    "manasy": ['cae', 'gra'],
    "manasya": ['ddsa', 'mw'],
    "manasyati": ['ap90'],
    "manasyu": ['cae', 'gra', 'mw'],
    "manasā": ['ap90', 'bhs', 'mw'],
    "manasādattā": ['mw'],
    "manasādevī": ['mw'],
    "manasāguptā": ['mw'],
    "manasājñāyin": ['mw'],
    "manasāpañcamī": ['mw'],
    "manasārāma": ['mw'],
    "manasāsaṃgatā": ['mw'],
    "manasīkaroti": ['bhs'],
    "manasīkāra": ['bhs'],
    "manasṛṅga": ['gra'],
    "manatā": ['cped'],
    "manavate": ['ddsa'],
    "manavaśas": ['mw'],
    "manayate": ['bhs'],
    "manayitṛ": ['mw'],
    "manaāpa": ['bhs', 'mw'],
    "manaś": ['mw'],
    "manaścit": ['gra', 'mw'],
    "manaū": ['mw'],
    "manaḥ": ['mw'],
    "manaḥkānta": ['mw'],
    "manaḥkṣepa": ['ddsa', 'mw'],
    "manaḥkṣobhakara": ['mw'],
    "manaḥparyāya": ['mw'],
    "manaḥpati": ['mw'],
    "manaḥprasāda": ['mw'],
    "manaḥpraṇīta": ['mw'],
    "manaḥpriya": ['mw'],
    "manaḥprīti": ['mw'],
    "manaḥpīḍā": ['mw'],
    "manaḥpūta": ['cae', 'mw'],
    "manaḥsad": ['mw'],
    "manaḥsamunnati": ['mw'],
    "manaḥsamṛddhi": ['mw'],
    "manaḥsaṃcetanāhāra": ['bhs', 'mw'],
    "manaḥsaṃkalpa": ['mw'],
    "manaḥsaṃtāpa": ['cae', 'mw'],
    "manaḥsaṃvara": ['mw'],
    "manaḥsaṅga": ['mw'],
    "manaḥsaṅkalpa": ['ddsa'],
    "manaḥsiddhi": ['mw'],
    "manaḥsilā": ['mw'],
    "manaḥsparśa": ['mw'],
    "manaḥstha": ['mw'],
    "manaḥsthairya": ['mw'],
    "manaḥsthirīkaraṇa": ['mw'],
    "manaḥsukha": ['mw'],
    "manaḥsvāmin": ['mw'],
    "manaḥsvāsthya": ['mw'],
    "manaḥsāramaya": ['mw'],
    "manaḥśalya": ['mw'],
    "manaḥśama": ['mw'],
    "manaḥśikṣā": ['mw'],
    "manaḥśila": ['cae', 'ddsa'],
    "manaḥśiloccaya": ['mw'],
    "manaḥśilā": ['cae', 'mw'],
    "manaḥśilācandanadhāvana": ['mw'],
    "manaḥśilāgiri": ['mw'],
    "manaḥśilāguhā": ['mw'],
    "manaḥśilāvicchurita": ['mw'],
    "manaḥśīghra": ['mw'],
    "manaḥśūka": ['mw'],
    "manaḥṣaṣṭha": ['cae', 'mw'],
    "manaṁ": ['cped'],
    "manaṛṅga": ['gra', 'mw'],
    "mand": ['ddsa', 'gra', 'mw'],
    "manda": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mandabala": ['mw'],
    "mandabhāgin": ['cae', 'mw'],
    "mandabhāgya": ['cae', 'mw'],
    "mandabhāj": ['cae', 'mw'],
    "mandabhāṣiṇī": ['mw'],
    "mandabuddhi": ['cae', 'mw'],
    "mandacchāya": ['cae', 'mw'],
    "mandacetas": ['cae', 'mw'],
    "mandacārin": ['mw'],
    "mandadhāra": ['mw'],
    "mandadhī": ['cae', 'mw'],
    "mandadvīra": ['gra', 'mw'],
    "mandaga": ['cae', 'mw'],
    "mandagamana": ['mw'],
    "mandagamanā": ['mw'],
    "mandagati": ['cae', 'mw'],
    "mandagatitva": ['mw'],
    "mandagā": ['mw'],
    "mandagāmin": ['mw'],
    "mandahāsa": ['ddsa', 'mw'],
    "mandahāsam": ['mw'],
    "mandahāsya": ['mw'],
    "mandajananī": ['mw'],
    "mandajaras": ['mw'],
    "mandajāta": ['mw'],
    "mandaka": ['bhs', 'mw'],
    "mandakarman": ['mw'],
    "mandakarṇa": ['mw'],
    "mandakarṇi": ['mw'],
    "mandakiraṇa": ['mw'],
    "mandakiraṇatva": ['mw'],
    "mandakānta": ['mw'],
    "mandakānti": ['mw'],
    "mandakārin": ['mw'],
    "mandam": ['mw'],
    "mandamandam": ['cae', 'mw'],
    "mandamandaṁ": ['cped'],
    "mandamandātapa": ['mw'],
    "mandamati": ['cae', 'mw'],
    "mandamedhas": ['cae', 'mw'],
    "mandana": ['cae', 'gra', 'mw'],
    "mandanāga": ['mw'],
    "mandaparidhi": ['mw'],
    "mandaphala": ['cae', 'mw'],
    "mandaprabodha": ['mw'],
    "mandaprajña": ['cae', 'mw'],
    "mandapreman": ['mw'],
    "mandaprāṇa": ['mw'],
    "mandaprāṇaviceṣṭita": ['mw'],
    "mandapuṇya": ['mw'],
    "mandapāla": ['cae', 'mw'],
    "mandapīṭha": ['mw'],
    "mandara": ['bhs', 'cae', 'ddsa', 'mw'],
    "mandaradeva": ['mw'],
    "mandaradevī": ['mw'],
    "mandaradevīya": ['mw'],
    "mandaradroṇī": ['mw'],
    "mandarahariṇa": ['mw'],
    "mandarakantha": ['mw'],
    "mandaramaṇi": ['mw'],
    "mandaravāsinī": ['mw'],
    "mandaraśmi": ['ddsa', 'mw'],
    "mandaregin": ['mw'],
    "mandarādri": ['mw'],
    "mandarāvāsā": ['mw'],
    "mandarāya": ['ddsa', 'mw'],
    "mandasamīraṇa": ['mw'],
    "mandasmita": ['mw'],
    "mandasmitaśataka": ['mw'],
    "mandasubodhinī": ['mw'],
    "mandasāna": ['cae', 'ddsa', 'gra', 'mw'],
    "mandasānu": ['mw'],
    "mandatara": ['mw'],
    "mandataram": ['mw'],
    "mandatta": ['cped'],
    "mandatva": ['mw'],
    "mandatā": ['cped', 'mw'],
    "mandautsukya": ['cae', 'mw'],
    "mandavalāhaka": ['bhs'],
    "mandavedana": ['mw'],
    "mandavedanatā": ['mw'],
    "mandavibhraṃśa": ['mw'],
    "mandaviceṣṭita": ['cae', 'ddsa', 'mw'],
    "mandavirikta": ['mw'],
    "mandavisarpa": ['mw'],
    "mandavisarpin": ['mw'],
    "mandavisarpiṇī": ['mw'],
    "mandaviveka": ['mw'],
    "mandavivekin": ['mw'],
    "mandaviṣa": ['mw'],
    "mandavāhinī": ['mw'],
    "mandavāś": ['bhs'],
    "mandavīrya": ['cae', 'mw'],
    "mandavṛṣṭi": ['mw'],
    "manday": ['cae'],
    "mandaya": ['ddsa', 'mw'],
    "mandayantī": ['mw'],
    "mandayat": ['mw'],
    "mandayatsakha": ['cae', 'gra', 'mw'],
    "mandayitṛ": ['ddsa'],
    "mandayu": ['cae', 'gra', 'mw'],
    "mandaśisira": ['mw'],
    "mandaṁ": ['cped'],
    "mandaṭa": ['mw'],
    "mandeha": ['mw'],
    "mandha": ['mw'],
    "mandhātṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "mandi": ['cae', 'gra'],
    "mandikukura": ['mw'],
    "mandiman": ['ddsa', 'mw'],
    "mandin": ['cae', 'ddsa', 'gra', 'mw'],
    "mandinispṛś": ['gra'],
    "mandira": ['cae', 'cped', 'ddsa', 'mw'],
    "mandiramaṇi": ['mw'],
    "mandirapaśu": ['mw'],
    "mandiya": ['cped'],
    "mandiṣṭha": ['cae', 'gra', 'mw'],
    "mandocca": ['mw'],
    "mandodaka": ['mw'],
    "mandodarī": ['cae', 'mw'],
    "mandodarīsuta": ['mw'],
    "mandodarīśa": ['mw'],
    "mandoka": ['mw'],
    "mandopakāriṇī": ['mw'],
    "mandotsāha": ['cae', 'ddsa', 'mw'],
    "mandoṣman": ['mw'],
    "mandoṣmatā": ['mw'],
    "mandoṣṇa": ['mw'],
    "mandoṣṇatā": ['mw'],
    "mandra": ['cae', 'ddsa', 'gra', 'mw'],
    "mandrabhadra": ['mw'],
    "mandrabhadralakṣaṇa": ['mw'],
    "mandrabhadramṛga": ['mw'],
    "mandradhvani": ['mw'],
    "mandradhvāna": ['mw'],
    "mandrajihva": ['cae', 'gra', 'mw'],
    "mandrakarṣaṇa": ['mw'],
    "mandrakaṇṭhagarjita": ['mw'],
    "mandram": ['mw'],
    "mandrasnigdha": ['mw'],
    "mandrasvana": ['mw'],
    "mandrasvara": ['mw'],
    "mandratama": ['mw'],
    "mandratara": ['mw'],
    "mandraya": ['mw'],
    "mandrayu": ['cae', 'gra', 'mw'],
    "mandrājanī": ['gra', 'mw'],
    "mandu": ['cae', 'ddsa', 'gra', 'mw'],
    "mandupāla": ['mw'],
    "mandura": ['mw'],
    "manduraja": ['mw'],
    "manduraka": ['bhs', 'mw'],
    "mandurika": ['mw'],
    "mandurā": ['cae', 'ddsa', 'mw'],
    "mandurābhūṣaṇa": ['mw'],
    "mandurāpati": ['mw'],
    "mandurāpāla": ['mw'],
    "mandā": ['mw'],
    "mandābhiniveśa": ['mw'],
    "mandācāra": ['mw'],
    "mandādara": ['cae', 'mw'],
    "mandāgni": ['mw'],
    "mandāgnidhārācalamāhātmya": ['mw'],
    "mandāgniharameṣadāna": ['mw'],
    "mandāka": ['mw'],
    "mandākinī": ['cae', 'cped', 'ddsa', 'mw'],
    "mandākrānta": ['cae', 'ddsa', 'mw'],
    "mandākrāntā": ['mw'],
    "mandākṣa": ['mw'],
    "mandāmukhī": ['cped'],
    "mandānala": ['mw'],
    "mandānalatva": ['mw'],
    "mandānila": ['mw'],
    "mandānusārin": ['mw'],
    "mandāra": ['cae', 'cped', 'ddsa', 'mw'],
    "mandāradeva": ['mw'],
    "mandāraka": ['cae', 'mw'],
    "mandārakadina": ['mw'],
    "mandāramañjarī": ['mw'],
    "mandāramālā": ['mw'],
    "mandārapuṣpa": ['mw'],
    "mandārasaptamī": ['mw'],
    "mandārasaptamīvrata": ['mw'],
    "mandārava": ['bhs', 'mw'],
    "mandāravagandha": ['bhs'],
    "mandāravatī": ['cae', 'mw'],
    "mandāravatīvanamāhātmya": ['mw'],
    "mandāraṣaṣṭhī": ['mw'],
    "mandāraṣaṣṭhīvrata": ['mw'],
    "mandāritā": ['mw'],
    "mandāru": ['mw'],
    "mandārī": ['mw'],
    "mandāsu": ['mw'],
    "mandāsya": ['mw'],
    "mandātman": ['cae', 'mw'],
    "mandāy": ['cae'],
    "mandāya": ['ddsa', 'mw'],
    "mandāyus": ['ddsa', 'mw'],
    "mandī": ['mw'],
    "mandībhāva": ['mw'],
    "mandībhū": ['mw'],
    "mandībhūta": ['mw'],
    "mandīkṛ": ['cae', 'ddsa', 'mw'],
    "mandīkṛta": ['mw'],
    "mandīra": ['mw'],
    "manesikā": ['cped'],
    "manesī": ['bhs'],
    "manindha": ['mw'],
    "manita": ['mw'],
    "manittha": ['mw'],
    "maniṅgā": ['mw'],
    "maniṣṭhakā": ['mw'],
    "manma": ['mw'],
    "manman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "manmana": ['ddsa', 'mw'],
    "manmanasa": ['ddsa', 'mw'],
    "manmanatva": ['mw'],
    "manmanaḥ": ['ap90'],
    "manmasādhana": ['gra', 'mw'],
    "manmatha": ['cae', 'ddsa', 'mw'],
    "manmathabandhu": ['mw'],
    "manmathakara": ['mw'],
    "manmathalekha": ['cae', 'mw'],
    "manmathamanmatha": ['mw'],
    "manmathamath": ['mw'],
    "manmathasakha": ['mw'],
    "manmathasamāna": ['mw'],
    "manmathasaṃjīvanī": ['mw'],
    "manmathasuhṛd": ['mw'],
    "manmathavat": ['mw'],
    "manmathayuddha": ['mw'],
    "manmathaḥ": ['ap90'],
    "manmatheśvaratīrtha": ['mw'],
    "manmathin": ['ap90', 'mw'],
    "manmathoddīpana": ['mw'],
    "manmathā": ['mw'],
    "manmathālaya": ['mw'],
    "manmathānala": ['cae', 'mw'],
    "manmathānanda": ['mw'],
    "manmathāviṣṭa": ['mw'],
    "manmathāvāsa": ['mw'],
    "manmathāyatana": ['mw'],
    "manmaya": ['cae', 'mw'],
    "manmaśas": ['gra', 'mw'],
    "manmoka": ['mw'],
    "mannimittam": ['cae'],
    "mannurāma": ['mw'],
    "mano": ['cped', 'mw'],
    "manobhava": ['cae', 'mw'],
    "manobhavadruma": ['mw'],
    "manobhavaśāsana": ['mw'],
    "manobhavāgāra": ['mw'],
    "manobhidhā": ['mw'],
    "manobhilāṣa": ['mw'],
    "manobhiniveśa": ['mw'],
    "manobhiprāya": ['cae', 'mw'],
    "manobhiprāyaga": ['mw'],
    "manobhirāma": ['bhs', 'cae', 'mw'],
    "manobhū": ['cae', 'ddsa', 'mw'],
    "manobhṛt": ['mw'],
    "manodatta": ['mw'],
    "manodattā": ['mw'],
    "manodaṇḍa": ['cae', 'ddsa', 'mw'],
    "manodhara": ['mw'],
    "manodhinātha": ['mw'],
    "manodhātu": ['cped', 'mw'],
    "manodhṛt": ['gra', 'mw'],
    "manoduccarita": ['cped'],
    "manoduḥkha": ['mw'],
    "manoduṣṭa": ['cae', 'mw'],
    "manodvāra": ['cped'],
    "manodāhin": ['mw'],
    "manodūtakāvya": ['mw'],
    "manodūtikā": ['mw'],
    "manogamya": ['mw'],
    "manogata": ['cae', 'ddsa', 'mw'],
    "manogati": ['mw'],
    "manogavī": ['mw'],
    "manoghna": ['mw'],
    "manoglāni": ['mw'],
    "manograhaṇa": ['cae', 'mw'],
    "manogrāhin": ['cae', 'mw'],
    "manogrāhya": ['mw'],
    "manogupta": ['mw'],
    "manoguptā": ['mw'],
    "manogṛhīta": ['mw'],
    "manohan": ['cae', 'mw'],
    "manohara": ['cae', 'cped', 'mw'],
    "manoharadāsa": ['mw'],
    "manoharakāvya": ['mw'],
    "manoharakṛṣṇa": ['mw'],
    "manoharasiṃha": ['mw'],
    "manoharatara": ['mw'],
    "manoharataratva": ['mw'],
    "manoharavīreśvara": ['mw'],
    "manoharaśarman": ['mw'],
    "manohartṛ": ['mw'],
    "manoharā": ['bhs', 'mw'],
    "manoharākāra": ['cae', 'mw'],
    "manoharī": ['mw'],
    "manohata": ['mw'],
    "manohlāda": ['mw'],
    "manohlādin": ['mw'],
    "manohvā": ['mw'],
    "manohā": ['mw'],
    "manohārikā": ['mw'],
    "manohārin": ['cae', 'mw'],
    "manohārī": ['mw'],
    "manohṛt": ['mw'],
    "manoja": ['cae', 'mw'],
    "manojalpa": ['bhs', 'mw'],
    "manojana": ['bhs'],
    "manojanman": ['cae', 'mw'],
    "manojava": ['cae', 'cped', 'gra', 'mw'],
    "manojavam": ['mw'],
    "manojavas": ['cae', 'gra', 'mw'],
    "manojavasa": ['mw'],
    "manojavatā": ['mw'],
    "manojavin": ['mw'],
    "manojavitva": ['mw'],
    "manojaviṣṭha": ['mw'],
    "manojavā": ['bhs', 'mw'],
    "manojavṛddhi": ['mw'],
    "manojighra": ['mw'],
    "manojvalā": ['mw'],
    "manojvara": ['mw'],
    "manojyotis": ['mw'],
    "manojña": ['bhs', 'cae', 'mw'],
    "manojñaghoṣa": ['mw'],
    "manojñanirṇādasvara": ['bhs'],
    "manojñasvara": ['bhs', 'mw'],
    "manojñatā": ['mw'],
    "manojñaśabdābhigarjita": ['bhs', 'mw'],
    "manojñā": ['bhs', 'mw'],
    "manojñārutasiṃhadhvaja": ['bhs'],
    "manojāta": ['cae', 'mw'],
    "manojū": ['cae', 'gra', 'mw'],
    "manoka": ['mw'],
    "manokamma": ['cped'],
    "manolakṣaṇa": ['mw'],
    "manolaulya": ['cae', 'mw'],
    "manolaya": ['mw'],
    "manomathana": ['mw'],
    "manomaya": ['ap90', 'cae', 'cped', 'mw'],
    "manomayakośa": ['mw'],
    "manomohinī": ['mw'],
    "manomuh": ['mw'],
    "manomuṣigṛhīta": ['mw'],
    "manomṛga": ['cae', 'mw'],
    "manonavasthāna": ['mw'],
    "manonetra": ['mw'],
    "manonmanī": ['mw'],
    "manonuga": ['mw'],
    "manonukūla": ['mw'],
    "manonāśa": ['mw'],
    "manonīta": ['mw'],
    "manopadosa": ['cped'],
    "manopahārin": ['mw'],
    "manopasāda": ['cped'],
    "manopeta": ['mw'],
    "manopubbaṅgama": ['cped'],
    "manoragā": ['bhs'],
    "manorama": ['bhs', 'cae', 'cped', 'mw'],
    "manoramā": ['bhs', 'mw'],
    "manoramākhaṇḍa": ['mw'],
    "manoramākucamardinī": ['mw'],
    "manoramāpariṇayanacarita": ['mw'],
    "manoramāvyākhyā": ['mw'],
    "manoratha": ['bhs', 'cae', 'cped', 'mw'],
    "manorathabandha": ['mw'],
    "manorathabandhabandhu": ['mw'],
    "manorathadruma": ['mw'],
    "manorathadvādaśī": ['mw'],
    "manorathadāyaka": ['mw'],
    "manorathakusuma": ['mw'],
    "manorathakṛta": ['mw'],
    "manorathamaya": ['mw'],
    "manorathaprabhā": ['mw'],
    "manoratharakṣita": ['bhs'],
    "manorathasiddha": ['mw'],
    "manorathasiddhi": ['mw'],
    "manorathasṛṣṭi": ['mw'],
    "manorathatīrtha": ['mw'],
    "manorathatṛtīyā": ['mw'],
    "manorathatṛtīyāvrata": ['mw'],
    "manorathā": ['mw'],
    "manorathāntara": ['cae', 'mw'],
    "manorañjana": ['mw'],
    "manorañjinī": ['mw'],
    "manorhata": ['mw'],
    "manorhita": ['mw'],
    "manorti": ['mw'],
    "manoruj": ['cae', 'mw'],
    "manorāga": ['cae', 'mw'],
    "manorājya": ['mw'],
    "manorūpa": ['mw'],
    "manosilā": ['cped'],
    "manota": ['mw'],
    "manotā": ['ddsa', 'mw'],
    "manotṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "manovahā": ['mw'],
    "manovalambikā": ['mw'],
    "manovallabhā": ['mw'],
    "manovatī": ['mw'],
    "manovedaśiras": ['mw'],
    "manovega": ['mw'],
    "manovibhu": ['bhs'],
    "manovid": ['mw'],
    "manovijñāna": ['bhs'],
    "manovikāra": ['mw'],
    "manovinayana": ['mw'],
    "manovinoda": ['mw'],
    "manovinodakṛt": ['mw'],
    "manoviruddha": ['mw'],
    "manovitakka": ['cped'],
    "manoviññeyya": ['cped'],
    "manoviññāṇa": ['cped'],
    "manovyathā": ['mw'],
    "manovāda": ['mw'],
    "manovāgdehaja": ['mw'],
    "manovākkarman": ['cae', 'mw'],
    "manovāta": ['gra', 'mw'],
    "manovāñchita": ['mw'],
    "manovāñchā": ['mw'],
    "manovṛtti": ['cae', 'mw'],
    "manoyoni": ['mw'],
    "manoyuj": ['cae', 'gra', 'mw'],
    "manoyāyin": ['mw'],
    "manoyāyitva": ['mw'],
    "manta": ['cped'],
    "mantadhara": ['cped'],
    "mantajjhāyaka": ['cped'],
    "mantana": ['cped'],
    "mantanā": ['cped'],
    "mantar": ['cped'],
    "mantavya": ['cae', 'ddsa', 'mw'],
    "mantayamāna": ['cped'],
    "mantayati": ['cped'],
    "mantenta": ['cped'],
    "mantesi": ['cped'],
    "manteti": ['cped'],
    "mantetuṁ": ['cped'],
    "mantetvā": ['cped'],
    "manth": ['cae', 'ddsa', 'gra', 'mw'],
    "mantha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "manthadaṇḍa": ['mw'],
    "manthadaṇḍaka": ['mw'],
    "manthadaṇḍīkṛta": ['mw'],
    "manthagiri": ['mw'],
    "manthaguṇa": ['mw'],
    "manthaguṇīkṛta": ['mw'],
    "manthaja": ['mw'],
    "manthaka": ['mw'],
    "manthan": ['mw'],
    "manthana": ['cae', 'ddsa', 'gra', 'mw'],
    "manthanadaṇḍa": ['mw'],
    "manthanaghaṭī": ['mw'],
    "manthanayantraka": ['mw'],
    "manthanī": ['mw'],
    "manthanīya": ['mw'],
    "manthaparvata": ['mw'],
    "manthapātra": ['mw'],
    "manthara": ['cae', 'cped', 'ddsa', 'mw'],
    "mantharagāmin": ['mw'],
    "mantharaka": ['cae', 'mw'],
    "mantharakaulika": ['mw'],
    "mantharam": ['mw'],
    "mantharatā": ['mw'],
    "mantharaviveka": ['mw'],
    "manthareṣaṇa": ['mw'],
    "mantharita": ['cae', 'ddsa', 'mw'],
    "mantharu": ['mw'],
    "mantharā": ['mw'],
    "mantharākṣaram": ['mw'],
    "manthaviṣkambha": ['mw'],
    "manthaśaila": ['mw'],
    "manthi": ['mw'],
    "manthin": ['cae', 'ddsa', 'gra', 'mw'],
    "manthinī": ['mw'],
    "manthipa": ['cae', 'mw'],
    "manthipātra": ['mw'],
    "manthitavya": ['cae', 'mw'],
    "manthitṛ": ['cae', 'mw'],
    "manthivat": ['mw'],
    "manthiśocis": ['mw'],
    "manthodadhi": ['mw'],
    "manthodaka": ['mw'],
    "manthu": ['mw'],
    "manthya": ['cae', 'mw'],
    "manthyagra": ['mw'],
    "manthā": ['bhs', 'cae', 'ddsa', 'mw'],
    "manthācala": ['ddsa', 'mw'],
    "manthādri": ['mw'],
    "manthāna": ['cae', 'ddsa', 'mw'],
    "manthānabhairava": ['mw'],
    "manthānaka": ['mw'],
    "manthāvala": ['ddsa', 'mw'],
    "manthīvat": ['mw'],
    "manti": ['mw'],
    "mantinī": ['cped'],
    "mantita": ['cped'],
    "mantr": ['mw'],
    "mantra": ['cae', 'ddsa', 'gra', 'mw'],
    "mantrabaddha": ['mw'],
    "mantrabala": ['cae', 'mw'],
    "mantrabheda": ['cae', 'mw'],
    "mantrabhāgavata": ['mw'],
    "mantrabhāṣya": ['mw'],
    "mantrabhūṣaṇa": ['mw'],
    "mantrabrāhmaṇa": ['mw'],
    "mantrabrāhmaṇavid": ['mw'],
    "mantrabīja": ['mw'],
    "mantracandrikā": ['mw'],
    "mantracintāmaṇi": ['mw'],
    "mantracūḍāmaṇi": ['mw'],
    "mantrada": ['cae', 'mw'],
    "mantradarpaṇa": ['mw'],
    "mantradarśin": ['cae', 'mw'],
    "mantradevatā": ['mw'],
    "mantradevatāprakāśa": ['mw'],
    "mantradevatāprakāśikā": ['mw'],
    "mantradhara": ['mw'],
    "mantradhāraṇī": ['bhs'],
    "mantradhārin": ['mw'],
    "mantradraṣṭṛ": ['mw'],
    "mantradruma": ['mw'],
    "mantradātṛ": ['mw'],
    "mantradīdhiti": ['mw'],
    "mantradīpaka": ['mw'],
    "mantradīpikā": ['mw'],
    "mantradṛś": ['cae', 'mw'],
    "mantragaṇapatitattvaratna": ['mw'],
    "mantragaṇḍaka": ['mw'],
    "mantragupta": ['mw'],
    "mantragupti": ['mw'],
    "mantragūḍha": ['mw'],
    "mantragṛha": ['mw'],
    "mantrahemādri": ['mw'],
    "mantrahīna": ['mw'],
    "mantraja": ['bhs'],
    "mantrajala": ['mw'],
    "mantrajihva": ['mw'],
    "mantrajyeṣṭha": ['mw'],
    "mantrajyotis": ['mw'],
    "mantrajña": ['cae', 'mw'],
    "mantrajāgara": ['mw'],
    "mantrakalpadruma": ['mw'],
    "mantrakalpalatā": ['mw'],
    "mantrakamalākara": ['mw'],
    "mantrakaraṇa": ['mw'],
    "mantrakaumudī": ['mw'],
    "mantrakhaṇḍa": ['mw'],
    "mantrakovida": ['mw'],
    "mantrakośa": ['mw'],
    "mantrakuśala": ['mw'],
    "mantrakāla": ['cae', 'mw'],
    "mantrakāra": ['mw'],
    "mantrakārya": ['mw'],
    "mantrakāśīkhaṇḍa": ['mw'],
    "mantrakṛt": ['cae', 'gra', 'mw'],
    "mantrakṛta": ['mw'],
    "mantramahodadhi": ['mw'],
    "mantramaya": ['mw'],
    "mantramayūkha": ['mw'],
    "mantramuktāvalī": ['mw'],
    "mantramālā": ['mw'],
    "mantramārtaṇḍa": ['mw'],
    "mantramūla": ['cae', 'mw'],
    "mantramūrti": ['mw'],
    "mantranetra": ['mw'],
    "mantranirṇaya": ['mw'],
    "mantranirṇayaprabandha": ['mw'],
    "mantrapada": ['cae', 'mw'],
    "mantrapaddhati": ['mw'],
    "mantrapati": ['mw'],
    "mantrapattra": ['mw'],
    "mantraphala": ['mw'],
    "mantraprabhāva": ['cae', 'mw'],
    "mantrapradīpa": ['mw'],
    "mantraprakaraṇa": ['mw'],
    "mantraprakāśa": ['mw'],
    "mantraprastāra": ['mw'],
    "mantraprayoga": ['mw'],
    "mantraprayogatantra": ['mw'],
    "mantrapraśna": ['mw'],
    "mantrapraśnabhāṣya": ['mw'],
    "mantrapraśnakāṇḍa": ['mw'],
    "mantrapuraścaraṇaprakāra": ['mw'],
    "mantrapustikā": ['cae', 'mw'],
    "mantrapuṣpa": ['mw'],
    "mantrapuṣpāñjali": ['mw'],
    "mantrapāda": ['mw'],
    "mantrapārāyaṇa": ['mw'],
    "mantrapārāyaṇakrama": ['mw'],
    "mantrapāṭha": ['mw'],
    "mantrapūta": ['mw'],
    "mantrapūtātman": ['mw'],
    "mantrarahasyaprakāśikā": ['mw'],
    "mantraratna": ['mw'],
    "mantraratnadīpikā": ['mw'],
    "mantraratnakośa": ['mw'],
    "mantraratnamañjūṣā": ['mw'],
    "mantraratnaprakāśa": ['mw'],
    "mantraratnākara": ['mw'],
    "mantraratnāvalī": ['mw'],
    "mantraratnāvalīkośa": ['mw'],
    "mantrarāja": ['mw'],
    "mantrarājavidhi": ['mw'],
    "mantrarājānuṣṭhānakrama": ['mw'],
    "mantrarājātmakastotra": ['mw'],
    "mantrarāmāyaṇa": ['mw'],
    "mantrasamuccaya": ['mw'],
    "mantrasaṃdhyā": ['mw'],
    "mantrasaṃhitā": ['cae', 'mw'],
    "mantrasaṃkalanā": ['mw'],
    "mantrasaṃnāma": ['mw'],
    "mantrasaṃskriyā": ['mw'],
    "mantrasaṃskāra": ['cae', 'mw'],
    "mantrasaṃskārakṛt": ['mw'],
    "mantrasaṃvaraṇa": ['mw'],
    "mantrasiddha": ['cae', 'mw'],
    "mantrasiddhi": ['mw'],
    "mantrasnāna": ['mw'],
    "mantraspṛś": ['mw'],
    "mantrasādhaka": ['mw'],
    "mantrasādhana": ['mw'],
    "mantrasādhya": ['mw'],
    "mantrasādhyatva": ['mw'],
    "mantrasāra": ['mw'],
    "mantrasārasamuccaya": ['mw'],
    "mantrasūtra": ['mw'],
    "mantratantrameruratnāvalī": ['mw'],
    "mantratas": ['cae', 'mw'],
    "mantratattva": ['mw'],
    "mantratattvanetra": ['mw'],
    "mantratattvaprakāśa": ['mw'],
    "mantratattvavid": ['cae', 'ddsa', 'mw'],
    "mantratoya": ['mw'],
    "mantravacana": ['mw'],
    "mantravaha": ['mw'],
    "mantravallarī": ['mw'],
    "mantravant": ['cae'],
    "mantravarjam": ['mw'],
    "mantravarṇa": ['cae', 'mw'],
    "mantravarṇana": ['mw'],
    "mantravat": ['mw'],
    "mantravaśīkṛ": ['mw'],
    "mantravibhāga": ['mw'],
    "mantravid": ['cae', 'mw'],
    "mantravidhi": ['mw'],
    "mantravidyā": ['cae', 'mw'],
    "mantraviṣaya": ['mw'],
    "mantravāda": ['cae', 'mw'],
    "mantravādin": ['cae', 'mw'],
    "mantray": ['cae', 'gra'],
    "mantraya": ['ddsa'],
    "mantrayantra": ['ddsa', 'mw'],
    "mantrayantraprakāśa": ['mw'],
    "mantrayoga": ['mw'],
    "mantrayogaprakaraṇa": ['mw'],
    "mantrayukti": ['mw'],
    "mantraśakti": ['cae', 'mw'],
    "mantraśodhana": ['mw'],
    "mantraśruti": ['mw'],
    "mantraśrutya": ['gra', 'mw'],
    "mantraśārīraka": ['mw'],
    "mantraśāstra": ['mw'],
    "mantraśāstrapratyaṅgirā": ['mw'],
    "mantraśāstrasārasaṃgraha": ['mw'],
    "mantraṇa": ['cae', 'ddsa', 'mw'],
    "mantraṇaka": ['mw'],
    "mantraṇāha": ['mw'],
    "mantraṇārhīya": ['mw'],
    "mantreśa": ['mw'],
    "mantreśvara": ['mw'],
    "mantri": ['mw'],
    "mantridhura": ['mw'],
    "mantriduhitṛ": ['cae'],
    "mantrika": ['ddsa', 'mw'],
    "mantrikā": ['mw'],
    "mantrimukhya": ['mw'],
    "mantrin": ['cae', 'mw'],
    "mantripati": ['ddsa', 'mw'],
    "mantripradhāna": ['mw'],
    "mantriprakāṇḍa": ['mw'],
    "mantriputra": ['cae', 'mw'],
    "mantrisuta": ['cae', 'mw'],
    "mantrisūnu": ['cae', 'mw'],
    "mantrita": ['cae', 'mw'],
    "mantritva": ['mw'],
    "mantritā": ['cae', 'mw'],
    "mantrivara": ['mw'],
    "mantrivat": ['mw'],
    "mantriśreṣṭha": ['mw'],
    "mantriśrotriya": ['mw'],
    "mantriṇī": ['mw'],
    "mantriṇīrahasya": ['mw'],
    "mantrodaka": ['mw'],
    "mantroddhāra": ['mw'],
    "mantroddhārakośa": ['mw'],
    "mantroddhāraprakaraṇa": ['mw'],
    "mantroddhāravidhi": ['mw'],
    "mantrokta": ['ddsa', 'mw'],
    "mantropaniṣad": ['mw'],
    "mantropaṣṭambha": ['mw'],
    "mantrā": ['bhs'],
    "mantrādhirāja": ['cae', 'mw'],
    "mantrākṣara": ['ddsa', 'mw'],
    "mantrākṣaribhavānīsahasranāmastotra": ['mw'],
    "mantrānta": ['mw'],
    "mantrānukramaṇikā": ['mw'],
    "mantrānusāriṇī": ['bhs'],
    "mantrānuṣṭhāna": ['mw'],
    "mantrānuṣṭhānāṅgatarpaṇa": ['mw'],
    "mantrārtha": ['mw'],
    "mantrārthabhāṣya": ['mw'],
    "mantrārthadīpa": ['mw'],
    "mantrārthadīpikā": ['mw'],
    "mantrārthakaumudī": ['mw'],
    "mantrārthamañjarī": ['mw'],
    "mantrārthapaddhati": ['mw'],
    "mantrārādhana": ['cae', 'mw'],
    "mantrārṇa": ['mw'],
    "mantrārṇava": ['mw'],
    "mantrārṣādhyāya": ['mw'],
    "mantrāvalī": ['mw'],
    "mantrāśīrvādasaṃhitā": ['mw'],
    "mantrāṅganāṭaka": ['mw'],
    "mantu": ['cae', 'ddsa', 'gra', 'mw'],
    "mantumant": ['cae'],
    "mantumat": ['gra', 'mw'],
    "mantī": ['cped'],
    "mantūya": ['mw'],
    "mantṛ": ['cae', 'ddsa', 'mw'],
    "manu": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "manubhū": ['mw'],
    "manudivi": ['mw'],
    "manuga": ['mw'],
    "manuja": ['cae', 'cped', 'ddsa', 'mw'],
    "manujaloka": ['mw'],
    "manujanātha": ['cae', 'mw'],
    "manujapati": ['cae', 'mw'],
    "manujavyāghra": ['mw'],
    "manujendra": ['cae', 'ddsa', 'mw'],
    "manujendraputra": ['mw'],
    "manujendraputrī": ['mw'],
    "manujeśvara": ['cae', 'mw'],
    "manujinda": ['cped'],
    "manujottama": ['mw'],
    "manujyeṣṭha": ['mw'],
    "manujña": ['bhs'],
    "manujā": ['mw'],
    "manujādhipa": ['cae', 'cped', 'mw'],
    "manujādhipati": ['cae', 'mw'],
    "manujāta": ['cae', 'gra', 'mw'],
    "manujātmaja": ['mw'],
    "manujātmajā": ['mw'],
    "manujī": ['mw'],
    "manujīkṛ": ['ddsa', 'mw'],
    "manukapāla": ['mw'],
    "manukulāditya": ['mw'],
    "manumuktāvali": ['mw'],
    "manupravalha": ['mw'],
    "manupravarha": ['mw'],
    "manupraṇīta": ['mw'],
    "manupraṇītatva": ['mw'],
    "manuprīta": ['gra', 'mw'],
    "manurhita": ['cae', 'ddsa', 'gra', 'mw'],
    "manurāj": ['mw'],
    "manus": ['cae', 'ddsa', 'gra', 'mw'],
    "manusava": ['mw'],
    "manusaṃhitā": ['ddsa', 'mw'],
    "manusmṛti": ['mw'],
    "manusmṛtimāhātmya": ['mw'],
    "manussa": ['cped'],
    "manussabhāva": ['cped'],
    "manussabhūta": ['cped'],
    "manussaloka": ['cped'],
    "manussatta": ['cped'],
    "manutantu": ['mw'],
    "manutva": ['mw'],
    "manutīrtha": ['mw'],
    "manuvat": ['gra', 'mw'],
    "manuvaśa": ['mw'],
    "manuvṛta": ['ddsa', 'mw'],
    "manuyuga": ['ddsa', 'mw'],
    "manuñña": ['cped'],
    "manuśreṣṭha": ['mw'],
    "manuḥ": ['ap90'],
    "manuṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "manuṣendra": ['mw'],
    "manuṣia": ['gra'],
    "manuṣvat": ['cae', 'ddsa', 'gra', 'mw'],
    "manuṣya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "manuṣyacara": ['mw'],
    "manuṣyacchandasa": ['mw'],
    "manuṣyacitta": ['mw'],
    "manuṣyadatta": ['bhs'],
    "manuṣyadeva": ['bhs', 'cae', 'mw'],
    "manuṣyadharma": ['mw'],
    "manuṣyadharman": ['mw'],
    "manuṣyadurga": ['mw'],
    "manuṣyagandha": ['mw'],
    "manuṣyagandharva": ['mw'],
    "manuṣyagavī": ['mw'],
    "manuṣyagranthi": ['mw'],
    "manuṣyahāra": ['mw'],
    "manuṣyahārin": ['mw'],
    "manuṣyainasa": ['mw'],
    "manuṣyajanman": ['mw'],
    "manuṣyajā": ['cae', 'gra', 'mw'],
    "manuṣyajāta": ['cae', 'mw'],
    "manuṣyajātaka": ['mw'],
    "manuṣyajāti": ['mw'],
    "manuṣyaka": ['bhs'],
    "manuṣyakilbiṣa": ['mw'],
    "manuṣyakāra": ['ddsa', 'mw'],
    "manuṣyakāya": ['mw'],
    "manuṣyakṛta": ['cae', 'mw'],
    "manuṣyaloka": ['cae', 'mw'],
    "manuṣyamāraṇa": ['cae', 'mw'],
    "manuṣyamātra": ['mw'],
    "manuṣyanāga": ['bhs'],
    "manuṣyanāma": ['mw'],
    "manuṣyanāman": ['mw'],
    "manuṣyapota": ['mw'],
    "manuṣyaprakṛti": ['mw'],
    "manuṣyapātra": ['mw'],
    "manuṣyarahaśayyāka": ['bhs'],
    "manuṣyaratha": ['mw'],
    "manuṣyarāj": ['mw'],
    "manuṣyarāja": ['cae', 'mw'],
    "manuṣyarājan": ['cae', 'mw'],
    "manuṣyarūpa": ['cae', 'mw'],
    "manuṣyasabhā": ['mw'],
    "manuṣyasava": ['mw'],
    "manuṣyasākṣya": ['mw'],
    "manuṣyasākṣye": ['mw'],
    "manuṣyat": ['cae', 'mw'],
    "manuṣyatrā": ['cae', 'mw'],
    "manuṣyatva": ['cae', 'mw'],
    "manuṣyatā": ['ap90', 'cae', 'mw'],
    "manuṣyavigraha": ['bhs'],
    "manuṣyaviś": ['cae', 'mw'],
    "manuṣyaviśa": ['mw'],
    "manuṣyaviśā": ['mw'],
    "manuṣyayajña": ['cae', 'mw'],
    "manuṣyayaśasa": ['mw'],
    "manuṣyayaśasin": ['mw'],
    "manuṣyayoni": ['mw'],
    "manuṣyayāna": ['mw'],
    "manuṣyaśiras": ['mw'],
    "manuṣyaśoṇita": ['mw'],
    "manuṣyaśṛṅga": ['mw'],
    "manuṣyendra": ['ddsa', 'mw'],
    "manuṣyeśvara": ['mw'],
    "manuṣyeṣu": ['mw'],
    "manuṣyālaya": ['mw'],
    "manuṣyālayacandrikā": ['mw'],
    "manuṣyālayalakṣaṇa": ['mw'],
    "manuṣyāmanuṣya": ['mw'],
    "manuṣyāyuṣa": ['mw'],
    "manuṣī": ['mw'],
    "manv": ['mw'],
    "manvantara": ['cae', 'ddsa', 'mw'],
    "manvantaravarṇana": ['mw'],
    "manvantarā": ['mw'],
    "manvarthacandrikā": ['mw'],
    "manvarthamuktāvalī": ['mw'],
    "manvarthasāra": ['mw'],
    "manviddha": ['cae', 'ddsa', 'mw'],
    "manvādi": ['mw'],
    "manvīśa": ['mw'],
    "manya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "manyantī": ['mw'],
    "manyanā": ['bhs'],
    "manyate": ['bhs'],
    "manyita": ['bhs'],
    "manyu": ['cae', 'ddsa', 'gra', 'mw'],
    "manyudeva": ['mw'],
    "manyumant": ['cae'],
    "manyumat": ['ap90', 'gra', 'mw'],
    "manyumaya": ['mw'],
    "manyumokṣa": ['cae'],
    "manyumī": ['cae', 'gra', 'mw'],
    "manyuparita": ['mw'],
    "manyuparopta": ['mw'],
    "manyupratikriyā": ['mw'],
    "manyusūkta": ['mw'],
    "manyusūktavidhāna": ['mw'],
    "manyutas": ['mw'],
    "manyuśamana": ['mw'],
    "manyuḥ": ['ap90'],
    "manyuṣāvin": ['gra', 'mw'],
    "manyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "manyāgata": ['mw'],
    "manyāgraha": ['mw'],
    "manyākā": ['mw'],
    "manyāstambha": ['mw'],
    "manyūya": ['mw'],
    "manā": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "manādya": ['mw'],
    "manāga": ['mw'],
    "manājya": ['mw'],
    "manāk": ['ap90', 'cae', 'ddsa', 'mw'],
    "manākkara": ['mw'],
    "manākpriya": ['mw'],
    "manākā": ['ap90', 'mw'],
    "manāna": ['mw'],
    "manānak": ['mw'],
    "manānaś": ['gra'],
    "manāpa": ['bhs', 'cped', 'mw'],
    "manāpika": ['cped'],
    "manāvasu": ['cae', 'gra', 'mw'],
    "manāvī": ['ap90', 'cae', 'mw'],
    "manāy": ['cae', 'gra'],
    "manāya": ['ddsa', 'mw'],
    "manāyu": ['cae', 'ddsa', 'gra', 'mw'],
    "manāyī": ['ap90', 'cae', 'mw'],
    "manīka": ['mw'],
    "manīkaṃ": ['ap90'],
    "manīkṛ": ['mw'],
    "manīmuṣagrāma": ['ddsa', 'mw'],
    "manīvaka": ['mw'],
    "manīṣikā": ['ap90', 'cae', 'mw'],
    "manīṣin": ['ap90', 'cae', 'gra', 'mw'],
    "manīṣita": ['ap90', 'cae', 'mw'],
    "manīṣitavarṣin": ['mw'],
    "manīṣitā": ['cae', 'mw'],
    "manīṣiṇā": ['mw'],
    "manīṣā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "manīṣāpañcaka": ['mw'],
    "mapara": ['bhs'],
    "mapaṣṭa": ['mw'],
    "mapaṣṭaka": ['mw'],
    "mapaṣṭaḥ": ['ap90'],
    "maphira": ['mw'],
    "mapuṣṭaka": ['mw'],
    "mapuṣṭhaka": ['mw'],
    "mar": ['gra'],
    "mara": ['cae', 'ddsa', 'mw'],
    "maraka": ['cae', 'mw'],
    "marakata": ['cae', 'ddsa', 'mw'],
    "marakatamaya": ['cae', 'mw'],
    "marakatamaṇi": ['mw'],
    "marakatapattrī": ['mw'],
    "marakatavallīpariṇaya": ['mw'],
    "marakataśilā": ['mw'],
    "marakataśyāma": ['mw'],
    "marakataṃ": ['ap90'],
    "marakaḥ": ['ap90'],
    "marakta": ['mw'],
    "maramāna": ['cped'],
    "maranda": ['ddsa', 'mw'],
    "marandaukas": ['mw'],
    "marandaukasa": ['mw'],
    "maranta": ['cped'],
    "marataḥ": ['ap90'],
    "marati": ['cped'],
    "maravāla": ['bhs'],
    "maraḥ": ['ap90'],
    "maraṃdaḥ": ['ap90'],
    "maraṇa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "maraṇabhaya": ['cped', 'mw'],
    "maraṇabhīruka": ['cae', 'mw'],
    "maraṇacetanā": ['cped'],
    "maraṇadaśā": ['cae', 'mw'],
    "maraṇadhamma": ['cped'],
    "maraṇadharma": ['mw'],
    "maraṇadharman": ['mw'],
    "maraṇaja": ['mw'],
    "maraṇakāla": ['cped'],
    "maraṇamañcaka": ['cped'],
    "maraṇamukha": ['cped'],
    "maraṇaniścaya": ['mw'],
    "maraṇanta": ['cped'],
    "maraṇapariyosāna": ['cped'],
    "maraṇaprajñāyate": ['bhs'],
    "maraṇasamaya": ['cped'],
    "maraṇasati": ['cped'],
    "maraṇasāmāyikanirṇaya": ['mw'],
    "maraṇavasa": ['cped'],
    "maraṇavyādhiśoka": ['mw'],
    "maraṇaśīla": ['mw'],
    "maraṇaṃ": ['ap90'],
    "maraṇonmukha": ['mw'],
    "maraṇābhimukha": ['mw'],
    "maraṇādhvan": ['mw'],
    "maraṇāgresara": ['mw'],
    "maraṇālasa": ['mw'],
    "maraṇāndhatamasa": ['mw'],
    "maraṇānta": ['cae', 'mw'],
    "maraṇāntika": ['cae', 'mw'],
    "maraṇātmaka": ['mw'],
    "maraṇāṃśika": ['bhs'],
    "maraṇīya": ['ap90', 'bhs', 'mw'],
    "maraṭa": ['mw'],
    "marb": ['ap90', 'mw'],
    "marc": ['ap90', 'gra', 'mw'],
    "marda": ['ap90', 'cae', 'ddsa', 'mw'],
    "mardaka": ['ap90', 'mw'],
    "mardala": ['cae', 'ddsa', 'mw'],
    "mardaladhvani": ['mw'],
    "mardalaka": ['mw'],
    "mardalaḥ": ['ap90'],
    "mardana": ['ap90', 'bhs', 'cae', 'mw'],
    "mardanaśālā": ['mw'],
    "mardanī": ['bhs', 'mw'],
    "mardanīya": ['cae', 'mw'],
    "mardin": ['cae', 'mw'],
    "mardinī": ['mw'],
    "mardita": ['ap90', 'ddsa'],
    "marditavya": ['cae', 'mw'],
    "marga": ['mw'],
    "margati": ['bhs'],
    "mari": ['cped'],
    "maria": ['gra'],
    "marica": ['cae', 'cped', 'ddsa', 'mw'],
    "maricakṣupa": ['mw'],
    "maricapattraka": ['mw'],
    "maricaḥ": ['ap90'],
    "mariman": ['ap90', 'mw'],
    "maritabba": ['cped'],
    "marituṁ": ['cped'],
    "maritvā": ['cped'],
    "mariyādā": ['cped'],
    "mariṣṇu": ['mw'],
    "mariṣṭaka": ['mw'],
    "marj": ['mw'],
    "marja": ['bhs'],
    "marjya": ['mw'],
    "marjū": ['mw'],
    "marjūḥ": ['ap90'],
    "mark": ['mw'],
    "marka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "markaka": ['mw'],
    "markakaḥ": ['ap90'],
    "markara": ['mw'],
    "markarā": ['ap90', 'mw'],
    "markasa": ['mw'],
    "markaḍikā": ['mw'],
    "markaṭa": ['bhs', 'cae', 'ddsa', 'mw'],
    "markaṭadanta": ['mw'],
    "markaṭahrada": ['mw'],
    "markaṭahradatīra": ['bhs'],
    "markaṭajoḍa": ['mw'],
    "markaṭajāla": ['bhs'],
    "markaṭaka": ['mw'],
    "markaṭakarṇa": ['mw'],
    "markaṭakaḥ": ['ap90'],
    "markaṭalocana": ['mw'],
    "markaṭanyāya": ['mw'],
    "markaṭanāsa": ['mw'],
    "markaṭapati": ['mw'],
    "markaṭapippalī": ['mw'],
    "markaṭapota": ['mw'],
    "markaṭapriya": ['mw'],
    "markaṭatinduka": ['mw'],
    "markaṭavāsa": ['mw'],
    "markaṭaśīrṣa": ['mw'],
    "markaṭaḥ": ['ap90'],
    "markaṭendu": ['mw'],
    "markaṭotplavana": ['mw'],
    "markaṭāsya": ['mw'],
    "markaṭī": ['mw'],
    "markaṭībhū": ['ddsa'],
    "markaṭībhūta": ['mw'],
    "markaṭīvrata": ['mw'],
    "markoṭapipīlikā": ['mw'],
    "marma": ['mw'],
    "marmabheda": ['mw'],
    "marmabhedana": ['mw'],
    "marmabhedin": ['cae', 'mw'],
    "marmacara": ['mw'],
    "marmaccheda": ['cae', 'mw'],
    "marmacchedin": ['cae', 'mw'],
    "marmacchid": ['cae', 'mw'],
    "marmaga": ['cae', 'ddsa', 'mw'],
    "marmaghnī": ['mw'],
    "marmaghāta": ['mw'],
    "marmaghātin": ['mw'],
    "marmahan": ['cae', 'mw'],
    "marmaja": ['mw'],
    "marmajña": ['cae', 'mw'],
    "marmajñāna": ['mw'],
    "marmakīla": ['mw'],
    "marmamaya": ['cae', 'mw'],
    "marman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "marmapāraga": ['ddsa', 'mw'],
    "marmapīḍā": ['mw'],
    "marmara": ['ap90', 'cae', 'ddsa', 'mw'],
    "marmaraka": ['mw'],
    "marmarapattramokṣa": ['mw'],
    "marmarā": ['mw'],
    "marmarāja": ['ddsa', 'mw'],
    "marmarāya": ['ddsa', 'mw'],
    "marmarāyate": ['ap90'],
    "marmarī": ['ap90', 'mw'],
    "marmarībhū": ['ddsa'],
    "marmarībhūta": ['mw'],
    "marmarīka": ['mw'],
    "marmarīkaḥ": ['ap90'],
    "marmasaṃdhi": ['mw'],
    "marmaspṛś": ['cae', 'mw'],
    "marmasthala": ['mw'],
    "marmasthāna": ['mw'],
    "marmatra": ['mw'],
    "marmatāḍana": ['mw'],
    "marmavedhin": ['mw'],
    "marmavedhitā": ['mw'],
    "marmavedin": ['cae'],
    "marmaveditā": ['mw'],
    "marmavegitā": ['mw'],
    "marmavibhedin": ['mw'],
    "marmavid": ['cae', 'ddsa', 'mw'],
    "marmavidāraṇa": ['mw'],
    "marmavyathā": ['mw'],
    "marmika": ['ap90', 'mw'],
    "marmābhighāta": ['mw'],
    "marmānveṣaṇa": ['mw'],
    "marmānveṣin": ['mw'],
    "marmātiga": ['ddsa', 'mw'],
    "marmāvaraṇa": ['mw'],
    "marmāvaraṇabhedin": ['mw'],
    "marmāvidh": ['ddsa', 'mw'],
    "marmāvin": ['mw'],
    "marmṛjenya": ['mw'],
    "marmṛtyu": ['mw'],
    "maroli": ['mw'],
    "marolika": ['mw'],
    "maroliḥ": ['ap90'],
    "marta": ['cae', 'ddsa', 'gra', 'mw'],
    "martabhojana": ['gra', 'mw'],
    "martavat": ['mw'],
    "martavatī": ['mw'],
    "martavya": ['cae', 'ddsa', 'mw'],
    "martaḥ": ['ap90'],
    "martia": ['gra'],
    "martiakṛta": ['gra'],
    "martiatrā": ['gra'],
    "martiatvana": ['gra'],
    "martieṣita": ['gra'],
    "martopaniṣad": ['mw'],
    "martya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "martyabhuvana": ['cae', 'mw'],
    "martyabhāva": ['mw'],
    "martyadharma": ['mw'],
    "martyadharman": ['mw'],
    "martyadharmin": ['mw'],
    "martyakṛta": ['gra', 'mw'],
    "martyaloka": ['mw'],
    "martyamahita": ['mw'],
    "martyamaṇḍala": ['mw'],
    "martyamukha": ['mw'],
    "martyanivāsin": ['mw'],
    "martyatrā": ['cae', 'gra', 'mw'],
    "martyatva": ['mw'],
    "martyatvana": ['gra', 'mw'],
    "martyatā": ['cae', 'mw'],
    "martyendramātṛ": ['mw'],
    "martyeṣita": ['cae', 'gra', 'mw'],
    "martyā": ['mw'],
    "martyāmṛta": ['mw'],
    "martyībhū": ['mw'],
    "maru": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "marubhauma": ['mw'],
    "marubhava": ['mw'],
    "marubhū": ['mw'],
    "marubhūmi": ['mw'],
    "marubhūmitva": ['mw'],
    "marubhūruha": ['mw'],
    "marubhūti": ['mw'],
    "marubhūtika": ['mw'],
    "marucchadā": ['mw'],
    "marucīpaṭṭana": ['mw'],
    "marud": ['mw'],
    "marudbaddha": ['mw'],
    "marudbhavā": ['mw'],
    "maruddatta": ['mw'],
    "maruddhvaja": ['mw'],
    "maruddvīpavatī": ['mw'],
    "marudeva": ['bhs', 'mw'],
    "marudeśa": ['mw'],
    "marudeśya": ['mw'],
    "marudgaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "marudhanva": ['mw'],
    "marudhanvan": ['cae', 'ddsa', 'mw'],
    "marudhara": ['mw'],
    "marudiṣṭa": ['mw'],
    "marudratha": ['mw'],
    "marudruma": ['mw'],
    "marudvartman": ['mw'],
    "marudvega": ['mw'],
    "marudvidhā": ['mw'],
    "marudvipa": ['mw'],
    "marudvāha": ['mw'],
    "marudvṛddhā": ['mw'],
    "marudvṛdha": ['cae', 'gra', 'mw'],
    "marudvṛdhā": ['mw'],
    "marudvṛtā": ['mw'],
    "marudāndola": ['mw'],
    "marugata": ['mw'],
    "maruja": ['mw'],
    "marujuṣ": ['mw'],
    "marujā": ['mw'],
    "marujātā": ['mw'],
    "maruka": ['mw'],
    "marukaccha": ['mw'],
    "marukacchanivāsin": ['mw'],
    "marukaḥ": ['ap90'],
    "marukucca": ['mw'],
    "marul": ['mw'],
    "marula": ['mw'],
    "marulaḥ": ['ap90'],
    "marulloka": ['mw'],
    "marumahī": ['mw'],
    "marumarīci": ['mw'],
    "marumarīcikā": ['mw'],
    "marumaṇḍala": ['mw'],
    "marumba": ['cped'],
    "marumārga": ['mw'],
    "marun": ['mw'],
    "marunandana": ['mw'],
    "marundha": ['mw'],
    "marundhava": ['mw'],
    "marunmaya": ['mw'],
    "marunmālā": ['mw'],
    "marunnāma": ['mw'],
    "marunta": ['mw'],
    "marupatha": ['mw'],
    "maruprapatana": ['mw'],
    "maruprapāta": ['mw'],
    "marupriya": ['mw'],
    "marupṛṣṭha": ['mw'],
    "marusambhava": ['mw'],
    "marusambhavā": ['mw'],
    "marusthala": ['cae', 'mw'],
    "marusthalī": ['mw'],
    "marusthita": ['mw'],
    "marusthā": ['mw'],
    "marut": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "maruta": ['bhs', 'ddsa', 'mw'],
    "marutaḥ": ['ap90'],
    "marutkara": ['mw'],
    "marutkarman": ['mw'],
    "marutkoṇa": ['mw'],
    "marutkriyā": ['mw'],
    "marutmat": ['mw'],
    "marutopaniṣad": ['mw'],
    "marutpatha": ['mw'],
    "marutpati": ['cae', 'mw'],
    "marutpaṭa": ['mw'],
    "marutphala": ['mw'],
    "marutplava": ['mw'],
    "marutputra": ['mw'],
    "marutpāla": ['mw'],
    "marutsahāya": ['cae', 'mw'],
    "marutsakha": ['cae', 'ddsa', 'mw'],
    "marutsakhi": ['cae', 'gra', 'mw'],
    "marutstoma": ['mw'],
    "marutstotra": ['gra', 'mw'],
    "marutsuta": ['mw'],
    "marutsūnu": ['mw'],
    "marutta": ['cae', 'ddsa', 'mw'],
    "maruttaka": ['mw'],
    "maruttakaḥ": ['ap90'],
    "maruttama": ['cae', 'gra', 'mw'],
    "maruttanaya": ['mw'],
    "maruttaruṇī": ['mw'],
    "maruttaḥ": ['ap90'],
    "marutvant": ['cae'],
    "marutvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "marutvatya": ['mw'],
    "marutvatī": ['mw'],
    "marutvatīya": ['mw'],
    "maruva": ['mw'],
    "maruvaka": ['mw'],
    "maruḥ": ['ap90'],
    "maruṃḍā": ['ap90'],
    "maruṇḍa": ['bhs', 'mw'],
    "maruṇḍā": ['mw'],
    "maruṭā": ['mw'],
    "marv": ['ap90', 'mw'],
    "marya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "maryaka": ['cae', 'gra', 'mw'],
    "maryakaḥ": ['ap90'],
    "maryatas": ['cae', 'gra', 'mw'],
    "maryaśrī": ['gra', 'mw'],
    "maryā": ['ap90', 'mw'],
    "maryāda": ['mw'],
    "maryādin": ['ap90', 'cae', 'ddsa', 'mw'],
    "maryādokti": ['mw'],
    "maryādā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "maryādābandha": ['bhs', 'mw'],
    "maryādābhedaka": ['cae', 'mw'],
    "maryādācala": ['mw'],
    "maryādādhāvana": ['mw'],
    "maryādāgiri": ['mw'],
    "maryādāmaya": ['mw'],
    "maryādāparvata": ['mw'],
    "maryādāparvatavat": ['mw'],
    "maryādāsindhu": ['mw'],
    "maryādāvacana": ['mw'],
    "maryādāvyatikrama": ['mw'],
    "maryādīkṛ": ['ap90', 'ddsa', 'mw'],
    "marākālī": ['mw'],
    "marāla": ['ap90', 'cae', 'ddsa', 'mw'],
    "marālagamanā": ['mw'],
    "marālaka": ['mw'],
    "marālakaḥ": ['ap90'],
    "marālatā": ['mw'],
    "marāra": ['mw'],
    "marāraḥ": ['ap90'],
    "marārāma": ['ddsa', 'mw'],
    "marāya": ['mw'],
    "marāyin": ['gra', 'mw'],
    "marāyu": ['cae', 'gra', 'mw'],
    "marī": ['mw'],
    "marīca": ['cae', 'ddsa', 'mw'],
    "marīcacūrṇa": ['cae'],
    "marīcaḥ": ['ap90'],
    "marīci": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "marīcidhamma": ['cped'],
    "marīcigarbha": ['mw'],
    "marīcijāla": ['bhs'],
    "marīcika": ['bhs', 'mw'],
    "marīcikā": ['ap90', 'cae', 'cped', 'mw'],
    "marīcimant": ['cae'],
    "marīcimat": ['ddsa', 'mw'],
    "marīcimālin": ['cae', 'mw'],
    "marīcin": ['ap90', 'cae', 'ddsa', 'mw'],
    "marīcipa": ['mw'],
    "marīcipattana": ['mw'],
    "marīcipaṭala": ['mw'],
    "marīcismṛti": ['mw'],
    "marīcitantra": ['mw'],
    "marīcitoya": ['mw'],
    "marīciḥ": ['ap90'],
    "marīcopapurāṇa": ['mw'],
    "marīcī": ['mw'],
    "marīmṛja": ['ap90', 'mw'],
    "marīmṛśa": ['cae', 'mw'],
    "marīsa": ['mw'],
    "marīyami": ['mw'],
    "marīyamiputra": ['mw'],
    "marśa": ['cae', 'mw'],
    "marśana": ['cae', 'ddsa', 'mw'],
    "marśanaṃ": ['ap90'],
    "marśaḥ": ['ap90'],
    "marūbaka": ['ap90'],
    "marūbhū": ['ddsa', 'mw'],
    "marūdbhava": ['mw'],
    "marūdbhavā": ['mw'],
    "marūka": ['mw'],
    "marūkaḥ": ['ap90'],
    "marūndha": ['mw'],
    "marūvaka": ['ap90'],
    "marūvaḥ": ['ap90'],
    "marḍitṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "marṣa": ['bhs', 'cae', 'gra', 'mw'],
    "marṣayati": ['bhs'],
    "marṣayitar": ['bhs'],
    "marṣaḥ": ['ap90'],
    "marṣaṇa": ['cae', 'ddsa', 'mw'],
    "marṣaṇā": ['bhs'],
    "marṣaṇīya": ['cae', 'mw'],
    "marṣin": ['ap90', 'cae', 'mw'],
    "marṣita": ['ap90', 'mw'],
    "marṣitavat": ['mw'],
    "marṣīkā": ['mw'],
    "marṭita": ['bhs'],
    "mas": ['ap90', 'ddsa', 'mw'],
    "masa": ['mw'],
    "masaka": ['ddsa', 'mw'],
    "masakkasāra": ['bhs'],
    "masamasā": ['mw'],
    "masana": ['mw'],
    "masanaṃ": ['ap90'],
    "masarā": ['ap90', 'mw'],
    "masaḥ": ['ap90'],
    "masi": ['cae', 'cped', 'ddsa', 'mw'],
    "masika": ['mw'],
    "masikaḥ": ['ap90'],
    "masikā": ['mw'],
    "masina": ['ap90', 'bhs', 'mw'],
    "masiḥ": ['ap90'],
    "masj": ['ap90'],
    "mask": ['ap90', 'mw'],
    "maskara": ['cae', 'mw'],
    "maskaraḥ": ['ap90'],
    "maskarin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "maskarīya": ['mw'],
    "masmasā": ['mw'],
    "masmā": ['ddsa', 'mw'],
    "masniya": ['bhs'],
    "massu": ['cped'],
    "massuka": ['cped'],
    "massukamma": ['cped'],
    "massukaraṇa": ['cped'],
    "masta": ['mw'],
    "mastadāru": ['mw'],
    "mastaka": ['cae', 'ddsa', 'mw'],
    "mastakajvara": ['mw'],
    "mastakaluṅga": ['bhs', 'mw'],
    "mastakam": ['mw'],
    "mastakamūlaka": ['mw'],
    "mastakapiṇḍaka": ['mw'],
    "mastakasneha": ['mw'],
    "mastakaśūla": ['mw'],
    "mastakaḥ": ['ap90'],
    "mastakodbhava": ['mw'],
    "mastakottaṃsa": ['cae'],
    "mastakākhya": ['mw'],
    "mastaluṅga": ['bhs'],
    "mastamūlaka": ['mw'],
    "mastaṃ": ['ap90'],
    "masti": ['mw'],
    "mastika": ['bhs', 'mw'],
    "mastikaṃ": ['ap90'],
    "mastiḥ": ['ap90'],
    "mastiṣka": ['cae', 'ddsa', 'gra', 'mw'],
    "mastiṣkatvac": ['mw'],
    "mastiṣkaṃ": ['ap90'],
    "mastu": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "mastuluṅga": ['cae', 'ddsa', 'mw'],
    "mastuluṅgaka": ['mw'],
    "mastvāmikṣā": ['mw'],
    "masura": ['mw'],
    "masurakarṇa": ['mw'],
    "masurakṣita": ['mw'],
    "masuraḥ": ['ap90'],
    "masurā": ['mw'],
    "masurākṣa": ['bhs'],
    "masāra": ['cae', 'ddsa', 'mw'],
    "masāragalla": ['cped'],
    "masāragalvarkamaya": ['mw'],
    "masāraḥ": ['ap90'],
    "masī": ['ap90', 'cae', 'mw'],
    "masībhū": ['ddsa'],
    "masīguḍikā": ['cae'],
    "masīnā": ['ap90', 'mw'],
    "masīra": ['mw'],
    "masīya": ['gra'],
    "masūra": ['cae', 'ddsa', 'mw'],
    "masūraka": ['mw'],
    "masūrakarṇa": ['mw'],
    "masūrakaḥ": ['ap90'],
    "masūrasaṃghārāma": ['mw'],
    "masūravidala": ['mw'],
    "masūravidalā": ['mw'],
    "masūraḥ": ['ap90'],
    "masūri": ['mw'],
    "masūrikā": ['ap90', 'bhs', 'mw'],
    "masūrā": ['mw'],
    "masūrābha": ['mw'],
    "masūrākṣa": ['mw'],
    "masūrī": ['ap90', 'mw'],
    "masūsya": ['cae', 'mw'],
    "masṛṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "masṛṇatva": ['mw'],
    "masṛṇavāṇī": ['mw'],
    "masṛṇay": ['cae'],
    "masṛṇaya": ['ddsa', 'mw'],
    "masṛṇita": ['ap90', 'mw'],
    "masṛṇitaśila": ['mw'],
    "mat": ['ddsa', 'mw'],
    "mata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "matabheda": ['ddsa', 'mw'],
    "matabhedana": ['mw'],
    "matacatuṣṭayaparīkṣā": ['mw'],
    "matajña": ['mw'],
    "mataka": ['cped'],
    "matakabhatta": ['cped'],
    "matakavattha": ['cped'],
    "matakhaṇḍanastotra": ['mw'],
    "matakicca": ['cped'],
    "matallikā": ['ap90', 'ddsa', 'mw'],
    "matallī": ['ap90', 'mw'],
    "mataparīkṣā": ['mw'],
    "matasna": ['cae', 'gra', 'mw'],
    "matavacas": ['cae', 'gra', 'mw'],
    "matavant": ['cae'],
    "matavat": ['gra', 'mw'],
    "matayogīśa": ['mw'],
    "mataṃga": ['mw'],
    "mataṃgadeva": ['mw'],
    "mataṃgahataka": ['mw'],
    "mataṃgaja": ['mw'],
    "mataṃgajatva": ['mw'],
    "mataṃgajaḥ": ['ap90'],
    "mataṃgajā": ['mw'],
    "mataṃgapura": ['mw'],
    "mataṃgapārameśvara": ['mw'],
    "mataṃgasarasa": ['mw'],
    "mataṃgatīrtha": ['mw'],
    "mataṃgavāpī": ['mw'],
    "mataṃgavṛtti": ['mw'],
    "mataṃgayajñāgni": ['mw'],
    "mataṃgaḥ": ['ap90'],
    "mataṃginī": ['mw'],
    "mataṃgānucara": ['mw'],
    "mataṅga": ['cae', 'ddsa'],
    "mataṅgaja": ['cae'],
    "mataṅginī": ['ddsa'],
    "math": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "matha": ['ap90', 'mw'],
    "mathaka": ['mw'],
    "mathan": ['ddsa', 'mw'],
    "mathana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "mathanācala": ['mw'],
    "mathati": ['cped'],
    "mathavya": ['mw'],
    "mathi": ['cped', 'ddsa', 'gra', 'mw'],
    "mathin": ['ap90', 'mw'],
    "mathita": ['ap90', 'cped', 'mw'],
    "mathitapādapa": ['mw'],
    "mathitorasa": ['mw'],
    "mathitvā": ['cped'],
    "mathitṛ": ['cae', 'mw'],
    "mathiḥ": ['ap90'],
    "mathna": ['gra', 'mw'],
    "mathra": ['cae', 'gra', 'mw'],
    "mathu": ['mw'],
    "mathura": ['cae', 'ddsa', 'mw'],
    "mathureśa": ['mw'],
    "mathurā": ['ap90', 'mw'],
    "mathurācampū": ['mw'],
    "mathurādāsa": ['mw'],
    "mathurāguhyavarnaṇa": ['mw'],
    "mathurākāṇḍa": ['mw'],
    "mathurāmahiman": ['mw'],
    "mathurāmāhātmya": ['mw'],
    "mathurāmāhātmyasaṃgraha": ['mw'],
    "mathurānātha": ['mw'],
    "mathurānāthajātimālā": ['mw'],
    "mathurānātharāya": ['mw'],
    "mathurānāthīya": ['mw'],
    "mathurānāṭaka": ['mw'],
    "mathurāsetu": ['mw'],
    "mathurātīrthamahātmya": ['mw'],
    "mathya": ['bhs', 'cae', 'mw'],
    "mathā": ['mw'],
    "mathāta": ['mw'],
    "mathāy": ['cae', 'gra'],
    "mathāya": ['ddsa', 'mw'],
    "mathīna": ['mw'],
    "mathūrā": ['ap90', 'mw'],
    "mati": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "matibhadragaṇi": ['mw'],
    "matibheda": ['cae', 'mw'],
    "matibhrama": ['cae', 'mw'],
    "matibhrānti": ['mw'],
    "maticitra": ['mw'],
    "matidarśana": ['mw'],
    "matidatta": ['mw'],
    "matidhvaja": ['mw'],
    "matidvaidha": ['mw'],
    "matidā": ['mw'],
    "matigarbha": ['mw'],
    "matigati": ['mw'],
    "matihīna": ['cae', 'mw'],
    "matijñānaśri": ['bhs'],
    "matikarman": ['ddsa', 'mw'],
    "matila": ['mw'],
    "matimant": ['cae', 'cped'],
    "matimat": ['ap90', 'ddsa', 'mw'],
    "matimukura": ['mw'],
    "matimānuṣa": ['mw'],
    "matinirṇaya": ['mw'],
    "matiniścaya": ['mw'],
    "matināra": ['mw'],
    "matipatha": ['mw'],
    "matipathaṃnī": ['mw'],
    "matiprakarṣa": ['mw'],
    "matipura": ['mw'],
    "matipūrva": ['cae', 'mw'],
    "matipūrvaka": ['mw'],
    "matipūrvakam": ['cae', 'mw'],
    "matipūrvam": ['mw'],
    "matipūrve": ['mw'],
    "matiratnamuni": ['mw'],
    "matirāja": ['mw'],
    "matisaciva": ['mw'],
    "matisāra": ['bhs'],
    "mativant": ['bhs'],
    "mativardhana": ['mw'],
    "mativat": ['mw'],
    "mativibhrama": ['cae', 'mw'],
    "mativibhraṃśa": ['mw'],
    "mativibhrānti": ['mw'],
    "mativid": ['cae', 'mw'],
    "mativijñāna": ['bhs'],
    "mativikrama": ['bhs'],
    "mativiparyaya": ['mw'],
    "mativippahīna": ['cped'],
    "matiśālin": ['cae', 'mw'],
    "matiḥ": ['ap90'],
    "matka": ['ap90', 'cae', 'ddsa', 'mw'],
    "matkoṭaka": ['mw'],
    "matkuṇa": ['cae', 'ddsa', 'mw'],
    "matkuṇagandha": ['mw'],
    "matkuṇatva": ['mw'],
    "matkuṇaḥ": ['ap90'],
    "matkuṇikā": ['mw'],
    "matkuṇā": ['mw'],
    "matkuṇāri": ['mw'],
    "matkṛta": ['cae', 'ddsa', 'gra', 'mw'],
    "matpara": ['cae', 'mw'],
    "matparama": ['cae', 'mw'],
    "matparāyaṇa": ['cae', 'mw'],
    "matprasūta": ['mw'],
    "matputra": ['mw'],
    "matpūrva": ['mw'],
    "matsa": ['mw'],
    "matsagaṇṭa": ['mw'],
    "matsagaṇṭha": ['mw'],
    "matsakhi": ['ddsa', 'gra', 'mw'],
    "matsakāśe": ['mw'],
    "matsamakṣam": ['mw'],
    "matsamatva": ['cae', 'mw'],
    "matsara": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "matsaramanas": ['mw'],
    "matsaravant": ['cae'],
    "matsaravat": ['gra', 'mw'],
    "matsarin": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "matsarī": ['mw'],
    "matsarīkṛtā": ['mw'],
    "matsaḥ": ['ap90'],
    "matsaṃdeśa": ['mw'],
    "matsaṃsthā": ['cae', 'mw'],
    "matsin": ['mw'],
    "matsodarī": ['mw'],
    "matstha": ['cae'],
    "matsya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "matsyabandha": ['cae', 'mw'],
    "matsyabandhana": ['cae', 'mw'],
    "matsyabandhanī": ['mw'],
    "matsyabandhin": ['mw'],
    "matsyabandhinī": ['mw'],
    "matsyadeśa": ['mw'],
    "matsyadhvaja": ['ddsa', 'mw'],
    "matsyadhānī": ['mw'],
    "matsyadvādaśikā": ['mw'],
    "matsyadvādaśī": ['mw'],
    "matsyadvīpa": ['mw'],
    "matsyagandha": ['mw'],
    "matsyagandhā": ['mw'],
    "matsyaghaṇṭa": ['mw'],
    "matsyaghāta": ['cae', 'mw'],
    "matsyaghātin": ['mw'],
    "matsyagu": ['mw'],
    "matsyahan": ['mw'],
    "matsyajāla": ['mw'],
    "matsyajīvat": ['mw'],
    "matsyajīvin": ['mw'],
    "matsyaka": ['ddsa', 'mw'],
    "matsyakaraṇḍikā": ['mw'],
    "matsyakūrmādyavatārin": ['mw'],
    "matsyamādhava": ['mw'],
    "matsyamāṃsa": ['cae', 'mw'],
    "matsyanārī": ['mw'],
    "matsyanātha": ['mw'],
    "matsyanāśaka": ['mw'],
    "matsyanāśana": ['mw'],
    "matsyapittā": ['mw'],
    "matsyaprādurbhāva": ['mw'],
    "matsyapurāṇa": ['cae', 'mw'],
    "matsyaraṅga": ['mw'],
    "matsyaraṅgaka": ['mw'],
    "matsyaraṅka": ['mw'],
    "matsyarāja": ['mw'],
    "matsyasagandhin": ['mw'],
    "matsyasaṃghāta": ['mw'],
    "matsyasaṃtānika": ['mw'],
    "matsyasūkta": ['mw'],
    "matsyatantra": ['mw'],
    "matsyavedhana": ['mw'],
    "matsyavedhanī": ['mw'],
    "matsyavid": ['mw'],
    "matsyavinnā": ['mw'],
    "matsyavratin": ['mw'],
    "matsyaśakalā": ['mw'],
    "matsyaḥ": ['ap90'],
    "matsyaṃḍikā": ['ap90'],
    "matsyaṇḍikā": ['cae', 'ddsa', 'mw'],
    "matsyaṇḍī": ['mw'],
    "matsyendra": ['mw'],
    "matsyendramuhūrta": ['mw'],
    "matsyeśvaratīrtha": ['mw'],
    "matsyodarin": ['mw'],
    "matsyodarī": ['mw'],
    "matsyodarīya": ['mw'],
    "matsyopajīvin": ['mw'],
    "matsyotthā": ['mw'],
    "matsyā": ['mw'],
    "matsyād": ['cae', 'mw'],
    "matsyāda": ['cae', 'mw'],
    "matsyādanī": ['mw'],
    "matsyākṣaka": ['mw'],
    "matsyākṣakā": ['mw'],
    "matsyākṣikā": ['mw'],
    "matsyākṣī": ['mw'],
    "matsyāsura": ['mw'],
    "matsyāsuraśailavadha": ['mw'],
    "matsyāvatāra": ['mw'],
    "matsyāvatārakathana": ['mw'],
    "matsyāvatāraprabandha": ['mw'],
    "matsyāśana": ['mw'],
    "matsyāśin": ['mw'],
    "matsyāṅgī": ['mw'],
    "matsyāṇḍa": ['ddsa', 'mw'],
    "matsyī": ['mw'],
    "matsādṛśya": ['mw'],
    "matsī": ['ddsa'],
    "matta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "mattadantin": ['mw'],
    "mattagāminī": ['mw'],
    "mattahastin": ['cae', 'mw'],
    "mattahatthī": ['cped'],
    "mattaka": ['ap90', 'mw'],
    "mattakāla": ['mw'],
    "mattakāśinī": ['cae', 'mw'],
    "mattakīśa": ['mw'],
    "mattamayūra": ['cae', 'mw'],
    "mattamayūraka": ['mw'],
    "mattamātaṃgalīlākara": ['mw'],
    "mattanāga": ['mw'],
    "mattara": ['mw'],
    "mattas": ['cae', 'ddsa'],
    "mattavilāsinī": ['mw'],
    "mattavāraṇa": ['cae', 'mw'],
    "mattavāraṇavikrama": ['mw'],
    "mattavāraṇīya": ['mw'],
    "mattavāṅmaunamūlikā": ['mw'],
    "mattaññutā": ['cped'],
    "mattaññū": ['cped'],
    "mattebha": ['mw'],
    "mattebhagamanā": ['mw'],
    "mattebhakumbhapariṇāhin": ['mw'],
    "mattebhavikrīḍita": ['mw'],
    "mattebhāsya": ['mw'],
    "matteyya": ['cped'],
    "matteyyatā": ['cped'],
    "matthaka": ['cped'],
    "matthaluṅga": ['cped'],
    "matthu": ['cped'],
    "mattigha": ['cped'],
    "mattikapatta": ['cped'],
    "mattikā": ['cped'],
    "mattikābhājana": ['cped'],
    "mattikāpiṇḍa": ['cped'],
    "mattā": ['cped', 'mw'],
    "mattākrīḍā": ['mw'],
    "mattālamba": ['mw'],
    "mattāsukha": ['cped'],
    "matula": ['mw'],
    "matutha": ['cae', 'gra', 'mw'],
    "matya": ['cae', 'ddsa', 'mw'],
    "matyaṃ": ['ap90'],
    "matyā": ['mw'],
    "matākṣa": ['cae', 'ddsa', 'mw'],
    "matāntara": ['mw'],
    "matānujñā": ['mw'],
    "matāvalambana": ['mw'],
    "matāvalambin": ['mw'],
    "matīkṛ": ['ddsa', 'mw'],
    "matīśvara": ['bhs', 'mw'],
    "mauca": ['cae', 'ddsa', 'mw'],
    "maucaṃ": ['ap90'],
    "mauda": ['mw'],
    "maudahāyana": ['mw'],
    "maudaka": ['ap90', 'mw'],
    "maudakika": ['mw'],
    "maudakikaḥ": ['ap90'],
    "maudamānika": ['mw'],
    "maudaneyaka": ['mw'],
    "maudanika": ['mw'],
    "maudapaippalāda": ['mw'],
    "maudga": ['ddsa', 'mw'],
    "maudgali": ['mw'],
    "maudgalikera": ['mw'],
    "maudgaliḥ": ['ap90'],
    "maudgalya": ['cae', 'ddsa', 'mw'],
    "maudgalyāyana": ['bhs', 'mw'],
    "maudgalīya": ['mw'],
    "maudgika": ['mw'],
    "maudgīna": ['ap90', 'mw'],
    "maudhya": ['ddsa'],
    "maudrika": ['bhs', 'mw'],
    "maudākin": ['mw'],
    "maugdha": ['mw'],
    "maugdhya": ['cae', 'ddsa'],
    "maugdhyaṃ": ['ap90'],
    "maughya": ['cae', 'mw'],
    "maughyaṃ": ['ap90'],
    "mauhanika": ['mw'],
    "mauhūrta": ['cae', 'ddsa', 'mw'],
    "mauhūrtaḥ": ['ap90'],
    "mauhūrtika": ['ap90', 'cae', 'mw'],
    "maujadīna": ['mw'],
    "maujavata": ['cae', 'gra', 'mw'],
    "maujāvata": ['ddsa'],
    "mauka": ['mw'],
    "maukali": ['mw'],
    "maukaliḥ": ['ap90'],
    "maukalya": ['mw'],
    "maukha": ['cae', 'ddsa', 'mw'],
    "maukhara": ['ddsa', 'mw'],
    "maukhari": ['mw'],
    "maukhariḥ": ['ap90'],
    "maukharya": ['cae', 'mw'],
    "maukharyaṃ": ['ap90'],
    "maukharyā": ['mw'],
    "maukharī": ['mw'],
    "maukhika": ['mw'],
    "maukhya": ['mw'],
    "maukhyaṃ": ['ap90'],
    "mauktika": ['cae', 'ddsa', 'mw'],
    "mauktikadāman": ['mw'],
    "mauktikagumphikā": ['mw'],
    "mauktikamaya": ['mw'],
    "mauktikamālā": ['mw'],
    "mauktikamāraṇa": ['mw'],
    "mauktikaprasavā": ['mw'],
    "mauktikaratna": ['mw'],
    "mauktikaratnatā": ['mw'],
    "mauktikasara": ['mw'],
    "mauktikataṇḍula": ['mw'],
    "mauktikaśukti": ['mw'],
    "mauktikaṃ": ['ap90'],
    "mauktikābha": ['mw'],
    "mauktikāhāra": ['cae', 'mw'],
    "mauktikāvali": ['cae', 'mw'],
    "mauktikāvalī": ['cae', 'mw'],
    "maukuli": ['ddsa', 'mw'],
    "maukuliḥ": ['ap90'],
    "maukunda": ['mw'],
    "maukya": ['cae', 'ddsa', 'mw'],
    "maukyaṃ": ['ap90'],
    "maukṣa": ['mw'],
    "maukṣika": ['ddsa', 'mw'],
    "maula": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "maulabhārika": ['mw'],
    "mauleya": ['mw'],
    "mauli": ['ap90', 'cae', 'ddsa', 'mw'],
    "maulibandha": ['mw'],
    "maulika": ['ap90', 'ddsa', 'mw'],
    "maulikapha": ['mw'],
    "maulikya": ['mw'],
    "maulimaṇi": ['mw'],
    "maulimaṇḍana": ['mw'],
    "maulimaṇḍanamālikā": ['mw'],
    "maulimukuṭa": ['mw'],
    "maulimālikā": ['cae', 'mw'],
    "maulimālin": ['mw'],
    "maulimālā": ['cae', 'mw'],
    "maulin": ['ap90', 'cae', 'mw'],
    "maulipṛṣṭha": ['ddsa', 'mw'],
    "mauliratna": ['mw'],
    "maulugi": ['mw'],
    "maulya": ['cae', 'ddsa', 'mw'],
    "maulyaṃ": ['ap90'],
    "maulyābharaṇa": ['ddsa', 'mw'],
    "maulyādhyāya": ['mw'],
    "maulī": ['mw'],
    "maulīndu": ['mw'],
    "mauna": ['bhs', 'cae', 'ddsa', 'mw'],
    "maunabhaṭṭa": ['mw'],
    "maunadhārin": ['mw'],
    "maunagopāla": ['mw'],
    "maunamantrāvabodha": ['mw'],
    "maunamudrā": ['mw'],
    "maunasammati": ['mw'],
    "maunasūtra": ['mw'],
    "maunatyāga": ['mw'],
    "maunavrata": ['cae', 'mw'],
    "maunavratadhara": ['mw'],
    "maunavratadhārin": ['mw'],
    "maunavratin": ['mw'],
    "maunavṛtti": ['cae', 'mw'],
    "maunaṃ": ['ap90'],
    "maunda": ['mw'],
    "mauneya": ['bhs', 'gra', 'mw'],
    "mauni": ['mw'],
    "mauniciti": ['mw'],
    "maunika": ['mw'],
    "maunin": ['ap90', 'cae', 'ddsa', 'mw'],
    "maunisthalika": ['mw'],
    "maunitva": ['mw'],
    "maunya": ['mw'],
    "maunī": ['mw'],
    "maunīndra": ['bhs', 'mw'],
    "maura": ['bhs'],
    "maurajika": ['mw'],
    "maurajikaḥ": ['ap90'],
    "maurava": ['ddsa', 'mw'],
    "maurin": ['bhs'],
    "maurkhya": ['cae', 'ddsa', 'mw'],
    "maurkhyaṃ": ['ap90'],
    "maurva": ['ap90', 'cae', 'ddsa', 'mw'],
    "maurvikā": ['mw'],
    "maurvī": ['ap90', 'mw'],
    "maurvījyā": ['cae'],
    "maurvīmekhalin": ['mw'],
    "maurya": ['bhs', 'cae', 'ddsa', 'mw'],
    "mauryadatta": ['mw'],
    "mauryaputra": ['mw'],
    "mauryaḥ": ['ap90'],
    "mausala": ['ap90', 'cae', 'ddsa', 'mw'],
    "mausalaparvan": ['mw'],
    "mausalya": ['mw'],
    "mausula": ['mw'],
    "mautra": ['ddsa', 'mw'],
    "mautrakṛcchrika": ['mw'],
    "mautraṃ": ['ap90'],
    "mauñja": ['cae', 'ddsa', 'gra', 'mw'],
    "mauñjaka": ['mw'],
    "mauñjakāyana": ['mw'],
    "mauñjavata": ['mw'],
    "mauñjavivāna": ['mw'],
    "mauñjibandhana": ['mw'],
    "mauñjin": ['cae', 'ddsa', 'mw'],
    "mauñjya": ['ddsa', 'mw'],
    "mauñjāyana": ['mw'],
    "mauñjāyanī": ['mw'],
    "mauñjāyanīya": ['mw'],
    "mauñjī": ['ddsa', 'mw'],
    "mauñjībandhana": ['cae', 'mw'],
    "mauñjībandhanacihnita": ['mw'],
    "mauñjīdhara": ['mw'],
    "mauñjīnibandhana": ['cae', 'mw'],
    "mauñjīpattrā": ['mw'],
    "mauñjītṛṇākhya": ['mw'],
    "mauñjīya": ['mw'],
    "mauśala": ['mw'],
    "mauḍhya": ['cae', 'ddsa', 'mw'],
    "mauḍhyaṃ": ['ap90'],
    "mauḍī": ['mw'],
    "mauṃja": ['ap90'],
    "mauṃjī": ['ap90'],
    "mauṃḍyaṃ": ['ap90'],
    "mauṇḍika": ['mw'],
    "mauṇḍinikāya": ['mw'],
    "mauṇḍya": ['cae', 'ddsa', 'mw'],
    "mauṣala": ['mw'],
    "mauṣika": ['ddsa', 'mw'],
    "mauṣiki": ['mw'],
    "mauṣikāra": ['mw'],
    "mauṣikīputra": ['mw'],
    "mauṣṭika": ['bhs', 'ddsa', 'mw'],
    "mauṣṭikaḥ": ['ap90'],
    "mauṣṭā": ['ap90', 'mw'],
    "mav": ['ap90', 'mw'],
    "mavara": ['bhs', 'mw'],
    "mavita": ['mw'],
    "mavy": ['ap90', 'mw'],
    "may": ['ap90', 'gra', 'mw'],
    "maya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mayadānava": ['mw'],
    "mayadīpikā": ['mw'],
    "mayagrāma": ['ddsa', 'mw'],
    "mayakā": ['mw'],
    "mayakṣetra": ['mw'],
    "mayakṣetramāhātmya": ['mw'],
    "mayamata": ['mw'],
    "mayanda": ['cae', 'mw'],
    "mayanirmita": ['mw'],
    "mayanta": ['cae', 'mw'],
    "mayas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mayasaras": ['mw'],
    "mayasaṃgraha": ['mw'],
    "mayaskara": ['cae', 'mw'],
    "mayaśilpa": ['mw'],
    "mayaṁ": ['cped'],
    "mayaṣṭa": ['mw'],
    "mayaṣṭaka": ['mw'],
    "mayaṣṭakaḥ": ['ap90'],
    "mayaṭa": ['mw'],
    "mayaṭaḥ": ['ap90'],
    "mayeśvara": ['mw'],
    "mayivasu": ['ddsa', 'mw'],
    "mayo": ['mw'],
    "mayobhava": ['cae', 'mw'],
    "mayobhu": ['cae', 'ddsa', 'gra', 'mw'],
    "mayobhuva": ['mw'],
    "mayobhū": ['cae', 'gra', 'mw'],
    "mayu": ['cae', 'ddsa', 'mw'],
    "mayurāja": ['mw'],
    "mayuḥ": ['ap90'],
    "mayuṣṭaka": ['mw'],
    "mayuṣṭakaḥ": ['ap90'],
    "mayya": ['cae', 'ddsa'],
    "mayā": ['mw'],
    "mayārāma": ['mw'],
    "mayī": ['mw'],
    "mayūka": ['mw'],
    "mayūkha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mayūkhamālikā": ['mw'],
    "mayūkhamālin": ['mw'],
    "mayūkhamālā": ['mw'],
    "mayūkhapṛkta": ['mw'],
    "mayūkhavat": ['mw'],
    "mayūkhaḥ": ['ap90'],
    "mayūkheśa": ['mw'],
    "mayūkhin": ['ap90', 'mw'],
    "mayūkhāditya": ['mw'],
    "mayūkhāvali": ['mw'],
    "mayūra": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mayūracaṭaka": ['mw'],
    "mayūracitraka": ['mw'],
    "mayūracūḍa": ['mw'],
    "mayūracūḍā": ['mw'],
    "mayūragati": ['mw'],
    "mayūraghṛta": ['mw'],
    "mayūragrīva": ['mw'],
    "mayūragrīvaka": ['mw'],
    "mayūrahastaka": ['bhs'],
    "mayūrajaṅgha": ['mw'],
    "mayūraka": ['mw'],
    "mayūrakarṇa": ['mw'],
    "mayūrakaḥ": ['ap90'],
    "mayūraketu": ['mw'],
    "mayūrakiśora": ['mw'],
    "mayūrakuśa": ['bhs'],
    "mayūramaya": ['mw'],
    "mayūrapadaka": ['mw'],
    "mayūraparvata": ['mw'],
    "mayūrapattrin": ['cae', 'mw'],
    "mayūrapiccha": ['mw'],
    "mayūrapicchamaya": ['mw'],
    "mayūrapoṣaka": ['mw'],
    "mayūrapura": ['mw'],
    "mayūrapuramāhātmya": ['mw'],
    "mayūraratha": ['mw'],
    "mayūraroman": ['gra', 'mw'],
    "mayūrasthalamāhātmya": ['mw'],
    "mayūrastuti": ['mw'],
    "mayūrasārin": ['mw'],
    "mayūrasāriṇī": ['mw'],
    "mayūratuttha": ['mw'],
    "mayūratva": ['mw'],
    "mayūratā": ['mw'],
    "mayūravarmacaritra": ['mw'],
    "mayūravarman": ['mw'],
    "mayūravidalā": ['mw'],
    "mayūravyaṃsaka": ['mw'],
    "mayūravācaspati": ['mw'],
    "mayūravāhana": ['mw'],
    "mayūraśarman": ['mw'],
    "mayūraśataka": ['mw'],
    "mayūraśepa": ['gra'],
    "mayūraśepia": ['gra'],
    "mayūraśepya": ['gra', 'mw'],
    "mayūraśikhā": ['mw'],
    "mayūraḥ": ['ap90'],
    "mayūreśa": ['mw'],
    "mayūreśavivāhavarṇana": ['mw'],
    "mayūreśvara": ['mw'],
    "mayūrikā": ['mw'],
    "mayūrikābandham": ['mw'],
    "mayūrollāsaka": ['mw'],
    "mayūrākṣa": ['mw'],
    "mayūrāri": ['mw'],
    "mayūrāṅgahastaka": ['bhs'],
    "mayūrāṅkī": ['bhs', 'mw'],
    "mayūrāṣṭaka": ['mw'],
    "mayūrī": ['ddsa', 'mw'],
    "mayūrībhū": ['ddsa', 'mw'],
    "mañc": ['ddsa', 'mw'],
    "mañca": ['cae', 'cped', 'ddsa', 'mw'],
    "mañcaka": ['cae', 'cped', 'mw'],
    "mañcakagata": ['mw'],
    "mañcakāmañcaka": ['bhs'],
    "mañcakāsura": ['mw'],
    "mañcakāsuradundubhivadha": ['mw'],
    "mañcakāśraya": ['mw'],
    "mañcakāśrayin": ['mw'],
    "mañcamaṇḍapa": ['mw'],
    "mañcana": ['mw'],
    "mañcanṛtya": ['mw'],
    "mañcaparāyaṇa": ['cped'],
    "mañcapītha": ['mw'],
    "mañcapīṭha": ['cped'],
    "mañcastha": ['mw'],
    "mañcavāna": ['cped'],
    "mañcavāṭa": ['mw'],
    "mañcayayya": ['mw'],
    "mañcayāpya": ['mw'],
    "mañcayūpa": ['mw'],
    "mañcikā": ['mw'],
    "mañcipattra": ['mw'],
    "mañcukā": ['mw'],
    "mañcāgāra": ['mw'],
    "mañcārohaṇa": ['mw'],
    "mañj": ['mw'],
    "mañjana": ['mw'],
    "mañjara": ['cae', 'ddsa', 'mw'],
    "mañjaraya": ['ddsa', 'mw'],
    "mañjari": ['cae', 'ddsa', 'mw'],
    "mañjaridhārin": ['mw'],
    "mañjarikā": ['mw'],
    "mañjarita": ['mw'],
    "mañjarī": ['cae', 'cped', 'mw'],
    "mañjarīcāmara": ['mw'],
    "mañjarīdīpikā": ['mw'],
    "mañjarījāla": ['mw'],
    "mañjarījāladhārin": ['mw'],
    "mañjarīka": ['mw'],
    "mañjarīkṛ": ['mw'],
    "mañjarīnamra": ['mw'],
    "mañjarīpiñjarita": ['mw'],
    "mañjarīprakāśa": ['mw'],
    "mañjarīsāra": ['mw'],
    "mañjeṭṭha": ['cped'],
    "mañjeṭṭhī": ['cped'],
    "mañji": ['mw'],
    "mañjikā": ['mw'],
    "mañjiman": ['ddsa', 'mw'],
    "mañjiphalā": ['mw'],
    "mañjiṣṭha": ['bhs', 'mw'],
    "mañjiṣṭhikā": ['bhs'],
    "mañjiṣṭhā": ['cae', 'ddsa', 'mw'],
    "mañjiṣṭhābha": ['mw'],
    "mañjiṣṭhāmeha": ['mw'],
    "mañjiṣṭhāmehin": ['mw'],
    "mañjiṣṭhārāga": ['mw'],
    "mañjiṭṭha": ['cped'],
    "mañjiṭṭhā": ['cped'],
    "mañju": ['cae', 'cped', 'ddsa', 'mw'],
    "mañjubhadra": ['mw'],
    "mañjubhaṭṭa": ['mw'],
    "mañjubhāṇaka": ['cped'],
    "mañjubhāṇin": ['bhs'],
    "mañjubhāṣin": ['cae', 'mw'],
    "mañjubhāṣiṇī": ['mw'],
    "mañjudeva": ['mw'],
    "mañjudhvaja": ['bhs'],
    "mañjugamana": ['mw'],
    "mañjugamanā": ['mw'],
    "mañjugarta": ['mw'],
    "mañjughoṣa": ['bhs', 'mw'],
    "mañjughoṣā": ['mw'],
    "mañjugir": ['mw'],
    "mañjuguñja": ['mw'],
    "mañjuguñjatsamīra": ['mw'],
    "mañjugīti": ['mw'],
    "mañjukeśin": ['mw'],
    "mañjukula": ['mw'],
    "mañjula": ['cae', 'ddsa', 'mw'],
    "mañjulikā": ['mw'],
    "mañjulā": ['mw'],
    "mañjumatī": ['mw'],
    "mañjumañjīra": ['mw'],
    "mañjumaṇi": ['mw'],
    "mañjunandin": ['mw'],
    "mañjunetra": ['mw'],
    "mañjunātha": ['bhs', 'mw'],
    "mañjunāśī": ['mw'],
    "mañjupattana": ['mw'],
    "mañjupaṭṭana": ['mw'],
    "mañjuprāṇa": ['mw'],
    "mañjupāṭhaka": ['mw'],
    "mañjurava": ['bhs'],
    "mañjusaurabha": ['mw'],
    "mañjussara": ['cped'],
    "mañjusvana": ['cae', 'mw'],
    "mañjusvara": ['bhs', 'mw'],
    "mañjutara": ['mw'],
    "mañjuvacana": ['mw'],
    "mañjuvajra": ['bhs'],
    "mañjuvaktra": ['mw'],
    "mañjuvara": ['bhs'],
    "mañjuvāc": ['mw'],
    "mañjuvādin": ['cae', 'ddsa', 'mw'],
    "mañjuvādinī": ['mw'],
    "mañjuśrī": ['bhs', 'mw'],
    "mañjuśrībuddhakṣetraguṇavyūha": ['bhs', 'mw'],
    "mañjuśrīmūlakalpa": ['bhs'],
    "mañjuśrīmūlatantra": ['mw'],
    "mañjuśrīparipṛcchā": ['mw'],
    "mañjuśrīparvata": ['mw'],
    "mañjuśrīvihāra": ['bhs', 'mw'],
    "mañjuśrīvikrīḍita": ['mw'],
    "mañjuśrīvikrīḍitasūtra": ['bhs'],
    "mañjuṣaka": ['bhs'],
    "mañjā": ['mw'],
    "mañjī": ['mw'],
    "mañjīla": ['mw'],
    "mañjīra": ['cae', 'ddsa', 'mw'],
    "mañjīradhvanikomala": ['mw'],
    "mañjīraka": ['mw'],
    "mañjīrakvaṇita": ['mw'],
    "mañjīrā": ['mw'],
    "mañjūlā": ['mw'],
    "mañjūsaka": ['cped'],
    "mañjūsā": ['cped'],
    "mañjūṣaka": ['bhs', 'mw'],
    "mañjūṣā": ['cae', 'ddsa', 'mw'],
    "mañjūṣākuñcikā": ['mw'],
    "mañm, maj": ['ddsa'],
    "maññamāna": ['cped'],
    "maññanā": ['cped'],
    "maññati": ['cped'],
    "maññe": ['cped'],
    "maññi": ['cped'],
    "maññita": ['cped'],
    "maññitvā": ['cped'],
    "maś": ['ap90', 'mw'],
    "maśa": ['mw'],
    "maśacchada": ['mw'],
    "maśaharī": ['mw'],
    "maśaka": ['cae', 'ddsa', 'mw'],
    "maśakaharī": ['mw'],
    "maśakajambhana": ['mw'],
    "maśakakalpa": ['mw'],
    "maśakakuṭi": ['mw'],
    "maśakakuṭī": ['bhs', 'mw'],
    "maśakavaraṇa": ['bhs', 'mw'],
    "maśakaḥ": ['ap90'],
    "maśakin": ['ap90', 'mw'],
    "maśakodumbara": ['mw'],
    "maśakārtha": ['mw'],
    "maśakāvatī": ['mw'],
    "maśana": ['mw'],
    "maśarśāra": ['gra', 'mw'],
    "maśaḥ": ['ap90'],
    "maśulabara": ['mw'],
    "maśuna": ['mw'],
    "maśunaḥ": ['ap90'],
    "maśāka": ['mw'],
    "maśī": ['ap90', 'bhs'],
    "maḍaka": ['mw'],
    "maḍamaḍ": ['mw'],
    "maḍarakantha": ['mw'],
    "maḍararājya": ['ddsa', 'mw'],
    "maḍmaḍāyita": ['ap90'],
    "maḍāra": ['mw'],
    "maḍūṣikā": ['mw'],
    "maḍḍacandra": ['ddsa', 'mw'],
    "maḍḍu": ['mw'],
    "maḍḍuka": ['bhs', 'mw'],
    "maḍḍukairika": ['mw'],
    "maḍḍuḥ": ['ap90'],
    "maḥ": ['ap90'],
    "maṁsa": ['cped'],
    "maṁsapesi": ['cped'],
    "maṁsapuñja": ['cped'],
    "maṃc": ['ap90'],
    "maṃcakaṃ": ['ap90'],
    "maṃcaḥ": ['ap90'],
    "maṃcikā": ['ap90'],
    "maṃd": ['ap90'],
    "maṃda": ['ap90'],
    "maṃdaka": ['ap90'],
    "maṃdanaṃ": ['ap90'],
    "maṃdara": ['ap90'],
    "maṃdasānaḥ": ['ap90'],
    "maṃdatā": ['ap90'],
    "maṃdayati": ['ap90'],
    "maṃdayaṃtī": ['ap90'],
    "maṃdaṭaḥ": ['ap90'],
    "maṃdhātṛ": ['ap90'],
    "maṃdiman": ['ap90'],
    "maṃdiraṃ": ['ap90'],
    "maṃdirā": ['ap90'],
    "maṃdra": ['ap90'],
    "maṃdurā": ['ap90'],
    "maṃdākaḥ": ['ap90'],
    "maṃdākinī": ['ap90'],
    "maṃdārakaḥ": ['ap90'],
    "maṃdāraḥ": ['ap90'],
    "maṃdāyate": ['ap90'],
    "maṃdībhū": ['ap90'],
    "maṃdīkṛ": ['ap90'],
    "maṃg": ['ap90'],
    "maṃgala": ['ap90'],
    "maṃgalya": ['ap90'],
    "maṃgalyakaḥ": ['ap90'],
    "maṃgalāvrataḥ": ['ap90'],
    "maṃgalīya": ['ap90'],
    "maṃgaḥ": ['ap90'],
    "maṃgh": ['ap90'],
    "maṃginī": ['ap90'],
    "maṃh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "maṃhama": ['ddsa', 'mw'],
    "maṃhana": ['ddsa', 'mw'],
    "maṃhaneṣṭhā": ['gra', 'mw'],
    "maṃhanā": ['cae', 'gra', 'mw'],
    "maṃhanīya": ['ap90', 'mw'],
    "maṃhayadrayi": ['gra', 'mw'],
    "maṃhayu": ['cae', 'gra', 'mw'],
    "maṃhiṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "maṃhiṣṭharāti": ['gra', 'mw'],
    "maṃhīyas": ['gra', 'mw'],
    "maṃhīyaṃs": ['cae'],
    "maṃj": ['ap90'],
    "maṃjaraṃ": ['ap90'],
    "maṃjarita": ['ap90'],
    "maṃjariḥ": ['ap90'],
    "maṃjarījātaka": ['bhs'],
    "maṃjikā": ['ap90'],
    "maṃjiman": ['ap90'],
    "maṃjiḥ": ['ap90'],
    "maṃjiṣṭha": ['ap90'],
    "maṃjiṣṭhā": ['ap90'],
    "maṃju": ['ap90'],
    "maṃjula": ['ap90'],
    "maṃjā": ['ap90'],
    "maṃjīlaḥ": ['ap90'],
    "maṃjīraḥ": ['ap90'],
    "maṃjūṣā": ['ap90'],
    "maṃk": ['ap90'],
    "maṃkhaḥ": ['ap90'],
    "maṃkilaḥ": ['ap90'],
    "maṃkuraḥ": ['ap90'],
    "maṃkṣaṇaṃ": ['ap90'],
    "maṃkṣu": ['ap90'],
    "maṃtavya": ['ap90'],
    "maṃth": ['ap90'],
    "maṃthanaḥ": ['ap90'],
    "maṃthara": ['ap90'],
    "maṃtharuḥ": ['ap90'],
    "maṃthaḥ": ['ap90'],
    "maṃthin": ['ap90'],
    "maṃthānakaḥ": ['ap90'],
    "maṃthānaḥ": ['ap90'],
    "maṃtr": ['ap90'],
    "maṃtrata": ['ap90'],
    "maṃtravat": ['ap90'],
    "maṃtraḥ": ['ap90'],
    "maṃtraṇaṃ": ['ap90'],
    "maṃtrin": ['ap90'],
    "maṃtrita": ['ap90'],
    "maṃtritā": ['ap90'],
    "maṃtriḥ": ['ap90'],
    "maṃtuḥ": ['ap90'],
    "maṃtūyati": ['ap90'],
    "maṃtṛ": ['ap90'],
    "maṃḍ": ['ap90'],
    "maṃḍakaḥ": ['ap90'],
    "maṃḍala": ['ap90'],
    "maṃḍalakaṃ": ['ap90'],
    "maṃḍalayati": ['ap90'],
    "maṃḍalin": ['ap90'],
    "maṃḍalita": ['ap90'],
    "maṃḍalāyate": ['ap90'],
    "maṃḍalāyita": ['ap90'],
    "maṃḍalībhū": ['ap90'],
    "maṃḍalīkaraṇaṃ": ['ap90'],
    "maṃḍalīkaḥ": ['ap90'],
    "maṃḍalīkṛ": ['ap90'],
    "maṃḍalīkṛta": ['ap90'],
    "maṃḍana": ['ap90'],
    "maṃḍapakaḥ": ['ap90'],
    "maṃḍapaḥ": ['ap90'],
    "maṃḍarī": ['ap90'],
    "maṃḍayaṃtaḥ": ['ap90'],
    "maṃḍaḥ": ['ap90'],
    "maṃḍita": ['ap90'],
    "maṃḍūkaḥ": ['ap90'],
    "maṃḍūraṃ": ['ap90'],
    "maṃṭh": ['ap90'],
    "maṃṭhaḥ": ['ap90'],
    "maṅg": ['mw'],
    "maṅga": ['cae', 'mw'],
    "maṅgala": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "maṅgalabherī": ['mw'],
    "maṅgalacaṇḍikā": ['mw'],
    "maṅgalacaṇḍī": ['mw'],
    "maṅgalacchāya": ['mw'],
    "maṅgaladaśaka": ['mw'],
    "maṅgaladevatā": ['mw'],
    "maṅgaladhvani": ['mw'],
    "maṅgaladivasa": ['cped'],
    "maṅgaladvāra": ['mw'],
    "maṅgalaghaṭa": ['mw'],
    "maṅgalagiri": ['mw'],
    "maṅgalagirimāhātmya": ['mw'],
    "maṅgalagraha": ['mw'],
    "maṅgalagāthikā": ['mw'],
    "maṅgalagīta": ['mw'],
    "maṅgalagṛha": ['cae', 'mw'],
    "maṅgalahatthī": ['cped'],
    "maṅgalakalaśa": ['cae', 'mw'],
    "maṅgalakalaśamaya": ['mw'],
    "maṅgalakaraṇa": ['cae', 'mw'],
    "maṅgalakarman": ['mw'],
    "maṅgalakicca": ['cped'],
    "maṅgalakolāhala": ['cped'],
    "maṅgalakuṭhāramiśra": ['mw'],
    "maṅgalakāla": ['mw'],
    "maṅgalakāraka": ['mw'],
    "maṅgalakārin": ['mw'],
    "maṅgalakārya": ['mw'],
    "maṅgalakṣauma": ['mw'],
    "maṅgalamaya": ['mw'],
    "maṅgalamayūkhamālikā": ['mw'],
    "maṅgalamālikā": ['mw'],
    "maṅgalamātrabhūṣaṇa": ['mw'],
    "maṅgalanirṇaya": ['mw'],
    "maṅgalapattra": ['mw'],
    "maṅgalapokkharaṇī": ['cped'],
    "maṅgalaprada": ['mw'],
    "maṅgalapradā": ['mw'],
    "maṅgalaprastha": ['mw'],
    "maṅgalapratisara": ['mw'],
    "maṅgalapura": ['mw'],
    "maṅgalapuṣpamaya": ['mw'],
    "maṅgalapātra": ['mw'],
    "maṅgalapāṇi": ['mw'],
    "maṅgalapāṭhaka": ['mw'],
    "maṅgalapūjita": ['mw'],
    "maṅgalapūjāprayoga": ['mw'],
    "maṅgalapūjāvidhi": ['mw'],
    "maṅgalarāja": ['mw'],
    "maṅgalasamālambhana": ['cae', 'mw'],
    "maṅgalasaṃstava": ['mw'],
    "maṅgalasena": ['bhs'],
    "maṅgalasilāpaṭṭa": ['cped'],
    "maṅgalasindhava": ['cped'],
    "maṅgalasnāna": ['mw'],
    "maṅgalassa": ['cped'],
    "maṅgalastava": ['mw'],
    "maṅgalastotra": ['mw'],
    "maṅgalasupina": ['cped'],
    "maṅgalasvara": ['mw'],
    "maṅgalasāman": ['mw'],
    "maṅgalasūcaka": ['mw'],
    "maṅgalasūtra": ['mw'],
    "maṅgalatūrya": ['cae', 'mw'],
    "maṅgalavacas": ['cae', 'mw'],
    "maṅgalavat": ['mw'],
    "maṅgalavatsa": ['mw'],
    "maṅgalavatī": ['mw'],
    "maṅgalavidhi": ['mw'],
    "maṅgalavāda": ['mw'],
    "maṅgalavādaṭīkā": ['mw'],
    "maṅgalavādin": ['mw'],
    "maṅgalavādārtha": ['mw'],
    "maṅgalavāra": ['mw'],
    "maṅgalavāsara": ['mw'],
    "maṅgalavṛṣabha": ['mw'],
    "maṅgalaśabda": ['mw'],
    "maṅgalaśaṃsana": ['mw'],
    "maṅgalaśānti": ['mw'],
    "maṅgalecchu": ['mw'],
    "maṅgalecchā": ['mw'],
    "maṅgalecchāyai": ['mw'],
    "maṅgaleśvaratīrtha": ['mw'],
    "maṅgalika": ['mw'],
    "maṅgalodgīta": ['cae'],
    "maṅgalopepsā": ['mw'],
    "maṅgalya": ['bhs', 'cae', 'ddsa', 'mw'],
    "maṅgalyadaṇḍa": ['mw'],
    "maṅgalyaka": ['mw'],
    "maṅgalyakusumā": ['mw'],
    "maṅgalyalipi": ['bhs'],
    "maṅgalyanāmadheyā": ['mw'],
    "maṅgalyanāman": ['mw'],
    "maṅgalyavastu": ['mw'],
    "maṅgalyā": ['mw'],
    "maṅgalyārhā": ['mw'],
    "maṅgalā": ['ddsa', 'mw'],
    "maṅgalācaraṇa": ['ddsa', 'mw'],
    "maṅgalācāra": ['cae', 'mw'],
    "maṅgalācārayukta": ['mw'],
    "maṅgalādeśavṛtta": ['cae', 'mw'],
    "maṅgalāgauryaṣṭaka": ['mw'],
    "maṅgalāgaurīpūjā": ['mw'],
    "maṅgalāgaurīvratakathā": ['mw'],
    "maṅgalāgaurīvratodyāpana": ['mw'],
    "maṅgalāguru": ['mw'],
    "maṅgalāhnika": ['mw'],
    "maṅgalākṣata": ['mw'],
    "maṅgalālabhanīya": ['mw'],
    "maṅgalālambhana": ['mw'],
    "maṅgalālambhanīya": ['mw'],
    "maṅgalālaya": ['mw'],
    "maṅgalālaṃkṛta": ['mw'],
    "maṅgalālāpana": ['mw'],
    "maṅgalārambha": ['mw'],
    "maṅgalārcanapaddhati": ['mw'],
    "maṅgalārha": ['mw'],
    "maṅgalārjuna": ['mw'],
    "maṅgalārtham": ['cae', 'mw'],
    "maṅgalāssa": ['cped'],
    "maṅgalātodya": ['mw'],
    "maṅgalāvaha": ['mw'],
    "maṅgalāvaṭa": ['mw'],
    "maṅgalāvrata": ['mw'],
    "maṅgalāvāsa": ['mw'],
    "maṅgalāya": ['mw'],
    "maṅgalāyana": ['mw'],
    "maṅgalāśāstra": ['mw'],
    "maṅgalāṣṭaka": ['mw'],
    "maṅgalī": ['mw'],
    "maṅgalīya": ['cae', 'ddsa', 'mw'],
    "maṅgh": ['mw'],
    "maṅginī": ['cae', 'mw'],
    "maṅgu": ['bhs', 'cae', 'mw'],
    "maṅgula": ['bhs', 'mw'],
    "maṅgura": ['cped', 'mw'],
    "maṅgusa": ['bhs'],
    "maṅguṣa": ['mw'],
    "maṅgīra": ['cae', 'mw'],
    "maṅk": ['mw'],
    "maṅkaṇaka": ['cae', 'ddsa', 'mw'],
    "maṅkh": ['mw'],
    "maṅkha": ['cae', 'ddsa', 'mw'],
    "maṅkhaka": ['mw'],
    "maṅkhakośa": ['mw'],
    "maṅkhanā": ['mw'],
    "maṅkhuṇa": ['mw'],
    "maṅkhāya": ['mw'],
    "maṅki": ['cae', 'mw'],
    "maṅkigīta": ['mw'],
    "maṅkila": ['mw'],
    "maṅktavya": ['cae', 'ddsa', 'mw'],
    "maṅktṛ": ['mw'],
    "maṅku": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "maṅkubhāva": ['cped'],
    "maṅkubhūta": ['cped'],
    "maṅkura": ['mw'],
    "maṅkuśa": ['mw'],
    "maṅkṣaṇa": ['mw'],
    "maṅkṣu": ['cae', 'ddsa', 'mw'],
    "maṇ": ['ap90', 'mw'],
    "maṇa": ['cae', 'mw'],
    "maṇaū": ['mw'],
    "maṇi": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "maṇibandha": ['cae', 'cped', 'mw'],
    "maṇibandhana": ['cae', 'mw'],
    "maṇibhadra": ['cae', 'mw'],
    "maṇibhadraka": ['mw'],
    "maṇibhava": ['mw'],
    "maṇibhitti": ['mw'],
    "maṇibhārava": ['mw'],
    "maṇibhū": ['mw'],
    "maṇibhūmi": ['bhs', 'mw'],
    "maṇibhūmikākarman": ['mw'],
    "maṇibīja": ['mw'],
    "maṇicakra": ['bhs'],
    "maṇicakravicitrapratimaṇḍitavyūhā": ['bhs'],
    "maṇicchidrā": ['mw'],
    "maṇicīra": ['mw'],
    "maṇicūḍa": ['bhs', 'mw'],
    "maṇicūḍā": ['bhs', 'mw'],
    "maṇidara": ['mw'],
    "maṇidarpaṇa": ['mw'],
    "maṇidatta": ['mw'],
    "maṇidaṇḍa": ['mw'],
    "maṇidhanu": ['cae', 'mw'],
    "maṇidhanus": ['mw'],
    "maṇidhara": ['mw'],
    "maṇidharā": ['bhs', 'mw'],
    "maṇidhāna": ['mw'],
    "maṇidhāriṇī": ['bhs', 'mw'],
    "maṇidhāva": ['mw'],
    "maṇidoṣa": ['mw'],
    "maṇidvīpa": ['mw'],
    "maṇidīdhiti": ['mw'],
    "maṇidīdhitigūḍhārthaprakāśikā": ['mw'],
    "maṇidīkṣitīya": ['mw'],
    "maṇidīpa": ['mw'],
    "maṇidīpaka": ['mw'],
    "maṇigarbha": ['bhs', 'mw'],
    "maṇigarbharājaśritejavatī": ['bhs'],
    "maṇigaṇa": ['mw'],
    "maṇighaṇṭākṛtanyāyaratnaprakaraṇa": ['mw'],
    "maṇigrantha": ['mw'],
    "maṇigrāma": ['mw'],
    "maṇigrīva": ['gra', 'mw'],
    "maṇiguṇanikara": ['mw'],
    "maṇiharmya": ['cae', 'mw'],
    "maṇijalā": ['mw'],
    "maṇika": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "maṇikarṇa": ['bhs', 'mw'],
    "maṇikarṇeśvara": ['mw'],
    "maṇikarṇikā": ['cae', 'mw'],
    "maṇikarṇikāmahiman": ['mw'],
    "maṇikarṇikāmāhātmya": ['mw'],
    "maṇikarṇikāstotra": ['mw'],
    "maṇikarṇikāṣṭaka": ['mw'],
    "maṇikarṇī": ['mw'],
    "maṇikarṇīśvara": ['mw'],
    "maṇikaḥ": ['ap90'],
    "maṇikaṇṭha": ['bhs', 'mw'],
    "maṇikaṇṭhaka": ['mw'],
    "maṇiketu": ['bhs', 'mw'],
    "maṇikhaṇḍadvayatraya": ['mw'],
    "maṇikkhandha": ['cped'],
    "maṇikusuma": ['mw'],
    "maṇikuṇḍala": ['cped'],
    "maṇikuṇḍaladhara": ['bhs'],
    "maṇikuṭṭikā": ['mw'],
    "maṇikāca": ['mw'],
    "maṇikānana": ['bhs', 'mw'],
    "maṇikāra": ['cae', 'cped', 'mw'],
    "maṇikāraka": ['bhs'],
    "maṇikāñcana": ['mw'],
    "maṇikāñcanaprameyasaṃgraha": ['mw'],
    "maṇikāṇa": ['bhs'],
    "maṇikūṭa": ['mw'],
    "maṇikṛt": ['mw'],
    "maṇila": ['cae', 'mw'],
    "maṇiliṅgeśvara": ['mw'],
    "maṇimadhya": ['mw'],
    "maṇimaheśa": ['mw'],
    "maṇimakuṭa": ['bhs'],
    "maṇimant": ['cae'],
    "maṇimanta": ['bhs'],
    "maṇimantha": ['mw'],
    "maṇimat": ['ap90', 'mw'],
    "maṇimatī": ['mw'],
    "maṇimaya": ['cae', 'cped', 'mw'],
    "maṇimayabhū": ['mw'],
    "maṇimayīpurī": ['mw'],
    "maṇimañjarī": ['mw'],
    "maṇimañjarīchedinī": ['mw'],
    "maṇimaṇḍapa": ['mw'],
    "maṇimaṇḍapamāhātmya": ['mw'],
    "maṇimaṇḍita": ['mw'],
    "maṇimegha": ['mw'],
    "maṇimekhala": ['mw'],
    "maṇimeruvirocanadhvajapradīpā": ['bhs'],
    "maṇimiśra": ['mw'],
    "maṇimuktā": ['mw'],
    "maṇimāhātmya": ['mw'],
    "maṇimālā": ['cae', 'mw'],
    "maṇinanda": ['mw'],
    "maṇiniryātana": ['mw'],
    "maṇināga": ['cae', 'mw'],
    "maṇipadma": ['mw'],
    "maṇipallaṅka": ['cped'],
    "maṇiparvata": ['mw'],
    "maṇiparīkṣā": ['mw'],
    "maṇipaticaritra": ['mw'],
    "maṇiprabhā": ['mw'],
    "maṇipradāna": ['mw'],
    "maṇipradīpa": ['mw'],
    "maṇiprakāśa": ['mw'],
    "maṇiprakāśakadīpti": ['mw'],
    "maṇiprakāśikā": ['mw'],
    "maṇiprastha": ['bhs', 'mw'],
    "maṇiprastāraka": ['bhs'],
    "maṇipratyakṣa": ['mw'],
    "maṇipraveka": ['mw'],
    "maṇipravāla": ['mw'],
    "maṇipuccha": ['mw'],
    "maṇipura": ['mw'],
    "maṇipurapureśvara": ['mw'],
    "maṇipuṣpaka": ['cae', 'mw'],
    "maṇipuṣpeśvara": ['mw'],
    "maṇipālī": ['mw'],
    "maṇipūra": ['cae', 'mw'],
    "maṇipūraka": ['mw'],
    "maṇipūrapati": ['mw'],
    "maṇipūrapura": ['mw'],
    "maṇipūravibhedana": ['mw'],
    "maṇipūreśvara": ['mw'],
    "maṇiradana": ['mw'],
    "maṇirata": ['mw'],
    "maṇiratana": ['cped'],
    "maṇiratna": ['cae', 'mw'],
    "maṇiratnagarbha": ['bhs'],
    "maṇiratnamaya": ['cae', 'mw'],
    "maṇiratnamālā": ['mw'],
    "maṇiratnasuvarṇin": ['mw'],
    "maṇiratnavant": ['cae'],
    "maṇiratnavat": ['mw'],
    "maṇiratnākara": ['mw'],
    "maṇirocanī": ['bhs', 'mw'],
    "maṇirāga": ['mw'],
    "maṇirāja": ['bhs', 'mw'],
    "maṇirāma": ['mw'],
    "maṇirāmakṛṣṇadīkṣitīya": ['mw'],
    "maṇirūpya": ['mw'],
    "maṇisappa": ['cped'],
    "maṇisara": ['mw'],
    "maṇisaupāna": ['mw'],
    "maṇiskandha": ['mw'],
    "maṇisopāna": ['mw'],
    "maṇisraj": ['cae', 'mw'],
    "maṇistambha": ['cae', 'mw'],
    "maṇisumeru": ['bhs'],
    "maṇisumeruśrī": ['bhs'],
    "maṇisuta": ['bhs'],
    "maṇisānu": ['mw'],
    "maṇisāra": ['mw'],
    "maṇisāradarpaṇa": ['mw'],
    "maṇisārakhaṇḍana": ['mw'],
    "maṇisāraprāmāṇyavāda": ['mw'],
    "maṇisūryacandravidyotitaprabhā": ['bhs'],
    "maṇisūryaprabhāsagarbhā": ['bhs'],
    "maṇisūtra": ['cae', 'mw'],
    "maṇita": ['cae', 'mw'],
    "maṇitaṃ": ['ap90'],
    "maṇitsaru": ['mw'],
    "maṇittha": ['mw'],
    "maṇitthavarṣaphala": ['mw'],
    "maṇitulākoṭi": ['mw'],
    "maṇituṇḍaka": ['mw'],
    "maṇitāraka": ['mw'],
    "maṇiva": ['mw'],
    "maṇivara": ['mw'],
    "maṇivarman": ['mw'],
    "maṇivarṇa": ['bhs'],
    "maṇivatī": ['bhs'],
    "maṇivaṇṇa": ['cped'],
    "maṇiviraja": ['bhs'],
    "maṇiviśeṣa": ['mw'],
    "maṇiviṣa": ['bhs'],
    "maṇiviṣāṇa": ['bhs'],
    "maṇivāhana": ['mw'],
    "maṇivāla": ['mw'],
    "maṇiyaṣṭi": ['cae', 'mw'],
    "maṇiśabda": ['mw'],
    "maṇiśaila": ['mw'],
    "maṇiśara": ['mw'],
    "maṇiśaṅkhaśarkara": ['mw'],
    "maṇiśekhara": ['mw'],
    "maṇiśilā": ['mw'],
    "maṇiśyāma": ['mw'],
    "maṇiśṛṅga": ['mw'],
    "maṇiḥ": ['ap90'],
    "maṇyāloka": ['mw'],
    "maṇyālokakaṇṭakoddhāra": ['mw'],
    "maṇīca": ['mw'],
    "maṇīcaka": ['mw'],
    "maṇīcakaḥ": ['ap90'],
    "maṇīndra": ['cae', 'ddsa', 'mw'],
    "maṇīvaka": ['mw'],
    "maṇīvakaṃ": ['ap90'],
    "maṇīvatī": ['mw'],
    "maṇīya": ['ddsa', 'mw'],
    "maṇīśvaratīrtha": ['mw'],
    "maṇḍ": ['cae', 'mw'],
    "maṇḍa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "maṇḍacitra": ['mw'],
    "maṇḍahāraka": ['mw'],
    "maṇḍajāta": ['mw'],
    "maṇḍaka": ['bhs', 'cae', 'mw'],
    "maṇḍakarṇa": ['mw'],
    "maṇḍakuṇḍa": ['mw'],
    "maṇḍala": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "maṇḍalabandha": ['mw'],
    "maṇḍalabhāga": ['mw'],
    "maṇḍalabrāhmaṇa": ['mw'],
    "maṇḍalabrāhmaṇopaniṣad": ['mw'],
    "maṇḍalacihna": ['mw'],
    "maṇḍalaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "maṇḍalakarājan": ['mw'],
    "maṇḍalakavi": ['mw'],
    "maṇḍalakārmuka": ['mw'],
    "maṇḍalamāla": ['cped'],
    "maṇḍalamāḍa": ['bhs', 'mw'],
    "maṇḍalanyāsa": ['cae', 'mw'],
    "maṇḍalanābhi": ['mw'],
    "maṇḍalanābhitā": ['mw'],
    "maṇḍalanṛtya": ['mw'],
    "maṇḍalapattrikā": ['mw'],
    "maṇḍalapucchaka": ['mw'],
    "maṇḍalatva": ['mw'],
    "maṇḍalavartin": ['mw'],
    "maṇḍalavarṣa": ['mw'],
    "maṇḍalavaṭa": ['mw'],
    "maṇḍalavāṭa": ['bhs', 'mw'],
    "maṇḍalaya": ['mw'],
    "maṇḍalaśas": ['mw'],
    "maṇḍaleśa": ['cae', 'ddsa', 'mw'],
    "maṇḍaleśvara": ['cae', 'mw'],
    "maṇḍaleṣṭakā": ['mw'],
    "maṇḍalika": ['bhs', 'cped', 'mw'],
    "maṇḍalikā": ['ddsa', 'mw'],
    "maṇḍalin": ['bhs', 'cae', 'mw'],
    "maṇḍalinī": ['mw'],
    "maṇḍalipattrikā": ['mw'],
    "maṇḍalissara": ['cped'],
    "maṇḍalita": ['cae', 'mw'],
    "maṇḍalitahastakāṇḍa": ['mw'],
    "maṇḍalottama": ['mw'],
    "maṇḍalābhiṣekapūjā": ['mw'],
    "maṇḍalādhipa": ['mw'],
    "maṇḍalādhīśa": ['mw'],
    "maṇḍalāgra": ['ddsa', 'mw'],
    "maṇḍalāgāra": ['mw'],
    "maṇḍalārcana": ['mw'],
    "maṇḍalāsana": ['bhs', 'ddsa', 'mw'],
    "maṇḍalāya": ['ddsa', 'mw'],
    "maṇḍalī": ['cped', 'mw'],
    "maṇḍalībhāva": ['mw'],
    "maṇḍalībhūta": ['mw'],
    "maṇḍalīkaraṇa": ['mw'],
    "maṇḍalīkāram": ['mw'],
    "maṇḍalīkṛ": ['cae', 'ddsa'],
    "maṇḍalīkṛta": ['mw'],
    "maṇḍalīnṛtya": ['mw'],
    "maṇḍalīśa": ['mw'],
    "maṇḍamaya": ['mw'],
    "maṇḍamā": ['bhs'],
    "maṇḍamāla": ['cped'],
    "maṇḍana": ['cae', 'cped', 'ddsa', 'mw'],
    "maṇḍanadeva": ['mw'],
    "maṇḍanajātika": ['cped'],
    "maṇḍanaka": ['mw'],
    "maṇḍanakāla": ['mw'],
    "maṇḍanakārikā": ['mw'],
    "maṇḍanapriya": ['mw'],
    "maṇḍanārha": ['mw'],
    "maṇḍanīya": ['bhs'],
    "maṇḍapa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "maṇḍapadruma": ['mw'],
    "maṇḍapakṣetra": ['mw'],
    "maṇḍapanirṇaya": ['mw'],
    "maṇḍapapratiṣṭhā": ['mw'],
    "maṇḍapapūjāvidhi": ['mw'],
    "maṇḍapavāḍa": ['bhs'],
    "maṇḍapeya": ['bhs'],
    "maṇḍapikā": ['cae', 'ddsa', 'mw'],
    "maṇḍapā": ['mw'],
    "maṇḍapāroha": ['mw'],
    "maṇḍapīṭhikā": ['mw'],
    "maṇḍapūla": ['bhs', 'mw'],
    "maṇḍara": ['bhs', 'mw'],
    "maṇḍarava": ['bhs'],
    "maṇḍarī": ['mw'],
    "maṇḍavya": ['bhs'],
    "maṇḍavāṭa": ['bhs', 'mw'],
    "maṇḍavī": ['bhs'],
    "maṇḍayanta": ['mw'],
    "maṇḍayantī": ['mw'],
    "maṇḍayitnu": ['mw'],
    "maṇḍesi": ['cped'],
    "maṇḍeti": ['cped'],
    "maṇḍetvā": ['cped'],
    "maṇḍika": ['mw'],
    "maṇḍita": ['cped', 'ddsa', 'mw'],
    "maṇḍitaka": ['bhs'],
    "maṇḍitaputra": ['mw'],
    "maṇḍitṛ": ['cae', 'mw'],
    "maṇḍodaka": ['ddsa', 'mw'],
    "maṇḍu": ['cae', 'mw'],
    "maṇḍuka": ['bhs', 'cped', 'ddsa', 'mw'],
    "maṇḍukeya": ['mw'],
    "maṇḍukī": ['mw'],
    "maṇḍā": ['mw'],
    "maṇḍānupūrvī": ['bhs'],
    "maṇḍīlaka": ['bhs', 'mw'],
    "maṇḍūka": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "maṇḍūkabrahmīkalpa": ['mw'],
    "maṇḍūkagati": ['mw'],
    "maṇḍūkagatilālasa": ['mw'],
    "maṇḍūkakula": ['mw'],
    "maṇḍūkamātṛ": ['mw'],
    "maṇḍūkaparṇa": ['mw'],
    "maṇḍūkaparṇikā": ['mw'],
    "maṇḍūkaparṇī": ['mw'],
    "maṇḍūkapluta": ['mw'],
    "maṇḍūkaplutasādhana": ['mw'],
    "maṇḍūkapluti": ['cae', 'mw'],
    "maṇḍūkasarasa": ['mw'],
    "maṇḍūkayoga": ['mw'],
    "maṇḍūkayoganiyata": ['mw'],
    "maṇḍūkayogaśayana": ['mw'],
    "maṇḍūkaśikṣā": ['mw'],
    "maṇḍūkaśāyin": ['mw'],
    "maṇḍūkikā": ['cae', 'mw'],
    "maṇḍūkānuvṛtti": ['mw'],
    "maṇḍūkī": ['gra', 'mw'],
    "maṇḍūra": ['cae', 'gra', 'mw'],
    "maṇḍūradhāṇika": ['gra'],
    "maṇḍūradhāṇikī": ['mw'],
    "maṇṭ": ['mw'],
    "maṇṭapa": ['mw'],
    "maṇṭapī": ['mw'],
    "maṇṭh": ['mw'],
    "maṇṭha": ['mw'],
    "maṇṭhaka": ['mw'],
    "maṇṭi": ['mw'],
    "maṣ": ['ap90', 'mw'],
    "maṣam": ['ddsa', 'mw'],
    "maṣi": ['cae', 'ddsa', 'mw'],
    "maṣidhāna": ['mw'],
    "maṣighaṭī": ['mw'],
    "maṣijala": ['mw'],
    "maṣikūpī": ['mw'],
    "maṣimaṇi": ['mw'],
    "maṣipatha": ['mw'],
    "maṣipaṇya": ['mw'],
    "maṣiprasū": ['mw'],
    "maṣivardhana": ['mw'],
    "maṣiḥ": ['ap90'],
    "maṣk": ['mw'],
    "maṣmaṣākṛ": ['mw'],
    "maṣy": ['mw'],
    "maṣyabhāva": ['mw'],
    "maṣyabhāvāt": ['mw'],
    "maṣyādhāra": ['mw'],
    "maṣī": ['cae', 'mw'],
    "maṣībhāvuka": ['mw'],
    "maṣībhāṇḍa": ['mw'],
    "maṣīdhanī": ['mw'],
    "maṣīguḍikā": ['mw'],
    "maṣījala": ['mw'],
    "maṣīkūrcaka": ['mw'],
    "maṣīlipta": ['mw'],
    "maṣīmaya": ['mw'],
    "maṣīpātra": ['mw'],
    "maṣīvarṇa": ['mw'],
    "maṣṇāra": ['ddsa', 'mw'],
    "maṣṭa": ['bhs'],
    "maṭa": ['mw'],
    "maṭacī": ['ap90', 'cae', 'ddsa', 'mw'],
    "maṭacīhata": ['mw'],
    "maṭaka": ['cae', 'ddsa', 'mw'],
    "maṭamaṭāya": ['mw'],
    "maṭatī": ['mw'],
    "maṭh": ['ap90', 'mw'],
    "maṭha": ['cae', 'ddsa', 'mw'],
    "maṭhacintā": ['mw'],
    "maṭhakeśavadhāriṇī": ['mw'],
    "maṭhapratiṣṭhātattva": ['mw'],
    "maṭhara": ['ap90', 'ddsa', 'mw'],
    "maṭhasthiti": ['mw'],
    "maṭhaya": ['ddsa', 'mw'],
    "maṭhaḥ": ['ap90'],
    "maṭhikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "maṭhośiloṭhikā": ['mw'],
    "maṭhośīloṭhikā": ['ddsa'],
    "maṭhādhipati": ['ddsa', 'mw'],
    "maṭhādhyakṣa": ['mw'],
    "maṭhāyatana": ['cae', 'mw'],
    "maṭmaṭa": ['mw'],
    "maṭusphaṭi": ['mw'],
    "maṭusphaṭiḥ": ['ap90'],
    "maṭutacaṇḍī": ['mw'],
    "maṭūṣikā": ['mw'],
    "maṭṭa": ['cped', 'ddsa', 'mw'],
    "maṭṭaka": ['mw'],
    "maṭṭakaṃ": ['ap90'],
    "maṭṭanṛtya": ['mw'],
    "maṭṭasāṭaka": ['cped'],
    "maṭṭha": ['cped'],
    "mdha, adhā": ['ddsa'],
    "mdharoṣṭha, adharauṣṭha": ['ddsa'],
    "me": ['ap90', 'cped', 'ddsa', 'mw'],
    "meb": ['mw'],
    "meca": ['mw'],
    "mecaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mecakacātanī": ['mw'],
    "mecakagala": ['mw'],
    "mecakita": ['mw'],
    "mecakābhidhā": ['mw'],
    "mecakāpagā": ['mw'],
    "mecaṭika": ['mw'],
    "mecurudi": ['mw'],
    "med": ['ddsa', 'mw'],
    "meda": ['cae', 'cped', 'ddsa', 'mw'],
    "medabhilla": ['mw'],
    "medaja": ['mw'],
    "medaka": ['mw'],
    "medakathālikā": ['cped'],
    "medakaḥ": ['ap90'],
    "medakṛt": ['mw'],
    "medana": ['cae', 'gra', 'mw'],
    "medapāṭa": ['ddsa', 'mw'],
    "medapāṭha": ['mw'],
    "medas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "medaskṛt": ['mw'],
    "medaspiṇḍa": ['mw'],
    "medastas": ['mw'],
    "medastejas": ['mw'],
    "medasvant": ['cae'],
    "medasvat": ['mw'],
    "medasvin": ['ap90', 'cae', 'ddsa', 'mw'],
    "medavaṇṇa": ['cped'],
    "medaāhuti": ['mw'],
    "medaś": ['mw'],
    "medaścheda": ['mw'],
    "medaśiras": ['mw'],
    "medaḥ": ['ap90', 'mw'],
    "medaḥpuccha": ['ddsa', 'mw'],
    "medaḥpucchaka": ['mw'],
    "medaḥsāra": ['mw'],
    "medaḥsārā": ['mw'],
    "medh": ['ap90', 'ddsa', 'mw'],
    "medha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "medhaga": ['cped'],
    "medhaja": ['ddsa', 'mw'],
    "medhajit": ['mw'],
    "medhapati": ['cae', 'ddsa', 'gra', 'mw'],
    "medhas": ['cae', 'ddsa', 'gra', 'mw'],
    "medhasa": ['mw'],
    "medhasāti": ['cae', 'ddsa', 'gra', 'mw'],
    "medhayu": ['gra', 'mw'],
    "medhaḥ": ['ap90'],
    "medhi": ['ap90', 'cae', 'mw'],
    "medhia": ['gra'],
    "medhin": ['cae', 'mw'],
    "medhira": ['cae', 'ddsa', 'gra', 'mw'],
    "medhiātithi": ['gra'],
    "medhiṣṭha": ['mw'],
    "medhya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "medhyamandira": ['mw'],
    "medhyamaya": ['mw'],
    "medhyatama": ['mw'],
    "medhyatara": ['mw'],
    "medhyatva": ['mw'],
    "medhyatā": ['cae', 'mw'],
    "medhyā": ['mw'],
    "medhyātithi": ['cae', 'ddsa', 'gra', 'mw'],
    "medhā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "medhācakra": ['mw'],
    "medhādhṛti": ['mw'],
    "medhājanana": ['cae', 'mw'],
    "medhājit": ['mw'],
    "medhākāma": ['mw'],
    "medhākāra": ['gra', 'mw'],
    "medhākṛt": ['mw'],
    "medhāmṛti": ['mw'],
    "medhārudra": ['mw'],
    "medhāsūkta": ['mw'],
    "medhātithi": ['cae', 'ddsa', 'gra', 'mw'],
    "medhāvara": ['mw'],
    "medhāvat": ['ap90', 'mw'],
    "medhāvatī": ['ddsa', 'mw'],
    "medhāvika": ['bhs', 'mw'],
    "medhāvin": ['ap90', 'cae', 'mw'],
    "medhāvinī": ['cped', 'mw'],
    "medhāvirudra": ['mw'],
    "medhāvitā": ['mw'],
    "medhāvī": ['cped'],
    "medhī": ['bhs', 'cae', 'mw'],
    "medhīyas": ['mw'],
    "medin": ['cae', 'ddsa', 'gra', 'mw'],
    "medinī": ['ap90', 'cped', 'ddsa', 'mw'],
    "medinīdhara": ['mw'],
    "medinīdina": ['mw'],
    "medinīdrava": ['mw'],
    "medinīdāna": ['mw'],
    "medinīja": ['mw'],
    "medinīkara": ['mw'],
    "medinīkośa": ['mw'],
    "medinīnandana": ['mw'],
    "medinīpati": ['cae', 'mw'],
    "medinīśa": ['cae', 'mw'],
    "medinīśatantra": ['mw'],
    "medo": ['mw'],
    "medobhava": ['mw'],
    "medobhavā": ['mw'],
    "medodbhavā": ['mw'],
    "medodharā": ['mw'],
    "medodoṣa": ['ddsa', 'mw'],
    "medogala": ['mw'],
    "medogaṇḍa": ['mw'],
    "medoghna": ['mw'],
    "medogranthi": ['mw'],
    "medoja": ['mw'],
    "medorbuda": ['mw'],
    "medoroga": ['mw'],
    "medorūpa": ['mw'],
    "medovaha": ['mw'],
    "medovatī": ['mw'],
    "medovṛddhi": ['mw'],
    "medura": ['ap90', 'cae', 'ddsa', 'mw'],
    "medurita": ['ap90', 'mw'],
    "medurā": ['mw'],
    "medya": ['ap90', 'cae', 'ddsa', 'mw'],
    "medā": ['mw'],
    "medī": ['mw'],
    "megha": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "meghabaddha": ['mw'],
    "meghabala": ['mw'],
    "meghabhagīrathaṭhakkura": ['mw'],
    "meghabhaṭṭa": ['mw'],
    "meghabhūti": ['mw'],
    "meghacandraśiṣya": ['mw'],
    "meghacintaka": ['mw'],
    "meghadatta": ['bhs'],
    "meghadundubhi": ['mw'],
    "meghadundubhinirghoṣa": ['mw'],
    "meghadundubhirāvin": ['mw'],
    "meghadundubhisvararāja": ['bhs', 'mw'],
    "meghadvāra": ['mw'],
    "meghadīpa": ['mw'],
    "meghadūta": ['cae', 'mw'],
    "meghadūtapādasamasyā": ['mw'],
    "meghadūtābhidha": ['mw'],
    "meghadūtārthamuktāvalī": ['mw'],
    "meghadūtāvacūri": ['mw'],
    "meghagambhīra": ['mw'],
    "meghagarjana": ['mw'],
    "meghagarjanavidhi": ['mw'],
    "meghagarjanā": ['mw'],
    "meghagarjitaghoṣatā": ['mw'],
    "meghagiri": ['mw'],
    "meghahrāda": ['mw'],
    "meghahīna": ['mw'],
    "meghahṛt": ['mw'],
    "meghajyotis": ['mw'],
    "meghajā": ['mw'],
    "meghajāla": ['mw'],
    "meghajīvaka": ['mw'],
    "meghajīvana": ['mw'],
    "meghakapha": ['mw'],
    "meghakarṇā": ['mw'],
    "meghakumāracarita": ['mw'],
    "meghakumāradeva": ['mw'],
    "meghakāla": ['cae', 'mw'],
    "meghakālī": ['mw'],
    "meghakūṭābhigarjitasvara": ['bhs'],
    "meghakūṭābhigarjiteśvara": ['mw'],
    "meghalatā": ['mw'],
    "meghalekhā": ['cae', 'mw'],
    "meghamaya": ['mw'],
    "meghamañjarī": ['mw'],
    "meghamaṇḍala": ['mw'],
    "meghamaṭha": ['mw'],
    "meghamedura": ['mw'],
    "meghamillārikā": ['mw'],
    "meghamodinī": ['mw'],
    "meghamāla": ['mw'],
    "meghamālin": ['bhs', 'mw'],
    "meghamālā": ['cae', 'mw'],
    "meghamāna": ['mw'],
    "meghamārga": ['mw'],
    "meghanibha": ['cped'],
    "meghanirghoṣa": ['cae', 'mw'],
    "meghanirghoṣasvara": ['bhs'],
    "meghanāda": ['cae', 'cped', 'mw'],
    "meghanādajit": ['mw'],
    "meghanādamaṇḍapa": ['mw'],
    "meghanādatīrtha": ['mw'],
    "meghanādin": ['cae', 'mw'],
    "meghanādā": ['mw'],
    "meghanādānulāsaka": ['mw'],
    "meghanādānulāsin": ['mw'],
    "meghanādāri": ['mw'],
    "meghanāman": ['mw'],
    "meghanīla": ['mw'],
    "meghaparvata": ['mw'],
    "meghapatha": ['mw'],
    "meghapaṅkti": ['mw'],
    "meghapradīpa": ['mw'],
    "meghaprasara": ['mw'],
    "meghaprasava": ['mw'],
    "meghapravāha": ['mw'],
    "meghapuṣpa": ['mw'],
    "meghapālitṛtīyāvrata": ['mw'],
    "meghapṛṣṭha": ['mw'],
    "megharatha": ['mw'],
    "megharava": ['mw'],
    "megharavā": ['mw'],
    "megharaṅgikā": ['mw'],
    "megharaṅgī": ['mw'],
    "megharekhā": ['cae', 'mw'],
    "megharāga": ['mw'],
    "megharāja": ['bhs', 'mw'],
    "megharāji": ['mw'],
    "megharājī": ['cae', 'mw'],
    "megharāva": ['mw'],
    "meghasakha": ['mw'],
    "meghasambhava": ['mw'],
    "meghasaṃbhava": ['bhs'],
    "meghasaṃcodana": ['bhs'],
    "meghasaṃdeśa": ['mw'],
    "meghasaṃdhi": ['mw'],
    "meghasaṃghāta": ['mw'],
    "meghaskandin": ['mw'],
    "meghastanita": ['mw'],
    "meghastanitodbhava": ['mw'],
    "meghasuhṛd": ['mw'],
    "meghasvanā": ['mw'],
    "meghasvara": ['bhs', 'mw'],
    "meghasvaradīpa": ['bhs'],
    "meghasvararāja": ['bhs', 'mw'],
    "meghasvāti": ['mw'],
    "meghasāra": ['mw'],
    "meghasūtra": ['bhs'],
    "meghataru": ['mw'],
    "meghatimira": ['mw'],
    "meghatva": ['mw'],
    "meghaunmukhya": ['mw'],
    "meghavahni": ['mw'],
    "meghavana": ['mw'],
    "meghavapus": ['mw'],
    "meghavartman": ['mw'],
    "meghavarṇa": ['mw'],
    "meghavarṇā": ['mw'],
    "meghavarṣa": ['mw'],
    "meghavat": ['mw'],
    "meghavatī": ['bhs'],
    "meghavaṇṇa": ['cped'],
    "meghavega": ['mw'],
    "meghaveśman": ['mw'],
    "meghavijaya": ['mw'],
    "meghavilambita": ['bhs'],
    "meghavisphūrjita": ['mw'],
    "meghavisphūrjitā": ['mw'],
    "meghavitāna": ['mw'],
    "meghavāhana": ['mw'],
    "meghavāhin": ['mw'],
    "meghavāhinī": ['mw'],
    "meghavāsas": ['mw'],
    "meghavāta": ['cae', 'mw'],
    "meghavṛnda": ['mw'],
    "meghaya": ['mw'],
    "meghayantī": ['mw'],
    "meghayat": ['mw'],
    "meghayati": ['ap90'],
    "meghayoni": ['mw'],
    "meghayāti": ['mw'],
    "meghaśrī": ['bhs'],
    "meghaśyāma": ['mw'],
    "meghaḍambara": ['mw'],
    "meghaḥ": ['ap90'],
    "meghaṃkara": ['ap90', 'mw'],
    "megheśvaranāṭaka": ['mw'],
    "megheśvaratīrtha": ['mw'],
    "meghodaka": ['cae', 'mw'],
    "meghodara": ['mw'],
    "meghodaya": ['cae', 'mw'],
    "meghopala": ['mw'],
    "meghya": ['mw'],
    "meghābha": ['mw'],
    "meghābhyudaya": ['mw'],
    "meghācchanna": ['mw'],
    "meghācchādita": ['mw'],
    "meghādhvan": ['mw'],
    "meghāgama": ['mw'],
    "meghāgamapriya": ['mw'],
    "meghāgaru": ['bhs'],
    "meghākhya": ['mw'],
    "meghākṣa": ['ddsa', 'mw'],
    "meghāloka": ['ddsa', 'mw'],
    "meghānandin": ['mw'],
    "meghānandā": ['mw'],
    "meghānayana": ['mw'],
    "meghānta": ['mw'],
    "meghāri": ['mw'],
    "meghārāva": ['mw'],
    "meghāspada": ['mw'],
    "meghāsthi": ['mw'],
    "meghāvalī": ['mw'],
    "meghāvatata": ['mw'],
    "meghāya": ['ddsa', 'mw'],
    "meghāḍambara": ['mw'],
    "meghāṭopa": ['mw'],
    "meha": ['cae', 'cped', 'ddsa', 'mw'],
    "mehaghnī": ['mw'],
    "mehala": ['mw'],
    "mehamudgararasa": ['mw'],
    "mehana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mehanaṃ": ['ap90'],
    "mehanā": ['cae', 'ddsa', 'gra', 'mw'],
    "mehanāvant": ['cae'],
    "mehanāvat": ['gra', 'mw'],
    "mehapāṭa": ['mw'],
    "mehatnū": ['gra', 'mw'],
    "mehavat": ['mw'],
    "mehaḥ": ['ap90'],
    "mehin": ['cae', 'ddsa', 'mw'],
    "mejjha": ['cped'],
    "meka": ['cae', 'gra', 'mw'],
    "mekala": ['ap90', 'cae', 'ddsa', 'mw'],
    "mekalaka": ['mw'],
    "mekalakanyakā": ['mw'],
    "mekalakanyakātaṭa": ['mw'],
    "mekalaprabhava": ['mw'],
    "mekalaśaila": ['mw'],
    "mekalaśailakanyā": ['mw'],
    "mekalaḥ": ['ap90'],
    "mekalā": ['mw'],
    "mekalādri": ['mw'],
    "mekalādrijā": ['mw'],
    "mekaḥ": ['ap90'],
    "mekhala": ['bhs', 'mw'],
    "mekhalakanyakā": ['mw'],
    "mekhalika": ['mw'],
    "mekhalin": ['ap90', 'cae', 'ddsa', 'mw'],
    "mekhalottha": ['mw'],
    "mekhalā": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "mekhalābandha": ['mw'],
    "mekhalādāman": ['mw'],
    "mekhalāla": ['mw'],
    "mekhalālaḥ": ['ap90'],
    "mekhalāmaṇi": ['mw'],
    "mekhalāpada": ['cae', 'mw'],
    "mekhalāpaddhati": ['mw'],
    "mekhalāvant": ['cae'],
    "mekhalāvat": ['mw'],
    "mekhalāvin": ['mw'],
    "mekhalī": ['bhs'],
    "mekhalīkṛ": ['mw'],
    "mekṣaṇa": ['cae', 'ddsa', 'mw'],
    "mela": ['bhs', 'cae', 'ddsa', 'mw'],
    "melaka": ['cae', 'mw'],
    "melakalavaṇa": ['mw'],
    "melana": ['cae', 'cped', 'mw'],
    "melanaṃ": ['ap90'],
    "melanduka": ['bhs'],
    "melaḥ": ['ap90'],
    "mellati": ['bhs'],
    "melu": ['bhs', 'mw'],
    "meluda": ['bhs', 'mw'],
    "melā": ['ap90', 'bhs', 'mw'],
    "melāmandā": ['mw'],
    "melāmaṇi": ['mw'],
    "melāmbu": ['mw'],
    "melānanda": ['mw'],
    "melānandāya": ['ddsa', 'mw'],
    "melāndhu": ['mw'],
    "melāndhuka": ['mw'],
    "melāpaka": ['ddsa', 'mw'],
    "melāpakaḥ": ['ap90'],
    "melāyana": ['mw'],
    "melāyanaṃ": ['ap90'],
    "mel̤i": ['cae', 'mw'],
    "mema": ['mw'],
    "memiṣa": ['mw'],
    "memyat": ['ddsa', 'mw'],
    "mena": ['mw'],
    "menakā": ['ap90', 'cae', 'ddsa', 'mw'],
    "menakāhita": ['mw'],
    "menakāprāṇeśa": ['mw'],
    "menakātmajā": ['mw'],
    "mendhikā": ['mw'],
    "mendhī": ['mw'],
    "meni": ['cae', 'ddsa', 'gra', 'mw'],
    "menilā": ['ddsa', 'mw'],
    "menula": ['mw'],
    "menā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "menāda": ['mw'],
    "menādaḥ": ['ap90'],
    "menādhava": ['mw'],
    "menājā": ['mw'],
    "mep": ['ap90', 'mw'],
    "meraka": ['bhs', 'mw'],
    "merakaḥ": ['ap90'],
    "meraya": ['cped'],
    "meraṇḍu": ['bhs', 'mw'],
    "meru": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "merubalapramardin": ['bhs', 'mw'],
    "merubhūta": ['mw'],
    "merucandratantra": ['mw'],
    "meruda": ['bhs'],
    "merudevī": ['mw'],
    "merudhvaja": ['bhs', 'mw'],
    "merudhāman": ['mw'],
    "meruduhitṛ": ['mw'],
    "merudṛśvan": ['mw'],
    "merugaṇḍa": ['mw'],
    "meruguru": ['mw'],
    "meruka": ['mw'],
    "merukalpa": ['bhs', 'mw'],
    "merukaḥ": ['ap90'],
    "merukūṭa": ['bhs', 'cae', 'mw'],
    "merumahībhṛt": ['mw'],
    "merumandara": ['mw'],
    "merunanda": ['mw'],
    "meruparvata": ['mw'],
    "meruprabha": ['mw'],
    "meruprabhā": ['bhs'],
    "meruprabhāsa": ['bhs', 'mw'],
    "merupradīpa": ['bhs', 'mw'],
    "merupradīparāja": ['bhs'],
    "meruprastāra": ['mw'],
    "meruputrī": ['mw'],
    "merupṛṣṭha": ['cae', 'mw'],
    "merusarṣapa": ['cae', 'mw'],
    "merususambhava": ['mw'],
    "merususaṃbhava": ['bhs'],
    "merusāvarṇa": ['mw'],
    "merusāvarṇatā": ['mw'],
    "merusāvarṇi": ['mw'],
    "merusāvarṇitā": ['mw'],
    "meruta": ['bhs'],
    "merutantra": ['mw'],
    "merutuṅga": ['mw'],
    "meruvardhana": ['mw'],
    "meruvarṣa": ['mw'],
    "meruvirahatantrebhuvaneśvarīsahasranāmastotra": ['mw'],
    "meruviśuddhavyūhadhvaja": ['bhs'],
    "meruvraja": ['mw'],
    "meruyantra": ['mw'],
    "meruśikharadhara": ['bhs'],
    "meruśikharadharakumārabhūta": ['mw'],
    "meruśrī": ['bhs', 'mw'],
    "meruśrīgarbha": ['bhs', 'mw'],
    "meruśṛṅga": ['mw'],
    "meruḥ": ['ap90'],
    "meruṇḍā": ['mw'],
    "meruṭu": ['bhs'],
    "meruṭū": ['mw'],
    "mervadrikarṇikā": ['mw'],
    "merūdgataśrī": ['bhs'],
    "mesa": ['cped'],
    "meth": ['ap90', 'ddsa', 'mw'],
    "methaka": ['bhs'],
    "methana": ['cae', 'ddsa', 'mw'],
    "methi": ['cae', 'ddsa', 'mw'],
    "methika": ['mw'],
    "methikā": ['ap90', 'mw'],
    "methinī": ['mw'],
    "methiṣṭha": ['mw'],
    "methuna": ['cped'],
    "methunadhamma": ['cped'],
    "methī": ['mw'],
    "metra": ['bhs'],
    "mettacitta": ['cped'],
    "metteyyanātha": ['cped'],
    "metthita": ['mw'],
    "metti": ['cped'],
    "mettā": ['cped'],
    "mettābhāvanā": ['cped'],
    "mettākammaṭṭhāna": ['cped'],
    "mettāvihārī": ['cped'],
    "mettāyanta": ['cped'],
    "mettāyanā": ['cped'],
    "mettāyati": ['cped'],
    "mettāyi": ['cped'],
    "mettāyitvā": ['cped'],
    "metārya": ['mw'],
    "metṛ": ['cae', 'gra', 'mw'],
    "mev": ['ap90', 'mw'],
    "mevārya": ['mw'],
    "meya": ['ap90', 'cae', 'ddsa', 'mw'],
    "meśikā": ['mw'],
    "meśī": ['mw'],
    "meḍ": ['mw'],
    "meḍha": ['mw'],
    "meḍhra": ['cae', 'ddsa', 'mw'],
    "meḍhracarman": ['mw'],
    "meḍhraja": ['mw'],
    "meḍhraka": ['mw'],
    "meḍhrakaḥ": ['ap90'],
    "meḍhranigraha": ['mw'],
    "meḍhraroga": ['mw'],
    "meḍhratvac": ['mw'],
    "meḍhraśṛṅgī": ['mw'],
    "meḍhraḥ": ['ap90'],
    "meḍhī": ['cae', 'mw'],
    "meḍhībhūta": ['mw'],
    "meḍi": ['cae', 'ddsa', 'gra', 'mw'],
    "meḍī": ['bhs'],
    "meḷi": ['ddsa'],
    "meṃdhikā": ['ap90'],
    "meṃḍhaḥ": ['ap90'],
    "meṃḍhraḥ": ['ap90'],
    "meṃṭhaḥ": ['ap90'],
    "meṅganātha": ['mw'],
    "meṇḍa": ['cped', 'mw'],
    "meṇḍaka": ['cped'],
    "meṇḍaviṣāṇikā": ['bhs'],
    "meṇḍha": ['mw'],
    "meṇḍhaka": ['bhs', 'mw'],
    "meṇḍhra": ['ddsa', 'mw'],
    "meṇṭha": ['cae', 'ddsa', 'mw'],
    "meṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "meṣacarman": ['mw'],
    "meṣahṛt": ['mw'],
    "meṣaka": ['bhs', 'mw'],
    "meṣakambala": ['mw'],
    "meṣakusuma": ['mw'],
    "meṣalocana": ['mw'],
    "meṣamāṃsa": ['mw'],
    "meṣapuṣpā": ['mw'],
    "meṣapāla": ['mw'],
    "meṣapālaka": ['mw'],
    "meṣasaṃdhi": ['mw'],
    "meṣavallī": ['mw'],
    "meṣaviṣaṇikā": ['mw'],
    "meṣavāhinī": ['mw'],
    "meṣavṛṣaṇa": ['cae', 'mw'],
    "meṣayūtha": ['mw'],
    "meṣaśṛṅga": ['mw'],
    "meṣaśṛṅgī": ['mw'],
    "meṣaḥ": ['ap90'],
    "meṣikā": ['ap90', 'cae', 'mw'],
    "meṣka": ['cae', 'mw'],
    "meṣā": ['ap90', 'mw'],
    "meṣāhvayā": ['mw'],
    "meṣākṣīkusuma": ['mw'],
    "meṣālu": ['mw'],
    "meṣānana": ['mw'],
    "meṣāntrī": ['mw'],
    "meṣāsya": ['mw'],
    "meṣāya": ['mw'],
    "meṣāyate": ['ap90'],
    "meṣāṇḍa": ['mw'],
    "meṣī": ['ddsa', 'gra', 'mw'],
    "meṣūraṇa": ['mw'],
    "meṭ": ['ap90', 'mw'],
    "meṭa": ['mw'],
    "meṭha": ['ddsa', 'mw'],
    "meṭhaḥ": ['ap90'],
    "meṭhi": ['mw'],
    "meṭhiḥ": ['ap90'],
    "meṭhī": ['mw'],
    "meṭi": ['mw'],
    "meṭulā": ['ap90', 'mw'],
    "meṭī": ['mw'],
    "mi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "miccaka": ['mw'],
    "micch": ['ap90'],
    "micchaka": ['mw'],
    "micchatta": ['cped'],
    "micchā": ['cped'],
    "micchācāra": ['cped'],
    "micchācārī": ['cped'],
    "micchādiṭṭhi": ['cped'],
    "micchāgahaṇa": ['cped'],
    "micchākammanta": ['cped'],
    "micchāpaṇihita": ['cped'],
    "micchāsaṅkappa": ['cped'],
    "micchāvācā": ['cped'],
    "micchāvāyāma": ['cped'],
    "mich": ['mw'],
    "micitā": ['mw'],
    "mid": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "middha": ['bhs', 'cped', 'mw'],
    "middhaṃ": ['ap90'],
    "middhin": ['bhs'],
    "middhī": ['cped'],
    "midh": ['mw'],
    "miga": ['cped'],
    "migachāpaka": ['cped'],
    "migadāya": ['cped'],
    "migaluddaka": ['cped'],
    "migamada": ['cped'],
    "migamātukā": ['cped'],
    "migapotaka": ['cped'],
    "migataṇhikā": ['cped'],
    "migava": ['cped'],
    "migh": ['cae', 'gra', 'mw'],
    "miginda": ['cped'],
    "migī": ['cped'],
    "mih": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mihikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "mihilāropya": ['ddsa', 'mw'],
    "mihira": ['cae', 'ddsa', 'mw'],
    "mihiradatta": ['mw'],
    "mihirakula": ['mw'],
    "mihiralakṣmī": ['mw'],
    "mihirapura": ['mw'],
    "mihirarati": ['mw'],
    "mihiraḥ": ['ap90'],
    "mihireśvara": ['mw'],
    "mihirāpad": ['mw'],
    "mihirāṇa": ['mw'],
    "mihirāṇaḥ": ['ap90'],
    "mihita": ['cped'],
    "mijī": ['bhs'],
    "mikṣ": ['cae', 'ddsa', 'mw'],
    "mil": ['ap90', 'cae', 'ddsa', 'mw'],
    "miladvyādha": ['ddsa', 'mw'],
    "milakkha": ['cped'],
    "milakkhadesa": ['cped'],
    "milana": ['cae', 'ddsa', 'mw'],
    "milanaṃ": ['ap90'],
    "milaspharaṇa": ['bhs'],
    "milat": ['mw'],
    "milikā": ['mw'],
    "milinda": ['cae', 'ddsa', 'mw'],
    "milindaka": ['mw'],
    "milindapraśna": ['mw'],
    "milita": ['ap90', 'cae', 'mw'],
    "miliṃdakaḥ": ['ap90'],
    "miliṃdaḥ": ['ap90'],
    "millati": ['bhs'],
    "millā": ['ddsa', 'mw'],
    "milā": ['mw'],
    "milāta": ['cped'],
    "milātā": ['cped'],
    "milāyamāna": ['cped'],
    "milāyati": ['bhs', 'cped'],
    "milāyi": ['cped'],
    "milāyitvā": ['cped'],
    "milīmilin": ['ap90', 'mw'],
    "mimanthiṣu": ['mw'],
    "mimanthiṣā": ['mw'],
    "mimardayiṣu": ['cae', 'ddsa', 'mw'],
    "mimardiṣu": ['cae', 'mw'],
    "mimata": ['mw'],
    "mimaṅkṣu": ['cae', 'ddsa', 'mw'],
    "mimaṅkṣā": ['mw'],
    "mime": ['ddsa'],
    "mimikṣ": ['mw'],
    "mimikṣa": ['cae', 'mw'],
    "mimikṣu": ['cae', 'gra', 'mw'],
    "mimikṣuḥ": ['ddsa'],
    "mimārayiṣu": ['ddsa', 'mw'],
    "mimīyāt": ['ddsa'],
    "mind": ['mw'],
    "mindā": ['cae', 'ddsa', 'mw'],
    "mindāhuti": ['mw'],
    "minmina": ['mw'],
    "minna": ['ap90', 'mw'],
    "minv": ['ap90', 'mw'],
    "minvat": ['ddsa'],
    "mirahu": ['bhs'],
    "mirapha": ['mw'],
    "mirava": ['bhs'],
    "mirikā": ['mw'],
    "mirmira": ['mw'],
    "mirā": ['mw'],
    "mirākhāna": ['mw'],
    "mis": ['mw'],
    "misara": ['mw'],
    "misaru": ['mw'],
    "misarumiśra": ['mw'],
    "misi": ['cae', 'mw'],
    "misr": ['mw'],
    "missa": ['cped'],
    "missaka": ['cped'],
    "missenta": ['cped'],
    "missesi": ['cped'],
    "misseti": ['cped'],
    "missetvā": ['cped'],
    "missita": ['cped'],
    "mit": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "mitabhojana": ['cae'],
    "mitabhuj": ['cae', 'mw'],
    "mitabhukta": ['cae', 'mw'],
    "mitabhāṇī": ['cped'],
    "mitabhāṣin": ['cae', 'mw'],
    "mitabhāṣitva": ['mw'],
    "mitabhāṣitṛ": ['cae', 'ddsa', 'mw'],
    "mitabhāṣiṇī": ['mw'],
    "mitadakṣiṇa": ['mw'],
    "mitadhvaja": ['mw'],
    "mitadru": ['cae', 'gra', 'mw'],
    "mitajñu": ['cae', 'ddsa', 'gra', 'mw'],
    "mitamati": ['mw'],
    "mitamedha": ['gra', 'mw'],
    "mitampaca": ['ddsa', 'mw'],
    "mitaprakāśikā": ['mw'],
    "mitarocin": ['mw'],
    "mitarāvin": ['mw'],
    "mitavyayin": ['mw'],
    "mitavāc": ['mw'],
    "mitavārṣika": ['bhs'],
    "mitaśāyin": ['ddsa', 'mw'],
    "mitaṃgama": ['ap90', 'mw'],
    "mitaṃpaca": ['ap90'],
    "mith": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mitha": ['mw'],
    "mithas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mithasavadyapa": ['gra'],
    "mithaspṛdhya": ['gra', 'mw'],
    "mithastur": ['gra', 'mw'],
    "mithati": ['gra'],
    "mithatyā": ['cae', 'mw'],
    "mithaḥ": ['mw'],
    "mithaḥkṛtya": ['mw'],
    "mithaḥprasthāna": ['cae', 'mw'],
    "mithaḥsamavāya": ['cae'],
    "mithaḥsamaya": ['cae', 'mw'],
    "mithaḥspṛdhya": ['cae'],
    "mithi": ['mw'],
    "mithila": ['cae', 'ddsa', 'mw'],
    "mithilaḥ": ['ap90'],
    "mithileśa": ['mw'],
    "mithileśacarita": ['mw'],
    "mithileśāhnika": ['mw'],
    "mithilā": ['ap90', 'mw'],
    "mithilādhipati": ['mw'],
    "mithita": ['mw'],
    "mitho": ['mw'],
    "mithoavadyapa": ['gra', 'mw'],
    "mithoviniyoga": ['mw'],
    "mithoyodha": ['mw'],
    "mithu": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "mithubheda": ['cped'],
    "mithuna": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mithunabhāva": ['mw'],
    "mithunatva": ['mw'],
    "mithunavratin": ['mw'],
    "mithunayamaka": ['mw'],
    "mithunayoni": ['mw'],
    "mithunecara": ['mw'],
    "mithunecaraḥ": ['ap90'],
    "mithunin": ['mw'],
    "mithunāya": ['mw'],
    "mithunāyate": ['ap90'],
    "mithunī": ['mw'],
    "mithunīas": ['mw'],
    "mithunībhāva": ['mw'],
    "mithunībhāvaḥ": ['ap90'],
    "mithunībhū": ['ap90', 'mw'],
    "mithunīcārin": ['ddsa', 'mw'],
    "mithunīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "mithus": ['cae', 'mw'],
    "mithuyā": ['cae', 'ddsa', 'mw'],
    "mithyatva": ['bhs'],
    "mithyopacāra": ['cae', 'mw'],
    "mithyopayojita": ['mw'],
    "mithyottara": ['mw'],
    "mithyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "mithyābhidhā": ['mw'],
    "mithyābhidhāna": ['mw'],
    "mithyābhigṛdhna": ['mw'],
    "mithyābhimāna": ['mw'],
    "mithyābhiyoga": ['mw'],
    "mithyābhiyogin": ['cae', 'mw'],
    "mithyābhiśapta": ['mw'],
    "mithyābhiśasta": ['mw'],
    "mithyābhiśasti": ['cae', 'mw'],
    "mithyābhiśaṃsana": ['mw'],
    "mithyābhiśaṃsin": ['cae', 'mw'],
    "mithyābhiśāpa": ['cae', 'mw'],
    "mithyābhiṣaṅga": ['mw'],
    "mithyācaryā": ['mw'],
    "mithyācāra": ['cae', 'mw'],
    "mithyācāraprahasana": ['mw'],
    "mithyācārika": ['bhs'],
    "mithyādarśana": ['bhs', 'mw'],
    "mithyādhita": ['mw'],
    "mithyādhyavasiti": ['mw'],
    "mithyādūta": ['mw'],
    "mithyādṛṣṭi": ['bhs', 'mw'],
    "mithyādṛṣṭika": ['bhs'],
    "mithyāglaha": ['mw'],
    "mithyāgnahaṇa": ['mw'],
    "mithyāgraha": ['cae', 'mw'],
    "mithyāhāra": ['mw'],
    "mithyāhāravihārin": ['mw'],
    "mithyājalpita": ['mw'],
    "mithyājñāna": ['cae', 'mw'],
    "mithyājñānakhaṇḍana": ['mw'],
    "mithyājīva": ['bhs'],
    "mithyājīvātu": ['mw'],
    "mithyākarman": ['mw'],
    "mithyākopa": ['cae', 'ddsa', 'mw'],
    "mithyākraya": ['cae', 'mw'],
    "mithyākrodha": ['mw'],
    "mithyākāruṇika": ['mw'],
    "mithyākṛta": ['cae', 'mw'],
    "mithyāliṅgadhara": ['mw'],
    "mithyāmanorama": ['mw'],
    "mithyāmati": ['mw'],
    "mithyāmāna": ['bhs', 'mw'],
    "mithyānirasana": ['mw'],
    "mithyāpavāda": ['mw'],
    "mithyāpaṇḍita": ['mw'],
    "mithyāphala": ['mw'],
    "mithyāprasupta": ['mw'],
    "mithyāpratijña": ['mw'],
    "mithyāpratipanna": ['bhs'],
    "mithyāpratyaya": ['mw'],
    "mithyāpravādin": ['mw'],
    "mithyāpravṛtti": ['mw'],
    "mithyāprayukta": ['mw'],
    "mithyāpraṇidhāna": ['bhs', 'mw'],
    "mithyāpuruṣa": ['mw'],
    "mithyārambha": ['mw'],
    "mithyārṇava": ['mw'],
    "mithyāstava": ['mw'],
    "mithyāstotra": ['mw'],
    "mithyāsākṣin": ['cae', 'mw'],
    "mithyāsākṣipradātṛ": ['mw'],
    "mithyātva": ['bhs', 'mw'],
    "mithyātvanirukti": ['mw'],
    "mithyātvanirvacana": ['mw'],
    "mithyātvaniyata": ['mw'],
    "mithyātvavādarahasya": ['mw'],
    "mithyātvaṃ": ['ap90'],
    "mithyātvin": ['mw'],
    "mithyātvānumānakhaṇḍana": ['mw'],
    "mithyāvacana": ['cae', 'mw'],
    "mithyāvadhyānukīrtana": ['mw'],
    "mithyāvikalpa": ['mw'],
    "mithyāvyāhārin": ['mw'],
    "mithyāvyāpāra": ['cae', 'mw'],
    "mithyāvāc": ['mw'],
    "mithyāvāda": ['cae', 'mw'],
    "mithyāvādin": ['cae'],
    "mithyāvākya": ['cae', 'mw'],
    "mithyāvārttā": ['mw'],
    "mithyāyoga": ['cae', 'mw'],
    "mithū": ['cae', 'gra', 'mw'],
    "mithūdṛś": ['gra', 'mw'],
    "mithūkṛt": ['gra', 'mw'],
    "miti": ['cae', 'ddsa', 'gra', 'mw'],
    "mitiḥ": ['ap90'],
    "mitokti": ['ddsa', 'mw'],
    "mitra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "mitrabandhuhīna": ['mw'],
    "mitrabha": ['mw'],
    "mitrabheda": ['cae', 'mw'],
    "mitrabhānu": ['mw'],
    "mitrabhāva": ['cae', 'mw'],
    "mitrabhū": ['mw'],
    "mitrabhūti": ['mw'],
    "mitrabhṛt": ['mw'],
    "mitrabāhu": ['mw'],
    "mitradeva": ['mw'],
    "mitradharman": ['mw'],
    "mitradheya": ['mw'],
    "mitradhita": ['cae', 'gra', 'mw'],
    "mitradhiti": ['cae', 'gra', 'mw'],
    "mitradhā": ['cae', 'mw'],
    "mitradroha": ['cae', 'mw'],
    "mitradrohin": ['mw'],
    "mitradruh": ['cae', 'mw'],
    "mitradveṣin": ['mw'],
    "mitradviṣ": ['mw'],
    "mitraghna": ['mw'],
    "mitraghnā": ['mw'],
    "mitragupta": ['cae', 'mw'],
    "mitragupti": ['mw'],
    "mitrahan": ['mw'],
    "mitrahana": ['mw'],
    "mitrahatyā": ['mw'],
    "mitrahū": ['mw'],
    "mitrajit": ['mw'],
    "mitrajña": ['mw'],
    "mitraka": ['mw'],
    "mitrakaraṇa": ['mw'],
    "mitrakarman": ['cae', 'mw'],
    "mitrakaustubha": ['mw'],
    "mitrakru": ['gra', 'mw'],
    "mitrakrū": ['mw'],
    "mitrakālikā": ['bhs'],
    "mitrakāma": ['mw'],
    "mitrakārya": ['cae', 'mw'],
    "mitrakṛt": ['mw'],
    "mitrakṛti": ['cae', 'mw'],
    "mitrakṛtya": ['mw'],
    "mitralabdhi": ['mw'],
    "mitralābha": ['cae', 'mw'],
    "mitramahas": ['cae', 'gra', 'mw'],
    "mitramitra": ['mw'],
    "mitramiśra": ['mw'],
    "mitramukha": ['mw'],
    "mitranandana": ['cae', 'mw'],
    "mitrapada": ['mw'],
    "mitrapathādikuṇḍamāhātmya": ['mw'],
    "mitrapati": ['cae', 'gra', 'mw'],
    "mitrapratīkṣā": ['mw'],
    "mitrarājan": ['gra'],
    "mitrasaha": ['cae', 'mw'],
    "mitrasamprāpti": ['mw'],
    "mitrasaptamī": ['mw'],
    "mitrasaṃprāpti": ['cae'],
    "mitrasena": ['mw'],
    "mitrasneha": ['cae', 'mw'],
    "mitrasāha": ['cae', 'mw'],
    "mitrasāhvayā": ['mw'],
    "mitrasūkta": ['mw'],
    "mitrati": ['ap90'],
    "mitratva": ['mw'],
    "mitratā": ['ap90', 'cae', 'mw'],
    "mitratūrya": ['mw'],
    "mitravaira": ['mw'],
    "mitravana": ['mw'],
    "mitravant": ['cae'],
    "mitravaraṇa": ['mw'],
    "mitravarcas": ['mw'],
    "mitravardha": ['mw'],
    "mitravardhana": ['mw'],
    "mitravardhra": ['mw'],
    "mitravarman": ['mw'],
    "mitravat": ['cae', 'mw'],
    "mitravatsala": ['cae', 'mw'],
    "mitravatī": ['mw'],
    "mitravid": ['mw'],
    "mitravinda": ['mw'],
    "mitravindeṣṭi": ['mw'],
    "mitravindeṣṭihautra": ['mw'],
    "mitravindeṣṭiprayoga": ['mw'],
    "mitravindā": ['mw'],
    "mitraviṣaya": ['mw'],
    "mitravāha": ['mw'],
    "mitraya": ['mw'],
    "mitrayajña": ['mw'],
    "mitrayu": ['ap90', 'mw'],
    "mitrayuddha": ['mw'],
    "mitrayuj": ['gra', 'mw'],
    "mitraīru": ['gra'],
    "mitraśarman": ['mw'],
    "mitraśis": ['mw'],
    "mitraḥ": ['ap90'],
    "mitreru": ['gra', 'mw'],
    "mitreyu": ['mw'],
    "mitreśvara": ['ddsa', 'mw'],
    "mitria": ['gra'],
    "mitrin": ['cae', 'gra', 'mw'],
    "mitriya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mitrodaya": ['ddsa', 'mw'],
    "mitropasthāna": ['mw'],
    "mitrya": ['cae', 'gra', 'mw'],
    "mitrā": ['mw'],
    "mitrābhidroha": ['mw'],
    "mitrācāra": ['ddsa', 'mw'],
    "mitrākhya": ['mw'],
    "mitrāmitra": ['cae', 'mw'],
    "mitrānugrahaṇa": ['mw'],
    "mitrātithi": ['cae', 'gra', 'mw'],
    "mitrāvaruṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "mitrāvaruṇasamīrita": ['mw'],
    "mitrāvaruṇau": ['ap90'],
    "mitrāvaruṇavat": ['gra', 'mw'],
    "mitrāvaruṇīya": ['mw'],
    "mitrāvasu": ['cae', 'ddsa', 'mw'],
    "mitrāya": ['mw'],
    "mitrāyate": ['ap90'],
    "mitrāyu": ['cae', 'gra', 'mw'],
    "mitrī": ['mw'],
    "mitrībhū": ['ap90', 'mw'],
    "mitrīkṛ": ['ap90', 'ddsa', 'mw'],
    "mitrīkṛta": ['mw'],
    "mitrīy": ['cae'],
    "mitrīya": ['ddsa', 'mw'],
    "mitrīyati": ['ap90'],
    "mitta": ['cped'],
    "mittabheda": ['cped'],
    "mittaddu": ['cped'],
    "mittadubbhi": ['cped'],
    "mittadūbhī": ['cped'],
    "mittapatirūpaka": ['cped'],
    "mittasanthava": ['cped'],
    "mitya": ['ddsa', 'mw'],
    "mitāhāra": ['cae', 'mw'],
    "mitākṣara": ['cae', 'ddsa', 'mw'],
    "mitākṣarasiddhāntasaṃgraha": ['mw'],
    "mitākṣarasāra": ['mw'],
    "mitākṣaravyākhyāna": ['mw'],
    "mitākṣarā": ['mw'],
    "mitākṣarākāra": ['mw'],
    "mitārtha": ['mw'],
    "mitārthabhāṣin": ['mw'],
    "mitāśana": ['cae', 'mw'],
    "mitāṅka": ['mw'],
    "mitāṅkakaraṇa": ['mw'],
    "miyedha": ['cae', 'ddsa', 'gra', 'mw'],
    "miyedhas": ['mw'],
    "miyedhaḥ": ['ap90'],
    "miyedhya": ['ap90', 'cae', 'gra', 'mw'],
    "miyedhīa": ['gra'],
    "miyyati": ['cped'],
    "miñj": ['bhs', 'mw'],
    "miñja": ['cped'],
    "miñjikāmiñjika": ['mw'],
    "miñjā": ['cped', 'mw'],
    "miñjāstha": ['mw'],
    "miñjāsthi": ['mw'],
    "miś": ['ap90', 'ddsa', 'gra', 'mw'],
    "miśa": ['cae'],
    "miśara": ['mw'],
    "miśi": ['mw'],
    "miśiḥ": ['ap90'],
    "miśla": ['cae', 'ddsa', 'gra', 'mw'],
    "miśr": ['ap90', 'mw'],
    "miśra": ['ap90', 'ddsa', 'gra', 'mw'],
    "miśrabhāva": ['mw'],
    "miśrabhāṇa": ['mw'],
    "miśracaturbhuja": ['mw'],
    "miśracaura": ['mw'],
    "miśracora": ['mw'],
    "miśradhana": ['mw'],
    "miśradhānya": ['cae', 'ddsa', 'mw'],
    "miśradinakara": ['mw'],
    "miśradāmodara": ['mw'],
    "miśraja": ['mw'],
    "miśrajāti": ['mw'],
    "miśraka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "miśrakavyavahāra": ['mw'],
    "miśrakeśava": ['mw'],
    "miśrakeśī": ['bhs', 'cae', 'mw'],
    "miśrakāvana": ['bhs'],
    "miśrakāvaṇa": ['mw'],
    "miśralaṭakana": ['mw'],
    "miśraprakṛtika": ['mw'],
    "miśrapuṣpā": ['mw'],
    "miśratā": ['mw'],
    "miśravarṇa": ['mw'],
    "miśravarṇaphalā": ['mw'],
    "miśraviṣkambhaka": ['mw'],
    "miśravyavahāra": ['mw'],
    "miśravṛtta": ['mw'],
    "miśray": ['cae'],
    "miśraya": ['ddsa'],
    "miśraśabda": ['mw'],
    "miśraṇa": ['cae', 'ddsa', 'mw'],
    "miśraṇaṃ": ['ap90'],
    "miśraṇīya": ['mw'],
    "miśreyā": ['mw'],
    "miśrika": ['bhs'],
    "miśrin": ['mw'],
    "miśrita": ['ap90', 'mw'],
    "miśritamāhātmya": ['mw'],
    "miśrāvana": ['bhs'],
    "miśrī": ['mw'],
    "miśrībhāva": ['mw'],
    "miśrībhāvakarman": ['mw'],
    "miśrībhū": ['mw'],
    "miśrīkaraṇa": ['mw'],
    "miśrīkṛ": ['cae', 'ddsa', 'mw'],
    "miśī": ['mw'],
    "miśṛ": ['bhs'],
    "miśṛṣa": ['mw'],
    "miṃd": ['ap90'],
    "miṇana": ['cped'],
    "miṇanta": ['cped'],
    "miṇi": ['cped'],
    "miṇituṁ": ['cped'],
    "miṇitvā": ['cped'],
    "miṇmiṇa": ['mw'],
    "miṇmiṇatva": ['mw'],
    "miṇāti": ['cped'],
    "miṇīyati": ['cped'],
    "miṇḍha": ['bhs'],
    "miṇḍhaka": ['bhs'],
    "miṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "miṣa": ['cae', 'ddsa', 'mw'],
    "miṣamiṣāya": ['mw'],
    "miṣaḥ": ['ap90'],
    "miṣi": ['mw'],
    "miṣikā": ['mw'],
    "miṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "miṣṭabhojana": ['mw'],
    "miṣṭabhuj": ['mw'],
    "miṣṭakartṛ": ['mw'],
    "miṣṭanimbū": ['mw'],
    "miṣṭapācaka": ['mw'],
    "miṣṭatā": ['mw'],
    "miṣṭavākya": ['mw'],
    "miṣṭānna": ['cae', 'mw'],
    "miṣṭānnapāna": ['mw'],
    "miṣṭāśā": ['mw'],
    "mlai": ['ap90', 'mw'],
    "mlakta": ['mw'],
    "mlakṣ": ['ap90', 'mw'],
    "mlapaya": ['ddsa'],
    "mlecch": ['ap90', 'cae'],
    "mleccha": ['cae', 'ddsa', 'mw'],
    "mlecchabhojana": ['mw'],
    "mlecchabhāṣā": ['mw'],
    "mlecchadeśa": ['cae', 'ddsa', 'mw'],
    "mlecchadviṣṭa": ['mw'],
    "mlecchajāti": ['mw'],
    "mlecchakanda": ['mw'],
    "mlecchamaṇḍala": ['mw'],
    "mlecchamukha": ['mw'],
    "mlecchana": ['cae', 'ddsa', 'mw'],
    "mlecchanaṃ": ['ap90'],
    "mlecchanivaha": ['mw'],
    "mlecchataskarasevita": ['mw'],
    "mlecchatā": ['cae', 'mw'],
    "mlecchavāc": ['cae', 'mw'],
    "mlecchaḥ": ['ap90'],
    "mlecchita": ['ap90', 'mw'],
    "mlecchitaka": ['ddsa', 'mw'],
    "mlecchitakaṃ": ['ap90'],
    "mlecchākhya": ['mw'],
    "mlecchāsya": ['mw'],
    "mlecchāśa": ['mw'],
    "mlech": ['mw'],
    "mlev": ['ap90', 'mw'],
    "mleḍ": ['mw'],
    "mleṭ": ['ap90', 'mw'],
    "mlich": ['ddsa', 'mw'],
    "mlit": ['cae'],
    "mliṣṭa": ['ap90', 'mw'],
    "mliṣṭokti": ['mw'],
    "mluc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mlukta": ['mw'],
    "mlup": ['cae', 'ddsa', 'mw'],
    "mluñc": ['mw'],
    "mlā": ['cae', 'ddsa', 'gra'],
    "mlāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "mlānaka": ['bhs'],
    "mlānakṣīṇa": ['mw'],
    "mlānamanas": ['mw'],
    "mlānasraj": ['mw'],
    "mlānatva": ['mw'],
    "mlānatā": ['mw'],
    "mlānavaktra": ['mw'],
    "mlānavrīḍa": ['mw'],
    "mlānendriya": ['mw'],
    "mlāni": ['cae', 'ddsa', 'mw'],
    "mlāniman": ['ddsa', 'mw'],
    "mlāniḥ": ['ap90'],
    "mlānāṅga": ['mw'],
    "mlānāṅgī": ['mw'],
    "mlāpin": ['ddsa', 'mw'],
    "mlāsnu": ['ap90', 'mw'],
    "mlāta": ['ap90', 'cae', 'mw'],
    "mlāyadvaktra": ['mw'],
    "mlāyat": ['ap90', 'mw'],
    "mlāyin": ['cae', 'mw'],
    "mmarta, amartya": ['ddsa'],
    "mnā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mnāta": ['ap90', 'mw'],
    "mo": ['cae', 'ddsa', 'mw'],
    "moca": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mocaka": ['ap90', 'cae', 'mw'],
    "mocana": ['ap90', 'cae', 'cped', 'mw'],
    "mocanaka": ['mw'],
    "mocanapaṭṭaka": ['bhs', 'mw'],
    "mocanikā": ['mw'],
    "mocaniryāsa": ['mw'],
    "mocanī": ['mw'],
    "mocanīya": ['cae', 'mw'],
    "mocarasa": ['mw'],
    "mocasrut": ['mw'],
    "mocasrāva": ['mw'],
    "mocasāra": ['mw'],
    "mocayitavya": ['cae', 'mw'],
    "mocayitṛ": ['ap90', 'mw'],
    "mocaḥ": ['ap90'],
    "mocenta": ['cped'],
    "mocesi": ['cped'],
    "moceti": ['cped'],
    "mocetuṁ": ['cped'],
    "mocetvā": ['cped'],
    "moci": ['mw'],
    "mocika": ['bhs', 'mw'],
    "mocikā": ['mw'],
    "mocin": ['mw'],
    "mocita": ['cped', 'mw'],
    "mociya": ['cped'],
    "mocya": ['cae', 'mw'],
    "mocā": ['mw'],
    "mocāhva": ['mw'],
    "mocāpana": ['cped'],
    "mocāpeti": ['cped'],
    "mocāṭa": ['mw'],
    "mocāṭaḥ": ['ap90'],
    "mocī": ['mw'],
    "moda": ['cae', 'ddsa', 'gra', 'mw'],
    "modaka": ['ap90', 'cae', 'cped', 'mw'],
    "modakakāra": ['mw'],
    "modakakāraka": ['bhs'],
    "modakamaya": ['mw'],
    "modakara": ['mw'],
    "modakavallabha": ['mw'],
    "modakikā": ['ap90', 'mw'],
    "modakī": ['mw'],
    "modamañjarīguṇaleśamātrasūcakāṣṭaka": ['mw'],
    "modamañjarīguṇaleśasūcakadaśaka": ['mw'],
    "modamodinī": ['mw'],
    "modamāna": ['cped', 'mw'],
    "modana": ['cae', 'cped', 'ddsa', 'mw'],
    "modanaṃ": ['ap90'],
    "modanā": ['cped'],
    "modanātha": ['mw'],
    "modanī": ['mw'],
    "modanīya": ['cae', 'mw'],
    "modati": ['cped'],
    "modayantī": ['mw'],
    "modayat": ['mw'],
    "modayati": ['bhs'],
    "modayaṃtikā": ['ap90'],
    "modaḥ": ['ap90'],
    "modi": ['bhs', 'cped'],
    "modin": ['ap90', 'cae', 'mw'],
    "modinī": ['mw'],
    "modinīśa": ['mw'],
    "modita": ['ap90', 'cped', 'mw'],
    "moditvā": ['cped'],
    "modoṣa": ['mw'],
    "modā": ['mw'],
    "modāgiri": ['mw'],
    "modākhya": ['mw'],
    "modāki": ['mw'],
    "modākin": ['mw'],
    "modāpura": ['mw'],
    "modāyani": ['mw'],
    "modāḍhyā": ['mw'],
    "moga": ['mw'],
    "mogha": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "moghabāṣpa": ['mw'],
    "moghahāsin": ['mw'],
    "moghajñāna": ['cae', 'mw'],
    "moghakarman": ['cae', 'ddsa', 'mw'],
    "mogham": ['mw'],
    "moghapurisa": ['cped'],
    "moghapuṣpā": ['mw'],
    "moghatā": ['cae', 'mw'],
    "mogholi": ['mw'],
    "mogholiḥ": ['ap90'],
    "moghā": ['mw'],
    "moghāya": ['mw'],
    "moghāśa": ['cae', 'mw'],
    "moghī": ['mw'],
    "moghībhūta": ['mw'],
    "moghīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "moha": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mohacarita": ['cped'],
    "mohacitta": ['mw'],
    "mohacūḍottara": ['mw'],
    "mohacūḍottaraśāstra": ['mw'],
    "mohadharmeśvara": ['bhs'],
    "mohajāla": ['mw'],
    "mohaka": ['mw'],
    "mohakalila": ['mw'],
    "mohakara": ['mw'],
    "mohakkhaya": ['cped'],
    "mohakārin": ['mw'],
    "mohama": ['ddsa', 'mw'],
    "mohamantra": ['mw'],
    "mohamaya": ['cae', 'mw'],
    "mohamudgara": ['cae', 'mw'],
    "mohana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "mohanabhoga": ['mw'],
    "mohanacanda": ['mw'],
    "mohanadāsa": ['mw'],
    "mohanaka": ['cped', 'mw'],
    "mohanakaḥ": ['ap90'],
    "mohanalatā": ['mw'],
    "mohanalāla": ['mw'],
    "mohanaprakṛti": ['mw'],
    "mohanasaptaśatī": ['mw'],
    "mohanavallikā": ['mw'],
    "mohanavallī": ['mw'],
    "mohaneyya": ['cped'],
    "mohanidrā": ['ddsa', 'mw'],
    "mohanikā": ['mw'],
    "mohanā": ['mw'],
    "mohanāstra": ['mw'],
    "mohanī": ['ddsa', 'mw'],
    "mohanīya": ['ap90', 'cae', 'cped', 'mw'],
    "mohaparimuktā": ['bhs', 'mw'],
    "mohaparāyaṇa": ['mw'],
    "mohapuruṣa": ['bhs'],
    "mohapāśa": ['mw'],
    "moharājaparājaya": ['mw'],
    "moharātri": ['mw'],
    "mohatama": ['cped'],
    "mohavant": ['cae'],
    "mohavat": ['mw'],
    "mohayitṛ": ['cae', 'mw'],
    "mohaśāstra": ['mw'],
    "mohaśūlottara": ['mw'],
    "mohaḥ": ['ap90'],
    "mohaṃ": ['bhs'],
    "mohesi": ['cped'],
    "moheti": ['cped'],
    "mohetvā": ['cped'],
    "mohin": ['ap90', 'cae', 'ddsa', 'mw'],
    "mohinī": ['ap90', 'mw'],
    "mohinīmantra": ['mw'],
    "mohinīrājasahasranāmāvalī": ['mw'],
    "mohita": ['ap90', 'cped', 'mw'],
    "mohopamā": ['cae', 'ddsa', 'mw'],
    "mohopaniṣad": ['mw'],
    "mohuka": ['cae', 'mw'],
    "mohā": ['bhs'],
    "mohāndhasūrya": ['mw'],
    "mohānta": ['mw'],
    "mohāt": ['mw'],
    "mohātmaka": ['mw'],
    "mojakeśin": ['mw'],
    "moka": ['cae', 'ddsa', 'mw'],
    "mokalin": ['mw'],
    "mokaṃ": ['ap90'],
    "mokkha": ['cped'],
    "mokkhaka": ['cped'],
    "mokkhamagga": ['cped'],
    "mokkhati": ['cped'],
    "moktavya": ['cae', 'ddsa', 'mw'],
    "moktukāma": ['mw'],
    "moktṛ": ['cae', 'mw'],
    "mokya": ['mw'],
    "mokī": ['ddsa', 'gra', 'mw'],
    "mokṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "mokṣa": ['cae', 'ddsa', 'mw'],
    "mokṣabhāgīya": ['mw'],
    "mokṣabhāj": ['mw'],
    "mokṣabhāva": ['cae', 'mw'],
    "mokṣadeva": ['mw'],
    "mokṣadharma": ['mw'],
    "mokṣadharmadīpikā": ['mw'],
    "mokṣadharmaparvan": ['mw'],
    "mokṣadharmasāroddhāra": ['mw'],
    "mokṣadharmavyākhyā": ['mw'],
    "mokṣadharmavyākhyāna": ['mw'],
    "mokṣadharmaṭīkā": ['mw'],
    "mokṣadharmārthadīpikā": ['mw'],
    "mokṣadviṣ": ['mw'],
    "mokṣadvāra": ['ddsa', 'mw'],
    "mokṣadā": ['mw'],
    "mokṣahetutāvāda": ['mw'],
    "mokṣajñāna": ['mw'],
    "mokṣaka": ['ap90', 'bhs', 'cae', 'mw'],
    "mokṣakhaṇḍa": ['mw'],
    "mokṣakriyāsamācāra": ['mw'],
    "mokṣakāma": ['mw'],
    "mokṣakāraṇatāvādārtha": ['mw'],
    "mokṣakārikā": ['mw'],
    "mokṣakāṅkṣin": ['mw'],
    "mokṣakāṇḍa": ['mw'],
    "mokṣalakṣmīsāmrājyasiddhi": ['mw'],
    "mokṣalakṣmīsāmrājyatantra": ['mw'],
    "mokṣalakṣmīvilāsa": ['mw'],
    "mokṣamahāpariṣad": ['mw'],
    "mokṣamārga": ['mw'],
    "mokṣanirṇaya": ['mw'],
    "mokṣaparāyaṇa": ['cae', 'mw'],
    "mokṣapati": ['mw'],
    "mokṣapraveśavyavasthāna": ['mw'],
    "mokṣapurī": ['mw'],
    "mokṣasiddhi": ['mw'],
    "mokṣasādhana": ['cae', 'mw'],
    "mokṣasādhanopadeśa": ['mw'],
    "mokṣasāmrājyasiddhi": ['mw'],
    "mokṣatīrtha": ['mw'],
    "mokṣavat": ['ddsa', 'mw'],
    "mokṣaviṃśaka": ['mw'],
    "mokṣaviṃśakastotra": ['mw'],
    "mokṣavāda": ['mw'],
    "mokṣavādamīmāṃsā": ['mw'],
    "mokṣavārttika": ['mw'],
    "mokṣay": ['cae'],
    "mokṣaya": ['ddsa'],
    "mokṣayitavya": ['cae', 'ddsa', 'mw'],
    "mokṣayitṛ": ['cae', 'mw'],
    "mokṣaśāstra": ['cae', 'mw'],
    "mokṣaḥ": ['ap90'],
    "mokṣaṇa": ['cae', 'ddsa', 'mw'],
    "mokṣaṇaṃ": ['ap90'],
    "mokṣaṇī": ['mw'],
    "mokṣaṇīya": ['cae', 'mw'],
    "mokṣecchā": ['cae', 'mw'],
    "mokṣeśvara": ['mw'],
    "mokṣin": ['ap90', 'cae', 'ddsa', 'mw'],
    "mokṣita": ['mw'],
    "mokṣopāya": ['mw'],
    "mokṣopāyaniścaya": ['mw'],
    "mokṣopāyasāra": ['mw'],
    "mokṣya": ['cae', 'mw'],
    "mokṣāgama": ['mw'],
    "mokṣāntaraṅga": ['mw'],
    "mokṣāvalambin": ['mw'],
    "mokṣāya": ['mw'],
    "mokṣāyaṇa": ['bhs'],
    "momahaṇa": ['mw'],
    "momahaṇavilāsa": ['mw'],
    "momugha": ['cae', 'ddsa', 'mw'],
    "momuha": ['bhs', 'cped'],
    "mona": ['cped'],
    "moneyya": ['cped'],
    "mora": ['bhs', 'cped', 'mw'],
    "morahasta": ['bhs'],
    "moraka": ['mw'],
    "moramba": ['bhs'],
    "morapiñja": ['cped'],
    "moraṅgī": ['bhs'],
    "moraṇa": ['mw'],
    "moraṭa": ['cae', 'ddsa', 'mw'],
    "moraṭaka": ['mw'],
    "moraṭaḥ": ['ap90'],
    "moraṭā": ['mw'],
    "moreśvara": ['mw'],
    "morikā": ['bhs', 'mw'],
    "morvaṇīkara": ['mw'],
    "morāka": ['ddsa', 'mw'],
    "morākabhavana": ['mw'],
    "morī": ['mw'],
    "mosa": ['cped'],
    "mosana": ['cped'],
    "mosavajja": ['cped'],
    "motīrāma": ['mw'],
    "moḍha": ['mw'],
    "moḍhaka": ['mw'],
    "moḍhaśataka": ['mw'],
    "moḷi": ['cped'],
    "moṇa": ['mw'],
    "moṇaka": ['mw'],
    "moṇaḥ": ['ap90'],
    "moṣa": ['cae', 'ddsa', 'mw'],
    "moṣadharma": ['bhs'],
    "moṣadharmin": ['bhs'],
    "moṣaka": ['bhs', 'mw'],
    "moṣakaḥ": ['ap90'],
    "moṣakṛt": ['mw'],
    "moṣayitnu": ['mw'],
    "moṣayitnuḥ": ['ap90'],
    "moṣaḥ": ['ap90'],
    "moṣaṇa": ['cae', 'ddsa', 'mw'],
    "moṣaṇaṃ": ['ap90'],
    "moṣya": ['cae', 'mw'],
    "moṣā": ['ap90'],
    "moṣābhidarśana": ['mw'],
    "moṣṭṛ": ['ap90', 'mw'],
    "moṭa": ['bhs', 'mw'],
    "moṭaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "moṭakaḥ": ['ap90'],
    "moṭakī": ['mw'],
    "moṭamāna": ['mw'],
    "moṭana": ['cae', 'mw'],
    "moṭanaka": ['mw'],
    "moṭanaṃ": ['ap90'],
    "moṭapallī": ['ddsa', 'mw'],
    "moṭi": ['mw'],
    "moṭā": ['mw'],
    "moṭī": ['mw'],
    "moṭṭika": ['bhs'],
    "moṭṭāyita": ['mw'],
    "moṭṭāyitaṃ": ['ap90'],
    "mrad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mrada": ['mw'],
    "mradas": ['ddsa', 'gra', 'mw'],
    "mradiman": ['ap90', 'cae', 'mw'],
    "mradimānvita": ['mw'],
    "mradiṣṭha": ['mw'],
    "mradīyas": ['mw'],
    "mradīyaṃs": ['cae'],
    "mrakṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mrakṣa": ['bhs', 'cae', 'gra', 'mw'],
    "mrakṣakṛtvan": ['gra', 'mw'],
    "mrakṣaḥ": ['ap90'],
    "mrakṣaṇa": ['cae', 'ddsa', 'mw'],
    "mrakṣaṇaṃ": ['ap90'],
    "mrakṣaṣaṇḍā": ['bhs'],
    "mrakṣin": ['bhs'],
    "mrakṣita": ['mw'],
    "mrakṣitaka": ['bhs'],
    "mrakṣya": ['bhs', 'mw'],
    "mreḍ": ['ap90', 'cae', 'ddsa', 'mw'],
    "mreḍita": ['bhs'],
    "mreṭ": ['ap90', 'mw'],
    "mrit": ['cae', 'ddsa', 'mw'],
    "mrita": ['mw'],
    "mritasaṃjīvaka": ['mw'],
    "mroka": ['mw'],
    "mrotaka": ['bhs'],
    "mruc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mrukta": ['mw'],
    "mruñc": ['mw'],
    "mruṃc": ['ap90'],
    "mrātana": ['mw'],
    "mrīḍha, arīlha": ['ddsa'],
    "mu": ['mw'],
    "muc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "muca": ['mw'],
    "mucaka": ['mw'],
    "mucakaḥ": ['ap90'],
    "mucakuṃdaḥ": ['ap90'],
    "mucalinda": ['cped', 'mw'],
    "muccamāna": ['cped'],
    "muccati": ['cped'],
    "mucchana": ['cped'],
    "mucchanta": ['cped'],
    "mucchanā": ['cped'],
    "mucchati": ['cped'],
    "mucchi": ['cped'],
    "mucchita": ['cped'],
    "mucchitvā": ['cped'],
    "mucchiya": ['cped'],
    "mucchā": ['cped'],
    "mucci": ['cped'],
    "muccita": ['cped'],
    "muccitvā": ['cped'],
    "much": ['mw'],
    "muci": ['bhs', 'mw'],
    "mucila": ['bhs'],
    "mucilinda": ['bhs', 'mw'],
    "mucilindā": ['bhs', 'mw'],
    "muciliṃdaḥ": ['ap90'],
    "mucira": ['ap90', 'mw'],
    "mucukunda": ['ddsa', 'mw'],
    "mucukundakavi": ['mw'],
    "mucukundamokṣa": ['mw'],
    "mucukundaprasādaka": ['mw'],
    "mucukundastuti": ['mw'],
    "mucukuṃdaḥ": ['ap90'],
    "muculinda": ['mw'],
    "mucuṭī": ['ap90', 'mw'],
    "mud": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "muda": ['mw'],
    "mudakara": ['mw'],
    "mudara": ['mw'],
    "mudbhāj": ['mw'],
    "mudda": ['mw'],
    "muddaṅkaṇa": ['cped'],
    "muddha": ['cped'],
    "muddhaja": ['cped'],
    "muddhatā": ['cped'],
    "muddhā": ['cped'],
    "muddhādhipāta": ['cped'],
    "muddhātuka": ['cped'],
    "muddhāvasitta": ['cped'],
    "muddikā": ['cped'],
    "muddikāsava": ['cped'],
    "muddā": ['cped'],
    "muddāpaka": ['cped'],
    "muddāpana": ['cped'],
    "muddāpesi": ['cped'],
    "muddāpeti": ['cped'],
    "muddāpetvā": ['cped'],
    "muddāpita": ['cped'],
    "muddāyanta": ['cped'],
    "mudga": ['cae', 'ddsa', 'gra', 'mw'],
    "mudgabhojin": ['mw'],
    "mudgabhuj": ['mw'],
    "mudgagiri": ['mw'],
    "mudgala": ['cae', 'ddsa', 'gra', 'mw'],
    "mudgaladeva": ['mw'],
    "mudgalapurāṇa": ['mw'],
    "mudgalasmṛti": ['mw'],
    "mudgalaḥ": ['ap90'],
    "mudgalikā": ['bhs'],
    "mudgalopaniṣad": ['mw'],
    "mudgalānī": ['gra', 'mw'],
    "mudgalāryā": ['mw'],
    "mudgamodaka": ['mw'],
    "mudgapa": ['mw'],
    "mudgaparṇī": ['mw'],
    "mudgara": ['bhs', 'cae', 'ddsa', 'mw'],
    "mudgaragomin": ['mw'],
    "mudgaraka": ['mw'],
    "mudgarakaḥ": ['ap90'],
    "mudgaraparṇaka": ['mw'],
    "mudgaraphala": ['mw'],
    "mudgarapiṇḍaka": ['mw'],
    "mudgaraḥ": ['ap90'],
    "mudgarākāra": ['mw'],
    "mudgaudana": ['mw'],
    "mudgavarṇa": ['cae'],
    "mudgavat": ['mw'],
    "mudgayūṣa": ['mw'],
    "mudgaḥ": ['ap90'],
    "mudgaṣṭa": ['mw'],
    "mudgaṣṭaka": ['mw'],
    "mudgaṣṭaḥ": ['ap90'],
    "mudgaṣṭha": ['mw'],
    "mudgaṣṭhaka": ['mw'],
    "mudgābha": ['mw'],
    "mudgārdrakavaṭa": ['mw'],
    "mudhā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "mudhāma": ['bhs'],
    "mudhāya": ['bhs'],
    "mudira": ['cae', 'mw'],
    "mudiraphala": ['mw'],
    "mudiraḥ": ['ap90'],
    "mudita": ['ap90', 'cae', 'cped', 'mw'],
    "muditabhadra": ['mw'],
    "muditamadālasa": ['mw'],
    "muditamana": ['cped'],
    "muditapuṣpā": ['bhs', 'mw'],
    "muditā": ['bhs', 'cped', 'mw'],
    "mudiṇga": ['cped'],
    "mudra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "mudraka": ['bhs'],
    "mudray": ['cae'],
    "mudraya": ['ddsa', 'mw'],
    "mudrayati": ['ap90'],
    "mudraṇa": ['cae', 'ddsa', 'mw'],
    "mudraṇaṃ": ['ap90'],
    "mudraṇīpattra": ['mw'],
    "mudrikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "mudrita": ['ap90', 'ddsa', 'mw'],
    "mudritamukha": ['mw'],
    "mudritapāṃsu": ['mw'],
    "mudritākṣa": ['cae', 'mw'],
    "mudrā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "mudrābala": ['bhs', 'mw'],
    "mudrādhāraṇa": ['mw'],
    "mudrādhāraṇamāhātmya": ['mw'],
    "mudrādhāraṇastotra": ['mw'],
    "mudrāhastaka": ['bhs'],
    "mudrākara": ['mw'],
    "mudrākṣara": ['ddsa', 'mw'],
    "mudrākṣepa": ['mw'],
    "mudrālakṣaṇa": ['mw'],
    "mudrālipi": ['bhs', 'mw'],
    "mudrāmārga": ['mw'],
    "mudrāprakāśa": ['mw'],
    "mudrārakṣaka": ['mw'],
    "mudrārākṣasa": ['cae', 'mw'],
    "mudrārākṣasakathāsaṃgraha": ['mw'],
    "mudrārākṣasakathāsāra": ['mw'],
    "mudrārākṣasaprakāśa": ['mw'],
    "mudrārākṣasapūrvapīṭhikā": ['mw'],
    "mudrārṇava": ['mw'],
    "mudrārṇavalakṣaṇaṭīkā": ['mw'],
    "mudrāsthāna": ['mw'],
    "mudrāvidhi": ['mw'],
    "mudrāvivaraṇa": ['mw'],
    "mudrāyantra": ['mw'],
    "mudrāyantrālaya": ['mw'],
    "mudrāṅka": ['cae', 'mw'],
    "mudrāṅkita": ['cae', 'mw'],
    "mudu": ['cped'],
    "mudubhūta": ['cped'],
    "muducitta": ['cped'],
    "muduhadaya": ['cped'],
    "mudujātika": ['cped'],
    "muduka": ['cped'],
    "mudutta": ['cped'],
    "mudutā": ['cped'],
    "mudā": ['cae', 'cped', 'ddsa', 'mw'],
    "mudākara": ['mw'],
    "mudānvita": ['mw'],
    "mudānādata": ['mw'],
    "mudāvasu": ['mw'],
    "mudāvat": ['mw'],
    "mudāvatī": ['mw'],
    "mudāyukta": ['mw'],
    "mudāyuta": ['mw'],
    "mudī": ['ap90', 'mw'],
    "mugadasa": ['mw'],
    "mugademu": ['mw'],
    "mugalasthāna": ['mw'],
    "mugdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "mugdhabhāva": ['cae', 'mw'],
    "mugdhabodha": ['cae', 'mw'],
    "mugdhabodhakāra": ['mw'],
    "mugdhabodhapariśiṣṭa": ['mw'],
    "mugdhabodhapradīpa": ['mw'],
    "mugdhabodhasubodhinī": ['mw'],
    "mugdhabodhinī": ['mw'],
    "mugdhabodhākhyājvarādirogacikitsā": ['mw'],
    "mugdhabuddhi": ['cae', 'mw'],
    "mugdhadhī": ['cae', 'mw'],
    "mugdhadvīpa": ['mw'],
    "mugdhadūrvā": ['cae', 'mw'],
    "mugdhadṛś": ['cae', 'mw'],
    "mugdhagaṇḍaphalaka": ['mw'],
    "mugdhahariṇī": ['mw'],
    "mugdhakathā": ['mw'],
    "mugdhakāntāstana": ['mw'],
    "mugdhamati": ['mw'],
    "mugdhamṛga": ['mw'],
    "mugdhaprabodha": ['mw'],
    "mugdhasvabhāva": ['cae', 'mw'],
    "mugdhatva": ['mw'],
    "mugdhatā": ['ap90', 'cae', 'ddsa', 'mw'],
    "mugdhavadhū": ['mw'],
    "mugdhavat": ['mw'],
    "mugdhavilokita": ['mw'],
    "mugdhavilopitopadeśa": ['mw'],
    "mugdhekṣaṇā": ['cae', 'mw'],
    "mugdhendu": ['cae', 'mw'],
    "mugdhiman": ['mw'],
    "mugdhācakra": ['mw'],
    "mugdhāgraṇī": ['mw'],
    "mugdhākṣī": ['cae', 'mw'],
    "mugdhāloka": ['mw'],
    "mugdhānana": ['mw'],
    "mugdhātman": ['cae', 'mw'],
    "mugga": ['cped'],
    "muggara": ['cped'],
    "mugūha": ['mw'],
    "mugūhaḥ": ['ap90'],
    "muh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "muharaparṇaka": ['mw'],
    "muhe": ['mw'],
    "muhera": ['mw'],
    "muheraḥ": ['ap90'],
    "muhira": ['ap90', 'mw'],
    "muhiṣa": ['mw'],
    "muhu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "muhuka": ['cae', 'gra', 'mw'],
    "muhukais": ['mw'],
    "muhukaṃ": ['ap90'],
    "muhur": ['cae', 'ddsa', 'gra', 'mw'],
    "muhurbhojin": ['mw'],
    "muhurbhuj": ['mw'],
    "muhurbhāṣā": ['mw'],
    "muhurdīkṣin": ['mw'],
    "muhurgir": ['gra', 'mw'],
    "muhurvacas": ['mw'],
    "muhus": ['ap90', 'mw'],
    "muhuskāma": ['mw'],
    "muhustanais": ['mw'],
    "muhutta": ['cped'],
    "muhuttaṁ": ['cped'],
    "muhuttena": ['cped'],
    "muhuttika": ['cped'],
    "muhuś": ['mw'],
    "muhuścārin": ['ddsa', 'mw'],
    "muhuḥ": ['mw'],
    "muhuḥprokta": ['mw'],
    "muhuṁ": ['cped'],
    "muhūrta": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "muhūrtabhairava": ['mw'],
    "muhūrtabhuvanonmārtaṇḍa": ['mw'],
    "muhūrtabhāga": ['mw'],
    "muhūrtabhūṣaṇaṭīkā": ['mw'],
    "muhūrtacakrāvali": ['mw'],
    "muhūrtacandrakalā": ['mw'],
    "muhūrtacintāmaṇi": ['mw'],
    "muhūrtacintāmaṇisāra": ['mw'],
    "muhūrtacintāmaṇisāriṇī": ['mw'],
    "muhūrtacūḍāmaṇi": ['mw'],
    "muhūrtadarpaṇa": ['mw'],
    "muhūrtadarśana": ['mw'],
    "muhūrtadīpa": ['mw'],
    "muhūrtadīpaka": ['mw'],
    "muhūrtadīpikā": ['mw'],
    "muhūrtagaṇapati": ['mw'],
    "muhūrtagrantha": ['mw'],
    "muhūrtaja": ['mw'],
    "muhūrtaka": ['cae', 'mw'],
    "muhūrtakalpadruma": ['mw'],
    "muhūrtakalpadrumīyasaṃkrāntisaṃjñākusuma": ['mw'],
    "muhūrtakalpākara": ['mw'],
    "muhūrtakaḥ": ['ap90'],
    "muhūrtakovida": ['mw'],
    "muhūrtalakṣaṇapaṭala": ['mw'],
    "muhūrtamañjarī": ['mw'],
    "muhūrtamañjūṣā": ['mw'],
    "muhūrtamaṇi": ['mw'],
    "muhūrtamuktāmaṇi": ['mw'],
    "muhūrtamuktāvalī": ['mw'],
    "muhūrtamādhavīya": ['mw'],
    "muhūrtamālā": ['mw'],
    "muhūrtamārtaṇḍa": ['mw'],
    "muhūrtanirṇaya": ['mw'],
    "muhūrtapadavī": ['mw'],
    "muhūrtaparīkṣā": ['mw'],
    "muhūrtaracana": ['mw'],
    "muhūrtaratna": ['mw'],
    "muhūrtaratnamālā": ['mw'],
    "muhūrtaratnākara": ['mw'],
    "muhūrtarājīya": ['mw'],
    "muhūrtasarvasva": ['mw'],
    "muhūrtasaṃgraha": ['mw'],
    "muhūrtasiddhi": ['mw'],
    "muhūrtasindhu": ['mw'],
    "muhūrtaskandha": ['mw'],
    "muhūrtastoma": ['mw'],
    "muhūrtasāra": ['mw'],
    "muhūrtasāriṇī": ['mw'],
    "muhūrtatattva": ['mw'],
    "muhūrtavallabhā": ['mw'],
    "muhūrtavidhānasāra": ['mw'],
    "muhūrtavṛttaśata": ['mw'],
    "muhūrtaśāstra": ['mw'],
    "muhūrtaḥ": ['ap90'],
    "muhūrtaṭīkā": ['mw'],
    "muhūrtena": ['mw'],
    "muhūrtā": ['mw'],
    "muhūrtālaṃkāra": ['mw'],
    "muhūrtārka": ['mw'],
    "muhūrtāvali": ['mw'],
    "muj": ['ap90', 'mw'],
    "muka": ['mw'],
    "mukandaka": ['mw'],
    "mukaya": ['mw'],
    "mukaṃdakaḥ": ['ap90'],
    "mukha": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mukhabandha": ['mw'],
    "mukhabandhana": ['mw'],
    "mukhabhagā": ['mw'],
    "mukhabhaṅga": ['mw'],
    "mukhabhaṅgī": ['mw'],
    "mukhabheda": ['cae', 'mw'],
    "mukhabhūṣaṇa": ['mw'],
    "mukhabāhūrupajja": ['mw'],
    "mukhabāhūrupādatas": ['mw'],
    "mukhacandra": ['cae', 'mw'],
    "mukhacandramas": ['cae', 'mw'],
    "mukhacapala": ['cae', 'mw'],
    "mukhacapalatva": ['mw'],
    "mukhacapalā": ['mw'],
    "mukhacapeṭikā": ['mw'],
    "mukhacchada": ['mw'],
    "mukhacchavi": ['mw'],
    "mukhacāli": ['mw'],
    "mukhacāpalya": ['mw'],
    "mukhacīrī": ['mw'],
    "mukhadaghna": ['cae', 'mw'],
    "mukhadhautā": ['mw'],
    "mukhadhovana": ['cped'],
    "mukhadoṣa": ['cae'],
    "mukhadundubhikā": ['bhs'],
    "mukhadvāra": ['cped'],
    "mukhadūṣaṇa": ['mw'],
    "mukhadūṣaṇaka": ['mw'],
    "mukhadūṣikā": ['mw'],
    "mukhagandhaka": ['mw'],
    "mukhagata": ['cae', 'ddsa', 'mw'],
    "mukhaghaṇṭikā": ['mw'],
    "mukhaghaṇṭā": ['mw'],
    "mukhagrahaṇa": ['mw'],
    "mukhaja": ['cae', 'mw'],
    "mukhajanman": ['mw'],
    "mukhajāha": ['mw'],
    "mukhaka": ['bhs'],
    "mukhakamala": ['mw'],
    "mukhakhura": ['mw'],
    "mukhalepa": ['mw'],
    "mukhalāṅgala": ['mw'],
    "mukham oloketi": ['cped'],
    "mukhamadhu": ['cae', 'mw'],
    "mukhamaṇḍala": ['mw'],
    "mukhamaṇḍana": ['mw'],
    "mukhamaṇḍanaka": ['mw'],
    "mukhamaṇḍikā": ['mw'],
    "mukhamaṇḍinikā": ['mw'],
    "mukhamaṇḍī": ['mw'],
    "mukhamoda": ['mw'],
    "mukhampaca": ['mw'],
    "mukhamudrā": ['mw'],
    "mukhamādhurya": ['mw'],
    "mukhamārjana": ['mw'],
    "mukhamāruta": ['cae', 'mw'],
    "mukhamātra": ['mw'],
    "mukhamātre": ['mw'],
    "mukhanirīkṣaka": ['mw'],
    "mukhanivāsinī": ['mw'],
    "mukhanāsika": ['mw'],
    "mukhapadma": ['mw'],
    "mukhapaṅkaja": ['cae', 'mw'],
    "mukhapaṭa": ['cae', 'mw'],
    "mukhaphullaka": ['bhs', 'mw'],
    "mukhapiṇḍa": ['mw'],
    "mukhapoñchana": ['mw'],
    "mukhaprasāda": ['mw'],
    "mukhaprasādhana": ['cae', 'mw'],
    "mukhapratimukha": ['mw'],
    "mukhaprekṣa": ['mw'],
    "mukhaprekṣin": ['mw'],
    "mukhapriya": ['mw'],
    "mukhaproñchana": ['bhs'],
    "mukhapuñchana": ['cped'],
    "mukhapuṣpaka": ['bhs', 'mw'],
    "mukhapāka": ['mw'],
    "mukhapūra": ['cped'],
    "mukhapūraṇa": ['mw'],
    "mukhara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mukharajju": ['mw'],
    "mukharaka": ['mw'],
    "mukharandhra": ['mw'],
    "mukharatā": ['cped', 'mw'],
    "mukharay": ['cae'],
    "mukharaya": ['ddsa', 'mw'],
    "mukharayati": ['ap90'],
    "mukharekhā": ['mw'],
    "mukharikā": ['ap90', 'ddsa', 'mw'],
    "mukharita": ['ap90', 'mw'],
    "mukharoga": ['ddsa', 'mw'],
    "mukharogika": ['mw'],
    "mukharogin": ['mw'],
    "mukharuj": ['mw'],
    "mukharā": ['mw'],
    "mukharāga": ['cae', 'ddsa', 'mw'],
    "mukharī": ['mw'],
    "mukharīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "mukhasambhava": ['mw'],
    "mukhasammita": ['mw'],
    "mukhasaññata": ['cped'],
    "mukhasaṃdaṃśa": ['mw'],
    "mukhasaṃdhi": ['mw'],
    "mukhasaṅkocana": ['cped'],
    "mukhasecaka": ['mw'],
    "mukhasrāva": ['mw'],
    "mukhasukha": ['mw'],
    "mukhasura": ['mw'],
    "mukhatas": ['cae', 'gra', 'mw'],
    "mukhataḥkāram": ['mw'],
    "mukhatuṇḍa": ['cped'],
    "mukhatuṇḍaka": ['mw'],
    "mukhatīya": ['mw'],
    "mukhavairasya": ['mw'],
    "mukhavallabha": ['mw'],
    "mukhavant": ['cae'],
    "mukhavarṇa": ['cae', 'mw'],
    "mukhavastrikā": ['mw'],
    "mukhavat": ['mw'],
    "mukhavaṇṇa": ['cped'],
    "mukhavaṭṭi": ['cped'],
    "mukhavikāra": ['cped'],
    "mukhaviluṇṭhikā": ['mw'],
    "mukhavipulā": ['cae', 'mw'],
    "mukhaviṣṭhā": ['mw'],
    "mukhavyādāna": ['cae', 'mw'],
    "mukhavādya": ['mw'],
    "mukhavāsa": ['mw'],
    "mukhavāsana": ['mw'],
    "mukhavāta": ['bhs', 'mw'],
    "mukhavāṭikā": ['mw'],
    "mukhayantraṇa": ['mw'],
    "mukhayoni": ['mw'],
    "mukhaśapha": ['mw'],
    "mukhaśaśin": ['cae', 'mw'],
    "mukhaśeṣa": ['mw'],
    "mukhaśobhā": ['mw'],
    "mukhaśodhana": ['mw'],
    "mukhaśodhin": ['mw'],
    "mukhaśoṣa": ['mw'],
    "mukhaśoṣin": ['mw'],
    "mukhaśrī": ['cae', 'mw'],
    "mukhaśuddhi": ['mw'],
    "mukhaśālā": ['mw'],
    "mukhaśṛṅga": ['mw'],
    "mukhaṁ ulloketi": ['cped'],
    "mukhaṃ": ['ap90'],
    "mukhaṃpacaḥ": ['ap90'],
    "mukhaṇḍī": ['mw'],
    "mukhaṣṭhīla": ['mw'],
    "mukhebalin": ['mw'],
    "mukhebhagā": ['mw'],
    "mukhebhava": ['mw'],
    "mukhena": ['mw'],
    "mukhendra": ['bhs'],
    "mukhendu": ['cae', 'mw'],
    "mukhendubimba": ['mw'],
    "mukhenādāyin": ['mw'],
    "mukhocchvāsa": ['mw'],
    "mukhodaka": ['cped'],
    "mukholkā": ['mw'],
    "mukhotkīrṇa": ['mw'],
    "mukhullocakaṃ": ['bhs'],
    "mukhullokaka": ['cped'],
    "mukhulī": ['mw'],
    "mukhuṇḍhī": ['mw'],
    "mukhya": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "mukhyacandra": ['mw'],
    "mukhyamantrin": ['mw'],
    "mukhyamantritva": ['mw'],
    "mukhyanṛpa": ['mw'],
    "mukhyarāj": ['mw'],
    "mukhyarājan": ['mw'],
    "mukhyasadṛśa": ['cae', 'mw'],
    "mukhyatas": ['mw'],
    "mukhyatva": ['mw'],
    "mukhyatā": ['ap90', 'cae', 'mw'],
    "mukhyaśas": ['cae', 'mw'],
    "mukhyaśaḥ": ['ap90'],
    "mukhyopāya": ['mw'],
    "mukhyā": ['mw'],
    "mukhyārdha": ['cae'],
    "mukhyārtha": ['mw'],
    "mukhyāśramin": ['mw'],
    "mukhābja": ['cae', 'mw'],
    "mukhādhāna": ['cped'],
    "mukhāditva": ['cae', 'mw'],
    "mukhādāna": ['mw'],
    "mukhāgni": ['mw'],
    "mukhāgra": ['mw'],
    "mukhākāra": ['ddsa', 'mw'],
    "mukhākṣepa": ['mw'],
    "mukhālu": ['mw'],
    "mukhāmaya": ['mw'],
    "mukhāmbuja": ['cae', 'mw'],
    "mukhāmodā": ['mw'],
    "mukhāmṛta": ['mw'],
    "mukhānila": ['mw'],
    "mukhārcis": ['mw'],
    "mukhārjaka": ['mw'],
    "mukhāsava": ['cae', 'mw'],
    "mukhāsrāva": ['mw'],
    "mukhāstra": ['mw'],
    "mukhāsvāda": ['cae', 'mw'],
    "mukhāvalepa": ['mw'],
    "mukhāvarī": ['mw'],
    "mukhāṅga": ['cae', 'mw'],
    "mukhībhū": ['mw'],
    "mukhīna": ['mw'],
    "mukhīya": ['ap90', 'cae', 'mw'],
    "mukta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "muktabandhana": ['mw'],
    "muktabandhanā": ['mw'],
    "muktabuddhi": ['cae', 'mw'],
    "muktacakṣus": ['mw'],
    "muktacetas": ['cae', 'mw'],
    "muktachattra": ['bhs'],
    "muktachattrapravātasadṛśa": ['bhs'],
    "muktacintāmaṇi": ['mw'],
    "muktadhvani": ['mw'],
    "muktahasta": ['mw'],
    "muktahastā": ['bhs'],
    "muktaka": ['bhs', 'ddsa', 'mw'],
    "muktakaccha": ['mw'],
    "muktakacchamata": ['mw'],
    "muktakara": ['mw'],
    "muktakañcuka": ['mw'],
    "muktakaṃ": ['ap90'],
    "muktakaṇṭha": ['mw'],
    "muktakaṇṭham": ['mw'],
    "muktakeśa": ['cae', 'mw'],
    "muktakusumapratimaṇḍitaprabha": ['bhs'],
    "muktalajja": ['mw'],
    "muktamaṇḍūkakaṇṭha": ['mw'],
    "muktamūrdhaja": ['mw'],
    "muktanidra": ['mw'],
    "muktanirmoka": ['mw'],
    "muktaphūtkāra": ['mw'],
    "muktaphūtkṛti": ['mw'],
    "muktaprabha": ['bhs'],
    "muktapuṣpa": ['mw'],
    "muktarodhonitamba": ['mw'],
    "muktaroṣa": ['mw'],
    "muktasaṃśaya": ['mw'],
    "muktasaṅga": ['cae', 'mw'],
    "muktasvāmin": ['mw'],
    "muktasūryā": ['mw'],
    "muktatva": ['mw'],
    "muktatā": ['cae', 'mw'],
    "muktavasana": ['mw'],
    "muktavyāpāra": ['mw'],
    "muktaśaiśava": ['mw'],
    "muktaśikha": ['cae', 'mw'],
    "mukte": ['cae', 'ddsa', 'mw'],
    "mukteśvara": ['mw'],
    "mukti": ['cae', 'ddsa', 'mw'],
    "mukticintāmaṇi": ['mw'],
    "mukticintāmaṇimāhātmya": ['mw'],
    "muktigrantha": ['mw'],
    "muktikalaśa": ['mw'],
    "muktikhaṇḍa": ['mw'],
    "muktikopaniṣad": ['mw'],
    "muktikopākhyāna": ['mw'],
    "muktikośaka": ['mw'],
    "muktikoṣṭaka": ['mw'],
    "muktikā": ['bhs', 'mw'],
    "muktikāntavilāsa": ['mw'],
    "muktikṣetra": ['mw'],
    "muktikṣetramāhātmya": ['mw'],
    "muktimatī": ['mw'],
    "muktimaṇḍapa": ['mw'],
    "muktimukta": ['mw'],
    "muktimārga": ['mw'],
    "muktipariṇaya": ['mw'],
    "muktipati": ['mw'],
    "muktipura": ['mw'],
    "muktipūrdasyu": ['mw'],
    "muktisaptaśatī": ['mw'],
    "muktisena": ['mw'],
    "muktisopāna": ['mw'],
    "muktisāra": ['mw'],
    "muktitattva": ['mw'],
    "muktitrayabhedanirūpaṇa": ['mw'],
    "muktivant": ['cae'],
    "muktivat": ['mw'],
    "muktivāda": ['mw'],
    "muktivādarahasya": ['mw'],
    "muktivādavicāra": ['mw'],
    "muktivādaṭīkā": ['mw'],
    "muktiḥ": ['ap90'],
    "muktvā": ['ap90', 'mw'],
    "muktā": ['ap90', 'bhs', 'ddsa', 'mw'],
    "muktābharaṇa": ['mw'],
    "muktābhā": ['mw'],
    "muktācaritra": ['mw'],
    "muktādāman": ['mw'],
    "muktāguṇa": ['cae', 'mw'],
    "muktāgāra": ['mw'],
    "muktāharaṇavrata": ['mw'],
    "muktāhāra": ['cae', 'mw'],
    "muktāhāralatā": ['mw'],
    "muktājāla": ['cae', 'mw'],
    "muktājālamaya": ['mw'],
    "muktākalāpa": ['mw'],
    "muktākalāpī": ['mw'],
    "muktākaṇa": ['mw'],
    "muktākeśava": ['mw'],
    "muktākhya": ['mw'],
    "muktākāra": ['mw'],
    "muktākāratā": ['mw'],
    "muktākāvya": ['mw'],
    "muktālatā": ['mw'],
    "muktāmaya": ['cae', 'mw'],
    "muktāmaṇi": ['cae', 'ddsa', 'mw'],
    "muktāmaṇisara": ['mw'],
    "muktāmbara": ['mw'],
    "muktāmodaka": ['mw'],
    "muktāmukta": ['ddsa', 'mw'],
    "muktāmālā": ['mw'],
    "muktāmātṛ": ['mw'],
    "muktānanda": ['mw'],
    "muktāpaṭala": ['mw'],
    "muktāphala": ['cae', 'ddsa', 'mw'],
    "muktāphaladhvaja": ['mw'],
    "muktāphalajāla": ['mw'],
    "muktāphalaka": ['bhs'],
    "muktāphalaketu": ['mw'],
    "muktāphalalatā": ['mw'],
    "muktāphalamaya": ['mw'],
    "muktāphalaparīkṣā": ['mw'],
    "muktāphalatā": ['mw'],
    "muktāpralamba": ['mw'],
    "muktāprasū": ['mw'],
    "muktāprālamba": ['mw'],
    "muktāpura": ['mw'],
    "muktāpuṣpa": ['mw'],
    "muktāpīḍa": ['mw'],
    "muktāratna": ['cae', 'ddsa', 'mw'],
    "muktāratnaraśmimaya": ['mw'],
    "muktāruc": ['cae'],
    "muktāsana": ['cae', 'ddsa', 'mw'],
    "muktāsena": ['ddsa', 'mw'],
    "muktāsphoṭa": ['mw'],
    "muktāsphoṭā": ['mw'],
    "muktāsraj": ['mw'],
    "muktāsthūla": ['mw'],
    "muktāsāra": ['bhs'],
    "muktātman": ['cae', 'mw'],
    "muktāvali": ['cae', 'mw'],
    "muktāvalī": ['cae', 'mw'],
    "muktāvalīdīpikā": ['mw'],
    "muktāvalīkiraṇa": ['mw'],
    "muktāvalīmaya": ['mw'],
    "muktāvalīpaddhati": ['mw'],
    "muktāvalīprabhā": ['mw'],
    "muktāvalīprakāśa": ['mw'],
    "muktāvalīvyākhyā": ['mw'],
    "muktāvalīvyāptivādadīpikā": ['mw'],
    "muktāvalīṭīkā": ['mw'],
    "muktāśukti": ['cae', 'mw'],
    "muktīśvara": ['mw'],
    "muku": ['mw'],
    "mukula": ['cae', 'cped', 'ddsa', 'mw'],
    "mukulay": ['cae'],
    "mukulaya": ['ddsa', 'mw'],
    "mukulayati": ['ap90'],
    "mukulaḥ": ['ap90'],
    "mukulikā": ['mw'],
    "mukulin": ['cae', 'ddsa', 'mw'],
    "mukulita": ['ap90', 'cae', 'mw'],
    "mukulitanayana": ['cae', 'mw'],
    "mukulitā": ['bhs'],
    "mukulitākṣa": ['mw'],
    "mukulāgra": ['mw'],
    "mukulāy": ['cae'],
    "mukulāya": ['ddsa', 'mw'],
    "mukulāyita": ['cae', 'mw'],
    "mukulī": ['mw'],
    "mukulībhāva": ['mw'],
    "mukulīkṛ": ['ddsa', 'mw'],
    "mukulīkṛta": ['mw'],
    "mukum": ['mw'],
    "mukunda": ['bhs', 'cae', 'ddsa', 'mw'],
    "mukundabhaṭṭa": ['mw'],
    "mukundabhaṭṭīya": ['mw'],
    "mukundacaturdaśa": ['mw'],
    "mukundadeva": ['mw'],
    "mukundadāsa": ['mw'],
    "mukundadāsaguṇaleśāṣṭaka": ['mw'],
    "mukundagovinda": ['mw'],
    "mukundaka": ['mw'],
    "mukundalāla": ['mw'],
    "mukundamuktāratnāvalīstotraṭīkā": ['mw'],
    "mukundamuktāvalī": ['mw'],
    "mukundamuni": ['mw'],
    "mukundamālā": ['mw'],
    "mukundapriya": ['mw'],
    "mukundarāja": ['mw'],
    "mukundasena": ['mw'],
    "mukundavana": ['mw'],
    "mukundavijaya": ['mw'],
    "mukundavilāsa": ['mw'],
    "mukundu": ['mw'],
    "mukundānanda": ['mw'],
    "mukundāṣṭaka": ['mw'],
    "mukura": ['cae', 'ddsa', 'mw'],
    "mukuraḥ": ['ap90'],
    "mukurita": ['mw'],
    "mukurāya": ['mw'],
    "mukuḥ": ['ap90'],
    "mukuṃdakaḥ": ['ap90'],
    "mukuṃdaḥ": ['ap90'],
    "mukuṇḍa": ['bhs'],
    "mukuṇṭha": ['mw'],
    "mukuṇṭī": ['mw'],
    "mukuṣṭa": ['bhs'],
    "mukuṣṭha": ['mw'],
    "mukuṣṭhaka": ['mw'],
    "mukuṣṭhaḥ": ['ap90'],
    "mukuṭa": ['cae', 'ddsa', 'mw'],
    "mukuṭaratna": ['mw'],
    "mukuṭatāḍitaka": ['mw'],
    "mukuṭaṃ": ['ap90'],
    "mukuṭekārṣāpaṇa": ['mw'],
    "mukuṭeśvara": ['mw'],
    "mukuṭeśvaratīrtha": ['mw'],
    "mukuṭeśvarī": ['mw'],
    "mukuṭin": ['mw'],
    "mukuṭopala": ['mw'],
    "mukuṭā": ['mw'],
    "mukuṭī": ['ap90', 'mw'],
    "mukuṭṭa": ['mw'],
    "mukā": ['mw'],
    "mukāriṇā": ['mw'],
    "mukāvilā": ['mw'],
    "mukūlaka": ['mw'],
    "mukṣījā": ['cae', 'gra', 'mw'],
    "mul": ['ap90', 'mw'],
    "muluta": ['bhs'],
    "mulālin": ['ddsa', 'mw'],
    "mulālī": ['mw'],
    "mum, muñj": ['ddsa'],
    "mummaḍideva": ['mw'],
    "mummuni": ['ddsa', 'mw'],
    "mumocayiṣu": ['cae', 'mw'],
    "mumokṣayiṣu": ['cae', 'ddsa', 'mw'],
    "mumucu": ['mw'],
    "mumucāna": ['mw'],
    "mumucānaḥ": ['ap90'],
    "mumukṣu": ['ap90', 'cae', 'gra', 'mw'],
    "mumukṣujanakalpa": ['mw'],
    "mumukṣumāhātmya": ['mw'],
    "mumukṣusarvasva": ['mw'],
    "mumukṣusarvasvasārasaṃgraha": ['mw'],
    "mumukṣusārasarvasva": ['mw'],
    "mumukṣusārasaṃgraha": ['mw'],
    "mumukṣutva": ['mw'],
    "mumukṣutā": ['cae', 'mw'],
    "mumukṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "mumuṣiṣu": ['mw'],
    "mumuṣiṣuvat": ['mw'],
    "mumuṣiṣuḥ": ['ap90'],
    "mumūrṣu": ['ap90', 'cae', 'mw'],
    "mumūrṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "muni": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "munibheṣaja": ['mw'],
    "munibhāvaprakāśikā": ['mw'],
    "municandra": ['mw'],
    "municchada": ['mw'],
    "municita": ['mw'],
    "munidauhitra": ['cae'],
    "munideva": ['mw'],
    "munideśa": ['mw'],
    "munidruma": ['mw'],
    "munidāraka": ['mw'],
    "munigāthā": ['bhs', 'mw'],
    "munihata": ['bhs', 'mw'],
    "munijñānajyanta": ['mw'],
    "munika": ['mw'],
    "munikeśa": ['ddsa', 'mw'],
    "munikharjūrikā": ['mw'],
    "munikumāra": ['mw'],
    "munimaraṇa": ['mw'],
    "munimata": ['mw'],
    "munimatamaṇimālā": ['mw'],
    "munimatamīmāṃsā": ['mw'],
    "muninda": ['cped'],
    "muninirmita": ['mw'],
    "munipadī": ['mw'],
    "muniparamparā": ['mw'],
    "munipaticaritra": ['mw'],
    "munipatnī": ['cae', 'mw'],
    "munipittala": ['mw'],
    "munipiṣṭakin": ['mw'],
    "munipravara": ['bhs'],
    "munipriya": ['mw'],
    "muniputra": ['cae', 'mw'],
    "muniputraka": ['mw'],
    "munipuṃgava": ['mw'],
    "munipuṣpaka": ['mw'],
    "munipūga": ['mw'],
    "munisattra": ['mw'],
    "munisevita": ['mw'],
    "munisthala": ['mw'],
    "munisthāna": ['mw'],
    "munisuta": ['cae', 'mw'],
    "munisuvrata": ['mw'],
    "munitanayā": ['cae', 'mw'],
    "munitaru": ['mw'],
    "munitraya": ['mw'],
    "munitva": ['mw'],
    "munitā": ['mw'],
    "munivana": ['cae', 'mw'],
    "munivara": ['cae', 'mw'],
    "muniveṣa": ['cae', 'mw'],
    "muniveṣadhara": ['cae'],
    "muniviṣṭara": ['mw'],
    "munivrata": ['cae', 'mw'],
    "munivratin": ['mw'],
    "munivākya": ['mw'],
    "munivīrya": ['mw'],
    "munivṛkṣa": ['mw'],
    "muniśa": ['mw'],
    "muniśāvaka": ['mw'],
    "muniḥ": ['ap90'],
    "munnabhaṭṭa": ['mw'],
    "munthahā": ['mw'],
    "munthā": ['mw'],
    "munthāphalavicāra": ['mw'],
    "muny": ['mw'],
    "munyanna": ['cae', 'ddsa', 'mw'],
    "munyayana": ['mw'],
    "munyālayatīrtha": ['mw'],
    "munāti": ['cped'],
    "munīmuṣa": ['ddsa'],
    "munīndra": ['cae', 'ddsa', 'mw'],
    "munīndratā": ['mw'],
    "munīndrā": ['bhs', 'mw'],
    "munīvaha": ['mw'],
    "munīvatī": ['mw'],
    "munīśa": ['cae', 'ddsa', 'mw'],
    "munīśvara": ['cae', 'mw'],
    "munīśvarīyapāṭīsāra": ['mw'],
    "mur": ['ap90', 'gra', 'mw'],
    "mura": ['cae', 'ddsa', 'mw'],
    "murabhid": ['mw'],
    "muracī": ['ddsa', 'mw'],
    "muracīpattana": ['mw'],
    "murada": ['mw'],
    "muradviṣ": ['cae', 'mw'],
    "muragaṃḍaḥ": ['ap90'],
    "muragaṇḍa": ['mw'],
    "murahan": ['mw'],
    "muraja": ['cae', 'cped', 'ddsa', 'mw'],
    "murajabandha": ['mw'],
    "murajadhvani": ['mw'],
    "murajaka": ['mw'],
    "murajaphala": ['mw'],
    "murajaḥ": ['ap90'],
    "murajit": ['cae', 'ddsa', 'mw'],
    "murajā": ['ap90', 'mw'],
    "murala": ['ap90', 'cae', 'ddsa', 'mw'],
    "muralaḥ": ['ap90'],
    "muralikā": ['mw'],
    "muralā": ['ap90', 'mw'],
    "muralī": ['ap90', 'mw'],
    "muralīdhara": ['mw'],
    "muralīprakāśa": ['mw'],
    "muramardana": ['mw'],
    "muramaṇḍa": ['mw'],
    "murandalā": ['mw'],
    "muraripu": ['cae', 'mw'],
    "murasidābāda": ['mw'],
    "murava": ['bhs'],
    "muravairin": ['ddsa', 'mw'],
    "muravāra": ['ddsa', 'mw'],
    "muraḥ": ['ap90'],
    "muraṃdalā": ['ap90'],
    "muraṃḍāḥ": ['ap90'],
    "muraṅgī": ['mw'],
    "muraṇḍa": ['mw'],
    "murbhiṇī": ['mw'],
    "murch": ['ap90', 'ddsa', 'mw'],
    "murmiṇī": ['ap90'],
    "murmura": ['cae', 'ddsa', 'mw'],
    "murmuraḥ": ['ap90'],
    "murmurā": ['mw'],
    "murmurīya": ['mw'],
    "muru": ['mw'],
    "murucikā": ['bhs'],
    "murudeśa": ['mw'],
    "murumurāyati": ['cped'],
    "murutāṇadeśa": ['mw'],
    "muruṅgī": ['mw'],
    "muruṇḍa": ['mw'],
    "muruṇḍaka": ['mw'],
    "muruṇṭaka": ['mw'],
    "murv": ['ap90', 'mw'],
    "murā": ['mw'],
    "murāda": ['mw'],
    "murāri": ['ap90', 'cae', 'mw'],
    "murārigupta": ['mw'],
    "murārimiśrīya": ['mw'],
    "murārināṭaka": ['mw'],
    "murārināṭakavyākhyā": ['mw'],
    "murārināṭakavyākhyāpūrṇasarasvatī": ['mw'],
    "murārivijaya": ['mw'],
    "murāriśrīpati": ['mw'],
    "murūṇḍa": ['mw'],
    "mus": ['ap90', 'mw'],
    "musala": ['cae', 'cped', 'ddsa', 'mw'],
    "musalaka": ['bhs', 'mw'],
    "musalapāṇi": ['mw'],
    "musalayaṣṭika": ['mw'],
    "musalaḥ": ['ap90'],
    "musalikā": ['mw'],
    "musalin": ['cae', 'ddsa', 'mw'],
    "musalina": ['ap90'],
    "musalita": ['mw'],
    "musallaha": ['mw'],
    "musalolūkhala": ['mw'],
    "musalya": ['ap90', 'mw'],
    "musalāmusali": ['ap90', 'mw'],
    "musalāyudha": ['mw'],
    "musalī": ['ap90', 'cped', 'mw'],
    "musalībhū": ['mw'],
    "musalīkā": ['ap90'],
    "musalīya": ['mw'],
    "musaṭī": ['mw'],
    "musra": ['mw'],
    "musraṃ": ['ap90'],
    "mussati": ['cped'],
    "mussi": ['cped'],
    "mussitvā": ['cped'],
    "must": ['ap90', 'mw'],
    "musta": ['cae', 'ddsa', 'mw'],
    "mustagiri": ['mw'],
    "mustaka": ['cae', 'mw'],
    "mustaḥ": ['ap90'],
    "mustu": ['mw'],
    "mustābha": ['mw'],
    "mustāda": ['mw'],
    "musuṇḍi": ['bhs'],
    "musuṇṭhī": ['mw'],
    "musā": ['cped'],
    "musāra": ['bhs'],
    "musāragalva": ['mw'],
    "musāragalvaka": ['bhs'],
    "musāvāda": ['cped'],
    "muta": ['cped'],
    "mutava": ['cae', 'ddsa', 'mw'],
    "muthahā": ['mw'],
    "muthaśila": ['mw'],
    "muthaśilin": ['mw'],
    "muthaśilita": ['mw'],
    "mutiba": ['cae'],
    "mutimant": ['cped'],
    "mutiṇga": ['cped'],
    "mutkala": ['ddsa', 'mw'],
    "mutkhalin": ['bhs', 'mw'],
    "mutta": ['cped'],
    "muttakaraṇa": ['cped'],
    "muttavatthi": ['cped'],
    "mutti": ['cped'],
    "muttā": ['cped'],
    "muttācāra": ['cped'],
    "muttāhāra": ['cped'],
    "muttājāla": ['cped'],
    "muttāvali": ['cped'],
    "mutya": ['mw'],
    "mutyaṃ": ['ap90'],
    "muyhamāna": ['cped'],
    "muyhana": ['cped'],
    "muyhati": ['cped'],
    "muyhi": ['cped'],
    "muyhitvā": ['cped'],
    "muñc": ['mw'],
    "muñca": ['ddsa'],
    "muñcaka": ['cped', 'mw'],
    "muñcamāna": ['cped'],
    "muñcana": ['bhs', 'cped'],
    "muñcanaka": ['cped'],
    "muñcanta": ['cped'],
    "muñcati": ['bhs', 'cped'],
    "muñci": ['cped'],
    "muñcita": ['cped'],
    "muñcitvā": ['cped'],
    "muñciya": ['cped'],
    "muñcāta": ['mw'],
    "muñcīyati": ['cped'],
    "muñj": ['mw'],
    "muñja": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "muñjabalbajajāta": ['bhs'],
    "muñjabandhana": ['mw'],
    "muñjadhārin": ['mw'],
    "muñjagrāma": ['mw'],
    "muñjaka": ['mw'],
    "muñjaketu": ['mw'],
    "muñjakeśa": ['bhs', 'ddsa', 'mw'],
    "muñjakeśin": ['mw'],
    "muñjakulāya": ['mw'],
    "muñjamaya": ['cae', 'mw'],
    "muñjamekhalin": ['mw'],
    "muñjana": ['bhs', 'mw'],
    "muñjanejana": ['cae', 'gra', 'mw'],
    "muñjapṛṣṭha": ['mw'],
    "muñjara": ['mw'],
    "muñjasūnu": ['mw'],
    "muñjavalśa": ['mw'],
    "muñjavat": ['mw'],
    "muñjavaṭa": ['mw'],
    "muñjavivayana": ['mw'],
    "muñjavāsas": ['mw'],
    "muñjaṃdhaya": ['mw'],
    "muñjeṣīkatūla": ['mw'],
    "muñjā": ['mw'],
    "muñjāditya": ['mw'],
    "muñjādri": ['mw'],
    "muñjājyābalbajamaya": ['mw'],
    "muñjāla": ['mw'],
    "muñjāta": ['mw'],
    "muñjātaka": ['mw'],
    "muñjāvaṭa": ['mw'],
    "muñjāṭavī": ['mw'],
    "muñjīkṛ": ['ddsa', 'mw'],
    "muśala": ['mw'],
    "muśallaha": ['mw'],
    "muśalī": ['ap90'],
    "muśaṭī": ['ap90', 'mw'],
    "muḍ": ['mw'],
    "muḥ": ['ap90'],
    "muḷāla": ['cped'],
    "muḷālapuppha": ['cped'],
    "muṃjaraṃ": ['ap90'],
    "muṃjavat": ['ap90'],
    "muṃjaḥ": ['ap90'],
    "muṃjāṭaḥ": ['ap90'],
    "muṃsala": ['mw'],
    "muṃth": ['ap90'],
    "muṃḍ": ['ap90'],
    "muṃḍa": ['ap90'],
    "muṃḍakaḥ": ['ap90'],
    "muṃḍanaṃ": ['ap90'],
    "muṃḍayati": ['ap90'],
    "muṃḍin": ['ap90'],
    "muṃḍita": ['ap90'],
    "muṃṭ": ['ap90'],
    "muṃṭh": ['ap90'],
    "muṅga": ['bhs', 'cae', 'ddsa', 'mw'],
    "muṅgaṭa": ['cae', 'mw'],
    "muṅgusa": ['cped'],
    "muṇ": ['ap90', 'mw'],
    "muṇḍ": ['mw'],
    "muṇḍa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "muṇḍacaṇaka": ['mw'],
    "muṇḍacchadda": ['cped'],
    "muṇḍadhānya": ['mw'],
    "muṇḍadhārin": ['cae', 'mw'],
    "muṇḍaja": ['mw'],
    "muṇḍaka": ['bhs', 'cae', 'cped', 'mw'],
    "muṇḍakhaṇḍeyopaniṣad": ['mw'],
    "muṇḍakopaniṣad": ['cae', 'mw'],
    "muṇḍakopaniṣadbhāṣya": ['mw'],
    "muṇḍakopaniṣaddīpikā": ['mw'],
    "muṇḍakopaniṣadāloka": ['mw'],
    "muṇḍakopaniṣatkhaṇḍārtha": ['mw'],
    "muṇḍaloha": ['mw'],
    "muṇḍamathanā": ['mw'],
    "muṇḍamaṇḍalī": ['mw'],
    "muṇḍamālinī": ['mw'],
    "muṇḍamālātantra": ['mw'],
    "muṇḍana": ['cae', 'ddsa', 'mw'],
    "muṇḍanaka": ['mw'],
    "muṇḍaneśa": ['mw'],
    "muṇḍanikā": ['mw'],
    "muṇḍanā": ['bhs'],
    "muṇḍaphala": ['mw'],
    "muṇḍapūla": ['bhs'],
    "muṇḍapṛṣṭha": ['mw'],
    "muṇḍatta": ['cped'],
    "muṇḍavedāṅga": ['mw'],
    "muṇḍay": ['cae'],
    "muṇḍaya": ['ddsa', 'mw'],
    "muṇḍaśayanāsanavārika": ['mw'],
    "muṇḍaśāli": ['mw'],
    "muṇḍaśṛṅkhalika": ['mw'],
    "muṇḍesi": ['cped'],
    "muṇḍeti": ['cped'],
    "muṇḍetvā": ['cped'],
    "muṇḍeśvaratīrtha": ['mw'],
    "muṇḍi": ['bhs'],
    "muṇḍibha": ['cae', 'mw'],
    "muṇḍika": ['bhs'],
    "muṇḍikā": ['mw'],
    "muṇḍin": ['cae', 'ddsa', 'mw'],
    "muṇḍita": ['cped', 'mw'],
    "muṇḍitamuṇḍa": ['mw'],
    "muṇḍitamūrdhan": ['mw'],
    "muṇḍitaprahasana": ['mw'],
    "muṇḍitaśiras": ['cae', 'mw'],
    "muṇḍitikā": ['mw'],
    "muṇḍitā": ['mw'],
    "muṇḍiya": ['cped'],
    "muṇḍā": ['bhs', 'mw'],
    "muṇḍākhyā": ['mw'],
    "muṇḍāpayati": ['bhs'],
    "muṇḍāra": ['mw'],
    "muṇḍāsana": ['mw'],
    "muṇḍāyasa": ['mw'],
    "muṇḍī": ['mw'],
    "muṇḍīkalpa": ['mw'],
    "muṇḍīra": ['mw'],
    "muṇḍīrikā": ['mw'],
    "muṇḍīrī": ['mw'],
    "muṇḍīśvaratīrtha": ['mw'],
    "muṇṭ": ['mw'],
    "muṇṭh": ['mw'],
    "muṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "muṣaka": ['mw'],
    "muṣakaḥ": ['ap90'],
    "muṣala": ['mw'],
    "muṣaṇa": ['bhs'],
    "muṣi": ['mw'],
    "muṣita": ['ap90', 'cae', 'mw'],
    "muṣitacetas": ['mw'],
    "muṣitaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "muṣitakaṃ": ['ap90'],
    "muṣitasmṛti": ['bhs', 'mw'],
    "muṣitasmṛtitā": ['mw'],
    "muṣitatrapa": ['mw'],
    "muṣiḥ": ['ap90'],
    "muṣka": ['cae', 'ddsa', 'gra', 'mw'],
    "muṣkabhāra": ['cae', 'gra', 'mw'],
    "muṣkadeśa": ['cae', 'mw'],
    "muṣkadvaya": ['mw'],
    "muṣkaka": ['mw'],
    "muṣkakacchū": ['mw'],
    "muṣkakaḥ": ['ap90'],
    "muṣkara": ['ap90', 'cae', 'mw'],
    "muṣkasrotas": ['mw'],
    "muṣkavant": ['cae'],
    "muṣkavat": ['mw'],
    "muṣkaśopha": ['mw'],
    "muṣkaśūnya": ['mw'],
    "muṣkaḥ": ['ap90'],
    "muṣkābarha": ['mw'],
    "muṣma": ['mw'],
    "muṣā": ['ap90', 'mw'],
    "muṣāy": ['cae', 'gra'],
    "muṣāya": ['ddsa', 'mw'],
    "muṣīvan": ['cae', 'ddsa', 'gra', 'mw'],
    "muṣṭa": ['ap90', 'mw'],
    "muṣṭadṛṣṭi": ['mw'],
    "muṣṭhaka": ['mw'],
    "muṣṭhakaḥ": ['ap90'],
    "muṣṭi": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "muṣṭibandha": ['bhs', 'mw'],
    "muṣṭibandham": ['mw'],
    "muṣṭideśa": ['mw'],
    "muṣṭidhaya": ['mw'],
    "muṣṭidyūta": ['mw'],
    "muṣṭighāta": ['mw'],
    "muṣṭigraha": ['mw'],
    "muṣṭigrāhya": ['mw'],
    "muṣṭihan": ['cae', 'gra', 'mw'],
    "muṣṭihatyā": ['gra', 'mw'],
    "muṣṭika": ['bhs', 'ddsa', 'mw'],
    "muṣṭikaghna": ['mw'],
    "muṣṭikaraṇa": ['mw'],
    "muṣṭikarman": ['mw'],
    "muṣṭikasvastika": ['mw'],
    "muṣṭikaḥ": ['ap90'],
    "muṣṭikā": ['ap90', 'mw'],
    "muṣṭikācintāmaṇi": ['mw'],
    "muṣṭikākathana": ['mw'],
    "muṣṭikāntaka": ['mw'],
    "muṣṭimeya": ['mw'],
    "muṣṭimpaca": ['mw'],
    "muṣṭimukha": ['mw'],
    "muṣṭimāndya": ['mw'],
    "muṣṭinyāsa": ['mw'],
    "muṣṭiprahāra": ['cae', 'mw'],
    "muṣṭipraśnacintana": ['mw'],
    "muṣṭipāta": ['mw'],
    "muṣṭistha": ['mw'],
    "muṣṭitā": ['mw'],
    "muṣṭivadha": ['mw'],
    "muṣṭivarcas": ['mw'],
    "muṣṭivisarga": ['mw'],
    "muṣṭiyoga": ['mw'],
    "muṣṭiyuddha": ['cae', 'mw'],
    "muṣṭiḥ": ['ap90'],
    "muṣṭiṃdhama": ['mw'],
    "muṣṭiṃdhayaḥ": ['ap90'],
    "muṣṭy": ['mw'],
    "muṣṭyaṅgula": ['mw'],
    "muṣṭyaṣṭaka": ['mw'],
    "muṣṭyāyojana": ['mw'],
    "muṣṭāmuṣṭi": ['ddsa', 'mw'],
    "muṣṭī": ['mw'],
    "muṣṭīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "muṣṭīmuṣṭi": ['ap90', 'mw'],
    "muṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "muṭa": ['bhs', 'cae', 'mw'],
    "muṭṭa": ['mw'],
    "muṭṭha": ['cped'],
    "muṭṭhasacca": ['cped'],
    "muṭṭhassatī": ['cped'],
    "muṭṭhi": ['cped'],
    "muṭṭhika": ['cped'],
    "muṭṭhimalla": ['cped'],
    "muṭṭhiyuddha": ['cped'],
    "myakṣ": ['cae', 'ddsa', 'gra', 'mw'],
    "mā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mābara": ['mw'],
    "mābhīda": ['mw'],
    "māca": ['mw'],
    "mācala": ['mw'],
    "mācalaḥ": ['ap90'],
    "mācaḥ": ['ap90'],
    "mācikā": ['ap90', 'mw'],
    "māciram": ['cae', 'ddsa', 'mw'],
    "mācākīya": ['mw'],
    "mācāla": ['mw'],
    "mācī": ['mw'],
    "mācīpattra": ['mw'],
    "māda": ['mw'],
    "mādadya": ['mw'],
    "mādaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "mādakatva": ['mw'],
    "mādakatā": ['mw'],
    "mādana": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "mādanī": ['mw'],
    "mādanīya": ['cae', 'mw'],
    "mādanīyaṃ": ['ap90'],
    "mādayitnu": ['cae', 'gra', 'mw'],
    "mādayitṛ": ['mw'],
    "mādayiṣṇu": ['cae', 'gra', 'mw'],
    "mādaḥ": ['ap90'],
    "mādhava": ['ap90', 'cae', 'ddsa', 'mw'],
    "mādhavabhaṭṭaprayoga": ['mw'],
    "mādhavabhikṣu": ['mw'],
    "mādhavacampū": ['mw'],
    "mādhavacandrakara": ['mw'],
    "mādhavacarita": ['mw'],
    "mādhavacikitsā": ['mw'],
    "mādhavadeva": ['mw'],
    "mādhavadruma": ['mw'],
    "mādhavadāsa": ['mw'],
    "mādhavagupta": ['ddsa', 'mw'],
    "mādhavaka": ['mw'],
    "mādhavakara": ['mw'],
    "mādhavakaḥ": ['ap90'],
    "mādhavakośa": ['mw'],
    "mādhavakālanirṇaya": ['mw'],
    "mādhavalaghukārikā": ['mw'],
    "mādhavamāgadha": ['mw'],
    "mādhavamāhātmya": ['mw'],
    "mādhavanandana": ['mw'],
    "mādhavanidāna": ['mw'],
    "mādhavapadābhirāma": ['mw'],
    "mādhavapriya": ['mw'],
    "mādhavaprācī": ['mw'],
    "mādhavapura": ['mw'],
    "mādhavapurī": ['mw'],
    "mādhavarāja": ['mw'],
    "mādhavarāmānandasarasvatī": ['mw'],
    "mādhavasaṃgraha": ['mw'],
    "mādhavasena": ['cae', 'mw'],
    "mādhavasenārājan": ['mw'],
    "mādhavasiṃha": ['mw'],
    "mādhavasomayājin": ['mw'],
    "mādhavastavarāja": ['mw'],
    "mādhavastuti": ['mw'],
    "mādhavatīrtha": ['mw'],
    "mādhavavallī": ['mw'],
    "mādhavavijaya": ['mw'],
    "mādhavaśāstrin": ['mw'],
    "mādhavendrapurī": ['mw'],
    "mādhaveṣṭā": ['mw'],
    "mādhavi": ['mw'],
    "mādhavikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "mādhavocita": ['mw'],
    "mādhavodbhava": ['mw'],
    "mādhavollāsa": ['mw'],
    "mādhavoṣita": ['mw'],
    "mādhavya": ['mw'],
    "mādhavyamānavaka": ['mw'],
    "mādhavyamāṇavaka": ['ddsa'],
    "mādhavābhyudayakāvya": ['mw'],
    "mādhavācarya": ['cae'],
    "mādhavācārya": ['mw'],
    "mādhavānala": ['mw'],
    "mādhavānalakathā": ['mw'],
    "mādhavānalakāmakandalakathā": ['mw'],
    "mādhavānalanāṭaka": ['mw'],
    "mādhavānandakāvya": ['mw'],
    "mādhavārya": ['mw'],
    "mādhavāśrama": ['mw'],
    "mādhavī": ['ap90', 'mw'],
    "mādhavīlatā": ['cae', 'ddsa', 'mw'],
    "mādhavīlatāgṛha": ['mw'],
    "mādhavīmaṇḍapa": ['cae', 'mw'],
    "mādhavīvana": ['mw'],
    "mādhavīvanamāhātmya": ['mw'],
    "mādhavīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "mādhavīyadhātuvṛtti": ['mw'],
    "mādhavīyanidāna": ['mw'],
    "mādhavīyavedārthaprakāśa": ['mw'],
    "mādhavīyā": ['mw'],
    "mādhu": ['mw'],
    "mādhucchandasa": ['mw'],
    "mādhuka": ['mw'],
    "mādhukara": ['ap90', 'ddsa', 'mw'],
    "mādhukarī": ['mw'],
    "mādhukarṇika": ['mw'],
    "mādhuki": ['mw'],
    "mādhumata": ['mw'],
    "mādhumataka": ['mw'],
    "mādhuparkika": ['ap90', 'cae', 'mw'],
    "mādhura": ['ddsa', 'mw'],
    "mādhuraṃ": ['ap90'],
    "mādhuri": ['mw'],
    "mādhurya": ['ddsa', 'mw'],
    "mādhuryakadambinī": ['mw'],
    "mādhuryaṃ": ['ap90'],
    "mādhurī": ['ap90', 'cae', 'mw'],
    "mādhutailika": ['mw'],
    "mādhva": ['ap90', 'ddsa', 'mw'],
    "mādhvaka": ['mw'],
    "mādhvakaṃ": ['ap90'],
    "mādhvasiddhāntasāra": ['mw'],
    "mādhvaśvi": ['mw'],
    "mādhvi": ['gra'],
    "mādhvika": ['cae', 'ddsa', 'mw'],
    "mādhvikaḥ": ['ap90'],
    "mādhvī": ['cae', 'ddsa', 'gra', 'mw'],
    "mādhvīka": ['cae', 'mw'],
    "mādhvīkaphala": ['mw'],
    "mādhvīkaṃ": ['ap90'],
    "mādhvīkā": ['mw'],
    "mādhvīmadhurā": ['mw'],
    "mādhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "mādhyama": ['ap90', 'cae', 'ddsa', 'mw'],
    "mādhyamaka": ['ap90', 'cae', 'mw'],
    "mādhyamakeya": ['mw'],
    "mādhyamasthya": ['mw'],
    "mādhyamika": ['bhs', 'cae', 'mw'],
    "mādhyamikā": ['mw'],
    "mādhyamikīya": ['mw'],
    "mādhyamineya": ['mw'],
    "mādhyandina": ['bhs', 'ddsa'],
    "mādhyastha": ['cae', 'ddsa', 'mw'],
    "mādhyasthaṃ": ['ap90'],
    "mādhyasthya": ['cae', 'mw'],
    "mādhyasya": ['ap90'],
    "mādhyaṃdina": ['ap90', 'cae', 'gra', 'mw'],
    "mādhyaṃdinagṛhya": ['mw'],
    "mādhyaṃdinasaṃdhyāprayoga": ['mw'],
    "mādhyaṃdinasaṃhitā": ['mw'],
    "mādhyaṃdinavat": ['mw'],
    "mādhyaṃdinaśākhā": ['mw'],
    "mādhyaṃdinaśākhīya": ['mw'],
    "mādhyaṃdineya": ['mw'],
    "mādhyaṃdini": ['mw'],
    "mādhyaṃdināraṇyakavyākhyā": ['mw'],
    "mādhyaṃdināyana": ['mw'],
    "mādhyaṃdinī": ['mw'],
    "mādhyaṃdinīya": ['mw'],
    "mādhyāhnika": ['ap90', 'cae', 'mw'],
    "mādhyāhnikamantra": ['mw'],
    "mādhyāhnikasaṃdhyāprayoga": ['mw'],
    "mādhyānhika": ['ddsa'],
    "mādhyāvarṣa": ['mw'],
    "mādhāta": ['bhs'],
    "mādhūcī": ['mw'],
    "mādhūka": ['ap90', 'cae', 'ddsa', 'mw'],
    "mādhūkara": ['mw'],
    "mādhūla": ['mw'],
    "mādin": ['mw'],
    "mādinī": ['mw'],
    "mādisa": ['cped'],
    "mādra": ['mw'],
    "mādrabāheya": ['mw'],
    "mādraka": ['ddsa', 'mw'],
    "mādrakaḥ": ['ap90'],
    "mādrakūlaka": ['mw'],
    "mādranagara": ['mw'],
    "mādravatī": ['ap90', 'cae', 'mw'],
    "mādravatīputra": ['cae'],
    "mādravatīsuta": ['mw'],
    "mādravatīsūnu": ['cae'],
    "mādreya": ['mw'],
    "mādreyaḥ": ['ap90'],
    "mādri": ['mw'],
    "mādrikā": ['mw'],
    "mādrinandana": ['mw'],
    "mādrukasthalaka": ['mw'],
    "mādrī": ['ap90', 'cae', 'ddsa', 'mw'],
    "mādrīpati": ['mw'],
    "mādrīpṛthāpati": ['mw'],
    "mādugha": ['mw'],
    "māduka": ['mw'],
    "mādurṇā": ['mw'],
    "māduṣa": ['ddsa', 'mw'],
    "māduṣatva": ['mw'],
    "mādya": ['mw'],
    "mādānaka": ['mw'],
    "mādānanda": ['mw'],
    "mādāyana": ['mw'],
    "mādṛkṣa": ['ap90'],
    "mādṛś": ['cae', 'ddsa', 'mw'],
    "mādṛśa": ['cae', 'mw'],
    "māgadha": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "māgadhadeśīya": ['mw'],
    "māgadhaka": ['bhs', 'cped', 'mw'],
    "māgadhamādhava": ['mw'],
    "māgadhapura": ['mw'],
    "māgadhika": ['ddsa', 'mw'],
    "māgadhikaḥ": ['ap90'],
    "māgadhikā": ['mw'],
    "māgadhā": ['ap90', 'mw'],
    "māgadhī": ['cped', 'mw'],
    "māgadya": ['mw'],
    "māgandika": ['bhs'],
    "māgasira": ['cped'],
    "māgavika": ['cped'],
    "māgavī": ['mw'],
    "māgha": ['cae', 'cped', 'ddsa', 'mw'],
    "māghacaitanya": ['mw'],
    "māghakāvya": ['cae', 'mw'],
    "māghamā": ['ap90', 'ddsa', 'mw'],
    "māghamāhātmya": ['mw'],
    "māghamāhātmyasaṃgraha": ['mw'],
    "māghamāsika": ['mw'],
    "māghapurāṇa": ['mw'],
    "māghapākṣika": ['mw'],
    "māghasnāna": ['mw'],
    "māghasnānavidhi": ['mw'],
    "māghavallabhā": ['mw'],
    "māghavana": ['ap90', 'ddsa', 'mw'],
    "māghavanī": ['mw'],
    "māghavata": ['ap90', 'ddsa', 'mw'],
    "māghavatacāpa": ['mw'],
    "māghavatī": ['mw'],
    "māghavyākhyā": ['mw'],
    "māghaśukla": ['cae', 'mw'],
    "māghaḥ": ['ap90'],
    "māghaṣṭeya": ['mw'],
    "māghodyāpana": ['mw'],
    "māghona": ['cae', 'ddsa', 'gra', 'mw'],
    "māghonī": ['mw'],
    "māghotsava": ['mw'],
    "māghya": ['mw'],
    "māghyaṃ": ['ap90'],
    "māghāta": ['cped'],
    "māghī": ['ddsa', 'mw'],
    "māghīpakṣa": ['mw'],
    "māghīpakṣayajanīya": ['mw'],
    "māh": ['ap90', 'mw'],
    "māhakasthalaka": ['mw'],
    "māhakasthalī": ['mw'],
    "māhaki": ['mw'],
    "māhakīprastha": ['mw'],
    "māhana": ['mw'],
    "māhanaḥ": ['ap90'],
    "māhanīya": ['mw'],
    "māhata": ['mw'],
    "māhela": ['mw'],
    "māhendra": ['cae', 'ddsa', 'mw'],
    "māhendraja": ['mw'],
    "māhendravāṇī": ['mw'],
    "māhendrī": ['mw'],
    "māheya": ['ap90', 'cae', 'ddsa', 'mw'],
    "māheyī": ['ap90', 'mw'],
    "māheśa": ['mw'],
    "māheśvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "māheśvarapada": ['mw'],
    "māheśvarapura": ['mw'],
    "māheśvaratantra": ['mw'],
    "māheśvaratā": ['mw'],
    "māheśvaropapurāṇa": ['mw'],
    "māheśvarī": ['mw'],
    "māheśvarītantra": ['mw'],
    "māheśī": ['mw'],
    "māheṃdra": ['ap90'],
    "māhika": ['mw'],
    "māhikīprastha": ['mw'],
    "māhina": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "māhināvat": ['gra', 'mw'],
    "māhira": ['mw'],
    "māhiraḥ": ['ap90'],
    "māhita": ['mw'],
    "māhitra": ['cae', 'ddsa', 'mw'],
    "māhitthi": ['mw'],
    "māhitya": ['mw'],
    "māhiṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "māhiṣaka": ['mw'],
    "māhiṣakaḥ": ['ap90'],
    "māhiṣasthalaka": ['mw'],
    "māhiṣasthalī": ['mw'],
    "māhiṣeya": ['cae', 'mw'],
    "māhiṣika": ['cae', 'mw'],
    "māhiṣikaḥ": ['ap90'],
    "māhiṣma": ['mw'],
    "māhiṣmateyaka": ['mw'],
    "māhiṣmatī": ['ap90', 'bhs', 'ddsa', 'mw'],
    "māhiṣya": ['cae', 'ddsa', 'mw'],
    "māhiṣyaḥ": ['ap90'],
    "māhiṣāḍḍaka": ['mw'],
    "māhula": ['mw'],
    "māhuradatta": ['mw'],
    "māhuṇḍaka": ['mw'],
    "māhā": ['ap90', 'mw'],
    "māhābhāgya": ['mw'],
    "māhābhāgyaṃ": ['ap90'],
    "māhācamasya": ['mw'],
    "māhācitti": ['mw'],
    "māhājanika": ['ap90', 'mw'],
    "māhājanīna": ['mw'],
    "māhākula": ['ap90', 'mw'],
    "māhākulīna": ['mw'],
    "māhānada": ['mw'],
    "māhānasa": ['ap90', 'mw'],
    "māhānāmana": ['ddsa', 'mw'],
    "māhānāmika": ['mw'],
    "māhānāmnika": ['mw'],
    "māhāprāṇa": ['ap90', 'mw'],
    "māhāputri": ['mw'],
    "māhārajana": ['cae', 'mw'],
    "māhārājika": ['ap90', 'mw'],
    "māhārājya": ['cae', 'ddsa', 'mw'],
    "māhārājyaṃ": ['ap90'],
    "māhārāṣṭra": ['cae', 'mw'],
    "māhārāṣṭrī": ['ap90', 'mw'],
    "māhātmika": ['ap90', 'cae', 'ddsa', 'mw'],
    "māhātmya": ['cae', 'mw'],
    "māhātmyaṃ": ['ap90'],
    "māhāvratika": ['mw'],
    "māhāvratī": ['mw'],
    "māhāvratīya": ['mw'],
    "māhāvārttika": ['mw'],
    "māhīna": ['gra', 'mw'],
    "māhīyatva": ['mw'],
    "mājala": ['mw'],
    "mājalapura": ['mw'],
    "mājalaḥ": ['ap90'],
    "mājava": ['mw'],
    "mājika": ['ddsa', 'mw'],
    "mājiraka": ['mw'],
    "mājīja": ['mw'],
    "mākali": ['mw'],
    "mākaliḥ": ['ap90'],
    "mākanda": ['cae', 'ddsa', 'mw'],
    "mākandaka": ['mw'],
    "mākandika": ['bhs', 'mw'],
    "mākandikā": ['mw'],
    "mākandī": ['mw'],
    "mākara": ['ap90', 'cae', 'ddsa', 'mw'],
    "mākaranda": ['cae', 'ddsa', 'mw'],
    "mākaraṃda": ['ap90'],
    "mākaṃdaḥ": ['ap90'],
    "mākaṣṭeya": ['mw'],
    "mākha": ['ap90', 'mw'],
    "mākhanalāla": ['mw'],
    "mākim": ['mw'],
    "mākis": ['cae', 'ddsa', 'gra', 'mw'],
    "mākkoṭaka": ['bhs'],
    "mākoṭa": ['mw'],
    "mākuli": ['cae', 'mw'],
    "mākāradhyāna": ['mw'],
    "mākī": ['cae', 'gra', 'mw'],
    "mākīm": ['cae', 'ddsa', 'gra', 'mw'],
    "mākīna": ['cae', 'gra', 'mw'],
    "mākṣavya": ['mw'],
    "mākṣavyāyaṇī": ['mw'],
    "mākṣika": ['ap90', 'cae', 'ddsa', 'mw'],
    "mākṣikadhātu": ['mw'],
    "mākṣikaja": ['mw'],
    "mākṣikaphala": ['mw'],
    "mākṣikasvāmin": ['mw'],
    "mākṣikāśarkarā": ['mw'],
    "mākṣikāśraya": ['mw'],
    "mākṣīka": ['ap90', 'cae', 'ddsa', 'mw'],
    "mākṣīkadhātu": ['mw'],
    "mākṣīkaśarkarā": ['mw'],
    "māla": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mālabhañjikā": ['mw'],
    "mālabhārin": ['ddsa', 'mw'],
    "mālacakraka": ['mw'],
    "mālada": ['mw'],
    "māladhānya": ['mw'],
    "mālahāyana": ['mw'],
    "mālajit": ['mw'],
    "mālajātaka": ['mw'],
    "mālaka": ['bhs', 'cae', 'cped', 'mw'],
    "mālakauśa": ['mw'],
    "mālakauśaḥ": ['ap90'],
    "mālakauśika": ['mw'],
    "mālakaḥ": ['ap90'],
    "mālakā": ['mw'],
    "mālakī": ['mw'],
    "mālamaṅgala": ['mw'],
    "mālamaṅgalabhāṇa": ['mw'],
    "mālasikā": ['mw'],
    "mālasī": ['ap90', 'mw'],
    "mālati": ['cae', 'mw'],
    "mālatikā": ['mw'],
    "mālatiḥ": ['ap90'],
    "mālatī": ['cae', 'cped', 'ddsa', 'mw'],
    "mālatīkṣāraka": ['mw'],
    "mālatīmādhava": ['cae', 'mw'],
    "mālatīmālā": ['mw'],
    "mālatīpattrikā": ['mw'],
    "mālatīphala": ['mw'],
    "mālatītīra": ['mw'],
    "mālatītīraja": ['mw'],
    "mālatītīrasambhava": ['mw'],
    "mālava": ['cae', 'ddsa', 'mw'],
    "mālavabhadra": ['mw'],
    "mālavadeśa": ['mw'],
    "mālavagauḍa": ['mw'],
    "mālavagupta": ['mw'],
    "mālavaka": ['mw'],
    "mālavakaḥ": ['ap90'],
    "mālavamaṇḍalādhipati": ['mw'],
    "mālavanṛpati": ['mw'],
    "mālavarti": ['mw'],
    "mālavarudra": ['mw'],
    "mālavastrī": ['mw'],
    "mālavaviṣaya": ['cae', 'mw'],
    "mālavaśrī": ['mw'],
    "mālavaḥ": ['ap90'],
    "mālavendra": ['mw'],
    "mālavikā": ['cae', 'ddsa', 'mw'],
    "mālavikāgnimitra": ['cae', 'mw'],
    "mālavodbhava": ['mw'],
    "mālavya": ['mw'],
    "mālavyadeśa": ['mw'],
    "mālavā": ['mw'],
    "mālavādhīśa": ['mw'],
    "mālavānaka": ['mw'],
    "mālavī": ['ddsa', 'mw'],
    "mālavīya": ['mw'],
    "mālaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "mālaśrī": ['mw'],
    "mālaḥ": ['ap90'],
    "mālaṭa": ['bhs'],
    "māleya": ['mw'],
    "māleyaḥ": ['ap90'],
    "māleyā": ['ap90', 'mw'],
    "māli": ['bhs', 'ddsa', 'mw'],
    "mālika": ['cae', 'cped', 'mw'],
    "mālikaḥ": ['ap90'],
    "mālikā": ['ap90', 'bhs', 'mw'],
    "mālin": ['ap90', 'cae', 'mw'],
    "mālindya": ['mw'],
    "mālinya": ['cae', 'ddsa', 'mw'],
    "mālinyaṃ": ['ap90'],
    "mālinī": ['bhs', 'cped', 'mw'],
    "mālinītantra": ['mw'],
    "mālinīvijaya": ['mw'],
    "mālita": ['ap90', 'mw'],
    "mālla": ['ddsa', 'mw'],
    "māllavāstava": ['mw'],
    "māllavī": ['ap90', 'mw'],
    "māllaḥ": ['ap90'],
    "māloji": ['mw'],
    "māloka": ['mw'],
    "mālopamā": ['cae', 'ddsa', 'mw'],
    "mālorjara": ['mw'],
    "mālu": ['bhs', 'ddsa', 'mw'],
    "māluda": ['bhs', 'mw'],
    "māludhāna": ['mw'],
    "māludhānī": ['mw'],
    "māludu": ['bhs'],
    "māluka": ['mw'],
    "mālukācchada": ['mw'],
    "mālulatā": ['mw'],
    "māluta": ['bhs', 'cped'],
    "mālutā": ['bhs'],
    "māluvā": ['bhs', 'cped', 'mw'],
    "māluḥ": ['ap90'],
    "mālvya": ['cae', 'mw'],
    "mālya": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mālyacitra": ['bhs'],
    "mālyadhara": ['bhs'],
    "mālyadāman": ['mw'],
    "mālyagrathana": ['mw'],
    "mālyaguṇāya": ['mw'],
    "mālyajīvaka": ['mw'],
    "mālyajīvin": ['mw'],
    "mālyapiṇḍaka": ['mw'],
    "mālyapuṣpa": ['mw'],
    "mālyapuṣpikā": ['mw'],
    "mālyavat": ['ap90', 'mw'],
    "mālyavatī": ['mw'],
    "mālyavṛtti": ['mw'],
    "mālyā": ['bhs', 'mw'],
    "mālyāpaṇa": ['mw'],
    "mālā": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "mālābhārī": ['cped'],
    "mālācumbaṭaka": ['cped'],
    "mālādhara": ['cped', 'mw'],
    "mālādharin": ['bhs'],
    "mālādharī": ['mw'],
    "mālādhāra": ['bhs', 'mw'],
    "mālādhārin": ['bhs'],
    "mālādhārī": ['bhs', 'cped'],
    "mālādāma": ['cped'],
    "mālādāman": ['mw'],
    "mālādīpaka": ['mw'],
    "mālādūrvā": ['mw'],
    "mālāgaccha": ['cped'],
    "mālāgranthi": ['mw'],
    "mālāguḷa": ['cped'],
    "mālāguṇa": ['cped', 'mw'],
    "mālāguṇaparikṣiptā": ['mw'],
    "mālāguṇā": ['mw'],
    "mālākamma": ['cped'],
    "mālākanda": ['mw'],
    "mālākara": ['mw'],
    "mālākaṇṭha": ['mw'],
    "mālākuṭa": ['mw'],
    "mālākuṭadantī": ['mw'],
    "mālākā": ['mw'],
    "mālākāra": ['cae', 'cped', 'ddsa', 'mw'],
    "mālākāriṇī": ['mw'],
    "mālālikā": ['mw'],
    "mālālī": ['mw'],
    "mālāmantra": ['mw'],
    "mālāmanu": ['mw'],
    "mālāmaya": ['mw'],
    "mālāphala": ['mw'],
    "mālāprastha": ['mw'],
    "mālāprasthaka": ['mw'],
    "mālāpuṭa": ['cped'],
    "mālāriṣṭā": ['mw'],
    "mālārūpa": ['mw'],
    "mālārūpatva": ['mw'],
    "mālārūpatā": ['mw'],
    "mālāsanadīpikā": ['mw'],
    "mālāsaṃskāra": ['mw'],
    "mālāsaṃskāravarṇana": ['mw'],
    "mālātṛṇa": ['mw'],
    "mālātṛṇaka": ['mw'],
    "mālāvaccha": ['cped'],
    "mālāvant": ['cae'],
    "mālāvat": ['mw'],
    "mālāvata": ['mw'],
    "mālāvatī": ['mw'],
    "mālāvihāra": ['bhs'],
    "mālāvādakhaṇḍa": ['mw'],
    "mālāyana": ['mw'],
    "mālāśodhana": ['mw'],
    "mālāṅka": ['mw'],
    "mālī": ['cped'],
    "mālīya": ['mw'],
    "mālūka": ['mw'],
    "mālūra": ['cae', 'cped', 'ddsa', 'mw'],
    "mālūraḥ": ['ap90'],
    "mām": ['ddsa', 'mw'],
    "māma": ['ap90', 'cae', 'ddsa', 'mw'],
    "māmaha": ['ddsa'],
    "māmaka": ['ap90', 'cae', 'cped', 'gra', 'mw'],
    "māmakesara": ['mw'],
    "māmakī": ['bhs', 'mw'],
    "māmakīna": ['ap90', 'cae', 'mw'],
    "māmalladevī": ['mw'],
    "māmanasāyati": ['mw'],
    "māmateya": ['cae', 'ddsa', 'gra', 'mw'],
    "māmiḍi": ['mw'],
    "māmpaśya": ['mw'],
    "māmudagajanavī": ['mw'],
    "māmukhī": ['mw'],
    "mān": ['ap90', 'mw'],
    "māna": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mānabhadraka": ['mw'],
    "mānabhañja": ['bhs'],
    "mānabhaṅga": ['mw'],
    "mānabhāj": ['cae', 'mw'],
    "mānabhṛt": ['cae', 'mw'],
    "mānada": ['cae', 'cped', 'mw'],
    "mānadeva": ['mw'],
    "mānadhana": ['mw'],
    "mānadhmāta": ['mw'],
    "mānadhānikā": ['mw'],
    "mānadā": ['mw'],
    "mānadīpikā": ['mw'],
    "mānagrahaṇa": ['cae', 'mw'],
    "mānagranthi": ['mw'],
    "mānagṛha": ['mw'],
    "mānahan": ['ddsa', 'mw'],
    "mānahāni": ['mw'],
    "mānaka": ['ddsa', 'mw'],
    "mānakalaha": ['mw'],
    "mānakali": ['mw'],
    "mānakanda": ['mw'],
    "mānakathana": ['mw'],
    "mānakūṭa": ['bhs', 'cped'],
    "mānakṛt": ['mw'],
    "mānakṣati": ['mw'],
    "mānamahat": ['mw'],
    "mānamandara": ['mw'],
    "mānamandira": ['mw'],
    "mānamanohara": ['mw'],
    "mānamauna": ['mw'],
    "mānamaya": ['mw'],
    "mānamañjarī": ['mw'],
    "mānamañjarīguṇaleśasūcakadaśaka": ['mw'],
    "mānampaca": ['mw'],
    "mānamānya": ['mw'],
    "mānamātra": ['mw'],
    "mānana": ['cae', 'cped', 'ddsa', 'mw'],
    "mānanaṃ": ['ap90'],
    "mānanīya": ['ap90', 'cae', 'mw'],
    "mānapara": ['ddsa', 'mw'],
    "mānaparikhaṇḍana": ['mw'],
    "mānaparā": ['mw'],
    "mānaprāṇa": ['mw'],
    "mānapuraḥsaram": ['mw'],
    "mānarandhrā": ['mw'],
    "mānarandhrī": ['mw'],
    "mānaratha": ['mw'],
    "mānasa": ['ap90', 'cae', 'cped', 'mw'],
    "mānasacārin": ['ddsa', 'mw'],
    "mānasagaṇitavidhi": ['mw'],
    "mānasaharaṇa": ['mw'],
    "mānasajanman": ['mw'],
    "mānasaka": ['bhs', 'cae'],
    "mānasakaraṇa": ['mw'],
    "mānasamuccayaṭīkā": ['mw'],
    "mānasanayana": ['mw'],
    "mānasanayanaprasādinī": ['mw'],
    "mānasapūjana": ['mw'],
    "mānasapūjā": ['mw'],
    "mānasapūjāprakāra": ['mw'],
    "mānasapūjāvidhi": ['mw'],
    "mānasaruj": ['mw'],
    "mānasasaṃtāpa": ['cae', 'mw'],
    "mānasatva": ['mw'],
    "mānasaukas": ['mw'],
    "mānasavega": ['mw'],
    "mānasaśuc": ['mw'],
    "mānasika": ['ap90', 'ddsa', 'mw'],
    "mānasiṃha": ['mw'],
    "mānasiṃhakīrtimuktāvalī": ['mw'],
    "mānaskṛta": ['mw'],
    "mānasoka": ['mw'],
    "mānasollāsa": ['mw'],
    "mānasollāsaprabandha": ['mw'],
    "mānasollāsavyākhyā": ['mw'],
    "mānasollāsavṛttānta": ['mw'],
    "mānasollāsavṛttāntavilāsa": ['mw'],
    "mānasopacārapūjāvidhi": ['mw'],
    "mānasotka": ['ddsa', 'mw'],
    "mānasottara": ['mw'],
    "mānastabdha": ['bhs'],
    "mānasthalaka": ['mw'],
    "mānasthiti": ['mw'],
    "mānastokīya": ['mw'],
    "mānasvarūpa": ['mw'],
    "mānasvarūpābhijñatva": ['mw'],
    "mānasya": ['mw'],
    "mānasā": ['ddsa'],
    "mānasācala": ['mw'],
    "mānasālaya": ['mw'],
    "mānasāra": ['ddsa', 'mw'],
    "mānasāyana": ['mw'],
    "mānasī": ['bhs', 'mw'],
    "mānasūtra": ['ddsa', 'mw'],
    "mānatantavya": ['mw'],
    "mānatas": ['mw'],
    "mānatthaddha": ['cped'],
    "mānatuṅga": ['mw'],
    "mānatva": ['bhs', 'mw'],
    "mānatā": ['mw'],
    "mānava": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "mānavadeva": ['cae', 'ddsa', 'mw'],
    "mānavadharmaśāstra": ['cae', 'mw'],
    "mānavagṛhyasūtra": ['cae', 'mw'],
    "mānavaka": ['bhs'],
    "mānavakalpasūtra": ['cae', 'mw'],
    "mānavant": ['cae'],
    "mānavapati": ['cae', 'mw'],
    "mānavapurāṇa": ['mw'],
    "mānavardhana": ['cae', 'mw'],
    "mānavarjaka": ['mw'],
    "mānavarjita": ['cae', 'ddsa', 'mw'],
    "mānavartika": ['mw'],
    "mānavarākṣasa": ['mw'],
    "mānavasaṃhitā": ['mw'],
    "mānavasy": ['gra'],
    "mānavasya": ['mw'],
    "mānavasāra": ['mw'],
    "mānavasūtra": ['mw'],
    "mānavat": ['ap90', 'ddsa', 'mw'],
    "mānavatī": ['mw'],
    "mānavaugha": ['mw'],
    "mānavavāstulakṣaṇa": ['mw'],
    "mānavaya": ['ddsa'],
    "mānavaśrautasūtra": ['mw'],
    "mānavedacampū": ['mw'],
    "mānavendra": ['cae', 'ddsa', 'mw'],
    "mānavendīyacarita": ['mw'],
    "mānaveya": ['mw'],
    "mānavikrayin": ['mw'],
    "mānavottara": ['mw'],
    "mānavya": ['mw'],
    "mānavyaṃ": ['ap90'],
    "mānavyāyanī": ['mw'],
    "mānavācala": ['mw'],
    "mānavādya": ['mw'],
    "mānavī": ['ddsa', 'mw'],
    "mānavīya": ['ap90', 'mw'],
    "mānavīyasaṃhitā": ['mw'],
    "mānaya": ['ddsa'],
    "mānayajña": ['mw'],
    "mānayitavya": ['cae', 'mw'],
    "mānayitṛ": ['ap90', 'cae', 'mw'],
    "mānayoga": ['cae', 'ddsa', 'mw'],
    "mānayāna": ['mw'],
    "mānaḥ": ['ap90'],
    "mānaḥśila": ['ap90', 'mw'],
    "mānda": ['cae', 'mw'],
    "māndhilava": ['mw'],
    "māndhyoda": ['mw'],
    "māndhāla": ['cae', 'ddsa', 'mw'],
    "māndhāta": ['bhs'],
    "māndhātaki": ['mw'],
    "māndhātra": ['mw'],
    "māndhātāpura": ['mw'],
    "māndhātṛ": ['cae', 'ddsa', 'mw'],
    "māndhātṛsūtra": ['bhs'],
    "māndhīra": ['mw'],
    "māndodareya": ['mw'],
    "māndra": ['mw'],
    "māndurika": ['mw'],
    "māndya": ['cae', 'ddsa', 'mw'],
    "māndyavyāja": ['mw'],
    "māndāra": ['bhs', 'ddsa', 'mw'],
    "māndāraka": ['bhs', 'mw'],
    "māndārava": ['bhs', 'mw'],
    "māndāria": ['gra'],
    "māndārya": ['cae', 'ddsa', 'gra', 'mw'],
    "mānenta": ['cped'],
    "mānesi": ['cped'],
    "māneti": ['cped'],
    "mānetvā": ['cped'],
    "māni": ['mw'],
    "mānia": ['gra'],
    "mānika": ['mw'],
    "mānikā": ['ap90', 'mw'],
    "mānin": ['ap90', 'cae', 'ddsa', 'mw'],
    "māninī": ['mw'],
    "mānita": ['ap90', 'cped', 'ddsa', 'mw'],
    "mānitasena": ['mw'],
    "mānitva": ['mw'],
    "mānitā": ['ap90', 'cae', 'ddsa', 'mw'],
    "mānmatha": ['ap90', 'cae', 'ddsa', 'mw'],
    "mānojñaka": ['mw'],
    "mānojñakaṃ": ['ap90'],
    "mānonmukta": ['mw'],
    "mānonmāda": ['mw'],
    "mānonmānikā": ['mw'],
    "mānonnata": ['mw'],
    "mānonnati": ['mw'],
    "mānotsekaparākramavyasanin": ['mw'],
    "mānotsāha": ['ddsa', 'mw'],
    "māntavya": ['mw'],
    "māntavyāyanī": ['mw'],
    "mānth": ['mw'],
    "mānthareṣaṇi": ['mw'],
    "māntharya": ['cae', 'ddsa', 'mw'],
    "mānthya": ['mw'],
    "mānthāla": ['cae', 'mw'],
    "mānthālava": ['cae', 'mw'],
    "mānthīlava": ['cae', 'mw'],
    "māntra": ['mw'],
    "māntravarṇika": ['ddsa', 'mw'],
    "māntravarṇikītva": ['mw'],
    "māntrika": ['cae', 'ddsa', 'mw'],
    "māntrita": ['mw'],
    "māntritya": ['mw'],
    "mānusa": ['cped'],
    "mānusaka": ['cped'],
    "mānusatta": ['cped'],
    "mānusika": ['cped'],
    "mānusī": ['cped'],
    "mānutantavya": ['ddsa', 'mw'],
    "mānuṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "mānuṣadaivika": ['cae', 'mw'],
    "mānuṣaka": ['ap90', 'bhs', 'ddsa', 'mw'],
    "mānuṣalaukika": ['mw'],
    "mānuṣamāṃsāda": ['mw'],
    "mānuṣanikāśana": ['mw'],
    "mānuṣapradhana": ['gra', 'mw'],
    "mānuṣarākṣasa": ['cae', 'mw'],
    "mānuṣarākṣasī": ['mw'],
    "mānuṣasambhava": ['mw'],
    "mānuṣatva": ['mw'],
    "mānuṣatā": ['ap90', 'cae', 'mw'],
    "mānuṣibuddha": ['mw'],
    "mānuṣopeta": ['mw'],
    "mānuṣya": ['cae', 'ddsa', 'mw'],
    "mānuṣyaka": ['cae', 'ddsa', 'mw'],
    "mānuṣyaṃ": ['ap90'],
    "mānuṣāda": ['mw'],
    "mānuṣādatva": ['mw'],
    "mānuṣī": ['ddsa', 'mw'],
    "mānuṣībhū": ['ddsa', 'mw'],
    "mānya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mānyamāna": ['gra', 'mw'],
    "mānyasthāna": ['cae', 'mw'],
    "mānyatva": ['mw'],
    "mānyava": ['mw'],
    "mānyavatī": ['mw'],
    "mānābharaṇa": ['mw'],
    "mānādhika": ['cae', 'mw'],
    "mānādhyāya": ['mw'],
    "mānāgnihotra": ['mw'],
    "mānānanda": ['mw'],
    "mānāndha": ['ddsa', 'mw'],
    "mānāpamāna": ['cae', 'mw'],
    "mānāpika": ['bhs'],
    "mānāpya": ['bhs', 'mw'],
    "mānārha": ['cae', 'mw'],
    "mānāsa": ['mw'],
    "mānāsakta": ['mw'],
    "mānātimāna": ['bhs'],
    "mānātva": ['bhs'],
    "mānāvabhaṅga": ['mw'],
    "mānāyana": ['mw'],
    "mānāyya": ['mw'],
    "mānāyyāyanī": ['mw'],
    "mānāṅgulamahātantra": ['mw'],
    "mānāṅka": ['mw'],
    "mānī": ['cped', 'mw'],
    "mānīndha": ['mw'],
    "māpaka": ['cped', 'ddsa', 'mw'],
    "māpana": ['mw'],
    "māpanaṃ": ['ap90'],
    "māpanā": ['cae', 'mw'],
    "māpatya": ['mw'],
    "māpatyaḥ": ['ap90'],
    "māpaya": ['mw'],
    "māpesi": ['cped'],
    "māpeti": ['cped'],
    "māpetvā": ['cped'],
    "māpika": ['cped'],
    "māpita": ['cped'],
    "māpya": ['mw'],
    "māra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mārabalapramardin": ['bhs'],
    "mārabandhana": ['cped'],
    "mārabīja": ['mw'],
    "māracittā": ['mw'],
    "mārada": ['mw'],
    "māradheyya": ['cped'],
    "māradhvaja": ['bhs'],
    "māradākāra": ['mw'],
    "mārahāṭhī": ['mw'],
    "mārahāṭī": ['mw'],
    "mārahāṭṭā": ['mw'],
    "mārajit": ['mw'],
    "mārajātaka": ['mw'],
    "māraka": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "mārakaraṇḍa": ['bhs'],
    "mārakata": ['ap90', 'cae', 'ddsa', 'mw'],
    "mārakatatva": ['mw'],
    "mārakāyika": ['bhs', 'cped', 'mw'],
    "māramaṇḍalanirghoṣasvara": ['bhs'],
    "māramohita": ['cae', 'mw'],
    "mārapa": ['mw'],
    "māraphī": ['mw'],
    "mārapramardaka": ['bhs'],
    "māraputra": ['mw'],
    "mārapāpīyas": ['mw'],
    "māraripu": ['cae', 'ddsa', 'mw'],
    "mārasenā": ['cped'],
    "mārasiṃha": ['mw'],
    "mārava": ['ap90', 'cae', 'ddsa', 'mw'],
    "māravarman": ['mw'],
    "māravat": ['ddsa', 'mw'],
    "māravī": ['mw'],
    "māraḥ": ['ap90'],
    "māraṇa": ['cae', 'cped', 'ddsa', 'mw'],
    "māraṇakarman": ['mw'],
    "māraṇakṛtya": ['mw'],
    "māraṇaṃ": ['ap90'],
    "māraṇāntika": ['bhs'],
    "māraṇī": ['mw'],
    "mārdalika": ['mw'],
    "mārdamarṣi": ['mw'],
    "mārdava": ['bhs', 'cae', 'ddsa', 'mw'],
    "mārdavabhāva": ['mw'],
    "mārdavaṃ": ['ap90'],
    "mārdavāyana": ['mw'],
    "mārdavīkṛ": ['mw'],
    "mārdaṃga": ['mw'],
    "mārdaṃgaḥ": ['ap90'],
    "mārdaṃgika": ['mw'],
    "mārdaṃgikapāṇavika": ['mw'],
    "mārdaṃgikaḥ": ['ap90'],
    "mārdaṅgika": ['ddsa'],
    "mārdeya": ['mw'],
    "mārdeyapura": ['mw'],
    "mārdvīka": ['ap90', 'mw'],
    "mārenta": ['cped'],
    "māresi": ['cped'],
    "māretar": ['cped'],
    "māreti": ['cped'],
    "māretuṁ": ['cped'],
    "māretvā": ['cped'],
    "mārg": ['ap90', 'cae', 'ddsa', 'mw'],
    "mārga": ['bhs', 'cae', 'ddsa', 'mw'],
    "mārgabandhana": ['mw'],
    "mārgadakṣaka": ['mw'],
    "mārgadarśaka": ['cae', 'mw'],
    "mārgadeśika": ['mw'],
    "mārgadhenu": ['mw'],
    "mārgadhenuka": ['mw'],
    "mārgadraṅga": ['mw'],
    "mārgadraṅgā": ['mw'],
    "mārgadruma": ['mw'],
    "mārgadāyinī": ['mw'],
    "mārgaharmya": ['mw'],
    "mārgaiṣin": ['mw'],
    "mārgaka": ['bhs', 'mw'],
    "mārgakaḥ": ['ap90'],
    "mārgakleśa": ['mw'],
    "mārgamadhyaga": ['mw'],
    "mārgamarṣi": ['mw'],
    "mārgapa": ['mw'],
    "mārgapariṇāyaka": ['mw'],
    "mārgapatha": ['mw'],
    "mārgapati": ['mw'],
    "mārgapranaṣṭa": ['mw'],
    "mārgapālī": ['mw'],
    "mārgarakṣaka": ['mw'],
    "mārgarodhin": ['mw'],
    "mārgasaṃdarśana": ['mw'],
    "mārgastha": ['cae', 'mw'],
    "mārgasthiti": ['mw'],
    "mārgatoraṇa": ['ddsa', 'mw'],
    "mārgatāla": ['mw'],
    "mārgava": ['cae', 'ddsa', 'mw'],
    "mārgavartman": ['mw'],
    "mārgavartmasu": ['mw'],
    "mārgavaśāgata": ['ddsa', 'mw'],
    "mārgavaśānuga": ['mw'],
    "mārgavaśāyāta": ['mw'],
    "mārgavaṭī": ['mw'],
    "mārgaveya": ['ddsa', 'mw'],
    "mārgavighna": ['mw'],
    "mārgavinodana": ['mw'],
    "mārgavāsas": ['mw'],
    "mārgavīya": ['mw'],
    "mārgayatha": ['mw'],
    "mārgaśira": ['mw'],
    "mārgaśiralakṣmīvāravratakalpa": ['mw'],
    "mārgaśiras": ['mw'],
    "mārgaśiraḥ": ['ap90'],
    "mārgaśirī": ['ap90', 'mw'],
    "mārgaśobhā": ['mw'],
    "mārgaśodhaka": ['mw'],
    "mārgaśākhin": ['ddsa', 'mw'],
    "mārgaśīrṣa": ['cae', 'mw'],
    "mārgaśīrṣaka": ['mw'],
    "mārgaśīrṣamāhātmya": ['mw'],
    "mārgaśīrṣādipūjā": ['mw'],
    "mārgaḥ": ['ap90'],
    "mārgaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "mārgaṇaka": ['mw'],
    "mārgaṇakaḥ": ['ap90'],
    "mārgaṇapriyā": ['mw'],
    "mārgaṇatā": ['bhs', 'mw'],
    "mārgaṇā": ['bhs'],
    "mārgeśa": ['ddsa', 'mw'],
    "mārgika": ['bhs', 'mw'],
    "mārgikaḥ": ['ap90'],
    "mārgin": ['ap90', 'mw'],
    "mārgita": ['ap90', 'ddsa', 'mw'],
    "mārgitavya": ['cae', 'mw'],
    "mārgodyotayitar": ['bhs'],
    "mārgopadiś": ['ddsa', 'mw'],
    "mārgya": ['mw'],
    "mārgāgata": ['cae', 'ddsa', 'mw'],
    "mārgākhyāyin": ['mw'],
    "mārgālī": ['ddsa', 'mw'],
    "mārgāra": ['mw'],
    "mārgāvalokin": ['cae', 'ddsa', 'mw'],
    "mārgāyaṇī": ['mw'],
    "mārgāyāta": ['cae', 'mw'],
    "mārgīyava": ['mw'],
    "māri": ['bhs', 'mw'],
    "mārica": ['ap90', 'ddsa', 'mw'],
    "māricika": ['ap90', 'mw'],
    "mārikā": ['ap90', 'ddsa', 'mw'],
    "mārin": ['ap90', 'cae', 'ddsa', 'mw'],
    "mārisa": ['cped'],
    "mārita": ['ap90', 'cped', 'mw'],
    "mārivyasanavāraka": ['mw'],
    "māriyamāna": ['cped'],
    "māriḥ": ['ap90'],
    "māriṇī": ['bhs'],
    "māriṣa": ['cae', 'ddsa', 'mw'],
    "māriṣaḥ": ['ap90'],
    "māriṣā": ['mw'],
    "mārj": ['ap90', 'mw'],
    "mārja": ['mw'],
    "mārjaka": ['ap90', 'mw'],
    "mārjana": ['ap90', 'cae', 'ddsa', 'mw'],
    "mārjanā": ['mw'],
    "mārjanī": ['bhs', 'mw'],
    "mārjanīya": ['mw'],
    "mārjara": ['bhs'],
    "mārjaḥ": ['ap90'],
    "mārjita": ['ap90', 'cae', 'ddsa', 'mw'],
    "mārjite": ['mw'],
    "mārjitā": ['ap90'],
    "mārjā": ['mw'],
    "mārjāla": ['bhs', 'mw'],
    "mārjālaḥ": ['ap90'],
    "mārjālia": ['gra'],
    "mārjālya": ['cae', 'gra', 'mw'],
    "mārjālīya": ['cae', 'ddsa', 'mw'],
    "mārjāra": ['cae', 'ddsa', 'mw'],
    "mārjāragandhikā": ['mw'],
    "mārjāragandhā": ['mw'],
    "mārjāraka": ['mw'],
    "mārjārakaraṇa": ['mw'],
    "mārjārakarṇikā": ['mw'],
    "mārjārakarṇī": ['mw'],
    "mārjārakaḥ": ['ap90'],
    "mārjārakaṇṭha": ['mw'],
    "mārjāraliṅgin": ['cae', 'mw'],
    "mārjāramūṣaka": ['mw'],
    "mārjāranyāya": ['mw'],
    "mārjāravaktra": ['mw'],
    "mārjāraḥ": ['ap90'],
    "mārjāri": ['mw'],
    "mārjārikā": ['mw'],
    "mārjārī": ['ap90', 'mw'],
    "mārjārīkramaṇa": ['mw'],
    "mārjārīya": ['mw'],
    "mārjārīyaḥ": ['ap90'],
    "mārka": ['mw'],
    "mārkava": ['mw'],
    "mārkaṃḍaḥ": ['ap90'],
    "mārkaṇḍa": ['mw'],
    "mārkaṇḍeya": ['cae', 'ddsa', 'mw'],
    "mārkaṇḍeyacarita": ['mw'],
    "mārkaṇḍeyadarśanastotra": ['mw'],
    "mārkaṇḍeyakavindra": ['mw'],
    "mārkaṇḍeyapurāṇa": ['cae', 'mw'],
    "mārkaṇḍeyasaṃhitā": ['mw'],
    "mārkaṇḍeyasmṛti": ['mw'],
    "mārkaṇḍeyastotra": ['mw'],
    "mārkaṇḍeyatīrtha": ['mw'],
    "mārkaṇḍeyī": ['mw'],
    "mārkaṇḍeśvaratīrtha": ['mw'],
    "mārkaṇḍikā": ['mw'],
    "mārkaṇḍī": ['mw'],
    "mārkaṇḍīya": ['mw'],
    "mārkaṭa": ['cae', 'ddsa', 'mw'],
    "mārkaṭapipīlikā": ['mw'],
    "mārkaṭi": ['mw'],
    "mārmika": ['ap90', 'mw'],
    "mārtavatsa": ['mw'],
    "mārtaṃḍaḥ": ['ap90'],
    "mārtaṇḍa": ['cae', 'ddsa', 'mw'],
    "mārtaṇḍadīpikā": ['mw'],
    "mārtaṇḍamaṇḍala": ['mw'],
    "mārtaṇḍamāhātmya": ['mw'],
    "mārtaṇḍapratimā": ['mw'],
    "mārtaṇḍatilakasvāmin": ['mw'],
    "mārtaṇḍavallabhā": ['mw'],
    "mārtaṇḍavedoddhāra": ['mw'],
    "mārtaṇḍaśataka": ['mw'],
    "mārtaṇḍārcana": ['mw'],
    "mārtaṇḍārcanacandrikā": ['mw'],
    "mārtaṇḍīya": ['ddsa', 'mw'],
    "mārtika": ['ap90'],
    "mārtsna": ['cae', 'mw'],
    "mārttika": ['cae', 'ddsa', 'mw'],
    "mārttikāvata": ['ddsa', 'mw'],
    "mārttikāvataka": ['mw'],
    "mārtya": ['ap90', 'mw'],
    "mārtyava": ['mw'],
    "mārtyuṃjayī": ['mw'],
    "mārtāṇḍa": ['cae', 'ddsa', 'gra', 'mw'],
    "mārudeva": ['mw'],
    "mārudha": ['mw'],
    "māruka": ['cae', 'ddsa', 'mw'],
    "mārulā": ['mw'],
    "māruta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mārutakopana": ['mw'],
    "mārutamaya": ['ddsa', 'mw'],
    "mārutamaṇḍana": ['mw'],
    "mārutantavya": ['mw'],
    "mārutapūrṇarandhra": ['mw'],
    "mārutaroga": ['mw'],
    "mārutasuta": ['mw'],
    "mārutasūnu": ['cae', 'mw'],
    "mārutavrata": ['mw'],
    "māruteśvaratīrtha": ['mw'],
    "māruti": ['cae', 'ddsa', 'mw'],
    "mārutimañjarī": ['mw'],
    "mārutipraṣṭha": ['mw'],
    "mārutiḥ": ['ap90'],
    "mārutodvellita": ['cae', 'mw'],
    "mārutotpatti": ['mw'],
    "mārutā": ['mw'],
    "mārutāndolita": ['cae', 'mw'],
    "mārutāpaha": ['mw'],
    "mārutāpūrṇa": ['mw'],
    "mārutātmaja": ['cae', 'mw'],
    "mārutāyana": ['mw'],
    "mārutāśana": ['mw'],
    "mārutāśva": ['gra', 'mw'],
    "mārutī": ['cae', 'ddsa', 'mw'],
    "māruvāra": ['mw'],
    "māruṃḍaḥ": ['ap90'],
    "māruṅga": ['mw'],
    "māruṇḍa": ['mw'],
    "mārābhibhu": ['mw'],
    "mārābhirāma": ['mw'],
    "mārāpana": ['cped'],
    "mārāpenta": ['cped'],
    "mārāpeti": ['cped'],
    "mārāpetvā": ['cped'],
    "mārāpita": ['cped'],
    "mārāri": ['cae', 'mw'],
    "mārātmaka": ['cae', 'mw'],
    "mārāvida": ['mw'],
    "mārāvika": ['mw'],
    "mārāṅka": ['mw'],
    "mārī": ['ap90', 'ddsa', 'mw'],
    "mārīca": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "mārīci": ['bhs', 'cae', 'mw'],
    "mārīcopapurāṇa": ['mw'],
    "mārīcya": ['cae', 'mw'],
    "mārīcī": ['bhs', 'mw'],
    "mārīmṛta": ['mw'],
    "mārīya": ['cae', 'ddsa', 'mw'],
    "mārḍyartha": ['mw'],
    "mārḍākava": ['mw'],
    "mārḍākavāyana": ['mw'],
    "mārḍīka": ['cae', 'ddsa', 'gra', 'mw'],
    "mārṇāla": ['mw'],
    "mārṣa": ['ap90', 'bhs', 'ddsa', 'mw'],
    "mārṣaka": ['mw'],
    "mārṣi": ['mw'],
    "mārṣika": ['mw'],
    "mārṣṭavya": ['ddsa', 'mw'],
    "mārṣṭi": ['cae', 'mw'],
    "mārṣṭimat": ['mw'],
    "mārṣṭiḥ": ['ap90'],
    "mās": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "māsa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "māsabhukti": ['mw'],
    "māsabhāj": ['mw'],
    "māsabhāvādhyāya": ['mw'],
    "māsacārika": ['mw'],
    "māsadarpaṇa": ['mw'],
    "māsadeya": ['mw'],
    "māsadhā": ['cae', 'mw'],
    "māsadvaya": ['mw'],
    "māsadvayodbhava": ['mw'],
    "māsajña": ['mw'],
    "māsajāta": ['mw'],
    "māsaka": ['cped', 'ddsa', 'mw'],
    "māsakaḥ": ['ap90'],
    "māsakālika": ['mw'],
    "māsala": ['mw'],
    "māsalaḥ": ['ap90'],
    "māsalokā": ['mw'],
    "māsamāna": ['mw'],
    "māsamīmāṃsā": ['mw'],
    "māsana": ['mw'],
    "māsanirṇaya": ['mw'],
    "māsanāman": ['mw'],
    "māsaphala": ['mw'],
    "māsapramita": ['mw'],
    "māsapraveśa": ['mw'],
    "māsapraveśasāriṇī": ['mw'],
    "māsapraveśānayana": ['mw'],
    "māsapāka": ['mw'],
    "māsapūrva": ['mw'],
    "māsara": ['cae', 'mw'],
    "māsaraḥ": ['ap90'],
    "māsasaṃcayika": ['cae', 'mw'],
    "māsastoma": ['mw'],
    "māsatama": ['mw'],
    "māsatraya": ['mw'],
    "māsatrayāvadhi": ['mw'],
    "māsatulya": ['mw'],
    "māsatālā": ['mw'],
    "māsavartikā": ['mw'],
    "māsaśas": ['cae', 'mw'],
    "māsaśivarātrivratakalpa": ['mw'],
    "māsaśivarātryudyāpana": ['mw'],
    "māsaḥ": ['ap90'],
    "māseśvaraphala": ['mw'],
    "māsika": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "māsikaśrāddha": ['mw'],
    "māsikaśrāddhanirṇaya": ['mw'],
    "māsikaśrāddhapaddhati": ['mw'],
    "māsikaśrāddhaprāyoga": ['mw'],
    "māsikānna": ['cae', 'mw'],
    "māsikārthavat": ['mw'],
    "māsiśrāddha": ['mw'],
    "māskarin": ['bhs'],
    "māsopavāsa": ['ddsa', 'mw'],
    "māsopavāsaka": ['bhs', 'mw'],
    "māsopavāsin": ['mw'],
    "māsopavāsinī": ['mw'],
    "māsurakarṇa": ['mw'],
    "māsurī": ['ap90', 'mw'],
    "māsya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "māsādhipa": ['mw'],
    "māsādhipati": ['mw'],
    "māsādhipatya": ['mw'],
    "māsādi": ['mw'],
    "māsādibhāvaphala": ['mw'],
    "māsādinirṇaya": ['mw'],
    "māsāgnihotravāda": ['mw'],
    "māsāhāra": ['mw'],
    "māsānta": ['mw'],
    "māsānumāsika": ['cae', 'mw'],
    "māsāpavarga": ['mw'],
    "māsāpavargatva": ['mw'],
    "māsāpavargatā": ['mw'],
    "māsārdhamāsa": ['mw'],
    "māsāvadhika": ['mw'],
    "māsīkṛ": ['ddsa', 'mw'],
    "māsīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "māsūra": ['ap90', 'cae', 'ddsa', 'mw'],
    "māta": ['mw'],
    "mātali": ['bhs', 'cae', 'ddsa', 'mw'],
    "mātalin": ['ddsa'],
    "mātalisārathi": ['cae', 'mw'],
    "mātaliḥ": ['ap90'],
    "mātalyupākhyāna": ['mw'],
    "mātalī": ['cae', 'cped', 'gra', 'mw'],
    "mātalīya": ['mw'],
    "mātar": ['cped'],
    "mātarapitarau": ['mw'],
    "mātari": ['mw'],
    "mātaribhvan": ['gra'],
    "mātaribhvarī": ['mw'],
    "mātaripuruṣa": ['mw'],
    "mātaripuruṣaḥ": ['ap90'],
    "mātariśva": ['mw'],
    "mātariśvaka": ['mw'],
    "mātariśvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mātariśvarī": ['mw'],
    "mātarāpitṛ": ['gra'],
    "mātavacasa": ['mw'],
    "mātavai": ['mw'],
    "mātaya": ['mw'],
    "mātaṃga": ['mw'],
    "mātaṃgadivākara": ['mw'],
    "mātaṃgaja": ['mw'],
    "mātaṃgaka": ['mw'],
    "mātaṃgakumārī": ['mw'],
    "mātaṃgalīlā": ['mw'],
    "mātaṃgalīlāprakāśikā": ['mw'],
    "mātaṃgalīlāvyākhyā": ['mw'],
    "mātaṃgamakara": ['mw'],
    "mātaṃgamātaṃga": ['mw'],
    "mātaṃganakra": ['mw'],
    "mātaṃgapati": ['mw'],
    "mātaṃgarāja": ['mw'],
    "mātaṃgasūtra": ['mw'],
    "mātaṃgatva": ['mw'],
    "mātaṃgaḥ": ['ap90'],
    "mātaṃgotsaṅga": ['mw'],
    "mātaṃgī": ['mw'],
    "mātaṃgīdaṇḍaka": ['mw'],
    "mātaṃgīdīpadānavidhāna": ['mw'],
    "mātaṃgīkarṇātakakathā": ['mw'],
    "mātaṃgīkrama": ['mw'],
    "mātaṃgīrahasya": ['mw'],
    "mātaṃgīstotra": ['mw'],
    "mātaṅga": ['bhs', 'cae', 'cped', 'ddsa'],
    "mātha": ['cae', 'ddsa', 'mw'],
    "māthaka": ['cae', 'mw'],
    "māthava": ['cae', 'ddsa', 'mw'],
    "māthaḥ": ['ap90'],
    "māthika": ['mw'],
    "māthitika": ['mw'],
    "māthura": ['ap90', 'cae', 'ddsa', 'mw'],
    "māthuradeśya": ['mw'],
    "māthuraka": ['mw'],
    "māthurī": ['mw'],
    "māthātha": ['mw'],
    "māti": ['gra', 'mw'],
    "mātika": ['cped'],
    "mātikā": ['cped'],
    "mātipakkha": ['cped'],
    "mātiḥ": ['ap90'],
    "mātputra": ['mw'],
    "mātra": ['ap90', 'bhs', 'ddsa', 'mw'],
    "mātrajña": ['bhs'],
    "mātrajñatā": ['bhs'],
    "mātraka": ['cae', 'ddsa', 'mw'],
    "mātrarāja": ['mw'],
    "mātratas": ['mw'],
    "mātratraya": ['mw'],
    "mātratva": ['mw'],
    "mātratā": ['cae', 'mw'],
    "mātrayā": ['mw'],
    "mātrika": ['mw'],
    "mātrikā": ['ap90', 'ddsa', 'mw'],
    "mātrā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mātrābhastrā": ['mw'],
    "mātrābhojin": ['bhs'],
    "mātrāchandas": ['cae', 'mw'],
    "mātrācyutaka": ['ddsa', 'mw'],
    "mātrādhika": ['mw'],
    "mātrādisrāddhanirṇaya": ['mw'],
    "mātrāguru": ['mw'],
    "mātrākośabhāravikā": ['mw'],
    "mātrākṛta": ['mw'],
    "mātrālakṣaṇa": ['mw'],
    "mātrālābha": ['mw'],
    "mātrāpacāra": ['mw'],
    "mātrāprayoga": ['mw'],
    "mātrārdha": ['mw'],
    "mātrāsamaka": ['mw'],
    "mātrāsaṃsarga": ['mw'],
    "mātrāsaṅga": ['cae', 'mw'],
    "mātrāsparśa": ['mw'],
    "mātrāsura": ['mw'],
    "mātrāvant": ['cae'],
    "mātrāvasti": ['mw'],
    "mātrāvat": ['mw'],
    "mātrāvidhānasūtra": ['mw'],
    "mātrāvṛtta": ['cae', 'mw'],
    "mātrāyām": ['mw'],
    "mātrāśin": ['cae', 'mw'],
    "mātrāśita": ['mw'],
    "mātrāśitīya": ['mw'],
    "mātrī": ['bhs'],
    "mātrīkṛ": ['mw'],
    "mātrīy": ['cae'],
    "mātrīya": ['ddsa', 'mw'],
    "mātsara": ['ap90', 'mw'],
    "mātsarika": ['ddsa', 'mw'],
    "mātsarya": ['cae', 'mw'],
    "mātsaryaṃ": ['ap90'],
    "mātsika": ['bhs', 'mw'],
    "mātsya": ['cae', 'ddsa', 'mw'],
    "mātsyagandha": ['mw'],
    "mātsyaka": ['mw'],
    "mātsyapurāṇa": ['mw'],
    "mātsyeya": ['mw'],
    "mātsyika": ['mw'],
    "mātsyikaḥ": ['ap90'],
    "mātu": ['mw'],
    "mātucchā": ['cped'],
    "mātughāta": ['cped'],
    "mātughātaka": ['cped'],
    "mātugāma": ['cped'],
    "mātukucchi": ['cped'],
    "mātula": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mātulaka": ['cae', 'mw'],
    "mātulakaḥ": ['ap90'],
    "mātulaputra": ['mw'],
    "mātulaputraka": ['mw'],
    "mātulasutāpariṇaya": ['mw'],
    "mātulaḥ": ['ap90'],
    "mātulaṅga": ['cae', 'mw'],
    "mātuleya": ['cae', 'ddsa', 'mw'],
    "mātuleyaḥ": ['ap90'],
    "mātuleyī": ['mw'],
    "mātuliṃgaḥ": ['ap90'],
    "mātuliṅga": ['cae', 'mw'],
    "mātuliṅgī": ['mw'],
    "mātuluṅga": ['cae', 'cped', 'ddsa', 'mw'],
    "mātuluṅgaka": ['mw'],
    "mātuluṅgaphala": ['mw'],
    "mātuluṅgarasa": ['mw'],
    "mātuluṅgikā": ['mw'],
    "mātuluṅgā": ['mw'],
    "mātuluṅgāsava": ['mw'],
    "mātuluṅgī": ['mw'],
    "mātulya": ['mw'],
    "mātulā": ['ap90', 'mw'],
    "mātulāhi": ['mw'],
    "mātulānī": ['cae', 'cped', 'ddsa', 'mw'],
    "mātulātmaja": ['mw'],
    "mātulī": ['mw'],
    "mātupaṭṭhāna": ['cped'],
    "mātuposaka": ['cped'],
    "mātur": ['mw'],
    "mātura": ['ddsa', 'mw'],
    "māturbhrātra": ['mw'],
    "mātuḥ": ['mw'],
    "mātuḥsvasṛ": ['mw'],
    "mātuḥṣvasṛ": ['mw'],
    "mātva": ['mw'],
    "mātyā": ['mw'],
    "mātā": ['ap90', 'ddsa', 'mw'],
    "mātāduhitṛ": ['cae', 'mw'],
    "mātālava": ['mw'],
    "mātālī": ['mw'],
    "mātāmaha": ['cae', 'cped', 'mw'],
    "mātāmahaḥ": ['ap90'],
    "mātāmahī": ['cped', 'mw'],
    "mātāmahīya": ['mw'],
    "mātāpaitṛka": ['bhs'],
    "mātāpettibhara": ['cped'],
    "mātāpettika": ['cped'],
    "mātāpitar": ['cped'],
    "mātāpitṛ": ['bhs', 'cae', 'mw'],
    "mātāpitṛghātaka": ['mw'],
    "mātāpitṛjña": ['bhs'],
    "mātāpitṛka": ['bhs'],
    "mātāpitṛsahasra": ['mw'],
    "mātāpitṛsaṃjñin": ['mw'],
    "mātāpitṛvihīna": ['mw'],
    "mātāputra": ['mw'],
    "mātī": ['mw'],
    "mātṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mātṛbandhu": ['mw'],
    "mātṛbandhū": ['mw'],
    "mātṛbhakti": ['cae', 'mw'],
    "mātṛbhedatantra": ['mw'],
    "mātṛbhogīṇa": ['mw'],
    "mātṛbhāva": ['mw'],
    "mātṛbāndhava": ['mw'],
    "mātṛcakra": ['mw'],
    "mātṛcakrapramathana": ['mw'],
    "mātṛceṭa": ['mw'],
    "mātṛdatta": ['mw'],
    "mātṛdattā": ['mw'],
    "mātṛdattīya": ['mw'],
    "mātṛdeva": ['mw'],
    "mātṛdoṣa": ['mw'],
    "mātṛdāsa": ['mw'],
    "mātṛgandhinī": ['mw'],
    "mātṛgarbha": ['mw'],
    "mātṛgarbhastha": ['mw'],
    "mātṛgaṇa": ['mw'],
    "mātṛghna": ['mw'],
    "mātṛghāta": ['mw'],
    "mātṛghātaka": ['mw'],
    "mātṛghātin": ['mw'],
    "mātṛghātuka": ['mw'],
    "mātṛgotra": ['mw'],
    "mātṛgotranirṇaya": ['mw'],
    "mātṛgrāma": ['bhs', 'mw'],
    "mātṛgrāmadoṣa": ['mw'],
    "mātṛgupta": ['cae', 'mw'],
    "mātṛguptābhiṣeṇana": ['mw'],
    "mātṛgāmin": ['mw'],
    "mātṛgṛha": ['mw'],
    "mātṛhan": ['cae', 'mw'],
    "mātṛjña": ['bhs', 'mw'],
    "mātṛka": ['ap90', 'cae', 'ddsa', 'mw'],
    "mātṛkacchida": ['mw'],
    "mātṛkalpika": ['mw'],
    "mātṛkeśaṭa": ['mw'],
    "mātṛkodaya": ['mw'],
    "mātṛkula": ['mw'],
    "mātṛkā": ['bhs', 'mw'],
    "mātṛkābhedatantra": ['mw'],
    "mātṛkābijakośa": ['mw'],
    "mātṛkāhṛdaya": ['mw'],
    "mātṛkājaganmaṅgalakavaca": ['mw'],
    "mātṛkākośa": ['mw'],
    "mātṛkākṣaranighaṇṭu": ['mw'],
    "mātṛkāmaha": ['mw'],
    "mātṛkāmaya": ['mw'],
    "mātṛkānighaṇṭu": ['mw'],
    "mātṛkānyāsa": ['mw'],
    "mātṛkāpravaṇa": ['mw'],
    "mātṛkāpuṣpamālikā": ['mw'],
    "mātṛkāpūjana": ['mw'],
    "mātṛkāpūjanavidhi": ['mw'],
    "mātṛkārthacintana": ['mw'],
    "mātṛkārṇava": ['mw'],
    "mātṛkāsthāpana": ['mw'],
    "mātṛkātantra": ['mw'],
    "mātṛkāviveka": ['mw'],
    "mātṛkāyantra": ['mw'],
    "mātṛkṛta": ['mw'],
    "mātṛmant": ['cae'],
    "mātṛmat": ['mw'],
    "mātṛmaṇḍala": ['mw'],
    "mātṛmaṇḍalavid": ['mw'],
    "mātṛmodaka": ['mw'],
    "mātṛmukha": ['mw'],
    "mātṛmātṛ": ['mw'],
    "mātṛmṛṣṭa": ['gra', 'mw'],
    "mātṛnandana": ['mw'],
    "mātṛnandin": ['mw'],
    "mātṛnivātam": ['mw'],
    "mātṛnāman": ['mw'],
    "mātṛpakṣa": ['mw'],
    "mātṛpitṛkṛtābhyāsa": ['mw'],
    "mātṛprayoga": ['mw'],
    "mātṛpālita": ['mw'],
    "mātṛpūjana": ['mw'],
    "mātṛpūjā": ['mw'],
    "mātṛsiṃhī": ['mw'],
    "mātṛsvaseyā": ['mw'],
    "mātṛsvasṛ": ['mw'],
    "mātṛtama": ['gra', 'mw'],
    "mātṛtamā": ['cae', 'ddsa'],
    "mātṛtas": ['cae', 'mw'],
    "mātṛtā": ['mw'],
    "mātṛvadha": ['mw'],
    "mātṛvartin": ['mw'],
    "mātṛvat": ['cae', 'mw'],
    "mātṛvatsala": ['cae', 'mw'],
    "mātṛvaṃśa": ['mw'],
    "mātṛvaṃśya": ['mw'],
    "mātṛvidūṣita": ['mw'],
    "mātṛviṣṇu": ['mw'],
    "mātṛvāhinī": ['mw'],
    "mātṛyajña": ['mw'],
    "mātṛyo": ['bhs'],
    "mātṛyāga": ['mw'],
    "mātṛśiṣṭa": ['mw'],
    "mātṛśrāddha": ['mw'],
    "mātṛśāsita": ['mw'],
    "mātṛṣaṣṭha": ['mw'],
    "mātṛṣeṇa": ['mw'],
    "mātṛṣvaseya": ['cae', 'mw'],
    "mātṛṣvaseyī": ['mw'],
    "mātṛṣvasrīya": ['mw'],
    "mātṛṣvasṛ": ['cae', 'mw'],
    "māutha": ['mw'],
    "māvant": ['cae'],
    "māvat": ['ddsa', 'gra', 'mw'],
    "māvella": ['mw'],
    "māvellaka": ['mw'],
    "māvilambam": ['cae', 'ddsa', 'mw'],
    "māvilambitam": ['mw'],
    "māya": ['ap90', 'bhs', 'ddsa', 'mw'],
    "māyadāsa": ['mw'],
    "māyati": ['bhs'],
    "māyatā": ['bhs'],
    "māyava": ['gra', 'mw'],
    "māyavant": ['cae'],
    "māyavat": ['mw'],
    "māyaṇa": ['mw'],
    "māyeya": ['mw'],
    "māyi": ['mw'],
    "māyibhairavatantra": ['mw'],
    "māyika": ['ap90', 'cae', 'ddsa', 'mw'],
    "māyikabhairava": ['mw'],
    "māyikāya": ['mw'],
    "māyimatakhaṇḍana": ['mw'],
    "māyin": ['ap90', 'cae', 'gra', 'mw'],
    "māyiphala": ['mw'],
    "māyitā": ['mw'],
    "māyobhava": ['cae', 'ddsa', 'mw'],
    "māyobhavya": ['mw'],
    "māyopajīvin": ['mw'],
    "māyu": ['cae', 'ddsa', 'gra', 'mw'],
    "māyuka": ['mw'],
    "māyurāja": ['mw'],
    "māyus": ['mw'],
    "māyuḥ": ['ap90'],
    "māyya": ['mw'],
    "māyā": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "māyābalavat": ['mw'],
    "māyābaṭu": ['mw'],
    "māyābhyudayana": ['mw'],
    "māyābījakalpa": ['mw'],
    "māyācaṇa": ['mw'],
    "māyāchadmapara": ['mw'],
    "māyācidyoga": ['mw'],
    "māyācāra": ['mw'],
    "māyāda": ['mw'],
    "māyādarśana": ['mw'],
    "māyādevī": ['cae', 'mw'],
    "māyādevīsuta": ['mw'],
    "māyādhara": ['cae', 'mw'],
    "māyādhika": ['mw'],
    "māyājālamahāyogatantra": ['bhs'],
    "māyājīvin": ['mw'],
    "māyākapota": ['cae', 'ddsa'],
    "māyākāpālika": ['mw'],
    "māyākāra": ['bhs', 'cped', 'mw'],
    "māyākṛt": ['mw'],
    "māyākṣetramāhātmya": ['mw'],
    "māyālīlāmata": ['mw'],
    "māyāmata": ['mw'],
    "māyāmaya": ['ap90', 'cae', 'mw'],
    "māyāmaṇavaka": ['mw'],
    "māyāmoha": ['mw'],
    "māyāmāhātmya": ['mw'],
    "māyāmṛga": ['cae', 'mw'],
    "māyānvita": ['mw'],
    "māyāpati": ['mw'],
    "māyāpaṭu": ['cae', 'mw'],
    "māyāphala": ['mw'],
    "māyāprayoga": ['mw'],
    "māyāpur": ['mw'],
    "māyāpurī": ['mw'],
    "māyāpurīmāhātmya": ['mw'],
    "māyārasika": ['mw'],
    "māyārati": ['mw'],
    "māyārāvaṇa": ['mw'],
    "māyāsura": ['mw'],
    "māyāsuta": ['mw'],
    "māyātantra": ['mw'],
    "māyāti": ['mw'],
    "māyātiḥ": ['ap90'],
    "māyātmaka": ['mw'],
    "māyāvacana": ['cae', 'mw'],
    "māyāvani": ['mw'],
    "māyāvant": ['cae'],
    "māyāvasika": ['mw'],
    "māyāvat": ['ap90', 'gra', 'mw'],
    "māyāvatī": ['mw'],
    "māyāvid": ['cae', 'mw'],
    "māyāvidhijña": ['mw'],
    "māyāvimālikā": ['mw'],
    "māyāvin": ['ap90', 'cae', 'gra', 'mw'],
    "māyāvitā": ['mw'],
    "māyāvāda": ['cae', 'mw'],
    "māyāvādakhaṇḍana": ['mw'],
    "māyāvādakhaṇḍanaṭippaṇī": ['mw'],
    "māyāvādakhaṇḍanaṭīkā": ['mw'],
    "māyāvādakhaṇḍavivaraṇa": ['mw'],
    "māyāvādasaṃdūṣaṇī": ['mw'],
    "māyāvī": ['cped'],
    "māyāyamaka": ['mw'],
    "māyāyantra": ['cae', 'mw'],
    "māyāyantravimāna": ['mw'],
    "māyāyin": ['mw'],
    "māyāyodhin": ['mw'],
    "māyāyoga": ['cae', 'mw'],
    "māyāśīla": ['mw'],
    "māyāṣṭaka": ['mw'],
    "māyīya": ['mw'],
    "māyūka": ['cae', 'mw'],
    "māyūra": ['ap90', 'cae', 'ddsa', 'mw'],
    "māyūraka": ['mw'],
    "māyūrakalpa": ['mw'],
    "māyūrakarṇa": ['mw'],
    "māyūrakaḥ": ['ap90'],
    "māyūravratin": ['bhs', 'mw'],
    "māyūri": ['mw'],
    "māyūrika": ['mw'],
    "māyūrikā": ['mw'],
    "māyūrī": ['bhs', 'mw'],
    "māñjiṣṭha": ['cae', 'ddsa', 'mw'],
    "māñjiṣṭhaka": ['cae', 'mw'],
    "māñjiṣṭhika": ['cae', 'mw'],
    "māñjiṣṭhīkṛ": ['mw'],
    "māñjīraka": ['mw'],
    "māśabdika": ['mw'],
    "māḍ": ['mw'],
    "māḍa": ['bhs', 'mw'],
    "māḍava": ['ddsa', 'mw'],
    "māḍaḥ": ['ap90'],
    "māḍhi": ['mw'],
    "māḍhiḥ": ['ap90'],
    "māḍi": ['mw'],
    "māḍiḥ": ['ap90'],
    "māḍārya": ['mw'],
    "māḍḍuka": ['mw'],
    "māḍḍukaḥ": ['ap90'],
    "māḍḍukika": ['mw'],
    "māṃdhātṛ": ['ap90'],
    "māṃdyaṃ": ['ap90'],
    "māṃdāraḥ": ['ap90'],
    "māṃgalika": ['ap90'],
    "māṃgalya": ['ap90'],
    "māṃjiṣṭha": ['ap90'],
    "māṃjiṣṭhika": ['ap90'],
    "māṃkṣ": ['ap90'],
    "māṃs": ['ap90', 'cae', 'ddsa', 'mw'],
    "māṃsa": ['cae', 'ddsa', 'gra', 'mw'],
    "māṃsabala": ['bhs'],
    "māṃsabhakṣa": ['mw'],
    "māṃsabhakṣaṇa": ['mw'],
    "māṃsabhakṣaṇadīpikā": ['mw'],
    "māṃsabhettṛ": ['cae', 'mw'],
    "māṃsabhikṣā": ['gra', 'mw'],
    "māṃsabhūta": ['cae', 'mw'],
    "māṃsabhūtodana": ['mw'],
    "māṃsabudbudavat": ['mw'],
    "māṃsacakṣu": ['bhs'],
    "māṃsacakṣus": ['mw'],
    "māṃsacaru": ['mw'],
    "māṃsacchadā": ['mw'],
    "māṃsaccheda": ['mw'],
    "māṃsacchedin": ['mw'],
    "māṃsadagdha": ['mw'],
    "māṃsadalana": ['mw'],
    "māṃsadhauta": ['mw'],
    "māṃsadhāvana": ['mw'],
    "māṃsadrāvin": ['mw'],
    "māṃsagranthi": ['mw'],
    "māṃsagṛdhyin": ['cae', 'mw'],
    "māṃsahāsā": ['mw'],
    "māṃsaja": ['bhs', 'mw'],
    "māṃsaka": ['bhs'],
    "māṃsakacchapa": ['mw'],
    "māṃsakandī": ['mw'],
    "māṃsakara": ['mw'],
    "māṃsakhaṇḍa": ['cae', 'mw'],
    "māṃsakāma": ['mw'],
    "māṃsakārin": ['mw'],
    "māṃsakīla": ['bhs', 'mw'],
    "māṃsakṣaya": ['mw'],
    "māṃsala": ['ap90', 'cae', 'ddsa', 'mw'],
    "māṃsalaphalā": ['mw'],
    "māṃsalatā": ['ddsa', 'mw'],
    "māṃsalubdha": ['cae', 'mw'],
    "māṃsamaithuna": ['mw'],
    "māṃsamaya": ['cae', 'mw'],
    "māṃsamayīpeśī": ['mw'],
    "māṃsamukha": ['mw'],
    "māṃsamāṣā": ['mw'],
    "māṃsamīmāṃsā": ['mw'],
    "māṃsaniryāsa": ['mw'],
    "māṃsanirṇaya": ['mw'],
    "māṃsanvat": ['mw'],
    "māṃsapa": ['mw'],
    "māṃsapacana": ['mw'],
    "māṃsaparivarjana": ['mw'],
    "māṃsaparivikrayin": ['mw'],
    "māṃsapeśī": ['cae', 'mw'],
    "māṃsaphala": ['mw'],
    "māṃsaphalā": ['mw'],
    "māṃsapitta": ['mw'],
    "māṃsapiṇḍa": ['mw'],
    "māṃsapiṇḍagṛhītavadana": ['mw'],
    "māṃsapiṭaka": ['mw'],
    "māṃsapraroha": ['mw'],
    "māṃsapuṣpikā": ['mw'],
    "māṃsapāka": ['mw'],
    "māṃsapīyūṣalatā": ['mw'],
    "māṃsarasa": ['mw'],
    "māṃsarohikā": ['mw'],
    "māṃsarohiṇī": ['mw'],
    "māṃsarohā": ['mw'],
    "māṃsarohī": ['mw'],
    "māṃsaruci": ['cae', 'mw'],
    "māṃsaruhā": ['mw'],
    "māṃsasaṃghāta": ['mw'],
    "māṃsasneha": ['mw'],
    "māṃsasāra": ['mw'],
    "māṃsatas": ['mw'],
    "māṃsatejas": ['mw'],
    "māṃsatva": ['mw'],
    "māṃsatāna": ['mw'],
    "māṃsaudana": ['mw'],
    "māṃsaudanapiṇḍa": ['mw'],
    "māṃsaudanika": ['mw'],
    "māṃsavarṣin": ['mw'],
    "māṃsavat": ['mw'],
    "māṃsavikraya": ['cae', 'mw'],
    "māṃsavikrayin": ['cae', 'mw'],
    "māṃsavikretṛ": ['cae', 'mw'],
    "māṃsaviveka": ['mw'],
    "māṃsavṛddhi": ['mw'],
    "māṃsayoni": ['mw'],
    "māṃsayūtha": ['mw'],
    "māṃsaśoṇita": ['mw'],
    "māṃsaśoṇitalepana": ['cae'],
    "māṃsaśoṇitapaṅkin": ['mw'],
    "māṃsaśukrala": ['mw'],
    "māṃsaśīla": ['mw'],
    "māṃsaṃ": ['ap90'],
    "māṃsepad": ['mw'],
    "māṃseṣṭā": ['mw'],
    "māṃsi": ['mw'],
    "māṃsika": ['bhs', 'mw'],
    "māṃsikaḥ": ['ap90'],
    "māṃsikā": ['mw'],
    "māṃsinī": ['mw'],
    "māṃsodana": ['mw'],
    "māṃsonnati": ['mw'],
    "māṃsopajīvin": ['mw'],
    "māṃspacana": ['ddsa', 'gra', 'mw'],
    "māṃspāka": ['mw'],
    "māṃspṛṣṭa": ['mw'],
    "māṃsād": ['cae', 'mw'],
    "māṃsāda": ['cae', 'mw'],
    "māṃsādin": ['cae', 'mw'],
    "māṃsāhāra": ['mw'],
    "māṃsānaśana": ['mw'],
    "māṃsārbuda": ['mw'],
    "māṃsārgala": ['mw'],
    "māṃsāśana": ['cae', 'mw'],
    "māṃsāśin": ['cae', 'mw'],
    "māṃsāśitva": ['mw'],
    "māṃsāśā": ['mw'],
    "māṃsāṣṭakā": ['mw'],
    "māṃsī": ['mw'],
    "māṃsīy": ['cae'],
    "māṃsīya": ['mw'],
    "māṃth": ['ap90'],
    "māṃtharyaṃ": ['ap90'],
    "māṃtrikaḥ": ['ap90'],
    "māṃścatu": ['gra', 'mw'],
    "māṃścatva": ['gra', 'mw'],
    "māṃḍalika": ['ap90'],
    "māṅ": ['ddsa'],
    "māṅgala": ['mw'],
    "māṅgali": ['mw'],
    "māṅgalika": ['cae', 'ddsa', 'mw'],
    "māṅgalikya": ['mw'],
    "māṅgalikā": ['mw'],
    "māṅgalya": ['cae', 'ddsa', 'mw'],
    "māṅgalyamṛdaṃga": ['mw'],
    "māṅgalyanāman": ['mw'],
    "māṅgalyārhā": ['mw'],
    "māṅguṣya": ['mw'],
    "māṅkaḍa": ['mw'],
    "māṅkṣ": ['mw'],
    "māṅkṣavya": ['mw'],
    "māṅkṣavyāyaṇī": ['mw'],
    "māṇa": ['bhs', 'cped', 'mw'],
    "māṇahala": ['mw'],
    "māṇaka": ['mw'],
    "māṇakīvrata": ['mw'],
    "māṇava": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "māṇavaka": ['cae', 'cped', 'mw'],
    "māṇavakakrīḍa": ['mw'],
    "māṇavakakrīḍanaka": ['mw'],
    "māṇavakakrīḍitaka": ['mw'],
    "māṇavakakrīḍā": ['mw'],
    "māṇavakaḥ": ['ap90'],
    "māṇavaḥ": ['ap90'],
    "māṇavikā": ['ap90', 'cped', 'mw'],
    "māṇavya": ['mw'],
    "māṇavyaṃ": ['ap90'],
    "māṇavī": ['cped'],
    "māṇavīna": ['ap90', 'mw'],
    "māṇi": ['mw'],
    "māṇibandha": ['mw'],
    "māṇibaṃdhaṃ": ['ap90'],
    "māṇibhadra": ['mw'],
    "māṇicara": ['bhs', 'ddsa', 'mw'],
    "māṇicari": ['mw'],
    "māṇicāra": ['mw'],
    "māṇika": ['cae', 'ddsa', 'mw'],
    "māṇikya": ['cae', 'ddsa', 'mw'],
    "māṇikyacandra": ['mw'],
    "māṇikyacandraka": ['mw'],
    "māṇikyadeva": ['mw'],
    "māṇikyamalla": ['mw'],
    "māṇikyamaya": ['mw'],
    "māṇikyamiśra": ['mw'],
    "māṇikyamukha": ['mw'],
    "māṇikyamukuṭa": ['mw'],
    "māṇikyamālā": ['mw'],
    "māṇikyapuñja": ['mw'],
    "māṇikyaratna": ['mw'],
    "māṇikyarāya": ['mw'],
    "māṇikyasūri": ['mw'],
    "māṇikyaṃ": ['ap90'],
    "māṇikyā": ['ap90', 'mw'],
    "māṇikyāditya": ['mw'],
    "māṇikyādri": ['mw'],
    "māṇikyāntaka": ['mw'],
    "māṇikā": ['ap90', 'mw'],
    "māṇikāmbā": ['mw'],
    "māṇimantha": ['mw'],
    "māṇipāla": ['mw'],
    "māṇipālika": ['mw'],
    "māṇipāra": ['mw'],
    "māṇirūpya": ['mw'],
    "māṇirūpyaka": ['mw'],
    "māṇivara": ['mw'],
    "māṇḍa": ['mw'],
    "māṇḍakarṇi": ['mw'],
    "māṇḍaleya": ['bhs'],
    "māṇḍalika": ['cae', 'ddsa', 'mw'],
    "māṇḍalya": ['bhs'],
    "māṇḍapa": ['ddsa', 'mw'],
    "māṇḍarika": ['mw'],
    "māṇḍava": ['mw'],
    "māṇḍavya": ['bhs', 'ddsa', 'mw'],
    "māṇḍavyapura": ['mw'],
    "māṇḍavyasaṃhitā": ['mw'],
    "māṇḍavyaśruti": ['mw'],
    "māṇḍavyeśvara": ['mw'],
    "māṇḍavyeśvaratīrtha": ['mw'],
    "māṇḍavyāyana": ['mw'],
    "māṇḍavī": ['mw'],
    "māṇḍūka": ['ddsa', 'mw'],
    "māṇḍūkeya": ['mw'],
    "māṇḍūkeyīya": ['mw'],
    "māṇḍūki": ['mw'],
    "māṇḍūkya": ['mw'],
    "māṇḍūkyaśruti": ['mw'],
    "māṇḍūkyopaniṣad": ['mw'],
    "māṇḍūkyopaniṣadbhāṣya": ['mw'],
    "māṇḍūkyopaniṣadbhāṣyasaṃgraha": ['mw'],
    "māṇḍūkyopaniṣaddīpikā": ['mw'],
    "māṇḍūkyopaniṣadāloka": ['mw'],
    "māṇḍūkyopaniṣatkārikā": ['mw'],
    "māṇḍūkāyana": ['mw'],
    "māṇḍūkāyanaputra": ['mw'],
    "māṇḍūkāyani": ['mw'],
    "māṇḍūkāyanī": ['mw'],
    "māṇḍūkī": ['mw'],
    "māṇḍūkīputra": ['mw'],
    "māṇṭi": ['mw'],
    "māṣa": ['cae', 'ddsa', 'mw'],
    "māṣaka": ['mw'],
    "māṣakaḥ": ['ap90'],
    "māṣamantha": ['mw'],
    "māṣamaya": ['mw'],
    "māṣamudgamaya": ['mw'],
    "māṣaparṇī": ['mw'],
    "māṣapattrikā": ['mw'],
    "māṣapeṣam": ['mw'],
    "māṣapiṣṭa": ['mw'],
    "māṣaprati": ['mw'],
    "māṣapuṣpa": ['mw'],
    "māṣarāśi": ['mw'],
    "māṣarāśivarṇa": ['bhs'],
    "māṣasthalaka": ['mw'],
    "māṣasthalī": ['mw'],
    "māṣasūpa": ['mw'],
    "māṣataila": ['mw'],
    "māṣatila": ['cae', 'mw'],
    "māṣavardhaka": ['mw'],
    "māṣavarṇa": ['mw'],
    "māṣavāpa": ['mw'],
    "māṣavāpin": ['mw'],
    "māṣaśarāvi": ['mw'],
    "māṣaśas": ['mw'],
    "māṣaḥ": ['ap90'],
    "māṣi": ['mw'],
    "māṣika": ['ap90', 'mw'],
    "māṣona": ['mw'],
    "māṣoṇa": ['mw'],
    "māṣya": ['ap90', 'mw'],
    "māṣāda": ['mw'],
    "māṣājya": ['mw'],
    "māṣāśa": ['mw'],
    "māṣāśin": ['mw'],
    "māṣī": ['mw'],
    "māṣīṇa": ['ap90', 'ddsa', 'mw'],
    "māṣṭa": ['bhs'],
    "māṭaṅka": ['mw'],
    "māṭha": ['mw'],
    "māṭhara": ['bhs', 'cae', 'ddsa', 'mw'],
    "māṭharaka": ['mw'],
    "māṭharaḥ": ['ap90'],
    "māṭharya": ['mw'],
    "māṭharāyaṇa": ['mw'],
    "māṭharī": ['mw'],
    "māṭhavya": ['cae', 'ddsa', 'mw'],
    "māṭhaḥ": ['ap90'],
    "māṭhya": ['mw'],
    "māṭhī": ['ap90', 'mw'],
    "māṭi": ['mw'],
    "māṭiyāri": ['mw'],
    "māṭāmraka": ['mw'],
    "māṭīyāri": ['mw'],
    "mī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mīgava": ['bhs'],
    "mīl": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mīlana": ['cae', 'ddsa', 'mw'],
    "mīlanaṃ": ['ap90'],
    "mīlika": ['mw'],
    "mīlikā": ['mw'],
    "mīlita": ['ap90', 'cae', 'mw'],
    "mīl̤ha": ['mw'],
    "mīl̤hu": ['mw'],
    "mīl̤huṣ": ['mw'],
    "mīm": ['ap90', 'mw'],
    "mīmāṃsaka": ['cae', 'ddsa', 'mw'],
    "mīmāṃsakaḥ": ['ap90'],
    "mīmāṃsana": ['bhs'],
    "mīmāṃsanaṃ": ['ap90'],
    "mīmāṃsikā": ['mw'],
    "mīmāṃsitavya": ['mw'],
    "mīmāṃsya": ['ddsa', 'mw'],
    "mīmāṃsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "mīmāṃsābhaṭṭa": ['mw'],
    "mīmāṃsābhāṣya": ['mw'],
    "mīmāṃsābālaprakāśa": ['mw'],
    "mīmāṃsādhikaraṇa": ['mw'],
    "mīmāṃsādhikaraṇamālāṭīkā": ['mw'],
    "mīmāṃsādhikaraṇanyāyavicāropanyāsa": ['mw'],
    "mīmāṃsājīvarakṣā": ['mw'],
    "mīmāṃsākaumudī": ['mw'],
    "mīmāṃsākaustubha": ['mw'],
    "mīmāṃsākusumāñjali": ['mw'],
    "mīmāṃsākutūhala": ['mw'],
    "mīmāṃsākutūhalavṛtti": ['mw'],
    "mīmāṃsākṛt": ['mw'],
    "mīmāṃsāmakaranda": ['mw'],
    "mīmāṃsānayaviveka": ['mw'],
    "mīmāṃsānayavivekagatārthamālikā": ['mw'],
    "mīmāṃsānayavivekaśaṅkādīpikā": ['mw'],
    "mīmāṃsānayavivekālaṃkāra": ['mw'],
    "mīmāṃsānyāya": ['mw'],
    "mīmāṃsānyāyaparimalollāsa": ['mw'],
    "mīmāṃsānyāyaprakāśa": ['mw'],
    "mīmāṃsānyāyaratnākara": ['mw'],
    "mīmāṃsāpadārthanirṇaya": ['mw'],
    "mīmāṃsāpalvala": ['mw'],
    "mīmāṃsāparibhāṣā": ['mw'],
    "mīmāṃsāprakriyā": ['mw'],
    "mīmāṃsāpādukā": ['mw'],
    "mīmāṃsārasapalvala": ['mw'],
    "mīmāṃsārtha": ['mw'],
    "mīmāṃsārthadīpa": ['mw'],
    "mīmāṃsārthasaṃgraha": ['mw'],
    "mīmāṃsāsarvasva": ['mw'],
    "mīmāṃsāsaṃgraha": ['mw'],
    "mīmāṃsāsaṃkalpakaumudī": ['mw'],
    "mīmāṃsāsiddhāntāryā": ['mw'],
    "mīmāṃsāstabaka": ['mw'],
    "mīmāṃsāsāra": ['mw'],
    "mīmāṃsāsārasaṃgraha": ['mw'],
    "mīmāṃsāsūtra": ['mw'],
    "mīmāṃsāsūtradīdhiti": ['mw'],
    "mīmāṃsāsūtrarahasya": ['mw'],
    "mīmāṃsātantravārttika": ['mw'],
    "mīmāṃsātattvacandrikā": ['mw'],
    "mīmāṃsāvidhibhūṣaṇa": ['mw'],
    "mīmāṃsāvivaraṇaratnamālā": ['mw'],
    "mīmāṃsāviṣaya": ['mw'],
    "mīmāṃsāvāda": ['mw'],
    "mīmāṃsāvādārtha": ['mw'],
    "mīmāṃsāvārttika": ['mw'],
    "mīmāṃsāśiromaṇi": ['mw'],
    "mīmāṃsāślokavārttika": ['mw'],
    "mīmāṃsāśāstra": ['mw'],
    "mīmāṃsāśāstradīpikā": ['mw'],
    "mīmāṃsāśāstrasarvasva": ['mw'],
    "mīna": ['cae', 'cped', 'ddsa', 'mw'],
    "mīnadhvaja": ['cae', 'mw'],
    "mīnadhāvanatoya": ['mw'],
    "mīnadvaya": ['mw'],
    "mīnagandhā": ['mw'],
    "mīnaghātin": ['mw'],
    "mīnagodhikā": ['mw'],
    "mīnaketana": ['mw'],
    "mīnaketu": ['cae', 'mw'],
    "mīnaketūdaya": ['mw'],
    "mīnalāñchana": ['mw'],
    "mīnamatsya": ['mw'],
    "mīnanayanāṣṭaka": ['mw'],
    "mīnanetrā": ['mw'],
    "mīnanātha": ['mw'],
    "mīnapuccha": ['mw'],
    "mīnapucchanibha": ['mw'],
    "mīnara": ['mw'],
    "mīnaratha": ['mw'],
    "mīnaraḥ": ['ap90'],
    "mīnaraṅga": ['mw'],
    "mīnaraṅka": ['mw'],
    "mīnarāja": ['mw'],
    "mīnarājajātaka": ['mw'],
    "mīnatā": ['mw'],
    "mīnavat": ['mw'],
    "mīnaḥ": ['ap90'],
    "mīnā": ['mw'],
    "mīnāghātin": ['mw'],
    "mīnākṣa": ['mw'],
    "mīnākṣā": ['mw'],
    "mīnākṣī": ['mw'],
    "mīnākṣīcūrṇikā": ['mw'],
    "mīnākṣīpariṇaya": ['mw'],
    "mīnākṣīpañcaratna": ['mw'],
    "mīnākṣīstavarāja": ['mw'],
    "mīnākṣīstotra": ['mw'],
    "mīnākṣīsundareśvara": ['mw'],
    "mīnālaya": ['mw'],
    "mīnāmrīṇa": ['mw'],
    "mīnāmrīṇaḥ": ['ap90'],
    "mīnāri": ['mw'],
    "mīnāṅka": ['mw'],
    "mīnāṇḍa": ['mw'],
    "mīra": ['mw'],
    "mīramīrā": ['mw'],
    "mīramīrāsuta": ['mw'],
    "mīraḥ": ['ap90'],
    "mīta": ['mw'],
    "mīv": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mīvaga": ['bhs', 'mw'],
    "mīvan": ['mw'],
    "mīvara": ['ap90', 'mw'],
    "mīvā": ['ap90', 'mw'],
    "mīyamāna": ['cped'],
    "mīyati": ['cped'],
    "mīḍam": ['cae', 'mw'],
    "mīḍha": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "mīḍhu": ['mw'],
    "mīḍhuaṣ": ['gra'],
    "mīḍhus": ['gra'],
    "mīḍhuṣ": ['mw'],
    "mīḍhuṣa": ['mw'],
    "mīḍhuṣmant": ['cae'],
    "mīḍhuṣmat": ['ddsa', 'gra', 'mw'],
    "mīḍhuṣī": ['mw'],
    "mīḍhuṣṭama": ['mw'],
    "mīḍhuṣṭamaḥ": ['ap90'],
    "mīḍhvas": ['ap90', 'ddsa', 'gra', 'mw'],
    "mīḍhvaṃs": ['cae'],
    "mīḍhā": ['mw'],
    "mīḷha": ['cped'],
    "mīṭa": ['bhs'],
    "mū": ['ap90', 'ddsa', 'gra', 'mw'],
    "mūcīpa": ['mw'],
    "mūdhāma": ['bhs'],
    "mūga": ['cped'],
    "mūjavant": ['cae'],
    "mūjavat": ['ddsa', 'gra', 'mw'],
    "mūjāladeva": ['mw'],
    "mūka": ['ap90', 'cae', 'ddsa', 'mw'],
    "mūkabhāva": ['mw'],
    "mūkakavi": ['mw'],
    "mūkalarāya": ['mw'],
    "mūkapañcaśatī": ['mw'],
    "mūkapraśna": ['mw'],
    "mūkatva": ['mw'],
    "mūkatā": ['mw'],
    "mūkavat": ['mw'],
    "mūkiman": ['ap90', 'mw'],
    "mūkita": ['mw'],
    "mūkā": ['mw'],
    "mūkāmbikā": ['mw'],
    "mūkāmbikāstotra": ['mw'],
    "mūkāṇḍaja": ['mw'],
    "mūkīkṛ": ['ddsa', 'mw'],
    "mūl": ['ap90', 'mw'],
    "mūla": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "mūlabandha": ['mw'],
    "mūlabarhaṇa": ['mw'],
    "mūlabhadra": ['mw'],
    "mūlabhava": ['mw'],
    "mūlabhaṭṭaprayoga": ['mw'],
    "mūlabhāga": ['mw'],
    "mūlabhāra": ['mw'],
    "mūlabhāvaprakāśikā": ['mw'],
    "mūlabhūta": ['mw'],
    "mūlabhṛtya": ['cae', 'mw'],
    "mūlabīja": ['cped'],
    "mūlaccheda": ['mw'],
    "mūlacchinna": ['mw'],
    "mūladeva": ['cae', 'mw'],
    "mūladhana": ['cped', 'mw'],
    "mūladhātu": ['mw'],
    "mūladravya": ['mw'],
    "mūladvāra": ['mw'],
    "mūladvāravatī": ['mw'],
    "mūlagrantha": ['bhs', 'mw'],
    "mūlagranthi": ['mw'],
    "mūlaguṇa": ['mw'],
    "mūlaguṇajāti": ['mw'],
    "mūlahara": ['cae', 'mw'],
    "mūlaharatva": ['mw'],
    "mūlaja": ['mw'],
    "mūlajātaśānti": ['mw'],
    "mūlajāti": ['mw'],
    "mūlaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mūlakamūlā": ['mw'],
    "mūlakanda": ['cped'],
    "mūlakaparṇī": ['mw'],
    "mūlakapaṇa": ['mw'],
    "mūlakapotikā": ['mw'],
    "mūlakapotī": ['mw'],
    "mūlakarmakriyā": ['mw'],
    "mūlakarman": ['cae', 'mw'],
    "mūlakatva": ['mw'],
    "mūlakaśākaṭa": ['mw'],
    "mūlakaśākina": ['mw'],
    "mūlakesara": ['mw'],
    "mūlakhānaka": ['cae', 'mw'],
    "mūlakopadaṃśam": ['mw'],
    "mūlakādisuta": ['mw'],
    "mūlakāra": ['mw'],
    "mūlakāraṇa": ['mw'],
    "mūlakārikā": ['mw'],
    "mūlakṛcchra": ['mw'],
    "mūlakṛt": ['mw'],
    "mūlamantra": ['mw'],
    "mūlamantramaya": ['mw'],
    "mūlamantrasāra": ['mw'],
    "mūlamantrārthasāra": ['mw'],
    "mūlamitra": ['mw'],
    "mūlamādhava": ['mw'],
    "mūlamādhavatīrtha": ['mw'],
    "mūlamānuṣa": ['bhs'],
    "mūlamāthurīya": ['mw'],
    "mūlanagara": ['mw'],
    "mūlanakṣatraśānti": ['mw'],
    "mūlanakṣatraśāntiprayoga": ['mw'],
    "mūlanikṛntana": ['mw'],
    "mūlanāthīya": ['mw'],
    "mūlanāśa": ['mw'],
    "mūlanāśaka": ['mw'],
    "mūlaparivāsa": ['mw'],
    "mūlaparṇī": ['mw'],
    "mūlaphala": ['cae', 'mw'],
    "mūlaphalada": ['mw'],
    "mūlaphalguna": ['bhs'],
    "mūlaphalāśana": ['cae', 'mw'],
    "mūlapotī": ['mw'],
    "mūlaprakāśa": ['mw'],
    "mūlaprakṛti": ['cae', 'mw'],
    "mūlapraṇihita": ['mw'],
    "mūlaprāṇahita": ['cae'],
    "mūlapuliśasiddhānta": ['mw'],
    "mūlapuruṣa": ['cae', 'mw'],
    "mūlapuṣkara": ['mw'],
    "mūlapuṣpikā": ['mw'],
    "mūlapāka": ['mw'],
    "mūlarasa": ['mw'],
    "mūlarāja": ['mw'],
    "mūlarāmāyaṇa": ['mw'],
    "mūlarāśi": ['mw'],
    "mūlasa": ['mw'],
    "mūlasarvāstivāda": ['bhs', 'mw'],
    "mūlasarvāstivādin": ['mw'],
    "mūlasasya": ['mw'],
    "mūlasatena": ['cped'],
    "mūlasaṅgha": ['mw'],
    "mūlasrotas": ['mw'],
    "mūlastambhanirṇaya": ['mw'],
    "mūlasthala": ['mw'],
    "mūlasthāna": ['mw'],
    "mūlasthānatīrtha": ['mw'],
    "mūlasthānī": ['mw'],
    "mūlasthāyin": ['mw'],
    "mūlasvāmin": ['cae', 'mw'],
    "mūlasādhana": ['cae', 'mw'],
    "mūlasūtra": ['mw'],
    "mūlatas": ['mw'],
    "mūlatrikoṇa": ['mw'],
    "mūlatva": ['mw'],
    "mūlatā": ['cae', 'mw'],
    "mūlauṣadhi": ['mw'],
    "mūlavacana": ['mw'],
    "mūlavat": ['mw'],
    "mūlavaṇigdhana": ['mw'],
    "mūlavibhuja": ['mw'],
    "mūlavidyā": ['mw'],
    "mūlavināśana": ['mw'],
    "mūlavirecana": ['mw'],
    "mūlavitta": ['mw'],
    "mūlavratin": ['mw'],
    "mūlavyasanavṛttimant": ['cae'],
    "mūlavyasanavṛttimat": ['mw'],
    "mūlavyādhi": ['mw'],
    "mūlavāpa": ['mw'],
    "mūlavārin": ['mw'],
    "mūlavāsin": ['mw'],
    "mūlaśakuna": ['mw'],
    "mūlaśrīpatitīrtha": ['mw'],
    "mūlaśākaṭa": ['mw'],
    "mūlaśākina": ['mw'],
    "mūlaśānti": ['mw'],
    "mūlaśāntipaddhati": ['mw'],
    "mūlaśāntividhi": ['mw'],
    "mūlaśāntividhāna": ['mw'],
    "mūlaṃ": ['ap90', 'bhs'],
    "mūle": ['bhs'],
    "mūlera": ['mw'],
    "mūleraḥ": ['ap90'],
    "mūlika": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "mūlikā": ['bhs', 'mw'],
    "mūlikārtha": ['mw'],
    "mūlin": ['ap90', 'cae', 'mw'],
    "mūlina": ['ap90'],
    "mūloccheda": ['ddsa', 'mw'],
    "mūloddharaṇa": ['mw'],
    "mūlotkhāta": ['mw'],
    "mūlotpātana": ['mw'],
    "mūlotpātanajīvin": ['mw'],
    "mūlya": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "mūlyadravya": ['mw'],
    "mūlyaka": ['mw'],
    "mūlyakaraṇa": ['mw'],
    "mūlyatva": ['mw'],
    "mūlyavivarjita": ['mw'],
    "mūlyādhyāya": ['mw'],
    "mūlyādhyāyavivaraṇa": ['mw'],
    "mūlā": ['ap90', 'mw'],
    "mūlābha": ['mw'],
    "mūlābhidharmaśāstra": ['mw'],
    "mūlācāra": ['mw'],
    "mūlādhāra": ['mw'],
    "mūlādiśānti": ['mw'],
    "mūlāgra": ['mw'],
    "mūlāhva": ['mw'],
    "mūlālavāla": ['mw'],
    "mūlāpakarṣa": ['bhs'],
    "mūlāpakarṣaparivāsa": ['mw'],
    "mūlāpatti": ['bhs'],
    "mūlārthaśekhara": ['mw'],
    "mūlāto": ['bhs'],
    "mūlāvidyāvināśaka": ['mw'],
    "mūlāyatana": ['cae', 'mw'],
    "mūlāśin": ['cae', 'mw'],
    "mūlāṭa": ['mw'],
    "mūlāṭī": ['mw'],
    "mūlī": ['ap90', 'mw'],
    "mūlībhūta": ['mw'],
    "mūlīkaraṇa": ['ddsa', 'mw'],
    "mūlīkarman": ['mw'],
    "mūlīkṛ": ['mw'],
    "mūr": ['ddsa', 'gra'],
    "mūra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mūradeva": ['gra', 'mw'],
    "mūrcchana": ['ap90'],
    "mūrcchita": ['ap90'],
    "mūrcchā": ['ap90'],
    "mūrcchāla": ['ap90'],
    "mūrch": ['cae', 'ddsa', 'mw'],
    "mūrchana": ['cae', 'ddsa', 'mw'],
    "mūrchita": ['bhs', 'cae', 'ddsa', 'mw'],
    "mūrchitaka": ['bhs'],
    "mūrchā": ['cae', 'ddsa', 'mw'],
    "mūrchākṣepa": ['mw'],
    "mūrchāla": ['mw'],
    "mūrchāmaya": ['mw'],
    "mūrchāpagama": ['mw'],
    "mūrchāparipluta": ['mw'],
    "mūrchāparīta": ['mw'],
    "mūrchāprada": ['mw'],
    "mūrchāvat": ['mw'],
    "mūrchāya": ['mw'],
    "mūrdha": ['cae', 'ddsa', 'mw'],
    "mūrdhabhinna": ['mw'],
    "mūrdhadhara": ['mw'],
    "mūrdhadharā": ['mw'],
    "mūrdhaga": ['cae', 'mw'],
    "mūrdhagata": ['mw'],
    "mūrdhaja": ['cae', 'mw'],
    "mūrdhajyotis": ['mw'],
    "mūrdhaka": ['bhs', 'mw'],
    "mūrdhakarparī": ['mw'],
    "mūrdhakarṇī": ['mw'],
    "mūrdhakhola": ['mw'],
    "mūrdhan": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "mūrdhanvat": ['mw'],
    "mūrdhanya": ['ap90', 'cae', 'ddsa', 'mw'],
    "mūrdhanyā": ['mw'],
    "mūrdhapidhāna": ['bhs'],
    "mūrdhapiṇḍa": ['mw'],
    "mūrdhapuṣpa": ['mw'],
    "mūrdhapāta": ['mw'],
    "mūrdharasa": ['mw'],
    "mūrdhasaṃhita": ['mw'],
    "mūrdhata": ['bhs'],
    "mūrdhatailika": ['mw'],
    "mūrdhatas": ['cae', 'mw'],
    "mūrdhaveṣṭana": ['mw'],
    "mūrdhaṭaka": ['bhs'],
    "mūrdhnaṭaka": ['bhs'],
    "mūrdhni": ['bhs'],
    "mūrdhvan": ['ap90', 'mw'],
    "mūrdhābhiṣeka": ['mw'],
    "mūrdhābhiṣikta": ['mw'],
    "mūrdhāgata": ['mw'],
    "mūrdhānta": ['ddsa', 'mw'],
    "mūrdhāpidhāna": ['bhs'],
    "mūrdhāta": ['bhs'],
    "mūrdhāvasikta": ['mw'],
    "mūrkha": ['ap90', 'cae', 'ddsa', 'mw'],
    "mūrkhabhrātṛka": ['mw'],
    "mūrkhabhūya": ['mw'],
    "mūrkhahā": ['mw'],
    "mūrkhalikā": ['bhs', 'mw'],
    "mūrkhamaṇḍala": ['mw'],
    "mūrkhapaṇḍita": ['mw'],
    "mūrkhatva": ['mw'],
    "mūrkhatā": ['ap90', 'cae', 'mw'],
    "mūrkhavyasanināyaka": ['mw'],
    "mūrkhaśata": ['mw'],
    "mūrkhaśataka": ['mw'],
    "mūrkhiman": ['mw'],
    "mūrkhībhū": ['ddsa', 'mw'],
    "mūrta": ['ap90', 'cae', 'ddsa', 'mw'],
    "mūrtamātra": ['mw'],
    "mūrtatva": ['mw'],
    "mūrtatvajātinirākaraṇa": ['mw'],
    "mūrtatvaṃ": ['ap90'],
    "mūrtaya": ['mw'],
    "mūrti": ['cae', 'ddsa', 'mw'],
    "mūrtibhāva": ['mw'],
    "mūrtidhara": ['mw'],
    "mūrtidhyāna": ['mw'],
    "mūrtilakṣaṇa": ['mw'],
    "mūrtiliṅga": ['mw'],
    "mūrtimant": ['cae'],
    "mūrtimat": ['ap90', 'mw'],
    "mūrtimaya": ['mw'],
    "mūrtimātrā": ['mw'],
    "mūrtipa": ['mw'],
    "mūrtipratiṣṭhā": ['mw'],
    "mūrtipratiṣṭhāpana": ['mw'],
    "mūrtipūjā": ['mw'],
    "mūrtisanātha": ['mw'],
    "mūrtisaṃcara": ['mw'],
    "mūrtisaṃcāra": ['mw'],
    "mūrtisevana": ['mw'],
    "mūrtitas": ['cae', 'mw'],
    "mūrtitva": ['mw'],
    "mūrtitvaṃ": ['ap90'],
    "mūrtivighneśa": ['mw'],
    "mūrtiḥ": ['ap90'],
    "mūrtsā": ['mw'],
    "mūru": ['cae', 'mw'],
    "mūrvikā": ['mw'],
    "mūrvā": ['ap90', 'cae', 'ddsa', 'mw'],
    "mūrvāmaya": ['mw'],
    "mūrvāvana": ['mw'],
    "mūrvāvaṇa": ['mw'],
    "mūrṇa": ['ddsa', 'mw'],
    "mūsariḥpha": ['mw'],
    "mūsika": ['cped'],
    "mūsikacchinna": ['cped'],
    "mūsikavacca": ['cped'],
    "mūsikā": ['cped'],
    "mūsā": ['cped'],
    "mūta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mūtaka": ['cae', 'mw'],
    "mūtakārya": ['mw'],
    "mūtiba": ['ddsa', 'mw'],
    "mūtoḍī": ['bhs'],
    "mūtra": ['cae', 'ddsa', 'mw'],
    "mūtrabhāvita": ['mw'],
    "mūtradoṣa": ['mw'],
    "mūtraghāta": ['mw'],
    "mūtragranthi": ['mw'],
    "mūtrajaṭhara": ['mw'],
    "mūtrakara": ['mw'],
    "mūtrakośa": ['mw'],
    "mūtrakṛcchra": ['mw'],
    "mūtrakṛcchrin": ['mw'],
    "mūtrakṛta": ['mw'],
    "mūtrakṣaya": ['mw'],
    "mūtrala": ['ap90', 'mw'],
    "mūtralā": ['mw'],
    "mūtramārga": ['mw'],
    "mūtramārganirodhana": ['mw'],
    "mūtranirodha": ['mw'],
    "mūtraparīkṣā": ['mw'],
    "mūtrapatana": ['mw'],
    "mūtrapatha": ['mw'],
    "mūtraphalā": ['mw'],
    "mūtrapraseka": ['mw'],
    "mūtrapratighāta": ['mw'],
    "mūtrapurīṣa": ['cae', 'mw'],
    "mūtrapurīṣoccāra": ['mw'],
    "mūtrapurīṣotsarga": ['mw'],
    "mūtrapuṭa": ['mw'],
    "mūtrarodha": ['mw'],
    "mūtrasaṃkṣaya": ['mw'],
    "mūtrasaṅga": ['mw'],
    "mūtrasaṅgin": ['mw'],
    "mūtrasāt": ['mw'],
    "mūtraukasāda": ['mw'],
    "mūtravaha": ['mw'],
    "mūtravardhaka": ['mw'],
    "mūtravarti": ['mw'],
    "mūtravartmarodha": ['mw'],
    "mūtravibandhaghna": ['mw'],
    "mūtraviṣa": ['mw'],
    "mūtravṛddhi": ['mw'],
    "mūtray": ['cae'],
    "mūtraya": ['ddsa', 'mw'],
    "mūtrayati": ['ap90'],
    "mūtraśakṛt": ['mw'],
    "mūtraśukra": ['mw'],
    "mūtraśūla": ['mw'],
    "mūtraṃ": ['ap90'],
    "mūtrita": ['ap90', 'mw'],
    "mūtroccāra": ['cae', 'ddsa', 'mw'],
    "mūtrotsarga": ['mw'],
    "mūtrotsaṅga": ['mw'],
    "mūtrya": ['cae', 'ddsa', 'mw'],
    "mūtrāghāta": ['mw'],
    "mūtrārti": ['mw'],
    "mūtrāsāda": ['mw'],
    "mūtrātīsāra": ['mw'],
    "mūtrātīta": ['mw'],
    "mūtrāśaya": ['mw'],
    "mūtākāra": ['mw'],
    "mūtāvabaddha": ['mw'],
    "mūyate": ['bhs'],
    "mūḍaka": ['mw'],
    "mūḍha": ['ap90', 'cae', 'ddsa', 'mw'],
    "mūḍhabuddhi": ['mw'],
    "mūḍhacakṣurgadacchetṛ": ['mw'],
    "mūḍhacetana": ['cae', 'ddsa', 'mw'],
    "mūḍhacetas": ['cae', 'mw'],
    "mūḍhadhī": ['cae', 'mw'],
    "mūḍhadṛṣṭi": ['cae'],
    "mūḍhagarbha": ['mw'],
    "mūḍhagrāha": ['mw'],
    "mūḍhamanas": ['mw'],
    "mūḍhamati": ['mw'],
    "mūḍhaprabhu": ['mw'],
    "mūḍharatha": ['mw'],
    "mūḍhasattva": ['mw'],
    "mūḍhatama": ['mw'],
    "mūḍhatva": ['mw'],
    "mūḍhatā": ['ap90', 'mw'],
    "mūḍhavat": ['mw'],
    "mūḍhaviḍambana": ['mw'],
    "mūḍhaśreṣṭha": ['mw'],
    "mūḍheśvara": ['mw'],
    "mūḍhāma": ['bhs'],
    "mūḍhātman": ['mw'],
    "mūḷha": ['cped'],
    "mūṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mūṣa": ['cae', 'ddsa', 'mw'],
    "mūṣaka": ['cae', 'mw'],
    "mūṣakakarṇikā": ['mw'],
    "mūṣakakarṇī": ['mw'],
    "mūṣakaḥ": ['ap90'],
    "mūṣakāda": ['mw'],
    "mūṣakārāti": ['mw'],
    "mūṣati": ['bhs'],
    "mūṣavāhana": ['mw'],
    "mūṣaḥ": ['ap90'],
    "mūṣaṇa": ['mw'],
    "mūṣaṇaṃ": ['ap90'],
    "mūṣika": ['cae', 'ddsa', 'mw'],
    "mūṣikakā": ['mw'],
    "mūṣikanirviśeṣa": ['mw'],
    "mūṣikaparṇī": ['mw'],
    "mūṣikaratha": ['mw'],
    "mūṣikasthala": ['mw'],
    "mūṣikaviṣāṇa": ['mw'],
    "mūṣikaśāvaka": ['cae'],
    "mūṣikaḥ": ['ap90'],
    "mūṣikikā": ['mw'],
    "mūṣikotkara": ['cae', 'mw'],
    "mūṣikā": ['ddsa', 'mw'],
    "mūṣikāda": ['mw'],
    "mūṣikādanta": ['mw'],
    "mūṣikādat": ['mw'],
    "mūṣikāhairanyika": ['mw'],
    "mūṣikāhairaṇyika": ['bhs'],
    "mūṣikāhvayā": ['mw'],
    "mūṣikākṛti": ['mw'],
    "mūṣikāntakṛt": ['mw'],
    "mūṣikāra": ['mw'],
    "mūṣikāraḥ": ['ap90'],
    "mūṣikārāti": ['mw'],
    "mūṣikāñcana": ['mw'],
    "mūṣikāñcita": ['mw'],
    "mūṣikāṅka": ['mw'],
    "mūṣiparṇikā": ['mw'],
    "mūṣita": ['mw'],
    "mūṣyāyaṇa": ['mw'],
    "mūṣā": ['ap90', 'mw'],
    "mūṣākarṇī": ['mw'],
    "mūṣātuttha": ['mw'],
    "mūṣī": ['ap90', 'bhs', 'mw'],
    "mūṣīka": ['mw'],
    "mūṣīkakarṇī": ['mw'],
    "mūṣīkaraṇa": ['mw'],
    "mūṣīkaraṇaṃ": ['ap90'],
    "mūṭa": ['bhs', 'mw'],
    "mūṭaka": ['mw'],
    "mṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛc": ['cae', 'ddsa', 'gra', 'mw'],
    "mṛcaya": ['cae', 'ddsa', 'mw'],
    "mṛccaya": ['mw'],
    "mṛcchakaṭi": ['cae'],
    "mṛcchakaṭika": ['ddsa'],
    "mṛcchakaṭikā": ['mw'],
    "mṛcchakaṭikāsetu": ['mw'],
    "mṛcchilāmaya": ['mw'],
    "mṛch": ['ddsa', 'mw'],
    "mṛd": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛdara": ['ap90', 'mw'],
    "mṛdava": ['mw'],
    "mṛdavaṃ": ['ap90'],
    "mṛdaṃga": ['mw'],
    "mṛdaṃgaka": ['mw'],
    "mṛdaṃgaphala": ['mw'],
    "mṛdaṃgaphalinī": ['mw'],
    "mṛdaṃgaḥ": ['ap90'],
    "mṛdaṃgī": ['mw'],
    "mṛdaṃkuraḥ": ['ap90'],
    "mṛdaṃkuruḥ": ['ap90'],
    "mṛdaṅga": ['cae', 'ddsa', 'mw'],
    "mṛdaṅkura": ['mw'],
    "mṛdaṅkuru": ['mw'],
    "mṛdbha": ['cae'],
    "mṛdbhāṇḍa": ['cae', 'mw'],
    "mṛdbhāṇḍāvaśeṣam": ['mw'],
    "mṛddha": ['mw'],
    "mṛddāruśaila": ['mw'],
    "mṛdga": ['mw'],
    "mṛdghaṭa": ['ddsa', 'mw'],
    "mṛdh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛdha": ['cae', 'ddsa', 'mw'],
    "mṛdhabhū": ['mw'],
    "mṛdhas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛdhaṃ": ['ap90'],
    "mṛdhra": ['cae', 'ddsa', 'gra', 'mw'],
    "mṛdhravāc": ['cae', 'gra', 'mw'],
    "mṛdhā": ['mw'],
    "mṛdi": ['mw'],
    "mṛdinī": ['ap90', 'mw'],
    "mṛdita": ['ap90', 'mw'],
    "mṛditakukṣika": ['bhs', 'mw'],
    "mṛdiṣṭha": ['mw'],
    "mṛdu": ['ap90', 'cae', 'ddsa', 'mw'],
    "mṛdubhāva": ['cae', 'mw'],
    "mṛdubhāṣin": ['cae', 'mw'],
    "mṛdubhāṣitā": ['mw'],
    "mṛducarmin": ['mw'],
    "mṛducchada": ['mw'],
    "mṛducāpa": ['mw'],
    "mṛducārubhāṣin": ['mw'],
    "mṛdugamanā": ['mw'],
    "mṛdugandhaka": ['bhs'],
    "mṛdugandhika": ['mw'],
    "mṛdugaṇa": ['mw'],
    "mṛdugir": ['cae', 'mw'],
    "mṛdugranthi": ['mw'],
    "mṛdugāmin": ['mw'],
    "mṛdugāminī": ['mw'],
    "mṛdugātratā": ['mw'],
    "mṛduhṛdaya": ['cae', 'mw'],
    "mṛdujihvatā": ['mw'],
    "mṛdujātīya": ['mw'],
    "mṛduka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "mṛdukam": ['mw'],
    "mṛdukarman": ['mw'],
    "mṛdukaṇṭaka": ['mw'],
    "mṛdukopa": ['mw'],
    "mṛdukoṣṭha": ['mw'],
    "mṛdukriyā": ['mw'],
    "mṛdukrūra": ['cae'],
    "mṛdukā": ['bhs', 'mw'],
    "mṛdukārṣṇāyasa": ['mw'],
    "mṛdukṛṣṇāyasa": ['mw'],
    "mṛdula": ['ap90', 'cae', 'ddsa', 'mw'],
    "mṛdulatā": ['mw'],
    "mṛdulomaka": ['mw'],
    "mṛdumadhyā": ['mw'],
    "mṛdumadhyādhimātra": ['mw'],
    "mṛdumadhyādhimātratva": ['mw'],
    "mṛdumṛtsna": ['mw'],
    "mṛdunnaka": ['mw'],
    "mṛdunnakaṃ": ['ap90'],
    "mṛduparuṣaguṇa": ['mw'],
    "mṛduparvaka": ['mw'],
    "mṛduparvan": ['mw'],
    "mṛdupattra": ['mw'],
    "mṛdupattrī": ['mw'],
    "mṛduphala": ['mw'],
    "mṛduprauḍha": ['mw'],
    "mṛduprayatna": ['mw'],
    "mṛdupriya": ['mw'],
    "mṛdupuṣpa": ['mw'],
    "mṛdupuṣpaka": ['mw'],
    "mṛdupāṇi": ['mw'],
    "mṛdupīṭhaka": ['mw'],
    "mṛdupūrva": ['cae', 'mw'],
    "mṛdupūrvam": ['mw'],
    "mṛdura": ['mw'],
    "mṛdurasvana": ['mw'],
    "mṛduri": ['mw'],
    "mṛduromaka": ['mw'],
    "mṛduroman": ['mw'],
    "mṛduromavat": ['mw'],
    "mṛdusparśa": ['cae', 'mw'],
    "mṛdusārā": ['mw'],
    "mṛdusūrya": ['cae', 'mw'],
    "mṛdutaruṇahastapādatalatā": ['mw'],
    "mṛdutva": ['mw'],
    "mṛdutvac": ['mw'],
    "mṛdutā": ['mw'],
    "mṛdutāla": ['mw'],
    "mṛdutīkṣṇa": ['cae', 'mw'],
    "mṛdutīkṣṇatara": ['mw'],
    "mṛduvarga": ['mw'],
    "mṛduvid": ['mw'],
    "mṛduvāc": ['cae', 'ddsa', 'mw'],
    "mṛduvāta": ['mw'],
    "mṛduyuddha": ['mw'],
    "mṛduyuddhatā": ['mw'],
    "mṛdv": ['mw'],
    "mṛdvavagraha": ['mw'],
    "mṛdvaṅga": ['cae', 'ddsa', 'mw'],
    "mṛdvaṅgī": ['mw'],
    "mṛdvī": ['ap90', 'ddsa', 'mw'],
    "mṛdvīkā": ['cae', 'mw'],
    "mṛdā": ['ap90', 'cae', 'ddsa', 'mw'],
    "mṛdāhvayā": ['mw'],
    "mṛdākara": ['mw'],
    "mṛdānī": ['mw'],
    "mṛdū": ['mw'],
    "mṛdūas": ['mw'],
    "mṛdūbhāva": ['ddsa', 'mw'],
    "mṛdūbhū": ['cae', 'mw'],
    "mṛdūcca": ['mw'],
    "mṛdūtpala": ['mw'],
    "mṛg": ['ap90', 'mw'],
    "mṛga": ['cae', 'ddsa', 'gra', 'mw'],
    "mṛgabandhinī": ['mw'],
    "mṛgabhakṣā": ['mw'],
    "mṛgabhojanī": ['mw'],
    "mṛgabālaka": ['mw'],
    "mṛgacaiṭaka": ['mw'],
    "mṛgacakra": ['bhs', 'mw'],
    "mṛgacarmīya": ['mw'],
    "mṛgacarya": ['bhs'],
    "mṛgacaryā": ['mw'],
    "mṛgacirbhiṭā": ['mw'],
    "mṛgacārin": ['mw'],
    "mṛgadarpa": ['mw'],
    "mṛgadaṃśa": ['mw'],
    "mṛgadaṃśaka": ['mw'],
    "mṛgadeva": ['bhs'],
    "mṛgadhara": ['mw'],
    "mṛgadharma": ['mw'],
    "mṛgadharman": ['mw'],
    "mṛgadhūma": ['mw'],
    "mṛgadhūrta": ['mw'],
    "mṛgadhūrtaka": ['mw'],
    "mṛgadvija": ['cae', 'mw'],
    "mṛgadviṣ": ['mw'],
    "mṛgadyut": ['mw'],
    "mṛgadyū": ['mw'],
    "mṛgadāva": ['mw'],
    "mṛgadāya": ['bhs'],
    "mṛgadṛś": ['cae', 'mw'],
    "mṛgagartāśrayāpcara": ['mw'],
    "mṛgagharmaja": ['mw'],
    "mṛgagrahaṇa": ['cae', 'mw'],
    "mṛgagāminī": ['mw'],
    "mṛgahan": ['cae', 'mw'],
    "mṛgahantṛ": ['cae', 'mw'],
    "mṛgairvāru": ['mw'],
    "mṛgairvāruka": ['mw'],
    "mṛgajala": ['mw'],
    "mṛgajalasnāna": ['mw'],
    "mṛgajambuka": ['mw'],
    "mṛgajālikā": ['mw'],
    "mṛgajāti": ['mw'],
    "mṛgajīvana": ['cae', 'mw'],
    "mṛgaka": ['bhs'],
    "mṛgaketana": ['mw'],
    "mṛgakāka": ['mw'],
    "mṛgakānana": ['mw'],
    "mṛgakṣīra": ['mw'],
    "mṛgalakṣman": ['cae', 'ddsa', 'mw'],
    "mṛgalekhā": ['mw'],
    "mṛgalipsu": ['cae', 'mw'],
    "mṛgalocana": ['mw'],
    "mṛgalocanā": ['cae', 'mw'],
    "mṛgalocanī": ['mw'],
    "mṛgalomika": ['mw'],
    "mṛgalāñchana": ['cae', 'mw'],
    "mṛgalāñchanaja": ['mw'],
    "mṛgamada": ['cae', 'mw'],
    "mṛgamadavāsā": ['mw'],
    "mṛgamanda": ['mw'],
    "mṛgamandra": ['mw'],
    "mṛgamandā": ['mw'],
    "mṛgamattaka": ['mw'],
    "mṛgamaya": ['mw'],
    "mṛgamukha": ['mw'],
    "mṛgamāsa": ['mw'],
    "mṛgamātṛka": ['mw'],
    "mṛgamātṛkā": ['mw'],
    "mṛgamāṃsa": ['mw'],
    "mṛganayanā": ['mw'],
    "mṛganetra": ['mw'],
    "mṛganetrā": ['mw'],
    "mṛganirmokavasana": ['mw'],
    "mṛganābhi": ['cae', 'mw'],
    "mṛganābhija": ['mw'],
    "mṛganābhijā": ['mw'],
    "mṛganābhimaya": ['mw'],
    "mṛgapada": ['mw'],
    "mṛgapakṣin": ['cae', 'mw'],
    "mṛgapati": ['cae', 'mw'],
    "mṛgapatigamanā": ['mw'],
    "mṛgapatiskandha": ['bhs'],
    "mṛgapatisvara": ['bhs'],
    "mṛgapiplu": ['mw'],
    "mṛgapota": ['mw'],
    "mṛgapotaka": ['mw'],
    "mṛgaprabhu": ['mw'],
    "mṛgaprekṣin": ['mw'],
    "mṛgapriya": ['mw'],
    "mṛgapālikā": ['mw'],
    "mṛgarasā": ['mw'],
    "mṛgaripu": ['mw'],
    "mṛgarkṣa": ['mw'],
    "mṛgarocanā": ['cae', 'mw'],
    "mṛgaromaja": ['cae', 'mw'],
    "mṛgarāj": ['cae', 'ddsa', 'mw'],
    "mṛgarāja": ['cae', 'mw'],
    "mṛgarājadhārin": ['cae', 'mw'],
    "mṛgarājaghoṣa": ['bhs'],
    "mṛgarājalakṣman": ['mw'],
    "mṛgarājatā": ['mw'],
    "mṛgarājinī": ['bhs', 'mw'],
    "mṛgarāṭikā": ['mw'],
    "mṛgarūpin": ['mw'],
    "mṛgasaktha": ['mw'],
    "mṛgasattama": ['mw'],
    "mṛgasattra": ['mw'],
    "mṛgasiṃhaka": ['mw'],
    "mṛgasūkara": ['mw'],
    "mṛgatoya": ['mw'],
    "mṛgatva": ['mw'],
    "mṛgatīrtha": ['mw'],
    "mṛgatṛṣ": ['mw'],
    "mṛgatṛṣā": ['mw'],
    "mṛgatṛṣṇi": ['mw'],
    "mṛgatṛṣṇikā": ['cae', 'mw'],
    "mṛgatṛṣṇā": ['cae', 'mw'],
    "mṛgava": ['bhs', 'mw'],
    "mṛgavadhājīva": ['mw'],
    "mṛgavadhājīvin": ['mw'],
    "mṛgavadhū": ['cae', 'mw'],
    "mṛgavaiṇika": ['mw'],
    "mṛgavallabha": ['mw'],
    "mṛgavana": ['cae', 'mw'],
    "mṛgavanatīrtha": ['mw'],
    "mṛgavarman": ['mw'],
    "mṛgavatī": ['mw'],
    "mṛgavrata": ['bhs'],
    "mṛgavya": ['cae', 'ddsa', 'mw'],
    "mṛgavyaṃ": ['ap90'],
    "mṛgavyā": ['bhs'],
    "mṛgavyādha": ['cae', 'ddsa', 'mw'],
    "mṛgavyādhakathānaka": ['mw'],
    "mṛgavyādhasarpasūkara": ['mw'],
    "mṛgavyādhīya": ['mw'],
    "mṛgavyālaniṣevita": ['mw'],
    "mṛgavāhana": ['mw'],
    "mṛgavīthikā": ['mw'],
    "mṛgavīthī": ['mw'],
    "mṛgay": ['cae', 'gra'],
    "mṛgaya": ['ddsa', 'gra', 'mw'],
    "mṛgayas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛgayu": ['cae', 'ddsa', 'mw'],
    "mṛgayuḥ": ['ap90'],
    "mṛgayā": ['ap90', 'cae', 'ddsa', 'mw'],
    "mṛgayādharma": ['mw'],
    "mṛgayākrīḍana": ['mw'],
    "mṛgayākrīḍā": ['mw'],
    "mṛgayārasa": ['mw'],
    "mṛgayāraṇya": ['cae', 'mw'],
    "mṛgayāvana": ['cae', 'mw'],
    "mṛgayāveṣa": ['mw'],
    "mṛgayāvihāra": ['mw'],
    "mṛgayāvihārin": ['mw'],
    "mṛgayāvyasana": ['mw'],
    "mṛgayāyāna": ['mw'],
    "mṛgayāśīla": ['cae', 'mw'],
    "mṛgayūtha": ['mw'],
    "mṛgayūthapa": ['mw'],
    "mṛgaśapha": ['mw'],
    "mṛgaśira": ['mw'],
    "mṛgaśiras": ['bhs', 'cae', 'mw'],
    "mṛgaśirā": ['bhs', 'mw'],
    "mṛgaśreṣṭha": ['mw'],
    "mṛgaśāva": ['cae', 'mw'],
    "mṛgaśāvaka": ['mw'],
    "mṛgaśāvākṣī": ['cae', 'mw'],
    "mṛgaśāyikā": ['mw'],
    "mṛgaśīrṣa": ['bhs', 'cae', 'mw'],
    "mṛgaśīrṣan": ['mw'],
    "mṛgaśṛṅga": ['mw'],
    "mṛgaśṛṅgavratin": ['bhs', 'mw'],
    "mṛgaḥ": ['ap90'],
    "mṛgaṇyu": ['cae', 'gra', 'mw'],
    "mṛgaṇā": ['ap90', 'gra', 'mw'],
    "mṛgaṭaṅka": ['mw'],
    "mṛgebha": ['cae', 'mw'],
    "mṛgekṣaṇa": ['ddsa', 'mw'],
    "mṛgekṣaṇā": ['cae', 'mw'],
    "mṛgendra": ['cae', 'mw'],
    "mṛgendracaṭaka": ['mw'],
    "mṛgendramukha": ['mw'],
    "mṛgendrasvātikarṇa": ['mw'],
    "mṛgendratā": ['mw'],
    "mṛgendravṛṣabha": ['mw'],
    "mṛgendrottara": ['mw'],
    "mṛgendrāsana": ['mw'],
    "mṛgendrāsya": ['mw'],
    "mṛgendrāṇī": ['mw'],
    "mṛgervāru": ['mw'],
    "mṛgervāruka": ['mw'],
    "mṛgeśa": ['mw'],
    "mṛgeśavaravarman": ['mw'],
    "mṛgeśvara": ['cae', 'mw'],
    "mṛgeṣṭa": ['mw'],
    "mṛgikā": ['bhs'],
    "mṛgila": ['bhs'],
    "mṛgita": ['ap90', 'mw'],
    "mṛgodbhava": ['mw'],
    "mṛgopākhyāna": ['mw'],
    "mṛgottama": ['mw'],
    "mṛgottamāṅga": ['mw'],
    "mṛgy": ['cae'],
    "mṛgya": ['ap90', 'cae', 'ddsa', 'mw'],
    "mṛgā": ['mw'],
    "mṛgād": ['mw'],
    "mṛgāda": ['mw'],
    "mṛgādana": ['mw'],
    "mṛgādanī": ['mw'],
    "mṛgādhipa": ['cae', 'mw'],
    "mṛgādhipatya": ['mw'],
    "mṛgādhirāja": ['mw'],
    "mṛgādī": ['mw'],
    "mṛgājina": ['mw'],
    "mṛgājira": ['mw'],
    "mṛgājīva": ['mw'],
    "mṛgākhara": ['mw'],
    "mṛgākhya": ['mw'],
    "mṛgākṣī": ['cae', 'ddsa', 'mw'],
    "mṛgākṣītriyāmā": ['mw'],
    "mṛgāntaka": ['mw'],
    "mṛgāra": ['bhs', 'mw'],
    "mṛgāramātar": ['bhs'],
    "mṛgāramātuḥprāsāda": ['bhs'],
    "mṛgārasūkta": ['mw'],
    "mṛgāreṣṭi": ['mw'],
    "mṛgāreṣṭihautra": ['mw'],
    "mṛgāreṣṭipaddhati": ['mw'],
    "mṛgāreṣṭiprayoga": ['mw'],
    "mṛgāreṣṭyādiprayoga": ['mw'],
    "mṛgāri": ['cae', 'mw'],
    "mṛgārāti": ['cae', 'mw'],
    "mṛgāsya": ['mw'],
    "mṛgāvatī": ['ddsa', 'mw'],
    "mṛgāvatīcaritra": ['mw'],
    "mṛgāvidh": ['mw'],
    "mṛgāyaṇī": ['bhs'],
    "mṛgāśana": ['mw'],
    "mṛgāṅganā": ['cae', 'ddsa', 'mw'],
    "mṛgāṅka": ['cae', 'ddsa', 'mw'],
    "mṛgāṅkabandhu": ['mw'],
    "mṛgāṅkadatta": ['mw'],
    "mṛgāṅkadattīya": ['mw'],
    "mṛgāṅkagupta": ['mw'],
    "mṛgāṅkaka": ['mw'],
    "mṛgāṅkalekha": ['mw'],
    "mṛgāṅkalekhakathā": ['mw'],
    "mṛgāṅkalekhā": ['mw'],
    "mṛgāṅkamauli": ['mw'],
    "mṛgāṅkamaṇi": ['mw'],
    "mṛgāṅkamālā": ['mw'],
    "mṛgāṅkamūrti": ['mw'],
    "mṛgāṅkarasa": ['mw'],
    "mṛgāṅkarkṣa": ['mw'],
    "mṛgāṅkasena": ['mw'],
    "mṛgāṅkatanaya": ['mw'],
    "mṛgāṅkavatī": ['mw'],
    "mṛgāṅkaśataka": ['mw'],
    "mṛgāṇḍajā": ['mw'],
    "mṛgāṇḍakī": ['mw'],
    "mṛgāṣṭaka": ['mw'],
    "mṛgāṭavī": ['mw'],
    "mṛgī": ['ap90', 'bhs', 'ddsa', 'mw'],
    "mṛgīdṛś": ['cae', 'mw'],
    "mṛgīkuṇḍa": ['mw'],
    "mṛgīkṣīra": ['mw'],
    "mṛgīlocanā": ['mw'],
    "mṛgīpati": ['mw'],
    "mṛgītva": ['mw'],
    "mṛgū": ['mw'],
    "mṛj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛja": ['cae', 'ddsa', 'mw'],
    "mṛjaḥ": ['ap90'],
    "mṛjita": ['ap90', 'mw'],
    "mṛjopeta": ['mw'],
    "mṛjya": ['cae', 'mw'],
    "mṛjā": ['ap90', 'mw'],
    "mṛjāhīna": ['mw'],
    "mṛjānagara": ['mw'],
    "mṛjānvaya": ['mw'],
    "mṛjāvarṇabalaprada": ['mw'],
    "mṛjāvat": ['mw'],
    "mṛjāvihīna": ['mw'],
    "mṛkaṇḍa": ['cae', 'ddsa', 'mw'],
    "mṛkaṇḍaka": ['mw'],
    "mṛkaṇḍu": ['cae', 'mw'],
    "mṛkta": ['mw'],
    "mṛktavāhas": ['gra', 'mw'],
    "mṛkṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛkṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "mṛkṣakanāṭaka": ['mw'],
    "mṛkṣin": ['gra'],
    "mṛkṣiṇī": ['cae', 'mw'],
    "mṛl": ['mw'],
    "mṛlloṣṭa": ['cae', 'ddsa', 'mw'],
    "mṛl̤": ['mw'],
    "mṛl̤aya": ['mw'],
    "mṛl̤ayāku": ['cae', 'mw'],
    "mṛl̤īka": ['mw'],
    "mṛn": ['mw'],
    "mṛnmaru": ['mw'],
    "mṛnmaya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛnmayaka": ['mw'],
    "mṛnmayūra": ['cae'],
    "mṛnmāna": ['mw'],
    "mṛnmūṣā": ['mw'],
    "mṛt": ['mw'],
    "mṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "mṛtabhartṛkā": ['mw'],
    "mṛtabhraj": ['mw'],
    "mṛtabhāva": ['mw'],
    "mṛtacela": ['cae', 'mw'],
    "mṛtadeha": ['cae', 'mw'],
    "mṛtadhavā": ['mw'],
    "mṛtadhāra": ['cae', 'mw'],
    "mṛtadhāraka": ['cae', 'mw'],
    "mṛtadāra": ['mw'],
    "mṛtagarbhā": ['mw'],
    "mṛtagṛha": ['bhs', 'mw'],
    "mṛtahāra": ['mw'],
    "mṛtahārin": ['mw'],
    "mṛtajāta": ['cae', 'mw'],
    "mṛtajātaka": ['mw'],
    "mṛtajīva": ['mw'],
    "mṛtajīvana": ['cae', 'mw'],
    "mṛtaka": ['cae', 'mw'],
    "mṛtakalpa": ['cae', 'mw'],
    "mṛtakambala": ['mw'],
    "mṛtakaḥ": ['ap90'],
    "mṛtakāntaka": ['mw'],
    "mṛtamanas": ['mw'],
    "mṛtamatta": ['mw'],
    "mṛtamattaka": ['mw'],
    "mṛtamātṛka": ['mw'],
    "mṛtanandana": ['mw'],
    "mṛtaniryātaka": ['mw'],
    "mṛtanātha": ['mw'],
    "mṛtapa": ['mw'],
    "mṛtapatnīkādhāna": ['mw'],
    "mṛtaprajā": ['mw'],
    "mṛtapriyā": ['mw'],
    "mṛtaprāya": ['mw'],
    "mṛtapuruṣadeha": ['cae'],
    "mṛtapuruṣaśarīra": ['cae', 'mw'],
    "mṛtaputra": ['mw'],
    "mṛtapā": ['mw'],
    "mṛtapūruṣadeha": ['mw'],
    "mṛtasaṃjīvana": ['cae', 'mw'],
    "mṛtasaṃjīvanī": ['mw'],
    "mṛtasaṃjīvin": ['mw'],
    "mṛtasaṃjīvinī": ['mw'],
    "mṛtasaṃskāra": ['mw'],
    "mṛtasnāna": ['mw'],
    "mṛtasnāta": ['mw'],
    "mṛtastrī": ['mw'],
    "mṛtasvamoktṛ": ['mw'],
    "mṛtasūtaka": ['mw'],
    "mṛtavastrabhṛt": ['cae', 'mw'],
    "mṛtavat": ['cae', 'mw'],
    "mṛtavatsakā": ['mw'],
    "mṛtavatsikā": ['mw'],
    "mṛtavatsā": ['mw'],
    "mṛtavatsācikitsā": ['mw'],
    "mṛtavārṣika": ['bhs', 'mw'],
    "mṛtavāsara": ['mw'],
    "mṛtaśabda": ['mw'],
    "mṛtaśaṅkā": ['mw'],
    "mṛtaṃḍaḥ": ['ap90'],
    "mṛtaṇḍa": ['mw'],
    "mṛti": ['cae', 'ddsa', 'mw'],
    "mṛtiman": ['ap90', 'ddsa', 'mw'],
    "mṛtirekhā": ['ddsa', 'mw'],
    "mṛtisādhana": ['mw'],
    "mṛtitattva": ['mw'],
    "mṛtitattvānusmaraṇa": ['mw'],
    "mṛtiḥ": ['ap90'],
    "mṛtkara": ['mw'],
    "mṛtkarman": ['mw'],
    "mṛtkarmasampanna": ['mw'],
    "mṛtkaṇa": ['ddsa', 'mw'],
    "mṛtkaṇatā": ['mw'],
    "mṛtkhalinī": ['mw'],
    "mṛtkhana": ['mw'],
    "mṛtkirā": ['mw'],
    "mṛtkāṃsya": ['mw'],
    "mṛtkṣāra": ['mw'],
    "mṛtodbhava": ['mw'],
    "mṛtotthita": ['mw'],
    "mṛtpaca": ['ddsa', 'mw'],
    "mṛtphalī": ['mw'],
    "mṛtpiṇḍa": ['cae', 'mw'],
    "mṛtpiṇḍabuddhi": ['cae', 'mw'],
    "mṛtpiṇḍatas": ['mw'],
    "mṛtprakṣepa": ['cae', 'mw'],
    "mṛtpātra": ['cae', 'mw'],
    "mṛtsna": ['cae', 'ddsa', 'mw'],
    "mṛtsnaṃ": ['ap90'],
    "mṛtsnā": ['mw'],
    "mṛtsnābhāṇḍaka": ['mw'],
    "mṛtstoma": ['mw'],
    "mṛtsā": ['ap90', 'mw'],
    "mṛttikama": ['bhs'],
    "mṛttikā": ['ap90', 'ddsa', 'mw'],
    "mṛttikācūrṇa": ['mw'],
    "mṛttikāvata": ['mw'],
    "mṛttikāvatī": ['mw'],
    "mṛttoya": ['cae', 'mw'],
    "mṛttāla": ['mw'],
    "mṛttālaka": ['mw'],
    "mṛtyava": ['mw'],
    "mṛtyu": ['cae', 'ddsa', 'gra', 'mw'],
    "mṛtyubandhu": ['cae', 'gra', 'mw'],
    "mṛtyubhaya": ['cae', 'mw'],
    "mṛtyubhaṅguraka": ['mw'],
    "mṛtyubhīta": ['mw'],
    "mṛtyubhṛtya": ['mw'],
    "mṛtyubīja": ['mw'],
    "mṛtyuda": ['mw'],
    "mṛtyudvāra": ['cae', 'mw'],
    "mṛtyudūta": ['cae', 'mw'],
    "mṛtyuhetave": ['mw'],
    "mṛtyuhetu": ['mw'],
    "mṛtyujit": ['mw'],
    "mṛtyuka": ['ddsa', 'mw'],
    "mṛtyukanyā": ['mw'],
    "mṛtyukara": ['mw'],
    "mṛtyukāla": ['cae', 'mw'],
    "mṛtyukālacihna": ['mw'],
    "mṛtyulaṅghanopaniṣad": ['mw'],
    "mṛtyuloka": ['mw'],
    "mṛtyulāṅgalopaniṣad": ['mw'],
    "mṛtyulāṅgulastotra": ['mw'],
    "mṛtyulāṅgūla": ['mw'],
    "mṛtyulāṅgūlamantra": ['mw'],
    "mṛtyumahiṣīdāna": ['mw'],
    "mṛtyumahiṣīdānavidhi": ['mw'],
    "mṛtyumant": ['cae'],
    "mṛtyumat": ['mw'],
    "mṛtyumāra": ['bhs', 'mw'],
    "mṛtyumṛtyu": ['mw'],
    "mṛtyumṛtyutva": ['mw'],
    "mṛtyunivartaka": ['mw'],
    "mṛtyunāśaka": ['mw'],
    "mṛtyunāśana": ['mw'],
    "mṛtyupatha": ['mw'],
    "mṛtyuphala": ['mw'],
    "mṛtyuphalā": ['mw'],
    "mṛtyuphalī": ['mw'],
    "mṛtyupratibaddha": ['mw'],
    "mṛtyupuṣpa": ['mw'],
    "mṛtyupā": ['mw'],
    "mṛtyupāśa": ['cae', 'mw'],
    "mṛtyurāj": ['mw'],
    "mṛtyurūpiṇī": ['mw'],
    "mṛtyusammita": ['mw'],
    "mṛtyusaṃdhita": ['mw'],
    "mṛtyusaṃjīvanī": ['mw'],
    "mṛtyusaṃjīvanīvidhāna": ['mw'],
    "mṛtyusaṃyamana": ['mw'],
    "mṛtyusaṃyuta": ['mw'],
    "mṛtyusenā": ['mw'],
    "mṛtyusevaka": ['mw'],
    "mṛtyusuta": ['mw'],
    "mṛtyusutā": ['mw'],
    "mṛtyusāt": ['mw'],
    "mṛtyusātkṛ": ['ddsa'],
    "mṛtyusūkta": ['mw'],
    "mṛtyusūti": ['mw'],
    "mṛtyutīrtha": ['mw'],
    "mṛtyutūrya": ['mw'],
    "mṛtyuvañcana": ['mw'],
    "mṛtyuvijaya": ['mw'],
    "mṛtyuśrama": ['mw'],
    "mṛtyuḥ": ['ap90'],
    "mṛtyuṃjaya": ['mw'],
    "mṛtyuṃjayadhyāna": ['mw'],
    "mṛtyuṃjayajapa": ['mw'],
    "mṛtyuṃjayakokila": ['mw'],
    "mṛtyuṃjayamānasa": ['mw'],
    "mṛtyuṃjayapaddhati": ['mw'],
    "mṛtyuṃjayastotra": ['mw'],
    "mṛtyuṃjayastotravidhāna": ['mw'],
    "mṛtyuṃjayatantra": ['mw'],
    "mṛtyuṃjayatvaprakaraṇa": ['mw'],
    "mṛtyuṃjayatā": ['mw'],
    "mṛtyuṃjayatīrtha": ['mw'],
    "mṛtyuṃjayavidhi": ['mw'],
    "mṛtyuṃjayavidhāna": ['mw'],
    "mṛtyuṃjayavidhānapaddhati": ['mw'],
    "mṛtyuṃjayayantra": ['mw'],
    "mṛtyuṃjayaḥ": ['ap90'],
    "mṛtyuṃjayādihomavidhi": ['mw'],
    "mṛtyvaṣṭaka": ['mw'],
    "mṛtādhāna": ['mw'],
    "mṛtāha": ['cae', 'mw'],
    "mṛtāhan": ['mw'],
    "mṛtāhas": ['mw'],
    "mṛtālaka": ['mw'],
    "mṛtālakaṃ": ['ap90'],
    "mṛtāmada": ['mw'],
    "mṛtāśana": ['mw'],
    "mṛtāśauca": ['mw'],
    "mṛtāṅga": ['cae', 'ddsa', 'mw'],
    "mṛtāṅgalagna": ['mw'],
    "mṛtāṅgāra": ['mw'],
    "mṛtāṇḍa": ['mw'],
    "mṛtāṇḍā": ['mw'],
    "mṛyati": ['bhs'],
    "mṛś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛśaya": ['mw'],
    "mṛśākhāna": ['mw'],
    "mṛśīta": ['mw'],
    "mṛḍ": ['ap90', 'cae', 'gra', 'mw'],
    "mṛḍa": ['cae', 'ddsa', 'mw'],
    "mṛḍana": ['cae', 'mw'],
    "mṛḍanaṃ": ['ap90'],
    "mṛḍaya": ['mw'],
    "mṛḍayat": ['mw'],
    "mṛḍayāku": ['gra', 'mw'],
    "mṛḍaḥ": ['ap90'],
    "mṛḍitṛ": ['cae', 'mw'],
    "mṛḍā": ['ap90'],
    "mṛḍāku": ['mw'],
    "mṛḍānī": ['cae', 'mw'],
    "mṛḍānīkānta": ['mw'],
    "mṛḍānīpati": ['mw'],
    "mṛḍānītantra": ['mw'],
    "mṛḍānīśvara": ['mw'],
    "mṛḍīka": ['cae', 'gra', 'mw'],
    "mṛḍīkaḥ": ['ap90'],
    "mṛṇ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛṇmaya": ['ap90', 'mw'],
    "mṛṇāla": ['bhs', 'cae', 'ddsa', 'mw'],
    "mṛṇālabhañjam": ['mw'],
    "mṛṇālabhaṅga": ['mw'],
    "mṛṇāladhavala": ['mw'],
    "mṛṇālahāra": ['mw'],
    "mṛṇālaka": ['cae', 'mw'],
    "mṛṇālakaṇṭha": ['mw'],
    "mṛṇālakomala": ['mw'],
    "mṛṇālalatikā": ['mw'],
    "mṛṇālamaya": ['mw'],
    "mṛṇālapattra": ['mw'],
    "mṛṇālasūtra": ['cae', 'mw'],
    "mṛṇālavalaya": ['cae', 'mw'],
    "mṛṇālavallī": ['mw'],
    "mṛṇālavat": ['mw'],
    "mṛṇālaḥ": ['ap90'],
    "mṛṇālikā": ['ap90', 'ddsa', 'mw'],
    "mṛṇālikāmaya": ['mw'],
    "mṛṇālikāpelava": ['mw'],
    "mṛṇālin": ['ap90', 'mw'],
    "mṛṇālinī": ['ap90', 'cae', 'ddsa'],
    "mṛṇāliṇī": ['mw'],
    "mṛṇālāsava": ['mw'],
    "mṛṇālāṅgada": ['mw'],
    "mṛṇālī": ['ddsa'],
    "mṛṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛṣa": ['bhs'],
    "mṛṣita": ['mw'],
    "mṛṣodya": ['cae', 'mw'],
    "mṛṣā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "mṛṣābhāṣin": ['cae', 'mw'],
    "mṛṣādhyānin": ['mw'],
    "mṛṣādhyāyin": ['mw'],
    "mṛṣādāna": ['mw'],
    "mṛṣādṛṣṭi": ['mw'],
    "mṛṣājñāna": ['cae', 'ddsa', 'mw'],
    "mṛṣālaka": ['mw'],
    "mṛṣālakaḥ": ['ap90'],
    "mṛṣānuśāsin": ['mw'],
    "mṛṣārtha": ['ddsa', 'mw'],
    "mṛṣārthaka": ['mw'],
    "mṛṣāsākṣin": ['mw'],
    "mṛṣātva": ['mw'],
    "mṛṣāvacana": ['cae', 'mw'],
    "mṛṣāvāc": ['mw'],
    "mṛṣāvāda": ['cae', 'mw'],
    "mṛṣāvādika": ['bhs'],
    "mṛṣāvādin": ['cae', 'mw'],
    "mṛṣāya": ['ddsa', 'mw'],
    "mṛṣāyate": ['ap90'],
    "mṛṣṭa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "mṛṣṭagandha": ['mw'],
    "mṛṣṭagandhapavana": ['mw'],
    "mṛṣṭakuṇḍala": ['mw'],
    "mṛṣṭaluñcita": ['mw'],
    "mṛṣṭasalila": ['mw'],
    "mṛṣṭatama": ['mw'],
    "mṛṣṭavat": ['mw'],
    "mṛṣṭavākya": ['mw'],
    "mṛṣṭayaśas": ['mw'],
    "mṛṣṭaśalāka": ['mw'],
    "mṛṣṭeruka": ['ap90', 'mw'],
    "mṛṣṭi": ['cae', 'ddsa', 'mw'],
    "mṛṣṭiḥ": ['ap90'],
    "mṛṣṭānulepana": ['mw'],
    "mṛṣṭāśana": ['mw'],
    "mṛṣṭāśin": ['mw'],
    "mṝ": ['ap90', 'mw'],
    "na": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "na ciraṁ": ['cped'],
    "na koci": ['cped'],
    "naarmin": ['gra'],
    "naasatya": ['gra'],
    "nabh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nabha": ['ap90', 'cae', 'mw'],
    "nabha(s)": ['cped'],
    "nabhaga": ['mw'],
    "nabhakānana": ['mw'],
    "nabhania": ['gra'],
    "nabhanu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nabhanya": ['cae', 'gra', 'mw'],
    "nabhanyu": ['ap90'],
    "nabhanū": ['gra', 'mw'],
    "nabhas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nabhasa": ['ap90', 'cae', 'mw'],
    "nabhasaṃgama": ['mw'],
    "nabhasaṃgamaḥ": ['ap90'],
    "nabhasigama": ['cped'],
    "nabhasmaya": ['cae', 'gra', 'mw'],
    "nabhastala": ['cae', 'ddsa', 'mw'],
    "nabhastas": ['cae', 'mw'],
    "nabhasvant": ['cae'],
    "nabhasvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "nabhasvatī": ['mw'],
    "nabhasya": ['ap90', 'cae', 'ddsa', 'mw'],
    "nabhaukas": ['mw'],
    "nabhaś": ['mw'],
    "nabhaścakṣus": ['mw'],
    "nabhaścamasa": ['mw'],
    "nabhaścara": ['cae', 'ddsa', 'mw'],
    "nabhaścyuta": ['mw'],
    "nabhaḥ": ['mw'],
    "nabhaḥketana": ['mw'],
    "nabhaḥkrānta": ['mw'],
    "nabhaḥkrāntin": ['mw'],
    "nabhaḥprabheda": ['mw'],
    "nabhaḥprabhedana": ['mw'],
    "nabhaḥprāṇa": ['mw'],
    "nabhaḥpāntha": ['mw'],
    "nabhaḥsad": ['cae', 'ddsa', 'mw'],
    "nabhaḥsaras": ['mw'],
    "nabhaḥsarit": ['mw'],
    "nabhaḥsenā": ['mw'],
    "nabhaḥsindhu": ['cae', 'mw'],
    "nabhaḥsindhuputra": ['mw'],
    "nabhaḥspṛś": ['cae', 'mw'],
    "nabhaḥspṛśa": ['cae'],
    "nabhaḥstha": ['mw'],
    "nabhaḥsthala": ['cae', 'mw'],
    "nabhaḥsthita": ['mw'],
    "nabhaḥśabdamaya": ['ddsa', 'mw'],
    "nabhaḥśrit": ['cae', 'mw'],
    "nabhaḥśvāsa": ['mw'],
    "nabhi": ['mw'],
    "nabho": ['mw'],
    "nabhoda": ['mw'],
    "nabhodhvaja": ['mw'],
    "nabhodhūma": ['mw'],
    "nabhoduha": ['mw'],
    "nabhodvīpa": ['mw'],
    "nabhodṛṣṭi": ['mw'],
    "nabhoga": ['mw'],
    "nabhogaja": ['mw'],
    "nabhogati": ['mw'],
    "nabhojā": ['cae', 'gra', 'mw'],
    "nabhojū": ['cae', 'gra', 'mw'],
    "nabholaya": ['mw'],
    "nabholih": ['mw'],
    "nabhomadhya": ['mw'],
    "nabhomaṇi": ['mw'],
    "nabhomaṇḍala": ['cae', 'mw'],
    "nabhomaṇḍaladīpa": ['mw'],
    "nabhombupa": ['mw'],
    "nabhomudrā": ['mw'],
    "nabhonabhasyatva": ['mw'],
    "nabhonadī": ['mw'],
    "nabhorajas": ['mw'],
    "nabhoreṇu": ['mw'],
    "nabhorūpa": ['cae', 'mw'],
    "nabhovaṭa": ['mw'],
    "nabhovid": ['cae', 'gra', 'mw'],
    "nabhovīthī": ['cae', 'mw'],
    "nabhoyoni": ['cae', 'mw'],
    "nabhoṅgaṇa": ['mw'],
    "nabho’ṅgaṇa": ['ddsa'],
    "nabhrāj": ['ap90', 'mw'],
    "nabhya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nabhyastha": ['cae', 'mw'],
    "nabhā": ['mw'],
    "nabhāga": ['mw'],
    "nabhāka": ['gra', 'mw'],
    "nabhākavat": ['mw'],
    "nabhākaḥ": ['ap90'],
    "nabhīta": ['cae', 'mw'],
    "nabhītavat": ['mw'],
    "naca": ['bhs'],
    "nacca": ['cped'],
    "naccagīta": ['cped'],
    "naccaka": ['cped'],
    "naccati": ['cped'],
    "naccayati": ['cped'],
    "nacceti": ['cped'],
    "nacci": ['cped'],
    "naciketa": ['cae', 'mw'],
    "naciketas": ['ap90', 'cae', 'ddsa', 'mw'],
    "nacira": ['ap90', 'cae', 'ddsa', 'mw'],
    "nacirakālam": ['mw'],
    "naciram": ['mw'],
    "nacireṇa": ['mw'],
    "nacirāt": ['mw'],
    "nacirāya": ['mw'],
    "nacārthavāda": ['mw'],
    "nad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nada": ['cae', 'ddsa', 'gra', 'mw'],
    "nada(t)": ['cped'],
    "nadabhakta": ['mw'],
    "nadabhartṛ": ['cae', 'ddsa', 'mw'],
    "nadadhra": ['mw'],
    "nadana": ['mw'],
    "nadanadī": ['mw'],
    "nadanadībhartṛ": ['cae', 'mw'],
    "nadanadīpati": ['cae', 'mw'],
    "nadaniman": ['cae', 'mw'],
    "nadanta": ['cped'],
    "nadanu": ['cae', 'gra', 'mw'],
    "nadanumant": ['cae'],
    "nadanumat": ['gra', 'mw'],
    "nadanuḥ": ['ap90'],
    "nadara": ['mw'],
    "nadarāja": ['cae', 'mw'],
    "nadarājasutā": ['mw'],
    "nadasya": ['mw'],
    "nadat": ['mw'],
    "nadathu": ['cae', 'mw'],
    "nadathuḥ": ['ap90'],
    "nadati": ['cped'],
    "nadaḥ": ['ap90'],
    "nadbhyas": ['mw'],
    "naddha": ['ap90', 'cae', 'ddsa', 'mw'],
    "naddhavimokṣa": ['mw'],
    "naddhavya": ['mw'],
    "naddhi": ['cae', 'cped', 'ddsa', 'mw'],
    "naddhiḥ": ['ap90'],
    "naddhrī": ['ap90', 'mw'],
    "nadeyī": ['mw'],
    "nadeśa": ['ddsa'],
    "nadh": ['gra'],
    "nadi": ['cae', 'cped', 'mw'],
    "nadija": ['mw'],
    "nadikā": ['ap90', 'cped', 'mw'],
    "nadin": ['bhs'],
    "nadita": ['cped'],
    "naditvā": ['cped'],
    "naditvāna": ['cped'],
    "nadiyā": ['cped'],
    "nadiḥ": ['ap90'],
    "nadya": ['ap90'],
    "nadyambujīvana": ['mw'],
    "nadyāmra": ['mw'],
    "nadāla": ['ap90', 'mw'],
    "nadī": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nadībhallātaka": ['mw'],
    "nadībhava": ['mw'],
    "nadīdatta": ['bhs', 'mw'],
    "nadīdhara": ['mw'],
    "nadīdoha": ['mw'],
    "nadīja": ['cae', 'mw'],
    "nadījña": ['mw'],
    "nadījā": ['mw'],
    "nadījāta": ['mw'],
    "nadīkadamba": ['mw'],
    "nadīkāla": ['bhs'],
    "nadīkānta": ['mw'],
    "nadīkāntā": ['mw'],
    "nadīkāśyapa": ['bhs', 'mw'],
    "nadīkūla": ['mw'],
    "nadīkūlapriya": ['mw'],
    "nadīkṣetrādimāhātmya": ['mw'],
    "nadīmukha": ['cae', 'mw'],
    "nadīmārga": ['mw'],
    "nadīmātṛka": ['mw'],
    "nadīmātṛkatā": ['mw'],
    "nadīna": ['cae', 'ddsa', 'mw'],
    "nadīnada": ['cae', 'ddsa', 'mw'],
    "nadīniṣpāva": ['mw'],
    "nadīnāma": ['mw'],
    "nadīnātha": ['cae', 'mw'],
    "nadīpati": ['cae', 'mw'],
    "nadīpaṅka": ['mw'],
    "nadīpūra": ['cae', 'mw'],
    "nadīraya": ['mw'],
    "nadīsantāra": ['ddsa'],
    "nadīsarja": ['mw'],
    "nadīsaṃtāra": ['cae', 'mw'],
    "nadīsīsa": ['mw'],
    "nadītara": ['mw'],
    "nadītarasthala": ['mw'],
    "nadītarasthāna": ['mw'],
    "nadītaṭa": ['cae', 'mw'],
    "nadītīra": ['mw'],
    "nadīvakra": ['mw'],
    "nadīvapra": ['mw'],
    "nadīvaṅka": ['mw'],
    "nadīvaṭa": ['mw'],
    "nadīvega": ['mw'],
    "nadīvelā": ['mw'],
    "nadīvāsa": ['mw'],
    "nadīvṛt": ['gra', 'mw'],
    "nadīya": ['mw'],
    "nadīśa": ['cae', 'ddsa', 'mw'],
    "nadīṣṇa": ['cae', 'ddsa', 'mw'],
    "nadūṣita": ['mw'],
    "nadūṣitadhī": ['mw'],
    "nadṛśya": ['cae', 'mw'],
    "nadṛśyatva": ['mw'],
    "naga": ['cae', 'cped', 'ddsa', 'mw'],
    "nagabhid": ['mw'],
    "nagabhū": ['mw'],
    "nagaja": ['mw'],
    "nagajā": ['mw'],
    "nagakarṇī": ['mw'],
    "nagamūrdhan": ['mw'],
    "naganadī": ['cae', 'ddsa', 'mw'],
    "naganandinī": ['mw'],
    "naganimnagā": ['cae', 'mw'],
    "nagapati": ['mw'],
    "nagara": ['cae', 'cped', 'ddsa', 'mw'],
    "nagarabhandana": ['cped'],
    "nagarabindu": ['bhs'],
    "nagarabāhu": ['mw'],
    "nagarabāhya": ['mw'],
    "nagaracatuṣpatha": ['mw'],
    "nagaradaivata": ['cae', 'mw'],
    "nagaradaivatavat": ['mw'],
    "nagaradhanasaṃghārāma": ['mw'],
    "nagaradhanavihāra": ['mw'],
    "nagaradvāra": ['cae', 'mw'],
    "nagaradvārakūṭaka": ['mw'],
    "nagaraghāta": ['cped', 'mw'],
    "nagaragāmin": ['cae', 'mw'],
    "nagarahāra": ['mw'],
    "nagarajana": ['cae', 'mw'],
    "nagarakhaṇḍa": ['mw'],
    "nagarakoṭi": ['mw'],
    "nagarakāka": ['mw'],
    "nagaramardin": ['mw'],
    "nagaramaṇḍanā": ['mw'],
    "nagaramoṣa": ['mw'],
    "nagaramustā": ['mw'],
    "nagaramālin": ['mw'],
    "nagarandhrakara": ['ddsa', 'mw'],
    "nagarapati": ['mw'],
    "nagarapaṭisaṅkhārika": ['cped'],
    "nagarapaṭisaṅkhāriya": ['cped'],
    "nagarapradakṣiṇā": ['mw'],
    "nagaraprānta": ['mw'],
    "nagarapura": ['mw'],
    "nagararakṣin": ['cae', 'mw'],
    "nagararakṣā": ['cae'],
    "nagararakṣādhikṛta": ['ddsa', 'mw'],
    "nagarasammita": ['mw'],
    "nagarastha": ['cae', 'mw'],
    "nagarasvāmin": ['mw'],
    "nagaraukas": ['cae', 'ddsa', 'mw'],
    "nagarauṣadhi": ['mw'],
    "nagaravāsin": ['mw'],
    "nagaravāyasa": ['mw'],
    "nagaravṛddha": ['cae', 'mw'],
    "nagaraṃ": ['ap90'],
    "nagarin": ['cae', 'ddsa', 'mw'],
    "nagaropānta": ['cae', 'ddsa', 'mw'],
    "nagarotthā": ['mw'],
    "nagaryanna": ['cae', 'mw'],
    "nagarābhyāśa": ['mw'],
    "nagarādhikṛta": ['ddsa', 'mw'],
    "nagarādhipa": ['cae', 'mw'],
    "nagarādhipati": ['cae', 'mw'],
    "nagarādhyakṣa": ['cae', 'mw'],
    "nagarāvalambaka": ['bhs'],
    "nagarāya": ['mw'],
    "nagarī": ['ap90', 'ddsa', 'mw'],
    "nagarībaka": ['mw'],
    "nagarīnirodha": ['mw'],
    "nagarīrakṣin": ['cae', 'mw'],
    "nagarīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "nagarīyukti": ['mw'],
    "nagarūpakārikā": ['cped'],
    "nagasvarūpiṇī": ['mw'],
    "nagaukas": ['mw'],
    "nagavant": ['cae'],
    "nagavat": ['mw'],
    "nagavāhana": ['mw'],
    "nagavṛttika": ['mw'],
    "nagaśreṣṭha": ['mw'],
    "nagaḥ": ['ap90'],
    "nagaṇā": ['mw'],
    "nagendra": ['cae', 'ddsa', 'mw'],
    "nageśa": ['cae', 'mw'],
    "nageśvara": ['cae', 'mw'],
    "nagga": ['cped'],
    "naggacarīya": ['cped'],
    "naggeyya": ['cped'],
    "naggiya": ['cped'],
    "naghamāra": ['gra', 'mw'],
    "naghuṣa": ['ddsa', 'mw'],
    "naghāriṣa": ['gra', 'mw'],
    "nagna": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "nagnabhūpatigraha": ['mw'],
    "nagnacaryā": ['bhs', 'mw'],
    "nagnadhara": ['mw'],
    "nagnahu": ['cae', 'mw'],
    "nagnahū": ['mw'],
    "nagnaikā": ['mw'],
    "nagnajit": ['mw'],
    "nagnaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "nagnakā": ['ap90'],
    "nagnakṣapaṇaka": ['ddsa', 'mw'],
    "nagnambhaviṣṇu": ['mw'],
    "nagnambhāvuka": ['ddsa'],
    "nagnamuṣita": ['mw'],
    "nagnanīlapaṭādika": ['mw'],
    "nagnatva": ['mw'],
    "nagnatā": ['cae', 'gra', 'mw'],
    "nagnavratadhara": ['mw'],
    "nagnavṛtti": ['mw'],
    "nagnaśramaṇa": ['mw'],
    "nagnaśravaṇa": ['bhs', 'mw'],
    "nagnaṃbhaviṣṇu": ['ap90'],
    "nagnaṃkaraṇa": ['mw'],
    "nagnaṃkaraṇaṃ": ['ap90'],
    "nagnikā": ['ddsa', 'mw'],
    "nagnā": ['mw'],
    "nagnācārya": ['mw'],
    "nagnāṭa": ['ddsa', 'mw'],
    "nagnāṭaka": ['mw'],
    "nagnī": ['mw'],
    "nagnīkaraṇa": ['mw'],
    "nagnīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "nagnīkṛta": ['ap90', 'mw'],
    "nagocchrāya": ['mw'],
    "nagodara": ['cae', 'mw'],
    "nagotsaṅga": ['mw'],
    "nagādhipa": ['mw'],
    "nagādhirāja": ['mw'],
    "nagāgra": ['cae', 'ddsa', 'mw'],
    "nagāhvaya": ['mw'],
    "nagālikā": ['mw'],
    "nagānikā": ['mw'],
    "nagāntare": ['cped'],
    "nagānī": ['mw'],
    "nagāpagā": ['cae', 'mw'],
    "nagāri": ['mw'],
    "nagāvāsa": ['mw'],
    "nagāśman": ['mw'],
    "nagāśraya": ['mw'],
    "nagāṭana": ['mw'],
    "nah": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nahana": ['cae', 'gra'],
    "naharū": ['bhs'],
    "nahasra": ['mw'],
    "nahatvā": ['cped'],
    "nahi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nahimantra": ['bhs'],
    "nahimātra": ['mw'],
    "nahus": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nahuta": ['cped'],
    "nahuṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "nahuṣacarita": ['mw'],
    "nahuṣaḥ": ['ap90'],
    "nahuṣia": ['gra'],
    "nahuṣya": ['ap90', 'cae', 'gra', 'mw'],
    "nahuṣākhya": ['mw'],
    "nahuṣātmaja": ['mw'],
    "nahāna": ['cped'],
    "nahānagaruka": ['cped'],
    "nahāniya": ['cped'],
    "nahāniyacuṇṇa": ['cped'],
    "nahānīya": ['cped'],
    "nahāpaka": ['cped'],
    "nahāpana": ['cped'],
    "nahāpayati": ['cped'],
    "nahāpesuṁ": ['cped'],
    "nahāpetabba": ['cped'],
    "nahāpeti": ['cped'],
    "nahāpetvā": ['cped'],
    "nahāpita": ['cped'],
    "nahāru": ['cped'],
    "nahārudaddula": ['cped'],
    "nahāta": ['cped'],
    "nahātaka": ['cped'],
    "nahāyamāna": ['cped'],
    "nahāyanta": ['cped'],
    "nahāyati": ['cped'],
    "nahāyita(r)": ['cped'],
    "nahāyitabba": ['cped'],
    "nahāyituṁ": ['cped'],
    "nahāyitvā": ['cped'],
    "nahāyiṁsu": ['cped'],
    "nahīnagarbha": ['bhs'],
    "nai": ['mw'],
    "naibaddhaka": ['mw'],
    "naibhṛtya": ['bhs', 'mw'],
    "naibhṛtyaṃ": ['ap90'],
    "naibiḍya": ['cae', 'ddsa', 'mw'],
    "naibiḍyaṃ": ['ap90'],
    "naibuka": ['mw'],
    "naicakya": ['mw'],
    "naicakī": ['ap90'],
    "naicika": ['mw'],
    "naicikaṃ": ['ap90'],
    "naicikī": ['ap90', 'mw'],
    "naicitya": ['mw'],
    "naicudāra": ['mw'],
    "naicula": ['mw'],
    "naicāśākha": ['ap90', 'gra', 'mw'],
    "naideśika": ['mw'],
    "naideśikaḥ": ['ap90'],
    "naidhana": ['ap90', 'cae', 'ddsa', 'mw'],
    "naidheya": ['mw'],
    "naidhruva": ['mw'],
    "naidhruvi": ['mw'],
    "naidhāna": ['mw'],
    "naidhānya": ['mw'],
    "naidra": ['cae', 'ddsa', 'mw'],
    "naidāgha": ['cae', 'ddsa', 'mw'],
    "naidāghaḥ": ['ap90'],
    "naidāghika": ['cae'],
    "naidāghī": ['mw'],
    "naidāghīya": ['cae'],
    "naidāna": ['mw'],
    "naidānaḥ": ['ap90'],
    "naidānikaḥ": ['ap90'],
    "naigama": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "naigamagameya": ['mw'],
    "naigamagamika": ['mw'],
    "naigamakāṇḍa": ['mw'],
    "naigameya": ['mw'],
    "naigameśa": ['bhs'],
    "naigameṣa": ['mw'],
    "naigamika": ['ap90'],
    "naigamābhidhāna": ['mw'],
    "naigeya": ['mw'],
    "naighaṃṭukaṃ": ['ap90'],
    "naighaṇṭuka": ['cae', 'ddsa', 'mw'],
    "naighaṇṭukaikādhyāya": ['mw'],
    "naiguta": ['gra', 'mw'],
    "naihāra": ['mw'],
    "naija": ['ap90', 'mw'],
    "naijameṣa": ['mw'],
    "naika": ['ap90', 'cae', 'ddsa', 'mw'],
    "naikabheda": ['mw'],
    "naikabhāvāśraya": ['mw'],
    "naikacara": ['mw'],
    "naikadharma": ['mw'],
    "naikadhā": ['ap90', 'cae', 'mw'],
    "naikadravyoccayavat": ['mw'],
    "naikaduḥkhada": ['ddsa'],
    "naikadṛś": ['mw'],
    "naikamukha": ['mw'],
    "naikamāya": ['mw'],
    "naikapuṭa": ['mw'],
    "naikapṛṣṭha": ['mw'],
    "naikarūpa": ['cae', 'mw'],
    "naikarṣi": ['mw'],
    "naikata": ['mw'],
    "naikavarṇa": ['cae', 'mw'],
    "naikavidha": ['cae', 'mw'],
    "naikavikalpa": ['cae', 'mw'],
    "naikaśas": ['ap90', 'cae', 'mw'],
    "naikaśastramaya": ['mw'],
    "naikaṣeya": ['mw'],
    "naikaṣeyaḥ": ['ap90'],
    "naikaṣī": ['mw'],
    "naikaṭika": ['ap90', 'ddsa', 'mw'],
    "naikaṭya": ['cae', 'mw'],
    "naikaṭyaṃ": ['ap90'],
    "naikhanya": ['bhs'],
    "naikhānya": ['mw'],
    "naikātman": ['mw'],
    "naikāyika": ['bhs'],
    "naikṛtika": ['ap90', 'cae', 'ddsa', 'mw'],
    "naikṛtin": ['mw'],
    "nailakaṇṭhi": ['mw'],
    "nailakaṇṭhīya": ['mw'],
    "nailya": ['ddsa', 'mw'],
    "nailyaṃ": ['ap90'],
    "nailāyani": ['mw'],
    "nailīnaka": ['mw'],
    "naimagnaka": ['mw'],
    "naimantraṇaka": ['mw'],
    "naimaya": ['mw'],
    "naimayaḥ": ['ap90'],
    "naimaṃtraṇakaṃ": ['ap90'],
    "naimba": ['mw'],
    "naimeya": ['mw'],
    "naimeyaḥ": ['ap90'],
    "naimitta": ['ap90', 'bhs', 'mw'],
    "naimittaka": ['bhs'],
    "naimittika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "naimittikakarman": ['mw'],
    "naimittikakriyā": ['mw'],
    "naimittikaprakaraṇa": ['mw'],
    "naimittikaprayoga": ['mw'],
    "naimittikaprayogaratnākara": ['mw'],
    "naimittikatva": ['mw'],
    "naimittikatā": ['bhs'],
    "naimittikaśrāddha": ['mw'],
    "naimittikī": ['bhs'],
    "naimiśa": ['mw'],
    "naimiśri": ['mw'],
    "naimiśīya": ['mw'],
    "naimiṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "naimiṣakuñja": ['mw'],
    "naimiṣakānana": ['mw'],
    "naimiṣanṛpa": ['mw'],
    "naimiṣeya": ['mw'],
    "naimiṣeyaḥ": ['ap90'],
    "naimiṣi": ['mw'],
    "naimiṣya": ['mw'],
    "naimiṣāraṇya": ['cae', 'mw'],
    "naimiṣāyana": ['mw'],
    "naimiṣīya": ['cae', 'mw'],
    "naināra": ['mw'],
    "nainārācārya": ['mw'],
    "naipa": ['mw'],
    "naipathyasavana": ['mw'],
    "naipuṇa": ['cae', 'ddsa', 'mw'],
    "naipuṇaṃ": ['ap90'],
    "naipuṇya": ['cae', 'ddsa', 'mw'],
    "naipuṇyaṃ": ['ap90'],
    "naipuṇyena": ['mw'],
    "naipya": ['mw'],
    "naipāla": ['ap90', 'mw'],
    "naipālika": ['ap90', 'mw'],
    "naipālikābda": ['mw'],
    "naipālī": ['mw'],
    "naipālīya": ['mw'],
    "naipālīyadevatā": ['mw'],
    "naipālīyadevatākalyāṇapañcaviṃśatikā": ['mw'],
    "naipātika": ['ap90', 'mw'],
    "naipātitha": ['mw'],
    "naipātya": ['mw'],
    "nair": ['mw'],
    "nairantarya": ['cae', 'ddsa', 'mw'],
    "nairantaryeṇa": ['mw'],
    "nairapekṣa": ['mw'],
    "nairapekṣya": ['cae', 'mw'],
    "nairapekṣyaṃ": ['ap90'],
    "nairarthya": ['cae', 'mw'],
    "nairarthyaṃ": ['ap90'],
    "nairayika": ['bhs', 'mw'],
    "nairayikaḥ": ['ap90'],
    "nairañjanavāsinī": ['bhs'],
    "nairañjanā": ['bhs', 'mw'],
    "nairaṃtaryaṃ": ['ap90'],
    "nairbādhya": ['mw'],
    "nairdaśya": ['ap90', 'mw'],
    "nairdeśika": ['mw'],
    "nairdeśikaḥ": ['ap90'],
    "nairdhanya": ['cae', 'ddsa', 'mw'],
    "nairgandhya": ['cae', 'ddsa', 'mw'],
    "nairghṛṇya": ['cae', 'mw'],
    "nairghṛṇyaṃ": ['ap90'],
    "nairgranthya": ['mw'],
    "nairguṇya": ['cae', 'mw'],
    "nairguṇyaṃ": ['ap90'],
    "nairhasta": ['mw'],
    "nairhetuka": ['bhs'],
    "nairjara": ['mw'],
    "nairjhara": ['mw'],
    "nairlajjya": ['cae', 'mw'],
    "nairlajjyaṃ": ['ap90'],
    "nairmalya": ['cae', 'mw'],
    "nairmalyaṃ": ['ap90'],
    "nairmitanairmāṇika": ['bhs'],
    "nairmāṇika": ['bhs', 'mw'],
    "nairnitya": ['bhs'],
    "nairr̥ta": ['ddsa'],
    "nairujya": ['cae', 'ddsa', 'mw'],
    "nairujyaṃ": ['ap90'],
    "nairukta": ['cae', 'mw'],
    "nairuktaḥ": ['ap90'],
    "nairvedhika": ['bhs', 'mw'],
    "nairvedhikaprajña": ['mw'],
    "nairvedhikasarvabhavatalopagata": ['bhs'],
    "nairvāhika": ['ap90', 'mw'],
    "nairvāṇa": ['bhs'],
    "nairvāṇika": ['bhs', 'mw'],
    "nairvāṇikamārgāvataraṇa": ['mw'],
    "nairyāṇika": ['bhs', 'mw'],
    "nairyāṇikatā": ['mw'],
    "nairākāṅkṣya": ['mw'],
    "nairāsya": ['mw'],
    "nairātma": ['bhs', 'mw'],
    "nairātmya": ['bhs', 'mw'],
    "nairātmyayoginī": ['bhs'],
    "nairāśya": ['cae', 'mw'],
    "nairāśyaṃ": ['ap90'],
    "nairūhika": ['mw'],
    "nairṛta": ['bhs', 'cae', 'mw'],
    "nairṛtakanyā": ['mw'],
    "nairṛtarāja": ['mw'],
    "nairṛtaḥ": ['ap90'],
    "nairṛteya": ['mw'],
    "nairṛti": ['mw'],
    "nairṛtya": ['mw'],
    "nairṛtī": ['ap90', 'mw'],
    "nais": ['mw'],
    "naisarga": ['cae', 'ddsa', 'mw'],
    "naisargika": ['ap90', 'bhs', 'cae', 'mw'],
    "naisargikadaśaka": ['mw'],
    "naisarpa": ['mw'],
    "naisnehya": ['mw'],
    "naistriṃśika": ['ddsa', 'mw'],
    "naistriṃśikaḥ": ['ap90'],
    "naistārika": ['bhs'],
    "naisvya": ['mw'],
    "naitala": ['ddsa', 'mw'],
    "naitalasadman": ['mw'],
    "naitalaṃ": ['ap90'],
    "naitandhava": ['mw'],
    "naitarī": ['bhs'],
    "naitośa": ['gra', 'mw'],
    "naituṇḍi": ['mw'],
    "naitya": ['mw'],
    "naityaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "naityaśabdika": ['mw'],
    "naityaṃ": ['ap90'],
    "naityika": ['cae', 'mw'],
    "naiva": ['mw'],
    "naivajīva": ['bhs'],
    "naivaki": ['mw'],
    "naivakiṃcanya": ['bhs'],
    "naivasaṃjñinaivāsaṃjñin": ['mw'],
    "naivasaṃjñānāsaṃjñānāyatana": ['mw'],
    "naivasaṃjñānāsaṃjñānāyatanopaga": ['mw'],
    "naivasaṃjñānāsaṃjñāyatana": ['bhs'],
    "naivasaṃjñānāsaṃjñāyatanopaga": ['bhs'],
    "naivasaṃjñāsamādhi": ['mw'],
    "naivati": ['mw'],
    "naivaśaikṣanāśaikṣa": ['bhs'],
    "naivaśāśvatonāśāśvataśca": ['mw'],
    "naivedya": ['cae', 'mw'],
    "naivedyaprakaraṇa": ['mw'],
    "naivedyaprasādamāhātmya": ['mw'],
    "naivedyavidhi": ['mw'],
    "naivedyaṃ": ['ap90'],
    "naiveśa": ['mw'],
    "naiveśika": ['cae', 'ddsa', 'mw'],
    "naiveśikaṃ": ['ap90'],
    "naivida": ['mw'],
    "naiviḍyaṃ": ['ap90'],
    "naivya": ['mw'],
    "naivābhigamana": ['ddsa'],
    "naivākava": ['mw'],
    "naivākavi": ['mw'],
    "naivākavīya": ['mw'],
    "naivākāśānantya": ['bhs'],
    "naivāla": ['bhs'],
    "naivāntavānnānantavāṃśca": ['mw'],
    "naivāra": ['cae', 'ddsa', 'mw'],
    "naivāsika": ['bhs', 'mw'],
    "naivāsikā": ['mw'],
    "naivātāyana": ['mw'],
    "naiyagrodha": ['cae', 'ddsa', 'mw'],
    "naiyagrodhaṃ": ['ap90'],
    "naiyamika": ['ap90', 'cae', 'mw'],
    "naiyatya": ['ddsa', 'mw'],
    "naiyatyaṃ": ['ap90'],
    "naiyaṅkava": ['mw'],
    "naiyyagrodha": ['mw'],
    "naiyyamika": ['mw'],
    "naiyyāyika": ['mw'],
    "naiyāsika": ['mw'],
    "naiyāya": ['mw'],
    "naiyāyika": ['cae', 'ddsa', 'mw'],
    "naiyāyikaḥ": ['ap90'],
    "naiś": ['mw'],
    "naiśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "naiścalya": ['mw'],
    "naiścalyaṃ": ['ap90'],
    "naiścintya": ['cae', 'ddsa', 'mw'],
    "naiścitya": ['mw'],
    "naiścityaṃ": ['ap90'],
    "naiśika": ['cae', 'ddsa', 'mw'],
    "naiśitya": ['ddsa', 'mw'],
    "naiśreyasa": ['mw'],
    "naiśvāsa": ['mw'],
    "naiśākara": ['ddsa', 'mw'],
    "naiḥ": ['mw'],
    "naiḥsargika": ['bhs', 'mw'],
    "naiḥsaṅgya": ['mw'],
    "naiḥsnehya": ['cae', 'ddsa', 'mw'],
    "naiḥspṛhya": ['mw'],
    "naiḥsvabhāvya": ['bhs', 'mw'],
    "naiḥsvaṃ": ['ap90'],
    "naiḥsvya": ['cae', 'mw'],
    "naiḥśreyasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "naiṣ": ['mw'],
    "naiṣa": ['mw'],
    "naiṣadha": ['cae', 'ddsa', 'mw'],
    "naiṣadhacarita": ['mw'],
    "naiṣadhaka": ['mw'],
    "naiṣadhakāvya": ['mw'],
    "naiṣadhaprakāśa": ['mw'],
    "naiṣadhaḥ": ['ap90'],
    "naiṣadhya": ['mw'],
    "naiṣadhānandanāṭaka": ['mw'],
    "naiṣadhīya": ['ap90', 'cae', 'mw'],
    "naiṣadhīyacarita": ['cae', 'mw'],
    "naiṣadhīyaprakāśa": ['mw'],
    "naiṣadika": ['bhs'],
    "naiṣadyika": ['bhs', 'mw'],
    "naiṣedhikī": ['mw'],
    "naiṣidha": ['mw'],
    "naiṣka": ['mw'],
    "naiṣkarmya": ['cae', 'ddsa', 'mw'],
    "naiṣkarmyasiddhi": ['mw'],
    "naiṣkarmyaṃ": ['ap90'],
    "naiṣkasahasrika": ['mw'],
    "naiṣkaśatika": ['ap90', 'mw'],
    "naiṣkika": ['ap90', 'mw'],
    "naiṣkiñcanya": ['ddsa'],
    "naiṣkiṃcanya": ['cae', 'mw'],
    "naiṣkiṃcanyaṃ": ['ap90'],
    "naiṣkramaṇa": ['mw'],
    "naiṣkramaṇaṃ": ['ap90'],
    "naiṣkramya": ['bhs', 'mw'],
    "naiṣkramyin": ['bhs'],
    "naiṣkāmya": ['mw'],
    "naiṣkṛtika": ['cae', 'ddsa', 'mw'],
    "naiṣpeṣika": ['mw'],
    "naiṣpeṣikatva": ['bhs', 'mw'],
    "naiṣpeṣikatā": ['bhs'],
    "naiṣphalya": ['cae', 'ddsa', 'mw'],
    "naiṣpremya": ['mw'],
    "naiṣpuruṣya": ['mw'],
    "naiṣpurīṣya": ['mw'],
    "naiṣyandika": ['bhs'],
    "naiṣāda": ['bhs', 'cae', 'ddsa', 'mw'],
    "naiṣādaka": ['mw'],
    "naiṣādakarṣuka": ['mw'],
    "naiṣādaki": ['mw'],
    "naiṣādi": ['mw'],
    "naiṣādāyana": ['mw'],
    "naiṣṇihya": ['mw'],
    "naiṣṭhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "naiṣṭhikasundara": ['mw'],
    "naiṣṭhurya": ['cae', 'ddsa', 'mw'],
    "naiṣṭhuryaṃ": ['ap90'],
    "naiṣṭhya": ['mw'],
    "naiṣṭhyaṃ": ['ap90'],
    "naj": ['ap90', 'mw'],
    "nak": ['cae', 'ddsa', 'mw'],
    "naka": ['mw'],
    "nakh": ['ap90', 'mw'],
    "nakha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nakhabhinna": ['mw'],
    "nakhaccedana": ['cped'],
    "nakhaccheda": ['mw'],
    "nakhacchedana": ['cae', 'mw'],
    "nakhacchedya": ['mw'],
    "nakhadāraṇa": ['mw'],
    "nakhagucchaphalā": ['mw'],
    "nakhajāha": ['mw'],
    "nakhaka": ['bhs', 'mw'],
    "nakhakhādin": ['cae', 'mw'],
    "nakhakuṭṭa": ['mw'],
    "nakhalekhaka": ['mw'],
    "nakhalekhā": ['mw'],
    "nakhampaca": ['mw'],
    "nakhamuca": ['mw'],
    "nakhanikṛntana": ['mw'],
    "nakhanirbhinna": ['mw'],
    "nakhaniṣpāvikā": ['mw'],
    "nakhaniṣpāvī": ['mw'],
    "nakhanyāsa": ['mw'],
    "nakhapada": ['cae', 'mw'],
    "nakhaparṇī": ['mw'],
    "nakhaphalinī": ['mw'],
    "nakhapiṭṭhikā": ['cped'],
    "nakhapraca": ['mw'],
    "nakhapuñjaphalā": ['mw'],
    "nakhapuṣpī": ['mw'],
    "nakhapūrvikā": ['mw'],
    "nakhara": ['cae', 'ddsa', 'mw'],
    "nakharajanī": ['mw'],
    "nakhararajanī": ['mw'],
    "nakharañjanī": ['mw'],
    "nakharaḥ": ['ap90'],
    "nakharikā": ['bhs'],
    "nakharāhva": ['mw'],
    "nakharāyudha": ['mw'],
    "nakharī": ['bhs', 'mw'],
    "nakhasikhā": ['cped'],
    "nakhasā": ['cped'],
    "nakhavilekhā": ['mw'],
    "nakhaviṣa": ['mw'],
    "nakhaviṣkira": ['cae', 'mw'],
    "nakhavraṇa": ['mw'],
    "nakhavādana": ['mw'],
    "nakhavādya": ['mw'],
    "nakhavṛkṣa": ['mw'],
    "nakhaśaṅkha": ['mw'],
    "nakhaḥ": ['ap90'],
    "nakhaṃpaca": ['ap90'],
    "nakhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "nakhācchoṭanikā": ['mw'],
    "nakhāghāta": ['cae', 'mw'],
    "nakhāgra": ['cae', 'ddsa', 'mw'],
    "nakhāli": ['mw'],
    "nakhālikā": ['mw'],
    "nakhālu": ['mw'],
    "nakhānakhi": ['ap90', 'cae', 'ddsa', 'mw'],
    "nakhāri": ['mw'],
    "nakhārtha": ['mw'],
    "nakhāvapūta": ['mw'],
    "nakhāyudha": ['cae', 'ddsa', 'mw'],
    "nakhāyudhatva": ['mw'],
    "nakhāśin": ['mw'],
    "nakhāṃśu": ['mw'],
    "nakhāṅga": ['mw'],
    "nakhāṅka": ['cae', 'mw'],
    "nakim": ['mw'],
    "nakis": ['cae', 'ddsa', 'gra', 'mw'],
    "nakiñcana": ['ddsa'],
    "nakiñcid": ['ddsa'],
    "nakiṃcana": ['cae', 'mw'],
    "nakiṃcid": ['cae', 'mw'],
    "nakiṃcidapisaṃkalpa": ['mw'],
    "nakk": ['ap90', 'mw'],
    "nakka": ['cped'],
    "nakkhatta": ['cped'],
    "nakkhattaggāha": ['cped'],
    "nakkhattamāli(n)": ['cped'],
    "nakkhattapada": ['cped'],
    "nakla": ['mw'],
    "nakra": ['cae', 'ddsa', 'mw'],
    "nakracakra": ['mw'],
    "nakrahāraka": ['mw'],
    "nakraketana": ['mw'],
    "nakramakṣikā": ['mw'],
    "nakrarāj": ['mw'],
    "nakrarājaka": ['mw'],
    "nakraḥ": ['ap90'],
    "nakrā": ['mw'],
    "nakta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "naktabhojana": ['mw'],
    "naktabhojin": ['ddsa', 'mw'],
    "naktabhojitva": ['mw'],
    "naktacārin": ['mw'],
    "naktaka": ['cae', 'mw'],
    "naktakaḥ": ['ap90'],
    "naktakālanirṇaya": ['mw'],
    "naktam": ['mw'],
    "naktambhogin": ['mw'],
    "naktambhāga": ['mw'],
    "naktamprabhava": ['mw'],
    "naktamukhā": ['mw'],
    "naktamāla": ['mw'],
    "naktamālaka": ['mw'],
    "naktan": ['ap90', 'cae', 'gra', 'mw'],
    "naktaprabhava": ['mw'],
    "naktavat": ['mw'],
    "naktavrata": ['mw'],
    "naktayā": ['cae', 'ddsa', 'gra', 'mw'],
    "naktañcara": ['ddsa'],
    "naktaṃ": ['ap90', 'mw'],
    "naktaṃcara": ['cae', 'mw'],
    "naktaṃcareśvara": ['mw'],
    "naktaṃcaryā": ['mw'],
    "naktaṃcarī": ['mw'],
    "naktaṃcārin": ['mw'],
    "naktaṃdina": ['cae', 'mw'],
    "naktaṃdinam": ['mw'],
    "naktaṃdivam": ['mw'],
    "naktaṃhoma": ['mw'],
    "naktaṃjāta": ['mw'],
    "naktaṃsamaya": ['mw'],
    "nakti": ['cae', 'ddsa', 'gra', 'mw'],
    "naktoṣas": ['cae', 'ddsa', 'gra'],
    "naktoṣāsā": ['mw'],
    "naktā": ['mw'],
    "naktāndha": ['mw'],
    "naktāndhya": ['mw'],
    "naktāśin": ['mw'],
    "nakuca": ['mw'],
    "nakula": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "nakulaka": ['bhs', 'mw'],
    "nakulatva": ['mw'],
    "nakulaḥ": ['ap90'],
    "nakuleśa": ['mw'],
    "nakuleṣṭakā": ['mw'],
    "nakuleṣṭā": ['mw'],
    "nakulikā": ['mw'],
    "nakuloṣṭhī": ['mw'],
    "nakulā": ['mw'],
    "nakulādyā": ['mw'],
    "nakulāndhatā": ['mw'],
    "nakulāndhya": ['mw'],
    "nakulī": ['mw'],
    "nakulīvāgīśvarīmantravidhāna": ['mw'],
    "nakulīśa": ['mw'],
    "nakulīśadarśana": ['mw'],
    "nakulīśapāśupata": ['mw'],
    "nakulīśayogapārāyaṇa": ['mw'],
    "nakutaścid": ['mw'],
    "nakutaścidbhaya": ['ddsa', 'mw'],
    "nakuṭa": ['mw'],
    "nakuṭaṃ": ['ap90'],
    "nakāra": ['cae', 'ddsa', 'mw'],
    "nakāravipulā": ['mw'],
    "nakīm": ['cae', 'ddsa', 'gra', 'mw'],
    "nakṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nakṣaddābha": ['cae', 'gra', 'mw'],
    "nakṣat": ['mw'],
    "nakṣatra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "nakṣatrabhakti": ['mw'],
    "nakṣatrabhuktaghaṭīcakra": ['mw'],
    "nakṣatracakra": ['mw'],
    "nakṣatracintāmaṇi": ['mw'],
    "nakṣatracūḍāmaṇi": ['mw'],
    "nakṣatradarśa": ['cae', 'mw'],
    "nakṣatradevata": ['mw'],
    "nakṣatradevatākathana": ['mw'],
    "nakṣatradohadaśāntika": ['mw'],
    "nakṣatradvaṃdva": ['mw'],
    "nakṣatradānavidhi": ['mw'],
    "nakṣatragrahayutyadhikāra": ['mw'],
    "nakṣatragrahotpāta": ['mw'],
    "nakṣatragrāmayājaka": ['mw'],
    "nakṣatragupta": ['bhs'],
    "nakṣatrajā": ['mw'],
    "nakṣatrajātaka": ['mw'],
    "nakṣatrajātakādibhāvaphala": ['mw'],
    "nakṣatrakalpa": ['mw'],
    "nakṣatrakośa": ['mw'],
    "nakṣatrakāntivistāra": ['mw'],
    "nakṣatrakūrma": ['mw'],
    "nakṣatrakūrmacāra": ['mw'],
    "nakṣatrakūrmavibhāga": ['mw'],
    "nakṣatraloka": ['cae', 'mw'],
    "nakṣatramaṇḍala": ['mw'],
    "nakṣatramālikā": ['mw'],
    "nakṣatramālā": ['cae', 'mw'],
    "nakṣatramālāya": ['ddsa', 'mw'],
    "nakṣatramārga": ['mw'],
    "nakṣatranemi": ['mw'],
    "nakṣatranighaṇṭu": ['mw'],
    "nakṣatranirdeśa": ['mw'],
    "nakṣatranirṇaya": ['mw'],
    "nakṣatranyāsa": ['mw'],
    "nakṣatranāma": ['mw'],
    "nakṣatranāman": ['mw'],
    "nakṣatranātha": ['cae', 'mw'],
    "nakṣatrapa": ['mw'],
    "nakṣatrapatha": ['mw'],
    "nakṣatrapathavarcas": ['mw'],
    "nakṣatrapati": ['mw'],
    "nakṣatrapatinandana": ['mw'],
    "nakṣatrapaṭalopāyadāna": ['mw'],
    "nakṣatraphala": ['mw'],
    "nakṣatraprakaraṇa": ['mw'],
    "nakṣatrapraśna": ['mw'],
    "nakṣatrapuruṣa": ['mw'],
    "nakṣatrapuruṣavrata": ['mw'],
    "nakṣatrapāta": ['mw'],
    "nakṣatrapāṭhaka": ['mw'],
    "nakṣatrapūjita": ['mw'],
    "nakṣatrarāja": ['bhs', 'cae', 'mw'],
    "nakṣatrarājaprabhāvabhāsagarbha": ['bhs', 'mw'],
    "nakṣatrarājasaṃkusumitābhijña": ['bhs', 'mw'],
    "nakṣatrarājavikrīḍita": ['bhs', 'mw'],
    "nakṣatrarājāditya": ['bhs'],
    "nakṣatrasamuccaya": ['mw'],
    "nakṣatrasattra": ['mw'],
    "nakṣatrasattrahautra": ['mw'],
    "nakṣatrasattraprayoga": ['mw'],
    "nakṣatrasattreṣṭihautraprayoga": ['mw'],
    "nakṣatrasattreṣṭiprayoga": ['mw'],
    "nakṣatrasaṃvatsara": ['mw'],
    "nakṣatrasthāpana": ['mw'],
    "nakṣatrastoma": ['mw'],
    "nakṣatrasūcaka": ['mw'],
    "nakṣatratārārājāditya": ['mw'],
    "nakṣatravartman": ['mw'],
    "nakṣatravidhāna": ['mw'],
    "nakṣatravidyā": ['cae', 'ddsa', 'mw'],
    "nakṣatravyūha": ['mw'],
    "nakṣatravādamālikā": ['mw'],
    "nakṣatravādāvali": ['mw'],
    "nakṣatravādāvalī": ['mw'],
    "nakṣatravīthī": ['mw'],
    "nakṣatravṛkṣa": ['mw'],
    "nakṣatravṛṣṭi": ['mw'],
    "nakṣatrayajña": ['mw'],
    "nakṣatrayoga": ['mw'],
    "nakṣatrayogadāna": ['mw'],
    "nakṣatrayogin": ['mw'],
    "nakṣatrayoginī": ['mw'],
    "nakṣatrayājaka": ['mw'],
    "nakṣatraśavas": ['ddsa', 'gra', 'mw'],
    "nakṣatraśuddhiprakaraṇa": ['mw'],
    "nakṣatraśānti": ['mw'],
    "nakṣatraṃ": ['ap90'],
    "nakṣatreśa": ['cae', 'mw'],
    "nakṣatreṣṭakā": ['mw'],
    "nakṣatreṣṭi": ['mw'],
    "nakṣatreṣṭihautra": ['mw'],
    "nakṣatreṣṭihoma": ['mw'],
    "nakṣatreṣṭinirūpaṇa": ['mw'],
    "nakṣatreṣṭipaddhati": ['mw'],
    "nakṣatreṣṭiprayoga": ['mw'],
    "nakṣatrin": ['ap90', 'mw'],
    "nakṣatriya": ['ap90', 'cae', 'mw'],
    "nakṣatropajīvin": ['mw'],
    "nakṣatrābhidhāna": ['mw'],
    "nakṣatrādhipa": ['mw'],
    "nakṣatrādhipati": ['mw'],
    "nakṣatrāśraya": ['mw'],
    "nakṣya": ['cae', 'mw'],
    "nal": ['ap90', 'mw'],
    "nala": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "nalabhūmipālanāṭaka": ['mw'],
    "nalacampū": ['mw'],
    "nalacarita": ['mw'],
    "nalacaritra": ['mw'],
    "nalada": ['cae', 'ddsa', 'mw'],
    "naladatva": ['mw'],
    "naladika": ['mw'],
    "naladā": ['mw'],
    "naladī": ['mw'],
    "nalaghātyā": ['bhs'],
    "nalagiri": ['cae', 'ddsa', 'mw'],
    "nalaka": ['cae', 'mw'],
    "nalakalāpī": ['cped'],
    "nalakaṃ": ['ap90'],
    "nalakinī": ['ap90', 'mw'],
    "nalakānana": ['mw'],
    "nalakīla": ['mw'],
    "nalakūbara": ['cae', 'mw'],
    "nalakūbarasaṃhitā": ['mw'],
    "nalakūvara": ['bhs'],
    "nalamālin": ['bhs', 'mw'],
    "nalamīna": ['mw'],
    "nalanāman": ['ddsa'],
    "nalapaṭṭikā": ['mw'],
    "nalapriyā": ['mw'],
    "nalapura": ['mw'],
    "nalapākaśāstra": ['mw'],
    "nalasena": ['mw'],
    "nalasetu": ['mw'],
    "nalastotra": ['mw'],
    "nalavarṇana": ['mw'],
    "nalayādavarāghavapāṇḍavīya": ['mw'],
    "nalaḥ": ['ap90'],
    "naledhma": ['mw'],
    "naleśvaratīrtha": ['mw'],
    "nalikā": ['ddsa', 'mw'],
    "nalikābandhapaddhati": ['mw'],
    "nalina": ['cae', 'ddsa', 'mw'],
    "nalinadala": ['cae', 'mw'],
    "nalinanābha": ['mw'],
    "nalinaḥ": ['ap90'],
    "nalineśaya": ['mw'],
    "nalineśayī": ['mw'],
    "nalini": ['mw'],
    "nalinidala": ['cae', 'mw'],
    "nalināsana": ['mw'],
    "nalinī": ['ap90', 'bhs', 'ddsa', 'mw'],
    "nalinīdala": ['cae', 'mw'],
    "nalinīdalamaya": ['mw'],
    "nalinīgulma": ['mw'],
    "nalinīka": ['mw'],
    "nalinīkhaṇḍa": ['mw'],
    "nalinīkā": ['mw'],
    "nalinīnandana": ['mw'],
    "nalinīpadmakośa": ['mw'],
    "nalinīpattra": ['cae', 'mw'],
    "nalinīruha": ['mw'],
    "nalinīsaṃvartikā": ['mw'],
    "naliptāṅga": ['mw'],
    "nalita": ['mw'],
    "nalla": ['mw'],
    "nallābudha": ['mw'],
    "nallādīkṣita": ['mw'],
    "nallāpaṇḍita": ['mw'],
    "nalodaya": ['cae', 'ddsa', 'mw'],
    "nalopākhyāna": ['cae', 'mw'],
    "nalottama": ['mw'],
    "nalva": ['cae', 'ddsa', 'mw'],
    "nalvavartmaga": ['mw'],
    "nalvavartmagā": ['mw'],
    "nalvaḥ": ['ap90'],
    "nalvaṇa": ['mw'],
    "nalvaṇgonnalakāmābhaṭṭa": ['mw'],
    "nalānanda": ['mw'],
    "nalāta": ['cped'],
    "nalāṭa": ['cped'],
    "nalāṭika": ['cped'],
    "nalī": ['mw'],
    "nalīya": ['mw'],
    "nal̤a": ['cae', 'mw'],
    "nam": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "nama": ['cae', 'gra', 'mw'],
    "nama(s)": ['cped'],
    "namaiya": ['mw'],
    "namaka": ['mw'],
    "namakabhāṣya": ['mw'],
    "namakacamakabhāṣya": ['mw'],
    "namana": ['cae', 'ddsa', 'mw'],
    "namanaṃ": ['ap90'],
    "namantra": ['bhs'],
    "namanīya": ['mw'],
    "namanīyapāda": ['mw'],
    "namas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "namasa": ['ap90', 'mw'],
    "namasia": ['gra'],
    "namasita": ['ap90', 'mw'],
    "namaskara": ['bhs'],
    "namaskartṛ": ['mw'],
    "namaskriyā": ['cae', 'mw'],
    "namaskāra": ['cae', 'ddsa', 'mw'],
    "namaskārastava": ['mw'],
    "namaskāravat": ['mw'],
    "namaskāravidhi": ['mw'],
    "namaskārya": ['cae', 'mw'],
    "namaskārī": ['mw'],
    "namaskṛti": ['cae', 'mw'],
    "namassa(t)": ['cped'],
    "namassamāna": ['cped'],
    "namassanta": ['cped'],
    "namassati": ['cped'],
    "namassi(ṁ)": ['cped'],
    "namassitabba": ['cped'],
    "namassitvā": ['cped'],
    "namasvant": ['cae'],
    "namasvat": ['ddsa', 'gra', 'mw'],
    "namasvin": ['cae', 'ddsa', 'gra', 'mw'],
    "namasy": ['cae', 'gra'],
    "namasya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "namasyati": ['ap90'],
    "namasyita": ['mw'],
    "namasyu": ['ap90', 'cae', 'gra', 'mw'],
    "namasyā": ['cae', 'gra', 'mw'],
    "namasāna": ['cae', 'mw'],
    "namat": ['mw'],
    "namata": ['ap90', 'bhs', 'mw'],
    "namataka": ['cped'],
    "namati": ['bhs', 'cped'],
    "namatra": ['mw'],
    "namaukti": ['cae', 'gra', 'mw'],
    "namayat": ['mw'],
    "namayati": ['cped'],
    "namayitavya": ['mw'],
    "namayiṣṇu": ['cae', 'gra', 'mw'],
    "namb": ['mw'],
    "nambikārikā": ['mw'],
    "nameru": ['ddsa', 'mw'],
    "nameruḥ": ['ap90'],
    "nametabba": ['cped'],
    "nameti": ['cped'],
    "nami": ['cped', 'mw'],
    "namita": ['ap90', 'mw'],
    "nammaiya": ['mw'],
    "namo": ['cped', 'mw'],
    "namoguru": ['mw'],
    "namovāka": ['gra', 'mw'],
    "namovṛdh": ['cae', 'gra', 'mw'],
    "namovṛdha": ['cae', 'gra', 'mw'],
    "namovṛkti": ['gra', 'mw'],
    "namovṛktivat": ['mw'],
    "namra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "namraka": ['ap90', 'mw'],
    "namramukha": ['mw'],
    "namramūrti": ['mw'],
    "namranāsika": ['mw'],
    "namraprakṛti": ['mw'],
    "namratva": ['mw'],
    "namratā": ['ap90', 'mw'],
    "namravaktra": ['cae'],
    "namrita": ['ap90', 'mw'],
    "namrā": ['mw'],
    "namrāṅga": ['mw'],
    "namrīkṛ": ['cae', 'mw'],
    "namuca": ['mw'],
    "namuci": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "namucidviṣ": ['mw'],
    "namucighna": ['mw'],
    "namucihan": ['cae', 'mw'],
    "namucisūdana": ['mw'],
    "namucisūdanasārathi": ['mw'],
    "namuciḥ": ['ap90'],
    "namucī": ['cped'],
    "namura": ['mw'],
    "namya": ['ap90', 'mw'],
    "namyā": ['mw'],
    "namāka": ['mw'],
    "namātra": ['bhs', 'mw'],
    "namī": ['gra', 'mw'],
    "namṛta": ['mw'],
    "nanandṛ": ['mw'],
    "nanaṃdṛ": ['ap90'],
    "nand": ['cae', 'ddsa', 'gra', 'mw'],
    "nanda": ['bhs', 'cae', 'ddsa', 'mw'],
    "nandabalā": ['bhs', 'mw'],
    "nandadatta": ['bhs'],
    "nandadeva": ['mw'],
    "nandadāsa": ['mw'],
    "nandagopa": ['mw'],
    "nandagopakula": ['mw'],
    "nandagopakulodbhavā": ['mw'],
    "nandagopakumāra": ['mw'],
    "nandagopitā": ['mw'],
    "nandaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "nandaki": ['mw'],
    "nandakin": ['mw'],
    "nandakiśora": ['mw'],
    "nandakumāra": ['mw'],
    "nandalāla": ['mw'],
    "nandamitra": ['mw'],
    "nandamāna": ['cped'],
    "nandana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "nandanadruma": ['mw'],
    "nandanaja": ['mw'],
    "nandanakānana": ['mw'],
    "nandanamālā": ['mw'],
    "nandanandana": ['cae', 'mw'],
    "nandanandanī": ['mw'],
    "nandanavana": ['cae', 'mw'],
    "nandanodbhava": ['mw'],
    "nandanta": ['mw'],
    "nandantī": ['mw'],
    "nandanā": ['mw'],
    "nandanātha": ['mw'],
    "nandapadra": ['mw'],
    "nandaparvata": ['ddsa', 'mw'],
    "nandapaṇḍita": ['mw'],
    "nandaprabhañjanavarman": ['mw'],
    "nandaprayāga": ['mw'],
    "nandaputra": ['mw'],
    "nandaputrotsava": ['mw'],
    "nandaputrī": ['mw'],
    "nandapāla": ['mw'],
    "nandarāma": ['mw'],
    "nandasundara": ['mw'],
    "nandasuta": ['mw'],
    "nandasāra": ['mw'],
    "nandasūnu": ['cae', 'mw'],
    "nandathu": ['mw'],
    "nandati": ['cped'],
    "nandavardhana": ['mw'],
    "nandayanta": ['mw'],
    "nandayantī": ['ddsa', 'mw'],
    "nandayat": ['mw'],
    "nandayitnu": ['mw'],
    "nandayitṛ": ['mw'],
    "nandaśarman": ['mw'],
    "nandaśrī": ['bhs'],
    "nanderī": ['mw'],
    "nandhi": ['cped'],
    "nandi": ['cae', 'cped', 'ddsa', 'mw'],
    "nandi(n)": ['cped'],
    "nandibharata": ['mw'],
    "nandideva": ['cae', 'mw'],
    "nandidevī": ['mw'],
    "nandidharma": ['mw'],
    "nandidhvaja": ['bhs'],
    "nandighoṣa": ['bhs', 'cae', 'mw'],
    "nandighoṣavijaya": ['mw'],
    "nandigiri": ['mw'],
    "nandigirimāhātmya": ['mw'],
    "nandigrāma": ['cae', 'mw'],
    "nandigrāmadarśana": ['mw'],
    "nandigupta": ['bhs', 'mw'],
    "nandihāra": ['bhs'],
    "nandija": ['mw'],
    "nandijanana": ['bhs'],
    "nandika": ['bhs', 'mw'],
    "nandikara": ['cae', 'mw'],
    "nandikasūtra": ['bhs'],
    "nandikeśa": ['mw'],
    "nandikeśaliṅga": ['mw'],
    "nandikeśvara": ['mw'],
    "nandikeśvarakārikā": ['mw'],
    "nandikeśvarakāśikā": ['mw'],
    "nandikeśvarapurāṇa": ['mw'],
    "nandikeśvarasaṃhitā": ['mw'],
    "nandikeśvaratārāvalī": ['mw'],
    "nandikeśvaratīrtha": ['mw'],
    "nandikeśvarotpatti": ['mw'],
    "nandikeśvarābhiṣeka": ['mw'],
    "nandikuṇḍa": ['mw'],
    "nandikā": ['mw'],
    "nandikācāryatantra": ['mw'],
    "nandikāvarta": ['bhs', 'mw'],
    "nandikṣetra": ['mw'],
    "nandimukha": ['ddsa', 'mw'],
    "nandimukhasughoṣa": ['mw'],
    "nandimukhasughoṣāvadāna": ['mw'],
    "nandimukhī": ['cped'],
    "nandimukhīratti": ['cped'],
    "nandin": ['bhs', 'cae', 'ddsa', 'mw'],
    "nandinagara": ['bhs'],
    "nandināgaraka": ['mw'],
    "nandināgarī": ['mw'],
    "nandinī": ['bhs', 'ddsa', 'mw'],
    "nandinīputra": ['mw'],
    "nandinīsuta": ['mw'],
    "nandinītanaya": ['mw'],
    "nandinītīrtha": ['mw'],
    "nandipadacchandas": ['mw'],
    "nandipuramāhātmya": ['mw'],
    "nandipurāṇa": ['mw'],
    "nandirakṣitā": ['bhs'],
    "nandirudra": ['mw'],
    "nandisena": ['mw'],
    "nandisenā": ['bhs'],
    "nandissaṁ": ['cped'],
    "nandisvāmin": ['mw'],
    "nanditaru": ['mw'],
    "nanditūrya": ['mw'],
    "nandivardha": ['mw'],
    "nandivardhana": ['bhs', 'cae', 'mw'],
    "nandivardhanī": ['bhs'],
    "nandivarman": ['mw'],
    "nandivega": ['mw'],
    "nandivivardhana": ['mw'],
    "nandivāralaka": ['mw'],
    "nandivṛkṣa": ['mw'],
    "nandivṛkṣaka": ['mw'],
    "nandiyaśas": ['mw'],
    "nandiśikhā": ['mw'],
    "nandiṁjaha": ['cped'],
    "nandiṣeṇa": ['mw'],
    "nandiṣeṇeśvara": ['mw'],
    "nandopananda": ['bhs', 'mw'],
    "nandopanandasaṃjñā": ['mw'],
    "nandopākhyāna": ['mw'],
    "nandottarā": ['bhs'],
    "nandyupapurāṇa": ['mw'],
    "nandyupākhyāna": ['mw'],
    "nandyāvarta": ['mw'],
    "nandā": ['bhs', 'ddsa', 'mw'],
    "nandāhradatīrtha": ['mw'],
    "nandāprācīmāhātmya": ['mw'],
    "nandāpurāṇa": ['mw'],
    "nandātmaja": ['cae', 'ddsa', 'mw'],
    "nandātmajā": ['mw'],
    "nandātīrtha": ['mw'],
    "nandāśrama": ['mw'],
    "nandī": ['bhs', 'cped', 'mw'],
    "nandīcarita": ['mw'],
    "nandīdhvaja": ['bhs'],
    "nandīghoṣa": ['bhs'],
    "nandīka": ['mw'],
    "nandīmukha": ['cae', 'mw'],
    "nandīmukhā": ['bhs'],
    "nandīmukhī": ['mw'],
    "nandīpati": ['mw'],
    "nandīpura": ['mw'],
    "nandīpurāṇa": ['mw'],
    "nandīpāla": ['bhs'],
    "nandīrāga": ['bhs'],
    "nandīsaras": ['mw'],
    "nandīvṛkṣa": ['mw'],
    "nandīśa": ['cae', 'ddsa', 'mw'],
    "nandīśvara": ['cae', 'mw'],
    "nandīśvaramāhātmya": ['mw'],
    "nandīśvarapurāṇa": ['mw'],
    "nandīśvarotpatti": ['mw'],
    "nandīṭa": ['mw'],
    "nandūpasecana": ['cped'],
    "nannama": ['mw'],
    "nannamyamāna": ['mw'],
    "nannayabhaṭṭa": ['mw'],
    "nantaka": ['cped'],
    "nantakavāsi(n)": ['cped'],
    "nantavya": ['mw'],
    "nantua": ['gra'],
    "nantva": ['cae', 'gra', 'mw'],
    "nantṛ": ['cae', 'mw'],
    "nanu": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nanā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nanānduḥpati": ['mw'],
    "nanāndṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "nanāndṛpati": ['mw'],
    "napara": ['mw'],
    "naparājit": ['ap90', 'mw'],
    "napta": ['bhs'],
    "napti": ['cae'],
    "naptrī": ['ddsa', 'mw'],
    "naptī": ['cae', 'ddsa', 'gra'],
    "naptṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "naptṛkā": ['mw'],
    "napuṃs": ['ap90', 'mw'],
    "napuṃsa": ['cae', 'mw'],
    "napuṃsaka": ['cae', 'ddsa', 'mw'],
    "napuṃsakaliṅga": ['mw'],
    "napuṃsakaliṅgasaṃgraha": ['mw'],
    "napuṃsakapāda": ['mw'],
    "napuṃsakaḥ": ['ap90'],
    "napāt": ['ap90', 'cae', 'ddsa', 'mw'],
    "napātka": ['mw'],
    "napātī": ['mw'],
    "nar": ['gra'],
    "nara": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "narabali": ['cae', 'mw'],
    "narabhuj": ['mw'],
    "narabhū": ['mw'],
    "narabhūmi": ['mw'],
    "narabrahmadeva": ['mw'],
    "naracandra": ['mw'],
    "naracihna": ['mw'],
    "narada": ['bhs', 'mw'],
    "naradamyasārathi": ['bhs'],
    "naradanta": ['cae', 'mw'],
    "naradatta": ['bhs', 'mw'],
    "naradattā": ['mw'],
    "naradeva": ['bhs', 'cae', 'mw'],
    "naradevadeva": ['mw'],
    "naradevaputra": ['mw'],
    "naradevatva": ['mw'],
    "naradika": ['mw'],
    "naradurācara": ['mw'],
    "naradviṣ": ['mw'],
    "naragaṇapativijaya": ['mw'],
    "naragrāha": ['mw'],
    "narahari": ['cae', 'mw'],
    "naraharideva": ['mw'],
    "narahaya": ['mw'],
    "narajaṅgala": ['mw'],
    "narajāṅgala": ['cae'],
    "naraka": ['cae', 'cped', 'ddsa', 'mw'],
    "narakabhūmi": ['mw'],
    "narakadevatā": ['mw'],
    "narakajit": ['cae', 'mw'],
    "narakakumbha": ['bhs'],
    "narakakuṇḍa": ['mw'],
    "narakapāla": ['ddsa', 'mw'],
    "narakapāta": ['mw'],
    "narakaripu": ['cae', 'ddsa', 'mw'],
    "narakarūpin": ['mw'],
    "narakastha": ['cae', 'mw'],
    "narakasthā": ['mw'],
    "narakasvargaprāptiprakāravarṇana": ['mw'],
    "narakatiryaksaṃśodhana": ['mw'],
    "narakaukas": ['mw'],
    "narakavarga": ['mw'],
    "narakavarṇana": ['mw'],
    "narakavedanā": ['mw'],
    "narakavāsa": ['mw'],
    "narakaḥ": ['ap90'],
    "narakesarin": ['mw'],
    "narakottaraṇa": ['mw'],
    "narakāka": ['ddsa', 'mw'],
    "narakāmaya": ['mw'],
    "narakāntaka": ['mw'],
    "narakāri": ['mw'],
    "narakārṇava": ['mw'],
    "narakāsuradhvaṃsa": ['mw'],
    "narakāsuravijaya": ['mw'],
    "narakāsuravyāyoga": ['mw'],
    "narakāvāsa": ['mw'],
    "narakāya": ['mw'],
    "narakāyate": ['ap90'],
    "narakīlaka": ['mw'],
    "naraloka": ['cae', 'mw'],
    "naralokapāla": ['mw'],
    "naralokavīra": ['mw'],
    "naramedha": ['cae', 'mw'],
    "narammanya": ['mw'],
    "naramohinī": ['mw'],
    "naramālinī": ['mw'],
    "naramālā": ['mw'],
    "naramānikā": ['mw'],
    "naramāninī": ['mw'],
    "naramāṃsa": ['cae', 'mw'],
    "naramūrchana": ['mw'],
    "naranagara": ['mw'],
    "naranāman": ['mw'],
    "naranārāyaṇa": ['mw'],
    "naranārāyaṇānandakāvya": ['mw'],
    "naranārīvilakṣaṇā": ['mw'],
    "naranātha": ['cae', 'mw'],
    "naranāthamārga": ['mw'],
    "naranāthāsana": ['mw'],
    "naranāyaka": ['mw'],
    "narapa": ['ddsa', 'mw'],
    "narapati": ['cae', 'mw'],
    "narapatijayacaryā": ['mw'],
    "narapatijayacaryāsāra": ['mw'],
    "narapatijayasūra": ['mw'],
    "narapatipatha": ['mw'],
    "narapativijaya": ['mw'],
    "narapaśu": ['cae', 'mw'],
    "narapriya": ['mw'],
    "narapuṃgava": ['cae', 'mw'],
    "narapāla": ['cae', 'mw'],
    "narapālinī": ['mw'],
    "narapūtanāśānti": ['mw'],
    "nararatha": ['mw'],
    "nararāja": ['bhs', 'cae', 'mw'],
    "nararājya": ['mw'],
    "nararūpa": ['cae', 'mw'],
    "nararṣaba": ['mw'],
    "narasakha": ['mw'],
    "narasarājīya": ['mw'],
    "narasaṃghārāma": ['mw'],
    "narasaṃsarga": ['mw'],
    "narasaṃvādasundara": ['mw'],
    "narasiṃha": ['bhs', 'cae', 'mw'],
    "narasiṃhabhaṭṭīya": ['mw'],
    "narasiṃhabhujaṃga": ['mw'],
    "narasiṃhabhāratīvilāsa": ['mw'],
    "narasiṃhabhūpālacaritra": ['mw'],
    "narasiṃhacūrṇa": ['mw'],
    "narasiṃhadvādaśī": ['mw'],
    "narasiṃhadvādaśīvrata": ['mw'],
    "narasiṃhakalpa": ['mw'],
    "narasiṃhanakhastotra": ['mw'],
    "narasiṃhapañcaratna": ['mw'],
    "narasiṃhapurāṇa": ['mw'],
    "narasiṃhapārijāta": ['mw'],
    "narasiṃharājīya": ['mw'],
    "narasiṃharṣabhakṣetramāhātmya": ['mw'],
    "narasiṃhasahasranāman": ['mw'],
    "narasiṃhastuti": ['mw'],
    "narasiṃhavarman": ['mw'],
    "narasiṃhayantra": ['mw'],
    "narasiṃhaśāstriprakāśikā": ['mw'],
    "naraskandha": ['mw'],
    "narasāra": ['mw'],
    "naratroṭakācārya": ['mw'],
    "naratva": ['mw'],
    "naratā": ['cae', 'mw'],
    "naravara": ['mw'],
    "naravaravṛṣabha": ['mw'],
    "naravarman": ['mw'],
    "naravarmanṛpatikathā": ['mw'],
    "naravarottama": ['mw'],
    "naravasabha": ['cped'],
    "naravat": ['mw'],
    "naraviṣvaṇa": ['mw'],
    "naraviṣāṇa": ['mw'],
    "naravyāghra": ['cae', 'mw'],
    "naravāhana": ['bhs', 'cae', 'mw'],
    "naravāhanadatta": ['mw'],
    "naravāhanadattacaritamaya": ['mw'],
    "naravāhanadattīya": ['mw'],
    "naravāhanajanana": ['mw'],
    "naravāhin": ['cae', 'mw'],
    "naravīra": ['cae', 'mw'],
    "naravīraloka": ['mw'],
    "naravīrā": ['bhs'],
    "naravṛttāṣṭaka": ['mw'],
    "narayantra": ['mw'],
    "narayāna": ['ddsa', 'mw'],
    "narayāṇa": ['mw'],
    "naraśreṣṭha": ['mw'],
    "naraśārdūla": ['cae', 'mw'],
    "naraśṛṅga": ['mw'],
    "naraḥ": ['ap90'],
    "naraṃdhiḥ": ['ap90'],
    "naraṃdhiṣa": ['mw'],
    "naraṃdhiṣaḥ": ['ap90'],
    "naraṃgaṃ": ['ap90'],
    "naraṃpravāha": ['bhs'],
    "naraṅga": ['mw'],
    "narb": ['ap90', 'mw'],
    "nard": ['ap90', 'cae', 'ddsa', 'mw'],
    "narda": ['ap90', 'mw'],
    "nardabuda": ['mw'],
    "nardana": ['bhs', 'cae', 'mw'],
    "nardanaṃ": ['ap90'],
    "nardanīya": ['mw'],
    "nardat": ['mw'],
    "nardaṭaka": ['mw'],
    "nardin": ['ap90', 'mw'],
    "nardita": ['ap90', 'cae', 'ddsa', 'mw'],
    "narendra": ['bhs', 'cae', 'ddsa', 'mw'],
    "narendradeva": ['mw'],
    "narendradruma": ['mw'],
    "narendraghoṣa": ['bhs'],
    "narendrakanyā": ['mw'],
    "narendramārga": ['cae', 'mw'],
    "narendranagarī": ['mw'],
    "narendraputra": ['mw'],
    "narendraraja": ['mw'],
    "narendrarāja": ['bhs'],
    "narendrasvāmin": ['mw'],
    "narendratva": ['mw'],
    "narendratā": ['mw'],
    "narendrācārya": ['mw'],
    "narendrāditya": ['mw'],
    "narendrāhva": ['mw'],
    "naretara": ['mw'],
    "nareśa": ['cae', 'ddsa', 'mw'],
    "nareśvara": ['bhs', 'cae', 'mw'],
    "nareśvaraparīkṣā": ['mw'],
    "nareśvaraviveka": ['mw'],
    "nareṣṭhā": ['cae', 'ddsa', 'gra'],
    "naria": ['gra'],
    "narikā": ['mw'],
    "nariāpas": ['gra'],
    "nariṣyant": ['cae'],
    "nariṣyanta": ['cae', 'mw'],
    "nariṣyat": ['mw'],
    "nariṣṭhā": ['ap90', 'cae', 'mw'],
    "nariṣṭā": ['cae', 'mw'],
    "narka": ['mw'],
    "narkuṭa": ['mw'],
    "narkuṭaka": ['mw'],
    "narkuṭakaṃ": ['ap90'],
    "narma": ['cae', 'mw'],
    "narmada": ['cae', 'mw'],
    "narmadeśvara": ['mw'],
    "narmadeśvaraliṅga": ['mw'],
    "narmadeśvaramāhātmya": ['mw'],
    "narmadeśvaraparīkṣā": ['mw'],
    "narmadeśvaratīrtha": ['mw'],
    "narmadyuti": ['mw'],
    "narmadā": ['mw'],
    "narmadākhaṇḍa": ['mw'],
    "narmadālaharī": ['mw'],
    "narmadāmāhātmya": ['mw'],
    "narmadāsundarīrāsa": ['mw'],
    "narmadātaṭadeśa": ['mw'],
    "narmadātīragamana": ['mw'],
    "narmadātīrtha": ['mw'],
    "narmadāṣṭaka": ['mw'],
    "narmagarbha": ['ddsa', 'mw'],
    "narmaikasodara": ['mw'],
    "narmakīla": ['mw'],
    "narman": ['ap90', 'cae', 'ddsa', 'mw'],
    "narmarā": ['ap90', 'mw'],
    "narmasaciva": ['cae', 'ddsa', 'mw'],
    "narmasaṃyukta": ['mw'],
    "narmasphañja": ['mw'],
    "narmasphiñja": ['mw'],
    "narmasphoṭa": ['mw'],
    "narmasphūrja": ['mw'],
    "narmasuhṛd": ['cae', 'mw'],
    "narmasācivya": ['mw'],
    "narmavat": ['ap90'],
    "narmavatī": ['mw'],
    "narmaya": ['ddsa', 'mw'],
    "narmayukta": ['cae', 'mw'],
    "narmaḥ": ['ap90'],
    "narmaṇā": ['mw'],
    "narmaṭa": ['mw'],
    "narmaṭaḥ": ['ap90'],
    "narmaṭha": ['mw'],
    "narmaṭhaḥ": ['ap90'],
    "narmokti": ['cae', 'ddsa', 'mw'],
    "narmālāpa": ['mw'],
    "narmārtham": ['mw'],
    "narmāyita": ['mw'],
    "naroga": ['mw'],
    "narottama": ['bhs', 'cae', 'ddsa', 'mw'],
    "narottamadāsa": ['mw'],
    "narottamakīrtileśamātradarśaka": ['mw'],
    "narottamāraṇyaśiṣya": ['mw'],
    "narta": ['ap90', 'mw'],
    "nartaka": ['cae', 'ddsa', 'mw'],
    "nartakaka": ['mw'],
    "nartakaḥ": ['ap90'],
    "nartakikā": ['mw'],
    "nartakī": ['mw'],
    "nartakītva": ['mw'],
    "nartana": ['cae', 'ddsa', 'mw'],
    "nartananirṇaya": ['mw'],
    "nartanapriya": ['mw'],
    "nartanasthāna": ['mw'],
    "nartanaśālā": ['mw'],
    "nartanaḥ": ['ap90'],
    "nartanāgāra": ['mw'],
    "nartanāgṛha": ['mw'],
    "nartayitṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "nartin": ['cae', 'mw'],
    "nartita": ['ap90', 'cae', 'mw'],
    "nartitabhrūlata": ['mw'],
    "nartitamayūra": ['mw'],
    "nartitavya": ['cae', 'mw'],
    "nartu": ['ap90'],
    "nartū": ['mw'],
    "naruṇa": ['mw'],
    "narya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "naryāpas": ['cae', 'gra', 'mw'],
    "narāca": ['mw'],
    "narācī": ['mw'],
    "narādhama": ['cae', 'mw'],
    "narādhipa": ['cae', 'ddsa', 'mw'],
    "narādhipati": ['cae', 'mw'],
    "narādhāra": ['mw'],
    "narādhārā": ['mw'],
    "narānta": ['mw'],
    "narāntaka": ['mw'],
    "narāntakanigrahavarṇana": ['mw'],
    "narāntakanirgama": ['mw'],
    "narāsabha": ['cped'],
    "narāyaṇa": ['mw'],
    "narāśa": ['cae', 'mw'],
    "narāśana": ['cae', 'mw'],
    "narāśaṃsa": ['cae', 'ddsa', 'gra', 'mw'],
    "narāśaṃsapaṅkti": ['mw'],
    "narāśaṃsaḥ": ['ap90'],
    "narāṅga": ['mw'],
    "narāṅghri": ['mw'],
    "narī": ['ap90', 'mw'],
    "narībhū": ['mw'],
    "narīya": ['mw'],
    "nas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nasa": ['cae', 'ddsa', 'mw'],
    "nasaratha": ['mw'],
    "nasaṃvid": ['ddsa', 'mw'],
    "nasi": ['mw'],
    "nasottha": ['mw'],
    "nasparśana": ['ddsa', 'mw'],
    "nasra": ['mw'],
    "nassa": ['cped'],
    "nassanadhamma": ['cped'],
    "nassati": ['cped'],
    "nassaṁ": ['cped'],
    "nassi": ['cped'],
    "nassāsiṁ": ['cped'],
    "nasta": ['mw'],
    "nastaka": ['cae', 'mw'],
    "nastakaraṇa": ['bhs', 'mw'],
    "nastakaṃ": ['ap90'],
    "nastas": ['ap90', 'cae', 'ddsa', 'mw'],
    "nastatas": ['mw'],
    "nastaḥ": ['ap90'],
    "nastaḥkaraṇa": ['mw'],
    "nastaḥkarman": ['mw'],
    "nastika": ['ddsa'],
    "nastita": ['ap90', 'mw'],
    "nastota": ['mw'],
    "nastā": ['cae', 'mw'],
    "nasukara": ['mw'],
    "nasvant": ['cae'],
    "nasvat": ['mw'],
    "nasya": ['ap90', 'cae', 'ddsa', 'mw'],
    "nasyabhairava": ['mw'],
    "nasyakarman": ['cae', 'mw'],
    "nasyavidhi": ['mw'],
    "nasyita": ['mw'],
    "nasyota": ['cae', 'mw'],
    "nasyā": ['ddsa', 'mw'],
    "nasā": ['ap90', 'mw'],
    "nat": ['mw'],
    "nata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "natabhrū": ['cae', 'mw'],
    "natabhāga": ['mw'],
    "natadruma": ['mw'],
    "natadvid": ['mw'],
    "nataghaṭikā": ['mw'],
    "natajyā": ['mw'],
    "natajānu": ['mw'],
    "natakaṃdhara": ['mw'],
    "natakāla": ['mw'],
    "natamaṃhas": ['mw'],
    "natamukha": ['mw'],
    "natamām": ['mw'],
    "natamūrdhan": ['mw'],
    "natanābhi": ['mw'],
    "natanāsika": ['mw'],
    "natanāḍikā": ['mw'],
    "natanāḍī": ['mw'],
    "nataparvan": ['mw'],
    "natarām": ['cae', 'ddsa', 'mw'],
    "nathāputta": ['cped'],
    "nati": ['cae', 'cped', 'ddsa', 'mw'],
    "natitati": ['mw'],
    "natiḥ": ['ap90'],
    "natodara": ['mw'],
    "natonnata": ['mw'],
    "natonnatabhrū": ['mw'],
    "natonnatabhūmibhāga": ['mw'],
    "natra": ['mw'],
    "natta(r)": ['cped'],
    "nattamahaṁ": ['cped'],
    "nattamatta": ['cped'],
    "nattamāla": ['cped'],
    "natthi": ['cped'],
    "natthika": ['cped'],
    "natthikavāda": ['cped'],
    "natthitā": ['cped'],
    "natthu": ['cped'],
    "natthukamma": ['cped'],
    "natthukaraṇī": ['cped'],
    "nattumatta": ['cped'],
    "natyakṣara": ['mw'],
    "natyūha": ['mw'],
    "natāgranāsa": ['mw'],
    "natāṃśa": ['mw'],
    "natāṅga": ['mw'],
    "natāṅgā": ['cae'],
    "natāṅgī": ['mw'],
    "nau": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "naubandhana": ['cae', 'mw'],
    "naubandhanamāhātmya": ['mw'],
    "naubhū": ['mw'],
    "naucakrīvat": ['mw'],
    "naucara": ['cae', 'mw'],
    "naudaṇḍa": ['mw'],
    "naudhasa": ['ddsa', 'mw'],
    "naudhasaśyaita": ['mw'],
    "naudhasaśyaitayoni": ['mw'],
    "naujīvika": ['cae', 'mw'],
    "nauka": ['cae', 'ddsa', 'mw'],
    "naukarman": ['cae', 'mw'],
    "naukarṇa": ['mw'],
    "naukarṇadhāra": ['cae', 'mw'],
    "naukarṇī": ['mw'],
    "naukrama": ['bhs', 'mw'],
    "naukā": ['ap90', 'mw'],
    "naukādaṇḍa": ['mw'],
    "naukādāna": ['mw'],
    "naukākṛṣṭa": ['mw'],
    "naukāya": ['mw'],
    "naulika": ['mw'],
    "naulī": ['mw'],
    "naumaṇḍa": ['mw'],
    "naunetṛ": ['mw'],
    "naunidhirāma": ['mw'],
    "naupura": ['mw'],
    "nausaṃkrama": ['mw'],
    "nausārathi": ['mw'],
    "nautana": ['mw'],
    "nautārya": ['mw'],
    "nauvimāna": ['mw'],
    "nauvyasana": ['cae', 'mw'],
    "nauvāha": ['mw'],
    "nauyāna": ['cae', 'ddsa', 'mw'],
    "nauyāyin": ['cae', 'mw'],
    "nauṣecana": ['mw'],
    "nava": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "navabaddha": ['mw'],
    "navabhāga": ['mw'],
    "navacatvāriṃśa": ['mw'],
    "navacatvāriṃśat": ['mw'],
    "navacchadi": ['mw'],
    "navacchātra": ['mw'],
    "navadala": ['mw'],
    "navadaśa": ['cae', 'mw'],
    "navadaśan": ['cae', 'ddsa', 'mw'],
    "navadevakula": ['mw'],
    "navadhā": ['ap90', 'cae', 'ddsa', 'mw'],
    "navadolā": ['mw'],
    "navadurgā": ['mw'],
    "navadvāra": ['cae', 'ddsa', 'mw'],
    "navadvīpa": ['mw'],
    "navadvīpaparikramā": ['mw'],
    "navadānta": ['bhs'],
    "navadāva": ['mw'],
    "navadāvya": ['mw'],
    "navadīdhiti": ['mw'],
    "navagat": ['cae', 'mw'],
    "navaggaha": ['cped'],
    "navaghāsa": ['mw'],
    "navagraha": ['ddsa', 'mw'],
    "navagrahabalidānaprayoga": ['mw'],
    "navagrahacakra": ['mw'],
    "navagrahacintāmaṇi": ['mw'],
    "navagrahadaśālakṣaṇa": ['mw'],
    "navagrahadhyāna": ['mw'],
    "navagrahadhyānaprakāra": ['mw'],
    "navagrahadāna": ['mw'],
    "navagrahagaṇita": ['mw'],
    "navagrahahoma": ['mw'],
    "navagrahakavaca": ['mw'],
    "navagrahamakha": ['mw'],
    "navagrahamakhaśānti": ['mw'],
    "navagrahamantra": ['mw'],
    "navagrahamaṅgalāṣṭaka": ['mw'],
    "navagrahanāmāvalī": ['mw'],
    "navagrahapaddhati": ['mw'],
    "navagrahaphala": ['mw'],
    "navagrahaprayoga": ['mw'],
    "navagrahapraśna": ['mw'],
    "navagrahapūjā": ['mw'],
    "navagrahapūjāpaddhati": ['mw'],
    "navagrahapūjāvidhi": ['mw'],
    "navagrahastava": ['mw'],
    "navagrahasthāpana": ['mw'],
    "navagrahastotra": ['mw'],
    "navagrahastuti": ['mw'],
    "navagrahasūkta": ['mw'],
    "navagrahavidhāna": ['mw'],
    "navagrahayantroddharaṇakrama": ['mw'],
    "navagrahayāga": ['mw'],
    "navagrahaśānti": ['mw'],
    "navagrahādhidevatāsthāpana": ['mw'],
    "navagrahādhipatyāhidevatāsthāpana": ['mw'],
    "navagrahānayanakoṣṭhaka": ['mw'],
    "navaguṇita": ['mw'],
    "navagva": ['cae', 'gra', 'mw'],
    "navaha": ['cped'],
    "navahapaṭicchanna": ['cped'],
    "navahasta": ['mw'],
    "navahā": ['cped'],
    "navaja": ['cae', 'ddsa', 'mw'],
    "navajvararipurasa": ['mw'],
    "navajvarebhasiṃha": ['mw'],
    "navajvāra": ['cae', 'gra', 'mw'],
    "navajā": ['cae', 'gra', 'mw'],
    "navajāta": ['cae', 'gra', 'mw'],
    "navaka": ['ap90', 'cae', 'cped', 'mw'],
    "navakamma": ['cped'],
    "navakammika": ['cped'],
    "navakanipāta": ['cped'],
    "navakapāla": ['mw'],
    "navakara": ['mw'],
    "navakarmika": ['bhs', 'mw'],
    "navakatara": ['cped'],
    "navakaṇḍikāśrāddhasūtra": ['mw'],
    "navakhaṇḍayogasahasra": ['mw'],
    "navakoṭi": ['mw'],
    "navakālaka": ['mw'],
    "navakālidāsa": ['mw'],
    "navakālikā": ['mw'],
    "navakānta": ['bhs'],
    "navakārikā": ['mw'],
    "navakṛt": ['mw'],
    "navakṛtvas": ['cae', 'ddsa', 'mw'],
    "navama": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "navamaka": ['mw'],
    "navamallikā": ['cae', 'ddsa', 'mw'],
    "navamallī": ['mw'],
    "navamaṇimālā": ['mw'],
    "navamegha": ['mw'],
    "navameghakāla": ['cae'],
    "navamikā": ['bhs'],
    "navamukha": ['ddsa', 'mw'],
    "navamva": ['ddsa'],
    "navamālikā": ['cae', 'mw'],
    "navamālinī": ['mw'],
    "navamālī": ['mw'],
    "navamāṃśa": ['mw'],
    "navamī": ['mw'],
    "navamūlaka": ['cped'],
    "navan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "navana": ['cae', 'ddsa', 'mw'],
    "navanagara": ['mw'],
    "navanalinadalāya": ['mw'],
    "navanava": ['cped', 'ddsa', 'mw'],
    "navanavati": ['mw'],
    "navanavatitama": ['mw'],
    "navanaṃ": ['ap90'],
    "navanivesa": ['cped'],
    "navanāthayogin": ['mw'],
    "navanī": ['cae', 'mw'],
    "navanīta": ['cped', 'ddsa', 'mw'],
    "navanītadhenu": ['mw'],
    "navanītagaṇapati": ['mw'],
    "navanītaja": ['mw'],
    "navanītajātaka": ['mw'],
    "navanītaka": ['mw'],
    "navanītakavi": ['mw'],
    "navanītakhoṭī": ['mw'],
    "navanītamaya": ['mw'],
    "navanītanibandha": ['mw'],
    "navanītapiṇḍa": ['mw'],
    "navanītapṛśni": ['mw'],
    "navanītasama": ['mw'],
    "navapad": ['cae', 'gra'],
    "navapallava": ['mw'],
    "navapariṇayā": ['mw'],
    "navaparṇādibhakṣaṇa": ['mw'],
    "navapattrikā": ['mw'],
    "navapañcāśa": ['mw'],
    "navapañcāśapad": ['mw'],
    "navapañcāśat": ['ddsa', 'mw'],
    "navaphalikā": ['mw'],
    "navappāya": ['cped'],
    "navaprasūtā": ['mw'],
    "navaprāśana": ['ddsa', 'mw'],
    "navapāṣāṇadarbhaśayanasaṃkalpa": ['mw'],
    "navara": ['bhs', 'mw'],
    "navarajas": ['mw'],
    "navaraktaka": ['mw'],
    "navaram": ['mw'],
    "navarasa": ['mw'],
    "navarasaratnahāra": ['mw'],
    "navarasataraṃgiṇī": ['mw'],
    "navarasaundaryabhaṭṭa": ['mw'],
    "navaratha": ['mw'],
    "navaratna": ['mw'],
    "navaratnadhātuvivāda": ['mw'],
    "navaratnadāna": ['mw'],
    "navaratnajyotirgaṇita": ['mw'],
    "navaratnamālikā": ['mw'],
    "navaratnamālā": ['mw'],
    "navaratnaparīkṣā": ['mw'],
    "navaratneśvaratantra": ['mw'],
    "navaratta": ['cped'],
    "navaraṅga": ['mw'],
    "navaraṅgakula": ['mw'],
    "navarca": ['cae', 'mw'],
    "navarāja": ['mw'],
    "navarātra": ['cae', 'ddsa', 'mw'],
    "navarātraghaṭasthāpanavidhi": ['mw'],
    "navarātrahavanavidhi": ['mw'],
    "navarātrakṛtya": ['mw'],
    "navarātranirṇaya": ['mw'],
    "navarātrapradīpa": ['mw'],
    "navarātrapūjāvidhāna": ['mw'],
    "navarātravrata": ['mw'],
    "navarāśika": ['mw'],
    "navarāṣṭra": ['mw'],
    "navasaptadaśa": ['mw'],
    "navasaptati": ['mw'],
    "navasaptatitama": ['mw'],
    "navasara": ['mw'],
    "navasassa": ['cped'],
    "navasasya": ['cae', 'ddsa', 'mw'],
    "navasasyeṣṭi": ['mw'],
    "navasaṃghārāma": ['mw'],
    "navasaṃyojanavisaṃyojanaka": ['mw'],
    "navasota": ['cped'],
    "navasrakti": ['gra', 'mw'],
    "navasthāna": ['mw'],
    "navastobha": ['mw'],
    "navasvastara": ['mw'],
    "navasāhasra": ['mw'],
    "navasāhasāṅkacarita": ['mw'],
    "navasū": ['cae', 'gra', 'mw'],
    "navasūtikā": ['mw'],
    "navata": ['ap90', 'cae', 'ddsa', 'mw'],
    "navatantu": ['mw'],
    "navatara": ['mw'],
    "navatardma": ['mw'],
    "navatattva": ['mw'],
    "navatattvabodha": ['mw'],
    "navatattvabālabodha": ['mw'],
    "navatattvabālāvabodha": ['mw'],
    "navatattvaprakaraṇa": ['mw'],
    "navatattvasūtra": ['mw'],
    "navati": ['cae', 'ddsa', 'gra', 'mw'],
    "navatidhanus": ['mw'],
    "navatidhā": ['mw'],
    "navatikā": ['ap90', 'mw'],
    "navatiprakrama": ['mw'],
    "navatiratha": ['mw'],
    "navatirupatimāhātmya": ['mw'],
    "navatitama": ['cae', 'mw'],
    "navatiśas": ['mw'],
    "navatiśata": ['mw'],
    "navatiḥ": ['ap90'],
    "navatva": ['cae', 'mw'],
    "navatā": ['ap90', 'cae', 'ddsa', 'mw'],
    "navatāntava": ['mw'],
    "navaucityavicāracarcā": ['mw'],
    "navavadhū": ['cae', 'ddsa', 'mw'],
    "navavarikā": ['mw'],
    "navavarṇamālā": ['mw'],
    "navavarṣamahotsava": ['mw'],
    "navavastra": ['mw'],
    "navavidha": ['cae', 'ddsa', 'mw'],
    "navavitṛṇṇa": ['mw'],
    "navavivekadīpikā": ['mw'],
    "navaviṃśa": ['mw'],
    "navaviṃśati": ['mw'],
    "navavrata": ['mw'],
    "navavyūha": ['mw'],
    "navavārṣika": ['cae', 'mw'],
    "navavārṣikadeśīya": ['mw'],
    "navavāstua": ['gra'],
    "navavāstva": ['gra', 'mw'],
    "navavṛṣa": ['mw'],
    "navayajña": ['ddsa', 'mw'],
    "navayauvana": ['cae', 'mw'],
    "navayogakallola": ['mw'],
    "navayānasaṃprasthita": ['bhs'],
    "navaśakti": ['mw'],
    "navaśas": ['mw'],
    "navaśata": ['mw'],
    "navaśatatama": ['mw'],
    "navaśaśibhṛt": ['ddsa', 'mw'],
    "navaśaḥ": ['ap90'],
    "navaśrāddha": ['mw'],
    "navaśāyaka": ['mw'],
    "navaśīrṣaka": ['bhs'],
    "navaṣaṣṭi": ['ddsa', 'mw'],
    "navaṣaṣṭitama": ['mw'],
    "navaṣaṭka": ['mw'],
    "navaṭṭhānika": ['cped'],
    "naveda": ['cae', 'gra', 'mw'],
    "navedas": ['cae', 'ddsa', 'gra'],
    "navetara": ['ddsa', 'mw'],
    "navia": ['gra'],
    "navidvas": ['mw'],
    "navidya": ['cae', 'mw'],
    "navikā": ['mw'],
    "navin": ['cae', 'mw'],
    "naviṣṭha": ['cae', 'gra', 'mw'],
    "naviṣṭi": ['cae', 'gra', 'mw'],
    "navodaka": ['bhs'],
    "navodaya": ['mw'],
    "navoddhṛta": ['mw'],
    "navodita": ['mw'],
    "navonavavyākhyā": ['mw'],
    "navotthāna": ['mw'],
    "navoḍhā": ['cae', 'ddsa', 'mw'],
    "navuti": ['cped'],
    "navutika": ['cped'],
    "navutiṁ": ['cped'],
    "navutpattika": ['bhs'],
    "navya": ['cae', 'ddsa', 'gra', 'mw'],
    "navyadharmitāvacchedakavādārtha": ['mw'],
    "navyamatarahasya": ['mw'],
    "navyamatavicāra": ['mw'],
    "navyamatavāda": ['mw'],
    "navyamatavādārtha": ['mw'],
    "navyamuktivādaṭippanī": ['mw'],
    "navyanirmāṇa": ['mw'],
    "navyas": ['ddsa', 'gra', 'mw'],
    "navyase": ['mw'],
    "navyasā": ['mw'],
    "navyavardhamāna": ['mw'],
    "navyavat": ['mw'],
    "navyaṃs": ['cae'],
    "navyā": ['mw'],
    "navyākṛti": ['mw'],
    "navyānumitiparāmarśakāryakāraṇabhāvavicāra": ['mw'],
    "navyānumitiparāmarśavicāra": ['mw'],
    "navā": ['mw'],
    "navāgata": ['mw'],
    "navāha": ['mw'],
    "navāhnikabhāṣya": ['mw'],
    "navākṣara": ['cae', 'mw'],
    "navākṣarīkalpa": ['mw'],
    "navāmbara": ['mw'],
    "navāmbu": ['mw'],
    "navānna": ['cae', 'ddsa', 'mw'],
    "navānnabhakṣaṇa": ['mw'],
    "navānnahautra": ['mw'],
    "navānnasthālīpākamantra": ['mw'],
    "navānnavidhi": ['mw'],
    "navānneṣṭi": ['mw'],
    "navānta": ['bhs'],
    "navānupūrvasamāpattikuśala": ['mw'],
    "navāratni": ['mw'],
    "navārcis": ['mw'],
    "navārma": ['mw'],
    "navārṇava": ['mw'],
    "navārṇavapaddhati": ['mw'],
    "navārṇavaprakaraṇa": ['mw'],
    "navātmaka": ['mw'],
    "navāvasita": ['mw'],
    "navāvasāna": ['mw'],
    "navāvuta": ['cped'],
    "navāyasa": ['mw'],
    "navāśra": ['mw'],
    "navāśrakuṇḍa": ['mw'],
    "navāśīti": ['ddsa', 'mw'],
    "navāśītitama": ['mw'],
    "navāṃśa": ['mw'],
    "navāṃśaka": ['mw'],
    "navāṃśakapa": ['mw'],
    "navāṅga": ['bhs'],
    "navāṅgā": ['mw'],
    "navāṅkura": ['mw'],
    "navī": ['mw'],
    "navībhāva": ['ddsa', 'mw'],
    "navībhū": ['ddsa', 'mw'],
    "navīkaraṇa": ['mw'],
    "navīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "navīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "navīnacandra": ['mw'],
    "navīnamatavicāra": ['mw'],
    "navīnanirmāṇa": ['mw'],
    "navīnavedāntin": ['mw'],
    "navīnavāda": ['mw'],
    "navīya": ['cae', 'gra', 'mw'],
    "navīyas": ['ddsa', 'gra', 'mw'],
    "navīyasā": ['mw'],
    "navīyaṃs": ['cae'],
    "nay": ['ap90', 'mw'],
    "naya": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "nayabodhikā": ['mw'],
    "nayacakṣus": ['mw'],
    "nayacandra": ['mw'],
    "nayacandrasūri": ['mw'],
    "nayadatta": ['mw'],
    "nayadyumaṇi": ['mw'],
    "nayaga": ['mw'],
    "nayahīna": ['cae'],
    "nayajña": ['cae', 'mw'],
    "nayajā": ['mw'],
    "nayaka": ['mw'],
    "nayakaḥ": ['ap90'],
    "nayakovida": ['cae', 'mw'],
    "nayalocana": ['mw'],
    "nayamayūkhamālikā": ['mw'],
    "nayamaṇimañjarī": ['mw'],
    "nayamāna": ['cped'],
    "nayamārtaṇḍa": ['mw'],
    "nayamāṇimālikā": ['mw'],
    "nayana": ['cae', 'cped', 'ddsa', 'mw'],
    "nayanabhūṣaṇa": ['mw'],
    "nayanabudbuda": ['mw'],
    "nayanacandrikā": ['mw'],
    "nayanacarita": ['mw'],
    "nayanacchada": ['mw'],
    "nayanagocara": ['cae', 'ddsa', 'mw'],
    "nayanajala": ['cae', 'mw'],
    "nayanamadhu": ['cae'],
    "nayanapadavī": ['mw'],
    "nayanapatha": ['cae', 'mw'],
    "nayanaplava": ['mw'],
    "nayanaprabandha": ['mw'],
    "nayanaprasādinī": ['mw'],
    "nayanaprīti": ['cae', 'mw'],
    "nayanapuṭa": ['mw'],
    "nayanasalila": ['cae', 'mw'],
    "nayanasukha": ['mw'],
    "nayanatva": ['mw'],
    "nayanauṣadha": ['mw'],
    "nayanavant": ['cae'],
    "nayanavat": ['mw'],
    "nayanaviṣaya": ['cae', 'mw'],
    "nayanaviṣayībhāva": ['mw'],
    "nayanavāri": ['mw'],
    "nayanaśāṇa": ['mw'],
    "nayanaṃ": ['ap90'],
    "nayanetṛ": ['mw'],
    "nayanirūpaṇa": ['mw'],
    "nayanoda": ['mw'],
    "nayanodabindu": ['cae', 'mw'],
    "nayanodaka": ['cae'],
    "nayanopānta": ['mw'],
    "nayanotsava": ['mw'],
    "nayanā": ['mw'],
    "nayanāmbu": ['cae', 'mw'],
    "nayanāmṛta": ['mw'],
    "nayanānanda": ['ddsa', 'mw'],
    "nayanānta": ['mw'],
    "nayanāñcala": ['cae', 'mw'],
    "nayanāñjala": ['mw'],
    "nayanāñjana": ['cae', 'mw'],
    "nayanī": ['mw'],
    "nayaprakāśikā": ['mw'],
    "nayaprayoga": ['mw'],
    "nayapāla": ['mw'],
    "nayapīṭhī": ['mw'],
    "nayaratna": ['mw'],
    "nayaratnamālā": ['mw'],
    "nayasaṃgraha": ['mw'],
    "nayasiddhi": ['mw'],
    "nayasādhana": ['mw'],
    "nayasāhasonnatimat": ['mw'],
    "nayasāra": ['mw'],
    "nayat": ['mw'],
    "nayati": ['cped'],
    "nayavant": ['cae'],
    "nayavartman": ['mw'],
    "nayavat": ['ddsa', 'mw'],
    "nayavedin": ['mw'],
    "nayavid": ['cae', 'mw'],
    "nayaviveka": ['mw'],
    "nayavivekadīpikā": ['mw'],
    "nayavivekaśaṅkādīpikā": ['mw'],
    "nayavivekālaṃkāra": ['mw'],
    "nayaviśārada": ['mw'],
    "nayavīthi": ['mw'],
    "nayaśālin": ['cae', 'mw'],
    "nayaśāstra": ['cae', 'mw'],
    "nayitavya": ['cae', 'mw'],
    "nayiṁsu": ['cped'],
    "nayiṣṭha": ['cae', 'gra', 'mw'],
    "nayuta": ['bhs', 'cae', 'mw'],
    "nayyagrodha": ['mw'],
    "nayācanaka": ['bhs'],
    "nayārthita": ['ddsa'],
    "nañ": ['ap90', 'ddsa', 'mw'],
    "nañartha": ['mw'],
    "nañarthanirṇaya": ['mw'],
    "nañarthavāda": ['mw'],
    "nañarthavādavivṛti": ['mw'],
    "nañarthavādaṭīkā": ['mw'],
    "nañjarāja": ['mw'],
    "nañjarājayaśobhūṣaṇa": ['mw'],
    "nañsamāsa": ['mw'],
    "nañsūtrārthavāda": ['mw'],
    "nañviveka": ['mw'],
    "nañvāda": ['mw'],
    "nañvādaviveka": ['mw'],
    "nañvādaṭippaṇī": ['mw'],
    "nañśiromaṇi": ['mw'],
    "naś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "naśa": ['gra', 'mw'],
    "naśakti": ['mw'],
    "naśana": ['cae', 'mw'],
    "naśeṣa": ['mw'],
    "naśitṛ": ['mw'],
    "naśubha": ['mw'],
    "naśvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "naśvaratva": ['mw'],
    "naśyat": ['mw'],
    "naśyatprasūti": ['mw'],
    "naśyatprasūtikā": ['ap90', 'mw'],
    "naśāka": ['mw'],
    "naśāy": ['gra'],
    "naśāya": ['mw'],
    "naḍ": ['mw'],
    "naḍa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "naḍabhakta": ['mw'],
    "naḍacippitikam": ['bhs'],
    "naḍaha": ['ap90', 'mw'],
    "naḍaka": ['bhs', 'cae', 'mw'],
    "naḍakaṃ": ['ap90'],
    "naḍakīya": ['mw'],
    "naḍakūbara": ['ddsa', 'mw'],
    "naḍamaya": ['cae', 'mw'],
    "naḍamīna": ['mw'],
    "naḍaneri": ['mw'],
    "naḍantikā": ['mw'],
    "naḍaprāya": ['mw'],
    "naḍasa": ['mw'],
    "naḍasaṃhati": ['mw'],
    "naḍavana": ['mw'],
    "naḍaśa": ['ap90'],
    "naḍaḥ": ['ap90'],
    "naḍbhuvaka": ['mw'],
    "naḍera": ['bhs'],
    "naḍila": ['ap90', 'mw'],
    "naḍinī": ['ap90', 'bhs', 'mw'],
    "naḍuvāha": ['mw'],
    "naḍvala": ['ap90', 'cae', 'ddsa', 'mw'],
    "naḍvalā": ['mw'],
    "naḍvat": ['mw'],
    "naḍvābhū": ['mw'],
    "naḍyā": ['ap90', 'mw'],
    "naḍāgiri": ['ddsa', 'mw'],
    "naḍāgāra": ['mw'],
    "naḥkṣudra": ['mw'],
    "naḷa": ['cped'],
    "naḷāgāra": ['cped'],
    "naḷāṭa": ['cped'],
    "naṁ": ['cped'],
    "naṃ": ['bhs'],
    "naṃd": ['ap90'],
    "naṃdaka": ['ap90'],
    "naṃdakin": ['ap90'],
    "naṃdakiḥ": ['ap90'],
    "naṃdana": ['ap90'],
    "naṃdanakaḥ": ['ap90'],
    "naṃdathuḥ": ['ap90'],
    "naṃdaḥ": ['ap90'],
    "naṃdaṃta": ['ap90'],
    "naṃdikaḥ": ['ap90'],
    "naṃdin": ['ap90'],
    "naṃdiḥ": ['ap90'],
    "naṃdā": ['ap90'],
    "naṃgaḥ": ['ap90'],
    "naṃhasa": ['mw'],
    "naṃś": ['cae', 'ddsa', 'gra', 'mw'],
    "naṃśa": ['cae', 'gra', 'mw'],
    "naṃśana": ['gra', 'mw'],
    "naṃśuka": ['ap90', 'cae', 'mw'],
    "naṃṣṭavya": ['mw'],
    "naṃṣṭṛ": ['mw'],
    "naṅgala": ['cped'],
    "naṅgalakaṭṭhakaraṇa": ['cped'],
    "naṅgalamukha": ['cped'],
    "naṅgalāvatta(n)": ['cped'],
    "naṅgalāvattani(n)": ['cped'],
    "naṅgalīsā": ['cped'],
    "naṅgula": ['bhs'],
    "naṅguṭṭha": ['cped'],
    "naṅgā": ['bhs'],
    "naṅkh": ['mw'],
    "naṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "naṣṭabīja": ['mw'],
    "naṣṭacandra": ['mw'],
    "naṣṭacaryā": ['mw'],
    "naṣṭacetana": ['cae', 'ddsa', 'mw'],
    "naṣṭaceṣṭa": ['cae', 'mw'],
    "naṣṭaceṣṭatā": ['mw'],
    "naṣṭadhī": ['mw'],
    "naṣṭadṛṣṭi": ['mw'],
    "naṣṭagaṇita": ['mw'],
    "naṣṭahīnavikalavikṛtasvara": ['mw'],
    "naṣṭahīnavikalavikṛtasvaratā": ['mw'],
    "naṣṭaiṣa": ['ddsa', 'mw'],
    "naṣṭaiṣin": ['mw'],
    "naṣṭaiṣya": ['ddsa', 'mw'],
    "naṣṭajanman": ['mw'],
    "naṣṭajātaka": ['mw'],
    "naṣṭakriya": ['mw'],
    "naṣṭakāryārtha": ['mw'],
    "naṣṭamati": ['mw'],
    "naṣṭamārgaṇa": ['mw'],
    "naṣṭanidra": ['mw'],
    "naṣṭapattrikā": ['mw'],
    "naṣṭapiṣṭa": ['mw'],
    "naṣṭapiṣṭīkṛ": ['mw'],
    "naṣṭapraśna": ['mw'],
    "naṣṭarājya": ['mw'],
    "naṣṭarūpa": ['cae', 'mw'],
    "naṣṭarūpā": ['mw'],
    "naṣṭarūpī": ['mw'],
    "naṣṭasalila": ['cae'],
    "naṣṭasaṃjña": ['cae', 'mw'],
    "naṣṭasaṃsmṛti": ['mw'],
    "naṣṭasmṛti": ['mw'],
    "naṣṭavat": ['mw'],
    "naṣṭavedana": ['mw'],
    "naṣṭaviṣa": ['mw'],
    "naṣṭendriya": ['ddsa', 'mw'],
    "naṣṭendukalā": ['mw'],
    "naṣṭi": ['cae', 'ddsa', 'mw'],
    "naṣṭiḥ": ['ap90'],
    "naṣṭobhayaloka": ['ddsa', 'mw'],
    "naṣṭoddiṣṭaprabodhakadhrauvapadaṭīkā": ['mw'],
    "naṣṭāgni": ['mw'],
    "naṣṭāptisūtra": ['mw'],
    "naṣṭārtha": ['cae', 'mw'],
    "naṣṭāsu": ['cae', 'mw'],
    "naṣṭātaṅkam": ['ddsa', 'mw'],
    "naṣṭātman": ['cae', 'mw'],
    "naṣṭāśaṅka": ['cae', 'mw'],
    "naṣṭāśvadagdharathavat": ['mw'],
    "naṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "naṭa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "naṭabaṭu": ['mw'],
    "naṭabhaṭikavihāra": ['mw'],
    "naṭabhaṭikā": ['bhs', 'mw'],
    "naṭabhūṣaṇa": ['mw'],
    "naṭacaryā": ['mw'],
    "naṭagati": ['mw'],
    "naṭagaṅgoka": ['mw'],
    "naṭaka": ['cae', 'cped', 'mw'],
    "naṭakamelaka": ['mw'],
    "naṭakaḥ": ['ap90'],
    "naṭamaṇḍana": ['mw'],
    "naṭana": ['cae', 'mw'],
    "naṭanaṃ": ['ap90'],
    "naṭanānandanātha": ['mw'],
    "naṭanārāyaṇa": ['mw'],
    "naṭanīya": ['cae', 'mw'],
    "naṭaparṇa": ['mw'],
    "naṭapattrikā": ['mw'],
    "naṭaraṅga": ['bhs', 'mw'],
    "naṭasaṃjñaka": ['mw'],
    "naṭasūtra": ['mw'],
    "naṭatā": ['cae', 'mw'],
    "naṭavara": ['mw'],
    "naṭaśreṣṭha": ['mw'],
    "naṭaḥ": ['ap90'],
    "naṭeśavijaya": ['mw'],
    "naṭeśvara": ['mw'],
    "naṭikā": ['bhs'],
    "naṭita": ['mw'],
    "naṭitaṃ": ['ap90'],
    "naṭiti": ['mw'],
    "naṭyā": ['ap90', 'mw'],
    "naṭā": ['bhs', 'mw'],
    "naṭāntikā": ['mw'],
    "naṭī": ['ap90', 'bhs', 'mw'],
    "naṭīsuta": ['mw'],
    "naṭṭa": ['mw'],
    "naṭṭahambīrā": ['mw'],
    "naṭṭaka": ['mw'],
    "naṭṭakalyāṇa": ['mw'],
    "naṭṭaki": ['cped'],
    "naṭṭamallārikā": ['mw'],
    "naṭṭanārāyaṇa": ['mw'],
    "naṭṭapaṭṭagrāma": ['mw'],
    "naṭṭavarāṭikā": ['mw'],
    "naṭṭha": ['cped'],
    "naṭṭhacīvarikā": ['cped'],
    "naṭṭā": ['bhs'],
    "ne": ['cped'],
    "necayika": ['cped'],
    "neccenta": ['cped'],
    "ned": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nedaya": ['mw'],
    "nediṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nediṣṭham": ['mw'],
    "nediṣṭhatama": ['cae', 'gra', 'mw'],
    "nediṣṭhatamām": ['mw'],
    "nediṣṭhin": ['mw'],
    "nediṣṭhāt": ['mw'],
    "nedya": ['mw'],
    "nedīyas": ['ap90', 'gra', 'mw'],
    "nedīyastā": ['mw'],
    "nedīyaṃs": ['cae'],
    "nedīyomaraṇa": ['mw'],
    "nega": ['mw'],
    "negama": ['cped'],
    "negamajanapada": ['cped'],
    "negamajānapada": ['cped'],
    "nejaka": ['cae', 'ddsa', 'mw'],
    "nejakaḥ": ['ap90'],
    "nejameṣa": ['mw'],
    "nejana": ['cae', 'mw'],
    "nejanaṃ": ['ap90'],
    "neka": ['cped'],
    "nekadhā": ['cped'],
    "nekatika": ['cped'],
    "nekavassagaṇika": ['cped'],
    "nekkha": ['cped'],
    "nekkhamma": ['cped'],
    "nekkhammadhatu": ['cped'],
    "nekkhammasita": ['cped'],
    "nekṣaṇa": ['cae', 'gra', 'mw'],
    "nela": ['bhs', 'cped', 'mw'],
    "nelaṅga": ['cped'],
    "nelu": ['bhs', 'mw'],
    "nelā": ['bhs'],
    "nema": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nemacandra": ['mw'],
    "nemadhita": ['mw'],
    "nemadhiti": ['cae', 'gra', 'mw'],
    "nemadhitā": ['mw'],
    "neman": ['gra'],
    "nemaniṣ": ['gra'],
    "nemanniṣ": ['gra', 'mw'],
    "nemantanika": ['cped'],
    "nemantaṇika": ['cped'],
    "nemanātha": ['mw'],
    "nemapiṣṭa": ['mw'],
    "nemapiṣṭatā": ['mw'],
    "nemaspṛṣṭa": ['mw'],
    "nemaśāha": ['mw'],
    "nemi": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nemicakra": ['mw'],
    "nemicaritra": ['mw'],
    "nemidhvani": ['mw'],
    "nemighoṣa": ['mw'],
    "nemika": ['bhs'],
    "nemin": ['bhs', 'mw'],
    "nemininada": ['mw'],
    "neminātha": ['mw'],
    "nemipurāṇa": ['mw'],
    "nemirājarṣicaritra": ['mw'],
    "nemisvana": ['mw'],
    "nemita": ['mw'],
    "nemitta": ['cped'],
    "nemittaka": ['cped'],
    "nemittika": ['cped'],
    "nemivṛkṣa": ['mw'],
    "nemivṛtti": ['mw'],
    "nemiśabda": ['cae', 'mw'],
    "nemiśāha": ['mw'],
    "nemiḥ": ['ap90'],
    "nemiṃdhara": ['bhs', 'mw'],
    "nemāditya": ['mw'],
    "nemī": ['cped'],
    "nenya": ['mw'],
    "nepa": ['mw'],
    "nepathya": ['cae', 'ddsa', 'mw'],
    "nepathyabhṛt": ['mw'],
    "nepathyagrahaṇa": ['mw'],
    "nepathyagṛha": ['cae', 'mw'],
    "nepathyaprayoga": ['mw'],
    "nepathyasamprayoga": ['mw'],
    "nepathyasavana": ['cae', 'mw'],
    "nepathyavidhāna": ['mw'],
    "nepathyaṃ": ['ap90'],
    "nepathye": ['mw'],
    "nepathyābhimukham": ['mw'],
    "nepattha": ['bhs'],
    "nepatthita": ['bhs'],
    "nepaḥ": ['ap90'],
    "nepāla": ['cae', 'ddsa', 'mw'],
    "nepālajā": ['mw'],
    "nepālajātā": ['mw'],
    "nepālaka": ['mw'],
    "nepālakaṃ": ['ap90'],
    "nepālamāhātmya": ['mw'],
    "nepālamūlaka": ['mw'],
    "nepālanimba": ['mw'],
    "nepālapāla": ['mw'],
    "nepālapālaka": ['mw'],
    "nepālavarṣa": ['mw'],
    "nepālaviṣaya": ['mw'],
    "nepālaḥ": ['ap90'],
    "nepālikā": ['ap90', 'mw'],
    "nepālābda": ['mw'],
    "nepālī": ['mw'],
    "nerayika": ['cped'],
    "neraṇivādārtha": ['mw'],
    "nerella": ['mw'],
    "neri": ['mw'],
    "neruṅgala": ['mw'],
    "nesajjika": ['cped'],
    "nesaṁ": ['cped'],
    "nesuṁ": ['cped'],
    "nesāda": ['cped'],
    "nesādī": ['cped'],
    "neta(r)": ['cped'],
    "netabba": ['cped'],
    "netavya": ['cae', 'ddsa', 'mw'],
    "netaṁ ṭhānaṁ vijjati": ['cped'],
    "neti": ['bhs', 'cped'],
    "netra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "netrabandha": ['mw'],
    "netrabhava": ['mw'],
    "netracapala": ['cae', 'mw'],
    "netracchada": ['mw'],
    "netragocara": ['cae', 'mw'],
    "netrahita": ['mw'],
    "netrahārin": ['mw'],
    "netraja": ['cae', 'mw'],
    "netrajala": ['cae', 'mw'],
    "netrajalasrava": ['mw'],
    "netrakanīnikā": ['mw'],
    "netrakośa": ['mw'],
    "netrakārmaṇa": ['mw'],
    "netramala": ['mw'],
    "netramanaḥsvabhāva": ['mw'],
    "netramuṣ": ['mw'],
    "netramīlā": ['mw'],
    "netraniṃsin": ['mw'],
    "netraparyanta": ['mw'],
    "netrapattra": ['mw'],
    "netrapeya": ['mw'],
    "netrapiṇḍa": ['mw'],
    "netraprabandha": ['mw'],
    "netrapraṇayin": ['mw'],
    "netrapuṣkarā": ['mw'],
    "netrapāka": ['mw'],
    "netrarañjana": ['mw'],
    "netraroga": ['mw'],
    "netrarogacikitsā": ['mw'],
    "netrarogahan": ['mw'],
    "netrarogatā": ['mw'],
    "netraroman": ['mw'],
    "netraruj": ['mw'],
    "netrasaṃkocana": ['mw'],
    "netrasaṃvejana": ['mw'],
    "netrastambha": ['mw'],
    "netratribhāgabrahmayaśasvin": ['mw'],
    "netratā": ['mw'],
    "netratāṃyā": ['mw'],
    "netrauṣadha": ['mw'],
    "netrauṣadhī": ['mw'],
    "netravasti": ['mw'],
    "netravastra": ['mw'],
    "netraviṣ": ['mw'],
    "netraviṣa": ['mw'],
    "netravār": ['mw'],
    "netravāri": ['cae', 'mw'],
    "netrayoni": ['mw'],
    "netraśrī": ['bhs'],
    "netraṃ": ['ap90'],
    "netrika": ['bhs', 'mw'],
    "netrikaṃ": ['ap90'],
    "netrikā": ['bhs'],
    "netrita": ['bhs'],
    "netroddyota": ['mw'],
    "netropama": ['mw'],
    "netropamaphala": ['mw'],
    "netropaniṣad": ['mw'],
    "netropādhyāya": ['mw'],
    "netrotsava": ['cae', 'mw'],
    "netrya": ['mw'],
    "netrābhiṣyanda": ['mw'],
    "netrāmaya": ['mw'],
    "netrāmbhas": ['mw'],
    "netrāmbu": ['mw'],
    "netrānta": ['mw'],
    "netrāri": ['mw'],
    "netrātithi": ['mw'],
    "netrāñjana": ['cae', 'mw'],
    "netrī": ['ap90', 'bhs', 'ddsa', 'gra', 'mw'],
    "netta": ['cped'],
    "netta(r)": ['cped'],
    "nettatappana": ['cped'],
    "netthāra": ['cped'],
    "nettika": ['cped'],
    "nettucchinna": ['cped'],
    "netvā": ['cped'],
    "netvāna": ['cped'],
    "netī": ['mw'],
    "netṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "netṛmat": ['mw'],
    "netṛtva": ['cae', 'mw'],
    "nevala": ['bhs'],
    "nevalla": ['mw'],
    "nevasaññanāsañña": ['cped'],
    "nevasaññanāsaññāyatana": ['cped'],
    "nevasaññīnāsaññī(n)": ['cped'],
    "nevatthita": ['bhs'],
    "nevāpika": ['cped'],
    "nevāsika": ['cped'],
    "neya": ['cae', 'ddsa', 'mw'],
    "neyadhī": ['mw'],
    "neyapāla": ['mw'],
    "neyya": ['cped'],
    "neyyattha": ['cped'],
    "neyārtha": ['bhs', 'cae', 'mw'],
    "neyārthaka": ['cae', 'mw'],
    "neyārthakatva": ['mw'],
    "neyārthakatā": ['mw'],
    "neyārthatva": ['mw'],
    "neyārthatā": ['mw'],
    "neḷa": ['cped'],
    "neṣ": ['ap90', 'mw'],
    "neṣa": ['gra', 'mw'],
    "neṣat": ['ddsa'],
    "neṣatamais": ['mw'],
    "neṣaṇi": ['mw'],
    "neṣṭa": ['cae'],
    "neṣṭodgātārau": ['mw'],
    "neṣṭra": ['cae', 'gra', 'mw'],
    "neṣṭrīya": ['ddsa', 'mw'],
    "neṣṭu": ['mw'],
    "neṣṭuḥ": ['ap90'],
    "neṣṭā": ['mw'],
    "neṣṭāpotārau": ['mw'],
    "neṣṭṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "neṣṭṛprayoga": ['mw'],
    "neṣṭṛtvaprayoga": ['mw'],
    "nhatvā": ['cped'],
    "nhāna": ['cped'],
    "nhānīya": ['cped'],
    "nhāpaka": ['cped'],
    "nhāpana": ['cped'],
    "nhāpayati": ['cped'],
    "nhāpesuṁ": ['cped'],
    "nhāpetabba": ['cped'],
    "nhāpeti": ['cped'],
    "nhāpetvā": ['cped'],
    "nhāpita": ['cped'],
    "nhāru": ['cped'],
    "nhārudaddula": ['cped'],
    "nhāta": ['cped'],
    "nhātaka": ['cped'],
    "nhātvā": ['cped'],
    "nhāyamāna": ['cped'],
    "nhāyanta": ['cped'],
    "nhāyati": ['cped'],
    "nhāyitabba": ['cped'],
    "nhāyituṁ": ['cped'],
    "nhāyitvā": ['cped'],
    "nhāyiṁsu": ['cped'],
    "ni": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nia": ['gra'],
    "niac": ['gra'],
    "niartha": ['gra'],
    "niayana": ['gra'],
    "niañcana": ['gra'],
    "nibaddha": ['ap90', 'bhs', 'cae', 'mw'],
    "nibaddhatelaka": ['cped'],
    "nibaddhavya": ['mw'],
    "nibala": ['mw'],
    "nibanddhṛ": ['cae', 'ddsa', 'mw'],
    "nibandh": ['mw'],
    "nibandha": ['cae', 'mw'],
    "nibandhacandrodaya": ['mw'],
    "nibandhadāna": ['mw'],
    "nibandhaka": ['mw'],
    "nibandhana": ['cae', 'mw'],
    "nibandhanagrantha": ['mw'],
    "nibandhanaka": ['mw'],
    "nibandhanavanīta": ['mw'],
    "nibandhanī": ['mw'],
    "nibandhanīya": ['mw'],
    "nibandharāja": ['mw'],
    "nibandhasarvasva": ['mw'],
    "nibandhasaṃgraha": ['mw'],
    "nibandhasāra": ['mw'],
    "nibandhatattvadīpa": ['mw'],
    "nibandhati": ['cped'],
    "nibandhavivṛtiyojanā": ['mw'],
    "nibandhaśiromaṇyuktanirṇaya": ['mw'],
    "nibandhika": ['mw'],
    "nibandhin": ['cae', 'mw'],
    "nibandhita": ['mw'],
    "nibarhaṇa": ['ap90', 'cae', 'mw'],
    "nibarhita": ['mw'],
    "nibarhitāṃhas": ['mw'],
    "nibaṃddhṛ": ['ap90'],
    "nibaṃdh": ['ap90'],
    "nibaṃdhanaṃ": ['ap90'],
    "nibaṃdhanī": ['ap90'],
    "nibaṃdhaḥ": ['ap90'],
    "nibaṃdhin": ['ap90'],
    "nibbahati": ['cped'],
    "nibbajjaya(t)": ['cped'],
    "nibbakosa": ['cped'],
    "nibbandhati": ['cped'],
    "nibbasana": ['cped'],
    "nibbatta": ['cped'],
    "nibbattabīja": ['cped'],
    "nibbattati": ['cped'],
    "nibbattayati": ['cped'],
    "nibbattetabba": ['cped'],
    "nibbatteti": ['cped'],
    "nibbattetuṁ": ['cped'],
    "nibbattetvā": ['cped'],
    "nibbatti": ['cped'],
    "nibbattitvā": ['cped'],
    "nibbaṭṭeti": ['cped'],
    "nibbedha": ['cped'],
    "nibbedhabhāgiya": ['cped'],
    "nibbedhika": ['cped'],
    "nibbematika": ['cped'],
    "nibbenjanīya": ['cped'],
    "nibbesa": ['cped'],
    "nibbeṭhana": ['cped'],
    "nibbeṭhayati": ['cped'],
    "nibbeṭhenta": ['cped'],
    "nibbeṭhetabba": ['cped'],
    "nibbeṭheti": ['cped'],
    "nibbeṭhiyamāna": ['cped'],
    "nibbhijjha": ['cped'],
    "nibbidā": ['cped'],
    "nibbijja": ['cped'],
    "nibbijjhati": ['cped'],
    "nibbinda": ['cped'],
    "nibbinda(t)": ['cped'],
    "nibbindamāna": ['cped'],
    "nibbindanta": ['cped'],
    "nibbindati": ['cped'],
    "nibbinditvā": ['cped'],
    "nibbinna": ['cped'],
    "nibbinnarūpa": ['cped'],
    "nibbisa": ['cped'],
    "nibbisamāna": ['cped'],
    "nibbisati": ['cped'],
    "nibbiṇṇa": ['cped'],
    "nibbiṭṭha": ['cped'],
    "nibbiṭṭharājabhaṭa": ['cped'],
    "nibbuddha": ['cped'],
    "nibbujjhati": ['cped'],
    "nibbusita": ['cped'],
    "nibbuta": ['cped'],
    "nibbuti": ['cped'],
    "nibbuyhamāna": ['cped'],
    "nibbuyhati": ['cped'],
    "nibbāhapetva": ['cped'],
    "nibbāhetvā": ['cped'],
    "nibbāhi": ['cped'],
    "nibbāna": ['cped'],
    "nibbānadhātu": ['cped'],
    "nibbānagama": ['cped'],
    "nibbānagamana": ['cped'],
    "nibbānagami(n)": ['cped'],
    "nibbānaninna": ['cped'],
    "nibbānapabbhāra": ['cped'],
    "nibbānapaṭisaṁyutta": ['cped'],
    "nibbānapoṇa": ['cped'],
    "nibbānogadha": ['cped'],
    "nibbānogadha-gāmi(n)": ['cped'],
    "nibbāpana": ['cped'],
    "nibbāpayati": ['cped'],
    "nibbāpesi": ['cped'],
    "nibbāpesuṁ": ['cped'],
    "nibbāpetabba": ['cped'],
    "nibbāpeti": ['cped'],
    "nibbāpetuṁ": ['cped'],
    "nibbāpetvā": ['cped'],
    "nibbāti": ['cped'],
    "nibbāyamāna": ['cped'],
    "nibbāyati": ['cped'],
    "nibbāyi": ['cped'],
    "nibha": ['ap90', 'cae', 'ddsa', 'mw'],
    "nibhal": ['ap90', 'mw'],
    "nibhanakti": ['bhs'],
    "nibhartsana": ['mw'],
    "nibhartsayat": ['mw'],
    "nibhasad": ['mw'],
    "nibhatā": ['mw'],
    "nibhañj": ['mw'],
    "nibhañjana": ['mw'],
    "nibhid": ['mw'],
    "nibhraṃś": ['mw'],
    "nibhuj": ['mw'],
    "nibhunakti": ['bhs'],
    "nibhā": ['bhs'],
    "nibhālana": ['mw'],
    "nibhālanaṃ": ['ap90'],
    "nibhūta": ['ap90', 'mw'],
    "nibhūyapa": ['mw'],
    "nibhṛta": ['ap90', 'cae', 'mw'],
    "nibhṛtam": ['mw'],
    "nibhṛtasthita": ['mw'],
    "nibhṛtordhvakarṇa": ['mw'],
    "nibhṛtā": ['mw'],
    "nibhṛtācāra": ['mw'],
    "nibhṛtāgata": ['mw'],
    "nibhṛtārtha": ['mw'],
    "nibhṛtātman": ['mw'],
    "nibhṛtīkṛ": ['mw'],
    "nibhṛṣṭa": ['mw'],
    "nibirīśa": ['mw'],
    "nibiḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "nibiḍay": ['cae'],
    "nibiḍaya": ['ddsa', 'mw'],
    "nibiḍita": ['mw'],
    "nibiḍīkṛ": ['mw'],
    "niboddhavya": ['ddsa', 'mw'],
    "niboddhṛ": ['mw'],
    "nibodhaḥ": ['ap90'],
    "nibodheti": ['cped'],
    "nibudh": ['ap90', 'mw'],
    "nibusīkṛta": ['mw'],
    "nibādh": ['mw'],
    "nibādha": ['gra', 'mw'],
    "nibādhayati": ['cped'],
    "nibāl̤ha": ['mw'],
    "nibāḍha": ['gra', 'mw'],
    "nibṛh": ['mw'],
    "nicaka": ['mw'],
    "nicaknu": ['mw'],
    "nicakrayā": ['cae', 'mw'],
    "nicakrā": ['gra'],
    "nicakṣus": ['mw'],
    "nical": ['mw'],
    "nicamana": ['cae', 'ddsa', 'mw'],
    "nicandra": ['mw'],
    "nicaya": ['cae', 'cped', 'mw'],
    "nicayagulma": ['mw'],
    "nicayaka": ['mw'],
    "nicayaḥ": ['ap90'],
    "nicayin": ['ap90', 'mw'],
    "nicayodarin": ['mw'],
    "nicaṅkuṇa": ['mw'],
    "nicca": ['cped'],
    "niccabhattaka": ['cped'],
    "niccabhattika": ['cped'],
    "niccaggini": ['cped'],
    "niccaggini(n)": ['cped'],
    "niccakappaṁ": ['cped'],
    "niccanavaka": ['cped'],
    "niccaṁ": ['cped'],
    "niccharanta": ['cped'],
    "niccharati": ['cped'],
    "nicchavi": ['bhs', 'cped', 'mw'],
    "nicchaviḥ": ['ap90'],
    "nicchayaṁ": ['cped'],
    "nicchayena": ['cped'],
    "nicchayā": ['cped'],
    "niccheda": ['mw'],
    "nicchedaḥ": ['ap90'],
    "nicchedeti": ['cped'],
    "niccheyya": ['cped'],
    "nicchidra": ['mw'],
    "nicchivi": ['ddsa', 'mw'],
    "nicchiviḥ": ['ap90'],
    "nicchodeti": ['cped'],
    "nicchoṭeti": ['cped'],
    "nicchuddha": ['cped'],
    "nicchādeti": ['cped'],
    "nicchārayati": ['cped'],
    "nicchāresi": ['cped'],
    "nicchāreta(r)": ['cped'],
    "nicchāreti": ['cped'],
    "nicchāta": ['cped'],
    "nicekāya": ['mw'],
    "niceru": ['cae', 'gra', 'mw'],
    "nicetṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "niceya": ['cae', 'mw'],
    "nici": ['ap90', 'mw'],
    "nicikī": ['ap90', 'mw'],
    "nicira": ['cae', 'gra', 'mw'],
    "nicita": ['ap90', 'cae', 'mw'],
    "nicitā": ['mw'],
    "nicola": ['cae', 'mw'],
    "nicolaka": ['mw'],
    "nicolakaḥ": ['ap90'],
    "nicolaḥ": ['ap90'],
    "nicud": ['mw'],
    "nicula": ['cae', 'mw'],
    "niculaka": ['cae', 'mw'],
    "niculakaṃ": ['ap90'],
    "niculaḥ": ['ap90'],
    "niculita": ['mw'],
    "nicumpuṇa": ['gra', 'mw'],
    "nicuṃpuṇaḥ": ['ap90'],
    "nicuṅkuṇa": ['mw'],
    "nicāy": ['mw'],
    "nicāya": ['mw'],
    "nicāyaḥ": ['ap90'],
    "nicāṅkuṇa": ['mw'],
    "nicūla": ['mw'],
    "nicūta": ['bhs'],
    "nicṛt": ['cae', 'mw'],
    "nid": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nida": ['ap90', 'mw'],
    "nidadru": ['mw'],
    "nidadruḥ": ['ap90'],
    "nidah": ['mw'],
    "nidahati": ['bhs', 'cped'],
    "nidahitabba": ['cped'],
    "nidahitvā": ['cped'],
    "nidarśaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "nidarśana": ['ap90', 'bhs', 'cae', 'mw'],
    "nidarśanatva": ['mw'],
    "nidarśanā": ['mw'],
    "nidarśanārtham": ['mw'],
    "nidarśayitar": ['bhs'],
    "nidarśayitavya": ['mw'],
    "nidarśin": ['cae', 'mw'],
    "nidarśita": ['mw'],
    "nidassana": ['cped'],
    "nidassayati": ['cped'],
    "nidassayi": ['cped'],
    "nidasseti": ['cped'],
    "nidatta": ['mw'],
    "nidaśa": ['bhs'],
    "nidaṁsayati": ['cped'],
    "nidaṁsayi": ['cped'],
    "nidaṁseti": ['cped'],
    "nidaṇḍa": ['mw'],
    "niddara": ['cped'],
    "niddassa": ['cped'],
    "niddesa": ['cped'],
    "niddhamana": ['cped'],
    "niddhamaniya": ['cped'],
    "niddhamati": ['cped'],
    "niddhamitvāna": ['cped'],
    "niddhanta": ['cped'],
    "niddhantakasāvamoha": ['cped'],
    "niddhantamala": ['cped'],
    "niddhota": ['cped'],
    "niddhovati": ['cped'],
    "niddhuniṁsu": ['cped'],
    "niddhunāti": ['cped'],
    "niddhūnāti": ['cped'],
    "niddisati": ['cped'],
    "niddisi": ['cped'],
    "niddisitabba": ['cped'],
    "niddiṭṭha": ['cped'],
    "niddā": ['cped'],
    "niddākilamathapaṭivinodana": ['cped'],
    "niddāna": ['cped'],
    "niddāpetabba": ['cped'],
    "niddāyita(r)": ['cped'],
    "niddāyitabba": ['cped'],
    "nideśa": ['cae', 'mw'],
    "nideśabhāj": ['mw'],
    "nideśakārin": ['cae', 'mw'],
    "nideśakṛt": ['cae', 'mw'],
    "nideśavartin": ['cae', 'mw'],
    "nideśaḥ": ['ap90'],
    "nideśe": ['mw'],
    "nideśin": ['ap90', 'mw'],
    "nideśinī": ['mw'],
    "nideśita": ['bhs'],
    "nideśya": ['mw'],
    "nideṣṭṛ": ['mw'],
    "nidhana": ['ap90', 'cae', 'ddsa', 'mw'],
    "nidhanabhūta": ['mw'],
    "nidhanakriyā": ['mw'],
    "nidhanakāma": ['mw'],
    "nidhanakārin": ['mw'],
    "nidhanakṛta": ['mw'],
    "nidhanapati": ['mw'],
    "nidhanasūtra": ['mw'],
    "nidhanasūtravṛtti": ['mw'],
    "nidhanatā": ['ap90', 'ddsa', 'mw'],
    "nidhanavat": ['mw'],
    "nidhanavāda": ['mw'],
    "nidhanottama": ['mw'],
    "nidhanā": ['mw'],
    "nidheti": ['cped'],
    "nidheya": ['cae', 'mw'],
    "nidhi": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nidhibhṛt": ['mw'],
    "nidhidatta": ['mw'],
    "nidhidīpikā": ['mw'],
    "nidhigopa": ['mw'],
    "nidhiguhyakādhipa": ['mw'],
    "nidhimat": ['gra', 'mw'],
    "nidhimaya": ['mw'],
    "nidhinātha": ['mw'],
    "nidhipa": ['cae', 'mw'],
    "nidhipati": ['cae', 'mw'],
    "nidhipatidatta": ['mw'],
    "nidhiprabhu": ['mw'],
    "nidhipā": ['cae', 'mw'],
    "nidhipāla": ['cae', 'mw'],
    "nidhipālita": ['mw'],
    "nidhirāma": ['mw'],
    "nidhivāda": ['mw'],
    "nidhivāsa": ['mw'],
    "nidhiḥ": ['ap90'],
    "nidhruva": ['mw'],
    "nidhruvi": ['cae', 'ddsa', 'gra', 'mw'],
    "nidhunāti": ['cped'],
    "nidhuvana": ['cae', 'ddsa', 'mw'],
    "nidhuvanaṃ": ['ap90'],
    "nidhvaṃs": ['mw'],
    "nidhvāna": ['mw'],
    "nidhvānaḥ": ['ap90'],
    "nidhyai": ['ap90', 'mw'],
    "nidhyapta": ['bhs'],
    "nidhyapti": ['bhs', 'mw'],
    "nidhyarthin": ['cae', 'ddsa', 'mw'],
    "nidhyāna": ['bhs', 'mw'],
    "nidhyānaṃ": ['ap90'],
    "nidhyāpaka": ['bhs'],
    "nidhyāpayati": ['bhs'],
    "nidhyāpti": ['bhs'],
    "nidhyāta": ['ap90', 'bhs', 'mw'],
    "nidhā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nidhāna": ['cae', 'gra', 'mw'],
    "nidhānaka": ['mw'],
    "nidhānakumbha": ['mw'],
    "nidhānakusala": ['cped'],
    "nidhānatā": ['mw'],
    "nidhānavatī": ['cped'],
    "nidhānaṃ": ['ap90'],
    "nidhāneśa": ['mw'],
    "nidhānia": ['gra'],
    "nidhānya": ['gra', 'mw'],
    "nidhānī": ['mw'],
    "nidhānīkṛ": ['mw'],
    "nidhāpaka": ['mw'],
    "nidhāpati": ['gra', 'mw'],
    "nidhāpeti": ['cped'],
    "nidhāpya": ['mw'],
    "nidhāraya": ['gra', 'mw'],
    "nidhātavya": ['mw'],
    "nidhātos": ['cae', 'mw'],
    "nidhātṛ": ['gra', 'mw'],
    "nidhāv": ['mw'],
    "nidhāya": ['cped', 'mw'],
    "nidhāyam": ['mw'],
    "nidhīśa": ['cae', 'mw'],
    "nidhīśatva": ['mw'],
    "nidhīśvara": ['mw'],
    "nidhū": ['mw'],
    "nidhūpita": ['bhs'],
    "nidhṛ": ['mw'],
    "nidhṛti": ['mw'],
    "nididhyāsana": ['cae', 'mw'],
    "nididhyāsaḥ": ['ap90'],
    "nididhyāsitavya": ['cae', 'mw'],
    "nididhyāsu": ['cae', 'mw'],
    "nididrāsu": ['mw'],
    "nidigdha": ['ap90', 'cae', 'mw'],
    "nidigdhikā": ['mw'],
    "nidigdhā": ['mw'],
    "nidita": ['cae', 'mw'],
    "nidiś": ['ap90', 'mw'],
    "nidiṣṭa": ['ap90', 'mw'],
    "nidrai": ['mw'],
    "nidrita": ['ap90', 'cae', 'mw'],
    "nidritavat": ['mw'],
    "nidrā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nidrābhaṅga": ['mw'],
    "nidrābhibhūta": ['mw'],
    "nidrācaura": ['cae', 'mw'],
    "nidrādaridra": ['mw'],
    "nidrādaridrīkṛ": ['mw'],
    "nidrādruh": ['mw'],
    "nidrāgama": ['cae', 'mw'],
    "nidrākara": ['mw'],
    "nidrākṣa": ['bhs'],
    "nidrākṣaṇa": ['mw'],
    "nidrālasa": ['cae', 'mw'],
    "nidrālasya": ['cae', 'mw'],
    "nidrālu": ['ap90', 'cae', 'ddsa', 'mw'],
    "nidrālutva": ['mw'],
    "nidrāmaya": ['mw'],
    "nidrāmudrita": ['mw'],
    "nidrāmudrā": ['mw'],
    "nidrāndha": ['mw'],
    "nidrāntarita": ['ddsa', 'mw'],
    "nidrāsaṃjanana": ['mw'],
    "nidrāt": ['mw'],
    "nidrātura": ['mw'],
    "nidrāvaśa": ['mw'],
    "nidrāvṛkṣa": ['mw'],
    "nidrāyamāṇa": ['mw'],
    "nidrāyoga": ['mw'],
    "nidrāṇa": ['ap90', 'cae', 'mw'],
    "niduśa": ['mw'],
    "nidyamāna": ['mw'],
    "nidā": ['cae', 'gra', 'mw'],
    "nidāgha": ['cae', 'mw'],
    "nidāghadhāman": ['mw'],
    "nidāghakara": ['mw'],
    "nidāghakāla": ['mw'],
    "nidāgharuci": ['mw'],
    "nidāghasindhu": ['mw'],
    "nidāghavārṣika": ['mw'],
    "nidāghaḥ": ['ap90'],
    "nidāghāvadhi": ['mw'],
    "nidāna": ['bhs', 'cae', 'cped', 'gra', 'mw'],
    "nidānapradīpa": ['mw'],
    "nidānasaṃgraha": ['mw'],
    "nidānasthāna": ['mw'],
    "nidānasūtra": ['cae', 'mw'],
    "nidānatattva": ['mw'],
    "nidānavat": ['mw'],
    "nidānavid": ['mw'],
    "nidānaṃ": ['ap90'],
    "nidānena": ['mw'],
    "nidānārthakara": ['mw'],
    "nidātṛ": ['cae', 'gra', 'mw'],
    "nidī": ['mw'],
    "nidṛś": ['ap90', 'mw'],
    "niga": ['mw'],
    "nigacchati": ['cped'],
    "nigad": ['ap90', 'mw'],
    "nigada": ['cae', 'ddsa', 'mw'],
    "nigadana": ['mw'],
    "nigadavyākhyāta": ['mw'],
    "nigadaya": ['mw'],
    "nigadaḥ": ['ap90'],
    "nigadita": ['ap90', 'mw'],
    "nigaditavat": ['mw'],
    "nigaditin": ['mw'],
    "nigai": ['mw'],
    "nigal": ['mw'],
    "nigala": ['bhs', 'mw'],
    "nigalana": ['mw'],
    "nigalaḥ": ['ap90'],
    "nigam": ['ap90', 'mw'],
    "nigama": ['bhs', 'cae', 'cped', 'mw'],
    "nigamabandhana": ['cped'],
    "nigamaghāta": ['cped'],
    "nigamajña": ['mw'],
    "nigamakalpadruma": ['mw'],
    "nigamakalpalatā": ['mw'],
    "nigamakalpasāra": ['mw'],
    "nigamalatā": ['mw'],
    "nigamana": ['cae', 'mw'],
    "nigamanaṃ": ['ap90'],
    "nigamapariśiṣṭa": ['mw'],
    "nigamasthāna": ['mw'],
    "nigamasāra": ['mw'],
    "nigamatattvasāra": ['mw'],
    "nigamaḥ": ['ap90'],
    "nigamin": ['ap90', 'mw'],
    "nigamākhyakośa": ['mw'],
    "nigamāntārtharatnākara": ['mw'],
    "nigantavya": ['cae', 'mw'],
    "nigantha": ['cped'],
    "niganthi": ['cped'],
    "nigara": ['mw'],
    "nigaraḥ": ['ap90'],
    "nigaraṇa": ['cae', 'mw'],
    "nigaraṇaṃ": ['ap90'],
    "nigarh": ['mw'],
    "nigarhaṇīya": ['bhs'],
    "nigarjana": ['bhs'],
    "nigarjati": ['bhs'],
    "nigarjita": ['bhs'],
    "nigaḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "nigaḍakṣveḍana": ['mw'],
    "nigaḍana": ['cae', 'mw'],
    "nigaḍanaṃ": ['ap90'],
    "nigaḍapūrita": ['cae'],
    "nigaḍay": ['cae'],
    "nigaḍaya": ['ddsa'],
    "nigaḍayati": ['ap90'],
    "nigaḍita": ['ap90', 'mw'],
    "nigaṇa": ['mw'],
    "nigaṇaḥ": ['ap90'],
    "nigaṇṭha": ['cped'],
    "nigaṇṭhaputta": ['cped'],
    "nigaṇṭhigabbha": ['cped'],
    "nigaṇṭhī": ['cped'],
    "nigaṇṭhūposata": ['cped'],
    "niggaha": ['cped'],
    "niggahaṇa": ['cped'],
    "niggahessati": ['cped'],
    "niggahetabba": ['cped'],
    "niggahetvā": ['cped'],
    "niggahissati": ['cped'],
    "niggahita": ['cped'],
    "niggahīta": ['cped'],
    "niggantha": ['cped'],
    "niggata": ['cped'],
    "niggayha": ['cped'],
    "niggayhavādi(n)": ['cped'],
    "niggaṇhaṇa": ['cped'],
    "niggaṇhissati": ['cped'],
    "niggaṇhāti": ['cped'],
    "nigghosa": ['cped'],
    "nigghāta": ['cped'],
    "niggāhaka": ['cped'],
    "nigha": ['ap90', 'bhs', 'cped', 'mw'],
    "nigharṣa": ['cae', 'ddsa', 'mw'],
    "nigharṣaḥ": ['ap90'],
    "nigharṣaṇa": ['mw'],
    "nighasa": ['mw'],
    "nighasaḥ": ['ap90'],
    "nighaṁsati": ['cped'],
    "nighaṃṭuḥ": ['ap90'],
    "nighaṇṭa": ['bhs', 'ddsa', 'mw'],
    "nighaṇṭi": ['mw'],
    "nighaṇṭikā": ['mw'],
    "nighaṇṭu": ['cae', 'mw'],
    "nighaṇṭubhāṣya": ['mw'],
    "nighaṇṭukhaṇḍanirvacana": ['mw'],
    "nighaṇṭukośa": ['mw'],
    "nighaṇṭurāja": ['mw'],
    "nighaṇṭusamaya": ['mw'],
    "nighaṇṭusaṃgrahanidāna": ['mw'],
    "nighaṇṭusāra": ['mw'],
    "nighaṇṭuśeṣa": ['mw'],
    "nighna": ['ap90', 'cae', 'mw'],
    "nighnaka": ['mw'],
    "nighnamāna": ['mw'],
    "nighnat": ['mw'],
    "nighnatā": ['mw'],
    "nighnāna": ['mw'],
    "nighoṣa": ['bhs'],
    "nighuṣ": ['mw'],
    "nighuṣṭa": ['mw'],
    "nighuṣṭaṃ": ['ap90'],
    "nighānigha": ['mw'],
    "nighāta": ['cae', 'cped', 'mw'],
    "nighātam": ['mw'],
    "nighātaḥ": ['ap90'],
    "nighāti": ['mw'],
    "nighātin": ['cae', 'mw'],
    "nighātiḥ": ['ap90'],
    "nighṛṣ": ['ap90', 'mw'],
    "nighṛṣva": ['ap90', 'mw'],
    "nighṛṣṭa": ['ap90', 'mw'],
    "nigiraṇa": ['cae', 'mw'],
    "nigrabhītṛ": ['cae', 'mw'],
    "nigrah": ['ap90', 'mw'],
    "nigraha": ['cae', 'mw'],
    "nigrahasthāna": ['mw'],
    "nigrahasthānasūtraṭīkā": ['mw'],
    "nigrahastotra": ['mw'],
    "nigrahasādhana": ['mw'],
    "nigrahaḥ": ['ap90'],
    "nigrahaṇa": ['ap90', 'cae', 'mw'],
    "nigrahāṣṭaka": ['mw'],
    "nigrahītavya": ['cae', 'mw'],
    "nigrahītṛ": ['cae', 'mw'],
    "nigranth": ['mw'],
    "nigrantha": ['bhs'],
    "nigranthana": ['mw'],
    "nigranthi": ['mw'],
    "nigraṃthanaṃ": ['ap90'],
    "nigrodha": ['cped'],
    "nigrodhaparimaṇḍala": ['cped'],
    "nigrābha": ['cae', 'mw'],
    "nigrābhya": ['mw'],
    "nigrāha": ['mw'],
    "nigrāhaka": ['mw'],
    "nigrāhakatva": ['mw'],
    "nigrāhaḥ": ['ap90'],
    "nigrāhya": ['cae', 'mw'],
    "nigu": ['ap90', 'mw'],
    "niguh": ['mw'],
    "nigup": ['mw'],
    "nigut": ['cae', 'gra', 'mw'],
    "niguṇa": ['bhs'],
    "nigā": ['mw'],
    "nigāda": ['mw'],
    "nigādin": ['mw'],
    "nigādya": ['mw'],
    "nigāla": ['mw'],
    "nigālaka": ['ap90', 'mw'],
    "nigālavat": ['mw'],
    "nigālaḥ": ['ap90'],
    "nigāra": ['mw'],
    "nigāraka": ['ap90', 'mw'],
    "nigāḷhika": ['cped'],
    "nigāḷhita": ['cped'],
    "nigīrṇa": ['ap90', 'mw'],
    "nigīrṇatva": ['mw'],
    "nigīrṇavat": ['mw'],
    "nigīta": ['mw'],
    "nigūhaka": ['mw'],
    "nigūhana": ['cae', 'mw'],
    "nigūhanaṃ": ['ap90'],
    "nigūhanīya": ['mw'],
    "nigūhin": ['mw'],
    "nigūḍha": ['ap90', 'cae', 'mw'],
    "nigūḍhacārin": ['mw'],
    "nigūḍhaka": ['mw'],
    "nigūḍhakārya": ['mw'],
    "nigūḍham": ['mw'],
    "nigūḍhaniścaya": ['mw'],
    "nigūḍharoman": ['mw'],
    "nigūḍhatara": ['mw'],
    "nigūḍhārtha": ['mw'],
    "nigūḍhārthadīpikā": ['mw'],
    "nigūḍhārthamañjūṣikā": ['mw'],
    "nigṛhya": ['mw'],
    "nigṛhīta": ['ap90', 'mw'],
    "nigṛhīti": ['cae', 'mw'],
    "nigṛhītiḥ": ['ap90'],
    "nigṛhītṛ": ['mw'],
    "nigṝ": ['ap90', 'mw'],
    "nih": ['mw'],
    "nihacca": ['cped'],
    "nihan": ['ap90', 'mw'],
    "nihanana": ['mw'],
    "nihananaṃ": ['ap90'],
    "nihanati": ['cped'],
    "nihanitabba": ['cped'],
    "nihantavya": ['cae', 'mw'],
    "nihanti": ['cped'],
    "nihantvā": ['cped'],
    "nihantṛ": ['cae', 'mw'],
    "niharati": ['cped'],
    "nihata": ['ap90', 'cped', 'mw'],
    "nihatabhūyiṣṭha": ['mw'],
    "nihatadhikaraṇa": ['cped'],
    "nihatadhīra": ['bhs'],
    "nihatamāna": ['cped'],
    "nihatapaccāmitta": ['cped'],
    "nihatasena": ['ddsa', 'mw'],
    "nihatatejas": ['bhs'],
    "nihatatva": ['mw'],
    "nihatārtha": ['mw'],
    "nihatārthatva": ['mw'],
    "nihatārthatā": ['mw'],
    "nihatāṣṭra": ['mw'],
    "nihava": ['mw'],
    "nihavaḥ": ['ap90'],
    "nihaṃtṛ": ['ap90'],
    "nihi": ['cped'],
    "nihiniṁ": ['cped'],
    "nihita": ['ap90', 'cae', 'cped', 'mw'],
    "nihitabhāga": ['mw'],
    "nihitadaṇḍa": ['cped', 'mw'],
    "nihitaguṇodita": ['bhs'],
    "nihitaka": ['bhs'],
    "nihitanayana": ['mw'],
    "nihiṃsana": ['mw'],
    "nihiṃsanaṃ": ['ap90'],
    "nihnava": ['cae', 'mw'],
    "nihnavanaṃ": ['ap90'],
    "nihnavavādin": ['mw'],
    "nihnavaḥ": ['ap90'],
    "nihnavottara": ['mw'],
    "nihnu": ['ap90', 'mw'],
    "nihnuta": ['ap90', 'cae', 'mw'],
    "nihnuti": ['cae', 'mw'],
    "nihnutiḥ": ['ap90'],
    "nihnuvana": ['mw'],
    "nihnuvāna": ['mw'],
    "nihrād": ['mw'],
    "nihrāda": ['mw'],
    "nihrādavat": ['mw'],
    "nihrādaḥ": ['ap90'],
    "nihrādin": ['mw'],
    "nihrādita": ['mw'],
    "nihuhuṃka": ['bhs'],
    "nihve": ['mw'],
    "nihā": ['mw'],
    "nihākā": ['ap90', 'cae', 'gra', 'mw'],
    "nihāra": ['ap90', 'mw'],
    "nihārin": ['mw'],
    "nihīna": ['ap90', 'cped', 'mw'],
    "nihīnasevi(n)": ['cped'],
    "nihīnatara": ['mw'],
    "nihīnataraka": ['bhs'],
    "nihīnavarṇa": ['mw'],
    "nihīyati": ['cped'],
    "nihṛ": ['mw'],
    "nihṛṣ": ['mw'],
    "nij": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nija": ['ap90', 'cae', 'ddsa', 'mw'],
    "nijadhṛti": ['mw'],
    "nijaghni": ['cae', 'gra', 'mw'],
    "nijaghāsa": ['mw'],
    "nijakarmabandhana": ['mw'],
    "nijakarman": ['mw'],
    "nijalābhapūrṇa": ['mw'],
    "nijamukta": ['mw'],
    "nijapakṣa": ['mw'],
    "nijasva": ['mw'],
    "nijavinoda": ['mw'],
    "nijaśatru": ['mw'],
    "niji": ['mw'],
    "nijighṛkṣayat": ['mw'],
    "nijigiṁsana": ['cped'],
    "nijigiṁsanaka": ['cped'],
    "nijigiṁsanatā": ['cped'],
    "nijigiṁsita(r)": ['cped'],
    "nijigīsana": ['cped'],
    "nijigīsanaka": ['cped'],
    "nijigīsanatā": ['cped'],
    "nijigīsita(r)": ['cped'],
    "nijihvika": ['mw'],
    "nijimat": ['mw'],
    "nijinitu": ['bhs'],
    "nijjara": ['cped'],
    "nijjarayati": ['cped'],
    "nijjaretabba": ['cped'],
    "nijjareti": ['cped'],
    "nijjarā": ['cped'],
    "nijjhapana": ['cped'],
    "nijjhapayati": ['cped'],
    "nijjhapeti": ['cped'],
    "nijjhatti": ['cped'],
    "nijjhattibala": ['cped'],
    "nijjhāma": ['cped'],
    "nijjhāna": ['cped'],
    "nijjhāpana": ['cped'],
    "nijjhāpaniya": ['cped'],
    "nijjhāpayati": ['cped'],
    "nijjhāpetabba": ['cped'],
    "nijjhāpeti": ['cped'],
    "nijjhāti": ['cped'],
    "nijjhāya(t)": ['cped'],
    "nijjhāyanta": ['cped'],
    "nijjhāyati": ['cped'],
    "nijjhāyi": ['cped'],
    "nijjiretabba": ['cped'],
    "nijjireti": ['cped'],
    "nijjiṇṇa": ['cped'],
    "nijuhnūṣu": ['mw'],
    "nijur": ['cae', 'ddsa', 'gra', 'mw'],
    "nijākṣaramīmāṃsā": ['mw'],
    "nijānandānubhūtiprakaraṇa": ['mw'],
    "nijānukā": ['mw'],
    "nijārtham": ['mw'],
    "nijātmānandanātha": ['mw'],
    "nijūrv": ['mw'],
    "nika": ['mw'],
    "nikacca": ['cped'],
    "nikakṣa": ['cae', 'ddsa', 'mw'],
    "nikam": ['ap90', 'mw'],
    "nikanta": ['cped'],
    "nikanti": ['cped'],
    "nikara": ['cae', 'ddsa', 'mw'],
    "nikaraḥ": ['ap90'],
    "nikaroti": ['cped'],
    "nikartana": ['mw'],
    "nikartanaṃ": ['ap90'],
    "nikartavya": ['mw'],
    "nikartu": ['mw'],
    "nikartṛ": ['mw'],
    "nikaruṇa": ['bhs'],
    "nikarṣa": ['cae', 'mw'],
    "nikarṣaṇa": ['ap90', 'mw'],
    "nikarṣaṇaṃ": ['ap90'],
    "nikasa": ['mw'],
    "nikasaḥ": ['ap90'],
    "nikasātmaja": ['mw'],
    "nikata": ['cped'],
    "nikathitin": ['mw'],
    "nikati": ['cped'],
    "nikaṇṇikāṁ": ['cped'],
    "nikaṇṭha": ['bhs'],
    "nikaṇṭhaka": ['bhs'],
    "nikaṣ": ['mw'],
    "nikaṣa": ['cae', 'mw'],
    "nikaṣagrāvan": ['mw'],
    "nikaṣapāṣāṇa": ['mw'],
    "nikaṣaḥ": ['ap90'],
    "nikaṣaṇa": ['cae', 'mw'],
    "nikaṣopala": ['mw'],
    "nikaṣā": ['ap90', 'cae', 'mw'],
    "nikaṣātmaja": ['mw'],
    "nikaṣāya": ['ddsa', 'mw'],
    "nikaṣāyamāna": ['mw'],
    "nikaṣāśman": ['mw'],
    "nikaṭa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "nikaṭaga": ['mw'],
    "nikaṭam": ['mw'],
    "nikaṭastha": ['mw'],
    "nikaṭavartin": ['mw'],
    "nikaṭe": ['mw'],
    "nikaṭāt": ['mw'],
    "nikaṭī": ['mw'],
    "nikaṭībhū": ['ddsa'],
    "nikaṭībhūta": ['mw'],
    "nikaṭībhūya": ['mw'],
    "nikaṭṭha": ['cped'],
    "nikaṭṭhacitta": ['cped'],
    "nikaṭṭhakāya": ['cped'],
    "nikecāya": ['mw'],
    "nikecāyaḥ": ['ap90'],
    "niketa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "niketacārika": ['cped'],
    "niketana": ['cae', 'mw'],
    "niketanaḥ": ['ap90'],
    "niketasāri(n)": ['cped'],
    "niketava(t)": ['cped'],
    "niketaḥ": ['ap90'],
    "niketi(n)": ['cped'],
    "nikhan": ['ap90', 'mw'],
    "nikhanana": ['ddsa', 'mw'],
    "nikhananaṃ": ['ap90'],
    "nikhanati": ['cped'],
    "nikhara": ['mw'],
    "nikharva": ['ap90', 'mw'],
    "nikharvaka": ['mw'],
    "nikharvaṭa": ['mw'],
    "nikharvāda": ['mw'],
    "nikhaḍga": ['bhs'],
    "nikhaṇati": ['cped'],
    "nikhaṇitabba": ['cped'],
    "nikhaṇitvā": ['cped'],
    "nikhaṇiyamāna": ['cped'],
    "nikhaṭvā": ['mw'],
    "nikheya": ['mw'],
    "nikhid": ['mw'],
    "nikhila": ['ap90', 'cae', 'ddsa', 'mw'],
    "nikhilena": ['mw'],
    "nikhilārtha": ['cae'],
    "nikhuryapa": ['mw'],
    "nikhādana": ['cped'],
    "nikhāna": ['mw'],
    "nikhānita": ['mw'],
    "nikhāta": ['ap90', 'cped', 'mw'],
    "nikhātaka": ['mw'],
    "nikilbiṣa": ['cae', 'gra', 'mw'],
    "nikiṇṇa": ['cped'],
    "nikkamadhātu": ['cped'],
    "nikkamati": ['cped'],
    "nikkanta": ['cped'],
    "nikkaruṇā": ['cped'],
    "nikkasava": ['cped'],
    "nikkaḍḍhana": ['cped'],
    "nikkaḍḍhanta": ['cped'],
    "nikkaḍḍhapesi": ['cped'],
    "nikkaḍḍhapeti": ['cped'],
    "nikkaḍḍhati": ['cped'],
    "nikkaḍḍhenta": ['cped'],
    "nikkaḍḍheti": ['cped'],
    "nikkaḍḍhi": ['cped'],
    "nikkaḍḍhita": ['cped'],
    "nikkaḍḍhitabba": ['cped'],
    "nikkaḍḍhitvā": ['cped'],
    "nikkaḍḍhiyamāna": ['cped'],
    "nikkaḍḍhiṁsu": ['cped'],
    "nikkaṇṭaka": ['cped'],
    "nikkaṭa": ['bhs'],
    "nikkaṭṭha": ['cped'],
    "nikkaṭṭhacitta": ['cped'],
    "nikkaṭṭhakāya": ['cped'],
    "nikkhamanta": ['cped'],
    "nikkhamati": ['cped'],
    "nikkhameti": ['cped'],
    "nikkhami": ['cped'],
    "nikkhamitabba": ['cped'],
    "nikkhamitvā": ['cped'],
    "nikkhamitvāna": ['cped'],
    "nikkhamitūna": ['cped'],
    "nikkhamiṁ": ['cped'],
    "nikkhamma": ['cped'],
    "nikkhanati": ['cped'],
    "nikkhanta": ['cped'],
    "nikkhanti": ['cped'],
    "nikkhaṇati": ['cped'],
    "nikkhepa": ['cped'],
    "nikkhepana": ['cped'],
    "nikkhipanta": ['cped'],
    "nikkhipati": ['cped'],
    "nikkhipi": ['cped'],
    "nikkhipita": ['cped'],
    "nikkhipitabba": ['cped'],
    "nikkhipitvā": ['cped'],
    "nikkhipitvāna": ['cped'],
    "nikkhipiṁsu": ['cped'],
    "nikkhippa": ['cped'],
    "nikkhippagāmi(n)": ['cped'],
    "nikkhitta": ['cped'],
    "nikkhāmenta": ['cped'],
    "nikkhāmeti": ['cped'],
    "nikkhāmetvā": ['cped'],
    "nikkhāmita": ['cped'],
    "nikkiṇṇa": ['cped'],
    "nikkuha": ['cped'],
    "nikkujja": ['cped'],
    "nikkujjanā": ['cped'],
    "nikkujjati": ['cped'],
    "nikkujjeti": ['cped'],
    "nikkujjita": ['cped'],
    "nikkujjitabba": ['cped'],
    "nikkujjitvā": ['cped'],
    "nikkāma": ['cped'],
    "nikkāmi": ['cped'],
    "nikkāmin": ['cped'],
    "nikkāraṇa": ['cped'],
    "nikoca": ['cae', 'ddsa', 'mw'],
    "nikocaka": ['mw'],
    "nikocana": ['mw'],
    "nikocanaṃ": ['ap90'],
    "nikothaka": ['mw'],
    "nikośya": ['mw'],
    "nikram": ['mw'],
    "nikramaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "nikramaṇaṃ": ['ap90'],
    "nikrand": ['mw'],
    "nikranda": ['bhs'],
    "nikrandita": ['mw'],
    "nikrīḍ": ['mw'],
    "nikrīḍa": ['mw'],
    "nikta": ['ap90', 'cae', 'mw'],
    "niktahasta": ['gra', 'mw'],
    "nikubbati": ['cped'],
    "nikubja": ['bhs', 'mw'],
    "nikubjana": ['bhs', 'mw'],
    "nikuciti": ['mw'],
    "nikucyakarṇi": ['mw'],
    "nikujja": ['cped'],
    "nikujjanā": ['cped'],
    "nikujjati": ['cped'],
    "nikujjeti": ['cped'],
    "nikujjetvā": ['cped'],
    "nikujjita": ['cped'],
    "nikujjitvā": ['cped'],
    "nikujjiya": ['cped'],
    "nikulīnakā": ['mw'],
    "nikulīnikā": ['ap90'],
    "nikumbha": ['cae', 'mw'],
    "nikumbhila": ['mw'],
    "nikumbhita": ['mw'],
    "nikumbhākhyabīja": ['mw'],
    "nikuramba": ['cae', 'mw'],
    "nikuraṃbaṃ": ['ap90'],
    "nikurumba": ['cae', 'mw'],
    "nikurumbaka": ['cae', 'mw'],
    "nikuruṃbaṃ": ['ap90'],
    "nikuñc": ['mw'],
    "nikuñca": ['mw'],
    "nikuñcaka": ['mw'],
    "nikuñcana": ['mw'],
    "nikuñcita": ['mw'],
    "nikuñja": ['cae', 'ddsa', 'mw'],
    "nikuñjikāmlā": ['mw'],
    "nikuṃbhaḥ": ['ap90'],
    "nikuṃbhilā": ['ap90'],
    "nikuṃcanaḥ": ['ap90'],
    "nikuṃjaḥ": ['ap90'],
    "nikuṇṭhā": ['bhs'],
    "nikuṭṭana": ['mw'],
    "nikvaṇa": ['mw'],
    "nikvaṇaḥ": ['ap90'],
    "nikāma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nikāmabhāmabhāṣya": ['mw'],
    "nikāmadharaṇa": ['mw'],
    "nikāmajala": ['mw'],
    "nikāmakāma": ['mw'],
    "nikāmalābhī(n)": ['cped'],
    "nikāman": ['cae', 'gra', 'mw'],
    "nikāmana": ['mw'],
    "nikāmanaṃ": ['ap90'],
    "nikāmaniraṅkuśa": ['mw'],
    "nikāmasukhin": ['mw'],
    "nikāmatapta": ['mw'],
    "nikāmavarṣa": ['mw'],
    "nikāmavarṣin": ['mw'],
    "nikāmayamāna": ['cped'],
    "nikāmayati": ['cped'],
    "nikāmeti": ['cped'],
    "nikāra": ['ap90', 'cae', 'mw'],
    "nikāraḥ": ['ap90'],
    "nikāraṇa": ['mw'],
    "nikāraṇaṃ": ['ap90'],
    "nikārin": ['cae', 'mw'],
    "nikāsa": ['mw'],
    "nikāvalgā": ['ddsa', 'mw'],
    "nikāya": ['bhs', 'cae', 'cped', 'mw'],
    "nikāyaḥ": ['ap90'],
    "nikāyin": ['mw'],
    "nikāyya": ['mw'],
    "nikāyyaḥ": ['ap90'],
    "nikāyāntarīya": ['bhs', 'mw'],
    "nikāśa": ['cae', 'ddsa', 'mw'],
    "nikāśaḥ": ['ap90'],
    "nikāṇam": ['mw'],
    "nikāṇamakṣi": ['mw'],
    "nikāṣa": ['cae', 'mw'],
    "nikāṣam": ['mw'],
    "nikāṣaḥ": ['ap90'],
    "nikūj": ['mw'],
    "nikūjati": ['cped'],
    "nikūjita": ['mw'],
    "nikūjitavya": ['mw'],
    "nikūla": ['bhs', 'mw'],
    "nikūlavṛkṣa": ['mw'],
    "nikūḍ": ['mw'],
    "nikūṇ": ['mw'],
    "nikūṇita": ['mw'],
    "nikūṭa": ['cped'],
    "nikṛ": ['ap90', 'mw'],
    "nikṛnta": ['bhs'],
    "nikṛntana": ['cae', 'mw'],
    "nikṛntin": ['mw'],
    "nikṛt": ['ap90', 'mw'],
    "nikṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "nikṛtamati": ['mw'],
    "nikṛtaprajña": ['mw'],
    "nikṛti": ['ap90', 'cae', 'mw'],
    "nikṛtijīvana": ['mw'],
    "nikṛtimat": ['mw'],
    "nikṛtin": ['ap90', 'cae', 'mw'],
    "nikṛtiprajña": ['mw'],
    "nikṛtiṃjuṣ": ['mw'],
    "nikṛtta": ['mw'],
    "nikṛttamūla": ['mw'],
    "nikṛtvan": ['cae', 'gra', 'mw'],
    "nikṛtyā": ['mw'],
    "nikṛṃtana": ['ap90'],
    "nikṛṣ": ['ap90', 'mw'],
    "nikṛṣṭa": ['ap90', 'cae', 'mw'],
    "nikṛṣṭabhūta": ['mw'],
    "nikṛṣṭopādhi": ['mw'],
    "nikṛṣṭopādhitā": ['mw'],
    "nikṛṣṭāśaya": ['mw'],
    "nikṛṣṭāśayatā": ['mw'],
    "nikṛṣṭīkṛ": ['mw'],
    "nikṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nikṣa": ['mw'],
    "nikṣatriya": ['mw'],
    "nikṣaṇaṃ": ['ap90'],
    "nikṣepa": ['bhs', 'cae', 'ddsa', 'mw'],
    "nikṣepacintāmaṇi": ['mw'],
    "nikṣepadīpa": ['mw'],
    "nikṣepalipi": ['bhs', 'mw'],
    "nikṣeparakṣā": ['mw'],
    "nikṣepaḥ": ['ap90'],
    "nikṣepaṇa": ['bhs', 'mw'],
    "nikṣepaṇaṃ": ['ap90'],
    "nikṣepin": ['mw'],
    "nikṣepita": ['ap90', 'mw'],
    "nikṣeptṛ": ['ap90', 'cae', 'mw'],
    "nikṣepya": ['cae', 'mw'],
    "nikṣip": ['ap90', 'mw'],
    "nikṣipati": ['bhs'],
    "nikṣipaṇa": ['bhs'],
    "nikṣipta": ['ap90', 'mw'],
    "nikṣiptabhāra": ['mw'],
    "nikṣiptavāda": ['mw'],
    "nikṣubhā": ['ap90', 'mw'],
    "nikṣvid": ['mw'],
    "nikṣā": ['ap90', 'mw'],
    "nil": ['mw'],
    "nilacchesi": ['cped'],
    "nilaccheti": ['cped'],
    "nilacchita": ['cped'],
    "nilamba": ['bhs'],
    "nilambha": ['bhs'],
    "nilapaka": ['bhs'],
    "nilay": ['mw'],
    "nilaya": ['cae', 'ddsa', 'mw'],
    "nilayana": ['cae', 'mw'],
    "nilayanaṃ": ['ap90'],
    "nilayasundara": ['mw'],
    "nilayaḥ": ['ap90'],
    "nilaṅgu": ['mw'],
    "nilihati": ['bhs'],
    "nilimpa": ['mw'],
    "nilimpanirjharī": ['mw'],
    "nilimpapāṃsulā": ['mw'],
    "nilimpikā": ['mw'],
    "nilimpā": ['mw'],
    "nilip": ['mw'],
    "niliṃpaḥ": ['ap90'],
    "niliṃpā": ['ap90'],
    "nillacchesi": ['cped'],
    "nillaccheti": ['cped'],
    "nillacchita": ['cped'],
    "nillehitvā": ['cped'],
    "nilloketabba": ['cped'],
    "nilloketi": ['cped'],
    "nillopa": ['cped'],
    "nillāletvā": ['cped'],
    "nillāḷetvā": ['cped'],
    "nillī": ['cped'],
    "nilup": ['mw'],
    "niluñchita": ['cped'],
    "nilāmbhoja": ['mw'],
    "nilāya": ['mw'],
    "nilāyana": ['mw'],
    "nilāyanakrīḍā": ['mw'],
    "nilāyin": ['mw'],
    "nilāyitā": ['mw'],
    "nilī": ['ap90', 'mw'],
    "nilīna": ['ap90', 'cped', 'mw'],
    "nilīnaka": ['mw'],
    "nilīyamāna": ['mw'],
    "nilīyati": ['bhs'],
    "nima": ['mw'],
    "nimad": ['mw'],
    "nimada": ['mw'],
    "nimadaḥ": ['ap90'],
    "nimagna": ['ap90', 'cae', 'mw'],
    "nimagnaka": ['mw'],
    "nimagnamadhyā": ['cae', 'mw'],
    "nimagnanābhi": ['cae', 'mw'],
    "nimajj": ['mw'],
    "nimajjana": ['cae', 'ddsa', 'mw'],
    "nimajjanasthāna": ['cae'],
    "nimajjanaṃ": ['ap90'],
    "nimajjathu": ['mw'],
    "nimajjathuḥ": ['ap90'],
    "nimajjita": ['mw'],
    "niman": ['mw'],
    "nimantana": ['cped'],
    "nimantayati": ['cped'],
    "nimantayi": ['cped'],
    "nimantesi": ['cped'],
    "nimantetabba": ['cped'],
    "nimanteti": ['cped'],
    "nimantetvā": ['cped'],
    "nimantita": ['cped'],
    "nimantiyamāna": ['cped'],
    "nimantr": ['mw'],
    "nimantraka": ['cae', 'mw'],
    "nimantraṇa": ['cae', 'mw'],
    "nimantraṇaka": ['bhs'],
    "nimantraṇā": ['bhs'],
    "nimantrita": ['mw'],
    "nimantritaka": ['bhs'],
    "nimantrya": ['mw'],
    "nimanyu": ['mw'],
    "nimardaka": ['mw'],
    "nimasj": ['ap90'],
    "nimath": ['mw'],
    "nimaya": ['cae', 'mw'],
    "nimayaḥ": ['ap90'],
    "nimaṃtr": ['ap90'],
    "nimaṃtraṇaṃ": ['ap90'],
    "nimba": ['cae', 'ddsa', 'mw'],
    "nimbabīja": ['cped', 'mw'],
    "nimbadeva": ['mw'],
    "nimbakara": ['mw'],
    "nimbamāla": ['mw'],
    "nimbapañcaka": ['mw'],
    "nimbapaṇṇa": ['cped'],
    "nimbarajas": ['bhs', 'mw'],
    "nimbaraka": ['mw'],
    "nimbataila": ['mw'],
    "nimbataru": ['mw'],
    "nimbavatī": ['mw'],
    "nimbāditya": ['mw'],
    "nimbārka": ['mw'],
    "nimbārkakaravīrārcanavrata": ['mw'],
    "nimbū": ['mw'],
    "nimbūka": ['mw'],
    "nimbūkaphalapānaka": ['mw'],
    "nime": ['mw'],
    "nimeya": ['mw'],
    "nimeyaḥ": ['ap90'],
    "nimeṣa": ['cae', 'mw'],
    "nimeṣadyut": ['mw'],
    "nimeṣaka": ['mw'],
    "nimeṣakaḥ": ['ap90'],
    "nimeṣakṛt": ['mw'],
    "nimeṣamātra": ['mw'],
    "nimeṣamātreṇa": ['mw'],
    "nimeṣaruc": ['mw'],
    "nimeṣatas": ['mw'],
    "nimeṣaḥ": ['ap90'],
    "nimeṣaṇa": ['cae', 'mw'],
    "nimeṣāntara": ['mw'],
    "nimeṣārdhāt": ['mw'],
    "nimi": ['bhs', 'cae', 'ddsa', 'mw'],
    "nimih": ['mw'],
    "nimināti": ['bhs'],
    "nimissaṁ": ['cped'],
    "nimisūtra": ['bhs'],
    "nimita": ['cae', 'mw'],
    "nimiti": ['mw'],
    "nimitta": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "nimitta(g)gāha": ['cped'],
    "nimitta(g)gāhī(n)": ['cped'],
    "nimittabhūta": ['mw'],
    "nimittadharma": ['mw'],
    "nimittagrahaṇa": ['mw'],
    "nimittahetu": ['cae', 'mw'],
    "nimittahetutva": ['mw'],
    "nimittajña": ['mw'],
    "nimittajñāna": ['mw'],
    "nimittaka": ['bhs', 'cae', 'mw'],
    "nimittakāla": ['mw'],
    "nimittakālatā": ['mw'],
    "nimittakāraṇa": ['cae', 'mw'],
    "nimittakāraṇatā": ['mw'],
    "nimittakṛt": ['mw'],
    "nimittamātra": ['cae', 'mw'],
    "nimittanaimittika": ['cae', 'mw'],
    "nimittanidāna": ['mw'],
    "nimittanimittin": ['mw'],
    "nimittanusāri(n)": ['cped'],
    "nimittaprajña": ['bhs'],
    "nimittasaptamī": ['mw'],
    "nimittatas": ['cae'],
    "nimittatva": ['cae', 'mw'],
    "nimittatā": ['mw'],
    "nimittavedhin": ['mw'],
    "nimittavid": ['mw'],
    "nimittaṁ gaṇhāti": ['cped'],
    "nimittaṁ karoti": ['cped'],
    "nimittaṃ": ['ap90'],
    "nimittika": ['bhs'],
    "nimittin": ['ap90', 'mw'],
    "nimittārtha": ['mw'],
    "nimittāvekṣa": ['mw'],
    "nimittāvṛtti": ['mw'],
    "nimittāyamāna": ['mw'],
    "nimittāyus": ['mw'],
    "nimittī": ['mw'],
    "nimittībhū": ['mw'],
    "nimittīkṛ": ['ddsa', 'mw'],
    "nimittīkṛtya": ['mw'],
    "nimiñjita": ['bhs'],
    "nimiśla": ['ap90', 'cae', 'gra', 'mw'],
    "nimiślatama": ['mw'],
    "nimiśra": ['mw'],
    "nimiḥ": ['ap90'],
    "nimiṃdhara": ['bhs', 'mw'],
    "nimiṇati": ['bhs'],
    "nimiṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nimiṣa": ['cae', 'gra', 'mw'],
    "nimiṣakṣetra": ['mw'],
    "nimiṣaḥ": ['ap90'],
    "nimiṣita": ['mw'],
    "nimiṣāntara": ['mw'],
    "nimiṣāntareṇa": ['mw'],
    "nimloca": ['mw'],
    "nimlocanī": ['mw'],
    "nimloci": ['mw'],
    "nimlocā": ['mw'],
    "nimluc": ['mw'],
    "nimlukti": ['ap90', 'mw'],
    "nimmadayati": ['cped'],
    "nimmadeti": ['cped'],
    "nimmajjati": ['cped'],
    "nimminitvā": ['cped'],
    "nimminitvāna": ['cped'],
    "nimmināti": ['cped'],
    "nimmita": ['cped'],
    "nimmugga": ['cped'],
    "nimmujjati": ['cped'],
    "nimmādesi": ['cped'],
    "nimmādeti": ['cped'],
    "nimmānarati": ['cped'],
    "nimmānaratino": ['cped'],
    "nimmānarāti": ['cped'],
    "nimmānayati": ['cped'],
    "nimmānāyati": ['cped'],
    "nimmāta": ['cped'],
    "nimmātar": ['cped'],
    "nimmīleti": ['cped'],
    "nimmīletvā": ['cped'],
    "nimna": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "nimnabhāga": ['mw'],
    "nimnadeśa": ['mw'],
    "nimnagata": ['mw'],
    "nimnagā": ['cae', 'mw'],
    "nimnagāpati": ['mw'],
    "nimnagāsuta": ['mw'],
    "nimnais": ['mw'],
    "nimnalalāṭa": ['mw'],
    "nimnanābhi": ['mw'],
    "nimnapravaṇa": ['mw'],
    "nimnatala": ['mw'],
    "nimnatva": ['mw'],
    "nimnatā": ['mw'],
    "nimnaya": ['mw'],
    "nimnita": ['mw'],
    "nimnonnata": ['cae', 'mw'],
    "nimnābhimukha": ['mw'],
    "nimokkha": ['cped'],
    "nimrocana": ['cae', 'mw'],
    "nimruc": ['cae', 'gra', 'mw'],
    "nimrukti": ['cae', 'ddsa', 'mw'],
    "nimugga": ['cped'],
    "nimujjanta": ['cped'],
    "nimujjati": ['cped'],
    "nimujjituṁ": ['cped'],
    "nimujjitvā": ['cped'],
    "nimuṣṭi": ['mw'],
    "nimuṣṭika": ['mw'],
    "nimyakṣ": ['mw'],
    "nimā": ['mw'],
    "nimāna": ['gra', 'mw'],
    "nimānaṃ": ['ap90'],
    "nimārjana": ['mw'],
    "nimātavya": ['mw'],
    "nimīl": ['ap90', 'mw'],
    "nimīlaka": ['mw'],
    "nimīlana": ['cae', 'mw'],
    "nimīlanaṃ": ['ap90'],
    "nimīlayati": ['cped'],
    "nimīleti": ['cped'],
    "nimīletvā": ['cped'],
    "nimīlikā": ['mw'],
    "nimīlin": ['mw'],
    "nimīlita": ['ap90', 'cae', 'mw'],
    "nimīlitadṛś": ['mw'],
    "nimīlitamukha": ['mw'],
    "nimīlitanakṣatra": ['mw'],
    "nimīlitākṣa": ['mw'],
    "nimīlā": ['ap90', 'mw'],
    "nimīv": ['mw'],
    "nimīśvara": ['mw'],
    "nimūlakāṣam": ['mw'],
    "nimūlam": ['mw'],
    "nimūlayati": ['bhs'],
    "nimūlaṃ": ['ap90'],
    "nimṛd": ['mw'],
    "nimṛda": ['cae'],
    "nimṛgra": ['cae', 'ddsa', 'gra', 'mw'],
    "nimṛj": ['mw'],
    "nimṝ": ['mw'],
    "ninad": ['ap90', 'mw'],
    "ninada": ['cae', 'ddsa', 'mw'],
    "ninadaḥ": ['ap90'],
    "ninaddha": ['cae', 'mw'],
    "ninahāta": ['cped'],
    "ninandati": ['bhs'],
    "ninard": ['ap90', 'mw'],
    "ninarda": ['mw'],
    "ninardaḥ": ['ap90'],
    "ninartaśatru": ['mw'],
    "ninartiṣā": ['ddsa', 'mw'],
    "ninayana": ['cae', 'mw'],
    "ninayanaṃ": ['ap90'],
    "ninayanīya": ['mw'],
    "ninaṃkṣu": ['ap90'],
    "ninaṅkṣu": ['mw'],
    "nind": ['ddsa', 'gra', 'mw'],
    "ninda": ['mw'],
    "nindaka": ['cae', 'ddsa', 'mw'],
    "nindana": ['cae', 'mw'],
    "nindanīya": ['mw'],
    "nindatala": ['mw'],
    "nindati": ['cped'],
    "nindia": ['gra'],
    "nindin": ['cae', 'mw'],
    "nindita": ['cae', 'cped', 'mw'],
    "ninditāśva": ['gra', 'mw'],
    "ninditṛ": ['cae', 'gra', 'mw'],
    "nindiya": ['bhs', 'cped'],
    "nindopamā": ['cae', 'mw'],
    "nindu": ['mw'],
    "nindya": ['cae', 'ddsa', 'gra', 'mw'],
    "nindyatā": ['mw'],
    "nindyaveśa": ['mw'],
    "nindā": ['cae', 'cped', 'mw'],
    "nindārha": ['cae'],
    "nindārosa": ['cped'],
    "nindārosi(n)": ['cped'],
    "nindāstuti": ['mw'],
    "nindāvyārosa-upārambhabhaya": ['cped'],
    "nindāvyārosana-upārambhabhaya": ['cped'],
    "ninhāta": ['cped'],
    "ninhātapāpaka": ['cped'],
    "ninhāya": ['cped'],
    "ninidrāsu": ['ddsa'],
    "ninitsu": ['cae', 'gra', 'mw'],
    "ninna": ['cped'],
    "ninneta(r)": ['cped'],
    "ninnetabba": ['cped'],
    "ninneti": ['cped'],
    "ninnetvā": ['cped'],
    "ninnādi(n)": ['cped'],
    "ninnāmayati": ['cped'],
    "ninnāmeti": ['cped'],
    "ninnāmetvā": ['cped'],
    "ninnīta": ['cped'],
    "ninnītakasāva": ['cped'],
    "ninv": ['mw'],
    "nināda": ['cae', 'ddsa', 'mw'],
    "ninādaḥ": ['ap90'],
    "ninādin": ['ap90', 'cae', 'mw'],
    "ninādita": ['ap90', 'mw'],
    "nināhya": ['mw'],
    "nināhyaḥ": ['ap90'],
    "ninī": ['ap90', 'mw'],
    "ninīṣu": ['cae', 'mw'],
    "ninīṣā": ['ddsa', 'mw'],
    "ninṛt": ['mw'],
    "ninṛtta": ['ap90', 'mw'],
    "ninṛttavat": ['mw'],
    "ninṛtti": ['ddsa', 'mw'],
    "ninṛttiḥ": ['ap90'],
    "niocanī": ['gra'],
    "niokas": ['gra'],
    "nipa": ['cae', 'gra', 'mw'],
    "nipaccakāra": ['cped'],
    "nipaccavādi(n)": ['cped'],
    "nipacchita": ['bhs'],
    "nipaccākāra": ['cped'],
    "nipad": ['mw'],
    "nipajjati": ['cped'],
    "nipajjaṁ": ['cped'],
    "nipajji": ['cped'],
    "nipajjisāmi": ['cped'],
    "nipajjitvā": ['cped'],
    "nipajjiṁsu": ['cped'],
    "nipajjā": ['cped'],
    "nipajjāpetvā": ['cped'],
    "nipaka": ['bhs', 'cped', 'mw'],
    "nipakṣati": ['mw'],
    "nipalāśam": ['mw'],
    "nipalāśaṃ": ['ap90'],
    "nipanna": ['bhs', 'cped'],
    "nipannokasa": ['cped'],
    "niparaṇa": ['mw'],
    "nipat": ['ap90', 'mw'],
    "nipata(t)": ['cped'],
    "nipatana": ['cae', 'ddsa', 'mw'],
    "nipatanaṃ": ['ap90'],
    "nipatanta": ['cped'],
    "nipatati": ['cped'],
    "nipathī": ['bhs'],
    "nipatita": ['mw'],
    "nipatitvā": ['cped'],
    "nipatya": ['mw'],
    "nipatyarohiṇī": ['mw'],
    "nipatyā": ['ap90', 'mw'],
    "nipatī": ['cped'],
    "nipaḥ": ['ap90'],
    "nipaṭha": ['mw'],
    "nipaṭhana": ['mw'],
    "nipaṭhaḥ": ['ap90'],
    "nipaṭhiti": ['mw'],
    "nipaṭhitin": ['mw'],
    "niphalā": ['mw'],
    "niphena": ['mw'],
    "niphālana": ['mw'],
    "nipitsu": ['mw'],
    "nipiṣṭa": ['mw'],
    "nippacati": ['cped'],
    "nippaci": ['cped'],
    "nippadā": ['cped'],
    "nippakka": ['cped'],
    "nippatati": ['cped'],
    "nippati": ['cped'],
    "nippatita": ['cped'],
    "nippatitvā": ['cped'],
    "nippaṭati": ['cped'],
    "nippesika": ['cped'],
    "nippesikatā": ['cped'],
    "nipphadā": ['cped'],
    "nipphannasobhana": ['cped'],
    "nipphannasobhi(n)": ['cped'],
    "nipphaṭati": ['cped'],
    "nipphotayati": ['cped'],
    "nipphotenta": ['cped'],
    "nipphoteti": ['cped'],
    "nipphoṭenta": ['cped'],
    "nipphoṭeti": ['cped'],
    "nippoṭheti": ['cped'],
    "nippātesi": ['cped'],
    "nippātita": ['cped'],
    "nippītika": ['cped'],
    "nippīḷana": ['cped'],
    "nippīḷanā": ['cped'],
    "nippīḷiyamāna": ['cped'],
    "niprahan": ['mw'],
    "niprath": ['mw'],
    "niprayatna": ['mw'],
    "nipriyāya": ['mw'],
    "nipu": ['mw'],
    "nipur": ['mw'],
    "nipura": ['bhs'],
    "niputh": ['mw'],
    "nipuṇa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "nipuṇadṛś": ['mw'],
    "nipuṇam": ['mw'],
    "nipuṇatara": ['mw'],
    "nipuṇataram": ['mw'],
    "nipuṇatas": ['mw'],
    "nipuṇatā": ['ap90', 'mw'],
    "nipuṇi": ['mw'],
    "nipuṇikā": ['cae', 'ddsa', 'mw'],
    "nipā": ['ap90', 'mw'],
    "nipāda": ['cae', 'gra', 'mw'],
    "nipādaḥ": ['ap90'],
    "nipāka": ['mw'],
    "nipākaḥ": ['ap90'],
    "nipāna": ['cae', 'mw'],
    "nipānakartṛ": ['mw'],
    "nipānasaras": ['mw'],
    "nipānavat": ['mw'],
    "nipānaṃ": ['ap90'],
    "nipānīkṛ": ['mw'],
    "nipāraka": ['mw'],
    "nipāta": ['bhs', 'cae', 'cped', 'mw'],
    "nipātaka": ['mw'],
    "nipātakaḥ": ['ap90'],
    "nipātana": ['ap90', 'cae', 'mw'],
    "nipātanīya": ['cae', 'mw'],
    "nipātapratīkāra": ['mw'],
    "nipātatva": ['mw'],
    "nipātayati": ['bhs', 'cped'],
    "nipātaḥ": ['ap90'],
    "nipātenta": ['cped'],
    "nipātesi": ['cped'],
    "nipātesuṁ": ['cped'],
    "nipāteti": ['cped'],
    "nipātetvā": ['cped'],
    "nipātin": ['ap90', 'bhs', 'cae', 'mw'],
    "nipātita": ['ap90', 'mw'],
    "nipātya": ['mw'],
    "nipātyamāna": ['mw'],
    "nipātāvyayopasarga": ['mw'],
    "nipāṭha": ['mw'],
    "nipīlana": ['cped', 'mw'],
    "nipīta": ['ap90', 'mw'],
    "nipītakusuma": ['mw'],
    "nipītasāra": ['mw'],
    "nipītatoya": ['mw'],
    "nipīti": ['mw'],
    "nipītiḥ": ['ap90'],
    "nipīy": ['mw'],
    "nipīyamāna": ['mw'],
    "nipīḍ": ['ap90', 'mw'],
    "nipīḍana": ['mw'],
    "nipīḍanaṃ": ['ap90'],
    "nipīḍanā": ['mw'],
    "nipīḍayat": ['mw'],
    "nipīḍita": ['ap90', 'mw'],
    "nipīḍitālaktakavat": ['mw'],
    "nipīḍya": ['mw'],
    "nipūrta": ['mw'],
    "nipūta": ['cae', 'mw'],
    "nipṛta": ['mw'],
    "nipṝ": ['mw'],
    "nir": ['ap90', 'ddsa', 'mw'],
    "nirabbuda": ['cped'],
    "nirabbudda": ['cped'],
    "nirabhibhava": ['mw'],
    "nirabhilapya": ['mw'],
    "nirabhilāpya": ['bhs'],
    "nirabhilāṣa": ['cae', 'mw'],
    "nirabhimāna": ['mw'],
    "nirabhinandin": ['bhs'],
    "nirabhiprāya": ['ddsa', 'mw'],
    "nirabhiramya": ['bhs'],
    "nirabhisaṃdhin": ['mw'],
    "nirabhisaṃdhāna": ['mw'],
    "nirabhra": ['cae', 'ddsa', 'mw'],
    "nirabhre": ['mw'],
    "nirabhyavekṣ": ['mw'],
    "nirabhyaṅga": ['mw'],
    "nirabhīmāna": ['mw'],
    "niradh": ['mw'],
    "niradhimānatā": ['bhs'],
    "niradhiṣṭhāna": ['bhs', 'mw'],
    "niradhva": ['mw'],
    "niragamā": ['cped'],
    "niraggaḷa": ['cped'],
    "niragha": ['cae', 'mw'],
    "niragni": ['cae', 'mw'],
    "niragnika": ['mw'],
    "niragra": ['mw'],
    "niragraka": ['mw'],
    "nirah": ['mw'],
    "niraham": ['mw'],
    "nirahammati": ['mw'],
    "nirahammāna": ['mw'],
    "nirahaṃkriya": ['mw'],
    "nirahaṃkriyā": ['cae', 'mw'],
    "nirahaṃkāra": ['cae', 'mw'],
    "nirahaṃkārin": ['mw'],
    "nirahaṃkṛta": ['mw'],
    "nirahaṃkṛti": ['cae', 'mw'],
    "nirahaṃstambha": ['mw'],
    "nirahaṅkāra": ['ddsa'],
    "nirahna": ['mw'],
    "niraj": ['mw'],
    "niraja": ['mw'],
    "nirajina": ['mw'],
    "nirakṣ": ['mw'],
    "nirakṣa": ['mw'],
    "nirakṣadeśa": ['mw'],
    "nirakṣara": ['ddsa', 'mw'],
    "niralaṃkāra": ['mw'],
    "niralaṃkṛti": ['mw'],
    "niram": ['mw'],
    "niramarṣa": ['mw'],
    "niramaṇa": ['mw'],
    "nirambara": ['cae', 'mw'],
    "nirambu": ['cae', 'mw'],
    "niramitra": ['cae', 'mw'],
    "nirandhas": ['mw'],
    "niranna": ['mw'],
    "niranne": ['mw'],
    "nirantara": ['cae', 'ddsa', 'mw'],
    "nirantaragṛhavāsin": ['mw'],
    "nirantaram": ['mw'],
    "nirantarapayodharā": ['cae', 'mw'],
    "nirantaratā": ['mw'],
    "nirantaraviśeṣa": ['mw'],
    "nirantaraśarīra": ['mw'],
    "nirantarodbhinna": ['cae', 'mw'],
    "nirantarotkaṇṭhā": ['cae', 'mw'],
    "nirantarābhyāsa": ['mw'],
    "nirantarāla": ['mw'],
    "nirantarālatā": ['mw'],
    "niranubandha": ['mw'],
    "niranubandhaka": ['mw'],
    "niranuga": ['mw'],
    "niranugraha": ['mw'],
    "niranukrośa": ['cae', 'mw'],
    "niranukrośakārin": ['mw'],
    "niranukrośatas": ['mw'],
    "niranukrośatā": ['mw'],
    "niranukrośayukta": ['mw'],
    "niranumāna": ['mw'],
    "niranunāsika": ['mw'],
    "niranurodha": ['cae', 'mw'],
    "niranurodhatva": ['mw'],
    "niranusaya": ['cped'],
    "niranuyojya": ['mw'],
    "niranuyojyānuyoga": ['mw'],
    "niranuśaya": ['mw'],
    "niranvaya": ['cae', 'mw'],
    "nirapa": ['cae', 'ddsa', 'mw'],
    "nirapahnava": ['mw'],
    "nirapakrama": ['mw'],
    "niraparādha": ['cae', 'mw'],
    "niraparādhatā": ['mw'],
    "niraparādhavat": ['mw'],
    "nirapatrapa": ['cae', 'mw'],
    "nirapatya": ['cae', 'mw'],
    "nirapatyatva": ['mw'],
    "nirapavarta": ['mw'],
    "nirapavartana": ['mw'],
    "nirapavāda": ['mw'],
    "nirapekṣa": ['cae', 'mw'],
    "nirapekṣam": ['mw'],
    "nirapekṣatva": ['mw'],
    "nirapekṣatā": ['mw'],
    "nirapekṣin": ['cae', 'mw'],
    "nirapekṣita": ['cae', 'mw'],
    "nirapekṣya": ['mw'],
    "nirapekṣā": ['mw'],
    "nirapāya": ['cae', 'mw'],
    "nirarbuda": ['bhs', 'mw'],
    "nirard": ['mw'],
    "nirargala": ['cae', 'ddsa', 'mw'],
    "nirargalam": ['mw'],
    "nirargalavāc": ['mw'],
    "nirargaḍa": ['bhs'],
    "nirartha": ['cae', 'ddsa', 'mw'],
    "nirarthaka": ['bhs', 'cae', 'mw'],
    "nirarthakam": ['mw'],
    "nirarthakatva": ['mw'],
    "nirarti": ['mw'],
    "niras": ['ap90', 'mw'],
    "nirasa": ['ap90'],
    "nirasana": ['ap90', 'cae', 'ddsa', 'mw'],
    "nirasanīya": ['mw'],
    "nirasassāda": ['cped'],
    "nirassajati": ['cped'],
    "nirassati": ['cped'],
    "nirasta": ['ap90', 'mw'],
    "nirastabheda": ['mw'],
    "nirastarāga": ['mw'],
    "nirastasaṃkhya": ['mw'],
    "nirastasukhodaya": ['mw'],
    "nirasthi": ['mw'],
    "nirasti": ['mw'],
    "nirastra": ['cae', 'mw'],
    "nirastāpad": ['mw'],
    "nirasya": ['mw'],
    "nirata": ['ap90', 'cae', 'cped', 'mw'],
    "nirati": ['bhs', 'ddsa', 'mw'],
    "niratiśaya": ['cae', 'ddsa', 'mw'],
    "niratiśayatva": ['mw'],
    "niratiḥ": ['ap90'],
    "niratta": ['cped'],
    "niratta(n)": ['cped'],
    "nirattha": ['cped'],
    "niratthaka": ['cped'],
    "niratthakaṁ": ['cped'],
    "niratyaya": ['cae', 'mw'],
    "niratyayatva": ['mw'],
    "niratīcāra": ['mw'],
    "nirauṣadha": ['cae', 'mw'],
    "nirava": ['gra', 'mw'],
    "niravaday": ['mw'],
    "niravadhe": ['mw'],
    "niravadhi": ['cae', 'ddsa', 'mw'],
    "niravado": ['mw'],
    "niravadoṣatva": ['mw'],
    "niravadya": ['bhs', 'cae', 'ddsa', 'mw'],
    "niravadyatva": ['mw'],
    "niravadyavat": ['mw'],
    "niravadāna": ['mw'],
    "niravagraha": ['cae', 'ddsa', 'mw'],
    "niravagrahe": ['mw'],
    "niravaha": ['mw'],
    "niravahālikā": ['ap90', 'mw'],
    "niravahānikā": ['ap90'],
    "niravakāśa": ['cae', 'ddsa', 'mw'],
    "niravakāśatā": ['mw'],
    "niravakāśīkṛ": ['ddsa', 'mw'],
    "niravalamba": ['cae', 'mw'],
    "niravalambana": ['cae', 'mw'],
    "niravarodha": ['cae', 'mw'],
    "niravasita": ['mw'],
    "niravaskṛta": ['mw'],
    "niravaso": ['mw'],
    "niravastāra": ['mw'],
    "niravasāda": ['mw'],
    "niravatta": ['mw'],
    "niravattabali": ['mw'],
    "niravatti": ['mw'],
    "niravayaj": ['mw'],
    "niravayava": ['cae', 'mw'],
    "niravayavatva": ['mw'],
    "niravaśeṣa": ['bhs', 'cae', 'mw'],
    "niravaśeṣatas": ['mw'],
    "niravaśeṣeṇa": ['mw'],
    "niravaśeṣya": ['bhs'],
    "niravekṣ": ['mw'],
    "niravekṣya": ['mw'],
    "niravinda": ['mw'],
    "niravyaya": ['mw'],
    "niraya": ['cae', 'cped', 'ddsa', 'mw'],
    "nirayagāmanīya": ['cped'],
    "nirayagāmi(n)": ['cped'],
    "nirayapati": ['mw'],
    "nirayapāla": ['cped'],
    "nirayaḥ": ['ap90'],
    "nirayaṇa": ['cae', 'gra', 'mw'],
    "nirayika": ['bhs'],
    "nirayin": ['mw'],
    "nirayāvalisūtra": ['mw'],
    "nirañchana": ['mw'],
    "nirañjana": ['cae', 'mw'],
    "nirañjanā": ['bhs', 'mw'],
    "nirañjanāṣṭaka": ['mw'],
    "niraśana": ['ddsa', 'mw'],
    "niraśva": ['mw'],
    "niraśvapuruṣa": ['mw'],
    "niraṁkaroti": ['cped'],
    "niraṃsaka": ['mw'],
    "niraṃśa": ['mw'],
    "niraṃśaka": ['cae', 'ddsa'],
    "niraṃśatva": ['mw'],
    "niraṃśu": ['cae', 'mw'],
    "niraṅga": ['ddsa', 'mw'],
    "niraṅgaṇa": ['bhs'],
    "niraṅgula": ['mw'],
    "niraṅguli": ['mw'],
    "niraṅguṣṭha": ['mw'],
    "niraṅkaroti": ['cped'],
    "niraṅkata": ['cped'],
    "niraṅkuśa": ['bhs', 'cae', 'mw'],
    "niraṅkuśam": ['mw'],
    "niraṅkuśatva": ['mw'],
    "niraṅkuśaya": ['ddsa', 'mw'],
    "niraṇ": ['mw'],
    "niraṣṭa": ['bhs', 'cae', 'gra', 'mw'],
    "nirbaddha": ['ap90', 'mw'],
    "nirbala": ['cae', 'mw'],
    "nirbandh": ['mw'],
    "nirbandha": ['cae', 'ddsa', 'mw'],
    "nirbandhanīya": ['mw'],
    "nirbandhapara": ['mw'],
    "nirbandhapṛṣṭa": ['mw'],
    "nirbandhatas": ['mw'],
    "nirbandhena": ['mw'],
    "nirbandhin": ['cae', 'mw'],
    "nirbandhitā": ['mw'],
    "nirbandhu": ['mw'],
    "nirbandhāt": ['mw'],
    "nirbarha": ['mw'],
    "nirbarhaṇa": ['ap90', 'mw'],
    "nirbaṃdh": ['ap90'],
    "nirbaṃdhaḥ": ['ap90'],
    "nirbhacchita": ['bhs'],
    "nirbhagna": ['ap90', 'mw'],
    "nirbhaj": ['mw'],
    "nirbhajyamāna": ['mw'],
    "nirbhakta": ['mw'],
    "nirbhal": ['mw'],
    "nirbhara": ['cae', 'mw'],
    "nirbharam": ['mw'],
    "nirbharanidrā": ['mw'],
    "nirbharaparirambha": ['mw'],
    "nirbharapraṇayitā": ['mw'],
    "nirbhararahaḥkrīḍā": ['mw'],
    "nirbharasambhoga": ['mw'],
    "nirbharts": ['ap90', 'mw'],
    "nirbhartsana": ['cae', 'mw'],
    "nirbhartsanadaṇḍamohita": ['mw'],
    "nirbhartsanaṃ": ['ap90'],
    "nirbhartsita": ['ap90', 'mw'],
    "nirbhartsitavat": ['mw'],
    "nirbhas": ['mw'],
    "nirbhastraka": ['mw'],
    "nirbhatsanā": ['bhs'],
    "nirbhatsayati": ['bhs'],
    "nirbhaya": ['cae', 'ddsa', 'mw'],
    "nirbhayabhīma": ['mw'],
    "nirbhayam": ['mw'],
    "nirbhayarāmabhaṭṭa": ['mw'],
    "nirbhañj": ['mw'],
    "nirbhaṭa": ['ap90', 'mw'],
    "nirbheda": ['cae', 'mw'],
    "nirbhedabhāgīya": ['bhs'],
    "nirbhedana": ['bhs'],
    "nirbhedaḥ": ['ap90'],
    "nirbhedin": ['cae', 'mw'],
    "nirbhedya": ['ap90', 'mw'],
    "nirbhid": ['ap90', 'mw'],
    "nirbhidyati": ['bhs'],
    "nirbhinna": ['ap90', 'cae', 'mw'],
    "nirbhinnatanu": ['mw'],
    "nirbhoga": ['cae', 'mw'],
    "nirbhrānti": ['cae'],
    "nirbhugna": ['ap90', 'mw'],
    "nirbhuj": ['mw'],
    "nirbhuja": ['mw'],
    "nirbhukta": ['bhs'],
    "nirbhā": ['ap90', 'mw'],
    "nirbhāga": ['mw'],
    "nirbhāgatva": ['mw'],
    "nirbhāgya": ['mw'],
    "nirbhājya": ['mw'],
    "nirbhās": ['mw'],
    "nirbhāsa": ['mw'],
    "nirbhāsana": ['cae', 'mw'],
    "nirbhāsaḥ": ['ap90'],
    "nirbhāsita": ['mw'],
    "nirbhāta": ['cae', 'mw'],
    "nirbhī": ['cae', 'mw'],
    "nirbhīka": ['cae', 'mw'],
    "nirbhīta": ['cae', 'mw'],
    "nirbhū": ['mw'],
    "nirbhūti": ['ap90', 'cae', 'mw'],
    "nirbhṛ": ['mw'],
    "nirbhṛta": ['mw'],
    "nirbhṛti": ['mw'],
    "nirbodha": ['mw'],
    "nirbrū": ['mw'],
    "nirbuda": ['bhs'],
    "nirbuddhi": ['cae', 'mw'],
    "nirbusa": ['mw'],
    "nirbusīkṛta": ['mw'],
    "nirbādh": ['mw'],
    "nirbādha": ['cae', 'mw'],
    "nirbādhatva": ['mw'],
    "nirbādhin": ['mw'],
    "nirbādhya": ['mw'],
    "nirbāṇa": ['mw'],
    "nirbīja": ['cae', 'mw'],
    "nirbījatva": ['mw'],
    "nirbījā": ['mw'],
    "nirdagdha": ['ap90', 'mw'],
    "nirdagdhikā": ['mw'],
    "nirdah": ['ap90', 'mw'],
    "nirdahana": ['ap90', 'cae', 'mw'],
    "nirdahanā": ['mw'],
    "nirdainya": ['mw'],
    "nirdalana": ['cae', 'mw'],
    "nirdalanaṃ": ['ap90'],
    "nirdanta": ['mw'],
    "nirdara": ['ap90', 'cae', 'mw'],
    "nirdaram": ['mw'],
    "nirdaravāsin": ['mw'],
    "nirdaraṇa": ['mw'],
    "nirdari": ['cae'],
    "nirdasyu": ['mw'],
    "nirdaya": ['cae', 'mw'],
    "nirdayadantadaṃśa": ['mw'],
    "nirdayam": ['mw'],
    "nirdayaratiśramālasa": ['mw'],
    "nirdayatva": ['mw'],
    "nirdayāsleṣa": ['mw'],
    "nirdaśa": ['cae', 'mw'],
    "nirdaśana": ['mw'],
    "nirdaśanākṣijihva": ['mw'],
    "nirdaśatā": ['mw'],
    "nirdaḍa": ['mw'],
    "nirdaṃś": ['mw'],
    "nirdaṃśin": ['ddsa', 'mw'],
    "nirdaṇḍa": ['mw'],
    "nirdaṭa": ['ap90', 'mw'],
    "nirdeva": ['cae', 'ddsa', 'mw'],
    "nirdeśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "nirdeśaka": ['ap90', 'mw'],
    "nirdeśakārin": ['mw'],
    "nirdeśana": ['bhs'],
    "nirdeśanīya": ['mw'],
    "nirdeśapālana": ['mw'],
    "nirdeśayati": ['bhs'],
    "nirdeśaḥ": ['ap90'],
    "nirdeśya": ['bhs', 'cae', 'mw'],
    "nirdeṣṭṛ": ['ap90', 'mw'],
    "nirdham": ['mw'],
    "nirdhamana": ['mw'],
    "nirdhana": ['cae', 'ddsa', 'mw'],
    "nirdhanatva": ['mw'],
    "nirdhanatā": ['mw'],
    "nirdhanībhū": ['mw'],
    "nirdhanīkṛ": ['mw'],
    "nirdharma": ['cae', 'mw'],
    "nirdharmamūrkhatā": ['mw'],
    "nirdharmatva": ['mw'],
    "nirdharmārtha": ['mw'],
    "nirdhauta": ['ap90', 'cae', 'mw'],
    "nirdhautālaya": ['bhs'],
    "nirdhe": ['mw'],
    "nirdhmāpana": ['mw'],
    "nirdhuta": ['cae'],
    "nirdhyai": ['mw'],
    "nirdhyāta": ['mw'],
    "nirdhā": ['mw'],
    "nirdhānta": ['bhs'],
    "nirdhāra": ['ap90', 'cae', 'mw'],
    "nirdhārayitṛ": ['mw'],
    "nirdhāraḥ": ['ap90'],
    "nirdhāraṇa": ['cae', 'mw'],
    "nirdhāraṇīya": ['mw'],
    "nirdhārita": ['ap90', 'mw'],
    "nirdhāritavya": ['mw'],
    "nirdhārtarāṣṭra": ['mw'],
    "nirdhārya": ['ap90', 'mw'],
    "nirdhāv": ['ap90', 'mw'],
    "nirdhāvana": ['bhs'],
    "nirdhāyate": ['bhs'],
    "nirdhāṭaya": ['mw'],
    "nirdhū": ['ap90', 'mw'],
    "nirdhūma": ['cae', 'mw'],
    "nirdhūmatva": ['mw'],
    "nirdhūnana": ['mw'],
    "nirdhūpita": ['bhs'],
    "nirdhūta": ['ap90', 'cae', 'mw'],
    "nirdhūtapāpa": ['mw'],
    "nirdhūtasaktu": ['mw'],
    "nirdhṛ": ['ap90', 'mw'],
    "nirdhṛti": ['mw'],
    "nirdidhārayiṣā": ['mw'],
    "nirdigdha": ['ap90', 'mw'],
    "nirdigdhā": ['mw'],
    "nirdiś": ['ap90', 'mw'],
    "nirdiṣṭa": ['ap90', 'mw'],
    "nirdoṣa": ['cae', 'mw'],
    "nirdoṣakulasārāvalī": ['mw'],
    "nirdoṣatā": ['mw'],
    "nirdoṣīkaraṇa": ['mw'],
    "nirdoṣīkṛta": ['mw'],
    "nirdravya": ['cae', 'ddsa', 'mw'],
    "nirdroha": ['mw'],
    "nirdru": ['mw'],
    "nirdruma": ['mw'],
    "nirdrumīkṛ": ['mw'],
    "nirdugdha": ['mw'],
    "nirduh": ['mw'],
    "nirdurdina": ['mw'],
    "nirduḥkha": ['cae', 'ddsa', 'mw'],
    "nirduḥkhatva": ['mw'],
    "nirdvaṃdva": ['cae', 'mw'],
    "nirdyut": ['mw'],
    "nirdāha": ['cae', 'mw'],
    "nirdāhuka": ['mw'],
    "nirdākṣiṇya": ['mw'],
    "nirdārayitar": ['bhs'],
    "nirdāraṇa": ['bhs'],
    "nirdāridrya": ['mw'],
    "nirdārita": ['ap90', 'mw'],
    "nirdātṛ": ['ap90', 'cae', 'mw'],
    "nirdī": ['mw'],
    "nirdṝ": ['mw'],
    "nire": ['mw'],
    "nirebha": ['ap90', 'mw'],
    "nireka": ['gra', 'mw'],
    "nireke": ['mw'],
    "nirenas": ['ddsa', 'mw'],
    "nirga": ['mw'],
    "nirgahana": ['mw'],
    "nirgalita": ['cae', 'mw'],
    "nirgam": ['ap90', 'mw'],
    "nirgama": ['cae', 'mw'],
    "nirgamana": ['mw'],
    "nirgamanaṃ": ['ap90'],
    "nirgamaḥ": ['ap90'],
    "nirgandha": ['cae', 'mw'],
    "nirgandhapuṣpī": ['mw'],
    "nirgandhatā": ['mw'],
    "nirgarati": ['bhs'],
    "nirgarbha": ['mw'],
    "nirgarha": ['cae', 'mw'],
    "nirgarva": ['mw'],
    "nirgata": ['ap90', 'mw'],
    "nirgatanikhilakalmaṣatā": ['mw'],
    "nirgataviśaṅka": ['mw'],
    "nirgatākhilakalmaṣa": ['ddsa'],
    "nirgaurava": ['mw'],
    "nirgauravam": ['mw'],
    "nirgavākṣa": ['mw'],
    "nirgaḍa": ['bhs'],
    "nirgaḥ": ['ap90'],
    "nirgaṃdhanaṃ": ['ap90'],
    "nirgharṣaṇa": ['cae', 'ddsa', 'mw'],
    "nirgharṣaṇaka": ['ap90', 'mw'],
    "nirgharṣaṇaṃ": ['ap90'],
    "nirghaṃṭaḥ": ['ap90'],
    "nirghaṇṭa": ['bhs', 'mw'],
    "nirghaṇṭu": ['cae', 'mw'],
    "nirghaṇṭuka": ['cae', 'mw'],
    "nirghaṭa": ['mw'],
    "nirghoṣa": ['bhs', 'cae', 'mw'],
    "nirghoṣaḥ": ['ap90'],
    "nirghoṣākṣaravimukta": ['bhs', 'mw'],
    "nirghuṣṭa": ['mw'],
    "nirghāta": ['cae', 'mw'],
    "nirghātaduḥsaha": ['mw'],
    "nirghātakara": ['mw'],
    "nirghātalakṣaṇa": ['mw'],
    "nirghātana": ['mw'],
    "nirghātanaṃ": ['ap90'],
    "nirghātaya": ['mw'],
    "nirghātaḥ": ['ap90'],
    "nirghātin": ['bhs'],
    "nirghātya": ['mw'],
    "nirghūriṇī": ['mw'],
    "nirghṛṇa": ['cae', 'mw'],
    "nirghṛṇam": ['mw'],
    "nirghṛṇatva": ['mw'],
    "nirghṛṇatā": ['mw'],
    "nirghṛṇā": ['mw'],
    "nirghṛṣ": ['mw'],
    "nirgraha": ['cae'],
    "nirgrantha": ['bhs', 'cae', 'mw'],
    "nirgranthajñātiputra": ['bhs'],
    "nirgranthaka": ['mw'],
    "nirgranthana": ['mw'],
    "nirgranthaśāstra": ['mw'],
    "nirgranthi": ['bhs', 'mw'],
    "nirgranthika": ['mw'],
    "nirgranthisiratā": ['mw'],
    "nirgraṃthanaṃ": ['ap90'],
    "nirgrāhya": ['ap90', 'mw'],
    "nirgulika": ['mw'],
    "nirgulma": ['mw'],
    "nirgup": ['mw'],
    "nirguṇa": ['cae', 'mw'],
    "nirguṇaka": ['mw'],
    "nirguṇamānasa": ['mw'],
    "nirguṇatattva": ['mw'],
    "nirguṇatva": ['mw'],
    "nirguṇatā": ['mw'],
    "nirguṇātmaka": ['mw'],
    "nirguṇḍi": ['mw'],
    "nirguṇḍī": ['mw'],
    "nirguṇṭī": ['mw'],
    "nirgā": ['mw'],
    "nirgīrṇa": ['mw'],
    "nirgūḍha": ['bhs', 'mw'],
    "nirgūḍhaḥ": ['ap90'],
    "nirgṛha": ['cae', 'mw'],
    "nirgṛhīta": ['bhs'],
    "nirhakakavivallabha": ['mw'],
    "nirhan": ['mw'],
    "nirharati": ['bhs'],
    "nirharaṇa": ['cae', 'ddsa', 'mw'],
    "nirharaṇaṃ": ['ap90'],
    "nirharaṇīya": ['mw'],
    "nirhartavya": ['mw'],
    "nirhasta": ['cae', 'mw'],
    "nirhata": ['mw'],
    "nirheti": ['cae', 'mw'],
    "nirhetu": ['cae', 'mw'],
    "nirhetutva": ['mw'],
    "nirhetutā": ['mw'],
    "nirhima": ['mw'],
    "nirhimam": ['mw'],
    "nirhlāda": ['cae', 'mw'],
    "nirhras": ['mw'],
    "nirhrasita": ['mw'],
    "nirhrasta": ['mw'],
    "nirhrād": ['mw'],
    "nirhrāda": ['cae', 'mw'],
    "nirhrādana": ['mw'],
    "nirhrādaḥ": ['ap90'],
    "nirhrādin": ['mw'],
    "nirhrāsa": ['mw'],
    "nirhrī": ['mw'],
    "nirhrīka": ['mw'],
    "nirhuta": ['mw'],
    "nirhve": ['mw'],
    "nirhā": ['mw'],
    "nirhāda": ['mw'],
    "nirhādaḥ": ['ap90'],
    "nirhāra": ['bhs', 'cae', 'mw'],
    "nirhāraka": ['bhs', 'mw'],
    "nirhāraḥ": ['ap90'],
    "nirhāraṇa": ['mw'],
    "nirhārin": ['ap90', 'mw'],
    "nirhṛ": ['ap90', 'mw'],
    "nirhṛta": ['mw'],
    "nirhṛti": ['mw'],
    "nirhṛtiḥ": ['ap90'],
    "nirhṛtya": ['mw'],
    "niri": ['mw'],
    "niriccha": ['cae', 'mw'],
    "nirikta": ['bhs'],
    "nirikṣate": ['bhs'],
    "nirindhana": ['mw'],
    "nirindriya": ['cae', 'ddsa', 'mw'],
    "niriṃgiṇī": ['ap90'],
    "niriṅga": ['cae', 'mw'],
    "niriṅginī": ['mw'],
    "niriṅgita": ['bhs'],
    "nirjala": ['cae', 'mw'],
    "nirjalada": ['mw'],
    "nirjalaikādaśī": ['mw'],
    "nirjalamīnāya": ['mw'],
    "nirjalatoyadābha": ['mw'],
    "nirjana": ['cae', 'ddsa', 'mw'],
    "nirjanatva": ['mw'],
    "nirjanatā": ['mw'],
    "nirjanavana": ['mw'],
    "nirjantu": ['mw'],
    "nirjara": ['cae', 'mw'],
    "nirjarapaṇyayoṣit": ['mw'],
    "nirjaraprakaraṇādi": ['mw'],
    "nirjarasarṣapa": ['mw'],
    "nirjaraṇa": ['mw'],
    "nirjarjalpa": ['ap90', 'mw'],
    "nirjarā": ['mw'],
    "nirjarāyu": ['cae', 'mw'],
    "nirjava": ['bhs'],
    "nirjavana": ['bhs'],
    "nirjavati": ['bhs'],
    "nirjaya": ['cae', 'mw'],
    "nirjayaḥ": ['ap90'],
    "nirjetṛ": ['cae', 'mw'],
    "nirjhara": ['cae', 'ddsa', 'mw'],
    "nirjharaḥ": ['ap90'],
    "nirjharaṇa": ['mw'],
    "nirjharin": ['ap90', 'mw'],
    "nirjhariṇī": ['ap90', 'cae', 'mw'],
    "nirjharī": ['mw'],
    "nirjhāṭita": ['mw'],
    "nirji": ['ap90', 'mw'],
    "nirjigamiṣu": ['mw'],
    "nirjihva": ['cae', 'mw'],
    "nirjihīrṣu": ['mw'],
    "nirjijñāsa": ['mw'],
    "nirjināti": ['bhs'],
    "nirjita": ['ap90', 'bhs', 'mw'],
    "nirjitavarman": ['mw'],
    "nirjitendriya": ['mw'],
    "nirjitendriyagrāma": ['mw'],
    "nirjiti": ['cae', 'mw'],
    "nirjitārigaṇa": ['mw'],
    "nirjuṣṭa": ['mw'],
    "nirjvara": ['bhs', 'mw'],
    "nirjyotis": ['mw'],
    "nirjñāna": ['cae', 'mw'],
    "nirjñāti": ['cae', 'mw'],
    "nirjālmaka": ['mw'],
    "nirjāta": ['ap90', 'bhs', 'mw'],
    "nirjāḍya": ['mw'],
    "nirjīva": ['cae', 'mw'],
    "nirjīvakaraṇa": ['mw'],
    "nirjīvita": ['cae', 'mw'],
    "nirjīvitatva": ['mw'],
    "nirjṝ": ['mw'],
    "nirlajja": ['cae', 'mw'],
    "nirlajjatā": ['mw'],
    "nirlakṣaṇa": ['cae', 'ddsa', 'mw'],
    "nirlakṣya": ['cae', 'mw'],
    "nirlapaka": ['bhs'],
    "nirlavaṇa": ['mw'],
    "nirlayanī": ['mw'],
    "nirlekhana": ['mw'],
    "nirlekhanaṃ": ['ap90'],
    "nirlepa": ['cae', 'mw'],
    "nirlepam": ['mw'],
    "nirlih": ['mw'],
    "nirlikh": ['mw'],
    "nirlikhita": ['bhs'],
    "nirlipta": ['mw'],
    "nirliṅga": ['mw'],
    "nirlobha": ['cae', 'mw'],
    "nirlobhatva": ['mw'],
    "nirloc": ['mw'],
    "nirloha": ['mw'],
    "nirloma": ['mw'],
    "nirlomaka": ['bhs'],
    "nirlopa": ['bhs', 'mw'],
    "nirlopāpahāraka": ['mw'],
    "nirlup": ['mw'],
    "nirluñcana": ['mw'],
    "nirluḍ": ['mw'],
    "nirluṃcanaṃ": ['ap90'],
    "nirluṃṭhanaṃ": ['ap90'],
    "nirluṇṭh": ['mw'],
    "nirluṇṭhana": ['cae', 'mw'],
    "nirluṇṭhita": ['mw'],
    "nirluṭh": ['mw'],
    "nirluṭhita": ['mw'],
    "nirlvayanī": ['ap90', 'mw'],
    "nirlāñchana": ['mw'],
    "nirlūna": ['mw'],
    "nirmad": ['mw'],
    "nirmada": ['cae', 'mw'],
    "nirmadana": ['bhs'],
    "nirmadhya": ['bhs', 'mw'],
    "nirmadhyā": ['mw'],
    "nirmagna": ['mw'],
    "nirmaj": ['gra', 'mw'],
    "nirmajj": ['mw'],
    "nirmajja": ['mw'],
    "nirmajā": ['mw'],
    "nirmakṣika": ['cae', 'ddsa', 'mw'],
    "nirmakṣikam": ['mw'],
    "nirmala": ['bhs', 'cae', 'mw'],
    "nirmalabhaṭṭa": ['mw'],
    "nirmalagada": ['mw'],
    "nirmalaprakāśa": ['mw'],
    "nirmalatva": ['mw'],
    "nirmalatā": ['mw'],
    "nirmalatīrtha": ['mw'],
    "nirmalopala": ['mw'],
    "nirmalātmavat": ['mw'],
    "nirmalāñjana": ['mw'],
    "nirmalīkaraṇa": ['mw'],
    "nirmalīkṛta": ['mw'],
    "nirmalīmasa": ['mw'],
    "nirmama": ['cae', 'ddsa', 'mw'],
    "nirmamatva": ['mw'],
    "nirmamatā": ['mw'],
    "nirmanaska": ['cae', 'mw'],
    "nirmanaskatā": ['mw'],
    "nirmanth": ['mw'],
    "nirmantha": ['mw'],
    "nirmanthadāru": ['mw'],
    "nirmanthakāṣṭha": ['mw'],
    "nirmanthana": ['cae', 'mw'],
    "nirmanthya": ['mw'],
    "nirmanthyadāru": ['mw'],
    "nirmantra": ['cae', 'mw'],
    "nirmantu": ['mw'],
    "nirmanuja": ['mw'],
    "nirmanuṣya": ['mw'],
    "nirmanuṣyamṛga": ['mw'],
    "nirmanyu": ['mw'],
    "nirmardayati": ['bhs'],
    "nirmaryāda": ['cae', 'ddsa', 'mw'],
    "nirmaryādam": ['mw'],
    "nirmath": ['mw'],
    "nirmatha": ['bhs', 'mw'],
    "nirmathadāru": ['mw'],
    "nirmathana": ['cae', 'mw'],
    "nirmathaḥ": ['ap90'],
    "nirmathita": ['mw'],
    "nirmathya": ['mw'],
    "nirmathyā": ['mw'],
    "nirmatsara": ['cae', 'mw'],
    "nirmatsya": ['mw'],
    "nirmatsyatā": ['mw'],
    "nirmañc": ['mw'],
    "nirmañcana": ['mw'],
    "nirmaśaka": ['mw'],
    "nirmaṃth": ['ap90'],
    "nirmaṃthya": ['ap90'],
    "nirmaṇḍūka": ['mw'],
    "nirmedha": ['mw'],
    "nirmedhāśrama": ['mw'],
    "nirmegha": ['ddsa', 'mw'],
    "nirmi": ['mw'],
    "nirmimitsā": ['mw'],
    "nirminoti": ['bhs'],
    "nirmita": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "nirmitaka": ['bhs'],
    "nirmitanirmāṇa": ['bhs'],
    "nirmitarāga": ['mw'],
    "nirmithya": ['ddsa', 'mw'],
    "nirmiti": ['cae', 'ddsa', 'mw'],
    "nirmitiḥ": ['ap90'],
    "nirmitsu": ['mw'],
    "nirmiṇoti": ['bhs'],
    "nirmlukti": ['mw'],
    "nirmocaka": ['mw'],
    "nirmocana": ['bhs', 'mw'],
    "nirmocanaṃ": ['ap90'],
    "nirmocayitar": ['bhs'],
    "nirmogha": ['mw'],
    "nirmoha": ['mw'],
    "nirmoka": ['cae', 'mw'],
    "nirmokapaṭṭa": ['mw'],
    "nirmokaḥ": ['ap90'],
    "nirmoktṛ": ['mw'],
    "nirmokṣa": ['cae', 'mw'],
    "nirmokṣaḥ": ['ap90'],
    "nirmretuka": ['mw'],
    "nirmuc": ['ap90', 'mw'],
    "nirmuda": ['mw'],
    "nirmuh": ['mw'],
    "nirmukta": ['ap90', 'cae', 'mw'],
    "nirmuktadeha": ['mw'],
    "nirmuktakalmaṣa": ['mw'],
    "nirmuktasaṅga": ['mw'],
    "nirmukti": ['cae', 'ddsa', 'mw'],
    "nirmuktiḥ": ['ap90'],
    "nirmumukṣu": ['mw'],
    "nirmuṇḍa": ['mw'],
    "nirmuṣ": ['mw'],
    "nirmuṭa": ['mw'],
    "nirmā": ['ap90', 'cae', 'mw'],
    "nirmādayati": ['bhs'],
    "nirmādhyastha": ['mw'],
    "nirmākhya": ['mw'],
    "nirmālya": ['ap90', 'cae', 'mw'],
    "nirmālyadāman": ['mw'],
    "nirmālyaka": ['bhs'],
    "nirmālyatā": ['mw'],
    "nirmālyā": ['mw'],
    "nirmālī": ['mw'],
    "nirmāna": ['cae', 'mw'],
    "nirmānuṣa": ['cae', 'mw'],
    "nirmānuṣe": ['mw'],
    "nirmānuṣīkṛ": ['mw'],
    "nirmāra": ['mw'],
    "nirmārga": ['mw'],
    "nirmārguka": ['mw'],
    "nirmārjana": ['cae', 'mw'],
    "nirmārjanaṃ": ['ap90'],
    "nirmārjanīya": ['mw'],
    "nirmārṣṭi": ['mw'],
    "nirmāta": ['mw'],
    "nirmāthin": ['mw'],
    "nirmātṛ": ['cae', 'ddsa', 'mw'],
    "nirmātṛtva": ['mw'],
    "nirmātṛtā": ['mw'],
    "nirmāya": ['bhs', 'cae', 'gra', 'mw'],
    "nirmāṃsa": ['cae', 'mw'],
    "nirmāṇa": ['bhs', 'cae', 'mw'],
    "nirmāṇabuddha": ['bhs'],
    "nirmāṇakāraka": ['mw'],
    "nirmāṇakāya": ['bhs', 'mw'],
    "nirmāṇarata": ['mw'],
    "nirmāṇarati": ['bhs'],
    "nirmāṇaratideva": ['mw'],
    "nirmāṇatā": ['bhs'],
    "nirmāṇaṃ": ['ap90'],
    "nirmāṇika": ['bhs'],
    "nirmāṇāṅgulimālaka": ['bhs'],
    "nirmūl": ['ap90'],
    "nirmūla": ['cae', 'ddsa', 'mw'],
    "nirmūlana": ['mw'],
    "nirmūlanaṃ": ['ap90'],
    "nirmūlatā": ['mw'],
    "nirmūlaya": ['ddsa', 'mw'],
    "nirmūṣaka": ['ddsa', 'mw'],
    "nirmṛga": ['mw'],
    "nirmṛj": ['ap90', 'mw'],
    "nirmṛṣa": ['bhs'],
    "nirmṛṣṭa": ['ap90', 'mw'],
    "nirnamaskāra": ['cae', 'ddsa', 'mw'],
    "nirnamayati": ['bhs'],
    "nirnara": ['cae', 'mw'],
    "nirnaś": ['mw'],
    "nirnaṣṭa": ['mw'],
    "nirnidra": ['cae', 'mw'],
    "nirnidratā": ['mw'],
    "nirnimeṣa": ['cae', 'mw'],
    "nirnimitta": ['cae', 'mw'],
    "nirnimittakṛta": ['mw'],
    "nirnimittam": ['mw'],
    "nirnimittatva": ['mw'],
    "nirnirodha": ['mw'],
    "nirnābhi": ['mw'],
    "nirnābhikauśeya": ['mw'],
    "nirnāda": ['bhs'],
    "nirnādana": ['bhs'],
    "nirnādayati": ['bhs'],
    "nirnādita": ['bhs'],
    "nirnāditasūrya": ['bhs'],
    "nirnāma": ['bhs'],
    "nirnāmayati": ['bhs'],
    "nirnānākaraṇa": ['bhs'],
    "nirnāsa": ['cae'],
    "nirnātha": ['cae', 'mw'],
    "nirnāthatā": ['mw'],
    "nirnāyaka": ['cae', 'mw'],
    "nirnāyakatva": ['mw'],
    "nirnāśana": ['cae', 'mw'],
    "nirnāśin": ['cae', 'mw'],
    "nirnāṇaka": ['mw'],
    "nirnīḍa": ['mw'],
    "nirodaka": ['bhs'],
    "niroddhavya": ['mw'],
    "nirodha": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "nirodhadhamma": ['cped'],
    "nirodhajñāna": ['mw'],
    "nirodhaka": ['mw'],
    "nirodhalakṣaṇa": ['mw'],
    "nirodhalakṣaṇavivaraṇa": ['mw'],
    "nirodhana": ['cae', 'cped', 'mw'],
    "nirodhanimna": ['bhs'],
    "nirodhasamāpatti": ['bhs'],
    "nirodhavarṇana": ['mw'],
    "nirodhavivṛti": ['mw'],
    "nirodhaḥ": ['ap90'],
    "nirodhetabba": ['cped'],
    "nirodhetvā": ['cped'],
    "nirodhin": ['mw'],
    "niropadhi": ['bhs'],
    "niroṣṭhya": ['ddsa', 'mw'],
    "nirr̥ti‍‍": ['ddsa'],
    "nirubj": ['mw'],
    "nirucchvāsa": ['mw'],
    "nirucchvāsanipīḍita": ['mw'],
    "nirudaka": ['cae', 'mw'],
    "nirudara": ['cae', 'mw'],
    "niruddeśam": ['mw'],
    "niruddha": ['ap90', 'cae', 'cped', 'mw'],
    "niruddhaguda": ['mw'],
    "niruddhakaṇṭha": ['mw'],
    "niruddhaprakaśa": ['mw'],
    "niruddhati": ['cae', 'mw'],
    "niruddhavat": ['mw'],
    "niruddhaśamavṛtti": ['mw'],
    "niruddrāva": ['mw'],
    "nirudh": ['ap90', 'mw'],
    "nirudhyamāna": ['mw'],
    "nirudvega": ['cae', 'mw'],
    "nirudvigna": ['cae', 'mw'],
    "nirudvignamanas": ['mw'],
    "nirudyama": ['cae', 'mw'],
    "nirudyoga": ['cae', 'mw'],
    "niruh": ['mw'],
    "niruja": ['cae', 'mw'],
    "nirujjhamāna": ['cped'],
    "nirujjhati": ['cped'],
    "nirukta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "niruktabhāṣya": ['mw'],
    "niruktaga": ['mw'],
    "niruktaja": ['mw'],
    "niruktakāra": ['mw'],
    "niruktakṛt": ['mw'],
    "niruktapariśiṣṭa": ['mw'],
    "niruktavat": ['mw'],
    "niruktavṛtti": ['mw'],
    "nirukti": ['bhs', 'cae', 'mw'],
    "niruktikhaṇḍa": ['mw'],
    "niruktilakṣaṇa": ['mw'],
    "niruktiniyatapraveśa": ['bhs'],
    "niruktiprakāśa": ['mw'],
    "niruktiḥ": ['ap90'],
    "nirukṣ": ['mw'],
    "nirundhat": ['mw'],
    "nirundhāna": ['mw'],
    "nirunmāda": ['mw'],
    "nirupabhoga": ['mw'],
    "nirupadhi": ['cae', 'cped', 'mw'],
    "nirupadhijīvana": ['mw'],
    "nirupadhijīvanatā": ['mw'],
    "nirupadhika": ['cped'],
    "nirupadhipālitaprakṛtika": ['mw'],
    "nirupadhiśeṣa": ['bhs', 'mw'],
    "nirupadrava": ['cae', 'mw'],
    "nirupadravatā": ['mw'],
    "nirupaghāta": ['bhs'],
    "nirupahata": ['mw'],
    "nirupahatya": ['bhs'],
    "nirupahita": ['mw'],
    "nirupajīvitā": ['mw'],
    "nirupaka": ['bhs'],
    "nirupakrama": ['mw'],
    "nirupakriya": ['mw'],
    "nirupakārin": ['mw'],
    "nirupala": ['mw'],
    "nirupalepa": ['bhs', 'mw'],
    "nirupama": ['cae', 'mw'],
    "nirupamā": ['bhs', 'mw'],
    "nirupapada": ['cae', 'mw'],
    "nirupapatti": ['mw'],
    "nirupapattitva": ['mw'],
    "nirupaplava": ['cae', 'mw'],
    "nirupasarga": ['mw'],
    "nirupaskṛta": ['mw'],
    "nirupasthāyaka": ['mw'],
    "nirupasṛṣṭa": ['mw'],
    "nirupatāpa": ['cped'],
    "nirupavadya": ['bhs'],
    "nirupayoga": ['mw'],
    "nirupekṣa": ['mw'],
    "nirupti": ['mw'],
    "nirupya": ['mw'],
    "nirupādhi": ['mw'],
    "nirupādhika": ['mw'],
    "nirupādhiśeṣa": ['bhs'],
    "nirupādāna": ['bhs', 'mw'],
    "nirupādātṛka": ['bhs'],
    "nirupākhya": ['mw'],
    "nirupākhyatva": ['mw'],
    "nirupāya": ['cae', 'mw'],
    "nirupāyena": ['bhs'],
    "nirupāyāsa": ['bhs'],
    "niruta": ['mw'],
    "nirutkaṇṭha": ['cae', 'mw'],
    "nirutpāta": ['mw'],
    "nirutsava": ['cae', 'mw'],
    "nirutsavārambha": ['cae', 'mw'],
    "nirutseka": ['cae'],
    "nirutsuka": ['ap90', 'cae', 'mw'],
    "nirutsāha": ['cae', 'mw'],
    "nirutsāhatā": ['mw'],
    "niruttamaka": ['bhs'],
    "niruttara": ['cae', 'mw'],
    "niruttarīkṛ": ['mw'],
    "niruttha": ['mw'],
    "nirutti": ['cped'],
    "niruttipatha": ['cped'],
    "niruttipaṭisambhidā": ['cped'],
    "niruttrāsam": ['bhs'],
    "niruñchana": ['mw'],
    "niruṣman": ['mw'],
    "niruṣṇatā": ['mw'],
    "niruṣṇatāṃnī": ['mw'],
    "niruṣṇīṣa": ['mw'],
    "nirvac": ['ap90', 'mw'],
    "nirvacana": ['cae', 'mw'],
    "nirvacanam": ['mw'],
    "nirvacanaṃ": ['ap90'],
    "nirvacanīya": ['mw'],
    "nirvad": ['mw'],
    "nirvadh": ['mw'],
    "nirvah": ['ap90', 'mw'],
    "nirvahaṇa": ['cae', 'mw'],
    "nirvahaṇaṃ": ['ap90'],
    "nirvahitṛ": ['mw'],
    "nirvai": ['mw'],
    "nirvailakṣya": ['mw'],
    "nirvaira": ['cae', 'mw'],
    "nirvairam": ['mw'],
    "nirvairatā": ['mw'],
    "nirvaktavya": ['mw'],
    "nirvalkala": ['cae', 'mw'],
    "nirvam": ['mw'],
    "nirvamhaṇa": ['bhs'],
    "nirvana": ['mw'],
    "nirvap": ['ap90', 'mw'],
    "nirvapaṇa": ['ap90', 'cae', 'mw'],
    "nirvapaṇīya": ['mw'],
    "nirvaptavya": ['mw'],
    "nirvara": ['mw'],
    "nirvartaka": ['ap90', 'mw'],
    "nirvartana": ['cae', 'mw'],
    "nirvartanaṃ": ['ap90'],
    "nirvartanīya": ['cae'],
    "nirvartayitavya": ['cae'],
    "nirvarti": ['mw'],
    "nirvartin": ['ap90', 'mw'],
    "nirvartitavya": ['mw'],
    "nirvartya": ['cae', 'mw'],
    "nirvartyatva": ['mw'],
    "nirvaruṇam": ['mw'],
    "nirvaruṇatva": ['mw'],
    "nirvaruṇatā": ['mw'],
    "nirvarvin": ['cae'],
    "nirvarṇ": ['ap90', 'mw'],
    "nirvarṇana": ['mw'],
    "nirvarṇanaṃ": ['ap90'],
    "nirvarṇanīya": ['bhs', 'mw'],
    "nirvas": ['ap90', 'mw'],
    "nirvastra": ['mw'],
    "nirvastrīkṛ": ['mw'],
    "nirvastuka": ['bhs'],
    "nirvasu": ['cae', 'mw'],
    "nirvasutva": ['mw'],
    "nirvatsala": ['cae', 'mw'],
    "nirvatsaśiśupuṃgava": ['mw'],
    "nirvayanī": ['ap90'],
    "nirvañc": ['mw'],
    "nirvaśa": ['cae', 'mw'],
    "nirvaśatā": ['mw'],
    "nirvaṃśa": ['cae', 'ddsa', 'mw'],
    "nirvaṃśaka": ['mw'],
    "nirvaṇa": ['bhs', 'mw'],
    "nirvaṇe": ['mw'],
    "nirvaṣaṭkāramaṅgala": ['mw'],
    "nirveda": ['cae', 'mw'],
    "nirvedaduḥsaham": ['cae', 'mw'],
    "nirvedavat": ['mw'],
    "nirvedaḥ": ['ap90'],
    "nirvedha": ['bhs', 'mw'],
    "nirvedhabhāgīya": ['bhs', 'mw'],
    "nirvedhana": ['bhs'],
    "nirvedhika": ['bhs'],
    "nirvedhima": ['mw'],
    "nirveditvā": ['bhs'],
    "nirvega": ['ddsa', 'mw'],
    "nirvepana": ['cae', 'mw'],
    "nirvetana": ['mw'],
    "nirveśa": ['cae', 'mw'],
    "nirveśanīya": ['mw'],
    "nirveśaḥ": ['ap90'],
    "nirveśya": ['cae', 'mw'],
    "nirveṣṭ": ['mw'],
    "nirveṣṭana": ['mw'],
    "nirveṣṭanaṃ": ['ap90'],
    "nirveṣṭavya": ['cae', 'mw'],
    "nirveṣṭita": ['mw'],
    "nirveṭhana": ['bhs'],
    "nirveṭhayati": ['bhs'],
    "nirvibandha": ['mw'],
    "nirvibhās": ['mw'],
    "nirviceṣṭa": ['cae', 'mw'],
    "nirvicikitsa": ['mw'],
    "nirvicikitsam": ['mw'],
    "nirvicāra": ['cae', 'mw'],
    "nirvicāram": ['mw'],
    "nirvid": ['ap90', 'ddsa', 'mw'],
    "nirviddha": ['mw'],
    "nirvidhitsa": ['mw'],
    "nirvidhitsu": ['mw'],
    "nirvidya": ['cae', 'mw'],
    "nirvidā": ['bhs'],
    "nirvighaṭṭa": ['bhs'],
    "nirvighaṭṭam": ['mw'],
    "nirvighna": ['cae', 'mw'],
    "nirvighnam": ['mw'],
    "nirvighnena": ['mw'],
    "nirvihaṃga": ['mw'],
    "nirvihāra": ['mw'],
    "nirvikalpa": ['cae', 'ddsa', 'mw'],
    "nirvikalpaka": ['cae', 'mw'],
    "nirvikalpam": ['mw'],
    "nirvikalpavicāra": ['mw'],
    "nirvikalpavāda": ['mw'],
    "nirvikalpayati": ['bhs'],
    "nirvikram": ['mw'],
    "nirvikāra": ['cae', 'mw'],
    "nirvikāratā": ['mw'],
    "nirvikāsa": ['mw'],
    "nirvikāsatva": ['mw'],
    "nirvimarśa": ['cae', 'mw'],
    "nirvindhyā": ['cae', 'mw'],
    "nirvinoda": ['cae', 'mw'],
    "nirvirodha": ['mw'],
    "nirvisarga": ['mw'],
    "nirvitarka": ['mw'],
    "nirvivah": ['mw'],
    "nirvivara": ['mw'],
    "nirvivaratā": ['mw'],
    "nirviveka": ['mw'],
    "nirvivekatva": ['mw'],
    "nirvivekatā": ['mw'],
    "nirvivikṣat": ['mw'],
    "nirvivikṣu": ['mw'],
    "nirvivitsu": ['mw'],
    "nirvivāda": ['mw'],
    "nirvivādīkṛ": ['mw'],
    "nirviś": ['ap90', 'mw'],
    "nirviśaṅka": ['cae', 'ddsa', 'mw'],
    "nirviśaṅkam": ['mw'],
    "nirviśaṅkena": ['mw'],
    "nirviśaṅkita": ['cae', 'mw'],
    "nirviśaṅkitam": ['mw'],
    "nirviśeṣa": ['cae', 'mw'],
    "nirviśeṣam": ['mw'],
    "nirviśeṣatva": ['mw'],
    "nirviśeṣatā": ['mw'],
    "nirviśeṣavat": ['mw'],
    "nirviśeṣaṇa": ['mw'],
    "nirviśeṣeṇa": ['mw'],
    "nirviśeṣākṛti": ['mw'],
    "nirviśiṣṭa": ['bhs'],
    "nirviśṝ": ['mw'],
    "nirviṇṇa": ['ap90', 'cae', 'mw'],
    "nirviṇṇacetas": ['mw'],
    "nirviṣa": ['cae', 'mw'],
    "nirviṣaya": ['cae', 'mw'],
    "nirviṣayatva": ['mw'],
    "nirviṣayoparāga": ['mw'],
    "nirviṣaṅga": ['mw'],
    "nirviṣāṇa": ['mw'],
    "nirviṣī": ['bhs'],
    "nirviṣīkaraṇa": ['bhs'],
    "nirviṣīkṛ": ['mw'],
    "nirviṣṭa": ['ap90', 'cae', 'mw'],
    "nirvlayanī": ['mw'],
    "nirvlī": ['mw'],
    "nirvoḍhṛ": ['cae', 'mw'],
    "nirvraj": ['mw'],
    "nirvraska": ['cae', 'mw'],
    "nirvrata": ['cae', 'mw'],
    "nirvraśc": ['mw'],
    "nirvraṇa": ['cae', 'mw'],
    "nirvraṇita": ['mw'],
    "nirvrīḍa": ['cae', 'mw'],
    "nirvyadh": ['mw'],
    "nirvyagra": ['mw'],
    "nirvyalīka": ['mw'],
    "nirvyalīkam": ['mw'],
    "nirvyalīkatas": ['mw'],
    "nirvyapatrapa": ['mw'],
    "nirvyapekṣa": ['cae', 'mw'],
    "nirvyasana": ['mw'],
    "nirvyatha": ['mw'],
    "nirvyathana": ['mw'],
    "nirvyathanaṃ": ['ap90'],
    "nirvyavadhāna": ['mw'],
    "nirvyavastha": ['mw'],
    "nirvyañjaka": ['ddsa', 'mw'],
    "nirvyañjana": ['mw'],
    "nirvyañjane": ['mw'],
    "nirvyuṣita": ['mw'],
    "nirvyādadāti": ['bhs'],
    "nirvyādhi": ['cae', 'mw'],
    "nirvyādhita": ['bhs'],
    "nirvyāghra": ['mw'],
    "nirvyāja": ['cae', 'mw'],
    "nirvyājam": ['mw'],
    "nirvyājatā": ['mw'],
    "nirvyājīkṛta": ['mw'],
    "nirvyākula": ['cae', 'ddsa', 'mw'],
    "nirvyākulatā": ['mw'],
    "nirvyāpāra": ['cae', 'mw'],
    "nirvyāpāratva": ['mw'],
    "nirvyāvṛtti": ['mw'],
    "nirvyūha": ['cae', 'mw'],
    "nirvyūhati": ['bhs'],
    "nirvyūḍha": ['ap90', 'cae', 'mw'],
    "nirvyūḍhi": ['cae', 'mw'],
    "nirvyūḍhiḥ": ['ap90'],
    "nirvā": ['ap90', 'mw'],
    "nirvāc": ['cae', 'mw'],
    "nirvācya": ['cae', 'ddsa', 'mw'],
    "nirvāda": ['cae', 'mw'],
    "nirvādaḥ": ['ap90'],
    "nirvāha": ['bhs', 'cae', 'mw'],
    "nirvāhaka": ['cae', 'mw'],
    "nirvāhakatā": ['mw'],
    "nirvāhaḥ": ['ap90'],
    "nirvāhaṇa": ['ap90', 'mw'],
    "nirvāhikā": ['mw'],
    "nirvāhin": ['ap90', 'mw'],
    "nirvāhya": ['cae', 'mw'],
    "nirvāka": ['mw'],
    "nirvākya": ['cae', 'mw'],
    "nirvānara": ['mw'],
    "nirvānta": ['bhs', 'mw'],
    "nirvāpa": ['cae', 'mw'],
    "nirvāpaka": ['cae', 'mw'],
    "nirvāpanīya": ['bhs'],
    "nirvāpayitṛ": ['ap90', 'cae', 'mw'],
    "nirvāpayitṛka": ['cae'],
    "nirvāpaḥ": ['ap90'],
    "nirvāpaṇa": ['cae', 'ddsa', 'mw'],
    "nirvāpaṇaṃ": ['ap90'],
    "nirvāpita": ['mw'],
    "nirvāpya": ['ddsa', 'mw'],
    "nirvārita": ['mw'],
    "nirvārāṇasi": ['mw'],
    "nirvāsa": ['cae', 'ddsa', 'mw'],
    "nirvāsana": ['cae', 'mw'],
    "nirvāsanīya": ['cae', 'mw'],
    "nirvāsaḥ": ['ap90'],
    "nirvāsita": ['mw'],
    "nirvāsya": ['cae', 'mw'],
    "nirvāta": ['cae', 'ddsa', 'mw'],
    "nirvātastha": ['mw'],
    "nirvāyasa": ['ddsa', 'mw'],
    "nirvāyate": ['bhs'],
    "nirvāñc": ['mw'],
    "nirvāṇa": ['ap90', 'cae', 'mw'],
    "nirvāṇabhūyiṣṭha": ['mw'],
    "nirvāṇada": ['mw'],
    "nirvāṇadaśaka": ['mw'],
    "nirvāṇadhātu": ['mw'],
    "nirvāṇadīkṣita": ['mw'],
    "nirvāṇakara": ['mw'],
    "nirvāṇakāṇḍa": ['mw'],
    "nirvāṇalakṣaṇa": ['mw'],
    "nirvāṇamantra": ['mw'],
    "nirvāṇamastaka": ['mw'],
    "nirvāṇamaya": ['mw'],
    "nirvāṇamaṇḍapa": ['mw'],
    "nirvāṇaprakaraṇa": ['mw'],
    "nirvāṇapriyā": ['bhs', 'mw'],
    "nirvāṇapurāṇa": ['mw'],
    "nirvāṇaruci": ['mw'],
    "nirvāṇasaṃcodana": ['mw'],
    "nirvāṇasūtra": ['mw'],
    "nirvāṇatantra": ['mw'],
    "nirvāṇayitṛ": ['cae'],
    "nirvāṇayitṛka": ['cae'],
    "nirvāṇayogapaṭalastotra": ['mw'],
    "nirvāṇayogottara": ['mw'],
    "nirvāṇaṣaṭka": ['mw'],
    "nirvāṇika": ['bhs'],
    "nirvāṇin": ['mw'],
    "nirvāṇopaniṣad": ['mw'],
    "nirvāṇāṅgulimālika": ['bhs'],
    "nirvāṇī": ['mw'],
    "nirvīja": ['mw'],
    "nirvīra": ['cae', 'mw'],
    "nirvīratā": ['mw'],
    "nirvīrudh": ['mw'],
    "nirvīrya": ['cae', 'mw'],
    "nirvīryatā": ['mw'],
    "nirvīrā": ['mw'],
    "nirvṛ": ['ap90', 'mw'],
    "nirvṛkṣa": ['cae', 'ddsa', 'mw'],
    "nirvṛkṣamṛgapakṣin": ['mw'],
    "nirvṛkṣatoya": ['mw'],
    "nirvṛt": ['ap90', 'mw'],
    "nirvṛta": ['ap90', 'bhs', 'cae', 'mw'],
    "nirvṛtaka": ['bhs'],
    "nirvṛti": ['bhs', 'cae', 'ddsa', 'mw'],
    "nirvṛticakṣus": ['mw'],
    "nirvṛtimat": ['mw'],
    "nirvṛtisthāna": ['mw'],
    "nirvṛtiśatru": ['mw'],
    "nirvṛtiḥ": ['ap90'],
    "nirvṛtta": ['ap90', 'bhs', 'cae', 'mw'],
    "nirvṛttacūḍaka": ['mw'],
    "nirvṛttamātra": ['mw'],
    "nirvṛttaśatru": ['mw'],
    "nirvṛtti": ['ap90', 'cae', 'mw'],
    "nirvṛṣa": ['mw'],
    "nirvṛṣṭa": ['mw'],
    "nirvṛṣṭi": ['mw'],
    "niryantraṇa": ['cae', 'mw'],
    "niryantraṇam": ['mw'],
    "niryantraṇapradeśāvasthita": ['mw'],
    "niryat": ['ap90', 'mw'],
    "niryatna": ['ddsa', 'mw'],
    "niryatnatā": ['mw'],
    "niryaśaska": ['mw'],
    "niryeṣ": ['mw'],
    "niryiyāsu": ['mw'],
    "niryoga": ['mw'],
    "niryogakṣema": ['cae', 'mw'],
    "niryola": ['mw'],
    "niryu": ['mw'],
    "niryukta": ['mw'],
    "niryukti": ['mw'],
    "niryuktika": ['mw'],
    "niryuktikatva": ['mw'],
    "niryā": ['ap90', 'mw'],
    "niryāc": ['mw'],
    "niryādava": ['mw'],
    "niryādayati": ['bhs'],
    "niryāma": ['mw'],
    "niryāmaka": ['bhs', 'mw'],
    "niryāmaḥ": ['ap90'],
    "niryāmaṇā": ['mw'],
    "niryāpaṇa": ['cae', 'mw'],
    "niryāpaṇaṃ": ['ap90'],
    "niryāpita": ['mw'],
    "niryāsa": ['cae', 'mw'],
    "niryāsaḥ": ['ap90'],
    "niryāsika": ['mw'],
    "niryāsyā": ['mw'],
    "niryāta": ['bhs', 'mw'],
    "niryātaka": ['mw'],
    "niryātana": ['cae', 'mw'],
    "niryātanaṃ": ['ap90'],
    "niryātanā": ['bhs'],
    "niryātayati": ['bhs'],
    "niryāti": ['bhs', 'mw'],
    "niryātita": ['mw'],
    "niryātitaka": ['bhs'],
    "niryātiḥ": ['ap90'],
    "niryātya": ['cae', 'mw'],
    "niryātṛ": ['mw'],
    "niryāṇa": ['bhs', 'cae', 'mw'],
    "niryāṇahasta": ['mw'],
    "niryāṇaṃ": ['ap90'],
    "niryāṇika": ['bhs', 'mw'],
    "niryūha": ['bhs', 'cae', 'mw'],
    "niryūhati": ['bhs'],
    "niryūhaḥ": ['ap90'],
    "niryūtha": ['mw'],
    "niryūṣa": ['mw'],
    "nirābhiramya": ['bhs'],
    "nirābhāsa": ['mw'],
    "nirābādha": ['cae', 'mw'],
    "nirābādhakara": ['mw'],
    "nirābādham": ['mw'],
    "nirācakṣ": ['mw'],
    "nirācikīrṣu": ['mw'],
    "nirācāra": ['mw'],
    "nirādara": ['mw'],
    "nirādeśa": ['mw'],
    "nirādeśaḥ": ['ap90'],
    "nirādhi": ['mw'],
    "nirādhā": ['mw'],
    "nirādhāna": ['mw'],
    "nirādhāra": ['mw'],
    "nirādhāratva": ['mw'],
    "nirādiṣṭa": ['ap90', 'cae', 'mw'],
    "nirādāna": ['mw'],
    "nirādīnava": ['cped'],
    "nirāga": ['ap90', 'cae', 'mw'],
    "nirāgama": ['mw'],
    "nirāgas": ['cae', 'mw'],
    "nirāgraha": ['mw'],
    "nirāgāra": ['cae', 'mw'],
    "nirāha": ['mw'],
    "nirāhava": ['mw'],
    "nirāhavavat": ['mw'],
    "nirāhāra": ['cae', 'mw'],
    "nirāhāratā": ['mw'],
    "nirāja": ['mw'],
    "nirājīvya": ['mw'],
    "nirāka": ['mw'],
    "nirākaraṇa": ['cae', 'ddsa', 'mw'],
    "nirākaraṇaṃ": ['ap90'],
    "nirākaraṇīya": ['mw'],
    "nirākariṣṇu": ['ap90', 'cae', 'mw'],
    "nirākariṣṇutā": ['mw'],
    "nirākartavya": ['mw'],
    "nirākartṛ": ['mw'],
    "nirākata": ['cped'],
    "nirākaḥ": ['ap90'],
    "nirākram": ['mw'],
    "nirākranda": ['mw'],
    "nirākriyā": ['cae', 'mw'],
    "nirākrośa": ['mw'],
    "nirākula": ['ap90', 'cae', 'mw'],
    "nirākuladvāra": ['mw'],
    "nirākulam": ['mw'],
    "nirākulārtham": ['mw'],
    "nirākāra": ['cae', 'mw'],
    "nirākārajñānavāda": ['mw'],
    "nirākāralocana": ['mw'],
    "nirākāraḥ": ['ap90'],
    "nirākāśa": ['mw'],
    "nirākāṅkṣa": ['cae', 'mw'],
    "nirākāṅkṣin": ['cae'],
    "nirākṛ": ['ap90', 'mw'],
    "nirākṛta": ['ap90', 'mw'],
    "nirākṛtanimeṣa": ['mw'],
    "nirākṛti": ['cae', 'mw'],
    "nirākṛtin": ['mw'],
    "nirākṛtiḥ": ['ap90'],
    "nirākṛtānyottara": ['mw'],
    "nirākṛtānyottaratva": ['mw'],
    "nirālaka": ['mw'],
    "nirālamba": ['cae', 'mw'],
    "nirālambam": ['mw'],
    "nirālambana": ['cae', 'mw'],
    "nirālambatva": ['mw'],
    "nirālambopaniṣad": ['mw'],
    "nirālambya": ['bhs'],
    "nirālambā": ['mw'],
    "nirālasya": ['mw'],
    "nirālaya": ['bhs'],
    "nirāloka": ['cae', 'mw'],
    "nirālāpa": ['mw'],
    "nirāmagandha": ['bhs', 'cped'],
    "nirāmarda": ['mw'],
    "nirāmarṣa": ['mw'],
    "nirāmaya": ['cae', 'mw'],
    "nirāmayam": ['mw'],
    "nirāmika": ['bhs'],
    "nirāmin": ['cae', 'gra', 'mw'],
    "nirāmisa": ['cped'],
    "nirāmitra": ['mw'],
    "nirāmiṣa": ['bhs', 'cae', 'mw'],
    "nirāmiṣāśin": ['cae', 'mw'],
    "nirāmālu": ['mw'],
    "nirāmāluḥ": ['ap90'],
    "nirānanda": ['cae', 'mw'],
    "nirānandakara": ['cae', 'mw'],
    "nirāntra": ['mw'],
    "nirānurakta": ['bhs'],
    "nirāpad": ['cae', 'mw'],
    "nirāparādha": ['bhs'],
    "nirārambha": ['bhs', 'cped', 'mw'],
    "nirāsa": ['cae', 'cped', 'mw'],
    "nirāsaguṭikā": ['mw'],
    "nirāsaka": ['mw'],
    "nirāsana": ['mw'],
    "nirāsasa": ['cped'],
    "nirāsatti": ['cped'],
    "nirāsaya": ['cped'],
    "nirāsaḥ": ['ap90'],
    "nirāsaṅga": ['mw'],
    "nirāsitva": ['mw'],
    "nirāspada": ['mw'],
    "nirāsrava": ['mw'],
    "nirāstha": ['mw'],
    "nirāsu": ['mw'],
    "nirāsvāda": ['cae', 'mw'],
    "nirāsvādarasa": ['mw'],
    "nirāsvādya": ['cae', 'mw'],
    "nirāsvādyatama": ['mw'],
    "nirāsāsa": ['cped'],
    "nirātapa": ['cae', 'mw'],
    "nirātapatra": ['cae', 'mw'],
    "nirātapā": ['mw'],
    "nirātaṅka": ['cae', 'mw'],
    "nirātithya": ['mw'],
    "nirātmaka": ['mw'],
    "nirātman": ['mw'],
    "nirātmatva": ['mw'],
    "nirātmavat": ['mw'],
    "nirāvah": ['mw'],
    "nirāvaraṇa": ['mw'],
    "nirāvarṣa": ['mw'],
    "nirāviś": ['mw'],
    "nirāya": ['mw'],
    "nirāyam": ['mw'],
    "nirāyata": ['mw'],
    "nirāyatapūrvakāya": ['mw'],
    "nirāyatatva": ['mw'],
    "nirāyati": ['mw'],
    "nirāyavyayavat": ['mw'],
    "nirāyudha": ['mw'],
    "nirāyāsa": ['mw'],
    "nirāśa": ['cae', 'mw'],
    "nirāśaguṭikā": ['mw'],
    "nirāśaka": ['mw'],
    "nirāśakara": ['mw'],
    "nirāśatva": ['mw'],
    "nirāśatā": ['mw'],
    "nirāśaya": ['mw'],
    "nirāśaṅka": ['cae', 'mw'],
    "nirāśaṅkam": ['mw'],
    "nirāśaṅkya": ['mw'],
    "nirāśin": ['cae', 'mw'],
    "nirāśis": ['cae', 'mw'],
    "nirāśitva": ['mw'],
    "nirāśrama": ['mw'],
    "nirāśramapada": ['mw'],
    "nirāśraya": ['cae', 'mw'],
    "nirāśā": ['cae', 'mw'],
    "nirāśāsanna": ['mw'],
    "nirāśībhāva": ['mw'],
    "nirāśībhūta": ['mw'],
    "nirāśīstva": ['mw'],
    "nirāḍambara": ['mw'],
    "nirāḍambarasundara": ['mw'],
    "nirāṇaddha": ['mw'],
    "nirī": ['mw'],
    "nirīha": ['cae', 'mw'],
    "nirīhaka": ['bhs'],
    "nirīhatva": ['mw'],
    "nirīhatā": ['mw'],
    "nirīhika": ['bhs'],
    "nirīhā": ['mw'],
    "nirīhāvasthā": ['mw'],
    "nirīkṣ": ['ap90', 'mw'],
    "nirīkṣaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "nirīkṣayā": ['mw'],
    "nirīkṣaṇa": ['cae', 'mw'],
    "nirīkṣaṇaṃ": ['ap90'],
    "nirīkṣin": ['mw'],
    "nirīkṣitavya": ['cae', 'mw'],
    "nirīkṣya": ['cae', 'mw'],
    "nirīkṣyamāṇa": ['mw'],
    "nirīkṣyate": ['bhs'],
    "nirīkṣā": ['cae', 'mw'],
    "nirīti": ['ddsa', 'mw'],
    "nirītika": ['mw'],
    "nirīśa": ['mw'],
    "nirīśaṃ": ['ap90'],
    "nirīśvara": ['mw'],
    "nirīśvarasāṃkhyaśāstra": ['mw'],
    "nirīśvaravāda": ['mw'],
    "nirīśvaravādin": ['mw'],
    "nirīṣa": ['mw'],
    "nirīṣaṃ": ['ap90'],
    "nirūdaka": ['mw'],
    "nirūh": ['mw'],
    "nirūha": ['mw'],
    "nirūhamārga": ['bhs'],
    "nirūhavastividhi": ['mw'],
    "nirūhaḥ": ['ap90'],
    "nirūhaṇa": ['mw'],
    "nirūhaṇaṃ": ['ap90'],
    "nirūhita": ['mw'],
    "nirūhādhikāra": ['mw'],
    "nirūp": ['ap90', 'mw'],
    "nirūpaka": ['ddsa', 'mw'],
    "nirūpama": ['mw'],
    "nirūpayitavya": ['cae', 'mw'],
    "nirūpaṇa": ['cae', 'mw'],
    "nirūpaṇaṃ": ['ap90'],
    "nirūpaṇā": ['mw'],
    "nirūpaṇīya": ['mw'],
    "nirūpita": ['ap90', 'mw'],
    "nirūpiti": ['mw'],
    "nirūpitiḥ": ['ap90'],
    "nirūpya": ['cae', 'mw'],
    "nirūpyatva": ['mw'],
    "nirūpyatā": ['mw'],
    "nirūpākhya": ['mw'],
    "nirūḍha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "nirūḍhalakṣaṇā": ['mw'],
    "nirūḍhamūla": ['mw'],
    "nirūḍhapaśubandha": ['mw'],
    "nirūḍhapaśubandhahautraprayoga": ['mw'],
    "nirūḍhapaśubandhamaitrāvaruṇaprayoga": ['mw'],
    "nirūḍhapaśubandhaprayoga": ['mw'],
    "nirūḍhapaśupaddhati": ['mw'],
    "nirūḍhaśiras": ['mw'],
    "nirūḍhi": ['ddsa', 'mw'],
    "nirūḍhiḥ": ['ap90'],
    "nirūṣman": ['mw'],
    "nirūṣmatva": ['mw'],
    "nirḍīna": ['mw'],
    "nirṇam": ['mw'],
    "nirṇamana": ['mw'],
    "nirṇara": ['mw'],
    "nirṇaraḥ": ['ap90'],
    "nirṇata": ['cae', 'mw'],
    "nirṇatatama": ['mw'],
    "nirṇatodara": ['mw'],
    "nirṇaya": ['cae', 'ddsa', 'mw'],
    "nirṇayabhāskara": ['mw'],
    "nirṇayabindu": ['mw'],
    "nirṇayacandrikā": ['mw'],
    "nirṇayadarpaṇa": ['mw'],
    "nirṇayadīpa": ['mw'],
    "nirṇayadīpaka": ['mw'],
    "nirṇayadīpikā": ['mw'],
    "nirṇayakamalākara": ['mw'],
    "nirṇayakaumudī": ['mw'],
    "nirṇayakaustubha": ['mw'],
    "nirṇayamañjarī": ['mw'],
    "nirṇayana": ['bhs', 'mw'],
    "nirṇayanaṃ": ['ap90'],
    "nirṇayapāda": ['mw'],
    "nirṇayaratna": ['mw'],
    "nirṇayaratnadīpikā": ['mw'],
    "nirṇayaratnākara": ['mw'],
    "nirṇayasamudāya": ['mw'],
    "nirṇayasaṃgraha": ['mw'],
    "nirṇayasiddhānta": ['mw'],
    "nirṇayasindhu": ['mw'],
    "nirṇayasāra": ['mw'],
    "nirṇayataraṇi": ['mw'],
    "nirṇayatattva": ['mw'],
    "nirṇayavivaraṇa": ['mw'],
    "nirṇayaḥ": ['ap90'],
    "nirṇayoddhāra": ['mw'],
    "nirṇayopamā": ['cae', 'mw'],
    "nirṇayāmṛta": ['mw'],
    "nirṇayārthapradīpa": ['mw'],
    "nirṇayārṇava": ['mw'],
    "nirṇega": ['mw'],
    "nirṇejaka": ['cae', 'mw'],
    "nirṇejakaḥ": ['ap90'],
    "nirṇejana": ['cae', 'mw'],
    "nirṇejanaṃ": ['ap90'],
    "nirṇeka": ['cae', 'mw'],
    "nirṇekaḥ": ['ap90'],
    "nirṇetṛ": ['ap90', 'cae', 'mw'],
    "nirṇetṛtva": ['mw'],
    "nirṇeya": ['mw'],
    "nirṇij": ['ap90', 'cae', 'gra', 'mw'],
    "nirṇikta": ['ap90', 'cae', 'mw'],
    "nirṇiktabāhuvalaya": ['mw'],
    "nirṇiktamanas": ['mw'],
    "nirṇikti": ['cae', 'ddsa', 'mw'],
    "nirṇiktiḥ": ['ap90'],
    "nirṇoda": ['cae', 'mw'],
    "nirṇodaḥ": ['ap90'],
    "nirṇud": ['ap90', 'mw'],
    "nirṇāma": ['cae', 'mw'],
    "nirṇāmayati": ['bhs'],
    "nirṇāmaḥ": ['ap90'],
    "nirṇānaka": ['cae'],
    "nirṇāyaka": ['ap90', 'mw'],
    "nirṇāyana": ['mw'],
    "nirṇāyanaṃ": ['ap90'],
    "nirṇī": ['ap90', 'mw'],
    "nirṇīta": ['ap90', 'cae', 'mw'],
    "nirṛ": ['ap90', 'mw'],
    "nirṛch": ['mw'],
    "nirṛj": ['mw'],
    "nirṛta": ['ap90', 'mw'],
    "nirṛtha": ['cae', 'gra', 'mw'],
    "nirṛti": ['cae', 'gra', 'mw'],
    "nirṛtigṛhīta": ['mw'],
    "nirṛtipāśa": ['mw'],
    "nirṛtiḥ": ['ap90'],
    "nirṛṇa": ['mw'],
    "nirṛṇin": ['mw'],
    "nis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nisabha": ['cped'],
    "nisabhavatā": ['cped'],
    "nisadā": ['cped'],
    "nisadāpota": ['cped'],
    "nisadāpotaka": ['cped'],
    "nisajja": ['cped'],
    "nisajjati": ['cped'],
    "nisajjā": ['cped'],
    "nisamma": ['cped'],
    "nisammakāri(n)": ['cped'],
    "nisampāta": ['mw'],
    "nisandi": ['mw'],
    "nisanti": ['cped'],
    "nisara": ['mw'],
    "nisarga": ['cae', 'ddsa', 'mw'],
    "nisargabhinna": ['mw'],
    "nisargabhāva": ['mw'],
    "nisargaja": ['cae', 'mw'],
    "nisarganipuṇa": ['cae', 'mw'],
    "nisargapadva": ['mw'],
    "nisargasauhṛda": ['cae', 'mw'],
    "nisargasiddha": ['mw'],
    "nisargatas": ['mw'],
    "nisargavinīta": ['mw'],
    "nisargaśālīna": ['cae', 'mw'],
    "nisargaḥ": ['ap90'],
    "nisargeṇa": ['mw'],
    "nisargāt": ['mw'],
    "nisarpa": ['mw'],
    "nisattva": ['bhs'],
    "nisaṃjña": ['mw'],
    "nisaṃkakṣa": ['mw'],
    "nisaṃpāta": ['ap90'],
    "nisaṃśayam": ['bhs'],
    "nisaṅkhati": ['cped'],
    "nisaṅkhiti": ['cped'],
    "nisedha": ['cped'],
    "nisedhati": ['cped'],
    "nisedhayati": ['cped'],
    "nisedhesuṁ": ['cped'],
    "nisedhetabba": ['cped'],
    "nisedheti": ['cped'],
    "nisevati": ['cped'],
    "nisevita": ['cped'],
    "nisevitavya": ['mw'],
    "nisindhu": ['mw'],
    "nisindhuka": ['mw'],
    "nisinna": ['cped'],
    "nisinnaka": ['cped'],
    "nisneha": ['mw'],
    "nisnāta": ['mw'],
    "nisnāva": ['mw'],
    "nisnāvaḥ": ['ap90'],
    "nispanda": ['mw'],
    "nispaṃda": ['ap90'],
    "nisphul": ['mw'],
    "nisphur": ['mw'],
    "nispṛh": ['mw'],
    "nispṛha": ['mw'],
    "nispṛś": ['gra', 'mw'],
    "nisrava": ['cae', 'mw'],
    "nisravaḥ": ['ap90'],
    "nisru": ['mw'],
    "nisruta": ['mw'],
    "nisrāva": ['bhs', 'cae', 'mw'],
    "nissaggiya": ['cped'],
    "nissajita": ['cped'],
    "nissajitvā": ['cped'],
    "nissajitvāna": ['cped'],
    "nissajiṁ": ['cped'],
    "nissajjati": ['cped'],
    "nissajjeta": ['cped'],
    "nissajjita": ['cped'],
    "nissajjitabba": ['cped'],
    "nissajjitvā": ['cped'],
    "nissajjitvāna": ['cped'],
    "nissajjiṁ": ['cped'],
    "nissanda": ['cped'],
    "nissarati": ['cped'],
    "nissaraṇa": ['cped'],
    "nissaraṇīya": ['cped'],
    "nissaya": ['cped'],
    "nissaya(t)": ['cped'],
    "nissayakaraṇīya": ['cped'],
    "nissayana": ['cped'],
    "nissayasampanna": ['cped'],
    "nissayati": ['cped'],
    "nissaṭa": ['cped'],
    "nissaṭṭha": ['cped'],
    "nissenī": ['cped'],
    "nisseṇī": ['cped'],
    "nissinnokasa": ['cped'],
    "nissita": ['cped'],
    "nissitajappi(n)": ['cped'],
    "nisssajja": ['cped'],
    "nissuta": ['cped'],
    "nissāraṇa": ['cped'],
    "nissāraṇīya": ['cped'],
    "nissāreti": ['cped'],
    "nissārita": ['cped'],
    "nissārīyati": ['cped'],
    "nissāya": ['cped'],
    "nistabdha": ['ap90', 'mw'],
    "nistakṣ": ['mw'],
    "nistala": ['mw'],
    "nistamaska": ['cae', 'ddsa', 'mw'],
    "nistambha": ['mw'],
    "nistamisra": ['mw'],
    "nistandra": ['mw'],
    "nistandratā": ['mw'],
    "nistandri": ['mw'],
    "nistandrī": ['mw'],
    "nistantra": ['mw'],
    "nistantu": ['mw'],
    "nistanī": ['ap90', 'mw'],
    "nistap": ['mw'],
    "nistara": ['bhs'],
    "nistaraṃga": ['mw'],
    "nistaraṇa": ['cae', 'mw'],
    "nistaraṇaṃ": ['ap90'],
    "nistaraṇīya": ['mw'],
    "nistarha": ['mw'],
    "nistarhaṇa": ['mw'],
    "nistarhaṇaṃ": ['ap90'],
    "nistarkya": ['mw'],
    "nistartavya": ['mw'],
    "nistarīka": ['mw'],
    "nistarīpa": ['mw'],
    "nistattva": ['mw'],
    "nistejas": ['cae', 'ddsa', 'mw'],
    "nistimira": ['mw'],
    "nistitīrṣat": ['mw'],
    "nistoda": ['mw'],
    "nistodana": ['mw'],
    "nistodaḥ": ['ap90'],
    "nistoya": ['mw'],
    "nistoyatṛṇapādapa": ['mw'],
    "nistraiguṇya": ['cae', 'mw'],
    "nistraiṇapuṣpaka": ['mw'],
    "nistrapa": ['ddsa', 'mw'],
    "nistras": ['mw'],
    "nistraṃśa": ['mw'],
    "nistriṃśa": ['cae', 'mw'],
    "nistriṃśabhṛt": ['mw'],
    "nistriṃśadharmin": ['mw'],
    "nistriṃśadhārin": ['mw'],
    "nistriṃśakarkaśa": ['cae', 'mw'],
    "nistriṃśapattraka": ['mw'],
    "nistriṃśapattrikā": ['mw'],
    "nistriṃśatva": ['mw'],
    "nistriṃśin": ['mw'],
    "nistruṭī": ['ap90', 'mw'],
    "nistud": ['mw'],
    "nistula": ['mw'],
    "nistuti": ['mw'],
    "nistuṣa": ['ddsa', 'mw'],
    "nistuṣakṣīra": ['mw'],
    "nistuṣakṣīrin": ['mw'],
    "nistuṣaratna": ['mw'],
    "nistuṣatva": ['mw'],
    "nistuṣita": ['mw'],
    "nistuṣīkṛ": ['mw'],
    "nistvakpakṣa": ['mw'],
    "nistyaj": ['mw'],
    "nistāntava": ['mw'],
    "nistāra": ['bhs', 'cae', 'mw'],
    "nistārabīja": ['mw'],
    "nistāraka": ['mw'],
    "nistārayitṛ": ['mw'],
    "nistāraḥ": ['ap90'],
    "nistāraṇa": ['cae', 'mw'],
    "nistāraṇaṃ": ['ap90'],
    "nistāḍana": ['bhs'],
    "nistāḍeti": ['bhs'],
    "nistīrati": ['bhs'],
    "nistīraṇa": ['bhs'],
    "nistīrṇa": ['ap90', 'cae', 'mw'],
    "nistṛ": ['mw'],
    "nistṛṇakaṇṭaka": ['mw'],
    "nistṛṣ": ['mw'],
    "nistṛṣṇa": ['mw'],
    "nistṝ": ['ap90', 'mw'],
    "nisumbha": ['mw'],
    "nisumbhati": ['cped'],
    "nisunda": ['mw'],
    "nisusūṣ": ['mw'],
    "nisvan": ['mw'],
    "nisvana": ['cae', 'ddsa', 'mw'],
    "nisvanaḥ": ['ap90'],
    "nisvanita": ['cae', 'mw'],
    "nisvap": ['mw'],
    "nisvara": ['bhs', 'cae', 'gra', 'mw'],
    "nisvaram": ['mw'],
    "nisvāna": ['mw'],
    "nisyand": ['mw'],
    "nisyanda": ['bhs', 'cae', 'ddsa', 'mw'],
    "nisyandin": ['cae', 'mw'],
    "nisyaṃdaḥ": ['ap90'],
    "nisyaṃdin": ['ap90'],
    "nisāmaka": ['cped'],
    "nisāmakajātika": ['cped'],
    "nisāmakajātiya": ['cped'],
    "nisāmayati": ['cped'],
    "nisāmayi": ['cped'],
    "nisāmayitvā": ['cped'],
    "nisāmeti": ['cped'],
    "nisāra": ['mw'],
    "nisīdana": ['cped'],
    "nisīdanta": ['cped'],
    "nisīdati": ['cped'],
    "nisīdi": ['cped'],
    "nisīdita(r)": ['cped'],
    "nisīditabba": ['cped'],
    "nisīditvā": ['cped'],
    "nisīditvāna": ['cped'],
    "nisīdiṁsu": ['cped'],
    "nisīdāpeti": ['cped'],
    "nisīdāpetvā": ['cped'],
    "nisīdāpita": ['cped'],
    "nisīdāpiyati": ['cped'],
    "nisītha": ['cped'],
    "nisūdaka": ['mw'],
    "nisūdana": ['ap90', 'ddsa'],
    "nisṛj": ['ap90'],
    "nisṛjā": ['bhs'],
    "nisṛta": ['ddsa', 'mw'],
    "nisṛtya": ['bhs'],
    "nisṛtā": ['mw'],
    "nisṛṣṭa": ['ap90', 'cae', 'mw'],
    "nisṛṣṭavat": ['mw'],
    "nisṛṣṭārtha": ['ddsa', 'mw'],
    "nitala": ['cae', 'mw'],
    "nitalaṃ": ['ap90'],
    "nitam": ['mw'],
    "nitamba": ['cae', 'ddsa', 'mw'],
    "nitambabimba": ['mw'],
    "nitambamaya": ['mw'],
    "nitambaprabhava": ['mw'],
    "nitambasthala": ['cae', 'mw'],
    "nitambasthalī": ['mw'],
    "nitambatā": ['mw'],
    "nitambavat": ['mw'],
    "nitambavatī": ['cae', 'mw'],
    "nitambhū": ['mw'],
    "nitambin": ['ddsa', 'mw'],
    "nitambinī": ['cae', 'mw'],
    "nitambā": ['mw'],
    "nitan": ['mw'],
    "nitap": ['mw'],
    "nitara": ['mw'],
    "nitarām": ['cae', 'ddsa', 'mw'],
    "nitarāṃ": ['ap90'],
    "nitatatapas": ['mw'],
    "nitatni": ['mw'],
    "nitatnī": ['mw'],
    "nitaṃbavat": ['ap90'],
    "nitaṃbaḥ": ['ap90'],
    "nitaṃbin": ['ap90'],
    "nitikta": ['cae', 'mw'],
    "nitikti": ['gra', 'mw'],
    "nitiṇṇa": ['cped'],
    "nitoda": ['cae', 'mw'],
    "nitodin": ['cae', 'ddsa', 'gra', 'mw'],
    "nitośana": ['cae', 'gra', 'mw'],
    "nittaṇha": ['cped'],
    "nitthananta": ['cped'],
    "nittharati": ['cped'],
    "nittharaṇa": ['cped'],
    "nitthariṁsu": ['cped'],
    "nitthiṇṇa": ['cped'],
    "nitthiṇṇa-ogha": ['cped'],
    "nitthiṇṇogha": ['cped'],
    "nitthuna": ['cped'],
    "nitthunanta": ['cped'],
    "nitthāra": ['cped'],
    "nittiṇṇa": ['cped'],
    "nittiṇṇa-ogha": ['cped'],
    "nitud": ['mw'],
    "nitunna": ['mw'],
    "nituś": ['mw'],
    "nituṇḍa": ['mw'],
    "nitya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "nityabhaktika": ['mw'],
    "nityabhāva": ['mw'],
    "nityabuddhi": ['mw'],
    "nityadhṛt": ['mw'],
    "nityadhṛta": ['mw'],
    "nityadā": ['ap90', 'cae', 'mw'],
    "nityadāna": ['mw'],
    "nityadānādipaddhati": ['mw'],
    "nityagati": ['mw'],
    "nityahoma": ['mw'],
    "nityahomaprāyaścitta": ['mw'],
    "nityahomavidhi": ['mw'],
    "nityahomādiprakīrṇaka": ['mw'],
    "nityahomādividhi": ['mw'],
    "nityahotṛ": ['gra', 'mw'],
    "nityajapavidhāna": ['mw'],
    "nityajvara": ['bhs', 'mw'],
    "nityajāta": ['cae', 'mw'],
    "nityaka": ['bhs'],
    "nityakarmalatā": ['mw'],
    "nityakarman": ['cae', 'ddsa', 'mw'],
    "nityakarmapaddhati": ['mw'],
    "nityakarmaprakāśikā": ['mw'],
    "nityakarmavidhi": ['mw'],
    "nityakarmānuṣṭhānakrama": ['mw'],
    "nityakriyā": ['mw'],
    "nityakta": ['cae'],
    "nityakālam": ['cae', 'mw'],
    "nityakṛtya": ['cae', 'mw'],
    "nityalīlāsthāpana": ['mw'],
    "nityam": ['mw'],
    "nityamaya": ['mw'],
    "nityamukta": ['mw'],
    "nityamuktatva": ['mw'],
    "nityanaimittika": ['mw'],
    "nityanarta": ['mw'],
    "nityanātha": ['mw'],
    "nityaparinirvṛta": ['bhs'],
    "nityaparivṛta": ['mw'],
    "nityaparīkṣaṇa": ['mw'],
    "nityapralaya": ['mw'],
    "nityapramudita": ['mw'],
    "nityaprayogaratnākara": ['mw'],
    "nityaprayukta": ['bhs'],
    "nityapuṣṭa": ['mw'],
    "nityapāda": ['mw'],
    "nityapūjā": ['mw'],
    "nityapūjāyantra": ['mw'],
    "nityartu": ['mw'],
    "nityasama": ['mw'],
    "nityasamāsa": ['mw'],
    "nityasaṃhṛṣṭa": ['mw'],
    "nityasaṃnyāsin": ['cae', 'mw'],
    "nityasevaka": ['cae', 'ddsa', 'mw'],
    "nityasiddha": ['mw'],
    "nityasnāyin": ['cae', 'mw'],
    "nityastha": ['mw'],
    "nityastotra": ['gra', 'mw'],
    "nityasvādhyāyin": ['mw'],
    "nityasvādhyāyitā": ['mw'],
    "nityatarpaṇa": ['mw'],
    "nityatva": ['mw'],
    "nityatā": ['ap90', 'mw'],
    "nityatṛpta": ['cae'],
    "nityavaikuṇṭha": ['mw'],
    "nityavarṣadeva": ['mw'],
    "nityavatsa": ['mw'],
    "nityavatsā": ['mw'],
    "nityavidhi": ['mw'],
    "nityavitrasta": ['mw'],
    "nityavrata": ['mw'],
    "nityavyaya": ['mw'],
    "nityavyayā": ['mw'],
    "nityayauvana": ['mw'],
    "nityayauvanā": ['mw'],
    "nityayuj": ['mw'],
    "nityayukta": ['cae', 'ddsa', 'mw'],
    "nityayātrā": ['mw'],
    "nityaśas": ['ap90', 'cae', 'ddsa', 'mw'],
    "nityaśatrughna": ['mw'],
    "nityaśaya": ['mw'],
    "nityaśaṅkin": ['mw'],
    "nityaśaṅkita": ['mw'],
    "nityaśrāddha": ['mw'],
    "nityaśrī": ['mw'],
    "nityodaka": ['cae', 'mw'],
    "nityodakin": ['cae', 'mw'],
    "nityodita": ['cae', 'mw'],
    "nityodyukta": ['bhs', 'mw'],
    "nityotkṣiptahasta": ['bhs', 'mw'],
    "nityotsava": ['mw'],
    "nityotsavavidhi": ['mw'],
    "nityā": ['mw'],
    "nityābhiyukta": ['cae'],
    "nityācāra": ['mw'],
    "nityācārapradīpa": ['mw'],
    "nityācāravidhi": ['mw'],
    "nityāgnihotra": ['mw'],
    "nityānadhyāya": ['mw'],
    "nityānanda": ['mw'],
    "nityānandarasa": ['mw'],
    "nityānandarasodadhi": ['mw'],
    "nityānandayugalāṣṭaka": ['mw'],
    "nityānitya": ['mw'],
    "nityānnadānamāhātmya": ['mw'],
    "nityānubaddha": ['mw'],
    "nityānubaddhā": ['mw'],
    "nityānugṛhīta": ['ddsa', 'mw'],
    "nityānusaṃdhāna": ['mw'],
    "nityānuṣṭhānapūjāpaddhati": ['mw'],
    "nityāritra": ['gra', 'mw'],
    "nityārthasāmānyapañcapaṭhī": ['mw'],
    "nityārādhana": ['mw'],
    "nityārādhanakrama": ['mw'],
    "nityārādhanavidhi": ['mw'],
    "nityātantra": ['mw'],
    "nityāyukta": ['mw'],
    "nitāna": ['mw'],
    "nitānta": ['cae', 'ddsa', 'mw'],
    "nitāntakathiṇa": ['mw'],
    "nitāntam": ['mw'],
    "nitāntarakta": ['mw'],
    "nitāntavṛkṣīya": ['mw'],
    "nitāntīya": ['mw'],
    "nitāṃta": ['ap90'],
    "nitīrayati": ['bhs'],
    "nitīraṇa": ['bhs', 'mw'],
    "nitṛd": ['mw'],
    "nitṛp": ['mw'],
    "nitṝ": ['mw'],
    "niva": ['mw'],
    "nivac": ['mw'],
    "nivacana": ['cae', 'gra', 'mw'],
    "nivacane": ['ap90'],
    "nivacanekṛ": ['mw'],
    "nivad": ['mw'],
    "nivadh": ['mw'],
    "nivah": ['ap90', 'mw'],
    "nivaha": ['cae', 'mw'],
    "nivahaḥ": ['ap90'],
    "nivakṣas": ['mw'],
    "nivala": ['bhs'],
    "nivana": ['gra'],
    "nivanā": ['cae', 'mw'],
    "nivap": ['ap90', 'mw'],
    "nivapana": ['cae', 'ddsa', 'mw'],
    "nivapanaṃ": ['ap90'],
    "nivapati": ['cped'],
    "nivapta": ['mw'],
    "nivara": ['ap90', 'cae', 'gra', 'mw'],
    "nivaraṇa": ['bhs', 'mw'],
    "nivarhaṇa": ['ap90', 'mw'],
    "nivarta": ['cae', 'gra', 'mw'],
    "nivartaka": ['ap90', 'bhs', 'mw'],
    "nivartakatva": ['mw'],
    "nivartana": ['ap90', 'cae', 'gra', 'mw'],
    "nivartanastūpa": ['mw'],
    "nivartanīya": ['cae', 'mw'],
    "nivartati": ['bhs'],
    "nivartayitavya": ['cae', 'mw'],
    "nivartin": ['ap90', 'cae', 'mw'],
    "nivartita": ['mw'],
    "nivartitapūrva": ['mw'],
    "nivartitavya": ['cae', 'mw'],
    "nivartitākhilāhāra": ['mw'],
    "nivartya": ['cae', 'mw'],
    "nivarā": ['ap90', 'mw'],
    "nivas": ['ap90', 'mw'],
    "nivasana": ['cae', 'mw'],
    "nivasanaṃ": ['ap90'],
    "nivasatha": ['mw'],
    "nivasathaḥ": ['ap90'],
    "nivasati": ['cped', 'mw'],
    "nivasatiḥ": ['ap90'],
    "nivasita": ['mw'],
    "nivasta": ['bhs'],
    "nivastavya": ['cae', 'mw'],
    "nivastra": ['bhs'],
    "nivat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nivatta": ['cped'],
    "nivattabīja": ['cped'],
    "nivattanta": ['cped'],
    "nivattati": ['cped'],
    "nivattenta": ['cped'],
    "nivatteti": ['cped'],
    "nivattha": ['cped'],
    "nivattitabba": ['cped'],
    "nivattāpeti": ['cped'],
    "nivattāpetvā": ['cped'],
    "nivatā": ['mw'],
    "nivedaka": ['ap90', 'cae', 'mw'],
    "nivedana": ['cae', 'ddsa', 'mw'],
    "nivedanaṃ": ['ap90'],
    "nivedayiṣu": ['mw'],
    "nivedayiṣukāma": ['cae'],
    "nivedin": ['cae', 'mw'],
    "nivedita": ['ap90', 'mw'],
    "nivedya": ['cae', 'mw'],
    "nivedyaṃ": ['ap90'],
    "nivesa": ['cped'],
    "nivesana": ['cped'],
    "nivesayati": ['cped'],
    "nivesayi": ['cped'],
    "nivesesi": ['cped'],
    "nivesetabba": ['cped'],
    "niveseti": ['cped'],
    "nivesiya": ['cped'],
    "niveśa": ['cae', 'gra', 'mw'],
    "niveśadeśa": ['mw'],
    "niveśaka": ['bhs'],
    "niveśana": ['bhs', 'cae', 'gra', 'mw'],
    "niveśanaṃ": ['ap90'],
    "niveśanīya": ['mw'],
    "niveśavat": ['mw'],
    "niveśayitar": ['bhs'],
    "niveśayitavya": ['mw'],
    "niveśaḥ": ['ap90'],
    "niveśin": ['cae', 'mw'],
    "niveśita": ['mw'],
    "niveśya": ['cae', 'mw'],
    "niveṣya": ['ap90', 'cae', 'mw'],
    "niveṣī": ['mw'],
    "niveṣṭ": ['mw'],
    "niveṣṭa": ['cae', 'mw'],
    "niveṣṭakāma": ['cae'],
    "niveṣṭana": ['mw'],
    "niveṣṭanaṃ": ['ap90'],
    "niveṣṭavya": ['cae', 'mw'],
    "niveṣṭaḥ": ['ap90'],
    "niveṣṭita": ['mw'],
    "nivicchaṃśam": ['mw'],
    "nivid": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nividadhyāya": ['mw'],
    "nividdha": ['mw'],
    "nividdhāna": ['mw'],
    "nividdhānīya": ['mw'],
    "nivirīsa": ['mw'],
    "nivirīśa": ['ap90'],
    "nivisamāna": ['cped'],
    "nivisati": ['cped'],
    "nivisi": ['cped'],
    "nivissa": ['cped'],
    "nivissavāda": ['cped'],
    "nivissavādi(n)": ['cped'],
    "nivivṛtsat": ['mw'],
    "nivivṛtsu": ['mw'],
    "niviś": ['ap90', 'mw'],
    "niviśeṣa": ['ap90'],
    "niviḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "niviṣṭa": ['ap90', 'cae', 'mw'],
    "niviṣṭacakra": ['mw'],
    "niviṣṭi": ['mw'],
    "niviṣṭiḥ": ['ap90'],
    "niviṭṭha": ['cped'],
    "nivraśc": ['mw'],
    "nivusita": ['cped'],
    "nivuta": ['cped'],
    "nivutabrahmaloka": ['cped'],
    "nivutta": ['cped'],
    "nivuttakesa": ['cped'],
    "nivuṭa": ['cped'],
    "nivuṭṭati": ['bhs'],
    "nivyadh": ['mw'],
    "nivye": ['mw'],
    "nivyādha": ['mw'],
    "nivyādhin": ['mw'],
    "nivyāpara": ['bhs'],
    "nivyūḍha": ['mw'],
    "nivyūḍhaṃ": ['ap90'],
    "nivāc": ['mw'],
    "nivāha": ['mw'],
    "nivāku": ['ap90', 'mw'],
    "nivānyavatsā": ['mw'],
    "nivānyā": ['ap90', 'mw'],
    "nivānyāvatsa": ['mw'],
    "nivāpa": ['cae', 'cped', 'mw'],
    "nivāpadatti": ['mw'],
    "nivāpaka": ['bhs', 'mw'],
    "nivāpakaḥ": ['ap90'],
    "nivāpamālya": ['mw'],
    "nivāpamālyatā": ['mw'],
    "nivāpapuṭṭha": ['cped'],
    "nivāpaḥ": ['ap90'],
    "nivāpin": ['mw'],
    "nivāpodaka": ['cae', 'mw'],
    "nivāpānna": ['mw'],
    "nivāpāñjali": ['cae', 'mw'],
    "nivāpāñjalidāna": ['mw'],
    "nivāra": ['mw'],
    "nivāraka": ['mw'],
    "nivārayati": ['cped'],
    "nivāraḥ": ['ap90'],
    "nivāraṇa": ['bhs', 'cae', 'cped', 'mw'],
    "nivāraṇīya": ['cae', 'mw'],
    "nivāresi": ['cped'],
    "nivāresuṁ": ['cped'],
    "nivāreta(r)": ['cped'],
    "nivāretabba": ['cped'],
    "nivāreti": ['cped'],
    "nivāretvā": ['cped'],
    "nivārin": ['mw'],
    "nivārita": ['mw'],
    "nivāriyamāna": ['cped'],
    "nivārya": ['cae', 'mw'],
    "nivārā": ['mw'],
    "nivāsa": ['bhs', 'cae', 'cped', 'mw'],
    "nivāsabhavana": ['mw'],
    "nivāsabhūmi": ['mw'],
    "nivāsabhūya": ['mw'],
    "nivāsana": ['bhs', 'cae', 'cped', 'mw'],
    "nivāsanaṃ": ['ap90'],
    "nivāsaracanā": ['cae', 'mw'],
    "nivāsarājan": ['mw'],
    "nivāsavṛkṣa": ['cae', 'mw'],
    "nivāsayati": ['bhs', 'cped'],
    "nivāsaḥ": ['ap90'],
    "nivāsenta": ['cped'],
    "nivāsesi": ['cped'],
    "nivāsesuṁ": ['cped'],
    "nivāsetabba": ['cped'],
    "nivāseti": ['cped'],
    "nivāsetvā": ['cped'],
    "nivāsi(n)": ['cped'],
    "nivāsikā": ['bhs'],
    "nivāsin": ['ap90', 'cae', 'mw'],
    "nivāsita": ['mw'],
    "nivāta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "nivātakavaca": ['mw'],
    "nivātastha": ['cae'],
    "nivāvarī": ['mw'],
    "nivāśa": ['mw'],
    "nivī": ['mw'],
    "nivīrya": ['mw'],
    "nivīta": ['cae', 'ddsa', 'mw'],
    "nivītaṃ": ['ap90'],
    "nivītin": ['ap90', 'cae', 'mw'],
    "nivṛ": ['ap90', 'mw'],
    "nivṛh": ['mw'],
    "nivṛj": ['mw'],
    "nivṛt": ['ap90', 'mw'],
    "nivṛta": ['ap90', 'bhs', 'cae', 'mw'],
    "nivṛti": ['mw'],
    "nivṛtiḥ": ['ap90'],
    "nivṛtta": ['ap90', 'cae', 'ddsa', 'mw'],
    "nivṛttadakṣiṇā": ['mw'],
    "nivṛttadevakārya": ['mw'],
    "nivṛttahṛdaya": ['mw'],
    "nivṛttakāraṇa": ['mw'],
    "nivṛttakṛṣigorakṣa": ['mw'],
    "nivṛttalaulya": ['mw'],
    "nivṛttamāṃsa": ['mw'],
    "nivṛttarāga": ['mw'],
    "nivṛttasaṃtāpa": ['mw'],
    "nivṛttavṛtti": ['mw'],
    "nivṛttayajñasvādhyāya": ['mw'],
    "nivṛttayauvana": ['mw'],
    "nivṛttaśatru": ['mw'],
    "nivṛttendriya": ['mw'],
    "nivṛtti": ['cae', 'mw'],
    "nivṛttiḥ": ['ap90'],
    "nivṛttātman": ['mw'],
    "niya": ['cped'],
    "niyaka": ['bhs', 'cped'],
    "niyam": ['ap90', 'mw'],
    "niyama": ['cae', 'ddsa', 'mw'],
    "niyamabhaṅga": ['mw'],
    "niyamadharma": ['mw'],
    "niyamahetu": ['mw'],
    "niyamalaṅghana": ['mw'],
    "niyamana": ['cae', 'mw'],
    "niyamanaṃ": ['ap90'],
    "niyamaniṣṭhā": ['mw'],
    "niyamapara": ['mw'],
    "niyamapattra": ['mw'],
    "niyamapāla": ['mw'],
    "niyamasthiti": ['mw'],
    "niyamavat": ['mw'],
    "niyamavatī": ['ap90', 'mw'],
    "niyamaḥ": ['ap90'],
    "niyamena": ['mw'],
    "niyamita": ['ap90', 'mw'],
    "niyamojjhiti": ['mw'],
    "niyamopamā": ['cae', 'mw'],
    "niyamya": ['cae', 'mw'],
    "niyamānanda": ['mw'],
    "niyamārtham": ['cae'],
    "niyamāt": ['mw'],
    "niyantavya": ['cae', 'ddsa', 'mw'],
    "niyantavyatva": ['mw'],
    "niyanti": ['bhs'],
    "niyantr": ['mw'],
    "niyantraṇa": ['cae', 'mw'],
    "niyantraṇā": ['mw'],
    "niyantrita": ['mw'],
    "niyantu": ['mw'],
    "niyantṛ": ['cae', 'gra', 'mw'],
    "niyantṛtva": ['mw'],
    "niyasa": ['cped'],
    "niyassa": ['cped'],
    "niyassaka": ['cped'],
    "niyassakamma": ['cped'],
    "niyassakammakata": ['cped'],
    "niyat": ['mw'],
    "niyata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "niyatabhojana": ['mw'],
    "niyatabhūmi": ['bhs'],
    "niyatacaryāpratipattibhūmi": ['bhs'],
    "niyatadhvajaketu": ['bhs'],
    "niyatakāla": ['cae', 'mw'],
    "niyatam": ['mw'],
    "niyatamaithuna": ['mw'],
    "niyatamānasa": ['mw'],
    "niyatana": ['bhs'],
    "niyatavibhaktika": ['mw'],
    "niyataviṣayavartin": ['mw'],
    "niyatavrata": ['cae', 'mw'],
    "niyatavāc": ['mw'],
    "niyatendriya": ['cae', 'ddsa', 'mw'],
    "niyati": ['bhs', 'cae', 'ddsa', 'mw'],
    "niyatiḥ": ['ap90'],
    "niyatāhāra": ['cae', 'mw'],
    "niyatāniyatāvatāramudrāsūtra": ['bhs'],
    "niyatānupūrvya": ['mw'],
    "niyatāpti": ['mw'],
    "niyatātman": ['cae', 'mw'],
    "niyatāyuka": ['cped'],
    "niyatāñjali": ['mw'],
    "niyatāśin": ['mw'],
    "niyatī": ['mw'],
    "niyava": ['gra', 'mw'],
    "niyavaḥ": ['ap90'],
    "niyayin": ['gra', 'mw'],
    "niyaṃtraṇaṃ": ['ap90'],
    "niyaṃtrita": ['ap90'],
    "niyaṃtṛ": ['ap90'],
    "niyoddhṛ": ['ap90', 'mw'],
    "niyodhaka": ['mw'],
    "niyodhakaḥ": ['ap90'],
    "niyoga": ['cae', 'ddsa', 'mw'],
    "niyogakaraṇa": ['mw'],
    "niyogakṛt": ['cae', 'mw'],
    "niyogaprayojana": ['mw'],
    "niyogapāśa": ['mw'],
    "niyogasaṃsthita": ['mw'],
    "niyogastha": ['mw'],
    "niyogatas": ['mw'],
    "niyogavidhi": ['mw'],
    "niyogaḥ": ['ap90'],
    "niyogena": ['mw'],
    "niyogin": ['ap90', 'ddsa', 'mw'],
    "niyogya": ['mw'],
    "niyogyarthagrahopāya": ['mw'],
    "niyogyaḥ": ['ap90'],
    "niyogārtha": ['cae', 'mw'],
    "niyogāt": ['mw'],
    "niyojaka": ['mw'],
    "niyojana": ['cae', 'ddsa', 'mw'],
    "niyojanaṃ": ['ap90'],
    "niyojanī": ['mw'],
    "niyojanīya": ['mw'],
    "niyojayati": ['cped'],
    "niyojayi": ['cped'],
    "niyojayitar": ['bhs'],
    "niyojayitavya": ['mw'],
    "niyojeti": ['cped'],
    "niyojikā": ['mw'],
    "niyojita": ['ap90', 'mw'],
    "niyojya": ['cae', 'mw'],
    "niyojyaḥ": ['ap90'],
    "niyojyānvayanirūpaṇa": ['mw'],
    "niyoktavya": ['cae', 'ddsa', 'mw'],
    "niyoktṛ": ['ap90', 'cae', 'mw'],
    "niyu": ['mw'],
    "niyuddha": ['cae', 'mw'],
    "niyuddhabhū": ['mw'],
    "niyuddhakuśala": ['mw'],
    "niyuddhaśīla": ['mw'],
    "niyuddhaṃ": ['ap90'],
    "niyudh": ['mw'],
    "niyudratha": ['gra', 'mw'],
    "niyuj": ['ap90', 'mw'],
    "niyujya": ['mw'],
    "niyukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "niyuktaka": ['bhs', 'mw'],
    "niyuktam": ['mw'],
    "niyukti": ['cae', 'mw'],
    "niyuktiḥ": ['ap90'],
    "niyut": ['ap90', 'cae', 'gra', 'mw'],
    "niyuta": ['bhs', 'cae', 'mw'],
    "niyutaṃ": ['ap90'],
    "niyutsā": ['mw'],
    "niyutvant": ['cae'],
    "niyutvat": ['gra', 'mw'],
    "niyutvatīya": ['mw'],
    "niyuñjati": ['cped'],
    "niyyamāna": ['cped'],
    "niyyanta": ['cped'],
    "niyyati": ['cped'],
    "niyyatta": ['cped'],
    "niyyiṁsu": ['cped'],
    "niyyādayati": ['cped'],
    "niyyādesi": ['cped'],
    "niyyādetabba": ['cped'],
    "niyyādeti": ['cped'],
    "niyyādetuṁ": ['cped'],
    "niyyādetvā": ['cped'],
    "niyyādita": ['cped'],
    "niyyāna": ['cped'],
    "niyyānika": ['cped'],
    "niyyāsi": ['cped'],
    "niyyāsuṁ": ['cped'],
    "niyyāta": ['cped'],
    "niyyāta(r)": ['cped'],
    "niyyātayati": ['cped'],
    "niyyātesi": ['cped'],
    "niyyātetabba": ['cped'],
    "niyyāteti": ['cped'],
    "niyyātetvā": ['cped'],
    "niyyāti": ['cped'],
    "niyyātita": ['cped'],
    "niyyātuṁ": ['cped'],
    "niyyāyanta": ['cped'],
    "niyyāyati": ['cped'],
    "niyyūha": ['cped'],
    "niyā": ['mw'],
    "niyāma": ['bhs', 'cped', 'mw'],
    "niyāmaka": ['ap90', 'cae', 'mw'],
    "niyāmakatva": ['mw'],
    "niyāmakatā": ['ap90', 'mw'],
    "niyāmana": ['mw'],
    "niyāmatā": ['cped'],
    "niyāmaḥ": ['ap90'],
    "niyāna": ['cae', 'gra', 'mw'],
    "niyānaṃ": ['ap90'],
    "niyātana": ['ap90', 'mw'],
    "niyūha": ['cped'],
    "niñj": ['mw'],
    "niś": ['ap90', 'cae', 'ddsa', 'mw'],
    "niśa": ['cae', 'ddsa', 'mw'],
    "niśabda": ['ap90', 'ddsa', 'mw'],
    "niśaita": ['mw'],
    "niśam": ['ap90', 'mw'],
    "niśamana": ['mw'],
    "niśamanaṃ": ['ap90'],
    "niśamaya": ['mw'],
    "niśaraṇa": ['mw'],
    "niśaraṇaṃ": ['ap90'],
    "niśaṭha": ['ap90', 'mw'],
    "niścakrika": ['mw'],
    "niścakṣus": ['mw'],
    "niścala": ['ap90', 'cae', 'ddsa', 'mw'],
    "niścaladāsasvāmin": ['mw'],
    "niścalakara": ['mw'],
    "niścalā": ['mw'],
    "niścalāṅga": ['mw'],
    "niścapraca": ['mw'],
    "niścar": ['ap90', 'mw'],
    "niścara": ['bhs', 'mw'],
    "niścat": ['mw'],
    "niścatvāriṃśa": ['mw'],
    "niścaura": ['ddsa', 'mw'],
    "niścaya": ['cae', 'ddsa', 'mw'],
    "niścayadatta": ['mw'],
    "niścayakṛt": ['mw'],
    "niścayarūpa": ['mw'],
    "niścayaḥ": ['ap90'],
    "niścayena": ['mw'],
    "niścayin": ['mw'],
    "niścayitvā": ['bhs'],
    "niścayāt": ['mw'],
    "niścetana": ['cae', 'ddsa', 'mw'],
    "niścetanatā": ['mw'],
    "niścetas": ['cae', 'mw'],
    "niścetavya": ['mw'],
    "niśceya": ['mw'],
    "niśceṣṭa": ['cae', 'mw'],
    "niśceṣṭam": ['mw'],
    "niśceṣṭā": ['mw'],
    "niśceṣṭākaraṇa": ['mw'],
    "niśceṣṭībhū": ['mw'],
    "niśchandas": ['cae', 'ddsa', 'mw'],
    "niśchavīkṛtvā": ['bhs'],
    "niścheda": ['mw'],
    "niśchidra": ['cae', 'mw'],
    "niśchāya": ['mw'],
    "niści": ['ap90', 'mw'],
    "niścikramiṣu": ['mw'],
    "niścikramiṣā": ['mw'],
    "niścikīrṣā": ['bhs'],
    "niścinta": ['cae', 'mw'],
    "niścira": ['mw'],
    "niścirā": ['mw'],
    "niścita": ['ap90', 'cae', 'ddsa', 'mw'],
    "niścitam": ['mw'],
    "niściti": ['mw'],
    "niścitiḥ": ['ap90'],
    "niścitta": ['bhs', 'mw'],
    "niścitya": ['mw'],
    "niścitā": ['mw'],
    "niścitārtha": ['bhs', 'mw'],
    "niścukkaṇa": ['mw'],
    "niścukkaṇaṃ": ['ap90'],
    "niścut": ['mw'],
    "niścutita": ['mw'],
    "niścyavana": ['mw'],
    "niścāmara": ['mw'],
    "niścāraka": ['mw'],
    "niścārakam": ['bhs'],
    "niścārakaṃ": ['ap90'],
    "niścārayati": ['bhs'],
    "niścārayitavya": ['mw'],
    "niścāraṇa": ['bhs'],
    "niścāyaka": ['ap90', 'mw'],
    "niścāyakatva": ['mw'],
    "niścīyamāna": ['mw'],
    "niścṛt": ['mw'],
    "niśeśa": ['mw'],
    "niśeśavaktrā": ['mw'],
    "niśi": ['mw'],
    "niśipuṣpikā": ['mw'],
    "niśipuṣpā": ['mw'],
    "niśipuṣpī": ['mw'],
    "niśipāla": ['mw'],
    "niśita": ['ap90', 'cae', 'mw'],
    "niśitanipāta": ['mw'],
    "niśitha": ['mw'],
    "niśiti": ['cae', 'gra', 'mw'],
    "niśitiḥ": ['ap90'],
    "niśitā": ['cae', 'gra', 'mw'],
    "niśitāṅkuśa": ['cae', 'mw'],
    "niśliṣ": ['mw'],
    "niśmaśru": ['mw'],
    "niśna": ['mw'],
    "niśnath": ['mw'],
    "niśo": ['mw'],
    "niśopaśāya": ['mw'],
    "niśotrā": ['mw'],
    "niśotsarga": ['mw'],
    "niśoṣita": ['mw'],
    "niśrama": ['mw'],
    "niśramaḥ": ['ap90'],
    "niśrath": ['mw'],
    "niśraya": ['bhs', 'mw'],
    "niśrayaṇī": ['ap90', 'mw'],
    "niśrayitvā": ['bhs'],
    "niśreṇī": ['ddsa', 'mw'],
    "niśri": ['mw'],
    "niśrita": ['bhs'],
    "niśritya": ['bhs', 'mw'],
    "niśrāvin": ['mw'],
    "niśrāya": ['bhs'],
    "niśrīka": ['mw'],
    "niśubh": ['mw'],
    "niśuc": ['mw'],
    "niśumbh": ['mw'],
    "niśumbha": ['cae', 'ddsa', 'mw'],
    "niśumbhamardinī": ['mw'],
    "niśumbhamathanī": ['mw'],
    "niśumbhana": ['mw'],
    "niśumbhin": ['mw'],
    "niśuṃbhanaṃ": ['ap90'],
    "niśuṃbhaḥ": ['ap90'],
    "niśuṣma": ['mw'],
    "niśvas": ['ap90', 'mw'],
    "niśvasita": ['cae', 'mw'],
    "niśvāsa": ['cae', 'mw'],
    "niśvāsaḥ": ['ap90'],
    "niśvāsita": ['ddsa'],
    "niśā": ['ap90', 'ddsa', 'mw'],
    "niśābala": ['mw'],
    "niśābhaṅgā": ['mw'],
    "niśācara": ['cae', 'mw'],
    "niśācarapati": ['mw'],
    "niśācarapūjāpaddhati": ['mw'],
    "niśācareśa": ['mw'],
    "niśācarman": ['mw'],
    "niśācarā": ['bhs'],
    "niśācarī": ['mw'],
    "niśāchada": ['mw'],
    "niśāda": ['mw'],
    "niśādana": ['mw'],
    "niśādarśin": ['mw'],
    "niśādatva": ['mw'],
    "niśādaḥ": ['ap90'],
    "niśādhīśa": ['cae', 'mw'],
    "niśādi": ['mw'],
    "niśādāputra": ['bhs', 'mw'],
    "niśādāśilā": ['bhs', 'mw'],
    "niśāgama": ['cae', 'mw'],
    "niśāgṛha": ['mw'],
    "niśāhasa": ['mw'],
    "niśāhvā": ['mw'],
    "niśājala": ['mw'],
    "niśākara": ['cae', 'mw'],
    "niśākarakalāmauli": ['mw'],
    "niśākāla": ['mw'],
    "niśākānta": ['mw'],
    "niśākṣaya": ['mw'],
    "niśāma": ['cae', 'mw'],
    "niśāmana": ['mw'],
    "niśāmanaṃ": ['ap90'],
    "niśāmayitavya": ['mw'],
    "niśāmaḥ": ['ap90'],
    "niśāmaṇi": ['mw'],
    "niśāmita": ['mw'],
    "niśāmiśra": ['mw'],
    "niśāmukha": ['cae', 'mw'],
    "niśāmṛga": ['mw'],
    "niśāna": ['mw'],
    "niśānapaṭṭa": ['mw'],
    "niśānaṃ": ['ap90'],
    "niśāndha": ['mw'],
    "niśāndhā": ['mw'],
    "niśāniśam": ['cae', 'mw'],
    "niśānta": ['cae', 'ddsa', 'mw'],
    "niśāntanārī": ['mw'],
    "niśāntanārīvṛkṣa": ['mw'],
    "niśāntodyāna": ['mw'],
    "niśāntāyu": ['bhs'],
    "niśāntīya": ['mw'],
    "niśānārāyaṇa": ['mw'],
    "niśānātha": ['cae', 'mw'],
    "niśāpati": ['cae', 'ddsa', 'mw'],
    "niśāprāṇeśvara": ['mw'],
    "niśāputra": ['mw'],
    "niśāpuṣpa": ['mw'],
    "niśāratna": ['mw'],
    "niśāraṇa": ['mw'],
    "niśāraṇaṃ": ['ap90'],
    "niśārdhakāla": ['mw'],
    "niśārthaka": ['mw'],
    "niśāruka": ['mw'],
    "niśārukaḥ": ['ap90'],
    "niśās": ['mw'],
    "niśāta": ['ap90', 'mw'],
    "niśātaya": ['mw'],
    "niśātikrama": ['mw'],
    "niśātyaya": ['cae', 'mw'],
    "niśāvana": ['mw'],
    "niśāvasāna": ['mw'],
    "niśāvedin": ['mw'],
    "niśāvihāra": ['mw'],
    "niśāvṛnda": ['mw'],
    "niśāyin": ['mw'],
    "niśāṃta": ['ap90'],
    "niśāṭa": ['mw'],
    "niśāṭaka": ['mw'],
    "niśāṭana": ['mw'],
    "niśāṭanī": ['mw'],
    "niśāṭhaka": ['bhs'],
    "niśītha": ['cae', 'ddsa', 'mw'],
    "niśīthacaṇḍa": ['mw'],
    "niśīthadīpa": ['cae', 'mw'],
    "niśīthaparyāya": ['mw'],
    "niśīthaḥ": ['ap90'],
    "niśīthikā": ['mw'],
    "niśīthinī": ['ap90', 'ddsa', 'mw'],
    "niśīthinīnātha": ['mw'],
    "niśīthinīpati": ['mw'],
    "niśīthyā": ['mw'],
    "niśṛmbha": ['gra', 'mw'],
    "niśṛtya": ['bhs'],
    "niśṛṇoti": ['bhs'],
    "niśṝ": ['mw'],
    "niḍīna": ['mw'],
    "niḍīnaṃ": ['ap90'],
    "niḍḍāpetabba": ['cped'],
    "niḍḍāyitabba": ['cped'],
    "niḥ": ['cae', 'mw'],
    "niḥk": ['bhs'],
    "niḥka˚": ['ddsa'],
    "niḥkṣatra": ['cae', 'mw'],
    "niḥkṣatrakaraṇa": ['mw'],
    "niḥkṣatre": ['mw'],
    "niḥkṣatriya": ['cae', 'ddsa', 'mw'],
    "niḥkṣepa": ['bhs', 'mw'],
    "niḥkṣepaḥ": ['ap90'],
    "niḥkṣi": ['mw'],
    "niḥkṣip": ['ap90', 'mw'],
    "niḥkṣipta": ['ap90', 'mw'],
    "niḥkṣipya": ['mw'],
    "niḥkṣobhya": ['bhs'],
    "niḥp": ['bhs'],
    "niḥpa˚": ['ddsa'],
    "niḥsaciva": ['mw'],
    "niḥsaha": ['ap90', 'cae', 'mw'],
    "niḥsahatva": ['mw'],
    "niḥsahatā": ['mw'],
    "niḥsahāya": ['mw'],
    "niḥsalila": ['cae', 'mw'],
    "niḥsambandha": ['mw'],
    "niḥsambhrama": ['mw'],
    "niḥsambādha": ['mw'],
    "niḥsambādhavelā": ['mw'],
    "niḥsampāta": ['mw'],
    "niḥsamā": ['mw'],
    "niḥsapatna": ['cae', 'mw'],
    "niḥsapatnatā": ['mw'],
    "niḥsara": ['bhs', 'mw'],
    "niḥsaratva": ['mw'],
    "niḥsaraṇa": ['bhs', 'cae', 'mw'],
    "niḥsaraṇavat": ['mw'],
    "niḥsaraṇaṃ": ['ap90'],
    "niḥsaraṇi": ['mw'],
    "niḥsaraṇīya": ['bhs'],
    "niḥsarga": ['bhs'],
    "niḥsargika": ['bhs'],
    "niḥsarita": ['bhs'],
    "niḥsarpa": ['mw'],
    "niḥsattva": ['cae', 'mw'],
    "niḥsattvatva": ['mw'],
    "niḥsattvatā": ['mw'],
    "niḥsatya": ['cae', 'mw'],
    "niḥsatyatā": ['mw'],
    "niḥsaṃcāra": ['cae', 'mw'],
    "niḥsaṃdeha": ['mw'],
    "niḥsaṃdeham": ['mw'],
    "niḥsaṃdhi": ['mw'],
    "niḥsaṃdigdha": ['cae', 'mw'],
    "niḥsaṃdigdham": ['mw'],
    "niḥsaṃjña": ['cae', 'mw'],
    "niḥsaṃkakṣa": ['mw'],
    "niḥsaṃkalpa": ['mw'],
    "niḥsaṃkhya": ['mw'],
    "niḥsaṃkṣobha": ['mw'],
    "niḥsaṃskāra": ['mw'],
    "niḥsaṃskāratā": ['mw'],
    "niḥsaṃtati": ['mw'],
    "niḥsaṃtāna": ['mw'],
    "niḥsaṃśaya": ['cae', 'ddsa', 'mw'],
    "niḥsaṃśayam": ['mw'],
    "niḥsaṅga": ['cae', 'mw'],
    "niḥsaṅgam": ['mw'],
    "niḥsaṅgatva": ['mw'],
    "niḥsaṅgatā": ['mw'],
    "niḥsaṅgena": ['mw'],
    "niḥsneha": ['cae', 'ddsa', 'mw'],
    "niḥsnehaphalā": ['mw'],
    "niḥsnehatva": ['mw'],
    "niḥsnehā": ['mw'],
    "niḥsomaka": ['mw'],
    "niḥspanda": ['ddsa', 'mw'],
    "niḥspandatva": ['mw'],
    "niḥsparśa": ['mw'],
    "niḥsparśagātra": ['mw'],
    "niḥsphur": ['mw'],
    "niḥsphura": ['cae', 'mw'],
    "niḥspṛ": ['mw'],
    "niḥspṛha": ['cae', 'mw'],
    "niḥspṛham": ['mw'],
    "niḥspṛhatā": ['mw'],
    "niḥspṛhā": ['mw'],
    "niḥsrava": ['ddsa', 'mw'],
    "niḥsravaḥ": ['ap90'],
    "niḥsru": ['mw'],
    "niḥsruta": ['mw'],
    "niḥsrāva": ['mw'],
    "niḥsrāvaḥ": ['ap90'],
    "niḥstambha": ['ddsa', 'mw'],
    "niḥsthāman": ['mw'],
    "niḥstuti": ['mw'],
    "niḥstṛta": ['mw'],
    "niḥsugrīva": ['mw'],
    "niḥsukha": ['mw'],
    "niḥsuvarṇaka": ['cae', 'mw'],
    "niḥsva": ['cae', 'mw'],
    "niḥsvabhāva": ['mw'],
    "niḥsvana": ['cae', 'mw'],
    "niḥsvanita": ['cae'],
    "niḥsvarate": ['bhs'],
    "niḥsvatā": ['mw'],
    "niḥsvādhyāyavaṣaṭkāra": ['cae', 'mw'],
    "niḥsvādu": ['mw'],
    "niḥsvāmikā": ['cae', 'mw'],
    "niḥsvībhūta": ['mw'],
    "niḥsvīkṛ": ['ddsa'],
    "niḥsvīkṛta": ['mw'],
    "niḥsvṛ": ['mw'],
    "niḥsyand": ['mw'],
    "niḥsyanda": ['mw'],
    "niḥsādhvasa": ['cae', 'mw'],
    "niḥsādhvasam": ['mw'],
    "niḥsādhvasatva": ['mw'],
    "niḥsādhvasatā": ['mw'],
    "niḥsādhāra": ['ddsa', 'mw'],
    "niḥsādhāram": ['mw'],
    "niḥsāla": ['mw'],
    "niḥsāmarthya": ['mw'],
    "niḥsāmānya": ['mw'],
    "niḥsāra": ['cae', 'mw'],
    "niḥsāraka": ['mw'],
    "niḥsāratva": ['mw'],
    "niḥsāratā": ['mw'],
    "niḥsāraḥ": ['ap90'],
    "niḥsāraṇa": ['cae', 'mw'],
    "niḥsāraṇaṃ": ['ap90'],
    "niḥsārita": ['ap90', 'mw'],
    "niḥsāru": ['mw'],
    "niḥsāruka": ['mw'],
    "niḥsārya": ['cae', 'mw'],
    "niḥsārā": ['mw'],
    "niḥsīman": ['cae', 'ddsa', 'mw'],
    "niḥsūnu": ['cae', 'mw'],
    "niḥsūtra": ['mw'],
    "niḥsṛ": ['ap90', 'mw'],
    "niḥsṛj": ['gra', 'mw'],
    "niḥsṛp": ['mw'],
    "niḥsṛta": ['mw'],
    "niḥsṛti": ['bhs'],
    "niḥśabda": ['cae', 'mw'],
    "niḥśabdam": ['mw'],
    "niḥśabdaniścala": ['mw'],
    "niḥśabdapadam": ['mw'],
    "niḥśabdasaṃvṛtta": ['mw'],
    "niḥśabdasravat": ['mw'],
    "niḥśabdastimita": ['mw'],
    "niḥśalka": ['mw'],
    "niḥśalkaka": ['mw'],
    "niḥśalya": ['cae', 'mw'],
    "niḥśalyam": ['mw'],
    "niḥśalāka": ['cae', 'mw'],
    "niḥśama": ['mw'],
    "niḥśaraṇa": ['bhs', 'cae', 'mw'],
    "niḥśarkara": ['mw'],
    "niḥśas": ['gra', 'mw'],
    "niḥśastra": ['cae', 'mw'],
    "niḥśatru": ['cae', 'mw'],
    "niḥśayāna": ['mw'],
    "niḥśaṅka": ['cae', 'ddsa', 'mw'],
    "niḥśaṅkalīla": ['mw'],
    "niḥśaṅkam": ['mw'],
    "niḥśaṅkasupta": ['mw'],
    "niḥśaṅkayā": ['mw'],
    "niḥśaṅkita": ['cae'],
    "niḥśaṅkā": ['cae', 'mw'],
    "niḥśeṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "niḥśeṣabhagna": ['mw'],
    "niḥśeṣakṛt": ['mw'],
    "niḥśeṣam": ['mw'],
    "niḥśeṣamuṣita": ['mw'],
    "niḥśeṣatas": ['mw'],
    "niḥśeṣatā": ['cae', 'mw'],
    "niḥśeṣay": ['cae'],
    "niḥśeṣaya": ['ddsa', 'mw'],
    "niḥśeṣaṇa": ['mw'],
    "niḥśeṣeṇa": ['mw'],
    "niḥśeṣita": ['mw'],
    "niḥśiṣ": ['ap90', 'mw'],
    "niḥśmaśru": ['mw'],
    "niḥśodhya": ['mw'],
    "niḥśoka": ['cae', 'ddsa', 'mw'],
    "niḥśrama": ['mw'],
    "niḥśrayaṇikā": ['bhs'],
    "niḥśrayaṇī": ['ap90', 'mw'],
    "niḥśreya": ['bhs'],
    "niḥśreyasa": ['cae', 'mw'],
    "niḥśreyasakara": ['cae', 'mw'],
    "niḥśreyasaṃ": ['ap90'],
    "niḥśreyaṇī": ['mw'],
    "niḥśreṇi": ['mw'],
    "niḥśreṇikā": ['mw'],
    "niḥśreṇipuṣpaka": ['mw'],
    "niḥśreṇībhūta": ['bhs'],
    "niḥśritya": ['bhs'],
    "niḥśrī": ['mw'],
    "niḥśrīka": ['ddsa', 'mw'],
    "niḥśrīkatā": ['mw'],
    "niḥśuc": ['mw'],
    "niḥśukra": ['cae', 'ddsa', 'mw'],
    "niḥśvas": ['ap90', 'mw'],
    "niḥśvasana": ['mw'],
    "niḥśvasanaṃ": ['ap90'],
    "niḥśvasita": ['ap90', 'cae', 'mw'],
    "niḥśvasya": ['mw'],
    "niḥśvāsa": ['cae', 'mw'],
    "niḥśvāsaparama": ['mw'],
    "niḥśvāsasaṃhitā": ['mw'],
    "niḥśvāsaḥ": ['ap90'],
    "niḥśākha": ['mw'],
    "niḥśākhatā": ['mw'],
    "niḥśākhīkṛ": ['ddsa', 'mw'],
    "niḥśās": ['mw'],
    "niḥśāṇa": ['mw'],
    "niḥśī": ['mw'],
    "niḥśūka": ['ddsa', 'mw'],
    "niḥśūnya": ['mw'],
    "niḥśṛṅga": ['mw'],
    "niḥśṛṅkhaṇa": ['mw'],
    "niḥśṝ": ['mw'],
    "niḥṣaṃdhi": ['mw'],
    "niḥṣaṅga": ['mw'],
    "niḥṣecana": ['cae', 'mw'],
    "niḥṣecanavat": ['mw'],
    "niḥṣic": ['mw'],
    "niḥṣidh": ['mw'],
    "niḥṣidhvan": ['mw'],
    "niḥṣikta": ['mw'],
    "niḥṣku": ['mw'],
    "niḥṣpanda": ['cae'],
    "niḥṣpandatā": ['ddsa'],
    "niḥṣu": ['mw'],
    "niḥṣupta": ['mw'],
    "niḥṣvap": ['mw'],
    "niḥṣyand": ['mw'],
    "niḥṣyandana": ['mw'],
    "niḥṣāmam": ['mw'],
    "niḥṣū": ['mw'],
    "niḥṣūti": ['mw'],
    "niḥṣṭan": ['mw'],
    "niḥṣṭhita": ['cae', 'mw'],
    "niḥṣṭhiv": ['mw'],
    "niḥṣṭhu": ['mw'],
    "niḥṣṭhā": ['cae', 'mw'],
    "niṃbaḥ": ['ap90'],
    "niṃbū": ['ap90'],
    "niṃbūkaḥ": ['ap90'],
    "niṃd": ['ap90'],
    "niṃdaka": ['ap90'],
    "niṃdanaṃ": ['ap90'],
    "niṃdita": ['ap90'],
    "niṃduḥ": ['ap90'],
    "niṃdya": ['ap90'],
    "niṃj": ['ap90'],
    "niṃs": ['cae', 'ddsa', 'gra', 'mw'],
    "niṃsin": ['cae', 'mw'],
    "niṇia": ['gra'],
    "niṇik": ['cae', 'gra', 'mw'],
    "niṇya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "niṇyam": ['mw'],
    "niṇḍikā": ['mw'],
    "niṣ": ['ap90', 'mw'],
    "niṣac": ['mw'],
    "niṣad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "niṣada": ['mw'],
    "niṣadana": ['bhs', 'cae', 'gra', 'mw'],
    "niṣadanaṃ": ['ap90'],
    "niṣadha": ['ap90', 'cae', 'ddsa', 'mw'],
    "niṣadhavaṃśa": ['mw'],
    "niṣadhendra": ['mw'],
    "niṣadhendrakāvya": ['mw'],
    "niṣadheśvara": ['mw'],
    "niṣadhā": ['mw'],
    "niṣadhādhipa": ['mw'],
    "niṣadhādhipati": ['mw'],
    "niṣadhāśva": ['mw'],
    "niṣadvara": ['cae', 'ddsa', 'mw'],
    "niṣadvaraḥ": ['ap90'],
    "niṣadyā": ['ap90', 'bhs', 'mw'],
    "niṣadā": ['bhs'],
    "niṣah": ['mw'],
    "niṣakta": ['cae', 'mw'],
    "niṣamam": ['mw'],
    "niṣarga": ['mw'],
    "niṣatsnu": ['cae', 'gra', 'mw'],
    "niṣatta": ['cae', 'mw'],
    "niṣatti": ['cae', 'gra', 'mw'],
    "niṣattiḥ": ['ap90'],
    "niṣaya": ['mw'],
    "niṣañj": ['mw'],
    "niṣañja": ['mw'],
    "niṣaṃgathiḥ": ['ap90'],
    "niṣaṃgaḥ": ['ap90'],
    "niṣaṃgin": ['ap90'],
    "niṣaṃj": ['ap90'],
    "niṣaṅga": ['cae', 'ddsa', 'gra', 'mw'],
    "niṣaṅgadhi": ['mw'],
    "niṣaṅgathi": ['mw'],
    "niṣaṅgin": ['gra', 'mw'],
    "niṣaṇa": ['cae'],
    "niṣaṇṇa": ['ap90', 'bhs', 'mw'],
    "niṣaṇṇaka": ['bhs', 'mw'],
    "niṣaṇṇakaṃ": ['ap90'],
    "niṣaṭha": ['mw'],
    "niṣecana": ['cae', 'mw'],
    "niṣecanaṃ": ['ap90'],
    "niṣecitṛ": ['mw'],
    "niṣeddhavya": ['cae', 'ddsa', 'mw'],
    "niṣeddhra": ['mw'],
    "niṣeddhṛ": ['cae', 'mw'],
    "niṣedha": ['cae', 'mw'],
    "niṣedhaka": ['mw'],
    "niṣedhana": ['mw'],
    "niṣedhavāda": ['mw'],
    "niṣedhaḥ": ['ap90'],
    "niṣedhin": ['cae', 'mw'],
    "niṣedhya": ['cae', 'mw'],
    "niṣedyati": ['bhs'],
    "niṣeka": ['cae', 'ddsa', 'mw'],
    "niṣekaprakāra": ['mw'],
    "niṣekasvarā": ['mw'],
    "niṣekavicāra": ['mw'],
    "niṣekaḥ": ['ap90'],
    "niṣektavya": ['mw'],
    "niṣektṛ": ['mw'],
    "niṣev": ['ap90', 'mw'],
    "niṣeva": ['cae', 'mw'],
    "niṣevaka": ['ap90', 'mw'],
    "niṣevamāṇa": ['mw'],
    "niṣevaṇa": ['mw'],
    "niṣevaṇaṃ": ['ap90'],
    "niṣevaṇīya": ['mw'],
    "niṣevin": ['cae', 'mw'],
    "niṣevita": ['ap90', 'cae', 'mw'],
    "niṣevitavya": ['cae', 'mw'],
    "niṣevitṛ": ['mw'],
    "niṣevya": ['cae', 'mw'],
    "niṣevā": ['mw'],
    "niṣic": ['ap90', 'mw'],
    "niṣiddha": ['ap90', 'cae', 'mw'],
    "niṣiddhavat": ['mw'],
    "niṣiddhi": ['cae', 'ddsa', 'mw'],
    "niṣiddhiḥ": ['ap90'],
    "niṣidh": ['ap90', 'mw'],
    "niṣidha": ['mw'],
    "niṣidā": ['bhs'],
    "niṣikta": ['ap90', 'mw'],
    "niṣiktapā": ['gra', 'mw'],
    "niṣita": ['mw'],
    "niṣiv": ['mw'],
    "niṣk": ['ap90', 'mw'],
    "niṣka": ['cae', 'ddsa', 'gra', 'mw'],
    "niṣkagrīva": ['gra', 'mw'],
    "niṣkaitava": ['mw'],
    "niṣkaivalya": ['mw'],
    "niṣkakaṇṭha": ['mw'],
    "niṣkal": ['mw'],
    "niṣkala": ['cae', 'mw'],
    "niṣkalatva": ['mw'],
    "niṣkalaṅka": ['cae', 'mw'],
    "niṣkalaṅkatīrtha": ['mw'],
    "niṣkali": ['mw'],
    "niṣkalmaṣa": ['cae'],
    "niṣkambha": ['mw'],
    "niṣkambhu": ['mw'],
    "niṣkampa": ['cae', 'mw'],
    "niṣkampatā": ['mw'],
    "niṣkanda": ['mw'],
    "niṣkaniṣṭha": ['mw'],
    "niṣkaniṣṭhika": ['mw'],
    "niṣkapaṭa": ['mw'],
    "niṣkara": ['cae', 'mw'],
    "niṣkarman": ['cae', 'mw'],
    "niṣkartanaṃ": ['ap90'],
    "niṣkartṛ": ['mw'],
    "niṣkaruṇa": ['cae', 'mw'],
    "niṣkaruṇatā": ['mw'],
    "niṣkaruṇīkṛ": ['mw'],
    "niṣkarūṣa": ['mw'],
    "niṣkarṇa": ['mw'],
    "niṣkarṣa": ['cae', 'mw'],
    "niṣkarṣaḥ": ['ap90'],
    "niṣkarṣaṇa": ['bhs', 'mw'],
    "niṣkarṣaṇaṃ": ['ap90'],
    "niṣkarṣin": ['mw'],
    "niṣkarṣāt": ['mw'],
    "niṣkas": ['ap90', 'mw'],
    "niṣkaurava": ['mw'],
    "niṣkauśāmbi": ['mw'],
    "niṣkaḥ": ['ap90'],
    "niṣkaṇa": ['bhs'],
    "niṣkaṇṭaka": ['cae', 'ddsa', 'mw'],
    "niṣkaṇṭha": ['mw'],
    "niṣkaṇṭikā": ['mw'],
    "niṣkaṣāya": ['mw'],
    "niṣkaṭṭati": ['bhs'],
    "niṣkevala": ['mw'],
    "niṣkevalya": ['ddsa', 'mw'],
    "niṣkhan": ['mw'],
    "niṣkhid": ['mw'],
    "niṣkilbiṣa": ['mw'],
    "niṣkin": ['mw'],
    "niṣkira": ['mw'],
    "niṣkirīya": ['mw'],
    "niṣkiñcana": ['ddsa'],
    "niṣkiṃcana": ['cae', 'mw'],
    "niṣkiṃcanatva": ['mw'],
    "niṣkleśa": ['mw'],
    "niṣkleśaleśa": ['mw'],
    "niṣkośa": ['cae', 'ddsa', 'mw'],
    "niṣkoṣa": ['mw'],
    "niṣkoṣaḥ": ['ap90'],
    "niṣkoṣaṇa": ['mw'],
    "niṣkoṣaṇaka": ['mw'],
    "niṣkoṣaṇakaṃ": ['ap90'],
    "niṣkoṣitavya": ['mw'],
    "niṣkram": ['ap90', 'mw'],
    "niṣkrama": ['cae', 'ddsa', 'mw'],
    "niṣkramaḥ": ['ap90'],
    "niṣkramaṇa": ['bhs', 'mw'],
    "niṣkramaṇaprayoga": ['mw'],
    "niṣkramaṇaṃ": ['ap90'],
    "niṣkramaṇikā": ['ap90'],
    "niṣkramaṇita": ['mw'],
    "niṣkramya": ['bhs'],
    "niṣkramyati": ['bhs'],
    "niṣkraya": ['cae', 'mw'],
    "niṣkrayaḥ": ['ap90'],
    "niṣkrayaṇa": ['cae', 'mw'],
    "niṣkrayaṇaṃ": ['ap90'],
    "niṣkriya": ['cae', 'ddsa', 'mw'],
    "niṣkriyatā": ['mw'],
    "niṣkriyātman": ['cae', 'mw'],
    "niṣkriyātmatā": ['mw'],
    "niṣkrodha": ['cae', 'ddsa', 'mw'],
    "niṣkrāmayitar": ['bhs'],
    "niṣkrānta": ['cae', 'mw'],
    "niṣkrī": ['ap90', 'mw'],
    "niṣkrīti": ['cae', 'mw'],
    "niṣkrītiḥ": ['ap90'],
    "niṣkuha": ['mw'],
    "niṣkuhaḥ": ['ap90'],
    "niṣkula": ['cae', 'mw'],
    "niṣkulatvac": ['mw'],
    "niṣkulatā": ['mw'],
    "niṣkulākṛ": ['mw'],
    "niṣkulīkṛ": ['mw'],
    "niṣkulīna": ['mw'],
    "niṣkumbha": ['mw'],
    "niṣkumbhā": ['mw'],
    "niṣkupita": ['mw'],
    "niṣkutūhala": ['cae', 'mw'],
    "niṣkuṣ": ['ap90', 'mw'],
    "niṣkuṣita": ['ap90', 'mw'],
    "niṣkuṭa": ['bhs', 'cae', 'ddsa', 'mw'],
    "niṣkuṭaḥ": ['ap90'],
    "niṣkuṭi": ['mw'],
    "niṣkuṭikā": ['mw'],
    "niṣkuṭiḥ": ['ap90'],
    "niṣkuṭī": ['mw'],
    "niṣkuṭṭati": ['bhs'],
    "niṣkvath": ['mw'],
    "niṣkvātha": ['mw'],
    "niṣkvāthaḥ": ['ap90'],
    "niṣkā": ['mw'],
    "niṣkādipramāṇa": ['mw'],
    "niṣkālaka": ['mw'],
    "niṣkālana": ['mw'],
    "niṣkālanaṃ": ['ap90'],
    "niṣkālika": ['mw'],
    "niṣkāma": ['cae', 'mw'],
    "niṣkāmacārin": ['mw'],
    "niṣkāmaṣa": ['mw'],
    "niṣkāmaṣībhū": ['mw'],
    "niṣkāmuka": ['mw'],
    "niṣkānta": ['ddsa', 'mw'],
    "niṣkāraṇa": ['cae', 'mw'],
    "niṣkāraṇam": ['mw'],
    "niṣkāraṇaṃ": ['ap90'],
    "niṣkāraṇāt": ['mw'],
    "niṣkāruṇika": ['bhs'],
    "niṣkārya": ['mw'],
    "niṣkāsa": ['mw'],
    "niṣkāsana": ['cae', 'mw'],
    "niṣkāsanīya": ['cae', 'mw'],
    "niṣkāsati": ['bhs'],
    "niṣkāsayitar": ['bhs'],
    "niṣkāsaḥ": ['ap90'],
    "niṣkāsin": ['mw'],
    "niṣkāsinī": ['ap90', 'mw'],
    "niṣkāsita": ['ap90', 'mw'],
    "niṣkāvam": ['mw'],
    "niṣkāś": ['mw'],
    "niṣkāśa": ['mw'],
    "niṣkāśanīya": ['mw'],
    "niṣkāśaḥ": ['ap90'],
    "niṣkāśita": ['mw'],
    "niṣkāṅkṣa": ['bhs', 'mw'],
    "niṣkāṣa": ['mw'],
    "niṣkūja": ['cae', 'mw'],
    "niṣkūṭa": ['mw'],
    "niṣkṛ": ['ap90', 'mw'],
    "niṣkṛpa": ['cae', 'mw'],
    "niṣkṛt": ['ap90', 'gra', 'mw'],
    "niṣkṛta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "niṣkṛti": ['cae', 'gra', 'mw'],
    "niṣkṛtiḥ": ['ap90'],
    "niṣkṛtāhāva": ['mw'],
    "niṣkṛṣ": ['ap90', 'mw'],
    "niṣkṛṣyamāṇa": ['mw'],
    "niṣkṛṣyavidhāna": ['mw'],
    "niṣkṛṣṭa": ['ap90', 'mw'],
    "niṣo": ['mw'],
    "niṣpad": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "niṣpada": ['cae', 'mw'],
    "niṣpadi": ['bhs'],
    "niṣpakva": ['ap90', 'mw'],
    "niṣpalāpa": ['bhs'],
    "niṣpalāva": ['bhs', 'mw'],
    "niṣpalāy": ['mw'],
    "niṣpalāyati": ['bhs'],
    "niṣpanda": ['bhs', 'cae', 'ddsa', 'mw'],
    "niṣpandahīna": ['mw'],
    "niṣpandatarībhū": ['mw'],
    "niṣpandīkṛ": ['mw'],
    "niṣpanna": ['ap90', 'cae', 'mw'],
    "niṣparicaya": ['mw'],
    "niṣparicchada": ['mw'],
    "niṣparidāha": ['bhs', 'mw'],
    "niṣparigraha": ['mw'],
    "niṣparihārya": ['mw'],
    "niṣparikara": ['mw'],
    "niṣparuṣa": ['bhs', 'mw'],
    "niṣparyanta": ['cae', 'mw'],
    "niṣparyāyanta": ['mw'],
    "niṣparākrama": ['mw'],
    "niṣparāmarśa": ['cae', 'mw'],
    "niṣparīhāra": ['mw'],
    "niṣparīhāram": ['mw'],
    "niṣparīkṣa": ['mw'],
    "niṣpat": ['ap90', 'mw'],
    "niṣpatana": ['cae', 'mw'],
    "niṣpatanaṃ": ['ap90'],
    "niṣpathya": ['mw'],
    "niṣpatisutā": ['mw'],
    "niṣpatita": ['mw'],
    "niṣpatiṣṇu": ['mw'],
    "niṣpatti": ['cae', 'mw'],
    "niṣpattiḥ": ['ap90'],
    "niṣpattra": ['mw'],
    "niṣpattraka": ['mw'],
    "niṣpattraya": ['mw'],
    "niṣpattrikā": ['mw'],
    "niṣpattrākṛ": ['mw'],
    "niṣpattrākṛti": ['mw'],
    "niṣpatāka": ['mw'],
    "niṣpatākadhvaja": ['mw'],
    "niṣpauruṣa": ['mw'],
    "niṣpauruṣāmarṣa": ['mw'],
    "niṣpavanaṃ": ['ap90'],
    "niṣpavaṇa": ['mw'],
    "niṣpayoda": ['mw'],
    "niṣpaṃda": ['ap90'],
    "niṣpaṅka": ['ddsa', 'mw'],
    "niṣpeya": ['mw'],
    "niṣpeṣa": ['cae', 'mw'],
    "niṣpeṣavat": ['mw'],
    "niṣpeṣaḥ": ['ap90'],
    "niṣpeṣaṇa": ['bhs', 'mw'],
    "niṣphala": ['cae', 'ddsa', 'mw'],
    "niṣphalatva": ['mw'],
    "niṣphalaya": ['ddsa', 'mw'],
    "niṣphalā": ['mw'],
    "niṣphalīkṛ": ['cae', 'ddsa', 'mw'],
    "niṣphena": ['cae', 'mw'],
    "niṣphul": ['mw'],
    "niṣphur": ['mw'],
    "niṣphāra": ['cae', 'mw'],
    "niṣpitṛka": ['mw'],
    "niṣpiś": ['mw'],
    "niṣpiṣ": ['ap90', 'mw'],
    "niṣpiṣṭa": ['ap90', 'mw'],
    "niṣpoṣa": ['bhs', 'mw'],
    "niṣprabha": ['cae', 'mw'],
    "niṣprabhatva": ['mw'],
    "niṣprabhatā": ['mw'],
    "niṣprabhaṃkara": ['bhs'],
    "niṣprabhāva": ['mw'],
    "niṣprabhāvatva": ['mw'],
    "niṣprabhīkṛta": ['bhs'],
    "niṣpracāra": ['mw'],
    "niṣpradeśa": ['mw'],
    "niṣpradhāna": ['mw'],
    "niṣpragala": ['mw'],
    "niṣprajña": ['cae', 'mw'],
    "niṣprakampa": ['mw'],
    "niṣprakrama": ['mw'],
    "niṣprakāraka": ['mw'],
    "niṣprakāśa": ['mw'],
    "niṣpramāda": ['mw'],
    "niṣpramāṇaka": ['mw'],
    "niṣprapañca": ['bhs', 'mw'],
    "niṣprapañcasadātman": ['mw'],
    "niṣprapañcasadātmatva": ['mw'],
    "niṣprapañcātman": ['mw'],
    "niṣpratibandha": ['mw'],
    "niṣpratibha": ['mw'],
    "niṣpratibhaṃkṛ": ['mw'],
    "niṣpratibhāna": ['bhs', 'mw'],
    "niṣpratidvaṃdva": ['mw'],
    "niṣpratigha": ['mw'],
    "niṣpratigraha": ['mw'],
    "niṣpratigrahatā": ['mw'],
    "niṣpratikriya": ['mw'],
    "niṣpratikriyatā": ['mw'],
    "niṣpratimāna": ['bhs'],
    "niṣpratipakṣa": ['mw'],
    "niṣpratipakṣatā": ['mw'],
    "niṣpratyāśa": ['cae', 'mw'],
    "niṣpratyāśībhū": ['mw'],
    "niṣpratyūha": ['cae', 'mw'],
    "niṣpratyūham": ['mw'],
    "niṣpratāpa": ['cae', 'mw'],
    "niṣpratīkāra": ['mw'],
    "niṣpratīkāram": ['mw'],
    "niṣpratīpa": ['mw'],
    "niṣpravaṇi": ['mw'],
    "niṣpravāṇa": ['mw'],
    "niṣpravāṇaṃ": ['ap90'],
    "niṣpravāṇi": ['cae', 'mw'],
    "niṣprayatna": ['mw'],
    "niṣprayojana": ['cae', 'mw'],
    "niṣprayojanam": ['mw'],
    "niṣprayojanatva": ['mw'],
    "niṣprayojanatā": ['mw'],
    "niṣpraṇaya": ['mw'],
    "niṣpraṇayatva": ['mw'],
    "niṣpraṇayatā": ['mw'],
    "niṣprāṇa": ['bhs', 'cae', 'mw'],
    "niṣprāṇatā": ['mw'],
    "niṣprīti": ['cae', 'mw'],
    "niṣprītika": ['bhs', 'mw'],
    "niṣpudgala": ['bhs', 'mw'],
    "niṣpudgalatva": ['mw'],
    "niṣpula": ['bhs'],
    "niṣpulāka": ['mw'],
    "niṣpuruṣa": ['bhs', 'cae', 'mw'],
    "niṣpurāṇa": ['mw'],
    "niṣpurīṣa": ['mw'],
    "niṣpurīṣībhāva": ['mw'],
    "niṣputra": ['cae', 'mw'],
    "niṣputrajīvana": ['mw'],
    "niṣputrīkṛ": ['mw'],
    "niṣpā": ['mw'],
    "niṣpādaka": ['cae', 'mw'],
    "niṣpādakatva": ['mw'],
    "niṣpādana": ['mw'],
    "niṣpādanaṃ": ['ap90'],
    "niṣpādanā": ['bhs'],
    "niṣpādanīya": ['cae', 'mw'],
    "niṣpādita": ['bhs', 'mw'],
    "niṣpāditavya": ['mw'],
    "niṣpādya": ['cae', 'mw'],
    "niṣpādyatva": ['mw'],
    "niṣpālaka": ['mw'],
    "niṣpālāyitā": ['bhs'],
    "niṣpāna": ['mw'],
    "niṣpāpa": ['cae', 'mw'],
    "niṣpāra": ['cae', 'mw'],
    "niṣpāta": ['bhs', 'mw'],
    "niṣpātita": ['mw'],
    "niṣpāva": ['ap90', 'mw'],
    "niṣpāvaka": ['mw'],
    "niṣpāvala": ['mw'],
    "niṣpāvi": ['mw'],
    "niṣpāvī": ['mw'],
    "niṣpāṇḍava": ['ddsa', 'mw'],
    "niṣpīta": ['mw'],
    "niṣpīḍ": ['mw'],
    "niṣpīḍa": ['mw'],
    "niṣpīḍana": ['cae', 'mw'],
    "niṣpīḍayati": ['bhs'],
    "niṣpīḍin": ['bhs'],
    "niṣpīḍita": ['ap90'],
    "niṣpīṣati": ['bhs'],
    "niṣpū": ['ap90', 'mw'],
    "niṣpūrta": ['mw'],
    "niṣpūtigandhika": ['mw'],
    "niṣpṛ": ['mw'],
    "niṣur": ['mw'],
    "niṣuta": ['mw'],
    "niṣvap": ['mw'],
    "niṣvañj": ['mw'],
    "niṣyand": ['mw'],
    "niṣyanda": ['bhs', 'cae', 'ddsa'],
    "niṣyandabuddha": ['bhs'],
    "niṣyandin": ['cae', 'mw'],
    "niṣyandāyate": ['bhs'],
    "niṣyaṃdaḥ": ['ap90'],
    "niṣyūta": ['mw'],
    "niṣāda": ['bhs', 'cae', 'ddsa', 'mw'],
    "niṣādagrāma": ['mw'],
    "niṣādakarṣu": ['mw'],
    "niṣādarāṣṭra": ['mw'],
    "niṣādasaṅgha": ['mw'],
    "niṣādasthapati": ['mw'],
    "niṣādastrī": ['mw'],
    "niṣādatva": ['mw'],
    "niṣādavat": ['mw'],
    "niṣādaḥ": ['ap90'],
    "niṣādikā": ['bhs'],
    "niṣādin": ['ap90', 'cae', 'ddsa', 'mw'],
    "niṣādita": ['ap90', 'mw'],
    "niṣāditin": ['mw'],
    "niṣādī": ['mw'],
    "niṣādītva": ['mw'],
    "niṣīdana": ['bhs'],
    "niṣūd": ['ap90', 'mw'],
    "niṣūda": ['mw'],
    "niṣūdaka": ['cae', 'ddsa', 'mw'],
    "niṣūdana": ['cae', 'mw'],
    "niṣūdanaṃ": ['ap90'],
    "niṣūdita": ['mw'],
    "niṣṇa": ['ap90', 'cae', 'mw'],
    "niṣṇā": ['mw'],
    "niṣṇāta": ['cae', 'ddsa', 'mw'],
    "niṣṇātatva": ['mw'],
    "niṣṣah": ['cae', 'gra', 'mw'],
    "niṣṣapin": ['gra', 'mw'],
    "niṣṣidh": ['cae', 'gra', 'mw'],
    "niṣṣidhvan": ['gra', 'mw'],
    "niṣṣāh": ['cae', 'gra', 'mw'],
    "niṣṭakvan": ['mw'],
    "niṣṭan": ['mw'],
    "niṣṭana": ['mw'],
    "niṣṭap": ['ap90', 'mw'],
    "niṣṭapana": ['mw'],
    "niṣṭapanaṃ": ['ap90'],
    "niṣṭapta": ['ap90', 'mw'],
    "niṣṭarkya": ['mw'],
    "niṣṭavaiśya": ['mw'],
    "niṣṭaṅk": ['mw'],
    "niṣṭha": ['ap90', 'cae', 'ddsa', 'mw'],
    "niṣṭhaloka": ['mw'],
    "niṣṭhapada": ['bhs'],
    "niṣṭhapeti": ['bhs'],
    "niṣṭheva": ['mw'],
    "niṣṭhevana": ['mw'],
    "niṣṭhevanaṃ": ['ap90'],
    "niṣṭhevaḥ": ['ap90'],
    "niṣṭhevaṃ": ['ap90'],
    "niṣṭhita": ['ap90', 'bhs', 'cae', 'mw'],
    "niṣṭhitacīvara": ['mw'],
    "niṣṭhiv": ['ap90', 'mw'],
    "niṣṭhura": ['ap90', 'cae', 'ddsa', 'mw'],
    "niṣṭhurabhāṣin": ['mw'],
    "niṣṭhuraka": ['mw'],
    "niṣṭhuramānasa": ['mw'],
    "niṣṭhuratva": ['mw'],
    "niṣṭhuratā": ['mw'],
    "niṣṭhurika": ['mw'],
    "niṣṭhya": ['mw'],
    "niṣṭhyūta": ['ap90', 'cae', 'ddsa', 'mw'],
    "niṣṭhyūti": ['mw'],
    "niṣṭhyūtiḥ": ['ap90'],
    "niṣṭhā": ['cae', 'gra', 'mw'],
    "niṣṭhāgamanabhūmi": ['bhs'],
    "niṣṭhāgata": ['bhs', 'mw'],
    "niṣṭhāna": ['bhs', 'mw'],
    "niṣṭhānaka": ['mw'],
    "niṣṭhānaṃ": ['ap90'],
    "niṣṭhānta": ['mw'],
    "niṣṭhāpada": ['bhs'],
    "niṣṭhāpana": ['bhs'],
    "niṣṭhātva": ['bhs'],
    "niṣṭhāva": ['ap90', 'mw'],
    "niṣṭhāvant": ['cae'],
    "niṣṭhāvat": ['mw'],
    "niṣṭhāśūnya": ['cae', 'mw'],
    "niṣṭhīv": ['mw'],
    "niṣṭhīva": ['bhs', 'mw'],
    "niṣṭhīvana": ['cae', 'ddsa', 'mw'],
    "niṣṭhīvanaśarāva": ['mw'],
    "niṣṭhīvanaṃ": ['ap90'],
    "niṣṭhīvaḥ": ['ap90'],
    "niṣṭhīvaṃ": ['ap90'],
    "niṣṭhīvikā": ['mw'],
    "niṣṭhīvita": ['mw'],
    "niṣṭhīvitaṃ": ['ap90'],
    "niṣṭhūrin": ['mw'],
    "niṣṭhūta": ['mw'],
    "niṣṭhūti": ['mw'],
    "niṣṭi": ['mw'],
    "niṣṭia": ['gra'],
    "niṣṭigrī": ['gra', 'mw'],
    "niṣṭu": ['mw'],
    "niṣṭur": ['ap90', 'cae', 'gra', 'mw'],
    "niṣṭya": ['ap90', 'cae', 'gra', 'mw'],
    "niṣṭyai": ['mw'],
    "niṣṭyā": ['mw'],
    "niṣṭānaka": ['mw'],
    "niṣṭānakaḥ": ['ap90'],
    "niṣṭāpa": ['cae'],
    "niṣṭāpaḥ": ['ap90'],
    "niṭala": ['cae', 'mw'],
    "niṭalaṃ": ['ap90'],
    "niṭalākṣa": ['mw'],
    "niṭila": ['cae', 'ddsa', 'mw'],
    "niṭilataṭacumbita": ['mw'],
    "niṭilekṣaṇa": ['mw'],
    "niṭilākṣa": ['mw'],
    "niṭāla": ['cae', 'ddsa', 'mw'],
    "niṭṭala": ['mw'],
    "niṭṭhapetvā": ['cped'],
    "niṭṭhaṁ gacchati": ['cped'],
    "niṭṭhita": ['cped'],
    "niṭṭhubhati": ['cped'],
    "niṭṭhubhitabba": ['cped'],
    "niṭṭhubhitvā": ['cped'],
    "niṭṭhuhati": ['cped'],
    "niṭṭhā": ['cped'],
    "niṭṭhāgata": ['cped'],
    "niṭṭhāna": ['cped'],
    "niṭṭhānantika": ['cped'],
    "niṭṭhāpesi": ['cped'],
    "niṭṭhāpetvā": ['cped'],
    "niṭṭhāti": ['cped'],
    "niṭṭhāyati": ['cped'],
    "niṭṭhāṅgata": ['cped'],
    "no": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nocet": ['ap90'],
    "nod": ['mw'],
    "noda": ['cae', 'mw'],
    "nodana": ['cae', 'ddsa', 'mw'],
    "nodanaṃ": ['ap90'],
    "nodayitṛ": ['ap90'],
    "nodhas": ['cae', 'ddsa', 'gra', 'mw'],
    "nodhā": ['ap90', 'cae', 'mw'],
    "nodin": ['cae', 'ddsa', 'mw'],
    "nodita": ['mw'],
    "nodya": ['mw'],
    "nohīdaṃ": ['bhs'],
    "nona": ['ddsa', 'mw'],
    "nonaratha": ['mw'],
    "nonuva": ['cae', 'mw'],
    "nonā": ['mw'],
    "nonīta": ['cped'],
    "nopalakṣita": ['cae'],
    "nopasthātṛ": ['cae', 'ddsa', 'mw'],
    "nopasthāyin": ['cae', 'mw'],
    "not": ['cae', 'mw'],
    "notpādita": ['mw'],
    "notpāditatva": ['mw'],
    "notseka": ['mw'],
    "noṇa": ['ddsa', 'mw'],
    "noṭī": ['mw'],
    "nradhīśa": ['cae', 'mw'],
    "nrasthimālin": ['mw'],
    "nrārthi": ['mw'],
    "nu": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nud": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nuda": ['ap90', 'cae', 'mw'],
    "nudantaka": ['bhs'],
    "nudati": ['cped'],
    "nudeti": ['cped'],
    "nudita": ['mw'],
    "nujjati": ['cped'],
    "nunna": ['ap90', 'cped', 'mw'],
    "nunutsu": ['mw'],
    "nuta": ['ap90', 'mw'],
    "nutamitra": ['ddsa', 'mw'],
    "nuti": ['cae', 'ddsa', 'mw'],
    "nutiḥ": ['ap90'],
    "nutta": ['ap90', 'mw'],
    "nutti": ['cae', 'ddsa', 'mw'],
    "nuḍ": ['ap90', 'mw'],
    "nuḥ": ['ap90'],
    "nuṇṇa": ['cped'],
    "nuṭṭhubhati": ['cped'],
    "nuṭṭhubhitvā": ['cped'],
    "nuṭṭhuhati": ['cped'],
    "nva": ['mw'],
    "nvai": ['cae', 'ddsa', 'mw'],
    "nya": ['gra', 'mw'],
    "nyac": ['gra'],
    "nyaccha": ['cae', 'mw'],
    "nyacchaṃ": ['ap90'],
    "nyag": ['mw'],
    "nyagbhāva": ['cae', 'ddsa', 'mw'],
    "nyagbhāvana": ['cae', 'mw'],
    "nyagbhāvayitṛ": ['mw'],
    "nyagbhāvaḥ": ['ap90'],
    "nyagbhāvita": ['ap90'],
    "nyagbhū": ['ap90'],
    "nyagbhūta": ['mw'],
    "nyagbhūtvā": ['mw'],
    "nyagjāti": ['mw'],
    "nyagrodha": ['bhs', 'cae', 'ddsa', 'mw'],
    "nyagrodhaka": ['mw'],
    "nyagrodhakṣīra": ['mw'],
    "nyagrodhaparimaṇḍala": ['mw'],
    "nyagrodhaparimaṇḍalatā": ['mw'],
    "nyagrodhaparimaṇḍalā": ['mw'],
    "nyagrodhapāda": ['mw'],
    "nyagrodharāja": ['bhs'],
    "nyagrodhaḥ": ['ap90'],
    "nyagrodhika": ['mw'],
    "nyagrodhikā": ['bhs'],
    "nyagrodhin": ['mw'],
    "nyagrodhā": ['mw'],
    "nyagrodhārāma": ['bhs'],
    "nyagrodhī": ['mw'],
    "nyahna": ['cae', 'mw'],
    "nyak": ['ap90', 'mw'],
    "nyakkaraṇa": ['mw'],
    "nyakkaraṇaṃ": ['ap90'],
    "nyakkāra": ['cae', 'ddsa', 'mw'],
    "nyakkṛ": ['ap90'],
    "nyakkṛta": ['mw'],
    "nyakkṛti": ['mw'],
    "nyakkṛtya": ['mw'],
    "nyakna": ['mw'],
    "nyakta": ['ap90', 'ddsa', 'mw'],
    "nyakṣa": ['ap90', 'mw'],
    "nyakṣeṇa": ['mw'],
    "nyanta": ['mw'],
    "nyante": ['cae', 'mw'],
    "nyantena": ['ddsa', 'mw'],
    "nyarbuda": ['ddsa', 'mw'],
    "nyarbudaṃ": ['ap90'],
    "nyarbudi": ['mw'],
    "nyarpaya": ['mw'],
    "nyarpita": ['mw'],
    "nyartha": ['cae', 'ddsa', 'gra', 'mw'],
    "nyarṇa": ['cae', 'mw'],
    "nyarṇṇa": ['mw'],
    "nyas": ['ap90', 'mw'],
    "nyasana": ['bhs', 'cae', 'ddsa', 'mw'],
    "nyasanaṃ": ['ap90'],
    "nyasanīya": ['mw'],
    "nyasati": ['bhs'],
    "nyasta": ['ap90', 'cae', 'ddsa', 'mw'],
    "nyastacihna": ['mw'],
    "nyastadaṇḍa": ['cae', 'mw'],
    "nyastadeha": ['mw'],
    "nyastaka": ['mw'],
    "nyastavya": ['cae', 'mw'],
    "nyastavāda": ['mw'],
    "nyastaśastra": ['cae', 'mw'],
    "nyastārtvijya": ['mw'],
    "nyasya": ['cae', 'ddsa', 'mw'],
    "nyavacar": ['mw'],
    "nyavagraha": ['mw'],
    "nyavasṛj": ['mw'],
    "nyavekṣ": ['mw'],
    "nyaya": ['mw'],
    "nyayana": ['cae', 'ddsa', 'gra', 'mw'],
    "nyayaḥ": ['ap90'],
    "nyañc": ['cae', 'ddsa', 'mw'],
    "nyañcana": ['cae', 'ddsa', 'gra', 'mw'],
    "nyañcanaiṣin": ['mw'],
    "nyañcanī": ['mw'],
    "nyañcita": ['mw'],
    "nyañj": ['mw'],
    "nyañjalikā": ['mw'],
    "nyaṃc": ['ap90'],
    "nyaṃcanaṃ": ['ap90'],
    "nyaṃcita": ['ap90'],
    "nyaṃgaḥ": ['ap90'],
    "nyaṃj": ['ap90'],
    "nyaṃkuḥ": ['ap90'],
    "nyaṅga": ['cae', 'ddsa', 'mw'],
    "nyaṅka": ['cae', 'mw'],
    "nyaṅkotaka": ['ddsa', 'mw'],
    "nyaṅku": ['bhs', 'cae', 'ddsa', 'mw'],
    "nyaṅkubhūruha": ['mw'],
    "nyaṅkusāriṇī": ['mw'],
    "nyaṅkuśiras": ['mw'],
    "nyaṅkuṭā": ['bhs'],
    "nye": ['mw'],
    "nyej": ['mw'],
    "nyer": ['mw'],
    "nyocanī": ['ap90', 'gra', 'mw'],
    "nyocara": ['mw'],
    "nyojas": ['ap90', 'mw'],
    "nyoka": ['mw'],
    "nyokas": ['ap90', 'cae', 'gra', 'mw'],
    "nyubh": ['mw'],
    "nyubj": ['ap90', 'mw'],
    "nyubja": ['ap90', 'cae', 'ddsa', 'mw'],
    "nyubjaka": ['mw'],
    "nyubjakhaḍga": ['mw'],
    "nyubjimat": ['mw'],
    "nyuc": ['ap90', 'mw'],
    "nyud": ['mw'],
    "nyund": ['mw'],
    "nyupta": ['mw'],
    "nyutta": ['mw'],
    "nyuṃkha": ['ap90'],
    "nyuṅkha": ['mw'],
    "nyuṣ": ['mw'],
    "nyācam": ['cae', 'mw'],
    "nyāda": ['mw'],
    "nyādaḥ": ['ap90'],
    "nyādhā": ['mw'],
    "nyādhṛ": ['mw'],
    "nyādru": ['mw'],
    "nyāgam": ['mw'],
    "nyāgrodhamūla": ['mw'],
    "nyāgrodhamūlika": ['mw'],
    "nyākya": ['mw'],
    "nyākyaṃ": ['ap90'],
    "nyākṛ": ['mw'],
    "nyālūna": ['mw'],
    "nyāma": ['bhs', 'mw'],
    "nyānī": ['mw'],
    "nyāsa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "nyāsabhūta": ['mw'],
    "nyāsad": ['mw'],
    "nyāsadaśaka": ['mw'],
    "nyāsadhāraka": ['mw'],
    "nyāsadhārin": ['cae', 'mw'],
    "nyāsahara": ['mw'],
    "nyāsakhaṇḍa": ['mw'],
    "nyāsakhaṇḍana": ['mw'],
    "nyāsakāra": ['mw'],
    "nyāsakṛt": ['mw'],
    "nyāsalopa": ['mw'],
    "nyāsaprakaraṇa": ['mw'],
    "nyāsatilaka": ['mw'],
    "nyāsatūlikā": ['mw'],
    "nyāsavidhāna": ['mw'],
    "nyāsavidyādarpaṇa": ['mw'],
    "nyāsavidyāvilāsa": ['mw'],
    "nyāsaviśeṣa": ['mw'],
    "nyāsaviṃśati": ['mw'],
    "nyāsaśataka": ['mw'],
    "nyāsaḥ": ['ap90'],
    "nyāsika": ['mw'],
    "nyāsin": ['ap90', 'mw'],
    "nyāsita": ['mw'],
    "nyāsoddyota": ['mw'],
    "nyāsādeśavivaraṇa": ['mw'],
    "nyāsāpahnava": ['mw'],
    "nyāsīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "nyāvicchāy": ['mw'],
    "nyāviś": ['mw'],
    "nyāvyadh": ['mw'],
    "nyāvṛt": ['mw'],
    "nyāya": ['cae', 'ddsa', 'mw'],
    "nyāyabhāskara": ['mw'],
    "nyāyabhāṣya": ['mw'],
    "nyāyabhūṣaṇa": ['mw'],
    "nyāyabindu": ['mw'],
    "nyāyabinduṭīkā": ['mw'],
    "nyāyabodhinī": ['mw'],
    "nyāyacandrikā": ['mw'],
    "nyāyacintāmaṇi": ['mw'],
    "nyāyacūḍāmaṇi": ['mw'],
    "nyāyacūḍāmaṇiprabhā": ['mw'],
    "nyāyadarpaṇa": ['mw'],
    "nyāyadeva": ['mw'],
    "nyāyadvayakāraṇatāvāda": ['mw'],
    "nyāyadvārakaśāstra": ['mw'],
    "nyāyadīpa": ['mw'],
    "nyāyadīpavyākhyā": ['mw'],
    "nyāyadīpikā": ['mw'],
    "nyāyadīpāvalī": ['mw'],
    "nyāyagrantha": ['mw'],
    "nyāyakalikā": ['mw'],
    "nyāyakalpalatikā": ['mw'],
    "nyāyakalpalatā": ['mw'],
    "nyāyakalānidhi": ['mw'],
    "nyāyakalāpa": ['mw'],
    "nyāyakandalī": ['mw'],
    "nyāyakaraṇḍa": ['mw'],
    "nyāyakaumudī": ['mw'],
    "nyāyakaustubha": ['mw'],
    "nyāyakaṇikā": ['mw'],
    "nyāyakhaṇḍanakhaṇḍakhādya": ['mw'],
    "nyāyakiraṇāvalī": ['mw'],
    "nyāyakokila": ['mw'],
    "nyāyakośa": ['mw'],
    "nyāyakroḍa": ['mw'],
    "nyāyakroḍapattra": ['mw'],
    "nyāyakuliśa": ['mw'],
    "nyāyakusumamañjarī": ['mw'],
    "nyāyakusumāñjali": ['mw'],
    "nyāyakusumāñjalikārikā": ['mw'],
    "nyāyakusumāñjaliprakāśa": ['mw'],
    "nyāyakusumāñjalivikāśa": ['mw'],
    "nyāyakusumāñjaliviveka": ['mw'],
    "nyāyakutūhala": ['mw'],
    "nyāyakāśikā": ['mw'],
    "nyāyalakṣaṇavicāra": ['mw'],
    "nyāyalīlāvatī": ['mw'],
    "nyāyalīlāvatībhāvaprakāśa": ['mw'],
    "nyāyalīlāvatīkaṇṭhābharaṇa": ['mw'],
    "nyāyalīlāvatīprakāśa": ['mw'],
    "nyāyalīlāvatīprakāśadidhitiviveka": ['mw'],
    "nyāyalīlāvatīprakāśadīdhiti": ['mw'],
    "nyāyalīlāvatīprakāśarahasya": ['mw'],
    "nyāyalīlāvatīrahasya": ['mw'],
    "nyāyalīlāvatīvibhūti": ['mw'],
    "nyāyalīlāvatīviveka": ['mw'],
    "nyāyam": ['mw'],
    "nyāyamahodadhi": ['mw'],
    "nyāyamakaranda": ['mw'],
    "nyāyamakarandavivardhinī": ['mw'],
    "nyāyamakarandavivecinī": ['mw'],
    "nyāyamakarandavivṛti": ['mw'],
    "nyāyamanoramā": ['mw'],
    "nyāyamatakhaṇḍana": ['mw'],
    "nyāyamañjarī": ['mw'],
    "nyāyamañjarīgranthabhaṅga": ['mw'],
    "nyāyamañjarīsāra": ['mw'],
    "nyāyamañjūṣā": ['mw'],
    "nyāyamuktāvalī": ['mw'],
    "nyāyamuktāvalīkiraṇa": ['mw'],
    "nyāyamuktāvalīprakāśa": ['mw'],
    "nyāyamālikā": ['mw'],
    "nyāyamālā": ['mw'],
    "nyāyamālāvaiyāsikī": ['mw'],
    "nyāyamālāvistara": ['mw'],
    "nyāyamālāvārttikasaṃgraha": ['mw'],
    "nyāyamārtaṇḍa": ['mw'],
    "nyāyamātṛkā": ['mw'],
    "nyāyamīmāṃsāprakaraṇa": ['mw'],
    "nyāyamīmāṃsārahasya": ['mw'],
    "nyāyamūlaparibhāṣā": ['mw'],
    "nyāyanaya": ['mw'],
    "nyāyanibhandha": ['mw'],
    "nyāyanibhandhaprakāśa": ['mw'],
    "nyāyanirvapaṇa": ['mw'],
    "nyāyanirṇaya": ['mw'],
    "nyāyapadārthamālā": ['mw'],
    "nyāyapariccheda": ['mw'],
    "nyāyapariśiṣṭa": ['mw'],
    "nyāyapariśiṣṭaprakāśa": ['mw'],
    "nyāyapariśuddhi": ['mw'],
    "nyāyapatha": ['mw'],
    "nyāyapañcādhyāyī": ['mw'],
    "nyāyapañcānana": ['mw'],
    "nyāyapañcāśat": ['mw'],
    "nyāyapradīpa": ['mw'],
    "nyāyapradīpikā": ['mw'],
    "nyāyaprakaraṇa": ['mw'],
    "nyāyaprakāśa": ['mw'],
    "nyāyaprakāśikā": ['mw'],
    "nyāyapramāṇamañjarīṭīkā": ['mw'],
    "nyāyaprasthānamārga": ['mw'],
    "nyāyapraveśa": ['mw'],
    "nyāyapraveśatārakaśāstra": ['mw'],
    "nyāyapuṣpāñjali": ['mw'],
    "nyāyapārijāta": ['mw'],
    "nyāyarahasya": ['mw'],
    "nyāyarakṣāmaṇi": ['mw'],
    "nyāyaratna": ['mw'],
    "nyāyaratnakośavādārtha": ['mw'],
    "nyāyaratnamālā": ['mw'],
    "nyāyaratnaprakaraṇa": ['mw'],
    "nyāyaratnaprakāśikā": ['mw'],
    "nyāyaratnaṭīkā": ['mw'],
    "nyāyaratnākara": ['mw'],
    "nyāyaratnāvalī": ['mw'],
    "nyāyasadarthasaṃgraha": ['mw'],
    "nyāyasambaddha": ['mw'],
    "nyāyasaṃgraha": ['mw'],
    "nyāyasaṃgrahadīpikā": ['mw'],
    "nyāyasaṃhita": ['mw'],
    "nyāyasaṃketa": ['mw'],
    "nyāyasaṃketatilakā": ['mw'],
    "nyāyasaṃkṣepa": ['mw'],
    "nyāyasiddhānta": ['mw'],
    "nyāyasiddhāntacandrikā": ['mw'],
    "nyāyasiddhāntadīpa": ['mw'],
    "nyāyasiddhāntamañjarī": ['mw'],
    "nyāyasiddhāntamañjarībhūṣā": ['mw'],
    "nyāyasiddhāntamañjarīdīpikā": ['mw'],
    "nyāyasiddhāntamañjarīprakāśa": ['mw'],
    "nyāyasiddhāntamañjarīsāra": ['mw'],
    "nyāyasiddhāntamuktāvalī": ['mw'],
    "nyāyasiddhāntamālā": ['mw'],
    "nyāyasiddhāntapañcānana": ['mw'],
    "nyāyasiddhāntatattva": ['mw'],
    "nyāyasiddhāntatattvāmṛta": ['mw'],
    "nyāyasiddhāntavāgīśa": ['mw'],
    "nyāyasiddhāñjana": ['mw'],
    "nyāyasudhā": ['mw'],
    "nyāyasvarūpanirūpaṇa": ['mw'],
    "nyāyasāra": ['mw'],
    "nyāyasāradīpikā": ['mw'],
    "nyāyasārapadapañjikā": ['mw'],
    "nyāyasārasaṃgraha": ['mw'],
    "nyāyasāraṭīkā": ['mw'],
    "nyāyasāriṇī": ['mw'],
    "nyāyasārāvalī": ['mw'],
    "nyāyasūtra": ['mw'],
    "nyāyasūtravṛtti": ['mw'],
    "nyāyatantra": ['mw'],
    "nyāyatantrabodhinī": ['mw'],
    "nyāyataraṃgiṇī": ['mw'],
    "nyāyatas": ['mw'],
    "nyāyatattva": ['mw'],
    "nyāyatattvaparīkṣā": ['mw'],
    "nyāyatattvaviloka": ['mw'],
    "nyāyatattvavivaraṇa": ['mw'],
    "nyāyataḥ": ['ap90'],
    "nyāyatrisūtrīvārttika": ['mw'],
    "nyāyatva": ['mw'],
    "nyāyatā": ['mw'],
    "nyāyatātparyadīpikā": ['mw'],
    "nyāyavant": ['cae'],
    "nyāyavartin": ['cae', 'mw'],
    "nyāyavastusāra": ['mw'],
    "nyāyavat": ['mw'],
    "nyāyavid": ['mw'],
    "nyāyavidyā": ['cae', 'mw'],
    "nyāyavihita": ['mw'],
    "nyāyavilāsa": ['mw'],
    "nyāyavirodha": ['mw'],
    "nyāyavirodhin": ['mw'],
    "nyāyaviruddha": ['mw'],
    "nyāyavivaraṇa": ['mw'],
    "nyāyaviveka": ['mw'],
    "nyāyavivekadīpikā": ['mw'],
    "nyāyavācaspati": ['mw'],
    "nyāyavāda": ['mw'],
    "nyāyavādin": ['cae', 'mw'],
    "nyāyavāgīśa": ['mw'],
    "nyāyavārttika": ['mw'],
    "nyāyavārttikatātparyapariśuddhi": ['mw'],
    "nyāyavārttikatātparyaṭīkā": ['mw'],
    "nyāyavṛtta": ['cae', 'mw'],
    "nyāyavṛtti": ['mw'],
    "nyāyaśikhāmaṇi": ['mw'],
    "nyāyaśikṣā": ['mw'],
    "nyāyaśiromaṇi": ['mw'],
    "nyāyaśuddhi": ['mw'],
    "nyāyaśāstra": ['cae', 'mw'],
    "nyāyaḥ": ['ap90'],
    "nyāyena": ['mw'],
    "nyāyika": ['mw'],
    "nyāyin": ['ap90', 'mw'],
    "nyāyopeta": ['mw'],
    "nyāyya": ['ap90', 'cae', 'ddsa', 'mw'],
    "nyāyyadaṇḍa": ['mw'],
    "nyāyyadaṇḍatva": ['mw'],
    "nyāyyatva": ['mw'],
    "nyāyābhāsa": ['mw'],
    "nyāyācāra": ['mw'],
    "nyāyācārya": ['mw'],
    "nyāyādhvadīpikā": ['mw'],
    "nyāyādhāra": ['mw'],
    "nyāyāgata": ['mw'],
    "nyāyālaṃkāra": ['mw'],
    "nyāyāmṛta": ['mw'],
    "nyāyāmṛtataraṃgiṇī": ['mw'],
    "nyāyānusāraśāstra": ['mw'],
    "nyāyānveṣaṇa": ['mw'],
    "nyāyārjita": ['mw'],
    "nyāyāropitavikrama": ['ddsa'],
    "nyāyārthadīpikā": ['mw'],
    "nyāyārthalaghusubodhinī": ['mw'],
    "nyāyāt": ['mw'],
    "nyāyāvakrākramaṇa": ['mw'],
    "nyāyāvakrākramaṇatā": ['mw'],
    "nyāyāvalīdīdhiti": ['mw'],
    "nyāyāvatāra": ['mw'],
    "nyāṅkava": ['mw'],
    "nyāṣatta": ['mw'],
    "nyūh": ['mw'],
    "nyūna": ['ap90', 'cae', 'ddsa', 'mw'],
    "nyūnabhāva": ['mw'],
    "nyūnam": ['mw'],
    "nyūnapadatva": ['mw'],
    "nyūnapadatā": ['mw'],
    "nyūnapañcāśadbhāva": ['mw'],
    "nyūnatara": ['mw'],
    "nyūnataram": ['mw'],
    "nyūnatva": ['mw'],
    "nyūnatā": ['mw'],
    "nyūnay": ['cae'],
    "nyūnaya": ['mw'],
    "nyūnayati": ['ap90'],
    "nyūnendriya": ['mw'],
    "nyūnādhika": ['cae', 'mw'],
    "nyūnādhikavibhakta": ['mw'],
    "nyūnādhikavibhāga": ['mw'],
    "nyūnādhikya": ['mw'],
    "nyūnādhikāṅga": ['mw'],
    "nyūnāha": ['mw'],
    "nyūnākṣara": ['mw'],
    "nyūnāṅga": ['mw'],
    "nyūnī": ['mw'],
    "nyūnībhāva": ['mw'],
    "nyūnīkṛ": ['cae', 'mw'],
    "nyūṃkha": ['ap90'],
    "nyūṅkha": ['cae', 'mw'],
    "nyūṅkham": ['mw'],
    "nyūṅkhamānaka": ['mw'],
    "nyūṅkhanīya": ['mw'],
    "nyūṅkhaya": ['mw'],
    "nyūṅkhya": ['mw'],
    "nyṛ": ['mw'],
    "nyṛñj": ['mw'],
    "nyṛṣ": ['mw'],
    "nyṛṣṭa": ['mw'],
    "nā": ['ap90', 'cae', 'mw'],
    "nābh": ['cae', 'ddsa', 'gra', 'mw'],
    "nābha": ['cae', 'ddsa', 'mw'],
    "nābhaka": ['mw'],
    "nābhakaḥ": ['ap90'],
    "nābhasa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "nābhasayogādhyāya": ['mw'],
    "nābheya": ['mw'],
    "nābhi": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nābhibhū": ['cae', 'mw'],
    "nābhicakra": ['mw'],
    "nābhicchedana": ['mw'],
    "nābhidaghna": ['cae', 'mw'],
    "nābhidaghnapāda": ['mw'],
    "nābhideśa": ['mw'],
    "nābhidhāvat": ['ddsa', 'mw'],
    "nābhigandha": ['mw'],
    "nābhigarbha": ['bhs'],
    "nābhigolaka": ['mw'],
    "nābhigupta": ['mw'],
    "nābhiguḍaka": ['mw'],
    "nābhija": ['mw'],
    "nābhijanman": ['mw'],
    "nābhijāta": ['cae', 'ddsa', 'mw'],
    "nābhika": ['cae', 'mw'],
    "nābhikapura": ['mw'],
    "nābhikaṇṭaka": ['mw'],
    "nābhikupikā": ['mw'],
    "nābhikā": ['ap90', 'mw'],
    "nābhikṛntana": ['mw'],
    "nābhila": ['ap90', 'mw'],
    "nābhilakṣita": ['cae', 'ddsa', 'mw'],
    "nābhimaṇḍala": ['cped'],
    "nābhimāna": ['cae', 'mw'],
    "nābhimātra": ['mw'],
    "nābhimūla": ['mw'],
    "nābhināla": ['ddsa', 'mw'],
    "nābhinālā": ['mw'],
    "nābhināḍī": ['mw'],
    "nābhitva": ['mw'],
    "nābhivardhana": ['cae', 'ddsa', 'mw'],
    "nābhivarṣa": ['mw'],
    "nābhya": ['ap90', 'cae', 'mw'],
    "nābhyāvarta": ['mw'],
    "nābhā": ['mw'],
    "nābhāga": ['cae', 'mw'],
    "nābhāgadiṣṭa": ['mw'],
    "nābhāganediṣṭha": ['mw'],
    "nābhāgi": ['mw'],
    "nābhāgāriṣṭa": ['cae', 'mw'],
    "nābhāka": ['ddsa', 'gra', 'mw'],
    "nābhānediṣṭha": ['cae', 'gra', 'mw'],
    "nābhī": ['cae', 'cped', 'ddsa'],
    "nābhīla": ['mw'],
    "nābhīlaṃ": ['ap90'],
    "nācika": ['mw'],
    "nāciketa": ['cae', 'mw'],
    "nāciketaprayoga": ['mw'],
    "nāciketaḥ": ['ap90'],
    "nāciketopākhyāna": ['mw'],
    "nācirāja": ['mw'],
    "nācoka": ['mw'],
    "nācīna": ['mw'],
    "nāda": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "nādabindūpaniṣad": ['mw'],
    "nādadīpaka": ['mw'],
    "nādakārikā": ['mw'],
    "nādana": ['bhs'],
    "nādapurāṇa": ['mw'],
    "nādara": ['mw'],
    "nādatā": ['mw'],
    "nādavat": ['ap90', 'mw'],
    "nādayati": ['cped'],
    "nādaḥ": ['ap90'],
    "nādeti": ['cped'],
    "nādeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "nādeyī": ['mw'],
    "nādh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nādhas": ['cae', 'gra', 'mw'],
    "nādhita": ['mw'],
    "nādhīta": ['cae', 'ddsa', 'mw'],
    "nādi": ['ap90', 'cae', 'mw'],
    "nādia": ['gra'],
    "nādiga": ['mw'],
    "nādika": ['mw'],
    "nādikā": ['bhs'],
    "nādin": ['ap90', 'cae', 'mw'],
    "nādita": ['cae', 'cped', 'mw'],
    "nādya": ['ap90', 'cae', 'gra', 'mw'],
    "nāga": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "nāgabala": ['bhs', 'mw'],
    "nāgabali": ['mw'],
    "nāgabalā": ['mw'],
    "nāgabandha": ['mw'],
    "nāgabandhaka": ['mw'],
    "nāgabandhu": ['mw'],
    "nāgabhaginī": ['mw'],
    "nāgabhaṭa": ['mw'],
    "nāgabhaṭṭa": ['mw'],
    "nāgabhid": ['mw'],
    "nāgabhoga": ['mw'],
    "nāgabhogabāhu": ['bhs'],
    "nāgabhuja": ['bhs'],
    "nāgabhūṣaṇa": ['mw'],
    "nāgabhṛt": ['mw'],
    "nāgabodha": ['mw'],
    "nāgabodhin": ['mw'],
    "nāgabuddha": ['mw'],
    "nāgabuddhi": ['mw'],
    "nāgabuddhinighaṇṭu": ['mw'],
    "nāgabāhu": ['bhs'],
    "nāgacampaka": ['mw'],
    "nāgacchattrā": ['mw'],
    "nāgacūḍa": ['mw'],
    "nāgadalopama": ['mw'],
    "nāgadamanī": ['mw'],
    "nāgadanta": ['cae', 'cped', 'ddsa', 'mw'],
    "nāgadantaka": ['cped', 'mw'],
    "nāgadantamaya": ['mw'],
    "nāgadantikā": ['mw'],
    "nāgadantā": ['mw'],
    "nāgadantī": ['mw'],
    "nāgadatta": ['bhs', 'mw'],
    "nāgadeva": ['cae', 'mw'],
    "nāgadevāhnika": ['mw'],
    "nāgadevīya": ['mw'],
    "nāgadeṇṭikā": ['mw'],
    "nāgadhanvan": ['mw'],
    "nāgadharīya": ['mw'],
    "nāgadhvani": ['mw'],
    "nāgadru": ['mw'],
    "nāgadvīpa": ['mw'],
    "nāgadāśaka": ['mw'],
    "nāgagandhā": ['mw'],
    "nāgagarbha": ['mw'],
    "nāgahantrī": ['mw'],
    "nāgahanu": ['mw'],
    "nāgahata": ['cped'],
    "nāgahrada": ['cae', 'mw'],
    "nāgaja": ['mw'],
    "nāgajihvikā": ['mw'],
    "nāgajihvā": ['mw'],
    "nāgajīvana": ['mw'],
    "nāgajīvanaśatru": ['mw'],
    "nāgaka": ['ddsa', 'mw'],
    "nāgakanda": ['mw'],
    "nāgakanyakā": ['cae', 'mw'],
    "nāgakanyā": ['mw'],
    "nāgakarṇa": ['mw'],
    "nāgakesara": ['mw'],
    "nāgakeśa": ['mw'],
    "nāgakhaṇḍa": ['mw'],
    "nāgakiñjalka": ['mw'],
    "nāgakulodbhavameghavirājita": ['bhs'],
    "nāgakulottama": ['bhs'],
    "nāgakumāra": ['cae', 'mw'],
    "nāgakumārī": ['mw'],
    "nāgakuṇḍalakuṇḍalin": ['mw'],
    "nāgalatā": ['ddsa', 'mw'],
    "nāgalekhā": ['mw'],
    "nāgalipi": ['bhs'],
    "nāgaloka": ['cae', 'mw'],
    "nāgalokapati": ['mw'],
    "nāgamalla": ['mw'],
    "nāgamatī": ['mw'],
    "nāgamauñjin": ['mw'],
    "nāgamaya": ['mw'],
    "nāgamaṇi": ['bhs'],
    "nāgamaṇḍalika": ['bhs', 'mw'],
    "nāgammā": ['mw'],
    "nāgamudra": ['mw'],
    "nāgamudrā": ['cae', 'mw'],
    "nāgamuni": ['bhs'],
    "nāgamāra": ['mw'],
    "nāgamātṛ": ['cae', 'mw'],
    "nāganadī": ['bhs'],
    "nāganakṣatra": ['mw'],
    "nāganiryūha": ['mw'],
    "nāganābha": ['mw'],
    "nāganāmaka": ['mw'],
    "nāganāman": ['mw'],
    "nāganāsorū": ['mw'],
    "nāganāsā": ['mw'],
    "nāganātha": ['cae', 'ddsa', 'mw'],
    "nāganāyaka": ['cae', 'mw'],
    "nāgapacāra": ['cped'],
    "nāgapada": ['mw'],
    "nāgapaiya": ['mw'],
    "nāgapalokita": ['cped'],
    "nāgaparṇī": ['mw'],
    "nāgapati": ['cae', 'mw'],
    "nāgapattrā": ['mw'],
    "nāgapañcamī": ['mw'],
    "nāgapañcamīvrata": ['mw'],
    "nāgapañcamīvratakathā": ['mw'],
    "nāgapaṭṭana": ['mw'],
    "nāgaphala": ['mw'],
    "nāgaphalā": ['mw'],
    "nāgapota": ['mw'],
    "nāgapratiṣṭhā": ['mw'],
    "nāgapura": ['cae', 'mw'],
    "nāgapurī": ['mw'],
    "nāgapurīmāhātmya": ['mw'],
    "nāgaputra": ['mw'],
    "nāgapuṣpa": ['mw'],
    "nāgapuṣpaphalā": ['mw'],
    "nāgapuṣpikā": ['mw'],
    "nāgapuṣpī": ['mw'],
    "nāgapāla": ['mw'],
    "nāgapālaka": ['bhs'],
    "nāgapāśa": ['mw'],
    "nāgapāśaka": ['mw'],
    "nāgara": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "nāgarabindava": ['bhs'],
    "nāgaraghana": ['mw'],
    "nāgaraka": ['ap90', 'cae', 'ddsa', 'mw'],
    "nāgarakhaṇḍa": ['mw'],
    "nāgarakta": ['mw'],
    "nāgaramardi": ['mw'],
    "nāgaramustaka": ['mw'],
    "nāgaramustā": ['mw'],
    "nāgaranṛpati": ['mw'],
    "nāgarasarvasva": ['mw'],
    "nāgarasena": ['mw'],
    "nāgarastrī": ['mw'],
    "nāgaratā": ['mw'],
    "nāgarayāyigraha": ['mw'],
    "nāgaraṅga": ['mw'],
    "nāgaraṅgaka": ['mw'],
    "nāgaraṭṭa": ['mw'],
    "nāgareyaka": ['ap90', 'mw'],
    "nāgareṇu": ['mw'],
    "nāgarika": ['cae', 'ddsa', 'mw'],
    "nāgarikabala": ['mw'],
    "nāgarikapura": ['mw'],
    "nāgarikavṛtti": ['cae', 'mw'],
    "nāgarikā": ['mw'],
    "nāgarotthā": ['mw'],
    "nāgaruka": ['mw'],
    "nāgarukaḥ": ['ap90'],
    "nāgarya": ['mw'],
    "nāgaryaṃ": ['ap90'],
    "nāgarāhva": ['mw'],
    "nāgarāj": ['cae', 'ddsa', 'mw'],
    "nāgarāja": ['cae', 'mw'],
    "nāgarājan": ['cae'],
    "nāgarājanāṭaka": ['mw'],
    "nāgarājapaddhati": ['mw'],
    "nāgarājaśataka": ['mw'],
    "nāgarājāya": ['mw'],
    "nāgarāvalambikā": ['mw'],
    "nāgarī": ['ddsa', 'mw'],
    "nāgarīṭa": ['mw'],
    "nāgarīṭaḥ": ['ap90'],
    "nāgarūpadhṛk": ['mw'],
    "nāgasambhava": ['mw'],
    "nāgasambhūta": ['mw'],
    "nāgasena": ['mw'],
    "nāgasphoṭā": ['mw'],
    "nāgasthala": ['mw'],
    "nāgastokaka": ['mw'],
    "nāgasugandhā": ['mw'],
    "nāgasvāmin": ['mw'],
    "nāgasāhvaya": ['cae', 'mw'],
    "nāgatamanī": ['mw'],
    "nāgatithi": ['mw'],
    "nāgatīrtha": ['mw'],
    "nāgatīrthamāhātmya": ['mw'],
    "nāgavadha": ['mw'],
    "nāgavadhū": ['cae', 'mw'],
    "nāgavallarī": ['mw'],
    "nāgavallī": ['mw'],
    "nāgavallīkalpa": ['mw'],
    "nāgavana": ['mw'],
    "nāgavanika": ['cped'],
    "nāgavant": ['cae'],
    "nāgavardhana": ['mw'],
    "nāgavarman": ['mw'],
    "nāgavartman": ['mw'],
    "nāgavat": ['mw'],
    "nāgavatman": ['mw'],
    "nāgavatā": ['cped'],
    "nāgavaśā": ['cae', 'mw'],
    "nāgavaṭṭa": ['mw'],
    "nāgavidhi": ['mw'],
    "nāgavikrāntagamitā": ['mw'],
    "nāgavyādhinirṇaya": ['mw'],
    "nāgavārika": ['mw'],
    "nāgavāsa": ['mw'],
    "nāgavīthī": ['mw'],
    "nāgavṛkṣa": ['mw'],
    "nāgayajñopavīta": ['mw'],
    "nāgayajñopavītavat": ['mw'],
    "nāgayajñopavītin": ['mw'],
    "nāgayana": ['bhs'],
    "nāgayaṣṭi": ['mw'],
    "nāgayaṣṭikā": ['mw'],
    "nāgayya": ['mw'],
    "nāgaśabdī": ['mw'],
    "nāgaśarman": ['mw'],
    "nāgaśata": ['mw'],
    "nāgaśrī": ['mw'],
    "nāgaśuṇḍī": ['mw'],
    "nāgaśūra": ['mw'],
    "nāgendra": ['cae', 'ddsa', 'mw'],
    "nāgendracūḍa": ['bhs'],
    "nāgeśa": ['mw'],
    "nāgeśavivaraṇa": ['mw'],
    "nāgeśvara": ['mw'],
    "nāgeśvararāja": ['bhs'],
    "nāgeśvaratīrtha": ['mw'],
    "nāgeśvarī": ['mw'],
    "nāgila": ['mw'],
    "nāgilā": ['mw'],
    "nāgin": ['ap90', 'cae', 'mw'],
    "nāginī": ['cped', 'mw'],
    "nāgnajita": ['mw'],
    "nāgnajitī": ['mw'],
    "nāgnidūṣita": ['ddsa', 'mw'],
    "nāgnya": ['bhs'],
    "nāgoba": ['mw'],
    "nāgoda": ['mw'],
    "nāgodara": ['mw'],
    "nāgodbheda": ['mw'],
    "nāgoji": ['cae', 'mw'],
    "nāgojibhaṭṭa": ['cae'],
    "nāgojibhaṭṭīya": ['mw'],
    "nāgojipaddhati": ['mw'],
    "nāgopavītin": ['mw'],
    "nāgottama": ['bhs'],
    "nāgulī": ['mw'],
    "nāgābharaṇa": ['mw'],
    "nāgābhibhu": ['mw'],
    "nāgābhibhū": ['bhs'],
    "nāgādhipa": ['mw'],
    "nāgādhipati": ['bhs', 'mw'],
    "nāgādhirāja": ['ddsa', 'mw'],
    "nāgāhva": ['mw'],
    "nāgāhvaya": ['bhs', 'cae', 'mw'],
    "nāgāhvā": ['mw'],
    "nāgākhya": ['mw'],
    "nāgālābu": ['mw'],
    "nāgāmaṇi": ['bhs'],
    "nāgānana": ['mw'],
    "nāgānanda": ['cae', 'mw'],
    "nāgānandīya": ['mw'],
    "nāgāntaka": ['mw'],
    "nāgāri": ['mw'],
    "nāgārigirivivarakalpa": ['mw'],
    "nāgāritantrahoma": ['mw'],
    "nāgārjuna": ['bhs', 'mw'],
    "nāgārjunacarita": ['mw'],
    "nāgārjunajātaka": ['mw'],
    "nāgārjunatantra": ['mw'],
    "nāgārjunī": ['mw'],
    "nāgārjunīya": ['mw'],
    "nāgārjunīyadharmaśāstra": ['mw'],
    "nāgārāti": ['mw'],
    "nāgārūḍha": ['mw'],
    "nāgāvalokita": ['cped', 'mw'],
    "nāgāñcalā": ['mw'],
    "nāgāñcanā": ['mw'],
    "nāgāñjanā": ['mw'],
    "nāgāśana": ['mw'],
    "nāgāṅga": ['mw'],
    "nāgāṅganā": ['mw'],
    "nāgī": ['cped', 'mw'],
    "nāgībhū": ['ddsa', 'mw'],
    "nāgīja": ['mw'],
    "nāha": ['mw'],
    "nāhala": ['mw'],
    "nāhaḥ": ['ap90'],
    "nāhnābhāi": ['mw'],
    "nāhuṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "nāhuṣaḥ": ['ap90'],
    "nāhuṣi": ['mw'],
    "nājjaka": ['ddsa', 'mw'],
    "nāka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nākacara": ['cae', 'mw'],
    "nākaloka": ['mw'],
    "nākanadī": ['mw'],
    "nākanārī": ['cae', 'mw'],
    "nākanātha": ['mw'],
    "nākanāthaka": ['mw'],
    "nākanāyaka": ['mw'],
    "nākanāyakapurohita": ['mw'],
    "nākapati": ['cae', 'mw'],
    "nākapriṣṭha": ['mw'],
    "nākapriṣṭhya": ['mw'],
    "nākapuraṃdhri": ['mw'],
    "nākapāla": ['cae', 'mw'],
    "nākapṛṣṭha": ['cae'],
    "nākasad": ['cae', 'mw'],
    "nākasattva": ['mw'],
    "nākastrī": ['cae', 'mw'],
    "nākaukas": ['ddsa', 'mw'],
    "nākavanitā": ['mw'],
    "nākeśa": ['mw'],
    "nākeśvara": ['ddsa', 'mw'],
    "nākin": ['ap90', 'cae', 'ddsa', 'mw'],
    "nākinātha": ['mw'],
    "nākināyaka": ['mw'],
    "nākoka": ['mw'],
    "nākra": ['mw'],
    "nāku": ['mw'],
    "nākula": ['ddsa', 'mw'],
    "nākulaka": ['mw'],
    "nākuli": ['mw'],
    "nākulāndhya": ['mw'],
    "nākulī": ['mw'],
    "nākusadman": ['mw'],
    "nākuḥ": ['ap90'],
    "nākādhipa": ['mw'],
    "nākādhipanāyikā": ['mw'],
    "nākāpagā": ['mw'],
    "nākṣatra": ['ap90', 'cae', 'ddsa', 'mw'],
    "nākṣatrika": ['ap90', 'cae', 'mw'],
    "nākṣatrikī": ['mw'],
    "nāla": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "nālada": ['bhs'],
    "nālaka": ['bhs', 'mw'],
    "nālakinī": ['mw'],
    "nālanda": ['bhs', 'mw'],
    "nālandara": ['mw'],
    "nālavaṃśa": ['mw'],
    "nālaveṣṭanaśāntiprayoga": ['mw'],
    "nālayu": ['bhs'],
    "nālaṃbī": ['ap90'],
    "nāli": ['bhs', 'mw'],
    "nālijaṅgha": ['mw'],
    "nālika": ['ddsa', 'mw'],
    "nālikasaṇḍāsa": ['cped'],
    "nālikaḥ": ['ap90'],
    "nālikela": ['ddsa', 'mw'],
    "nālikera": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "nālikā": ['bhs', 'cped', 'mw'],
    "nālikāpuṣpa": ['mw'],
    "nālinī": ['mw'],
    "nālitā": ['mw'],
    "nāliya": ['cped'],
    "nāliyasāka": ['cped'],
    "nāliyā": ['cped'],
    "nāliḥ": ['ap90'],
    "nālya": ['mw'],
    "nālā": ['ap90', 'mw'],
    "nālāgiri": ['mw'],
    "nālāstra": ['mw'],
    "nālāya": ['mw'],
    "nālāyana": ['mw'],
    "nālāyita": ['mw'],
    "nālī": ['bhs', 'cped', 'mw'],
    "nālījaṅgha": ['ddsa', 'mw'],
    "nālīka": ['cae', 'ddsa', 'mw'],
    "nālīkaḥ": ['ap90'],
    "nālīkera": ['bhs'],
    "nālīkinī": ['ap90', 'mw'],
    "nālīpa": ['mw'],
    "nālīpaḥ": ['ap90'],
    "nālīvraṇa": ['mw'],
    "nāma": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "nāmabibhratin": ['mw'],
    "nāmacandrikā": ['mw'],
    "nāmacaraṇabhāṣya": ['mw'],
    "nāmacaraṇavārttika": ['mw'],
    "nāmacaura": ['mw'],
    "nāmacintāmaṇi": ['mw'],
    "nāmadeva": ['mw'],
    "nāmadha": ['cae', 'mw'],
    "nāmadhaḥ": ['ap90'],
    "nāmadheya": ['cae', 'gra', 'mw'],
    "nāmadheyagrahaṇa": ['mw'],
    "nāmadheyakaraṇa": ['mw'],
    "nāmadheyapādakaustubha": ['mw'],
    "nāmadheyatas": ['mw'],
    "nāmadheyya": ['cped'],
    "nāmadhā": ['ap90', 'cae', 'gra', 'mw'],
    "nāmadhāraka": ['cae', 'ddsa', 'mw'],
    "nāmadhārin": ['cae', 'mw'],
    "nāmadhātu": ['mw'],
    "nāmadvādaśī": ['mw'],
    "nāmagotra": ['mw'],
    "nāmagotta": ['cped'],
    "nāmagraha": ['cae', 'mw'],
    "nāmagrahaṇa": ['mw'],
    "nāmagrāha": ['mw'],
    "nāmagrāham": ['mw'],
    "nāmagṛhya": ['mw'],
    "nāmajātigraha": ['mw'],
    "nāmajātigrahaṇa": ['mw'],
    "nāmaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "nāmakamma": ['cped'],
    "nāmakaraṇa": ['cae', 'ddsa', 'mw'],
    "nāmakaraṇaprayoga": ['mw'],
    "nāmakarman": ['cae', 'mw'],
    "nāmakaumudī": ['mw'],
    "nāmakaustubha": ['mw'],
    "nāmakāya": ['cped'],
    "nāmakīrtana": ['cae', 'mw'],
    "nāmakīrtanamāhātmya": ['mw'],
    "nāmaliṅga": ['mw'],
    "nāmaliṅgākhyākomudī": ['mw'],
    "nāmaliṅgānuśāsana": ['mw'],
    "nāmamudrā": ['cae', 'mw'],
    "nāmamāhātmya": ['mw'],
    "nāmamālikā": ['mw'],
    "nāmamālā": ['cae', 'mw'],
    "nāmamālākośa": ['mw'],
    "nāmamālāsaṃgraha": ['mw'],
    "nāmamātra": ['cae', 'ddsa', 'mw'],
    "nāmamātreṇa": ['mw'],
    "nāmamātrikānighaṇṭu": ['mw'],
    "nāmamātrāvaśeṣita": ['mw'],
    "nāman": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "nāmana": ['bhs', 'cae', 'mw'],
    "nāmanau": ['mw'],
    "nāmanidhāna": ['mw'],
    "nāmanighaṇṭu": ['mw'],
    "nāmanirdeśa": ['mw'],
    "nāmaniyatapraveśa": ['bhs', 'mw'],
    "nāmantika": ['bhs'],
    "nāmanāmika": ['mw'],
    "nāmapada": ['mw'],
    "nāmapaṭhanastotra": ['mw'],
    "nāmaprapañca": ['mw'],
    "nāmapārāyaṇa": ['mw'],
    "nāmapūrva": ['mw'],
    "nāmarasodaya": ['mw'],
    "nāmarasāyana": ['mw'],
    "nāmaratnavivaraṇa": ['mw'],
    "nāmaratnākara": ['mw'],
    "nāmaratnāvalī": ['mw'],
    "nāmarūpa": ['cae', 'cped', 'mw'],
    "nāmarūpajātika": ['cped'],
    "nāmarūpātmaka": ['mw'],
    "nāmasaṃgraha": ['mw'],
    "nāmasaṃgrahamālā": ['mw'],
    "nāmasaṃgrahanighaṇṭu": ['mw'],
    "nāmasaṃkīrtana": ['mw'],
    "nāmasiddhānta": ['mw'],
    "nāmasāroddhara": ['mw'],
    "nāmasūtra": ['mw'],
    "nāmatas": ['cae', 'ddsa', 'mw'],
    "nāmataḥ": ['ap90'],
    "nāmathā": ['cae', 'mw'],
    "nāmatideva": ['bhs'],
    "nāmatika": ['bhs', 'mw'],
    "nāmato gaṇhāti": ['cped'],
    "nāmatīrtha": ['mw'],
    "nāmavant": ['cae'],
    "nāmavarjita": ['mw'],
    "nāmavat": ['mw'],
    "nāmavidhi": ['mw'],
    "nāmavismṛti": ['mw'],
    "nāmavivarjita": ['mw'],
    "nāmavyūha": ['mw'],
    "nāmavācaka": ['mw'],
    "nāmayajña": ['mw'],
    "nāmayati": ['bhs', 'cped'],
    "nāmayāthārthyanirṇaya": ['mw'],
    "nāmaśeṣa": ['cae', 'mw'],
    "nāmaśuṇḍī": ['mw'],
    "nāmaṁ gaṇhāti": ['cped'],
    "nāmba": ['cae', 'mw'],
    "nāmetabba": ['cped'],
    "nāmeti": ['cped'],
    "nāmi": ['mw'],
    "nāmika": ['ap90', 'ddsa', 'mw'],
    "nāmin": ['cae', 'ddsa', 'gra', 'mw'],
    "nāmita": ['ap90', 'bhs', 'mw'],
    "nāmiḥ": ['ap90'],
    "nāmnas": ['bhs'],
    "nāmnā": ['mw'],
    "nāmra": ['mw'],
    "nāmya": ['ap90', 'cae', 'ddsa', 'mw'],
    "nāmādeśam": ['mw'],
    "nāmāhutividhi": ['mw'],
    "nāmākhyātika": ['mw'],
    "nāmākṣara": ['cae', 'mw'],
    "nāmānuśāsana": ['mw'],
    "nāmāparādhanirasanastotra": ['mw'],
    "nāmāvali": ['mw'],
    "nāmāvalī": ['mw'],
    "nāmāvaśeṣa": ['bhs'],
    "nāmāṅka": ['cae', 'ddsa', 'mw'],
    "nāmāṅkaśobhita": ['mw'],
    "nāmāṅkita": ['cae'],
    "nāna": ['bhs', 'cped', 'mw'],
    "nānacaya": ['cped'],
    "nānada": ['ddsa', 'mw'],
    "nānadhimuttikatā": ['cped'],
    "nānakacandrodaya": ['mw'],
    "nānappakāra": ['cped'],
    "nānappakāraka": ['cped'],
    "nānardamāna": ['mw'],
    "nānatta": ['cped'],
    "nānattakathā": ['cped'],
    "nānattakāya": ['cped'],
    "nānattasaññi(n)": ['cped'],
    "nānattavaṇṇi(n)": ['cped'],
    "nānattavaṇṇī": ['cped'],
    "nānauṣadha": ['mw'],
    "nānauṣadhapariccheda": ['mw'],
    "nānauṣadhavidhi": ['mw'],
    "nānaṁ": ['cped'],
    "nānda": ['mw'],
    "nāndana": ['cae', 'gra', 'mw'],
    "nāndi": ['mw'],
    "nāndidatta": ['mw'],
    "nāndika": ['mw'],
    "nāndikara": ['mw'],
    "nāndin": ['mw'],
    "nānduka": ['ddsa', 'mw'],
    "nāndī": ['cae', 'ddsa', 'gra', 'mw'],
    "nāndībhājana": ['mw'],
    "nāndīghoṣa": ['mw'],
    "nāndīka": ['mw'],
    "nāndīkara": ['mw'],
    "nāndīmukha": ['cae', 'mw'],
    "nāndīmukhaśrāddhanirūpaṇa": ['mw'],
    "nāndīmukhaśrāddhapaddhati": ['mw'],
    "nāndīmukhaśrāddhaprayoga": ['mw'],
    "nāndīmukhī": ['mw'],
    "nāndīnināda": ['mw'],
    "nāndīnāda": ['ddsa', 'mw'],
    "nāndīpaṭa": ['mw'],
    "nāndīpura": ['mw'],
    "nāndīpuraka": ['mw'],
    "nāndīrava": ['mw'],
    "nāndīviśāla": ['mw'],
    "nāndīśrāddha": ['mw'],
    "nānolba": ['mw'],
    "nāntarīyaka": ['mw'],
    "nāntarīyakatva": ['mw'],
    "nāntra": ['mw'],
    "nānurakta": ['mw'],
    "nānyacetas": ['cae'],
    "nānyadeva": ['mw'],
    "nānyagāmin": ['cae'],
    "nānyatra": ['mw'],
    "nānā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nānā atthi": ['cped'],
    "nānā bhavati": ['cped'],
    "nānābhava": ['cped'],
    "nānābhaṭṭa": ['mw'],
    "nānābhāva": ['bhs', 'cped', 'mw'],
    "nānābhūta": ['mw'],
    "nānābrahmasāmatva": ['mw'],
    "nānābuddhiruc": ['mw'],
    "nānābīja": ['mw'],
    "nānācaya": ['cped'],
    "nānācetas": ['mw'],
    "nānādevata": ['mw'],
    "nānādevatya": ['mw'],
    "nānādeśa": ['cae', 'mw'],
    "nānādeśya": ['mw'],
    "nānādeśīya": ['mw'],
    "nānādharman": ['mw'],
    "nānādhiṣṇya": ['mw'],
    "nānādhvani": ['mw'],
    "nānādhātu": ['mw'],
    "nānādhātuprakriyā": ['mw'],
    "nānādhātusamākīrṇa": ['mw'],
    "nānādhātuśata": ['mw'],
    "nānādhī": ['cae', 'gra', 'mw'],
    "nānādigdeśa": ['cae', 'mw'],
    "nānādigdeśāt": ['mw'],
    "nānādiṭṭhika": ['cped'],
    "nānādāna": ['mw'],
    "nānādīkṣita": ['mw'],
    "nānāgati": ['mw'],
    "nānāgotra": ['mw'],
    "nānāgraha": ['mw'],
    "nānājacca": ['cped'],
    "nānājana": ['mw'],
    "nānājātīya": ['mw'],
    "nānākanda": ['mw'],
    "nānākaraṇa": ['bhs', 'cped', 'mw'],
    "nānākarman": ['mw'],
    "nānākhantika": ['cped'],
    "nānākāma": ['mw'],
    "nānākāra": ['cae', 'mw'],
    "nānākāram": ['mw'],
    "nānākṛtvā": ['mw'],
    "nānākṛtya": ['mw'],
    "nānākṣetramāhātmya": ['mw'],
    "nānāliṅga": ['mw'],
    "nānāliṅgatva": ['mw'],
    "nānāmanas": ['mw'],
    "nānāmantraughasiddhimat": ['mw'],
    "nānāmṛgagaṇa": ['mw'],
    "nānāna": ['gra'],
    "nānānam": ['cae', 'mw'],
    "nānānarghamahāratnamaya": ['mw'],
    "nānānaṃ": ['ap90'],
    "nānāndra": ['mw'],
    "nānāndrāyaṇa": ['mw'],
    "nānānāmanirūpaṇa": ['mw'],
    "nānāpada": ['mw'],
    "nānāpadavat": ['mw'],
    "nānāpadīya": ['mw'],
    "nānāpakṣigaṇākīrṇa": ['mw'],
    "nānāpattrakā": ['mw'],
    "nānāphalamaya": ['mw'],
    "nānāprabhṛti": ['mw'],
    "nānāprakāra": ['mw'],
    "nānāprastāva": ['mw'],
    "nānāpāṭhaka": ['mw'],
    "nānārajja": ['cped'],
    "nānārasa": ['cae', 'mw'],
    "nānāratham": ['gra', 'mw'],
    "nānāratnavyūha": ['bhs'],
    "nānāratnākaravat": ['mw'],
    "nānārtha": ['cae', 'mw'],
    "nānārthadhvanimañjarī": ['mw'],
    "nānārthakośa": ['mw'],
    "nānārthamañjarī": ['mw'],
    "nānārtharatnamālā": ['mw'],
    "nānārtharatnatilaka": ['mw'],
    "nānārthasaṃdigdhārthavicāra": ['mw'],
    "nānārthasaṃgraha": ['mw'],
    "nānārthaśabdakośa": ['mw'],
    "nānārthaśabdaratna": ['mw'],
    "nānārthaśabdānuśāsana": ['mw'],
    "nānārucika": ['cped'],
    "nānārūpa": ['cae', 'mw'],
    "nānārūpasamutthāna": ['mw'],
    "nānārūpatā": ['mw'],
    "nānāsamutthāna": ['mw'],
    "nānāsaṁvāsaka": ['cped'],
    "nānāsaṃvāsika": ['bhs', 'mw'],
    "nānāstrī": ['cae', 'mw'],
    "nānāsāmavat": ['mw'],
    "nānāsūrya": ['gra', 'mw'],
    "nānāsūryatva": ['mw'],
    "nānātantra": ['mw'],
    "nānātanu": ['mw'],
    "nānātma": ['mw'],
    "nānātmapakṣa": ['mw'],
    "nānātmavādin": ['mw'],
    "nānātva": ['cae', 'mw'],
    "nānātvavādatattva": ['mw'],
    "nānātyaya": ['mw'],
    "nānāvarṇa": ['mw'],
    "nānāvarṇatva": ['mw'],
    "nānāvarṇākṛti": ['mw'],
    "nānāvastha": ['mw'],
    "nānāverajjagata": ['cped'],
    "nānāverajjaka": ['cped'],
    "nānāveṣākṛtimat": ['mw'],
    "nānāvidha": ['cae', 'mw'],
    "nānāvidhaśānti": ['mw'],
    "nānāvihita": ['cped'],
    "nānāvinā": ['mw'],
    "nānāviśya": ['mw'],
    "nānāvrata": ['mw'],
    "nānāvādasaṃgrahagrantha": ['mw'],
    "nānāvāsa": ['bhs'],
    "nānāvīrya": ['mw'],
    "nānāvīryatā": ['mw'],
    "nānāvṛkṣīya": ['mw'],
    "nānāvṛttamaya": ['mw'],
    "nānāyoga": ['mw'],
    "nānāyudhalakṣaṇa": ['mw'],
    "nānāśraya": ['mw'],
    "nānāśāstra": ['mw'],
    "nānāśāstrārthanirṇaya": ['mw'],
    "nānāśāstrīya": ['mw'],
    "nānāṃdraḥ": ['ap90'],
    "nānū": ['mw'],
    "nāpi": ['mw'],
    "nāpinī": ['bhs'],
    "nāpita": ['cae', 'ddsa', 'mw'],
    "nāpitabhāṇḍa": ['mw'],
    "nāpitagṛha": ['cae', 'mw'],
    "nāpitakarman": ['mw'],
    "nāpitavāstu": ['mw'],
    "nāpitavāstuka": ['mw'],
    "nāpitaśālikā": ['mw'],
    "nāpitaśālā": ['mw'],
    "nāpitaḥ": ['ap90'],
    "nāpitya": ['mw'],
    "nāpityaṃ": ['ap90'],
    "nāpitāyani": ['mw'],
    "nāpitāyaniḥ": ['ap90'],
    "nāpitī": ['mw'],
    "nār": ['mw'],
    "nāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "nāracandra": ['mw'],
    "nāracandrapaddhati": ['mw'],
    "nārada": ['bhs', 'cae', 'ddsa', 'mw'],
    "nāradabindūpaniṣad": ['mw'],
    "nāradagītā": ['mw'],
    "nāradaparivrājakopaniṣad": ['mw'],
    "nāradapañcarātra": ['mw'],
    "nāradapurāṇa": ['mw'],
    "nāradasaṃhitā": ['mw'],
    "nāradasmṛti": ['mw'],
    "nāradastotra": ['mw'],
    "nāradatantra": ['mw'],
    "nāradavacana": ['mw'],
    "nāradavilāsakavya": ['mw'],
    "nāradaśataka": ['mw'],
    "nāradaśikṣā": ['mw'],
    "nāradaḥ": ['ap90'],
    "nāradeśvaratīrtha": ['mw'],
    "nāradin": ['mw'],
    "nāradopadeśa": ['mw'],
    "nāradopaniṣad": ['mw'],
    "nāradopaniṣaddīpikā": ['mw'],
    "nāradopapurāṇa": ['mw'],
    "nāradvāsava": ['mw'],
    "nāradā": ['mw'],
    "nāradīya": ['cae', 'ddsa', 'mw'],
    "nāradīyakrama": ['mw'],
    "nāradīyamahāsthāna": ['mw'],
    "nāradīyapurāṇa": ['mw'],
    "nāradīyasaptasahasra": ['mw'],
    "nāradīyopapurāṇa": ['mw'],
    "nārahaya": ['mw'],
    "nārajīvana": ['mw'],
    "nāraka": ['ap90', 'cae', 'ddsa', 'mw'],
    "nārakapāla": ['mw'],
    "nārakapālakuṇḍalavat": ['mw'],
    "nārakeya": ['bhs'],
    "nārakika": ['ap90', 'mw'],
    "nārakikin": ['mw'],
    "nārakikīya": ['mw'],
    "nārakin": ['ddsa'],
    "nārakīya": ['bhs'],
    "nārakīṭa": ['mw'],
    "nārasiṃha": ['ap90', 'mw'],
    "nārasiṃhacūrṇa": ['mw'],
    "nārasiṃhapurāṇa": ['mw'],
    "nārasiṃhatantra": ['mw'],
    "nārasiṃhaṣaṭcakryupaniṣad": ['mw'],
    "nārasiṃhopaniṣad": ['mw'],
    "nārasiṃhopapurāṇa": ['mw'],
    "nārasiṃhīya": ['mw'],
    "nāraṃgaḥ": ['ap90'],
    "nāraṅga": ['cae', 'ddsa', 'mw'],
    "nāraṅgapattraka": ['mw'],
    "nāreya": ['mw'],
    "nāri": ['cae', 'ddsa', 'gra', 'mw'],
    "nāria": ['gra'],
    "nārika": ['ap90', 'mw'],
    "nārikela": ['cae', 'ddsa', 'mw'],
    "nārikeladvīpa": ['mw'],
    "nārikelakṣāra": ['mw'],
    "nārikera": ['cae', 'ddsa', 'mw'],
    "nārikeraḥ": ['ap90'],
    "nāriṅga": ['mw'],
    "nāriṅgakanda": ['mw'],
    "nāriṅgī": ['mw'],
    "nāriṣṭa": ['mw'],
    "nāriṣṭahoma": ['mw'],
    "nāriṣṭha": ['mw'],
    "nāriṣṭhahoma": ['mw'],
    "nārkalpi": ['mw'],
    "nārkuṭa": ['mw'],
    "nārmada": ['ddsa', 'mw'],
    "nārmara": ['gra', 'mw'],
    "nārmata": ['mw'],
    "nārmedha": ['mw'],
    "nārmin": ['gra'],
    "nārmiṇī": ['mw'],
    "nārnamana": ['mw'],
    "nārojipaṇḍita": ['mw'],
    "nāropāyana": ['mw'],
    "nārpatya": ['ap90', 'mw'],
    "nārtika": ['mw'],
    "nāruṃtuda": ['mw'],
    "nārya": ['cae', 'gra', 'mw'],
    "nāryadhanahīna": ['bhs'],
    "nāryatikta": ['mw'],
    "nāryaṃgaḥ": ['ap90'],
    "nāryaṅga": ['mw'],
    "nārāca": ['cae', 'cped', 'ddsa', 'mw'],
    "nārācacūrṇa": ['mw'],
    "nārācadurdina": ['mw'],
    "nārācaghṛta": ['mw'],
    "nārācaka": ['mw'],
    "nārācarasa": ['mw'],
    "nārācaḥ": ['ap90'],
    "nārācikā": ['ap90', 'mw'],
    "nārācī": ['mw'],
    "nārāyaṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "nārāyaṇabali": ['mw'],
    "nārāyaṇabaliprayoga": ['mw'],
    "nārāyaṇabalisamarthana": ['mw'],
    "nārāyaṇabalisvayamprayojanasañcikā": ['mw'],
    "nārāyaṇabalividhi": ['mw'],
    "nārāyaṇabhaṭṭī": ['mw'],
    "nārāyaṇabhaṭṭīya": ['mw'],
    "nārāyaṇacakravartikośa": ['mw'],
    "nārāyaṇacakravartin": ['mw'],
    "nārāyaṇacaritramālā": ['mw'],
    "nārāyaṇacurṇa": ['mw'],
    "nārāyaṇadatta": ['mw'],
    "nārāyaṇadeva": ['mw'],
    "nārāyaṇadharmasārasaṃgraha": ['mw'],
    "nārāyaṇadāsa": ['mw'],
    "nārāyaṇadīkṣita": ['mw'],
    "nārāyaṇadīkṣitasūnu": ['mw'],
    "nārāyaṇagupta": ['mw'],
    "nārāyaṇagītā": ['mw'],
    "nārāyaṇahṛdaya": ['mw'],
    "nārāyaṇakalpa": ['mw'],
    "nārāyaṇakavaca": ['mw'],
    "nārāyaṇakaṇṭha": ['mw'],
    "nārāyaṇalabdhi": ['mw'],
    "nārāyaṇamantrārtha": ['mw'],
    "nārāyaṇamaya": ['mw'],
    "nārāyaṇamiśra": ['mw'],
    "nārāyaṇamiśrīya": ['mw'],
    "nārāyaṇanāmavivaraṇa": ['mw'],
    "nārāyaṇapaddhati": ['mw'],
    "nārāyaṇaparipṛcchā": ['bhs'],
    "nārāyaṇaprabodhotsava": ['mw'],
    "nārāyaṇapriya": ['mw'],
    "nārāyaṇarāja": ['mw'],
    "nārāyaṇasaras": ['mw'],
    "nārāyaṇasarovaramāhātmya": ['mw'],
    "nārāyaṇasaṃhitā": ['mw'],
    "nārāyaṇasmṛti": ['mw'],
    "nārāyaṇastavarāja": ['mw'],
    "nārāyaṇastotra": ['mw'],
    "nārāyaṇasvāmin": ['mw'],
    "nārāyaṇasārasaṃgraha": ['mw'],
    "nārāyaṇasūri": ['mw'],
    "nārāyaṇasūtra": ['mw'],
    "nārāyaṇataila": ['mw'],
    "nārāyaṇatattvavāda": ['mw'],
    "nārāyaṇatāra": ['mw'],
    "nārāyaṇatīrtha": ['mw'],
    "nārāyaṇatīrthataraṃga": ['mw'],
    "nārāyaṇavarman": ['mw'],
    "nārāyaṇavarṇana": ['mw'],
    "nārāyaṇavilāsa": ['mw'],
    "nārāyaṇavratasumeruśrī": ['bhs'],
    "nārāyaṇavārttika": ['mw'],
    "nārāyaṇavīrya": ['bhs'],
    "nārāyaṇavṛtti": ['mw'],
    "nārāyaṇaśabdavādārtha": ['mw'],
    "nārāyaṇaśabdārtha": ['mw'],
    "nārāyaṇaśeṣa": ['mw'],
    "nārāyaṇaśruti": ['mw'],
    "nārāyaṇaśrīgarbha": ['bhs', 'mw'],
    "nārāyaṇaḥ": ['ap90'],
    "nārāyaṇendra": ['mw'],
    "nārāyaṇi": ['mw'],
    "nārāyaṇopaniṣad": ['mw'],
    "nārāyaṇopaniṣadarthaprakāśa": ['mw'],
    "nārāyaṇopaniṣaddīpikā": ['mw'],
    "nārāyaṇopaniṣatsāra": ['mw'],
    "nārāyaṇopaniṣaṭṭīkā": ['mw'],
    "nārāyaṇātharvaṇaśīrṣopaniṣad": ['mw'],
    "nārāyaṇāvalī": ['mw'],
    "nārāyaṇāya": ['ddsa', 'mw'],
    "nārāyaṇāśrama": ['mw'],
    "nārāyaṇāśramīya": ['mw'],
    "nārāyaṇāṣṭottaraśatastotra": ['mw'],
    "nārāyaṇī": ['mw'],
    "nārāyaṇīpraśnāvalī": ['mw'],
    "nārāyaṇīvilāsa": ['mw'],
    "nārāyaṇīya": ['mw'],
    "nārāyaṇīyabīja": ['mw'],
    "nārāyaṇīyatantra": ['mw'],
    "nārāyaṇīyavyākhyā": ['mw'],
    "nārāyaṇīyopaniṣad": ['mw'],
    "nārāśarya": ['mw'],
    "nārāśaṃsa": ['cae', 'ddsa', 'gra', 'mw'],
    "nārāśaṃsapaṅkti": ['mw'],
    "nārāśaṃsī": ['mw'],
    "nārāśībhāvaḥ": ['bhs'],
    "nārī": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nārīca": ['mw'],
    "nārīdūṣaṇa": ['mw'],
    "nārīka": ['mw'],
    "nārīkavaca": ['mw'],
    "nārīkela": ['bhs', 'mw'],
    "nārīkelī": ['mw'],
    "nārīkuñjara": ['mw'],
    "nārīmaya": ['mw'],
    "nārīmukha": ['mw'],
    "nārīnātha": ['mw'],
    "nārīparāyaṇa": ['mw'],
    "nārīpattana": ['mw'],
    "nārīprasaṅga": ['mw'],
    "nārīpura": ['mw'],
    "nārīratna": ['mw'],
    "nārīsahanāmasavhaya": ['cped'],
    "nārītaraṃgaka": ['mw'],
    "nārītīrtha": ['mw'],
    "nārīvākya": ['mw'],
    "nārīya": ['mw'],
    "nārīyāna": ['mw'],
    "nārīṣṭha": ['cae', 'mw'],
    "nārīṣṭā": ['mw'],
    "nārṣada": ['gra', 'mw'],
    "nās": ['ap90', 'ddsa', 'mw'],
    "nāsacchidda": ['cped'],
    "nāsacchinna": ['cped'],
    "nāsadāsīya": ['ddsa'],
    "nāsanāntika": ['cped'],
    "nāsatya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nāsatyā": ['mw'],
    "nāsayati": ['cped'],
    "nāsayi": ['cped'],
    "nāsayitvāna": ['cped'],
    "nāsesi": ['cped'],
    "nāsesuṁ": ['cped'],
    "nāsetabba": ['cped'],
    "nāseti": ['cped'],
    "nāsetva": ['cped'],
    "nāsika": ['mw'],
    "nāsikakṣetramahātmya": ['mw'],
    "nāsikasota": ['cped'],
    "nāsikatryambaka": ['mw'],
    "nāsikatryambakatīrtha": ['mw'],
    "nāsikavat": ['mw'],
    "nāsikaṃdhama": ['ap90', 'mw'],
    "nāsikaṃdhaya": ['ap90', 'mw'],
    "nāsikya": ['ap90', 'cae', 'ddsa', 'mw'],
    "nāsikyakaṃ": ['ap90'],
    "nāsikā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nāsikāchidra": ['mw'],
    "nāsikāchinnī": ['mw'],
    "nāsikāgra": ['cae', 'mw'],
    "nāsikāgratas": ['mw'],
    "nāsikāloma": ['cped'],
    "nāsikāmala": ['mw'],
    "nāsikāmūla": ['cae', 'mw'],
    "nāsikāpuṭa": ['cae', 'mw'],
    "nāsikāpāka": ['mw'],
    "nāsikārajju": ['cae', 'mw'],
    "nāsikāropaṇa": ['mw'],
    "nāsikāsota": ['cped'],
    "nāsikāsrotas": ['mw'],
    "nāsira": ['ddsa', 'mw'],
    "nāsita": ['cped'],
    "nāsitabba": ['cped'],
    "nāsitaka": ['cped'],
    "nāsiyamāna": ['cped'],
    "nāsti": ['ap90', 'mw'],
    "nāstibhāva": ['bhs'],
    "nāstida": ['mw'],
    "nāstidaḥ": ['ap90'],
    "nāstika": ['ap90', 'cae', 'mw'],
    "nāstikamata": ['mw'],
    "nāstikatva": ['mw'],
    "nāstikatā": ['cae', 'mw'],
    "nāstikavṛtti": ['cae', 'mw'],
    "nāstikya": ['ddsa', 'mw'],
    "nāstikyaṃ": ['ap90'],
    "nāstimūrti": ['ddsa', 'mw'],
    "nāstitada": ['mw'],
    "nāstitva": ['mw'],
    "nāstitā": ['cae', 'mw'],
    "nāstivāda": ['mw'],
    "nāsya": ['cae', 'ddsa', 'mw'],
    "nāsyagrāsam": ['mw'],
    "nāsyaṃ": ['ap90'],
    "nāsā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nāsābhaṅga": ['mw'],
    "nāsāchidra": ['mw'],
    "nāsāchinnī": ['mw'],
    "nāsādakṣṇāvarta": ['mw'],
    "nāsādāru": ['mw'],
    "nāsāgra": ['cae', 'ddsa', 'mw'],
    "nāsājvara": ['mw'],
    "nāsālu": ['mw'],
    "nāsāmūla": ['cae', 'mw'],
    "nāsāntika": ['cae', 'mw'],
    "nāsānāha": ['mw'],
    "nāsāparisrāva": ['mw'],
    "nāsāpariśoṣa": ['mw'],
    "nāsāpeti": ['cped'],
    "nāsāpramāṇa": ['mw'],
    "nāsāpratīnāha": ['mw'],
    "nāsāpuṭa": ['cae', 'ddsa', 'mw'],
    "nāsāpuṭamaryādā": ['mw'],
    "nāsāpāka": ['mw'],
    "nāsāraktapitta": ['mw'],
    "nāsārandhra": ['mw'],
    "nāsārbuda": ['mw'],
    "nāsāroga": ['mw'],
    "nāsārśas": ['mw'],
    "nāsāsaṃvedana": ['mw'],
    "nāsāsrāva": ['mw'],
    "nāsāvabhaṅga": ['mw'],
    "nāsāvaṃśa": ['mw'],
    "nāsāvedha": ['mw'],
    "nāsāviroka": ['mw'],
    "nāsāvivara": ['mw'],
    "nāsāvāmāvarta": ['mw'],
    "nāsāyoni": ['mw'],
    "nāsāśoṣa": ['mw'],
    "nāsīra": ['mw'],
    "nāsīraṃ": ['ap90'],
    "nātaputta": ['cped'],
    "nātaputtiya": ['cped'],
    "nātaṅkovilsthalamāhātmya": ['mw'],
    "nāth": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nātha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nāthahari": ['mw'],
    "nāthahāra": ['mw'],
    "nāthakaraṇa": ['cped'],
    "nāthakumāra": ['mw'],
    "nāthakāma": ['mw'],
    "nāthamalla": ['mw'],
    "nāthamallabrahmacārin": ['mw'],
    "nāthamāna": ['mw'],
    "nāthasiṃha": ['mw'],
    "nāthastuti": ['mw'],
    "nāthatva": ['mw'],
    "nāthavant": ['cae'],
    "nāthavat": ['ap90', 'mw'],
    "nāthavattā": ['cae', 'mw'],
    "nāthavatī": ['mw'],
    "nāthavid": ['mw'],
    "nāthavindu": ['mw'],
    "nāthaḥ": ['ap90'],
    "nāthin": ['cae', 'mw'],
    "nāthita": ['cae', 'mw'],
    "nāthoka": ['mw'],
    "nāthānandamuni": ['mw'],
    "nāthāya": ['mw'],
    "nāti": ['mw'],
    "nātibhinna": ['cae', 'mw'],
    "nātibhogin": ['mw'],
    "nātibhārika": ['mw'],
    "nāticchina": ['mw'],
    "nāticira": ['ap90', 'cae', 'mw'],
    "nāticire": ['mw'],
    "nātidhanin": ['mw'],
    "nātidoṣala": ['mw'],
    "nātidrava": ['mw'],
    "nātidrutam": ['mw'],
    "nātidīrgha": ['cae', 'mw'],
    "nātidīrgham": ['mw'],
    "nātidūra": ['ap90', 'cae', 'ddsa', 'mw'],
    "nātidūraga": ['cae', 'mw'],
    "nātidūranirīkṣin": ['mw'],
    "nātidūrasthita": ['cae', 'mw'],
    "nātidūravartin": ['cae', 'mw'],
    "nātigādha": ['mw'],
    "nātihṛṣṭa": ['mw'],
    "nātijalpaka": ['mw'],
    "nātikalyāṇa": ['ddsa', 'mw'],
    "nātikovida": ['mw'],
    "nātikrūramṛdu": ['mw'],
    "nātikṛcchra": ['mw'],
    "nātikṛcchrāt": ['mw'],
    "nātilaghuvipula": ['mw'],
    "nātilalita": ['mw'],
    "nātilampaṭa": ['mw'],
    "nātilomaśa": ['mw'],
    "nātimahat": ['mw'],
    "nātimudāvat": ['mw'],
    "nātimānin": ['cae', 'mw'],
    "nātimānitā": ['mw'],
    "nātimātram": ['cae', 'mw'],
    "nātinirbhagna": ['mw'],
    "nātinirvṛti": ['ddsa'],
    "nātinirvṛtti": ['mw'],
    "nātinīca": ['cae', 'mw'],
    "nātiparikara": ['mw'],
    "nātiparisphuṭa": ['cae', 'mw'],
    "nātiparyāpta": ['mw'],
    "nātipracurapadyavat": ['mw'],
    "nātiprakupita": ['mw'],
    "nātipramanas": ['cae', 'mw'],
    "nātiprasiddha": ['mw'],
    "nātiprasīdat": ['mw'],
    "nātiprīta": ['mw'],
    "nātipuṣṭa": ['mw'],
    "nātipṛthu": ['mw'],
    "nātiramaṇīya": ['mw'],
    "nātiramaṇīyatā": ['mw'],
    "nātirohiṇī": ['mw'],
    "nātirūpa": ['cae', 'mw'],
    "nātirūḍha": ['mw'],
    "nātisamañjasa": ['mw'],
    "nātisvalpa": ['mw'],
    "nātisvastha": ['cae', 'mw'],
    "nātisāndra": ['mw'],
    "nātitīvra": ['mw'],
    "nātitṛpti": ['mw'],
    "nātivatsala": ['mw'],
    "nātivilambin": ['mw'],
    "nātivilambita": ['mw'],
    "nātivilambitam": ['mw'],
    "nātivilambitā": ['mw'],
    "nātivistārasaṃkaṭa": ['mw'],
    "nātiviśadam": ['mw'],
    "nātivyakta": ['mw'],
    "nātivyasta": ['mw'],
    "nātivāda": ['mw'],
    "nātivādaḥ": ['ap90'],
    "nātivātala": ['mw'],
    "nātivṛddha": ['mw'],
    "nātivṛtta": ['mw'],
    "nātiśliṣṭa": ['cae', 'mw'],
    "nātiśobhita": ['mw'],
    "nātiśrānta": ['mw'],
    "nātiśītoṣṇa": ['mw'],
    "nātra": ['mw'],
    "nātraḥ": ['ap90'],
    "nāty": ['mw'],
    "nātyantadūra": ['ddsa', 'mw'],
    "nātyapacita": ['mw'],
    "nātyucca": ['mw'],
    "nātyucchrita": ['cae', 'mw'],
    "nātyupapanna": ['mw'],
    "nātyupasaṃhṛta": ['mw'],
    "nātyādṛta": ['ddsa', 'mw'],
    "nātyākīrṇa": ['mw'],
    "nātyāyatavacanatā": ['mw'],
    "nātānatika": ['mw'],
    "nāv": ['mw'],
    "nāva": ['cae', 'ddsa', 'gra', 'mw'],
    "nāvamika": ['ap90', 'mw'],
    "nāvana": ['mw'],
    "nāvanīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "nāvanīya": ['mw'],
    "nāvaprabhraṃśana": ['mw'],
    "nāvara": ['mw'],
    "nāvayajñika": ['mw'],
    "nāvika": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "nāvikanāyaka": ['mw'],
    "nāvikapati": ['mw'],
    "nāvikaḥ": ['ap90'],
    "nāvikī": ['cped'],
    "nāvin": ['ap90', 'mw'],
    "nāviā": ['gra'],
    "nāvopajīvana": ['cae', 'mw'],
    "nāvopajīvin": ['cae', 'mw'],
    "nāvutika": ['cped'],
    "nāvy": ['mw'],
    "nāvya": ['ap90', 'cae', 'ddsa', 'mw'],
    "nāvyudaka": ['mw'],
    "nāvyā": ['gra', 'mw'],
    "nāvā": ['cped', 'gra', 'mw'],
    "nāvāja": ['cae', 'mw'],
    "nāvākāra": ['mw'],
    "nāvāroha": ['mw'],
    "nāya": ['cae', 'ddsa', 'gra', 'mw'],
    "nāyaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "nāyakaratna": ['mw'],
    "nāyakatva": ['mw'],
    "nāyakādhipa": ['mw'],
    "nāyakāya": ['ddsa', 'mw'],
    "nāyana": ['mw'],
    "nāyati": ['cped'],
    "nāyaḥ": ['ap90'],
    "nāyikā": ['ap90', 'cped', 'ddsa', 'mw'],
    "nāyikācūrṇa": ['mw'],
    "nāyikāsādhana": ['mw'],
    "nāyin": ['bhs', 'mw'],
    "nāśa": ['cae', 'ddsa', 'mw'],
    "nāśaka": ['ap90', 'cae', 'mw'],
    "nāśana": ['ap90', 'cae', 'mw'],
    "nāśanakara": ['mw'],
    "nāśanīya": ['mw'],
    "nāśatas": ['mw'],
    "nāśayitṛ": ['mw'],
    "nāśaśata": ['mw'],
    "nāśaḥ": ['ap90'],
    "nāśin": ['ap90', 'cae', 'mw'],
    "nāśira": ['mw'],
    "nāśita": ['ap90', 'mw'],
    "nāśitasaṃgraha": ['bhs', 'mw'],
    "nāśuka": ['cae', 'mw'],
    "nāśya": ['ap90', 'cae', 'mw'],
    "nāśyatva": ['mw'],
    "nāśī": ['mw'],
    "nāḍa": ['ap90', 'bhs', 'mw'],
    "nāḍakantheya": ['bhs'],
    "nāḍakanthā": ['bhs'],
    "nāḍapit": ['mw'],
    "nāḍapitī": ['mw'],
    "nāḍi": ['cae', 'ddsa', 'mw'],
    "nāḍicīra": ['mw'],
    "nāḍika": ['cae', 'mw'],
    "nāḍikela": ['mw'],
    "nāḍikelaḥ": ['ap90'],
    "nāḍikā": ['ap90', 'bhs', 'mw'],
    "nāḍikādatta": ['mw'],
    "nāḍikāvṛtta": ['mw'],
    "nāḍimaṇḍala": ['mw'],
    "nāḍindhama": ['ddsa'],
    "nāḍipattra": ['mw'],
    "nāḍiḥ": ['ap90'],
    "nāḍiṃdhama": ['ap90', 'mw'],
    "nāḍiṃdhaya": ['ap90', 'mw'],
    "nāḍvaleya": ['mw'],
    "nāḍyā": ['bhs'],
    "nāḍā": ['mw'],
    "nāḍāyana": ['mw'],
    "nāḍāyanaka": ['mw'],
    "nāḍī": ['cae', 'ddsa', 'gra', 'mw'],
    "nāḍīca": ['mw'],
    "nāḍīcakra": ['mw'],
    "nāḍīcaraṇa": ['mw'],
    "nāḍīdatta": ['mw'],
    "nāḍīdeha": ['mw'],
    "nāḍīgrantha": ['mw'],
    "nāḍīhiṅgu": ['mw'],
    "nāḍījaṅgha": ['mw'],
    "nāḍījñāna": ['mw'],
    "nāḍījñānadīpikā": ['mw'],
    "nāḍīka": ['mw'],
    "nāḍīkalāpaka": ['mw'],
    "nāḍīkela": ['mw'],
    "nāḍīkerī": ['bhs'],
    "nāḍīkā": ['ap90', 'cae', 'mw'],
    "nāḍīnakṣatra": ['mw'],
    "nāḍīnakṣatramālā": ['mw'],
    "nāḍīnidāna": ['mw'],
    "nāḍīparīkṣā": ['mw'],
    "nāḍīparīkṣādicikitsākathana": ['mw'],
    "nāḍīprakaraṇa": ['mw'],
    "nāḍīprakāśa": ['mw'],
    "nāḍīpātra": ['mw'],
    "nāḍīsamuccaya": ['mw'],
    "nāḍīsaṃcāra": ['mw'],
    "nāḍīsaṃjñāna": ['mw'],
    "nāḍīsaṃkhyā": ['mw'],
    "nāḍīsneha": ['mw'],
    "nāḍīsveda": ['mw'],
    "nāḍītaraṃga": ['mw'],
    "nāḍītikta": ['mw'],
    "nāḍīvalaya": ['mw'],
    "nāḍīvigraha": ['mw'],
    "nāḍīvijñāna": ['mw'],
    "nāḍīvijñānīya": ['mw'],
    "nāḍīvraṇa": ['mw'],
    "nāḍīvṛtta": ['mw'],
    "nāḍīyantra": ['mw'],
    "nāḍīśuddhi": ['mw'],
    "nāḍīśāka": ['mw'],
    "nāḍīśāstra": ['mw'],
    "nāḍīṃdhama": ['ap90', 'mw'],
    "nāḷa": ['cped'],
    "nāḷi": ['cped'],
    "nāḷikodana": ['cped'],
    "nāḷikā": ['cped'],
    "nāḷikāgabbha": ['cped'],
    "nāḷikāsaka": ['cped'],
    "nāḷiyasāka": ['cped'],
    "nāḷī": ['cped'],
    "nāṃdikaraḥ": ['ap90'],
    "nāṃdī": ['ap90'],
    "nāṃdīkaḥ": ['ap90'],
    "nāṃta": ['ap90'],
    "nāṃtarīyaka": ['ap90'],
    "nāṃtraṃ": ['ap90'],
    "nāṇaka": ['cae', 'ddsa', 'mw'],
    "nāṇakaparīkṣin": ['mw'],
    "nāṇakaparīkṣā": ['mw'],
    "nāṇakaṃ": ['ap90'],
    "nāṣṭika": ['cae', 'ddsa', 'mw'],
    "nāṣṭikaḥ": ['ap90'],
    "nāṣṭrā": ['ap90', 'cae', 'ddsa', 'mw'],
    "nāṭa": ['cae', 'ddsa', 'mw'],
    "nāṭabhaṭikavihāra": ['mw'],
    "nāṭaka": ['cae', 'ddsa', 'mw'],
    "nāṭakacandrikā": ['mw'],
    "nāṭakadīpa": ['mw'],
    "nāṭakalakṣaṇa": ['mw'],
    "nāṭakaparibhāṣā": ['mw'],
    "nāṭakaprakāśa": ['mw'],
    "nāṭakaprapañca": ['mw'],
    "nāṭakaratnakośa": ['mw'],
    "nāṭakavidhi": ['mw'],
    "nāṭakaṃ": ['ap90'],
    "nāṭakeya": ['mw'],
    "nāṭakākhyāyikadarśana": ['mw'],
    "nāṭakāvatāra": ['mw'],
    "nāṭakī": ['mw'],
    "nāṭakīkṛ": ['mw'],
    "nāṭakīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "nāṭakīyā": ['mw'],
    "nāṭaputta": ['cped'],
    "nāṭaputtiya": ['cped'],
    "nāṭasūtra": ['mw'],
    "nāṭayitavya": ['cae', 'ddsa', 'mw'],
    "nāṭaḥ": ['ap90'],
    "nāṭera": ['mw'],
    "nāṭeya": ['mw'],
    "nāṭeyaḥ": ['ap90'],
    "nāṭikā": ['ap90', 'ddsa', 'mw'],
    "nāṭin": ['mw'],
    "nāṭita": ['cae', 'ddsa', 'mw'],
    "nāṭitaka": ['cae'],
    "nāṭitakaṃ": ['ap90'],
    "nāṭya": ['cae', 'ddsa', 'mw'],
    "nāṭyadarpaṇa": ['mw'],
    "nāṭyadhara": ['mw'],
    "nāṭyadharmikā": ['mw'],
    "nāṭyadharmī": ['mw'],
    "nāṭyalakṣaṇa": ['mw'],
    "nāṭyalocana": ['mw'],
    "nāṭyalocanakāra": ['mw'],
    "nāṭyapradīpa": ['mw'],
    "nāṭyapriya": ['mw'],
    "nāṭyarāsaka": ['mw'],
    "nāṭyavarga": ['mw'],
    "nāṭyaveda": ['cae', 'mw'],
    "nāṭyavedī": ['cae', 'mw'],
    "nāṭyaśekhara": ['mw'],
    "nāṭyaśālā": ['cae', 'mw'],
    "nāṭyaśāstra": ['cae', 'mw'],
    "nāṭyaśāstrapravaktṛ": ['mw'],
    "nāṭyaṃ": ['ap90'],
    "nāṭyena": ['mw'],
    "nāṭyocita": ['mw'],
    "nāṭyokti": ['mw'],
    "nāṭyācārya": ['cae', 'mw'],
    "nāṭyācāryaka": ['mw'],
    "nāṭyāgāra": ['mw'],
    "nāṭyālābu": ['mw'],
    "nāṭāmra": ['mw'],
    "nāṭāra": ['mw'],
    "nāṭāraḥ": ['ap90'],
    "nāṭī": ['mw'],
    "nī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nīca": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nīcabhojya": ['mw'],
    "nīcaga": ['mw'],
    "nīcagata": ['mw'],
    "nīcagā": ['mw'],
    "nīcagāmin": ['mw'],
    "nīcagṛha": ['mw'],
    "nīcair": ['mw'],
    "nīcairmukha": ['mw'],
    "nīcairākhya": ['ddsa', 'mw'],
    "nīcais": ['ap90', 'cae', 'ddsa', 'mw'],
    "nīcaistana": ['mw'],
    "nīcaistarām": ['mw'],
    "nīcaiḥ": ['mw'],
    "nīcaiḥkara": ['mw'],
    "nīcaiḥkāram": ['mw'],
    "nīcaiḥkṛtvā": ['mw'],
    "nīcaiḥkṛtya": ['mw'],
    "nīcajāti": ['mw'],
    "nīcaka": ['ap90', 'mw'],
    "nīcakadamba": ['mw'],
    "nīcakais": ['ap90', 'mw'],
    "nīcakarman": ['mw'],
    "nīcakeśanakha": ['mw'],
    "nīcakeśaśmaśrunakha": ['mw'],
    "nīcakin": ['ap90', 'mw'],
    "nīcakula": ['cped', 'mw'],
    "nīcakulodbhava": ['mw'],
    "nīcakulodgata": ['mw'],
    "nīcakulīna": ['cped'],
    "nīcakā": ['ap90'],
    "nīcanakharoman": ['mw'],
    "nīcaniviṭṭha": ['cped'],
    "nīcapatha": ['mw'],
    "nīcarata": ['mw'],
    "nīcarkṣa": ['mw'],
    "nīcatara": ['cped'],
    "nīcataraka": ['bhs'],
    "nīcataraṁ": ['cped'],
    "nīcatayāyā": ['mw'],
    "nīcatva": ['mw'],
    "nīcatā": ['mw'],
    "nīcavajra": ['mw'],
    "nīcavatthuka": ['cped'],
    "nīcayonin": ['mw'],
    "nīcaśākha": ['mw'],
    "nīcaṁ karoti": ['cped'],
    "nīcceyya": ['cped'],
    "nīcikā": ['ap90'],
    "nīcoccavṛtta": ['mw'],
    "nīcokti": ['mw'],
    "nīcopagata": ['mw'],
    "nīcya": ['mw'],
    "nīcā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nīcākulīna": ['cped'],
    "nīcāmeḍhra": ['mw'],
    "nīcāt": ['cae', 'ddsa', 'mw'],
    "nīcāvagāha": ['ddsa', 'mw'],
    "nīcāvayas": ['ddsa', 'gra', 'mw'],
    "nīcāyaka": ['mw'],
    "nīcāyakīya": ['mw'],
    "nīcīkṛ": ['ap90', 'mw'],
    "nīcīna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nīcīnabāra": ['gra', 'mw'],
    "nīdhra": ['cae', 'ddsa', 'mw'],
    "nīdhraṃ": ['ap90'],
    "nīgha": ['bhs', 'cped'],
    "nīharanta": ['cped'],
    "nīharati": ['bhs', 'cped'],
    "nīhari": ['cped'],
    "nīharitabba": ['cped'],
    "nīharittha": ['cped'],
    "nīharitvā": ['cped'],
    "nīhariṁsu": ['cped'],
    "nīhata": ['cped'],
    "nīhaṭa": ['cped'],
    "nīhāra": ['cae', 'ddsa', 'gra', 'mw'],
    "nīhārabhatta": ['cped'],
    "nīhāracakṣus": ['mw'],
    "nīhārakara": ['mw'],
    "nīhāramaya": ['mw'],
    "nīhāraḥ": ['ap90'],
    "nīhāritabba": ['cped'],
    "nīhārituṁ": ['cped'],
    "nīhārāpetabba": ['cped'],
    "nīhārāya": ['mw'],
    "nīhārīkṛ": ['ddsa', 'mw'],
    "nīhātuṁ": ['cped'],
    "nīka": ['mw'],
    "nīkarṣin": ['mw'],
    "nīkleda": ['mw'],
    "nīkulaka": ['mw'],
    "nīkā": ['ap90', 'mw'],
    "nīkāra": ['ddsa', 'mw'],
    "nīkāraḥ": ['ap90'],
    "nīkāśa": ['ap90', 'cae', 'mw'],
    "nīkṣaṇa": ['gra', 'mw'],
    "nīkṣaṇaṃ": ['ap90'],
    "nīl": ['ddsa', 'mw'],
    "nīla": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "nīlabha": ['mw'],
    "nīlabhijāti": ['cped'],
    "nīlabhū": ['mw'],
    "nīlabhūti": ['bhs'],
    "nīlabhṛṅgarāja": ['mw'],
    "nīlabuhnā": ['mw'],
    "nīlabīja": ['mw'],
    "nīlacandra": ['mw'],
    "nīlacarman": ['mw'],
    "nīlacchada": ['mw'],
    "nīlacchavin": ['mw'],
    "nīlacchavī": ['mw'],
    "nīlacolakavat": ['mw'],
    "nīladaṇḍa": ['bhs', 'mw'],
    "nīladhvaja": ['mw'],
    "nīladruma": ['mw'],
    "nīladūrvā": ['mw'],
    "nīlagala": ['mw'],
    "nīlagalamāla": ['mw'],
    "nīlagandhika": ['mw'],
    "nīlagarbha": ['mw'],
    "nīlagaṅgā": ['mw'],
    "nīlagaṇeśa": ['mw'],
    "nīlaghora": ['mw'],
    "nīlagiri": ['cae', 'mw'],
    "nīlagirikarṇikā": ['mw'],
    "nīlagiryanilavega": ['bhs'],
    "nīlagiva": ['cped'],
    "nīlagrīva": ['bhs', 'cae', 'mw'],
    "nīlaja": ['mw'],
    "nīlajhiṇṭī": ['mw'],
    "nīlajā": ['mw'],
    "nīlaka": ['bhs', 'cped', 'mw'],
    "nīlakamala": ['mw'],
    "nīlakanda": ['mw'],
    "nīlakapitthaka": ['mw'],
    "nīlakasiṇa": ['cped'],
    "nīlakavaddhika": ['cped'],
    "nīlakaṃ": ['ap90'],
    "nīlakaṇā": ['mw'],
    "nīlakaṇṭha": ['cae', 'mw'],
    "nīlakaṇṭhabhāṣya": ['mw'],
    "nīlakaṇṭhacampū": ['mw'],
    "nīlakaṇṭhadīkṣitīya": ['mw'],
    "nīlakaṇṭhajātaka": ['mw'],
    "nīlakaṇṭhakośa": ['mw'],
    "nīlakaṇṭhamālā": ['mw'],
    "nīlakaṇṭhaprakāśa": ['mw'],
    "nīlakaṇṭhaprakāśikā": ['mw'],
    "nīlakaṇṭhastava": ['mw'],
    "nīlakaṇṭhasthānamāhātmya": ['mw'],
    "nīlakaṇṭhastotra": ['mw'],
    "nīlakaṇṭhatantra": ['mw'],
    "nīlakaṇṭhodāharaṇa": ['mw'],
    "nīlakaṇṭhākṣa": ['mw'],
    "nīlakaṇṭhī": ['mw'],
    "nīlakaṇṭhīya": ['mw'],
    "nīlakeśa": ['bhs'],
    "nīlakeśī": ['mw'],
    "nīlakrauñca": ['mw'],
    "nīlakrāntā": ['mw'],
    "nīlakuntalā": ['mw'],
    "nīlakuraṇṭaka": ['mw'],
    "nīlakuruṇṭaka": ['mw'],
    "nīlakusumā": ['mw'],
    "nīlakuṇḍa": ['mw'],
    "nīlakāca": ['mw'],
    "nīlakāyika": ['bhs', 'mw'],
    "nīlakṛtsna": ['bhs', 'mw'],
    "nīlaloha": ['mw'],
    "nīlalohita": ['cae', 'gra', 'mw'],
    "nīlalohitā": ['mw'],
    "nīlalohitākṣa": ['mw'],
    "nīlalohitāntevāsin": ['mw'],
    "nīlamahiṣa": ['mw'],
    "nīlamakṣikā": ['mw'],
    "nīlamakṣā": ['mw'],
    "nīlamallikā": ['mw'],
    "nīlamata": ['mw'],
    "nīlamatapurāṇa": ['mw'],
    "nīlamaya": ['mw'],
    "nīlamaṇi": ['cae', 'mw'],
    "nīlameha": ['mw'],
    "nīlamehin": ['mw'],
    "nīlamuktā": ['bhs'],
    "nīlamādhava": ['mw'],
    "nīlamāṣa": ['mw'],
    "nīlamīlika": ['mw'],
    "nīlamṛttikā": ['mw'],
    "nīlanakha": ['mw'],
    "nīlanibhāsa": ['cped'],
    "nīlanicolin": ['mw'],
    "nīlanirguṇḍī": ['mw'],
    "nīlaniryāsaka": ['mw'],
    "nīlanīraja": ['mw'],
    "nīlapadma": ['mw'],
    "nīlapakṣman": ['cae', 'mw'],
    "nīlaparṇa": ['mw'],
    "nīlapattra": ['mw'],
    "nīlapattrā": ['mw'],
    "nīlapattrī": ['mw'],
    "nīlapaura": ['mw'],
    "nīlapaṅka": ['mw'],
    "nīlapaṅkaja": ['mw'],
    "nīlapaṭa": ['cae', 'mw'],
    "nīlapaṭala": ['mw'],
    "nīlapaṭṭa": ['mw'],
    "nīlaphalā": ['mw'],
    "nīlapiccha": ['mw'],
    "nīlapiṅgala": ['mw'],
    "nīlapiṇḍa": ['mw'],
    "nīlapiṣṭauṇḍī": ['mw'],
    "nīlapiṭa": ['mw'],
    "nīlapora": ['mw'],
    "nīlapunarnavā": ['mw'],
    "nīlapura": ['mw'],
    "nīlapurāṇa": ['mw'],
    "nīlapuṣpa": ['mw'],
    "nīlapuṣpikā": ['mw'],
    "nīlapuṣpā": ['mw'],
    "nīlapuṣpī": ['mw'],
    "nīlapācana": ['mw'],
    "nīlapācanabhāṇḍa": ['mw'],
    "nīlapīta": ['mw'],
    "nīlapṛṣṭha": ['cae', 'gra', 'mw'],
    "nīlaratna": ['mw'],
    "nīlaratnaka": ['mw'],
    "nīlarudropaniṣad": ['mw'],
    "nīlarāji": ['mw'],
    "nīlarūpaka": ['mw'],
    "nīlasarasvatī": ['mw'],
    "nīlasarasvatīmanu": ['mw'],
    "nīlasarasvatīpaddhati": ['mw'],
    "nīlasaroruha": ['cae', 'mw'],
    "nīlasaroruhākṣī": ['mw'],
    "nīlasaṃdhyā": ['mw'],
    "nīlasaṃdhānabhāṇḍa": ['cae', 'mw'],
    "nīlasindhuka": ['mw'],
    "nīlaskandhā": ['mw'],
    "nīlaskandā": ['mw'],
    "nīlaspandā": ['mw'],
    "nīlasvarūpa": ['mw'],
    "nīlasāra": ['mw'],
    "nīlatantra": ['mw'],
    "nīlataru": ['mw'],
    "nīlati": ['ap90'],
    "nīlatoyada": ['mw'],
    "nīlatā": ['mw'],
    "nīlatāla": ['mw'],
    "nīlatārāsarasvatīstotra": ['mw'],
    "nīlavadhika": ['cped'],
    "nīlavajra": ['mw'],
    "nīlavallī": ['mw'],
    "nīlavant": ['cae'],
    "nīlavarṇa": ['cae', 'mw'],
    "nīlavarṇā": ['mw'],
    "nīlavarṣābhū": ['mw'],
    "nīlavasana": ['cae', 'mw'],
    "nīlavastra": ['cae', 'mw'],
    "nīlavastrā": ['mw'],
    "nīlavat": ['gra', 'mw'],
    "nīlavrata": ['mw'],
    "nīlavānara": ['mw'],
    "nīlavāsas": ['bhs', 'mw'],
    "nīlavṛkṣa": ['mw'],
    "nīlavṛnta": ['mw'],
    "nīlavṛntaka": ['mw'],
    "nīlavṛṣa": ['mw'],
    "nīlavṛṣā": ['mw'],
    "nīlayaṣṭikā": ['mw'],
    "nīlaśigru": ['mw'],
    "nīlaśikhaṇḍa": ['mw'],
    "nīlaśīrṣṇī": ['mw'],
    "nīlaṃguḥ": ['ap90'],
    "nīlaṅgu": ['mw'],
    "nīlaṣaṇḍa": ['mw'],
    "nīleśvara": ['mw'],
    "nīlikā": ['ap90', 'mw'],
    "nīlikākāca": ['mw'],
    "nīliman": ['ap90', 'cae', 'mw'],
    "nīlinī": ['ddsa'],
    "nīliṇī": ['mw'],
    "nīliṇīphala": ['mw'],
    "nīloda": ['bhs', 'mw'],
    "nīlodvāha": ['mw'],
    "nīlodvāhapaddhati": ['mw'],
    "nīlodvāhavidhi": ['mw'],
    "nīlopakāśa": ['mw'],
    "nīlopala": ['mw'],
    "nīlotpala": ['cae', 'ddsa', 'mw'],
    "nīlotpalagandha": ['mw'],
    "nīlotpalamaya": ['mw'],
    "nīlotpalin": ['mw'],
    "nīlotpalinī": ['mw'],
    "nīlotpalā": ['bhs'],
    "nīlotsargapaddhati": ['mw'],
    "nīlā": ['bhs', 'mw'],
    "nīlābha": ['mw'],
    "nīlābhra": ['mw'],
    "nīlābhrasaṃvṛta": ['mw'],
    "nīlābja": ['cae', 'mw'],
    "nīlācala": ['mw'],
    "nīlāda": ['bhs', 'mw'],
    "nīlādri": ['mw'],
    "nīlādrikarṇikā": ['mw'],
    "nīlādrimahodaya": ['mw'],
    "nīlādrimāhātmya": ['mw'],
    "nīlādriparājitā": ['mw'],
    "nīlāgalasālā": ['mw'],
    "nīlākṣa": ['mw'],
    "nīlālakavarūthin": ['mw'],
    "nīlālikulasaṃkula": ['mw'],
    "nīlālu": ['mw'],
    "nīlāmbara": ['mw'],
    "nīlāmbhoja": ['cae'],
    "nīlāmbuda": ['bhs'],
    "nīlāmbujanman": ['mw'],
    "nīlāmlāna": ['mw'],
    "nīlāmlī": ['mw'],
    "nīlāpariṇaya": ['mw'],
    "nīlāruna": ['mw'],
    "nīlāsana": ['mw'],
    "nīlāsura": ['mw'],
    "nīlāya": ['ddsa', 'mw'],
    "nīlāyudha": ['mw'],
    "nīlāñjana": ['cae', 'mw'],
    "nīlāñjanā": ['mw'],
    "nīlāñjanī": ['mw'],
    "nīlāñjasā": ['mw'],
    "nīlāśmaja": ['mw'],
    "nīlāśman": ['ddsa', 'mw'],
    "nīlāśoka": ['mw'],
    "nīlāśva": ['mw'],
    "nīlāśī": ['mw'],
    "nīlāṃguḥ": ['ap90'],
    "nīlāṃśuka": ['mw'],
    "nīlāṅga": ['mw'],
    "nīlāṅgu": ['mw'],
    "nīlāṅkitadala": ['mw'],
    "nīlāṇḍaja": ['mw'],
    "nīlī": ['ap90', 'cped', 'ddsa', 'mw'],
    "nīlībhāṇḍa": ['cae', 'mw'],
    "nīlīrasa": ['mw'],
    "nīlīroga": ['mw'],
    "nīlīrāga": ['mw'],
    "nīlīsaṃdhānabhāṇḍa": ['mw'],
    "nīlīvarṇa": ['cae', 'mw'],
    "nīlīvastra": ['mw'],
    "nīl̤a": ['cae'],
    "nīmānuja": ['mw'],
    "nīnāha": ['mw'],
    "nīpa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nīparāja": ['mw'],
    "nīpya": ['cae', 'mw'],
    "nīpā": ['mw'],
    "nīpātithi": ['gra', 'mw'],
    "nīr": ['mw'],
    "nīra": ['cae', 'ddsa', 'mw'],
    "nīracara": ['mw'],
    "nīrada": ['cae', 'ddsa', 'mw'],
    "nīradhi": ['cae', 'ddsa', 'mw'],
    "nīradin": ['ddsa', 'mw'],
    "nīragraha": ['mw'],
    "nīraja": ['cae', 'mw'],
    "nīrajas": ['cae', 'ddsa', 'mw'],
    "nīrajaska": ['cae', 'mw'],
    "nīrajastama": ['mw'],
    "nīrajastamaska": ['mw'],
    "nīrajastamasā": ['mw'],
    "nīrajasva": ['mw'],
    "nīrajākṣī": ['mw'],
    "nīrajāta": ['ddsa', 'mw'],
    "nīrajīkārita": ['mw'],
    "nīrajīkṛ": ['ddsa', 'mw'],
    "nīrakta": ['mw'],
    "nīrandhra": ['cae', 'ddsa', 'mw'],
    "nīrandhratva": ['mw'],
    "nīrandhrita": ['mw'],
    "nīranidhi": ['cae', 'mw'],
    "nīrapatatrin": ['ddsa', 'mw'],
    "nīrapriya": ['mw'],
    "nīraruha": ['mw'],
    "nīrarāśi": ['mw'],
    "nīrasa": ['cae', 'mw'],
    "nīrasatva": ['mw'],
    "nīrasatā": ['mw'],
    "nīrata": ['mw'],
    "nīrataraṃga": ['mw'],
    "nīratīraja": ['mw'],
    "nīrava": ['cae', 'ddsa', 'mw'],
    "nīraśana": ['mw'],
    "nīraṃ": ['ap90'],
    "nīraṅgikā": ['mw'],
    "nīraṅgī": ['mw'],
    "nīreṇuka": ['mw'],
    "nīrindu": ['mw'],
    "nīroga": ['cae', 'mw'],
    "nīrogadurbhikṣa": ['mw'],
    "nīrogatā": ['mw'],
    "nīrogyatā": ['mw'],
    "nīroha": ['cae', 'mw'],
    "nīruc": ['mw'],
    "nīruj": ['cae', 'mw'],
    "nīruja": ['cae', 'mw'],
    "nīrāga": ['cae', 'mw'],
    "nīrāj": ['ap90', 'mw'],
    "nīrājana": ['cae', 'mw'],
    "nīrājanadvādaśīvrata": ['mw'],
    "nīrājanagiri": ['mw'],
    "nīrājanapadyālilakṣaṇavibhakti": ['mw'],
    "nīrājanaprakāśa": ['mw'],
    "nīrājanastotra": ['mw'],
    "nīrājanavidhi": ['mw'],
    "nīrājanaṃ": ['ap90'],
    "nīrājita": ['mw'],
    "nīrājya": ['mw'],
    "nīrākhu": ['mw'],
    "nīrī": ['mw'],
    "nīrūpa": ['mw'],
    "nīta": ['ap90', 'cped', 'mw'],
    "nītadakṣiṇa": ['mw'],
    "nītamiśra": ['mw'],
    "nītattha": ['cped'],
    "nītha": ['cae', 'ddsa', 'gra', 'mw'],
    "nīthaḥ": ['ap90'],
    "nīthya": ['mw'],
    "nīthā": ['gra', 'mw'],
    "nīthāvid": ['gra', 'mw'],
    "nīti": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "nītibīja": ['mw'],
    "nītidoṣa": ['mw'],
    "nītidīpikā": ['mw'],
    "nītigarbhitaśāstra": ['mw'],
    "nītighoṣa": ['mw'],
    "nītijña": ['cae', 'mw'],
    "nītikalpataru": ['mw'],
    "nītikamalākara": ['mw'],
    "nītikathā": ['mw'],
    "nītikuśala": ['cae', 'mw'],
    "nītilatā": ['mw'],
    "nītimant": ['cae'],
    "nītimat": ['ap90', 'mw'],
    "nītimayūkha": ['mw'],
    "nītimañjarī": ['mw'],
    "nītimukula": ['mw'],
    "nītinipuṇa": ['mw'],
    "nītiniṣṇa": ['mw'],
    "nītipaṭala": ['mw'],
    "nītipradīpa": ['mw'],
    "nītiprakāśa": ['mw'],
    "nītiratna": ['mw'],
    "nītiratnākara": ['mw'],
    "nītisamuccaya": ['mw'],
    "nītisaṃdhi": ['mw'],
    "nītisaṃgraha": ['mw'],
    "nītisaṃhitā": ['mw'],
    "nītisaṃkalana": ['mw'],
    "nītisumāvali": ['mw'],
    "nītisāra": ['mw'],
    "nītisārasaṃgraha": ['mw'],
    "nītitantra": ['mw'],
    "nītitaraṃga": ['mw'],
    "nītivarman": ['mw'],
    "nītivartani": ['mw'],
    "nītivedin": ['mw'],
    "nītivid": ['mw'],
    "nītividyā": ['cae', 'mw'],
    "nītivilāsa": ['mw'],
    "nītiviveka": ['mw'],
    "nītiviṣaya": ['mw'],
    "nītivyatikrama": ['mw'],
    "nītivākya": ['mw'],
    "nītivākyāmṛta": ['mw'],
    "nītiyukta": ['mw'],
    "nītiśataka": ['mw'],
    "nītiśāstra": ['mw'],
    "nītiśāstrasamuccaya": ['mw'],
    "nītiḥ": ['ap90'],
    "nītta": ['mw'],
    "nītārtha": ['bhs', 'ddsa', 'mw'],
    "nīv": ['mw'],
    "nīva": ['cae', 'ddsa', 'mw'],
    "nīvan": ['mw'],
    "nīvara": ['mw'],
    "nīvaraḥ": ['ap90'],
    "nīvaraṇa": ['bhs', 'cped', 'mw'],
    "nīveṣya": ['mw'],
    "nīvi": ['cae', 'ddsa', 'mw'],
    "nīvibhārya": ['mw'],
    "nīvid": ['mw'],
    "nīviā": ['gra'],
    "nīviḥ": ['ap90'],
    "nīvra": ['ap90', 'mw'],
    "nīvraṃ": ['ap90'],
    "nīvyā": ['gra'],
    "nīvāha": ['mw'],
    "nīvāka": ['mw'],
    "nīvākaḥ": ['ap90'],
    "nīvāra": ['cae', 'ddsa', 'mw'],
    "nīvārabhakka": ['cped'],
    "nīvārakaṇa": ['cae'],
    "nīvāramuṣṭimpaca": ['mw'],
    "nīvāraprasṛtimpaca": ['mw'],
    "nīvāraḥ": ['ap90'],
    "nīvārā": ['mw'],
    "nīvī": ['cae', 'mw'],
    "nīvṛt": ['ap90', 'mw'],
    "nīvṛti": ['mw'],
    "nīyamāna": ['cped'],
    "nīyanta": ['cped'],
    "nīyati": ['cped'],
    "nīyyāṇa": ['cped'],
    "nīyāti": ['cped'],
    "nīyāyanta": ['cped'],
    "nīśāra": ['cae', 'mw'],
    "nīśāraḥ": ['ap90'],
    "nīḍ": ['gra'],
    "nīḍa": ['cae', 'ddsa', 'gra', 'mw'],
    "nīḍagarbha": ['mw'],
    "nīḍaja": ['mw'],
    "nīḍajajendra": ['mw'],
    "nīḍaka": ['bhs', 'mw'],
    "nīḍakaḥ": ['ap90'],
    "nīḍaya": ['mw'],
    "nīḍaḥ": ['ap90'],
    "nīḍi": ['gra', 'mw'],
    "nīḍin": ['mw'],
    "nīḍodbhava": ['mw'],
    "nīḷa": ['ddsa'],
    "nīṣah": ['cae', 'mw'],
    "nīṣāh": ['mw'],
    "nū": ['ap90', 'cae', 'gra', 'mw'],
    "nūda": ['mw'],
    "nūna": ['cped'],
    "nūnabhāva": ['mw'],
    "nūnabhāvāt": ['mw'],
    "nūnam": ['cae', 'ddsa', 'gra', 'mw'],
    "nūnaṃ": ['ap90'],
    "nūpura": ['cae', 'ddsa', 'mw'],
    "nūpuravat": ['mw'],
    "nūpuraḥ": ['ap90'],
    "nūpurin": ['mw'],
    "nūpurottamā": ['bhs', 'mw'],
    "nūta": ['ap90', 'mw'],
    "nūtana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nūtanagajārohaprakāra": ['mw'],
    "nūtanamūrtipratiṣṭhā": ['mw'],
    "nūtanapratiṣṭhāprayoga": ['mw'],
    "nūtanatari": ['mw'],
    "nūtanatva": ['mw'],
    "nūtanatā": ['mw'],
    "nūtanaya": ['mw'],
    "nūtanayati": ['ap90'],
    "nūtanayauvana": ['mw'],
    "nūtanaśrutigītāvyākhyā": ['mw'],
    "nūtaneśvara": ['mw'],
    "nūtaneṣṭiprayoga": ['mw'],
    "nūtanāśvārohaprayoga": ['mw'],
    "nūtna": ['cae', 'gra', 'mw'],
    "nūtnavayas": ['mw'],
    "nṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nṛbandhu": ['mw'],
    "nṛbhartṛ": ['cae', 'mw'],
    "nṛbhṛta": ['mw'],
    "nṛbāhu": ['cae', 'gra', 'mw'],
    "nṛcakṣas": ['cae', 'gra', 'mw'],
    "nṛcakṣus": ['mw'],
    "nṛcandra": ['mw'],
    "nṛdeva": ['cae', 'mw'],
    "nṛdevī": ['mw'],
    "nṛdharman": ['mw'],
    "nṛdhūta": ['gra', 'mw'],
    "nṛdurga": ['cae', 'ddsa', 'mw'],
    "nṛga": ['cae', 'mw'],
    "nṛgamokṣaprakaraṇa": ['mw'],
    "nṛganṛpatipāṣāṇayajñayūpapraśasti": ['mw'],
    "nṛgatīrtha": ['mw'],
    "nṛgaśvabhrapraveśa": ['mw'],
    "nṛgaśāpa": ['mw'],
    "nṛgaḥ": ['ap90'],
    "nṛgopākhyāna": ['mw'],
    "nṛgā": ['mw'],
    "nṛgākhyāna": ['mw'],
    "nṛhan": ['cae', 'gra', 'mw'],
    "nṛhari": ['cae', 'mw'],
    "nṛjala": ['mw'],
    "nṛjit": ['cae', 'mw'],
    "nṛjyāya": ['cae', 'mw'],
    "nṛjīt": ['gra'],
    "nṛkalevara": ['cae', 'ddsa', 'mw'],
    "nṛkalpa": ['mw'],
    "nṛkesari": ['mw'],
    "nṛkesarin": ['cae', 'mw'],
    "nṛkukkura": ['mw'],
    "nṛkuladevā": ['mw'],
    "nṛkāra": ['mw'],
    "nṛloka": ['cae', 'mw'],
    "nṛlokapāla": ['mw'],
    "nṛmana": ['mw'],
    "nṛmara": ['mw'],
    "nṛmat": ['mw'],
    "nṛmaṇas": ['cae', 'gra', 'mw'],
    "nṛmaṇasy": ['cae', 'gra'],
    "nṛmaṇasya": ['mw'],
    "nṛmaṇi": ['mw'],
    "nṛmaṇā": ['mw'],
    "nṛmedha": ['cae', 'gra', 'mw'],
    "nṛmegha": ['mw'],
    "nṛmithuna": ['mw'],
    "nṛmādana": ['cae', 'gra', 'mw'],
    "nṛmāṃsa": ['cae', 'mw'],
    "nṛmāṃsāśana": ['mw'],
    "nṛmṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nṛmṇavardhana": ['gra', 'mw'],
    "nṛmṇā": ['mw'],
    "nṛmṇāyi": ['mw'],
    "nṛnamana": ['mw'],
    "nṛpa": ['ap90', 'ddsa', 'mw'],
    "nṛpabadara": ['mw'],
    "nṛpabhūṣaṇī": ['mw'],
    "nṛpacihna": ['mw'],
    "nṛpadruma": ['mw'],
    "nṛpadviṣ": ['mw'],
    "nṛpadīpa": ['mw'],
    "nṛpagṛha": ['mw'],
    "nṛpajana": ['cae', 'mw'],
    "nṛpakanda": ['mw'],
    "nṛpakaṃ": ['bhs'],
    "nṛpakriyā": ['mw'],
    "nṛpakriyāṃkṛ": ['mw'],
    "nṛpakārya": ['cae', 'mw'],
    "nṛpalakṣman": ['mw'],
    "nṛpaliṅga": ['mw'],
    "nṛpaliṅgadhara": ['mw'],
    "nṛpamandira": ['mw'],
    "nṛpamāna": ['mw'],
    "nṛpamāṅgalyaka": ['mw'],
    "nṛpamāṣa": ['mw'],
    "nṛpanāpitaputranyāya": ['mw'],
    "nṛpanīti": ['mw'],
    "nṛpapalāṇḍu": ['mw'],
    "nṛpapriya": ['mw'],
    "nṛpapriyaphalā": ['mw'],
    "nṛpapriyā": ['mw'],
    "nṛparṣi": ['mw'],
    "nṛpasabha": ['mw'],
    "nṛpasaṃśraya": ['mw'],
    "nṛpasnuṣā": ['mw'],
    "nṛpasuta": ['cae', 'mw'],
    "nṛpasutā": ['mw'],
    "nṛpati": ['cae', 'ddsa', 'gra', 'mw'],
    "nṛpatidvāra": ['mw'],
    "nṛpatikanyakā": ['cae', 'mw'],
    "nṛpatinītigarbhitavṛtta": ['mw'],
    "nṛpatipatha": ['mw'],
    "nṛpatnī": ['cae', 'gra', 'mw'],
    "nṛpatva": ['cae', 'ddsa', 'mw'],
    "nṛpatvaṃkṛ": ['mw'],
    "nṛpatāla": ['mw'],
    "nṛpavallabha": ['ddsa', 'mw'],
    "nṛpavallabhā": ['mw'],
    "nṛpaveśman": ['mw'],
    "nṛpavṛkṣa": ['mw'],
    "nṛpayoga": ['mw'],
    "nṛpañcānana": ['mw'],
    "nṛpañcāsya": ['mw'],
    "nṛpaśreṣṭha": ['mw'],
    "nṛpaśu": ['cae', 'ddsa', 'mw'],
    "nṛpaśāsana": ['mw'],
    "nṛpaṃjaya": ['mw'],
    "nṛpecchā": ['mw'],
    "nṛpeśas": ['gra', 'mw'],
    "nṛpeṣṭa": ['mw'],
    "nṛpocita": ['mw'],
    "nṛprajā": ['ddsa', 'mw'],
    "nṛpābhīra": ['mw'],
    "nṛpādhvara": ['mw'],
    "nṛpāhvaya": ['mw'],
    "nṛpākṛṣṭa": ['mw'],
    "nṛpāla": ['cae', 'ddsa', 'mw'],
    "nṛpālaya": ['ddsa', 'mw'],
    "nṛpāmaya": ['mw'],
    "nṛpānna": ['mw'],
    "nṛpānucara": ['mw'],
    "nṛpānyatva": ['mw'],
    "nṛpāryaman": ['mw'],
    "nṛpāsana": ['cae', 'mw'],
    "nṛpāspada": ['mw'],
    "nṛpātmaja": ['cae', 'mw'],
    "nṛpātmajā": ['mw'],
    "nṛpātṛ": ['cae', 'gra', 'mw'],
    "nṛpāvarta": ['mw'],
    "nṛpāyia": ['gra'],
    "nṛpāyya": ['cae', 'gra', 'mw'],
    "nṛpāṃśa": ['mw'],
    "nṛpāṅgana": ['cae', 'mw'],
    "nṛpāṅganā": ['mw'],
    "nṛpāṅgaṇa": ['cae', 'ddsa', 'mw'],
    "nṛpāṇa": ['cae', 'gra', 'mw'],
    "nṛpīti": ['cae', 'gra', 'mw'],
    "nṛpīṭa": ['mw'],
    "nṛsena": ['mw'],
    "nṛsenā": ['mw'],
    "nṛsiṃha": ['cae', 'mw'],
    "nṛsiṃhabhaṭṭīya": ['mw'],
    "nṛsiṃhabījastotra": ['mw'],
    "nṛsiṃhacampū": ['mw'],
    "nṛsiṃhacarita": ['mw'],
    "nṛsiṃhacaturdaśī": ['mw'],
    "nṛsiṃhadvādaśī": ['mw'],
    "nṛsiṃhagaṇita": ['mw'],
    "nṛsiṃhagāyatrī": ['mw'],
    "nṛsiṃhajayantī": ['mw'],
    "nṛsiṃhajayantīkalpa": ['mw'],
    "nṛsiṃhakalpa": ['mw'],
    "nṛsiṃhakaraṇa": ['mw'],
    "nṛsiṃhakavaca": ['mw'],
    "nṛsiṃhamahataścaritra": ['mw'],
    "nṛsiṃhamahiman": ['mw'],
    "nṛsiṃhamantra": ['mw'],
    "nṛsiṃhamantrapaddhati": ['mw'],
    "nṛsiṃhamantrarājapuraścaraṇavidhi": ['mw'],
    "nṛsiṃhamāhātmya": ['mw'],
    "nṛsiṃhamālāmantra": ['mw'],
    "nṛsiṃhapaddhati": ['mw'],
    "nṛsiṃhapara": ['mw'],
    "nṛsiṃhaparicaryā": ['mw'],
    "nṛsiṃhaparicaryāpratiṣṭhākalpa": ['mw'],
    "nṛsiṃhapañcaratnamālā": ['mw'],
    "nṛsiṃhapañjara": ['mw'],
    "nṛsiṃhapaṭala": ['mw'],
    "nṛsiṃhaprakāśikā": ['mw'],
    "nṛsiṃhaprasāda": ['mw'],
    "nṛsiṃhaprādurbhāva": ['mw'],
    "nṛsiṃhapurāṇa": ['mw'],
    "nṛsiṃhapūjāpaddhati": ['mw'],
    "nṛsiṃhapūrvatāpanīya": ['mw'],
    "nṛsiṃharṣabhakṣetramāhātmya": ['mw'],
    "nṛsiṃhasahasranāman": ['mw'],
    "nṛsiṃhasahasranāmastotra": ['mw'],
    "nṛsiṃhasarvasva": ['mw'],
    "nṛsiṃhastavarāja": ['mw'],
    "nṛsiṃhastotra": ['mw'],
    "nṛsiṃhastuti": ['mw'],
    "nṛsiṃhatva": ['mw'],
    "nṛsiṃhatāpanī": ['mw'],
    "nṛsiṃhatāpanīyopaniṣad": ['mw'],
    "nṛsiṃhavajrapañjara": ['mw'],
    "nṛsiṃhavana": ['mw'],
    "nṛsiṃhodaya": ['mw'],
    "nṛsiṃhottaratāpanīya": ['mw'],
    "nṛsiṃhādisāman": ['mw'],
    "nṛsiṃhārādhana": ['mw'],
    "nṛsiṃhāṣṭaka": ['mw'],
    "nṛsiṃhāṣṭottaraśatanāman": ['mw'],
    "nṛsiṃhīya": ['mw'],
    "nṛsoma": ['mw'],
    "nṛsūrya": ['mw'],
    "nṛt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "nṛtama": ['cae', 'gra', 'mw'],
    "nṛti": ['cae', 'ddsa', 'gra', 'mw'],
    "nṛtiḥ": ['ap90'],
    "nṛtta": ['cae', 'ddsa', 'mw'],
    "nṛttajña": ['mw'],
    "nṛttamaya": ['mw'],
    "nṛttaprayoga": ['mw'],
    "nṛttaṃ": ['ap90'],
    "nṛtu": ['cae', 'ddsa', 'gra', 'mw'],
    "nṛtuḥ": ['ap90'],
    "nṛtya": ['cae', 'ddsa', 'mw'],
    "nṛtyagīta": ['cae', 'mw'],
    "nṛtyagītavādya": ['mw'],
    "nṛtyahasta": ['mw'],
    "nṛtyapriya": ['mw'],
    "nṛtyapriyā": ['mw'],
    "nṛtyasarvasva": ['mw'],
    "nṛtyasthāna": ['mw'],
    "nṛtyavilāsa": ['mw'],
    "nṛtyaśālā": ['mw'],
    "nṛtyaśāstra": ['mw'],
    "nṛtyekṣaṇa": ['mw'],
    "nṛtyā": ['bhs'],
    "nṛtyādhyāya": ['mw'],
    "nṛtā": ['cae', 'ddsa', 'mw'],
    "nṛtū": ['ap90', 'cae', 'ddsa', 'gra'],
    "nṛvant": ['cae'],
    "nṛvara": ['mw'],
    "nṛvarāha": ['cae', 'mw'],
    "nṛvat": ['ap90', 'cae', 'gra', 'mw'],
    "nṛvatsakhi": ['gra', 'mw'],
    "nṛveṣṭana": ['mw'],
    "nṛviḍamba": ['mw'],
    "nṛvāhas": ['cae', 'gra', 'mw'],
    "nṛvāhaṇa": ['cae', 'gra', 'mw'],
    "nṛvāhya": ['mw'],
    "nṛvīra": ['cae'],
    "nṛyajña": ['cae', 'ddsa', 'mw'],
    "nṛyugma": ['mw'],
    "nṛyuj": ['mw'],
    "nṛśastra": ['mw'],
    "nṛśaṃsa": ['ap90', 'cae', 'gra', 'mw'],
    "nṛśaṃsahṛdaya": ['cae'],
    "nṛśaṃsakārin": ['mw'],
    "nṛśaṃsakṛt": ['mw'],
    "nṛśaṃsatā": ['mw'],
    "nṛśaṃsavarṇa": ['mw'],
    "nṛśaṃsavat": ['mw'],
    "nṛśaṃsavādin": ['mw'],
    "nṛśaṃsavṛtta": ['mw'],
    "nṛśaṃsita": ['mw'],
    "nṛśaṃsya": ['ap90', 'cae', 'mw'],
    "nṛśṛṅga": ['cae', 'mw'],
    "nṛṣac": ['cae', 'gra', 'mw'],
    "nṛṣad": ['cae', 'gra', 'mw'],
    "nṛṣadana": ['cae', 'gra', 'mw'],
    "nṛṣadman": ['cae', 'gra', 'mw'],
    "nṛṣadvan": ['cae', 'gra', 'mw'],
    "nṛṣadvara": ['mw'],
    "nṛṣah": ['cae', 'gra', 'mw'],
    "nṛṣahya": ['cae', 'gra', 'mw'],
    "nṛṣaḍgu": ['mw'],
    "nṛṣā": ['cae', 'gra', 'mw'],
    "nṛṣāc": ['gra', 'mw'],
    "nṛṣāh": ['cae', 'gra', 'mw'],
    "nṛṣāhia": ['gra'],
    "nṛṣāhya": ['cae', 'gra', 'mw'],
    "nṛṣāti": ['cae', 'gra', 'mw'],
    "nṛṣūta": ['cae', 'gra', 'mw'],
    "nṝ": ['mw'],
    "nṝ~ḥpraṇetra": ['mw'],
    "o": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "obhagga": ['cped'],
    "obhaggavibhagga": ['cped'],
    "obhaggobhagga": ['cped'],
    "obhanditvā": ['cped'],
    "obhatacumbaṭa": ['cped'],
    "obhoga": ['cped'],
    "obhāsa": ['bhs', 'cped'],
    "obhāsana": ['cped'],
    "obhāsanta": ['cped'],
    "obhāsarāja": ['bhs'],
    "obhāsasāgaraviyūha": ['bhs'],
    "obhāsate": ['cped'],
    "obhāsati": ['cped'],
    "obhāsaya": ['cped'],
    "obhāsayanta": ['bhs'],
    "obhāsayat": ['cped'],
    "obhāsenta": ['cped'],
    "obhāseti": ['cped'],
    "obhāsetvā": ['cped'],
    "obhāsi": ['cped'],
    "obhāsita": ['cped'],
    "obhāsitabba": ['cped'],
    "ocaraka": ['cped'],
    "ocarati": ['cped'],
    "ocetuṁ": ['cped'],
    "ocinati": ['cped'],
    "ocināpesi": ['cped'],
    "ocināpeti": ['cped'],
    "ocināti": ['cped'],
    "ocita": ['cped'],
    "ociṇṇa": ['cped'],
    "ocīraka": ['cped'],
    "ocīrakajāta": ['cped'],
    "odadhati": ['bhs'],
    "odahana": ['bhs', 'cped'],
    "odahati": ['cped'],
    "odahi": ['cped'],
    "odahitvā": ['cped'],
    "odahiṁsu": ['cped'],
    "odaka": ['bhs', 'cped', 'mw'],
    "odakantika": ['cped'],
    "odana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "odanabhojikā": ['mw'],
    "odanakulmāṣopacaya": ['bhs'],
    "odanakummāsūpacaya": ['cped'],
    "odanamaya": ['cae'],
    "odanapac": ['mw'],
    "odanapacana": ['cae', 'mw'],
    "odanapiṇḍa": ['cae', 'mw'],
    "odanaprati": ['mw'],
    "odanapāka": ['cped'],
    "odanapākī": ['mw'],
    "odanapāṇinīya": ['mw'],
    "odanasava": ['mw'],
    "odanasurā": ['cped'],
    "odanavant": ['cae'],
    "odanavat": ['mw'],
    "odanaḥ": ['ap90'],
    "odanika": ['mw'],
    "odanikā": ['mw'],
    "odaniyaghara": ['cped'],
    "odanya": ['mw'],
    "odanāhvayā": ['mw'],
    "odanāhvā": ['mw'],
    "odanī": ['mw'],
    "odanīy": ['cae'],
    "odanīya": ['mw'],
    "odanīyati": ['ap90'],
    "odapattakinī": ['cped'],
    "odarika": ['cped'],
    "odarikatta": ['cped'],
    "odariya": ['cped'],
    "odatī": ['ap90', 'cae', 'mw'],
    "oddhasaṃdhi": ['bhs'],
    "odhas": ['ap90', 'mw'],
    "odhasta": ['cped'],
    "odhastapatoda": ['cped'],
    "odhesiṁ": ['cped'],
    "odheti": ['cped'],
    "odhi": ['cped'],
    "odhiso": ['cped'],
    "odhunitvā": ['cped'],
    "odhuniṁsu": ['cped'],
    "odhunāti": ['cped'],
    "odhārita": ['cped'],
    "odhṛta": ['bhs'],
    "odissa": ['cped'],
    "odma": ['mw'],
    "odman": ['cae', 'mw'],
    "odmaḥ": ['ap90'],
    "odumbara": ['bhs'],
    "odāta": ['cped'],
    "odātaka": ['cped'],
    "odātakasiṇa": ['cped'],
    "odātanibhāsa": ['cped'],
    "odātavasana": ['cped'],
    "ogacchamāna": ['cped'],
    "ogacchanta": ['cped'],
    "ogacchati": ['cped'],
    "ogadha": ['cped'],
    "ogahana": ['cped'],
    "ogamana": ['bhs', 'cped'],
    "ogata": ['cped'],
    "ogayha": ['cped'],
    "ogaṇa": ['ap90', 'cae', 'cped', 'gra', 'mw'],
    "oggacchamāna": ['cped'],
    "oggacchati": ['cped'],
    "oggamana": ['cped'],
    "oggata": ['cped'],
    "oggayha": ['cped'],
    "ogha": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "oghadeva": ['mw'],
    "oghaja": ['bhs'],
    "oghana": ['cped'],
    "oghaniryukti": ['mw'],
    "ogharatha": ['mw'],
    "oghatama": ['cped'],
    "oghatara": ['cped'],
    "oghatiṇṇa": ['cped'],
    "oghavat": ['mw'],
    "oghavatī": ['mw'],
    "oghaḥ": ['ap90'],
    "oghātiga": ['cped'],
    "ogilituṁ": ['cped'],
    "ogrāhaka": ['bhs'],
    "ogumpheti": ['cped'],
    "ogumphetvā": ['cped'],
    "ogumphiyati": ['cped'],
    "oguṇṭhita": ['cped'],
    "oguṇṭhitvā": ['cped'],
    "ogādhappatta": ['cped'],
    "ogāha": ['cped'],
    "ogāha-m-uttiṇṇa": ['cped'],
    "ogāhati": ['cped'],
    "ogāhaṁ": ['cped'],
    "ogāhetvā": ['cped'],
    "ogāhi": ['cped'],
    "ogāhitvā": ['cped'],
    "ogāḷha": ['cped'],
    "ogīyas": ['mw'],
    "oha": ['cae', 'gra', 'mw'],
    "ohabrahman": ['cae', 'gra', 'mw'],
    "ohacca": ['cped'],
    "ohala": ['mw'],
    "ohana": ['bhs'],
    "oharati": ['cped'],
    "oharetvā": ['cped'],
    "ohas": ['ap90', 'cae', 'gra', 'mw'],
    "ohata": ['cped'],
    "ohaḥ": ['ap90'],
    "ohaṭa": ['cped'],
    "ohita": ['cped'],
    "ohitabhāra": ['bhs', 'cped'],
    "ohitasota": ['cped'],
    "ohiyyaka": ['cped'],
    "ohiyyati": ['cped'],
    "ohāra": ['bhs'],
    "ohārapetvā": ['cped'],
    "ohārayitvā": ['cped'],
    "ohāretabba": ['cped'],
    "ohāri": ['cped'],
    "ohārin": ['cped'],
    "ohārita": ['cped'],
    "ohāya": ['cped'],
    "ohīna": ['cped'],
    "ohīyaka": ['cped'],
    "ohīyati": ['cped'],
    "ohīyi": ['cped'],
    "ohīyitvā": ['cped'],
    "oj": ['ap90', 'mw'],
    "oja": ['ap90', 'cae', 'ddsa', 'mw'],
    "ojas": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ojaska": ['bhs'],
    "ojastara": ['mw'],
    "ojasvant": ['cae'],
    "ojasvat": ['ap90', 'gra', 'mw'],
    "ojasvin": ['cae', 'mw'],
    "ojasvitā": ['cae', 'mw'],
    "ojasya": ['cae', 'mw'],
    "ojasīna": ['ap90', 'cae', 'mw'],
    "ojava": ['cped'],
    "ojavanikā": ['cped'],
    "ojavat": ['cped'],
    "ojaḥpratyāhāriṇī": ['bhs'],
    "ojaṭṭhāyi": ['cped'],
    "ojaṭṭhāyin": ['cped'],
    "ojiṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ojman": ['ap90', 'cae', 'gra', 'mw'],
    "ojo": ['mw'],
    "ojobalā": ['bhs', 'mw'],
    "ojodā": ['cae', 'gra', 'mw'],
    "ojodātama": ['mw'],
    "ojohāra": ['bhs'],
    "ojohāraka": ['bhs'],
    "ojohāriṇī": ['bhs'],
    "ojomānī": ['mw'],
    "ojopati": ['bhs', 'mw'],
    "ojovantatara": ['bhs'],
    "ojā": ['bhs', 'cped'],
    "ojāpaharaṇa": ['cped'],
    "ojāy": ['cae', 'gra'],
    "ojāya": ['ddsa', 'mw'],
    "ojāyate": ['ap90'],
    "ojāyita": ['mw'],
    "ojīyas": ['ap90', 'gra', 'mw'],
    "ojīyaṃs": ['cae'],
    "oka": ['bhs', 'cae', 'cped', 'mw'],
    "oka-m-okata": ['cped'],
    "oka-m-okato": ['cped'],
    "oka-ñ-jaha": ['cped'],
    "okacara": ['cped'],
    "okacārikā": ['cped'],
    "okaja": ['mw'],
    "okampetvā": ['cped'],
    "okantati": ['cped'],
    "okappanīya": ['cped'],
    "okappeti": ['cped'],
    "okapuṇṇa": ['cped'],
    "okara": ['bhs'],
    "okas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "okassa": ['cped'],
    "okasta": ['bhs'],
    "okasāri": ['cped'],
    "okasārin": ['cped'],
    "okaḍḍhati": ['cped'],
    "okaḥ": ['ap90'],
    "okaḥsārin": ['mw'],
    "okaṇa": ['mw'],
    "okaṇaḥ": ['ap90'],
    "okaṇiḥ": ['ap90'],
    "okaṭṭati": ['bhs'],
    "okh": ['ap90', 'mw'],
    "okhittapaligha": ['cped'],
    "okia": ['gra'],
    "okilinī": ['cped'],
    "okirati": ['cped'],
    "okiri": ['cped'],
    "okiriṁsu": ['cped'],
    "okiriṇi": ['cped'],
    "okirīyati": ['cped'],
    "okivas": ['ap90', 'gra', 'mw'],
    "okiṇṇa": ['cped'],
    "okiṇṇavikiṇṇa": ['cped'],
    "okkalā": ['cped'],
    "okkama": ['cped'],
    "okkamamāna": ['cped'],
    "okkamana": ['cped'],
    "okkamaniya": ['cped'],
    "okkamanta": ['cped'],
    "okkamat": ['cped'],
    "okkamati": ['cped'],
    "okkamayati": ['cped'],
    "okkameti": ['cped'],
    "okkami": ['cped'],
    "okkamissatha": ['cped'],
    "okkamita": ['cped'],
    "okkamitar": ['cped'],
    "okkamitvā": ['cped'],
    "okkamiṁsu": ['cped'],
    "okkamma": ['cped'],
    "okkanta": ['cped'],
    "okkantati": ['cped'],
    "okkanti": ['cped'],
    "okkarika": ['bhs'],
    "okkassa": ['cped'],
    "okkassayati": ['cped'],
    "okkaṇī": ['mw'],
    "okkhipati": ['cped'],
    "okkhipitvā": ['cped'],
    "okkhitta": ['cped'],
    "okkhittacakku": ['cped'],
    "okkhā": ['cped'],
    "okkhāsata": ['cped'],
    "okkhāyati": ['cped'],
    "okkhāyika": ['cped'],
    "okkādhara": ['cped'],
    "okkāmeti": ['cped'],
    "okodanī": ['mw'],
    "okonidhana": ['mw'],
    "okoṭimaka": ['cped'],
    "okramaṇa": ['bhs'],
    "okta": ['mw'],
    "okula": ['mw'],
    "okulaḥ": ['ap90'],
    "okya": ['ap90', 'cae', 'gra', 'mw'],
    "okāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "okāsa": ['cped'],
    "okāsaṁ karoti": ['cped'],
    "okāsaṁ kāreti": ['cped'],
    "okāsaṁ kārāpeti": ['cped'],
    "okāseti": ['cped'],
    "okṣ": ['mw'],
    "okṣapayati": ['bhs'],
    "ola": ['ap90', 'mw'],
    "olagga": ['cped'],
    "olaggeti": ['cped'],
    "olaggetvā": ['cped'],
    "olaggi": ['cped'],
    "olaj": ['mw'],
    "olambaka": ['cped'],
    "olambanaka": ['cped'],
    "olambati": ['cped'],
    "olambenta": ['cped'],
    "olambeti": ['cped'],
    "olambā": ['bhs'],
    "olaṃḍ": ['ap90'],
    "olaṅgheti": ['cped'],
    "olaṅghāna": ['cped'],
    "olaṅka": ['bhs'],
    "olaṇḍ": ['mw'],
    "oligalla": ['cped'],
    "olikhati": ['cped'],
    "olikhiṁ": ['cped'],
    "oliyati": ['cped'],
    "olj": ['mw'],
    "olla": ['ap90'],
    "olokanaka": ['bhs', 'cped'],
    "olokayati": ['cped'],
    "olokayitvāna": ['cped'],
    "olokenta": ['cped'],
    "olokesi": ['cped'],
    "oloketabba": ['cped'],
    "oloketi": ['cped'],
    "oloketvā": ['cped'],
    "olubbha": ['cped'],
    "olugga": ['cped'],
    "oluggavilugga": ['cped'],
    "olujjati": ['cped'],
    "olumpetvā": ['cped'],
    "olīnavilīna": ['cped'],
    "olīnavuttika": ['cped'],
    "olīnavuttitā": ['cped'],
    "olīyati": ['bhs', 'cped'],
    "om": ['ap90', 'cae', 'ddsa', 'mw'],
    "oma": ['cae', 'cped', 'gra', 'mw'],
    "omadda": ['cped'],
    "omaddakāraka": ['cped'],
    "omaddati": ['cped'],
    "omadditvā": ['cped'],
    "omaka": ['cped'],
    "omakacātumāsaṁ": ['cped'],
    "omalā": ['mw'],
    "oman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "omanvant": ['cae'],
    "omanvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "omasa": ['cped'],
    "omasanta": ['cped'],
    "omasanā": ['cped'],
    "omasati": ['cped'],
    "omasavāda": ['cped'],
    "omasitvā": ['cped'],
    "omasiṁsu": ['cped'],
    "omaḥ": ['ap90'],
    "omaṭṭha": ['cped'],
    "omila": ['mw'],
    "omiāvat": ['gra'],
    "omkārīya": ['mw'],
    "omuddhaka": ['bhs', 'cped'],
    "omukka": ['cped'],
    "omuttayati": ['cped'],
    "omutteti": ['cped'],
    "omuñcapetvā": ['cped'],
    "omuñcati": ['cped'],
    "omuñcitvā": ['cped'],
    "omyā": ['ap90', 'cae', 'gra', 'mw'],
    "omyāvant": ['cae'],
    "omyāvat": ['gra', 'mw'],
    "omāna": ['cped'],
    "omāraka": ['bhs'],
    "omāti": ['cped'],
    "omātrā": ['ap90', 'cae', 'gra', 'mw'],
    "omūrdhaka": ['bhs'],
    "onaddha": ['cped'],
    "onahati": ['cped'],
    "onahinayāna": ['cped'],
    "onahiyāna": ['cped'],
    "onamana": ['cped'],
    "onamanā": ['bhs'],
    "onameti": ['cped'],
    "onandhati": ['cped'],
    "onandhitvā": ['cped'],
    "onata": ['cped'],
    "onatonata": ['cped'],
    "onayhati": ['cped'],
    "onojana": ['cped'],
    "onojeti": ['cped'],
    "onādeti": ['bhs'],
    "onāha": ['cped'],
    "onāmesi": ['cped'],
    "onāmeti": ['cped'],
    "onīta": ['cped'],
    "onītapattapāṇi": ['cped'],
    "onīyati": ['cped'],
    "opa": ['bhs'],
    "opabhogga": ['cped'],
    "opadhika": ['bhs', 'cped'],
    "opadru": ['mw'],
    "opakkamika": ['cped'],
    "opalambhika": ['bhs'],
    "opalipyate": ['bhs'],
    "opamma": ['cped'],
    "opanayika": ['cped'],
    "opapakkhi": ['cped'],
    "opapakkhiṅkaroti": ['cped'],
    "opapātika": ['cped'],
    "oparajja": ['cped'],
    "opasamika": ['cped'],
    "opasāyika": ['cped'],
    "opatitvā": ['cped'],
    "opavayha": ['cped'],
    "opavuyha": ['cped'],
    "opayati": ['cped'],
    "opaśa": ['cae', 'gra', 'mw'],
    "opaśaḥ": ['ap90'],
    "opaśin": ['mw'],
    "opeti": ['cped'],
    "ophunāti": ['cped'],
    "ophuta": ['cped'],
    "ophuṭa": ['cped'],
    "opilavati": ['cped'],
    "opilāpesi": ['cped'],
    "opilāpetabba": ['cped'],
    "opilāpeti": ['cped'],
    "opiya": ['cped'],
    "opunati": ['bhs'],
    "opuni": ['cped'],
    "opunāpetabba": ['cped'],
    "opunāpeti": ['cped'],
    "opunāpetvā": ['cped'],
    "opunāti": ['cped'],
    "opura": ['bhs'],
    "opuñchitvā": ['cped'],
    "opuñchāpetvā": ['cped'],
    "opuñjati": ['cped'],
    "opuñjitvā": ['cped'],
    "opuñjāpetvā": ['cped'],
    "opuṇāti": ['cped'],
    "opya": ['mw'],
    "opānabhūta": ['cped'],
    "opārambha": ['cped'],
    "opāsimbha": ['bhs'],
    "opāta": ['cped'],
    "opātetabba": ['cped'],
    "opāteti": ['cped'],
    "opāyika": ['cped'],
    "opāṭesi": ['cped'],
    "opāṭeti": ['cped'],
    "opāṭetvā": ['cped'],
    "ora": ['bhs', 'cped'],
    "orabbhika": ['cped'],
    "oraka": ['cped'],
    "oramatha": ['cped'],
    "oramati": ['cped'],
    "oramattaka": ['cped'],
    "orambhāgamanīya": ['cped'],
    "orambhāgiya": ['cped'],
    "oramgāmanīya": ['cped'],
    "orapāra": ['cped'],
    "orasa": ['bhs', 'cped'],
    "orasika": ['cped'],
    "orato": ['cped'],
    "oravati": ['bhs'],
    "oravita": ['cped'],
    "oravitar": ['cped'],
    "oraṁ": ['cped'],
    "oraṃphaḥ": ['ap90'],
    "orena": ['cped'],
    "orima": ['cped'],
    "orimikā": ['mw'],
    "orodha": ['cped'],
    "orodheti": ['cped'],
    "orohanta": ['cped'],
    "orohati": ['cped'],
    "orohitvā": ['cped'],
    "orohitvāna": ['cped'],
    "oropana": ['cped'],
    "oropanā": ['cped'],
    "oropayati": ['cped'],
    "oropayitvā": ['cped'],
    "oropaṇa": ['cped'],
    "oropenta": ['cped'],
    "oropesi": ['cped'],
    "oropesuṁ": ['cped'],
    "oropeti": ['cped'],
    "oropetvā": ['cped'],
    "oruddha": ['cped'],
    "oruddhati": ['cped'],
    "oruhati": ['cped'],
    "oruhitvā": ['cped'],
    "oruhitvāna": ['cped'],
    "orundhati": ['cped'],
    "orupta": ['bhs'],
    "oruyha": ['cped'],
    "oruḷha": ['cped'],
    "oruṇḍa": ['bhs'],
    "orāpayi": ['bhs'],
    "orāṭikā": ['bhs'],
    "orūpayati": ['bhs'],
    "orūḷha": ['cped'],
    "osa": ['bhs'],
    "osadha": ['cped'],
    "osadhī": ['cped'],
    "osadhītiṇavanappatayo": ['cped'],
    "osadhītiṇavanaspatayo": ['cped'],
    "osadhītārakā": ['cped'],
    "osajjati": ['cped'],
    "osajji": ['cped'],
    "osakkanta": ['cped'],
    "osakkati": ['bhs', 'cped'],
    "osakkita": ['cped'],
    "osanna": ['bhs'],
    "osaraka": ['cped'],
    "osarati": ['bhs', 'cped'],
    "osaraṇa": ['bhs', 'cped'],
    "osaritvā": ['cped'],
    "osaṇhetabba": ['cped'],
    "osaṇheti": ['cped'],
    "osaṭa": ['cped'],
    "oseti": ['cped'],
    "osirati": ['bhs'],
    "osiya": ['cped'],
    "osiñcanta": ['cped'],
    "osiñcati": ['cped'],
    "osiñceyya": ['cped'],
    "osiñci": ['cped'],
    "osiñcitabba": ['cped'],
    "osiñciṁsu": ['cped'],
    "osopana": ['bhs'],
    "osopati": ['bhs'],
    "ossajati": ['cped'],
    "ossaji": ['cped'],
    "ossajjati": ['cped'],
    "ossajji": ['cped'],
    "ossavana": ['cped'],
    "ossaṭṭha": ['cped'],
    "ossaṭṭhakāya": ['cped'],
    "ossāvana": ['cped'],
    "ostarati": ['bhs'],
    "ostāraka": ['bhs'],
    "osupta": ['bhs'],
    "osvāpana": ['bhs'],
    "osvāpita": ['bhs'],
    "osādayati": ['cped'],
    "osādeti": ['cped'],
    "osāna": ['cped'],
    "osāpayati": ['cped'],
    "osāpeti": ['cped'],
    "osāraka": ['cped'],
    "osārayati": ['cped'],
    "osāraṇa": ['cped'],
    "osāraṇā": ['bhs'],
    "osāraṇīya": ['bhs', 'cped'],
    "osārenta": ['cped'],
    "osāresi": ['cped'],
    "osāretabba": ['cped'],
    "osāreti": ['cped'],
    "osāretvā": ['cped'],
    "osārita": ['cped'],
    "osāriyati": ['cped'],
    "osīdati": ['cped'],
    "ota": ['ap90', 'cae', 'ddsa', 'mw'],
    "otalā": ['bhs'],
    "otalāyana": ['bhs'],
    "otalīya": ['bhs'],
    "otappati": ['cped'],
    "otaprota": ['mw'],
    "otaranta": ['cped'],
    "otarati": ['bhs', 'cped'],
    "otaraṇa": ['cped'],
    "otaritabba": ['cped'],
    "otaritvā": ['cped'],
    "otariṁ": ['cped'],
    "otata": ['cped'],
    "otavai": ['cae', 'mw'],
    "otave": ['cae', 'mw'],
    "otiṇṇa": ['cped'],
    "otkarika": ['bhs'],
    "otomasika": ['cped'],
    "otrapa": ['bhs'],
    "otsūryam": ['mw'],
    "ottapa": ['cped'],
    "ottapamāna": ['cped'],
    "ottapat": ['cped'],
    "ottapati": ['cped'],
    "ottappa": ['cped'],
    "ottappamāna": ['cped'],
    "ottappat": ['cped'],
    "ottappati": ['cped'],
    "ottappi": ['cped'],
    "ottappin": ['cped'],
    "ottappiya": ['cped'],
    "ottareṇa": ['bhs'],
    "ottharaka": ['cped'],
    "ottharati": ['cped'],
    "ottharika": ['cped'],
    "ottharitvā": ['cped'],
    "ottharāpetvā": ['cped'],
    "ottharīyati": ['cped'],
    "otthata": ['cped'],
    "otthaṭa": ['cped'],
    "ottānaka": ['bhs'],
    "ottāpa": ['cped'],
    "ottāpi": ['cped'],
    "ottāpin": ['cped'],
    "otu": ['cae', 'ddsa', 'gra', 'mw'],
    "otum": ['cae'],
    "otuḥ": ['ap90'],
    "otāpayamāna": ['cped'],
    "otāpayati": ['cped'],
    "otāpenta": ['cped'],
    "otāpetabba": ['cped'],
    "otāpeti": ['cped'],
    "otāpetvā": ['cped'],
    "otāra": ['cped'],
    "otārayati": ['cped'],
    "otārayitabba": ['cped'],
    "otāretabba": ['cped'],
    "otāreti": ['cped'],
    "otāriyamāna": ['cped'],
    "otārāpekkha": ['cped'],
    "ovada": ['cped'],
    "ovadanta": ['cped'],
    "ovadat": ['cped'],
    "ovadati": ['bhs', 'cped'],
    "ovaddheyya": ['cped'],
    "ovadeti": ['cped'],
    "ovadita": ['cped'],
    "ovaditabba": ['cped'],
    "ovaditvā": ['cped'],
    "ovadiya": ['cped'],
    "ovadiyamāna": ['cped'],
    "ovadiṁsu": ['cped'],
    "ovadī": ['cped'],
    "ovamitvā": ['cped'],
    "ovaraka": ['cped'],
    "ovaraṇa": ['cped'],
    "ovarenta": ['cped'],
    "ovariyāna": ['cped'],
    "ovassate": ['cped'],
    "ovassati": ['cped'],
    "ovassāpenta": ['cped'],
    "ovassāpeti": ['cped'],
    "ovassāyati": ['cped'],
    "ovaṭa": ['cped'],
    "ovaṭṭa": ['cped'],
    "ovaṭṭha": ['cped'],
    "ovaṭṭika": ['cped'],
    "ovaṭṭikā": ['bhs', 'cped'],
    "ovaṭṭiya": ['cped'],
    "ovidhyanakhā": ['bhs'],
    "ovilī": ['mw'],
    "ovuta": ['cped'],
    "ovuyhati": ['cped'],
    "ovuṭa": ['cped'],
    "ovuṭṭha": ['cped'],
    "ovā": ['mw'],
    "ovācu": ['bhs'],
    "ovāda": ['cped'],
    "ovādaka": ['cped'],
    "ovādakara": ['cped'],
    "ovādaṭhapita": ['cped'],
    "ovādikā": ['cped'],
    "ovādita": ['cped'],
    "ovāyati": ['bhs'],
    "ovṛṣṭa": ['bhs'],
    "oyācati": ['cped'],
    "oññāta": ['cped'],
    "oñāta": ['cped'],
    "ośaṭuka": ['bhs'],
    "ośirati": ['bhs'],
    "ośākha": ['bhs'],
    "oḍa": ['cae', 'ddsa', 'mw'],
    "oḍaka": ['ap90'],
    "oḍava": ['mw'],
    "oḍha": ['cae', 'ddsa', 'mw'],
    "oḍigalla": ['bhs'],
    "oḍikā": ['mw'],
    "oḍikāḥ": ['ap90'],
    "oḍiyāna": ['bhs'],
    "oḍra": ['cae', 'ddsa', 'mw'],
    "oḍradeśa": ['mw'],
    "oḍrapuṣpa": ['bhs', 'mw'],
    "oḍraḥ": ['ap90'],
    "oḍrākhyā": ['mw'],
    "oḍḍayati": ['cped'],
    "oḍḍeti": ['bhs', 'cped'],
    "oḍḍetvā": ['cped'],
    "oḍḍi": ['cped'],
    "oḍḍita": ['cped'],
    "oḍḍiya": ['cped'],
    "oḍḍiyāna": ['bhs'],
    "oḷigalla": ['cped'],
    "oḷārika": ['cped'],
    "oṃkāra": ['cae', 'mw'],
    "oṃkārabhaṭṭa": ['mw'],
    "oṃkāragrantha": ['mw'],
    "oṃkārapīṭha": ['mw'],
    "oṃkāratīrtha": ['mw'],
    "oṃkāraḥ": ['ap90'],
    "oṃkārā": ['mw'],
    "oṃkṛta": ['mw'],
    "oṅkāra": ['ddsa'],
    "oṇ": ['ap90', 'mw'],
    "oṇamana": ['cped'],
    "oṇata": ['cped'],
    "oṇatoṇata": ['cped'],
    "oṇi": ['ap90', 'cae', 'gra', 'mw'],
    "oṇirakkha": ['cped'],
    "oṇojana": ['cped'],
    "oṇojesi": ['cped'],
    "oṇojesiṁ": ['cped'],
    "oṇojeti": ['cped'],
    "oṇīta": ['cped'],
    "oṇḍra": ['cae', 'mw'],
    "oṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "oṣadha": ['bhs'],
    "oṣadhi": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "oṣadhigarbha": ['mw'],
    "oṣadhihoma": ['mw'],
    "oṣadhija": ['mw'],
    "oṣadhiloka": ['mw'],
    "oṣadhināmāvalī": ['mw'],
    "oṣadhipati": ['cae', 'mw'],
    "oṣadhiprastha": ['mw'],
    "oṣadhirāja": ['bhs'],
    "oṣadhivallabha": ['mw'],
    "oṣadhivanaspati": ['mw'],
    "oṣadhiḥ": ['ap90'],
    "oṣadhyanuvāka": ['mw'],
    "oṣadhī": ['cae', 'gra', 'mw'],
    "oṣadhīmant": ['cae'],
    "oṣadhīmat": ['mw'],
    "oṣadhīpati": ['mw'],
    "oṣadhīsaṃśita": ['mw'],
    "oṣadhīsūkta": ['mw'],
    "oṣadhītvara": ['mw'],
    "oṣadhīśa": ['mw'],
    "oṣadāvan": ['mw'],
    "oṣam": ['cae', 'ddsa', 'mw'],
    "oṣarati": ['bhs'],
    "oṣas": ['gra'],
    "oṣaḥ": ['ap90'],
    "oṣaṃ": ['ap90'],
    "oṣaṇa": ['mw'],
    "oṣaṇaḥ": ['ap90'],
    "oṣaṇī": ['mw'],
    "oṣita": ['bhs'],
    "oṣiṣṭha": ['mw'],
    "oṣiṣṭhadāvan": ['mw'],
    "oṣiṣṭhahan": ['mw'],
    "oṣṇa": ['ap90', 'mw'],
    "oṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "oṣṭhaja": ['mw'],
    "oṣṭhajāha": ['mw'],
    "oṣṭhaka": ['ap90', 'mw'],
    "oṣṭhakarṇaka": ['mw'],
    "oṣṭhakopa": ['mw'],
    "oṣṭhamudrā": ['mw'],
    "oṣṭhapallava": ['mw'],
    "oṣṭhaphalā": ['mw'],
    "oṣṭhaprakopa": ['mw'],
    "oṣṭhapuṭa": ['mw'],
    "oṣṭharoga": ['mw'],
    "oṣṭharucaka": ['ddsa', 'mw'],
    "oṣṭhaya": ['cae'],
    "oṣṭhaśataka": ['mw'],
    "oṣṭhaḥ": ['ap90'],
    "oṣṭhopamaphalā": ['mw'],
    "oṣṭhya": ['ap90', 'ddsa', 'mw'],
    "oṣṭhyasthāna": ['mw'],
    "oṣṭhyayoni": ['mw'],
    "oṣṭhādhara": ['mw'],
    "oṣṭhāpidhāna": ['mw'],
    "oṣṭhī": ['mw'],
    "oṣṭrāvin": ['ap90'],
    "oṣṭṛ": ['mw'],
    "oṭṭha": ['cped'],
    "oṭṭhanillehakaṁ": ['cped'],
    "oṭṭhavacittaka": ['cped'],
    "oṭṭhubhati": ['cped'],
    "pa": ['ap90', 'cae', 'ddsa', 'mw'],
    "pabala": ['cped'],
    "pabandha": ['cped'],
    "pabba": ['cped'],
    "pabbajana": ['cped'],
    "pabbajanta": ['cped'],
    "pabbajati": ['cped'],
    "pabbaji": ['cped'],
    "pabbajita": ['cped'],
    "pabbajitvā": ['cped'],
    "pabbajjā": ['cped'],
    "pabbakūṭa": ['cped'],
    "pabbata": ['cped'],
    "pabbatagahana": ['cped'],
    "pabbatakūṭa": ['cped'],
    "pabbatapāda": ['cped'],
    "pabbatasikhara": ['cped'],
    "pabbataṭṭha": ['cped'],
    "pabbateyya": ['cped'],
    "pabbeka": ['mw'],
    "pabbhāra": ['cped'],
    "pabbājana": ['cped'],
    "pabbājaniya": ['cped'],
    "pabhagga": ['cped'],
    "pabhassara": ['cped'],
    "pabhava": ['cped'],
    "pabhavati": ['cped'],
    "pabhavi": ['cped'],
    "pabhavita": ['cped'],
    "pabhavitvā": ['cped'],
    "pabhaṅgu": ['cped'],
    "pabhaṅgura": ['cped'],
    "pabhaṅkara": ['cped'],
    "pabheda": ['cped'],
    "pabhedana": ['cped'],
    "pabhijjamāna": ['cped'],
    "pabhijjana": ['cped'],
    "pabhijjati": ['cped'],
    "pabhijji": ['cped'],
    "pabhijjitvā": ['cped'],
    "pabhinna": ['cped'],
    "pabhuti": ['cped'],
    "pabhutika": ['cped'],
    "pabhā": ['cped'],
    "pabhāsa": ['cped'],
    "pabhāsanta": ['cped'],
    "pabhāsati": ['cped'],
    "pabhāsenta": ['cped'],
    "pabhāsesi": ['cped'],
    "pabhāseti": ['cped'],
    "pabhāsetvā": ['cped'],
    "pabhāsi": ['cped'],
    "pabhāsita": ['cped'],
    "pabhāsitvā": ['cped'],
    "pabhāta": ['cped'],
    "pabhāva": ['cped'],
    "pabhāvesi": ['cped'],
    "pabhāveti": ['cped'],
    "pabhāvetvā": ['cped'],
    "pabhāvita": ['cped'],
    "pabhū": ['cped'],
    "pabodhana": ['cped'],
    "pabodhentā": ['cped'],
    "pabodhesi": ['cped'],
    "pabodheti": ['cped'],
    "pabodhetvā": ['cped'],
    "pabodhita": ['cped'],
    "pabuddha": ['cped'],
    "pabujjhati": ['cped'],
    "pabujjhi": ['cped'],
    "pabujjhitvā": ['cped'],
    "pabājesi": ['cped'],
    "pabājeti": ['cped'],
    "pabājetvā": ['cped'],
    "pabājita": ['cped'],
    "pac": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "paca": ['ap90', 'cae', 'ddsa', 'mw'],
    "pacaka": ['mw'],
    "pacakaḥ": ['ap90'],
    "pacalavaṇā": ['mw'],
    "pacalāyati": ['cped'],
    "pacalāyi": ['cped'],
    "pacalāyikā": ['cped'],
    "pacampacā": ['mw'],
    "pacamānaka": ['mw'],
    "pacana": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "pacanakriyā": ['mw'],
    "pacanikā": ['bhs', 'mw'],
    "pacanta": ['cped'],
    "pacanā": ['mw'],
    "pacanāgni": ['mw'],
    "pacanāgāra": ['mw'],
    "pacanī": ['mw'],
    "pacapaca": ['mw'],
    "pacapacaḥ": ['ap90'],
    "pacaprakūṭā": ['mw'],
    "pacarati": ['cped'],
    "pacari": ['cped'],
    "pacat": ['mw'],
    "pacata": ['ap90', 'cae', 'gra', 'mw'],
    "pacatabhṛjjatā": ['mw'],
    "pacati": ['cped'],
    "pacatia": ['gra'],
    "pacatikalpam": ['mw'],
    "pacatpuṭa": ['mw'],
    "pacatra": ['mw'],
    "pacatya": ['gra', 'mw'],
    "paccabhavi": ['cped'],
    "paccabhavitvā": ['cped'],
    "paccaggha": ['cped'],
    "paccajāta": ['cped'],
    "paccakkha": ['cped'],
    "paccakkhakamma": ['cped'],
    "paccakkhāna": ['cped'],
    "paccakkhāsi": ['cped'],
    "paccakkhāta": ['cped'],
    "paccakkhāti": ['cped'],
    "paccakkhāya": ['cped'],
    "paccakkosati": ['cped'],
    "paccakkosi": ['cped'],
    "paccamāna": ['cped'],
    "paccana": ['cped'],
    "paccanika": ['cped'],
    "paccanikā": ['mw'],
    "paccanta": ['cped'],
    "paccantadesa": ['cped'],
    "paccantavisaya": ['cped'],
    "paccantavāsī": ['cped'],
    "paccantima": ['cped'],
    "paccanubhavati": ['cped'],
    "paccanubhavi": ['cped'],
    "paccanubhavitvā": ['cped'],
    "paccanubhoti": ['cped'],
    "paccanubhūta": ['cped'],
    "paccanī": ['mw'],
    "paccassosi": ['cped'],
    "paccate": ['bhs'],
    "paccati": ['cped'],
    "paccatta": ['cped'],
    "paccattaṁ": ['cped'],
    "paccattharaṇa": ['cped'],
    "paccatthika": ['cped'],
    "paccatā": ['cped'],
    "paccavekkhana": ['cped'],
    "paccavekkhanā": ['cped'],
    "paccavekkhati": ['cped'],
    "paccavekkhi": ['cped'],
    "paccavekkhita": ['cped'],
    "paccavekkhitvā": ['cped'],
    "paccavekkhiya": ['cped'],
    "paccaya": ['cped'],
    "paccayatā": ['cped'],
    "paccayika": ['cped'],
    "paccayuppanna": ['cped'],
    "paccayākāra": ['cped'],
    "paccaṅga": ['cped'],
    "pacceka": ['cped'],
    "paccekabuddha": ['cped'],
    "paccekaṁ": ['cped'],
    "paccesi": ['cped'],
    "pacceti": ['cped'],
    "pacchabda": ['mw'],
    "pacchanna": ['cped'],
    "pacchas": ['cae', 'ddsa', 'mw'],
    "pacchato": ['cped'],
    "pacchauca": ['cae', 'mw'],
    "pacchaḥśasya": ['mw'],
    "pacchedana": ['cped'],
    "pacchi": ['cped'],
    "pacchijjana": ['cped'],
    "pacchijjati": ['cped'],
    "pacchijji": ['cped'],
    "pacchijjitvā": ['cped'],
    "pacchima": ['cped'],
    "pacchimaka": ['bhs', 'cped'],
    "pacchimo kālo": ['cped'],
    "pacchindati": ['cped'],
    "pacchindi": ['cped'],
    "pacchinditvā": ['cped'],
    "pacchinna": ['cped'],
    "pacchā": ['bhs', 'cped'],
    "pacchābhattaṁ": ['cped'],
    "pacchābhāga": ['cped'],
    "pacchābāhaṁ": ['cped'],
    "pacchāda": ['cped'],
    "pacchājāta": ['cped'],
    "pacchānipātī": ['cped'],
    "pacchānutappati": ['cped'],
    "pacchānutappi": ['cped'],
    "pacchānutāpa": ['cped'],
    "pacchāsamaṇa": ['cped'],
    "pacchāyā": ['cped'],
    "pacci": ['cped'],
    "paccitvā": ['cped'],
    "paccorohati": ['cped'],
    "paccorohi": ['cped'],
    "paccorohitvā": ['cped'],
    "paccoruyha": ['cped'],
    "paccorūḷha": ['cped'],
    "paccosakkanā": ['cped'],
    "paccosakkati": ['cped'],
    "paccosakki": ['cped'],
    "paccosakkita": ['cped'],
    "paccosakkitvā": ['cped'],
    "paccuggacchati": ['cped'],
    "paccuggamana": ['cped'],
    "paccuggantvā": ['cped'],
    "paccupakāra": ['cped'],
    "paccupaṭthitvā": ['cped'],
    "paccupaṭṭhita": ['cped'],
    "paccupaṭṭhāna": ['cped'],
    "paccupaṭṭhāpeti": ['cped'],
    "paccupaṭṭhāsi": ['cped'],
    "paccupaṭṭhāti": ['cped'],
    "paccuppanna": ['cped'],
    "paccuṭṭhita": ['cped'],
    "paccuṭṭhitvā": ['cped'],
    "paccuṭṭhāna": ['cped'],
    "paccuṭṭhānaka": ['cped'],
    "paccuṭṭhāsi": ['cped'],
    "paccuṭṭhāti": ['cped'],
    "paccāgacchati": ['cped'],
    "paccāgacchi": ['cped'],
    "paccāgamana": ['cped'],
    "paccāgantvā": ['cped'],
    "paccāgata": ['cped'],
    "paccāharati": ['cped'],
    "paccāhari": ['cped'],
    "paccāharitvā": ['cped'],
    "paccāhata": ['cped'],
    "paccāhāra": ['cped'],
    "paccājāyati": ['cped'],
    "paccājāyi": ['cped'],
    "paccājāyitvā": ['cped'],
    "paccākata": ['cped'],
    "paccākoṭita": ['cped'],
    "paccāmitta": ['cped'],
    "paccāsiṁsati": ['cped'],
    "paccāsiṁsi": ['cped'],
    "paccāsiṁsita": ['cped'],
    "paccūsa": ['cped'],
    "paccūsakāla": ['cped'],
    "pacelima": ['ap90', 'cae', 'ddsa', 'mw'],
    "paceluka": ['mw'],
    "pacelukaḥ": ['ap90'],
    "paci": ['cped', 'mw'],
    "pacinanta": ['cped'],
    "pacini": ['cped'],
    "pacināti": ['cped'],
    "pacita": ['cped'],
    "pacitabba": ['cped'],
    "pacitvā": ['cped'],
    "paciḥ": ['ap90'],
    "pacura": ['cped'],
    "pacya": ['mw'],
    "pacyate": ['bhs'],
    "pacā": ['ap90'],
    "pacālaka": ['cped'],
    "pacāpesi": ['cped'],
    "pacāpeti": ['cped'],
    "pacāpetvā": ['cped'],
    "pacāraka": ['cped'],
    "pacāresi": ['cped'],
    "pacāreti": ['cped'],
    "pacāretvā": ['cped'],
    "pacārita": ['cped'],
    "pad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pada": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "padabandha": ['bhs', 'cae', 'mw'],
    "padabhañjana": ['mw'],
    "padabhañjikā": ['mw'],
    "padabhraṃśa": ['mw'],
    "padabhājana": ['cped'],
    "padabhāvārthacandrikā": ['mw'],
    "padabhāṇaka": ['cped'],
    "padacandrikā": ['mw'],
    "padacaturūrdhva": ['mw'],
    "padaccheda": ['mw'],
    "padacetiya": ['cped'],
    "padacihna": ['mw'],
    "padacyuta": ['mw'],
    "padadevatā": ['mw'],
    "padadyotinī": ['mw'],
    "padadārḍhya": ['mw'],
    "padadīpikā": ['mw'],
    "padaga": ['mw'],
    "padagata": ['mw'],
    "padagati": ['cae', 'mw'],
    "padaghātam": ['mw'],
    "padagotra": ['mw'],
    "padagāḍha": ['mw'],
    "padahana": ['cped'],
    "padahati": ['cped'],
    "padahi": ['cped'],
    "padahita": ['cped', 'mw'],
    "padahitvā": ['cped'],
    "padaikadeśa": ['mw'],
    "padajyotis": ['mw'],
    "padajñā": ['cae', 'gra', 'mw'],
    "padajāta": ['cped', 'mw'],
    "padaka": ['bhs', 'ddsa', 'mw'],
    "padakamala": ['mw'],
    "padakaumudī": ['mw'],
    "padakaṃ": ['ap90'],
    "padakkhiṇā": ['cped'],
    "padakrama": ['bhs', 'mw'],
    "padakramaka": ['mw'],
    "padakramalakṣaṇa": ['mw'],
    "padakramavid": ['mw'],
    "padakāla": ['mw'],
    "padakāra": ['mw'],
    "padakārikāratnamālā": ['mw'],
    "padakṛt": ['mw'],
    "padakṛtya": ['mw'],
    "padamañjarī": ['mw'],
    "padamālā": ['mw'],
    "padana": ['mw'],
    "padanidhana": ['mw'],
    "padanuṣaṅga": ['mw'],
    "padanyāsa": ['cae', 'mw'],
    "padanī": ['cae', 'mw'],
    "padanīya": ['cae', 'mw'],
    "padanīyatva": ['mw'],
    "padapaddhati": ['cae', 'mw'],
    "padapadma": ['mw'],
    "padaparama": ['bhs'],
    "padapañcaka": ['mw'],
    "padapaṅkaja": ['mw'],
    "padapaṅkti": ['cae', 'mw'],
    "padapāta": ['mw'],
    "padapāṭha": ['cae', 'mw'],
    "padapūraṇa": ['cae', 'cped', 'mw'],
    "padara": ['cped'],
    "padaracanā": ['cae', 'mw'],
    "padaratnāvalī": ['mw'],
    "padasadda": ['cped'],
    "padasadhātu": ['mw'],
    "padasamaya": ['mw'],
    "padasamūha": ['mw'],
    "padasandhi": ['ddsa'],
    "padasaṃdarbha": ['mw'],
    "padasaṃdhi": ['mw'],
    "padasaṃdhāna": ['mw'],
    "padasaṃghāta": ['mw'],
    "padasaṃghāṭa": ['mw'],
    "padasaṃhitā": ['mw'],
    "padasaṃtāna": ['mw'],
    "padastha": ['cae', 'mw'],
    "padasthita": ['mw'],
    "padasthāna": ['mw'],
    "padastobha": ['mw'],
    "padasā": ['bhs'],
    "padatta": ['cped'],
    "padatva": ['mw'],
    "padatvarā": ['mw'],
    "padatā": ['mw'],
    "padavalañja": ['cped'],
    "padavaṇṇanā": ['cped'],
    "padavedin": ['mw'],
    "padavi": ['mw'],
    "padavibhāga": ['cped'],
    "padaviccheda": ['mw'],
    "padavid": ['mw'],
    "padavigraha": ['mw'],
    "padavikṣepa": ['mw'],
    "padavirāma": ['mw'],
    "padaviḥ": ['ap90'],
    "padaviṣṭambha": ['mw'],
    "padavyākhyāna": ['mw'],
    "padavādya": ['mw'],
    "padavākyaratnākara": ['mw'],
    "padavākyaratnākarakārikāsaṃgraha": ['mw'],
    "padavākyārthapañjikā": ['mw'],
    "padavāmīka": ['mw'],
    "padavāya": ['mw'],
    "padavī": ['cae', 'ddsa', 'gra', 'mw'],
    "padavītihāra": ['cped'],
    "padavīya": ['cae', 'gra', 'mw'],
    "padavṛtti": ['ddsa', 'mw'],
    "padayojana": ['mw'],
    "padayojanikā": ['mw'],
    "padayojanā": ['mw'],
    "padayopana": ['mw'],
    "padaśabda": ['cae', 'mw'],
    "padaśas": ['bhs', 'cae', 'ddsa', 'mw'],
    "padaśreṇi": ['cae', 'mw'],
    "padaśāstra": ['ddsa', 'mw'],
    "padaṃ": ['ap90'],
    "padaṣṭhīva": ['mw'],
    "padaṭṭhāna": ['cped'],
    "paddhati": ['cae', 'ddsa', 'mw'],
    "paddhatibhūṣaṇa": ['mw'],
    "paddhaticandrikā": ['mw'],
    "paddhaticintāmaṇi": ['mw'],
    "paddhatiprakāśa": ['mw'],
    "paddhatiprakāśikā": ['mw'],
    "paddhatiratna": ['mw'],
    "paddhatisāra": ['mw'],
    "paddhaḍī": ['mw'],
    "paddhima": ['mw'],
    "padeka": ['bhs', 'mw'],
    "padekaḥ": ['ap90'],
    "padesa": ['cped'],
    "padesarajja": ['cped'],
    "padesarāja": ['cped'],
    "padesañāṇa": ['cped'],
    "padga": ['ap90', 'mw'],
    "padghoṣa": ['mw'],
    "padhaṁsa": ['cped'],
    "padhaṁsana": ['cped'],
    "padhaṁsenta": ['cped'],
    "padhaṁsesi": ['cped'],
    "padhaṁseti": ['cped'],
    "padhaṁsetvā": ['cped'],
    "padhaṁsita": ['cped'],
    "padhaṁsiya": ['cped'],
    "padhota": ['cped'],
    "padhāna": ['cped'],
    "padhānaghara": ['cped'],
    "padhānika": ['cped'],
    "padhāvana": ['cped'],
    "padhāvati": ['cped'],
    "padhāvi": ['cped'],
    "padhūpeti": ['cped'],
    "padhūpita": ['cped'],
    "padi": ['gra', 'mw'],
    "padibaddha": ['mw'],
    "padika": ['ap90', 'cped', 'mw'],
    "padikā": ['mw'],
    "padinna": ['cped'],
    "padippamāna": ['cped'],
    "padippati": ['cped'],
    "padippi": ['cped'],
    "padira": ['mw'],
    "padissamāna": ['cped'],
    "padissati": ['cped'],
    "padissi": ['cped'],
    "paditta": ['cped'],
    "padiā": ['gra'],
    "padiḥ": ['ap90'],
    "padiṭṭha": ['cped'],
    "padma": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "padmabandha": ['mw'],
    "padmabandhu": ['mw'],
    "padmabandhukula": ['mw'],
    "padmabhadrābhirāmanetraśrī": ['bhs'],
    "padmabhava": ['cae', 'mw'],
    "padmabhāśa": ['mw'],
    "padmabhū": ['cae', 'mw'],
    "padmabimbyupaśobhita": ['bhs'],
    "padmabīja": ['mw'],
    "padmabījābha": ['mw'],
    "padmacaraṇa": ['mw'],
    "padmacāriṇī": ['mw'],
    "padmadalekṣaṇa": ['cae', 'mw'],
    "padmadarśana": ['mw'],
    "padmadhara": ['mw'],
    "padmadhṛk": ['bhs'],
    "padmagandha": ['mw'],
    "padmagandhi": ['mw'],
    "padmagarbha": ['bhs', 'cae', 'mw'],
    "padmagarbhaśrī": ['bhs'],
    "padmagiripurāṇa": ['mw'],
    "padmagupta": ['mw'],
    "padmagṛhā": ['cae', 'mw'],
    "padmahasta": ['bhs', 'mw'],
    "padmahemamaṇi": ['mw'],
    "padmahāsa": ['mw'],
    "padmaja": ['cae', 'mw'],
    "padmajātaka": ['mw'],
    "padmajāti": ['mw'],
    "padmaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "padmakalikā": ['mw'],
    "padmakalyāṇakhaṇḍa": ['mw'],
    "padmakandāda": ['mw'],
    "padmakara": ['mw'],
    "padmakarkaṭī": ['mw'],
    "padmakarā": ['mw'],
    "padmakarṇika": ['mw'],
    "padmakarṇikā": ['mw'],
    "padmakaṃ": ['ap90'],
    "padmakesara": ['mw'],
    "padmaketana": ['mw'],
    "padmaketu": ['mw'],
    "padmakhaṇḍa": ['mw'],
    "padmakhaṇḍanagara": ['mw'],
    "padmakin": ['ap90', 'mw'],
    "padmakośa": ['mw'],
    "padmakośajātaka": ['mw'],
    "padmakośāya": ['mw'],
    "padmakośīkṛ": ['mw'],
    "padmakuṇḍa": ['mw'],
    "padmakā": ['bhs'],
    "padmakāṣṭha": ['mw'],
    "padmakīṭa": ['mw'],
    "padmakūṭa": ['mw'],
    "padmakūṭāgāra": ['bhs'],
    "padmakṣetra": ['mw'],
    "padmalekhā": ['mw'],
    "padmalocana": ['mw'],
    "padmalāñchana": ['mw'],
    "padmalāñchanā": ['mw'],
    "padmalīlāvilāsinī": ['mw'],
    "padmamaya": ['cae', 'mw'],
    "padmamihira": ['mw'],
    "padmamukhī": ['mw'],
    "padmamāla": ['bhs'],
    "padmamālin": ['mw'],
    "padmamālinī": ['mw'],
    "padmamūla": ['mw'],
    "padmanandi": ['mw'],
    "padmanandin": ['mw'],
    "padmanarteśvara": ['bhs'],
    "padmanetra": ['bhs', 'mw'],
    "padmanibhekṣaṇa": ['mw'],
    "padmanidhi": ['mw'],
    "padmanimīlana": ['mw'],
    "padmanābha": ['cae', 'mw'],
    "padmanābhabīja": ['mw'],
    "padmanābhadvadaśī": ['mw'],
    "padmanābhi": ['mw'],
    "padmanāla": ['mw'],
    "padmapada": ['mw'],
    "padmaparṇa": ['mw'],
    "padmapattra": ['mw'],
    "padmapattranibhekṣaṇa": ['mw'],
    "padmapaṇḍita": ['mw'],
    "padmaprabha": ['bhs', 'mw'],
    "padmaprabhu": ['mw'],
    "padmaprabhā": ['bhs', 'mw'],
    "padmapriyā": ['mw'],
    "padmapura": ['ap90', 'cae', 'mw'],
    "padmapurāṇa": ['cae', 'mw'],
    "padmapuṣpa": ['mw'],
    "padmapuṣpāñjalistotra": ['mw'],
    "padmapāda": ['mw'],
    "padmapādarahasya": ['mw'],
    "padmapādācārya": ['mw'],
    "padmapāṇi": ['cae', 'mw'],
    "padmarajavarṇa": ['bhs'],
    "padmaratha": ['mw'],
    "padmarati": ['cae', 'mw'],
    "padmaratna": ['mw'],
    "padmarekhā": ['mw'],
    "padmarāga": ['cae', 'mw'],
    "padmarāgamaya": ['mw'],
    "padmarāgī": ['mw'],
    "padmarāja": ['mw'],
    "padmarūpa": ['mw'],
    "padmarūpā": ['mw'],
    "padmasadman": ['mw'],
    "padmasambhava": ['mw'],
    "padmasamāsana": ['mw'],
    "padmasaras": ['cae', 'mw'],
    "padmasaugandhika": ['mw'],
    "padmasaugandhikavat": ['mw'],
    "padmasaṃbhava": ['cae'],
    "padmasaṃhitā": ['mw'],
    "padmasaṃkāśa": ['mw'],
    "padmasena": ['mw'],
    "padmasenā": ['mw'],
    "padmasnuṣā": ['mw'],
    "padmasundara": ['mw'],
    "padmasvastika": ['mw'],
    "padmasvāmin": ['mw'],
    "padmasūtra": ['mw'],
    "padmatantu": ['mw'],
    "padmatā": ['cae', 'mw'],
    "padmavajrī": ['bhs'],
    "padmavana": ['bhs'],
    "padmavanabāndhava": ['mw'],
    "padmavanabāndhavavaṃśa": ['mw'],
    "padmavant": ['cae'],
    "padmavara": ['bhs'],
    "padmavarcas": ['cae', 'mw'],
    "padmavardhana": ['bhs'],
    "padmavarṇa": ['cae', 'mw'],
    "padmavarṇaka": ['mw'],
    "padmavat": ['mw'],
    "padmavatī": ['mw'],
    "padmaveṣa": ['mw'],
    "padmaviṣaya": ['mw'],
    "padmavyākośa": ['cae', 'mw'],
    "padmavyūha": ['mw'],
    "padmavyūhā": ['bhs'],
    "padmavāhinī": ['mw'],
    "padmavāsinī": ['bhs'],
    "padmavāsā": ['mw'],
    "padmavṛkṣa": ['mw'],
    "padmavṛṣabhavikrāmin": ['bhs', 'mw'],
    "padmayoni": ['bhs', 'cae', 'mw'],
    "padmaśas": ['cae', 'mw'],
    "padmaśekhara": ['mw'],
    "padmaśrī": ['bhs', 'mw'],
    "padmaśrīgarbha": ['bhs', 'mw'],
    "padmaśrīgarbhasaṃbhavā": ['bhs'],
    "padmaśāyinī": ['mw'],
    "padmaḍākinī": ['bhs'],
    "padmaṣaṇḍa": ['cae', 'mw'],
    "padmeśaya": ['mw'],
    "padmeśayaḥ": ['ap90'],
    "padmin": ['ap90', 'cae', 'ddsa', 'mw'],
    "padminī": ['ap90', 'mw'],
    "padminīkaṇṭaka": ['mw'],
    "padminīkhaṇḍa": ['cae', 'mw'],
    "padminīkānta": ['mw'],
    "padminīpattra": ['cae', 'mw'],
    "padminīvallabha": ['mw'],
    "padminīśa": ['mw'],
    "padminīṣaṇḍa": ['mw'],
    "padminīṣaṇḍapura": ['mw'],
    "padmiṣṭhā": ['ddsa', 'mw'],
    "padmoccā": ['bhs'],
    "padmodbhava": ['cae', 'ddsa', 'mw'],
    "padmodbhavaprādurbhāva": ['mw'],
    "padmodbhavā": ['mw'],
    "padmodgata": ['bhs'],
    "padmopaniṣad": ['mw'],
    "padmopaniṣaddīpikā": ['mw'],
    "padmotpalakumudvat": ['mw'],
    "padmottama": ['bhs', 'mw'],
    "padmottara": ['bhs', 'mw'],
    "padmottaraśrī": ['bhs'],
    "padmottarikāśāka": ['mw'],
    "padmottarātmaja": ['mw'],
    "padmoṣṇīṣa": ['bhs'],
    "padmā": ['bhs', 'mw'],
    "padmābha": ['bhs'],
    "padmācala": ['mw'],
    "padmācārya": ['mw'],
    "padmādhīśa": ['mw'],
    "padmādi": ['mw'],
    "padmāditva": ['cae', 'mw'],
    "padmāhvaya": ['mw'],
    "padmāhvā": ['mw'],
    "padmākara": ['cae', 'ddsa', 'mw'],
    "padmākarabhaṭṭa": ['mw'],
    "padmākaradeva": ['mw'],
    "padmākaramati": ['bhs'],
    "padmākāra": ['mw'],
    "padmākṣa": ['bhs', 'cae', 'mw'],
    "padmālaya": ['cae', 'mw'],
    "padmālayā": ['mw'],
    "padmālaṃkārā": ['bhs', 'mw'],
    "padmānanda": ['mw'],
    "padmānandaśataka": ['mw'],
    "padmāntaka": ['bhs'],
    "padmāntara": ['mw'],
    "padmāsana": ['cae', 'ddsa', 'mw'],
    "padmāsanatā": ['mw'],
    "padmāsanā": ['mw'],
    "padmāvabhāsa": ['mw'],
    "padmāvali": ['mw'],
    "padmāvata": ['mw'],
    "padmāvatī": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "padmāvatīkalpa": ['mw'],
    "padmāvatīpañcāṅga": ['mw'],
    "padmāvatīpriya": ['mw'],
    "padmāvatīstotra": ['mw'],
    "padmāya": ['mw'],
    "padmāṅghri": ['mw'],
    "padmāṅkamudrā": ['bhs', 'mw'],
    "padmāṭa": ['mw'],
    "padoccaya": ['mw'],
    "padopahata": ['mw'],
    "padopasaṃgrahaṇa": ['mw'],
    "padosa": ['cped'],
    "padra": ['cae', 'mw'],
    "padratha": ['mw'],
    "padraḥ": ['ap90'],
    "padubbhati": ['cped'],
    "padubbhi": ['cped'],
    "padubbhita": ['cped'],
    "padubbhitvā": ['cped'],
    "paduka": ['mw'],
    "paduma": ['bhs', 'cped', 'mw'],
    "padumagabbha": ['cped'],
    "padumakalāpa": ['cped'],
    "padumakaṇṇikā": ['cped'],
    "padumapatta": ['cped'],
    "padumarāga": ['cped'],
    "padumasara": ['cped'],
    "paduminī": ['cped'],
    "paduminīpatta": ['cped'],
    "padumuttara": ['bhs'],
    "padumī": ['cped'],
    "padussana": ['cped'],
    "padussati": ['cped'],
    "padussi": ['cped'],
    "padussitvā": ['cped'],
    "paduṭṭha": ['cped'],
    "padva": ['ddsa', 'mw'],
    "padvan": ['ap90', 'mw'],
    "padvant": ['cae'],
    "padvat": ['ddsa', 'gra', 'mw'],
    "padvaḥ": ['ap90'],
    "padya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "padyakādambarī": ['mw'],
    "padyamaya": ['cae', 'mw'],
    "padyamuktāvalī": ['mw'],
    "padyamālā": ['mw'],
    "padyamātrikā": ['mw'],
    "padyapañjāśikā": ['mw'],
    "padyaprasūnāñjali": ['mw'],
    "padyaracanā": ['mw'],
    "padyasaṃgraha": ['mw'],
    "padyatrayīvyākhyāna": ['mw'],
    "padyaveṇī": ['mw'],
    "padyaśataka": ['mw'],
    "padyā": ['gra', 'mw'],
    "padyālaya": ['mw'],
    "padyāmṛta": ['mw'],
    "padyāmṛtasamudraṭīkā": ['mw'],
    "padyāmṛtasarovara": ['mw'],
    "padyāmṛtasopāna": ['mw'],
    "padyāmṛtataraṃgiṇī": ['mw'],
    "padyātmikopaniṣad": ['mw'],
    "padyāvali": ['mw'],
    "padābhihoma": ['mw'],
    "padābhilāṣin": ['mw'],
    "padābja": ['mw'],
    "padādhyayana": ['mw'],
    "padādhyāhāravāda": ['mw'],
    "padādhyāyin": ['mw'],
    "padādi": ['cae', 'mw'],
    "padādyavid": ['mw'],
    "padāghāta": ['mw'],
    "padāhata": ['mw'],
    "padāji": ['mw'],
    "padākrānta": ['cae', 'mw'],
    "padālika": ['mw'],
    "padāmbhoja": ['mw'],
    "padāmnāyasiddhi": ['mw'],
    "padāna": ['cped'],
    "padānta": ['cae', 'mw'],
    "padāntara": ['cae', 'mw'],
    "padāntaśuddhāśuddhīya": ['mw'],
    "padāntya": ['mw'],
    "padāntīya": ['mw'],
    "padānuga": ['cae', 'ddsa', 'mw'],
    "padānurāga": ['mw'],
    "padānusvāra": ['mw'],
    "padānusāra": ['cae', 'mw'],
    "padānuśāsana": ['mw'],
    "padānuṣaṅga": ['mw'],
    "padānveṣin": ['mw'],
    "padāra": ['mw'],
    "padāravinda": ['mw'],
    "padāraḥ": ['ap90'],
    "padārtha": ['cae', 'ddsa', 'mw'],
    "padārthabhāskara": ['mw'],
    "padārthabodha": ['mw'],
    "padārthacandrikā": ['mw'],
    "padārthadharmasaṃgraha": ['mw'],
    "padārthadīpikā": ['mw'],
    "padārthadīpinī": ['mw'],
    "padārthaguṇacintāmaṇi": ['mw'],
    "padārthakaumudī": ['mw'],
    "padārthakaumudīkośa": ['mw'],
    "padārthakaumudīsārakośa": ['mw'],
    "padārthakhaṇḍana": ['mw'],
    "padārthakhaṇḍanaṭippaṇavyākhyā": ['mw'],
    "padārthamaṇimālā": ['mw'],
    "padārthamālā": ['mw'],
    "padārthamālāvṛtti": ['mw'],
    "padārthanirūpaṇa": ['mw'],
    "padārthapradeśa": ['mw'],
    "padārthaprakāśa": ['mw'],
    "padārthaprakāśikā": ['mw'],
    "padārthapārijāta": ['mw'],
    "padārtharatnamañjūṣā": ['mw'],
    "padārtharatnamālā": ['mw'],
    "padārthasarasī": ['mw'],
    "padārthasaṃgraha": ['mw'],
    "padārthatattva": ['mw'],
    "padārthatattvanirūpaṇa": ['mw'],
    "padārthatattvanirṇaya": ['mw'],
    "padārthatattvavivecana": ['mw'],
    "padārthatritaya": ['mw'],
    "padārthavidyāsāra": ['mw'],
    "padārthaviveka": ['mw'],
    "padārthoddeśa": ['mw'],
    "padārthādarśa": ['mw'],
    "padārthānusamaya": ['mw'],
    "padārthīyadivyacakṣus": ['mw'],
    "padāsa": ['mw'],
    "padāsana": ['mw'],
    "padāta": ['bhs', 'mw'],
    "padātar": ['cped'],
    "padātave": ['cped'],
    "padātaḥ": ['ap90'],
    "padāti": ['cae', 'ddsa', 'mw'],
    "padātijana": ['mw'],
    "padātijanasaṃkula": ['mw'],
    "padātika": ['mw'],
    "padātikaḥ": ['ap90'],
    "padātilava": ['mw'],
    "padātimātra": ['mw'],
    "padātin": ['ap90', 'mw'],
    "padātyadhyakṣa": ['mw'],
    "padātīya": ['mw'],
    "padāvagrāham": ['mw'],
    "padāvalī": ['ddsa', 'mw'],
    "padāvihāra": ['bhs', 'mw'],
    "padāvṛtti": ['mw'],
    "padāyata": ['mw'],
    "padāyatā": ['mw'],
    "padāśva": ['bhs'],
    "padāḷana": ['cped'],
    "padāḷenta": ['cped'],
    "padāḷesi": ['cped'],
    "padāḷetar": ['cped'],
    "padāḷeti": ['cped'],
    "padāḷetvā": ['cped'],
    "padāḷita": ['cped'],
    "padāṅguṣṭha": ['mw'],
    "padāṅgī": ['mw'],
    "padāṅka": ['cae', 'ddsa', 'mw'],
    "padāṅkadūta": ['mw'],
    "padīkṛ": ['mw'],
    "padīkṛtatva": ['mw'],
    "padīpa": ['cped'],
    "padīpakāla": ['cped'],
    "padīpenta": ['cped'],
    "padīpesi": ['cped'],
    "padīpeti": ['cped'],
    "padīpetvā": ['cped'],
    "padīpeyya": ['cped'],
    "padīpita": ['cped'],
    "padīyati": ['cped'],
    "padīyi": ['cped'],
    "padūsesi": ['cped'],
    "padūseti": ['cped'],
    "padūsetvā": ['cped'],
    "padūsita": ['cped'],
    "pagabbha": ['cped'],
    "pageva": ['cped'],
    "paggaha": ['cped'],
    "paggahana": ['cped'],
    "paggahetabba": ['cped'],
    "paggahetvā": ['cped'],
    "paggahita": ['cped'],
    "paggayha": ['cped'],
    "paggaṇhanta": ['cped'],
    "paggaṇhi": ['cped'],
    "paggaṇhāti": ['cped'],
    "paggharanta": ['cped'],
    "paggharati": ['cped'],
    "paggharaṇa": ['cped'],
    "paggharaṇaka": ['cped'],
    "pagghari": ['cped'],
    "paggharita": ['cped'],
    "paggharitvā": ['cped'],
    "paggāha": ['cped'],
    "paghaṇa": ['cped'],
    "pagiddha": ['cped'],
    "pagumba": ['cped'],
    "paguṇa": ['cped'],
    "paguṇatā": ['cped'],
    "pagāhanta": ['cped'],
    "pagāhati": ['cped'],
    "pagāhi": ['cped'],
    "pagāhitvā": ['cped'],
    "pagārā": ['mw'],
    "pagāḷha": ['cped'],
    "paharanta": ['cped'],
    "paharati": ['cped'],
    "paharaṇa": ['cped'],
    "paharaṇaka": ['cped'],
    "pahari": ['cped'],
    "paharituṁ": ['cped'],
    "paharitvā": ['cped'],
    "pahaṭa": ['cped'],
    "pahaṭṭha": ['cped'],
    "paheṇaka": ['cped'],
    "pahita": ['cped'],
    "pahitatta": ['cped'],
    "pahiṇagamana": ['cped'],
    "pahiṇana": ['cped'],
    "pahiṇanta": ['cped'],
    "pahiṇi": ['cped'],
    "pahiṇitvā": ['cped'],
    "pahiṇāti": ['cped'],
    "pahlava": ['cae', 'mw'],
    "pahlikā": ['mw'],
    "pahnavāḥ": ['ap90'],
    "pahonaka": ['cped'],
    "pahoti": ['cped'],
    "pahāna": ['cped'],
    "pahāra": ['cped'],
    "pahāradāna": ['cped'],
    "pahāsa": ['cped'],
    "pahāsesi": ['cped'],
    "pahāseti": ['cped'],
    "pahāsita": ['cped'],
    "pahāya": ['cped'],
    "pahāyī": ['cped'],
    "pahāḍī": ['mw'],
    "pahīna": ['cped'],
    "pahīyamāna": ['cped'],
    "pahīyati": ['cped'],
    "pahīyi": ['cped'],
    "pahīyitvā": ['cped'],
    "pahū": ['cped'],
    "pahūta": ['cped'],
    "pahūtabhakkha": ['cped'],
    "pahūtajivha": ['cped'],
    "pai": ['ap90', 'mw'],
    "paicchilya": ['ddsa', 'mw'],
    "paidva": ['cae', 'gra', 'mw'],
    "paija": ['cae', 'mw'],
    "paijavana": ['cae', 'ddsa', 'gra', 'mw'],
    "paijūlāyana": ['mw'],
    "paila": ['ddsa', 'mw'],
    "pailagarbha": ['mw'],
    "pailagarga": ['mw'],
    "pailameli": ['mw'],
    "pailasūtrabhāṣya": ['mw'],
    "pailava": ['ap90', 'cae', 'ddsa', 'mw'],
    "pailaśyāparṇeya": ['mw'],
    "paileya": ['mw'],
    "paillya": ['mw'],
    "pailottaka": ['bhs'],
    "pailottika": ['bhs'],
    "pailu": ['mw'],
    "pailukuṇa": ['mw'],
    "pailumūla": ['mw'],
    "pailuvaha": ['mw'],
    "pailuvahaka": ['mw'],
    "pailuśīrṣi": ['mw'],
    "pailuśīrṣyā": ['mw'],
    "pailva": ['mw'],
    "pailvakāyana": ['mw'],
    "pailya": ['mw'],
    "pailīya": ['mw'],
    "painaddhaka": ['mw'],
    "painya": ['mw'],
    "paināka": ['cae', 'ddsa', 'mw'],
    "paippala": ['ap90', 'cae', 'ddsa', 'mw'],
    "paippalava": ['mw'],
    "paippalavya": ['mw'],
    "paippalāda": ['cae', 'ddsa', 'mw'],
    "paippalādaka": ['mw'],
    "paippalādi": ['mw'],
    "paippalādopaniṣad": ['mw'],
    "paippalāyani": ['mw'],
    "paippalīkacchapa": ['mw'],
    "paisukāyana": ['mw'],
    "paitadārava": ['mw'],
    "paitarāvaṇa": ['mw'],
    "paitra": ['ap90', 'cae', 'ddsa', 'mw'],
    "paitrika": ['mw'],
    "paitrya": ['mw'],
    "paitrāhorātra": ['mw'],
    "paitta": ['ap90', 'ddsa', 'mw'],
    "paittala": ['ap90', 'mw'],
    "paittika": ['mw'],
    "paitudrava": ['mw'],
    "paitudārava": ['ddsa', 'mw'],
    "paitā": ['mw'],
    "paitāmaha": ['ap90', 'cae', 'mw'],
    "paitāmahaka": ['mw'],
    "paitāmahasiddhānta": ['mw'],
    "paitāmahatīrtha": ['mw'],
    "paitāmahika": ['ap90'],
    "paitāmahībhāṣya": ['mw'],
    "paitāputrīya": ['ddsa', 'mw'],
    "paitṛ": ['mw'],
    "paitṛka": ['ap90', 'cae', 'ddsa', 'mw'],
    "paitṛkabhūmi": ['mw'],
    "paitṛkadhana": ['mw'],
    "paitṛkatithinirṇaya": ['mw'],
    "paitṛkavidhāna": ['mw'],
    "paitṛkaṣvaseya": ['mw'],
    "paitṛkaṣvaseyī": ['mw'],
    "paitṛkriyā": ['mw'],
    "paitṛkya": ['bhs'],
    "paitṛmatya": ['mw'],
    "paitṛmatyaḥ": ['ap90'],
    "paitṛmedhika": ['ddsa', 'mw'],
    "paitṛmedhikasūtra": ['mw'],
    "paitṛmedhikavidhi": ['mw'],
    "paitṛmedhikavidhāna": ['mw'],
    "paitṛmedhikavidhānaprayoga": ['mw'],
    "paitṛyajñika": ['cae', 'mw'],
    "paitṛyajñīya": ['cae', 'mw'],
    "paitṛṣvaseya": ['cae', 'mw'],
    "paitṛṣvaseyaḥ": ['ap90'],
    "paitṛṣvaseyī": ['mw'],
    "paitṛṣvasrīya": ['mw'],
    "paiyavana": ['mw'],
    "paiyūkṣa": ['mw'],
    "paiyūṣa": ['mw'],
    "paiñjūṣa": ['mw'],
    "paiśalya": ['cae', 'ddsa', 'mw'],
    "paiśalyaṃ": ['ap90'],
    "paiśuna": ['cae', 'ddsa', 'mw'],
    "paiśunaṃ": ['ap90'],
    "paiśunika": ['bhs', 'mw'],
    "paiśunya": ['bhs', 'cae', 'mw'],
    "paiśunyavādin": ['mw'],
    "paiśāca": ['ap90', 'cae', 'ddsa', 'mw'],
    "paiśācabhāṣya": ['mw'],
    "paiśācika": ['ap90', 'mw'],
    "paiśācya": ['mw'],
    "paiśācī": ['mw'],
    "paiḍika": ['mw'],
    "paiḍva": ['mw'],
    "paiṃgiḥ": ['ap90'],
    "paiṃjūṣaḥ": ['ap90'],
    "paiṃḍikyaṃ": ['ap90'],
    "paiṅga": ['mw'],
    "paiṅgala": ['cae', 'ddsa', 'mw'],
    "paiṅgalakāṇva": ['mw'],
    "paiṅgalaudāyani": ['mw'],
    "paiṅgalopaniṣad": ['mw'],
    "paiṅgalya": ['cae', 'mw'],
    "paiṅgalāyana": ['cae', 'mw'],
    "paiṅgalāyani": ['cae', 'mw'],
    "paiṅgarāja": ['mw'],
    "paiṅgarāyaṇa": ['mw'],
    "paiṅgi": ['cae', 'ddsa', 'mw'],
    "paiṅgika": ['bhs'],
    "paiṅgin": ['cae', 'mw'],
    "paiṅginpaiṅgirahasyabrāhmaṇa": ['mw'],
    "paiṅgya": ['cae', 'mw'],
    "paiṅgyasmṛti": ['mw'],
    "paiṅgyāyanabrāhmaṇa": ['mw'],
    "paiṅgākṣīputra": ['mw'],
    "paiṅgākṣīputrīya": ['mw'],
    "paiṅgāyanibrāhmaṇa": ['mw'],
    "paiṅgī": ['mw'],
    "paiṅgīputra": ['mw'],
    "paiṇ": ['mw'],
    "paiṇḍapātika": ['bhs', 'ddsa', 'mw'],
    "paiṇḍikya": ['mw'],
    "paiṇḍilika": ['bhs'],
    "paiṇḍinya": ['mw'],
    "paiṇḍya": ['mw'],
    "paiṇḍāyana": ['mw'],
    "paiṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "paiṣṭika": ['ap90', 'mw'],
    "paiṣṭikā": ['mw'],
    "paiṣṭī": ['ap90', 'mw'],
    "paiṭaka": ['mw'],
    "paiṭakalāyana": ['mw'],
    "paiṭakika": ['mw'],
    "paiṭhara": ['ap90', 'cae', 'mw'],
    "paiṭharika": ['mw'],
    "paiṭhasarpa": ['mw'],
    "paiṭhika": ['mw'],
    "paiṭhīna": ['mw'],
    "paiṭhīnasi": ['ddsa', 'mw'],
    "paiṭhīnasismṛti": ['mw'],
    "paiṭhīnasiḥ": ['ap90'],
    "paiṭhīnasya": ['mw'],
    "paiṭāka": ['mw'],
    "paiṭākika": ['mw'],
    "paj": ['gra', 'mw'],
    "pajagghana": ['cped'],
    "pajagghati": ['cped'],
    "pajagghi": ['cped'],
    "pajahanta": ['cped'],
    "pajahati": ['cped'],
    "pajahi": ['cped'],
    "pajahita": ['cped'],
    "pajahitvā": ['cped'],
    "pajappati": ['cped'],
    "pajappi": ['cped'],
    "pajasvat": ['gra'],
    "pajihaṭikā": ['mw'],
    "pajja": ['cped', 'mw'],
    "pajjabanda": ['cped'],
    "pajjalana": ['cped'],
    "pajjalanta": ['cped'],
    "pajjalati": ['cped'],
    "pajjali": ['cped'],
    "pajjalita": ['cped'],
    "pajjalitvā": ['cped'],
    "pajjhaṭikā": ['ap90'],
    "pajjhāyanta": ['cped'],
    "pajjhāyati": ['cped'],
    "pajjhāyi": ['cped'],
    "pajjota": ['cped'],
    "pajjunna": ['cped'],
    "pajoka": ['mw'],
    "pajra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pajrahoṣin": ['gra', 'mw'],
    "pajriya": ['cae', 'gra', 'mw'],
    "pajā": ['cped'],
    "pajānanā": ['cped'],
    "pajānāti": ['cped'],
    "pajāpati": ['cped'],
    "pajāyana": ['cped'],
    "pajāyati": ['cped'],
    "pajāyi": ['cped'],
    "pakampana": ['cped'],
    "pakampati": ['cped'],
    "pakampi": ['cped'],
    "pakampita": ['cped'],
    "pakappanā": ['cped'],
    "pakappesi": ['cped'],
    "pakappeti": ['cped'],
    "pakappetvā": ['cped'],
    "pakappita": ['cped'],
    "pakaraṇa": ['cped'],
    "pakata": ['cped'],
    "pakatatta": ['cped'],
    "pakatha": ['mw'],
    "pakati": ['cped'],
    "pakaticitta": ['cped'],
    "pakatigamana": ['cped'],
    "pakatika": ['cped'],
    "pakatisīla": ['cped'],
    "pakaṭṭha": ['cped'],
    "pakaṭṭhita": ['cped'],
    "pakhauda": ['mw'],
    "pakhoda": ['mw'],
    "pakhuma": ['cped'],
    "pakirati": ['cped'],
    "pakiri": ['cped'],
    "pakittenta": ['cped'],
    "pakittesi": ['cped'],
    "pakitteti": ['cped'],
    "pakittetvā": ['cped'],
    "pakittita": ['cped'],
    "pakiṇṇa": ['cped'],
    "pakiṇṇaka": ['cped'],
    "pakka": ['cped'],
    "pakkama": ['cped'],
    "pakkamana": ['cped'],
    "pakkamanta": ['cped'],
    "pakkamati": ['cped'],
    "pakkami": ['cped'],
    "pakkamitvā": ['cped'],
    "pakkandī": ['cped'],
    "pakkanta": ['cped'],
    "pakkarukkha": ['cped'],
    "pakkaṇa": ['ddsa', 'mw'],
    "pakkaṇaḥ": ['ap90'],
    "pakkaṭī": ['mw'],
    "pakkaṭṭhita": ['cped'],
    "pakkha": ['cped'],
    "pakkhabilāla": ['cped'],
    "pakkhalana": ['cped'],
    "pakkhalati": ['cped'],
    "pakkhali": ['cped'],
    "pakkhalita": ['cped'],
    "pakkhalitvā": ['cped'],
    "pakkhandana": ['cped'],
    "pakkhandati": ['cped'],
    "pakkhandi": ['cped'],
    "pakkhandikā": ['cped'],
    "pakkhanditvā": ['cped'],
    "pakkhandī": ['cped'],
    "pakkhanta": ['cped'],
    "pakkhepa": ['cped'],
    "pakkhika": ['cped'],
    "pakkhikabhatta": ['cped'],
    "pakkhipana": ['cped'],
    "pakkhipanta": ['cped'],
    "pakkhipati": ['cped'],
    "pakkhipi": ['cped'],
    "pakkhipitvā": ['cped'],
    "pakkhitta": ['cped'],
    "pakkhiya": ['cped'],
    "pakkhālesi": ['cped'],
    "pakkhāleti": ['cped'],
    "pakkhālita": ['cped'],
    "pakkhālitvā": ['cped'],
    "pakkhī": ['cped'],
    "pakkosana": ['cped'],
    "pakkosanā": ['cped'],
    "pakkosati": ['cped'],
    "pakkosi": ['cped'],
    "pakkosita": ['cped'],
    "pakkositvā": ['cped'],
    "pakkāmi": ['cped'],
    "pakopa": ['cped'],
    "pakopana": ['cped'],
    "paktapauḍa": ['mw'],
    "paktavya": ['cae', 'ddsa', 'mw'],
    "paktha": ['cae', 'gra', 'mw'],
    "pakthin": ['gra', 'mw'],
    "pakti": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "paktidṛṣṭi": ['cae', 'mw'],
    "paktināśana": ['mw'],
    "paktisthāna": ['mw'],
    "paktiśūla": ['mw'],
    "paktiḥ": ['ap90'],
    "paktra": ['mw'],
    "paktraṃ": ['ap90'],
    "paktrima": ['ap90', 'mw'],
    "paktṛ": ['ap90', 'cae', 'mw'],
    "pakubbamāna": ['cped'],
    "pakubbati": ['cped'],
    "pakuppati": ['cped'],
    "pakuppi": ['cped'],
    "pakva": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "pakvagātra": ['mw'],
    "pakvaharitalūna": ['mw'],
    "pakvaka": ['mw'],
    "pakvakaṣāya": ['mw'],
    "pakvakeśa": ['mw'],
    "pakvakṛt": ['mw'],
    "pakvamāna": ['bhs'],
    "pakvarasa": ['mw'],
    "pakvasasyopamonnati": ['mw'],
    "pakvataila": ['bhs'],
    "pakvatā": ['ap90', 'mw'],
    "pakvavat": ['mw'],
    "pakvavāri": ['mw'],
    "pakvaśa": ['mw'],
    "pakvaśaḥ": ['ap90'],
    "pakveṣṭaka": ['cae', 'mw'],
    "pakveṣṭakacita": ['mw'],
    "pakveṣṭakā": ['mw'],
    "pakveṣṭakāmaya": ['mw'],
    "pakvādhāna": ['mw'],
    "pakvānna": ['cae', 'mw'],
    "pakvāpakvā": ['mw'],
    "pakvātīsāra": ['mw'],
    "pakvāśaya": ['mw'],
    "pakvāśin": ['mw'],
    "pakāra": ['cped', 'mw'],
    "pakāsa": ['cped'],
    "pakāsaka": ['cped'],
    "pakāsana": ['cped'],
    "pakāsati": ['cped'],
    "pakāsenta": ['cped'],
    "pakāsesi": ['cped'],
    "pakāseti": ['cped'],
    "pakāsetvā": ['cped'],
    "pakāsi": ['cped'],
    "pakāsita": ['cped'],
    "pakṣ": ['ap90', 'mw'],
    "pakṣa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "pakṣabala": ['mw'],
    "pakṣabheda": ['mw'],
    "pakṣabhukti": ['mw'],
    "pakṣabhāga": ['mw'],
    "pakṣabindu": ['mw'],
    "pakṣacara": ['mw'],
    "pakṣacchid": ['mw'],
    "pakṣadhara": ['cae', 'mw'],
    "pakṣadharamiśra": ['mw'],
    "pakṣadharavyākhyā": ['mw'],
    "pakṣadharmatāvāda": ['mw'],
    "pakṣadharoddhāra": ['mw'],
    "pakṣadharī": ['mw'],
    "pakṣadvaya": ['mw'],
    "pakṣadvāra": ['cae', 'mw'],
    "pakṣagama": ['mw'],
    "pakṣaghna": ['mw'],
    "pakṣaghāta": ['mw'],
    "pakṣagrahaṇa": ['cae', 'mw'],
    "pakṣagrāha": ['cae', 'mw'],
    "pakṣagrāhin": ['cae', 'mw'],
    "pakṣagupta": ['bhs', 'mw'],
    "pakṣahara": ['mw'],
    "pakṣahata": ['mw'],
    "pakṣahoma": ['mw'],
    "pakṣahomasamasyavidhāna": ['mw'],
    "pakṣahomavidhi": ['mw'],
    "pakṣaja": ['mw'],
    "pakṣaka": ['cae', 'ddsa', 'mw'],
    "pakṣakaḥ": ['ap90'],
    "pakṣakṛt": ['mw'],
    "pakṣakṣaya": ['mw'],
    "pakṣakṣepa": ['mw'],
    "pakṣamūla": ['mw'],
    "pakṣanikṣepa": ['mw'],
    "pakṣanāḍī": ['mw'],
    "pakṣapoṣaṇa": ['mw'],
    "pakṣapradoṣavrata": ['mw'],
    "pakṣapradyota": ['mw'],
    "pakṣapuccha": ['cae', 'mw'],
    "pakṣapucchavat": ['mw'],
    "pakṣapuṭa": ['mw'],
    "pakṣapāli": ['mw'],
    "pakṣapāta": ['cae', 'mw'],
    "pakṣapātakṛtasneha": ['mw'],
    "pakṣapātin": ['cae', 'mw'],
    "pakṣapātitva": ['mw'],
    "pakṣapātitā": ['mw'],
    "pakṣaracanā": ['mw'],
    "pakṣaracanānaipuṇya": ['mw'],
    "pakṣarātri": ['mw'],
    "pakṣas": ['ap90', 'cae', 'gra', 'mw'],
    "pakṣasammita": ['mw'],
    "pakṣasundara": ['mw'],
    "pakṣati": ['bhs', 'ddsa', 'mw'],
    "pakṣatipuṭa": ['mw'],
    "pakṣatitā": ['mw'],
    "pakṣatiḥ": ['ap90'],
    "pakṣatva": ['ddsa', 'mw'],
    "pakṣatā": ['ap90', 'mw'],
    "pakṣatāgrantha": ['mw'],
    "pakṣatākroḍa": ['mw'],
    "pakṣatārahasya": ['mw'],
    "pakṣatāsiddhāntagrantha": ['mw'],
    "pakṣatāvicāra": ['mw'],
    "pakṣatāvāda": ['mw'],
    "pakṣatāvādārtha": ['mw'],
    "pakṣatāṭippanī": ['mw'],
    "pakṣatāṭīkā": ['mw'],
    "pakṣavadha": ['mw'],
    "pakṣavant": ['cae'],
    "pakṣavat": ['mw'],
    "pakṣavañcitaka": ['mw'],
    "pakṣavikala": ['cae', 'mw'],
    "pakṣavyāpin": ['mw'],
    "pakṣavāda": ['mw'],
    "pakṣavāhana": ['mw'],
    "pakṣayāga": ['mw'],
    "pakṣaśas": ['mw'],
    "pakṣaḥ": ['ap90'],
    "pakṣaṃgama": ['mw'],
    "pakṣeśvara": ['mw'],
    "pakṣi": ['mw'],
    "pakṣia": ['gra'],
    "pakṣibālaka": ['mw'],
    "pakṣijyotiṣa": ['mw'],
    "pakṣika": ['bhs'],
    "pakṣikīṭa": ['mw'],
    "pakṣila": ['mw'],
    "pakṣilasvāmin": ['mw'],
    "pakṣilaḥ": ['ap90'],
    "pakṣimanuṣyālayalakṣaṇa": ['mw'],
    "pakṣimārga": ['mw'],
    "pakṣimṛgatā": ['cae', 'ddsa', 'mw'],
    "pakṣin": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "pakṣipati": ['mw'],
    "pakṣipravara": ['mw'],
    "pakṣipuṃgava": ['mw'],
    "pakṣipānīyaśālikā": ['mw'],
    "pakṣirāj": ['cae', 'mw'],
    "pakṣirāja": ['cae', 'mw'],
    "pakṣirājya": ['mw'],
    "pakṣisiṃha": ['mw'],
    "pakṣisvāmin": ['cae', 'mw'],
    "pakṣitva": ['ddsa', 'mw'],
    "pakṣitīrtha": ['mw'],
    "pakṣiśālā": ['mw'],
    "pakṣiśārdūla": ['mw'],
    "pakṣiśāvaka": ['cae', 'mw'],
    "pakṣiṇī": ['ap90', 'mw'],
    "pakṣma": ['mw'],
    "pakṣmakopa": ['mw'],
    "pakṣmala": ['ap90', 'cae', 'ddsa', 'mw'],
    "pakṣmaladṛś": ['mw'],
    "pakṣman": ['ap90', 'cae', 'ddsa', 'mw'],
    "pakṣmaprakopa": ['mw'],
    "pakṣmapāta": ['ddsa', 'mw'],
    "pakṣmasampāta": ['mw'],
    "pakṣmasampātaja": ['mw'],
    "pakṣmaspanda": ['mw'],
    "pakṣmayūkā": ['mw'],
    "pakṣmākṣa": ['mw'],
    "pakṣodgrāhin": ['mw'],
    "pakṣotkṣepa": ['mw'],
    "pakṣottara": ['cae'],
    "pakṣu": ['bhs', 'mw'],
    "pakṣya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pakṣyavayas": ['mw'],
    "pakṣābhāsa": ['cae', 'mw'],
    "pakṣādhyāya": ['mw'],
    "pakṣādi": ['mw'],
    "pakṣāghāta": ['mw'],
    "pakṣāhati": ['mw'],
    "pakṣāhāra": ['mw'],
    "pakṣākāra": ['mw'],
    "pakṣālikā": ['mw'],
    "pakṣālu": ['mw'],
    "pakṣāluḥ": ['ap90'],
    "pakṣānta": ['cae', 'ddsa', 'mw'],
    "pakṣāntara": ['mw'],
    "pakṣāvalī": ['mw'],
    "pakṣāvasara": ['mw'],
    "pakṣāvasāna": ['mw'],
    "pakṣāṣṭamī": ['mw'],
    "pakṣīkṛ": ['ddsa', 'mw'],
    "pakṣīndra": ['cae', 'ddsa', 'mw'],
    "pakṣīya": ['ap90', 'ddsa', 'mw'],
    "pakṣīśa": ['mw'],
    "pakṣṇu": ['ap90', 'mw'],
    "pal": ['ap90', 'mw'],
    "pala": ['cae', 'cped', 'ddsa', 'mw'],
    "palabhā": ['mw'],
    "palabhākhaṇḍana": ['mw'],
    "palabhāsādhana": ['mw'],
    "palada": ['mw'],
    "paladī": ['mw'],
    "paladīya": ['mw'],
    "palagaṇḍa": ['bhs', 'cped', 'mw'],
    "palaka": ['bhs'],
    "palakyā": ['mw'],
    "palakṣa": ['ap90', 'cae', 'mw'],
    "palakṣāra": ['mw'],
    "palala": ['cae', 'ddsa', 'mw'],
    "palalajvara": ['mw'],
    "palalapalalāśaya": ['mw'],
    "palalapiṇḍa": ['mw'],
    "palalapriya": ['mw'],
    "palalaudana": ['cae', 'mw'],
    "palalaḥ": ['ap90'],
    "palanḍuka": ['cped'],
    "palapana": ['cped'],
    "palapati": ['cped'],
    "palapi": ['cped'],
    "palapita": ['cped'],
    "palapitvā": ['cped'],
    "palapriya": ['mw'],
    "palapīyūṣalatā": ['mw'],
    "palasa": ['ap90', 'mw'],
    "palasti": ['gra'],
    "palastijamadagni": ['gra', 'mw'],
    "palava": ['mw'],
    "palavaḥ": ['ap90'],
    "palavibhā": ['mw'],
    "palaḥ": ['ap90'],
    "palaṃkara": ['mw'],
    "palaṃkaraḥ": ['ap90'],
    "palaṃkaṣa": ['mw'],
    "palaṃkaṣaḥ": ['ap90'],
    "palaṃkaṣā": ['mw'],
    "palaṃkaṭa": ['ap90'],
    "palaṅkaṭa": ['mw'],
    "palaṇḍu": ['cped'],
    "palaṇḍuka": ['cped'],
    "paleti": ['cped'],
    "paleśinī": ['mw'],
    "palhava": ['ddsa'],
    "paligha": ['cped', 'mw'],
    "palighaḥ": ['ap90'],
    "paligodha": ['bhs'],
    "paliguddha": ['bhs'],
    "palika": ['ddsa', 'mw'],
    "palikhanati": ['bhs'],
    "paliknī": ['ap90', 'cae', 'ddsa', 'mw'],
    "palikuñca": ['bhs'],
    "palimbha": ['bhs'],
    "palipa": ['cped'],
    "palipanna": ['cped'],
    "palipatha": ['cped'],
    "palita": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "palitacchadman": ['mw'],
    "palitadarśana": ['mw'],
    "palitaka": ['bhs'],
    "palitambhaviṣṇu": ['mw'],
    "palitambhāvuka": ['mw'],
    "palitamlāna": ['mw'],
    "palitavat": ['mw'],
    "palitaṃbhaviṣṇu": ['ap90'],
    "palitaṃkaraṇa": ['ap90', 'mw'],
    "palitin": ['ap90', 'mw'],
    "paliyoga": ['mw'],
    "paliśuddha": ['bhs'],
    "paliṅgu": ['mw'],
    "pall": ['mw'],
    "palla": ['cae', 'mw'],
    "pallaka": ['mw'],
    "pallala": ['cped'],
    "pallatthikā": ['bhs', 'cped'],
    "pallava": ['cae', 'cped', 'ddsa', 'mw'],
    "pallavadhārin": ['mw'],
    "pallavadru": ['mw'],
    "pallavagrāhin": ['mw'],
    "pallavagrāhitā": ['mw'],
    "pallavaka": ['mw'],
    "pallavakaḥ": ['ap90'],
    "pallavakā": ['cae', 'mw'],
    "pallavamaya": ['mw'],
    "pallavana": ['mw'],
    "pallavapūra": ['mw'],
    "pallavarāgatāmra": ['mw'],
    "pallavati": ['ap90'],
    "pallavay": ['cae'],
    "pallavaya": ['ddsa', 'mw'],
    "pallavaḥ": ['ap90'],
    "pallavika": ['mw'],
    "pallavikaḥ": ['ap90'],
    "pallavikā": ['mw'],
    "pallavin": ['ap90', 'cae', 'ddsa', 'mw'],
    "pallavita": ['ap90', 'mw'],
    "pallavāda": ['mw'],
    "pallavādhāra": ['mw'],
    "pallavāpīḍita": ['ddsa', 'mw'],
    "pallavāstra": ['mw'],
    "pallavāṅguli": ['mw'],
    "pallavāṅkura": ['mw'],
    "pallavīkṛ": ['mw'],
    "pallaḥ": ['ap90'],
    "pallaṅka": ['cped'],
    "palli": ['cae', 'mw'],
    "palligupta": ['mw'],
    "pallikā": ['ap90', 'ddsa', 'mw'],
    "pallipañjaka": ['mw'],
    "pallivāha": ['mw'],
    "palliḥ": ['ap90'],
    "pallānati": ['bhs'],
    "pallāraṇyamāhātmya": ['mw'],
    "pallāśa": ['bhs'],
    "pallī": ['ddsa', 'mw'],
    "pallīdeśa": ['mw'],
    "pallīpatana": ['mw'],
    "pallīpatanakārikā": ['mw'],
    "pallīpatanaphala": ['mw'],
    "pallīpatanavicāra": ['mw'],
    "pallīpatanaśānti": ['mw'],
    "pallīpati": ['mw'],
    "pallīvicāra": ['mw'],
    "pallīvidhāna": ['mw'],
    "pallīśa": ['mw'],
    "pallīśaraṭa": ['mw'],
    "pallīśaraṭakākabhāsādiśakuna": ['mw'],
    "pallīśaraṭavidhāna": ['mw'],
    "pallīśaraṭayoḥphalāphalavicāra": ['mw'],
    "pallīśaraṭayoḥśānti": ['mw'],
    "palobhana": ['cped'],
    "palobhesi": ['cped'],
    "palobheti": ['cped'],
    "palobhetvā": ['cped'],
    "palobhita": ['cped'],
    "palodbhava": ['mw'],
    "palpūlana": ['cae', 'ddsa', 'mw'],
    "palpūlay": ['cae'],
    "palpūlaya": ['ddsa', 'mw'],
    "palpūlita": ['mw'],
    "palpūlī": ['mw'],
    "paluddha": ['cped'],
    "palugga": ['cped'],
    "palujjamāna": ['cped'],
    "palujjana": ['cped'],
    "palujjati": ['cped'],
    "palujji": ['cped'],
    "palujjitvā": ['cped'],
    "palvala": ['cae', 'ddsa', 'mw'],
    "palvalakarṣaka": ['mw'],
    "palvalapaṅka": ['mw'],
    "palvalatīra": ['mw'],
    "palvalaṃ": ['ap90'],
    "palvalya": ['mw'],
    "palvalāvāsa": ['mw'],
    "palvalībhū": ['mw'],
    "palvara": ['bhs'],
    "palya": ['cae', 'mw'],
    "palyakathāpuṣpāñjali": ['mw'],
    "palyalika": ['mw'],
    "palyavarcasa": ['mw'],
    "palyay": ['mw'],
    "palyaya": ['ddsa'],
    "palyayana": ['mw'],
    "palyayanaṃ": ['ap90'],
    "palyaṃ": ['ap90'],
    "palyaṃkaḥ": ['ap90'],
    "palyaṅg": ['mw'],
    "palyaṅgaya": ['ddsa'],
    "palyaṅka": ['cae', 'ddsa', 'mw'],
    "palyopama": ['mw'],
    "palyula": ['mw'],
    "palyāṇa": ['mw'],
    "palyāṇaya": ['mw'],
    "palyūla": ['mw'],
    "palāda": ['mw'],
    "palādana": ['mw'],
    "palāgni": ['mw'],
    "palāka": ['mw'],
    "palāla": ['cae', 'cped', 'ddsa', 'mw'],
    "palālabhāra": ['cae'],
    "palālabhāraka": ['cae', 'mw'],
    "palāladohada": ['mw'],
    "palālapuñja": ['cped'],
    "palālaḥ": ['ap90'],
    "palāli": ['mw'],
    "palālina": ['mw'],
    "palāliḥ": ['ap90'],
    "palāloccaya": ['cae', 'mw'],
    "palālā": ['mw'],
    "palālānupalāla": ['mw'],
    "palālī": ['mw'],
    "palāna": ['bhs'],
    "palānna": ['mw'],
    "palāpa": ['bhs', 'cped', 'mw'],
    "palāpahā": ['mw'],
    "palāpaḥ": ['ap90'],
    "palāpesi": ['cped'],
    "palāpeti": ['cped'],
    "palāpetvā": ['cped'],
    "palāpita": ['cped'],
    "palāpī": ['cped'],
    "palārdha": ['mw'],
    "palāsa": ['cped'],
    "palāsāda": ['cped'],
    "palāsī": ['cped'],
    "palāta": ['bhs', 'cped'],
    "palāva": ['bhs', 'cae', 'ddsa', 'mw'],
    "palāy": ['ap90', 'cae', 'mw'],
    "palāya": ['ddsa'],
    "palāyaka": ['ap90', 'bhs', 'mw'],
    "palāyana": ['cae', 'cped', 'ddsa', 'mw'],
    "palāyanaka": ['cped'],
    "palāyanamanas": ['mw'],
    "palāyanaparāyaṇa": ['mw'],
    "palāyanaviṣaya": ['mw'],
    "palāyanaṃ": ['ap90'],
    "palāyanta": ['cped'],
    "palāyati": ['cped'],
    "palāyi": ['cped'],
    "palāyin": ['ap90', 'cae', 'mw'],
    "palāyita": ['ap90', 'mw'],
    "palāyitvā": ['cped'],
    "palāyī": ['cped'],
    "palāśa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "palāśaka": ['bhs', 'mw'],
    "palāśakaḥ": ['ap90'],
    "palāśana": ['mw'],
    "palāśanagara": ['mw'],
    "palāśaparṇī": ['mw'],
    "palāśapattra": ['mw'],
    "palāśapuṭa": ['mw'],
    "palāśatā": ['mw'],
    "palāśaśātana": ['mw'],
    "palāśikā": ['mw'],
    "palāśila": ['mw'],
    "palāśin": ['ap90', 'cae', 'mw'],
    "palāśinī": ['mw'],
    "palāśākhya": ['mw'],
    "palāśāmbhā": ['mw'],
    "palāśāntā": ['mw'],
    "palāśāṅgā": ['mw'],
    "palāśī": ['mw'],
    "palāśīya": ['mw'],
    "palāṃḍu": ['ap90'],
    "palāṅga": ['mw'],
    "palāṇḍu": ['cae', 'ddsa', 'mw'],
    "palāṇḍubhakṣita": ['mw'],
    "palāṇḍumaṇḍana": ['mw'],
    "palījaka": ['mw'],
    "palīkṛta": ['bhs'],
    "palīśa": ['mw'],
    "pam, pañj": ['ddsa'],
    "pamaddana": ['cped'],
    "pamaddati": ['cped'],
    "pamaddi": ['cped'],
    "pamaddita": ['cped'],
    "pamadditvā": ['cped'],
    "pamaddī": ['cped'],
    "pamadā": ['cped'],
    "pamadāvana": ['cped'],
    "pamajja": ['cped'],
    "pamajjana": ['cped'],
    "pamajjanā": ['cped'],
    "pamajjati": ['cped'],
    "pamajji": ['cped'],
    "pamajjituṁ": ['cped'],
    "pamajjitvā": ['cped'],
    "pamajjiya": ['cped'],
    "pamarā": ['mw'],
    "pamathati": ['cped'],
    "pamathi": ['cped'],
    "pamathita": ['cped'],
    "pamathitvā": ['cped'],
    "pamatta": ['cped'],
    "pamattabandhu": ['bhs', 'cped'],
    "pamb": ['mw'],
    "pameyya": ['cped'],
    "pamha": ['cped'],
    "pamita": ['cped'],
    "pamitvā": ['cped'],
    "pamiṇi": ['cped'],
    "pamiṇitvā": ['cped'],
    "pamiṇāti": ['cped'],
    "pamocana": ['cped'],
    "pamocesi": ['cped'],
    "pamoceti": ['cped'],
    "pamocetvā": ['cped'],
    "pamocita": ['cped'],
    "pamoda": ['cped'],
    "pamodamāna": ['cped'],
    "pamodanā": ['cped'],
    "pamodati": ['cped'],
    "pamodi": ['cped'],
    "pamodita": ['cped'],
    "pamoditvā": ['cped'],
    "pamohana": ['cped'],
    "pamohesi": ['cped'],
    "pamoheti": ['cped'],
    "pamohetvā": ['cped'],
    "pamohita": ['cped'],
    "pamokkha": ['cped'],
    "pampaka": ['cped'],
    "pampasya": ['mw'],
    "pampā": ['cae', 'ddsa', 'mw'],
    "pampāmāhātmya": ['mw'],
    "pamuccati": ['cped'],
    "pamucchati": ['cped'],
    "pamucchi": ['cped'],
    "pamucchita": ['cped'],
    "pamucchitvā": ['cped'],
    "pamucci": ['cped'],
    "pamuccitvā": ['cped'],
    "pamudita": ['cped'],
    "pamukha": ['cped'],
    "pamussati": ['cped'],
    "pamussi": ['cped'],
    "pamussitvā": ['cped'],
    "pamutta": ['cped'],
    "pamutti": ['cped'],
    "pamuyha": ['cped'],
    "pamuyhati": ['cped'],
    "pamuyhi": ['cped'],
    "pamuyhitvā": ['cped'],
    "pamuñcanta": ['cped'],
    "pamuñcati": ['cped'],
    "pamuñci": ['cped'],
    "pamuñcita": ['cped'],
    "pamuñcitvā": ['cped'],
    "pamuñciya": ['cped'],
    "pamuñtatti": ['cped'],
    "pamuṭṭha": ['cped'],
    "pamāda": ['cped'],
    "pamādapāṭha": ['cped'],
    "pamāṇa": ['cped'],
    "pamāṇaka": ['cped'],
    "pamāṇika": ['cped'],
    "pamūḷha": ['cped'],
    "pan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pana": ['bhs', 'cped'],
    "panaka": ['mw'],
    "panasa": ['cae', 'cped', 'ddsa', 'mw'],
    "panasanālikā": ['mw'],
    "panasatālikā": ['mw'],
    "panasaḥ": ['ap90'],
    "panasikā": ['ap90', 'mw'],
    "panassati": ['cped'],
    "panassi": ['cped'],
    "panasy": ['cae', 'gra'],
    "panasya": ['ddsa', 'mw'],
    "panasyati": ['ap90'],
    "panasyu": ['cae', 'gra', 'mw'],
    "panasāsthi": ['mw'],
    "panasī": ['mw'],
    "panayāyia": ['gra'],
    "panayāyya": ['cae', 'gra', 'mw'],
    "panaṭṭha": ['cped'],
    "pandara": ['mw'],
    "paneti": ['bhs'],
    "panipnat": ['mw'],
    "panita": ['mw'],
    "panitṛ": ['cae', 'gra', 'mw'],
    "paniṣpada": ['mw'],
    "paniṣṭama": ['mw'],
    "paniṣṭha": ['cae', 'gra', 'mw'],
    "paniṣṭi": ['gra', 'mw'],
    "panmiśra": ['mw'],
    "panna": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "pannabhāra": ['cped'],
    "pannada": ['mw'],
    "pannaddhrī": ['mw'],
    "pannaddhā": ['mw'],
    "pannaga": ['cae', 'cped', 'mw'],
    "pannagabhojana": ['cae', 'mw'],
    "pannagakesara": ['mw'],
    "pannagamaya": ['mw'],
    "pannaganāśana": ['cae', 'mw'],
    "pannagapurī": ['mw'],
    "pannagarāja": ['cae', 'mw'],
    "pannagendra": ['cae', 'mw'],
    "pannageśvara": ['cae', 'mw'],
    "pannagāri": ['cae', 'mw'],
    "pannagāśana": ['mw'],
    "pannagī": ['mw'],
    "pannagīgīrtakīrti": ['mw'],
    "pannaloma": ['cped'],
    "pannarūpa": ['mw'],
    "pannarūpīya": ['mw'],
    "pannejana": ['mw'],
    "pannejanī": ['mw'],
    "panniṣka": ['mw'],
    "pannāgāra": ['mw'],
    "panta": ['cped'],
    "pantasenāsana": ['cped'],
    "panth": ['gra', 'mw'],
    "pantha": ['bhs', 'cped'],
    "panthadūhana": ['cped'],
    "panthaghāta": ['cped'],
    "panthaghātaka": ['cped'],
    "panthaka": ['bhs', 'cped', 'mw'],
    "panthalika": ['bhs'],
    "panthalikā": ['mw'],
    "panthan": ['cae'],
    "panthika": ['cped'],
    "panthitā": ['bhs'],
    "panthā": ['ddsa', 'gra'],
    "panthān": ['ddsa'],
    "panthāna": ['mw'],
    "panti": ['cped'],
    "panu": ['cae', 'ddsa', 'gra', 'mw'],
    "panudamāna": ['cped'],
    "panudana": ['cped'],
    "panudati": ['cped'],
    "panudi": ['cped'],
    "panudita": ['cped'],
    "panuditvā": ['cped'],
    "panudiya": ['cped'],
    "panuḥ": ['ap90'],
    "panya": ['cae', 'ddsa', 'gra', 'mw'],
    "panyas": ['gra', 'mw'],
    "panyaṃs": ['cae'],
    "panāy": ['gra'],
    "panāya": ['ddsa', 'mw'],
    "panāyia": ['gra'],
    "panāyita": ['ap90'],
    "panāyya": ['cae', 'ddsa', 'gra', 'mw'],
    "panāḷikā": ['cped'],
    "panīyas": ['gra', 'mw'],
    "panīyaṃs": ['cae'],
    "panū": ['cae', 'gra', 'mw'],
    "panūdana": ['cped'],
    "panūḥ": ['ap90'],
    "papa": ['cped'],
    "papada": ['cped'],
    "papasya": ['mw'],
    "papatana": ['cped'],
    "papatati": ['cped'],
    "papati": ['cped'],
    "papatita": ['cped'],
    "papatitvā": ['cped'],
    "papañca": ['cped'],
    "papañcesi": ['cped'],
    "papañceti": ['cped'],
    "papañcetvā": ['cped'],
    "papañcita": ['cped'],
    "papaṭikā": ['cped'],
    "paphaka": ['mw'],
    "paphakanaraka": ['mw'],
    "papi": ['cae', 'gra', 'mw'],
    "papitāmaha": ['cped'],
    "papiḥ": ['ap90'],
    "pappaṭaka": ['cped'],
    "papphāsa": ['cped'],
    "pappoti": ['cped'],
    "pappoṭhesi": ['cped'],
    "pappoṭheti": ['cped'],
    "pappoṭhetvā": ['cped'],
    "pappoṭhita": ['cped'],
    "pappuyya": ['cped'],
    "papri": ['cae', 'ddsa', 'gra', 'mw'],
    "papu": ['ap90', 'mw'],
    "papuri": ['cae', 'gra', 'mw'],
    "paputta": ['cped'],
    "papā": ['cped'],
    "papāta": ['cped'],
    "papātaṭa": ['cped'],
    "papī": ['ap90', 'mw'],
    "papīti": ['mw'],
    "papṛkṣeṇya": ['cae', 'gra', 'mw'],
    "par": ['gra'],
    "para": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "parabala": ['mw'],
    "parabalīyas": ['mw'],
    "parabhedaka": ['mw'],
    "parabhedana": ['mw'],
    "parabhāga": ['cae', 'cped', 'mw'],
    "parabhāgatā": ['mw'],
    "parabhāgya": ['mw'],
    "parabhāgyopajīvin": ['mw'],
    "parabhāva": ['mw'],
    "parabhāṣā": ['mw'],
    "parabhū": ['mw'],
    "parabhūjātinirṇaya": ['mw'],
    "parabhūmi": ['mw'],
    "parabhūmiṣṭha": ['mw'],
    "parabhūprakaraṇa": ['mw'],
    "parabhūta": ['mw'],
    "parabhūṣaṇa": ['mw'],
    "parabhṛt": ['mw'],
    "parabhṛta": ['cae', 'mw'],
    "parabhṛtamaya": ['mw'],
    "parabhṛtikā": ['cae', 'mw'],
    "parabhṛtya": ['mw'],
    "parabhṛtyatva": ['mw'],
    "parabhṛtā": ['mw'],
    "parabrahman": ['ddsa', 'mw'],
    "parabrahmaprakāśikā": ['mw'],
    "parabrahmastotra": ['mw'],
    "parabrahmopaniṣad": ['mw'],
    "parabrahmānandabodha": ['mw'],
    "parabrahmāṣṭottaraśatanāman": ['mw'],
    "paracakra": ['mw'],
    "paracakrasūdana": ['mw'],
    "paracchanda": ['mw'],
    "paracchandānuvartana": ['mw'],
    "paracchidra": ['cae', 'mw'],
    "paracintā": ['ddsa', 'mw'],
    "paracittajñāna": ['mw'],
    "paradattūpajīvī": ['cped'],
    "paradevatā": ['mw'],
    "paradevatāstuti": ['mw'],
    "paradeśa": ['cae', 'mw'],
    "paradeśasevin": ['mw'],
    "paradeśin": ['mw'],
    "paradhana": ['cae', 'mw'],
    "paradhanāsvādanasukha": ['mw'],
    "paradharma": ['mw'],
    "paradharmatva": ['mw'],
    "paradhyāna": ['mw'],
    "paradoṣa": ['mw'],
    "paradoṣajña": ['cae', 'mw'],
    "paradravya": ['cae', 'mw'],
    "paradravyāpahāraka": ['mw'],
    "paradroha": ['mw'],
    "paradrohakarmadhī": ['mw'],
    "paradrohin": ['mw'],
    "paraduḥkha": ['mw'],
    "paradveṣin": ['mw'],
    "paradāra": ['cae', 'cped', 'ddsa', 'mw'],
    "paradārabhuj": ['mw'],
    "paradāradārika": ['cped'],
    "paradārakamma": ['cped'],
    "paradāraparigraha": ['mw'],
    "paradārin": ['cae', 'mw'],
    "paradāropasevana": ['cae', 'mw'],
    "paradārābhigamana": ['mw'],
    "paradārābhimarśa": ['mw'],
    "paradūṣaṇa": ['mw'],
    "paragata": ['mw'],
    "paragaṇamathana": ['bhs'],
    "paragehavāsa": ['mw'],
    "paraglāni": ['mw'],
    "paragranthi": ['mw'],
    "paraguṇa": ['mw'],
    "paraguṇagrāhin": ['mw'],
    "paragāmin": ['mw'],
    "paragṛhavāsa": ['mw'],
    "parahan": ['mw'],
    "parahatthagata": ['cped'],
    "parahaṃsa": ['mw'],
    "parahetu": ['cped'],
    "parahita": ['cped', 'ddsa', 'mw'],
    "parahitagrantha": ['mw'],
    "parahitarakṣita": ['mw'],
    "parahitasaṃhitā": ['mw'],
    "paraidhita": ['mw'],
    "paraja": ['mw'],
    "parajana": ['cae', 'cped', 'mw'],
    "parajanman": ['mw'],
    "parajanmika": ['mw'],
    "parajñānamaya": ['mw'],
    "parajāta": ['mw'],
    "paraka": ['mw'],
    "parakalatra": ['mw'],
    "parakalatrābhigamana": ['mw'],
    "parakaragata": ['ddsa', 'mw'],
    "parakarman": ['mw'],
    "parakarmanirata": ['mw'],
    "parakata": ['cped'],
    "parakathā": ['cae', 'ddsa', 'mw'],
    "parakhātaka": ['mw'],
    "parakkama": ['cped'],
    "parakkamana": ['cped'],
    "parakkamanta": ['cped'],
    "parakkamati": ['cped'],
    "parakkami": ['cped'],
    "parakkamitvā": ['cped'],
    "parakkamma": ['cped'],
    "parakkanta": ['cped'],
    "parakkhati": ['cped'],
    "parakrama": ['mw'],
    "parakrānti": ['mw'],
    "parakrāthin": ['mw'],
    "parakula": ['mw'],
    "parakāla": ['mw'],
    "parakāra": ['cped'],
    "parakārya": ['cae', 'mw'],
    "parakāyapraveśana": ['mw'],
    "parakīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "parakīyanipāna": ['mw'],
    "parakīyatā": ['mw'],
    "parakīyā": ['mw'],
    "parakīyātva": ['mw'],
    "parakṛta": ['ddsa'],
    "parakṛti": ['mw'],
    "parakṛtya": ['cae', 'mw'],
    "parakṛtyapakṣa": ['mw'],
    "parakṣa": ['bhs'],
    "parakṣetra": ['cae', 'mw'],
    "parakṣudrā": ['mw'],
    "paraloka": ['cae', 'cped', 'mw'],
    "paralokabādha": ['mw'],
    "paralokaga": ['mw'],
    "paralokagama": ['mw'],
    "paralokagamana": ['mw'],
    "paralokagata": ['mw'],
    "paralokahasta": ['cae', 'mw'],
    "paralokasthāna": ['mw'],
    "paralokavaha": ['mw'],
    "paralokavidhi": ['mw'],
    "paralokayāna": ['mw'],
    "param": ['bhs', 'mw'],
    "parama": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "paramabhaṭṭāraka": ['mw'],
    "paramabhāsvara": ['mw'],
    "paramabrahmacāriṇī": ['mw'],
    "paramabrahman": ['mw'],
    "paramabrahmaṇya": ['mw'],
    "paramacetas": ['mw'],
    "paramada": ['mw'],
    "paramadharmātman": ['cae', 'mw'],
    "paramadru": ['mw'],
    "paramadurmedhas": ['mw'],
    "paramaduḥkhita": ['mw'],
    "paramadāruṇa": ['cae', 'mw'],
    "paramagahana": ['mw'],
    "paramagati": ['mw'],
    "paramagava": ['mw'],
    "paramahaṃsa": ['mw'],
    "paramahaṃsadharmanirūpaṇa": ['mw'],
    "paramahaṃsakavaca": ['mw'],
    "paramahaṃsanirṇaya": ['mw'],
    "paramahaṃsapaddhati": ['mw'],
    "paramahaṃsaparivrājakadharmasaṃgraha": ['mw'],
    "paramahaṃsaparivrājakopaniṣad": ['mw'],
    "paramahaṃsaparivrājakācārya": ['mw'],
    "paramahaṃsapañcāṅga": ['mw'],
    "paramahaṃsapaṭala": ['mw'],
    "paramahaṃsapriyā": ['mw'],
    "paramahaṃsasahasranāman": ['mw'],
    "paramahaṃsasaṃhitā": ['mw'],
    "paramahaṃsastavarāja": ['mw'],
    "paramahaṃsastotra": ['mw'],
    "paramahaṃsopaniṣad": ['mw'],
    "paramahaṃsopaniṣadhṛdaya": ['mw'],
    "paramahaṃsopāsanaprakāra": ['mw'],
    "paramaiśvarya": ['mw'],
    "paramajiā": ['gra'],
    "paramajyā": ['gra', 'mw'],
    "paramajā": ['mw'],
    "paramaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "paramakaṇṭha": ['mw'],
    "paramakrodhin": ['mw'],
    "paramakruddha": ['mw'],
    "paramakrānti": ['mw'],
    "paramakrāntijyā": ['mw'],
    "paramakāṇḍa": ['mw'],
    "paramalaghumañjūṣā": ['mw'],
    "paramam": ['mw'],
    "paramamahat": ['mw'],
    "paramamanyumat": ['mw'],
    "paramamokṣa": ['mw'],
    "paramananda": ['mw'],
    "paramanthu": ['mw'],
    "paramantra": ['bhs', 'mw'],
    "paramanyu": ['mw'],
    "paramanyumat": ['ddsa'],
    "paramapada": ['mw'],
    "paramapadanirṇāyaka": ['mw'],
    "paramapadasopāna": ['mw'],
    "paramapadātmavat": ['mw'],
    "paramaparama": ['mw'],
    "paramaprabha": ['mw'],
    "paramaprīta": ['cae', 'mw'],
    "paramapumaṃs": ['cae'],
    "paramapuruṣa": ['mw'],
    "paramapuruṣamahotsavaprāyaścitta": ['mw'],
    "paramapuruṣaprārthanāmañjarī": ['mw'],
    "paramapuruṣasaṃhitā": ['mw'],
    "paramapuṃs": ['ddsa', 'mw'],
    "paramapūruṣa": ['mw'],
    "paramarahasya": ['mw'],
    "paramarahasyajapasaṃgraha": ['mw'],
    "paramarahasyasaṃhitā": ['mw'],
    "paramarahasyavāda": ['mw'],
    "paramarahasyopadeśasaṃgraha": ['mw'],
    "paramarahasyopaniṣad": ['mw'],
    "paramaraja": ['mw'],
    "paramarasa": ['mw'],
    "paramarddhika": ['mw'],
    "paramarkṣa": ['mw'],
    "paramarma": ['mw'],
    "paramarmabhāṣaṇa": ['mw'],
    "paramarṣi": ['cae', 'ddsa', 'mw'],
    "paramasammata": ['mw'],
    "paramasamudaya": ['cae', 'mw'],
    "paramasarvatra": ['mw'],
    "paramasaṃhitā": ['mw'],
    "paramasaṃhṛṣṭa": ['mw'],
    "paramasaṃtuṣṭa": ['mw'],
    "paramasvadharman": ['mw'],
    "paramata": ['bhs', 'cae', 'ddsa', 'mw'],
    "paramatabhañjana": ['mw'],
    "paramatabhaṅga": ['mw'],
    "paramatakhaṇḍanasaṃgraha": ['mw'],
    "paramatakālānala": ['mw'],
    "paramatas": ['mw'],
    "paramatattva": ['mw'],
    "paramatattvaprakāśikā": ['mw'],
    "paramatattvarahasyopaniṣad": ['mw'],
    "paramataḥ": ['ap90'],
    "paramattha": ['cped'],
    "paramatā": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "paramavismita": ['mw'],
    "paramavyomnika": ['mw'],
    "paramaśiva": ['mw'],
    "paramaśobhana": ['ddsa', 'mw'],
    "paramaṇi": ['mw'],
    "parame": ['mw'],
    "paramekṣu": ['mw'],
    "parameśa": ['cae', 'mw'],
    "parameśastotrāvalī": ['mw'],
    "parameśvara": ['cae', 'ddsa', 'mw'],
    "parameśvaradatta": ['mw'],
    "parameśvarapañcamukhadhyāna": ['mw'],
    "parameśvarapañcaratna": ['mw'],
    "parameśvarapraṇidhāna": ['mw'],
    "parameśvararakṣita": ['mw'],
    "parameśvarasaṃhitā": ['mw'],
    "parameśvarastotra": ['mw'],
    "parameśvarastuti": ['mw'],
    "parameśvarasākṣātkāra": ['mw'],
    "parameśvaratantra": ['mw'],
    "parameśvaratva": ['mw'],
    "parameśvaratā": ['mw'],
    "parameśvaravarman": ['mw'],
    "parameśvarāstitvavādin": ['mw'],
    "parameśvarī": ['mw'],
    "parameśvarīdāsābdhi": ['mw'],
    "parameśvarīya": ['mw'],
    "parameṣvāsa": ['cae', 'ddsa', 'mw'],
    "parameṣvāsatā": ['mw'],
    "parameṣṭha": ['ap90', 'mw'],
    "parameṣṭhi": ['mw'],
    "parameṣṭhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "parameṣṭhina": ['mw'],
    "parameṣṭhinī": ['mw'],
    "parameṣṭhitā": ['mw'],
    "parameṣṭhā": ['mw'],
    "parammukha": ['cped'],
    "parammukhā": ['cped'],
    "paramokṣanirāsakārikā": ['mw'],
    "paramopāsaka": ['mw'],
    "parampara": ['ddsa', 'mw'],
    "paramparabhojana": ['mw'],
    "paramparam": ['mw'],
    "paramparatas": ['mw'],
    "paramparayā": ['mw'],
    "paramparā": ['cped', 'mw'],
    "paramparāprāpta": ['mw'],
    "paramparāsambandha": ['mw'],
    "paramparāvāhana": ['mw'],
    "paramparāyāta": ['mw'],
    "paramukhacapeṭikā": ['mw'],
    "paramukhā": ['cped'],
    "paramādvaita": ['mw'],
    "paramādīśvara": ['mw'],
    "paramāgama": ['mw'],
    "paramāgamacūḍāmaṇisaṃhitā": ['mw'],
    "paramāgamasāra": ['mw'],
    "paramāha": ['mw'],
    "paramāhlādana": ['mw'],
    "paramākhya": ['mw'],
    "paramākṣara": ['cae', 'mw'],
    "paramāmṛta": ['mw'],
    "paramānanda": ['cae', 'mw'],
    "paramānandalaharīstotra": ['mw'],
    "paramānandamādhavastava": ['mw'],
    "paramānandatantra": ['mw'],
    "paramānna": ['mw'],
    "paramāpad": ['mw'],
    "paramāpakrama": ['mw'],
    "paramāpama": ['mw'],
    "paramāpsaras": ['mw'],
    "paramāra": ['mw'],
    "paramārhata": ['mw'],
    "paramārta": ['mw'],
    "paramārtavat": ['cae', 'mw'],
    "paramārtha": ['cae', 'mw'],
    "paramārthabhāj": ['mw'],
    "paramārthabodha": ['mw'],
    "paramārthadaridra": ['mw'],
    "paramārthadarśana": ['mw'],
    "paramārthadharmavijaya": ['bhs'],
    "paramārthamatsya": ['mw'],
    "paramārthanirṇaya": ['mw'],
    "paramārthapradīpikā": ['mw'],
    "paramārthaprakāśa": ['mw'],
    "paramārthaprapā": ['mw'],
    "paramārthasarit": ['mw'],
    "paramārthasattva": ['bhs'],
    "paramārthasatya": ['mw'],
    "paramārthasaṃdarbha": ['mw'],
    "paramārthasaṃgraha": ['mw'],
    "paramārthasaṃvṛtisatyanirdeśa": ['bhs', 'mw'],
    "paramārthastuti": ['mw'],
    "paramārthasupta": ['mw'],
    "paramārthasāra": ['mw'],
    "paramārthasārasaṃgraha": ['mw'],
    "paramārthasārasaṃkṣepavivṛti": ['mw'],
    "paramārthatas": ['mw'],
    "paramārthatā": ['mw'],
    "paramārthavid": ['mw'],
    "paramārthavikrāmin": ['bhs'],
    "paramārthavinda": ['mw'],
    "paramārthaviveka": ['mw'],
    "paramārya": ['mw'],
    "paramārādhya": ['mw'],
    "paramāsana": ['mw'],
    "paramātma": ['mw'],
    "paramātmagatiprakāśa": ['mw'],
    "paramātmaka": ['mw'],
    "paramātmamaya": ['mw'],
    "paramātman": ['cae', 'ddsa', 'mw'],
    "paramātmaprakāśa": ['mw'],
    "paramātmasaṃdarbha": ['mw'],
    "paramātmastava": ['mw'],
    "paramātmavinoda": ['mw'],
    "paramātra": ['bhs', 'mw'],
    "paramāvadhi": ['mw'],
    "paramāvaṭika": ['mw'],
    "paramāyu": ['cped'],
    "paramāyus": ['mw'],
    "paramāyuṣa": ['mw'],
    "paramāśva": ['bhs'],
    "paramāṅganā": ['mw'],
    "paramāṇu": ['cae', 'cped', 'ddsa', 'mw'],
    "paramāṇukāraṇavāda": ['mw'],
    "paramāṇumaya": ['mw'],
    "paramāṇurajaḥpraveśa": ['bhs'],
    "paramāṇutā": ['mw'],
    "paramāṇvaṅgaka": ['mw'],
    "paramāṭika": ['mw'],
    "paramṛtyu": ['mw'],
    "paraneyya": ['cped'],
    "paranindā": ['mw'],
    "paranipāta": ['mw'],
    "paranirmita": ['bhs'],
    "paranirmitavaśavartin": ['bhs', 'mw'],
    "paranirmitodyukta": ['bhs'],
    "paranirvāṇa": ['mw'],
    "parantapa": ['ddsa'],
    "parapaccaya": ['cped'],
    "parapada": ['mw'],
    "parapakṣa": ['cae', 'ddsa', 'mw'],
    "paraparibhava": ['mw'],
    "paraparigraha": ['cae', 'mw'],
    "paraparita": ['mw'],
    "paraparivāda": ['mw'],
    "paraparāka": ['mw'],
    "paraparīṇa": ['mw'],
    "parapatnī": ['mw'],
    "parapattiya": ['cped'],
    "parapauravatantava": ['mw'],
    "parapessa": ['cped'],
    "parapiṇḍa": ['mw'],
    "parapiṇḍapuṣṭaka": ['cae'],
    "parapiṇḍāda": ['mw'],
    "paraprakāśaka": ['mw'],
    "parapratyaya": ['bhs'],
    "parapravāda": ['bhs'],
    "parapravādin": ['bhs', 'mw'],
    "paraprayojana": ['mw'],
    "parapraṇava": ['mw'],
    "parapraṇeya": ['bhs'],
    "parapreṣyatva": ['cae', 'mw'],
    "paraprāṇeya": ['bhs'],
    "parapurapraveśa": ['mw'],
    "parapuraṃjaya": ['cae', 'mw'],
    "parapuruṣa": ['cae', 'mw'],
    "parapuṣṭa": ['cae', 'mw'],
    "parapuṣṭamahotsava": ['mw'],
    "parapuṣṭamaya": ['mw'],
    "parapuṣṭā": ['mw'],
    "parapuṭṭha": ['cped'],
    "parapāka": ['cae', 'mw'],
    "parapākanivṛtta": ['mw'],
    "parapākarata": ['mw'],
    "parapākaruci": ['mw'],
    "parapākopabhojin": ['mw'],
    "parapārabhūta": ['mw'],
    "parapūruṣa": ['cae', 'mw'],
    "parapūrvatva": ['mw'],
    "parapūrvā": ['cae', 'mw'],
    "parapūrvāpati": ['mw'],
    "pararamaṇa": ['mw'],
    "pararu": ['mw'],
    "pararāṣṭra": ['mw'],
    "pararūpa": ['mw'],
    "pararūpatva": ['mw'],
    "paras": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "parasambandha": ['mw'],
    "parasambandhin": ['mw'],
    "parasasthāna": ['mw'],
    "parasavarṇa": ['mw'],
    "parasavarṇībhū": ['mw'],
    "parasaṃcāraka": ['mw'],
    "parasaṃgata": ['mw'],
    "parasaṃjñaka": ['mw'],
    "parasevā": ['ddsa', 'mw'],
    "parasmai": ['mw'],
    "parasmaibhāṣa": ['mw'],
    "parasmaibhāṣā": ['mw'],
    "parasmaipada": ['cae', 'ddsa', 'mw'],
    "parasmaipadaṃ": ['ap90'],
    "parasmaipadin": ['mw'],
    "paraspa": ['cae', 'mw'],
    "paraspara": ['ap90', 'cae', 'ddsa', 'mw'],
    "parasparahata": ['mw'],
    "parasparahita": ['mw'],
    "parasparajña": ['mw'],
    "parasparam": ['mw'],
    "parasparaprīti": ['mw'],
    "parasparasakhya": ['mw'],
    "parasparasamāgama": ['mw'],
    "parasparasthita": ['mw'],
    "parasparasukhaiṣin": ['mw'],
    "parasparatas": ['cae'],
    "parasparavibandhana": ['mw'],
    "parasparaviruddha": ['mw'],
    "parasparavivāda": ['mw'],
    "parasparavyāvṛtti": ['mw'],
    "parasparopakāra": ['mw'],
    "parasparopakārin": ['mw'],
    "parasparotpīḍana": ['mw'],
    "parasparādin": ['cae', 'mw'],
    "parasparākrandin": ['mw'],
    "parasparāmiṣatā": ['mw'],
    "parasparānumati": ['mw'],
    "parasparāsaṃsakti": ['bhs'],
    "parasparāśraya": ['mw'],
    "paraspatva": ['cae'],
    "paraspā": ['cae', 'gra', 'mw'],
    "parastaram": ['cae', 'gra', 'mw'],
    "parastarām": ['cae', 'ddsa', 'mw'],
    "parasthāna": ['cae', 'ddsa', 'mw'],
    "parastrī": ['mw'],
    "parastāt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "parasu": ['cped'],
    "parasuve": ['cped'],
    "parasva": ['cae', 'ddsa', 'mw'],
    "parasvadhaḥ": ['ap90'],
    "parasvagraha": ['mw'],
    "parasvaharaṇa": ['mw'],
    "parasvahṛt": ['mw'],
    "parasvant": ['cae'],
    "parasvat": ['gra', 'mw'],
    "parasvatva": ['mw'],
    "parasvatvāpādāna": ['mw'],
    "parasvehā": ['mw'],
    "parasvopajīvika": ['mw'],
    "parasvopajīvin": ['mw'],
    "parasvādāyin": ['cae', 'mw'],
    "parasātkṛ": ['ddsa', 'mw'],
    "paratalpa": ['mw'],
    "paratalpagāmin": ['mw'],
    "paratama": ['mw'],
    "paratantra": ['bhs', 'mw'],
    "paratantradṛṣṭi": ['mw'],
    "paratantrahaṃsopaniṣad": ['mw'],
    "paratantratā": ['mw'],
    "paratantrīkṛta": ['mw'],
    "paratara": ['bhs', 'ddsa', 'mw'],
    "paratarkaka": ['mw'],
    "paratarkuka": ['mw'],
    "paratas": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "paratastva": ['mw'],
    "paratattva": ['mw'],
    "paratattvanirṇaya": ['mw'],
    "paratattvaprakāśikā": ['mw'],
    "paratattvavāda": ['mw'],
    "parataḥpoṣa": ['mw'],
    "parataṅgaṇa": ['mw'],
    "paratoṣayitṛ": ['ddsa', 'mw'],
    "paratra": ['ap90', 'cae', 'ddsa', 'mw'],
    "paratrabhīru": ['mw'],
    "paratraṃ": ['bhs'],
    "parattha": ['cped'],
    "paratva": ['ddsa', 'mw'],
    "paratvaratnākara": ['mw'],
    "paratvaṃ": ['ap90'],
    "paratā": ['ddsa', 'mw'],
    "paratāpana": ['mw'],
    "paratīrthika": ['bhs', 'mw'],
    "parauru": ['mw'],
    "parauṣṇih": ['mw'],
    "parava": ['bhs'],
    "paravallabha": ['mw'],
    "paravambhana": ['cped'],
    "paravant": ['cae'],
    "paravarga": ['mw'],
    "paravastu": ['mw'],
    "paravat": ['ap90', 'mw'],
    "paravattā": ['ap90', 'cae', 'mw'],
    "paravaśa": ['cae', 'mw'],
    "paravaśya": ['mw'],
    "paravaśyatā": ['mw'],
    "paravaśākṣepa": ['mw'],
    "paraveśman": ['mw'],
    "paravisaya": ['cped'],
    "paravisenā": ['cped'],
    "paravitta": ['mw'],
    "paravrata": ['mw'],
    "paravyākṣepin": ['mw'],
    "paravyūhavināśana": ['mw'],
    "paravācya": ['mw'],
    "paravācyatā": ['mw'],
    "paravāda": ['cped', 'mw'],
    "paravādin": ['bhs', 'mw'],
    "paravādī": ['cped'],
    "paravākya": ['mw'],
    "paravāraṇa": ['cae', 'mw'],
    "paravāḍa": ['bhs'],
    "paravāṇi": ['mw'],
    "paravīrahan": ['cae', 'mw'],
    "parayoṣit": ['ddsa', 'mw'],
    "parayuvatiga": ['mw'],
    "paraś": ['mw'],
    "paraśa": ['mw'],
    "paraśakti": ['mw'],
    "paraśarīrāveśa": ['mw'],
    "paraśava": ['mw'],
    "paraśavya": ['mw'],
    "paraśaḥ": ['ap90'],
    "paraścatvāriṃśa": ['mw'],
    "paraśiva": ['mw'],
    "paraśivamahimastotra": ['mw'],
    "paraśivendrasarasvatī": ['mw'],
    "paraśrī": ['mw'],
    "paraśu": ['cae', 'ddsa', 'gra', 'mw'],
    "paraśuci": ['mw'],
    "paraśudhara": ['mw'],
    "paraśuhastā": ['mw'],
    "paraśumant": ['cae'],
    "paraśumat": ['gra', 'mw'],
    "paraśupalāśa": ['mw'],
    "paraśuphāṇṭa": ['mw'],
    "paraśurāma": ['cae', 'mw'],
    "paraśurāmajayantī": ['mw'],
    "paraśurāmaprakāśa": ['mw'],
    "paraśurāmapratāpa": ['mw'],
    "paraśurāmasūtra": ['mw'],
    "paraśurāmāvatāra": ['mw'],
    "paraśurāmāvatārakathana": ['mw'],
    "paraśuvana": ['mw'],
    "paraśuvanapradurbhāva": ['mw'],
    "paraśuvanasahasranāman": ['mw'],
    "paraśuḥ": ['ap90'],
    "paraśvadha": ['cae', 'ddsa', 'mw'],
    "paraśvadhaḥ": ['ap90'],
    "paraśvadhin": ['mw'],
    "paraśvadhāyudha": ['mw'],
    "paraśvan": ['mw'],
    "paraśvas": ['cae', 'ddsa', 'mw'],
    "paraśvat": ['mw'],
    "paraśāsana": ['mw'],
    "paraḥ": ['mw'],
    "paraḥkṛṣṇa": ['mw'],
    "paraḥpuruṣa": ['mw'],
    "paraḥpuṃsā": ['mw'],
    "paraḥsahasra": ['cae', 'ddsa', 'mw'],
    "paraḥsāman": ['mw'],
    "paraḥśata": ['cae', 'ddsa', 'mw'],
    "paraḥśatarggātha": ['mw'],
    "paraḥśvas": ['mw'],
    "paraḥṣaṣṭa": ['mw'],
    "paraṁ": ['cped'],
    "paraṁmaraṇā": ['cped'],
    "paraṃjanaḥ": ['ap90'],
    "paraṃjaḥ": ['ap90'],
    "paraṃpadaṃ": ['ap90'],
    "paraṃpara": ['ap90', 'cae'],
    "paraṃparabhojana": ['bhs'],
    "paraṃparāka": ['ap90'],
    "paraṃparīṇa": ['ap90'],
    "paraṃtapa": ['ap90', 'cae', 'mw'],
    "paraṃśakti": ['ddsa'],
    "paraṇa": ['gra', 'mw'],
    "paraṛkśatagātha": ['mw'],
    "parb": ['ap90', 'mw'],
    "parc": ['ddsa'],
    "pard": ['ap90', 'cae', 'mw'],
    "parda": ['mw'],
    "pardana": ['mw'],
    "pardaḥ": ['ap90'],
    "pardi": ['mw'],
    "pare": ['ap90', 'cae', 'ddsa', 'mw'],
    "paredyavi": ['ap90', 'cae', 'ddsa', 'mw'],
    "paredyus": ['mw'],
    "parekṣ": ['mw'],
    "pareman": ['mw'],
    "parepa": ['mw'],
    "pareprāṇa": ['ddsa', 'mw'],
    "pareta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "paretabhartṛ": ['mw'],
    "paretabhūmi": ['mw'],
    "paretakalpa": ['mw'],
    "paretara": ['ddsa', 'mw'],
    "paretarāj": ['mw'],
    "paretarāja": ['mw'],
    "pareti": ['cae', 'cped', 'gra', 'mw'],
    "paretiḥ": ['ap90'],
    "paretācarita": ['mw'],
    "paretāvāsa": ['mw'],
    "pareyivas": ['mw'],
    "pareśa": ['cae', 'mw'],
    "pareśeśa": ['mw'],
    "pareṅgitajñānaphala": ['ddsa'],
    "pareṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "pareṣṭaḥ": ['ap90'],
    "pareṣṭi": ['mw'],
    "pareṣṭu": ['mw'],
    "pareṣṭukā": ['mw'],
    "parhāṇa": ['mw'],
    "pari": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "paribaddha": ['mw'],
    "paribandh": ['mw'],
    "paribandhana": ['mw'],
    "paribarha": ['ddsa', 'mw'],
    "paribarhavat": ['mw'],
    "paribarhaḥ": ['ap90'],
    "paribarhaṇa": ['mw'],
    "paribarhaṇaṃ": ['ap90'],
    "paribarhaṇā": ['mw'],
    "paribaṃdh": ['ap90'],
    "paribaṃdhanaṃ": ['ap90'],
    "paribbajati": ['cped'],
    "paribbaji": ['cped'],
    "paribbaya": ['cped'],
    "paribbhamana": ['cped'],
    "paribbhamanta": ['cped'],
    "paribbhamati": ['cped'],
    "paribbhamesi": ['cped'],
    "paribbhameti": ['cped'],
    "paribbhametvā": ['cped'],
    "paribbhami": ['cped'],
    "paribbhamita": ['cped'],
    "paribbhamitvā": ['cped'],
    "paribbhanta": ['cped'],
    "paribbājaka": ['cped'],
    "paribbājikā": ['cped'],
    "paribbūḷha": ['cped'],
    "paribhagna": ['cae', 'mw'],
    "paribhagnakrama": ['mw'],
    "paribhaj": ['mw'],
    "paribhakṣ": ['mw'],
    "paribhakṣaṇa": ['mw'],
    "paribhakṣita": ['mw'],
    "paribhakṣā": ['mw'],
    "paribharts": ['mw'],
    "paribhartsana": ['mw'],
    "paribhartsanaṃ": ['ap90'],
    "paribhartsita": ['mw'],
    "paribhava": ['cae', 'cped', 'mw'],
    "paribhavamāna": ['cped'],
    "paribhavana": ['cae', 'cped', 'mw'],
    "paribhavanta": ['cped'],
    "paribhavanīya": ['cae', 'mw'],
    "paribhavapada": ['mw'],
    "paribhavati": ['cped'],
    "paribhavavidhi": ['mw'],
    "paribhavaḥ": ['ap90'],
    "paribhavi": ['cped'],
    "paribhavin": ['ap90', 'cae', 'mw'],
    "paribhavitvā": ['cped'],
    "paribhavāspada": ['mw'],
    "paribhaya": ['ddsa', 'mw'],
    "paribhaṃgaḥ": ['ap90'],
    "paribhaṅga": ['mw'],
    "paribhaṇḍa": ['cped'],
    "paribhaṇḍakata": ['cped'],
    "paribhaṭṭha": ['cped'],
    "paribheda": ['bhs', 'mw'],
    "paribhedaka": ['mw'],
    "paribhid": ['mw'],
    "paribhinna": ['ap90', 'cped', 'mw'],
    "paribhoga": ['bhs', 'cae', 'cped', 'mw'],
    "paribhogacetiya": ['cped'],
    "paribhogaḥ": ['ap90'],
    "paribhogin": ['cae'],
    "paribhogya": ['bhs', 'mw'],
    "paribhogīya": ['bhs'],
    "paribhojanīya": ['cped'],
    "paribhojanīyudaka": ['cped'],
    "paribhojya": ['bhs'],
    "paribhoktṛ": ['ap90', 'cae', 'mw'],
    "paribhrajj": ['mw'],
    "paribhram": ['ap90', 'mw'],
    "paribhrama": ['cae', 'mw'],
    "paribhramaḥ": ['ap90'],
    "paribhramaṇa": ['cae', 'mw'],
    "paribhramaṇaṃ": ['ap90'],
    "paribhraṃś": ['ap90', 'mw'],
    "paribhraṃśa": ['cae', 'mw'],
    "paribhraṃśana": ['cae', 'mw'],
    "paribhraṃśanaṃ": ['ap90'],
    "paribhraṃśaḥ": ['ap90'],
    "paribhraṣṭa": ['ap90', 'cae', 'mw'],
    "paribhraṣṭasatkarman": ['mw'],
    "paribhraṣṭasukha": ['mw'],
    "paribhrāj": ['mw'],
    "paribhrāmaṇa": ['cae', 'mw'],
    "paribhrāmin": ['mw'],
    "paribhugna": ['ap90', 'mw'],
    "paribhuj": ['ap90', 'mw'],
    "paribhukta": ['ap90', 'bhs', 'mw'],
    "paribhuktaka": ['bhs'],
    "paribhukṣita": ['bhs'],
    "paribhutta": ['cped'],
    "paribhutvā": ['cped'],
    "paribhuñjamāna": ['cped'],
    "paribhuñjanta": ['cped'],
    "paribhuñjati": ['cped'],
    "paribhuñji": ['cped'],
    "paribhuñjitabba": ['cped'],
    "paribhuñjitvā": ['cped'],
    "paribhuñjiya": ['cped'],
    "paribhās": ['mw'],
    "paribhāsa": ['cped'],
    "paribhāsaka": ['cped'],
    "paribhāsamāna": ['cped'],
    "paribhāsana": ['cped'],
    "paribhāsati": ['cped'],
    "paribhāsi": ['cped'],
    "paribhāsita": ['cped', 'mw'],
    "paribhāsitvā": ['cped'],
    "paribhāva": ['cae', 'mw'],
    "paribhāvana": ['mw'],
    "paribhāvanaṃ": ['ap90'],
    "paribhāvanā": ['mw'],
    "paribhāvaḥ": ['ap90'],
    "paribhāvin": ['ap90', 'cae', 'mw'],
    "paribhāvita": ['ap90', 'bhs', 'cped', 'mw'],
    "paribhāvitatva": ['mw'],
    "paribhāvuka": ['ap90', 'cae', 'mw'],
    "paribhāṇḍa": ['mw'],
    "paribhāṣ": ['ap90', 'mw'],
    "paribhāṣaka": ['bhs', 'mw'],
    "paribhāṣati": ['bhs'],
    "paribhāṣaṇa": ['bhs', 'cae', 'mw'],
    "paribhāṣaṇaṃ": ['ap90'],
    "paribhāṣaṇīya": ['mw'],
    "paribhāṣendubhāskara": ['mw'],
    "paribhāṣenduśekhara": ['cae', 'mw'],
    "paribhāṣenduśekharasaṃgraha": ['mw'],
    "paribhāṣin": ['mw'],
    "paribhāṣita": ['mw'],
    "paribhāṣitatva": ['mw'],
    "paribhāṣopaskāra": ['mw'],
    "paribhāṣya": ['mw'],
    "paribhāṣā": ['ap90', 'cae', 'mw'],
    "paribhāṣābhāskara": ['mw'],
    "paribhāṣābhāṣyasūtra": ['mw'],
    "paribhāṣāchandomañjarī": ['mw'],
    "paribhāṣākroḍapattra": ['mw'],
    "paribhāṣāmañjarī": ['mw'],
    "paribhāṣāpradīpa": ['mw'],
    "paribhāṣāpradīpārcis": ['mw'],
    "paribhāṣāprakaraṇa": ['mw'],
    "paribhāṣāprakāśa": ['mw'],
    "paribhāṣāprakāśikā": ['mw'],
    "paribhāṣārahasya": ['mw'],
    "paribhāṣārthamañjarī": ['mw'],
    "paribhāṣārthasaṃgraha": ['mw'],
    "paribhāṣāsaṃgraha": ['mw'],
    "paribhāṣāsāra": ['mw'],
    "paribhāṣāsārasaṃgraha": ['mw'],
    "paribhāṣāsūtra": ['mw'],
    "paribhāṣāviveka": ['mw'],
    "paribhāṣāviśeṣa": ['mw'],
    "paribhāṣāvṛtti": ['mw'],
    "paribhāṣāśiromaṇi": ['mw'],
    "paribhāṣāṅkasūtra": ['mw'],
    "paribhāṣāṭīkā": ['mw'],
    "paribhū": ['ap90', 'cae', 'gra', 'mw'],
    "paribhūta": ['cped', 'mw'],
    "paribhūtagatitraya": ['mw'],
    "paribhūtaka": ['bhs'],
    "paribhūtatā": ['mw'],
    "paribhūti": ['cae', 'gra', 'mw'],
    "paribhūtiḥ": ['ap90'],
    "paribhūṣ": ['ap90', 'mw'],
    "paribhūṣaṇa": ['mw'],
    "paribhūṣaṇaḥ": ['ap90'],
    "paribhūṣita": ['mw'],
    "paribhṛ": ['mw'],
    "paribhṛṣṭa": ['mw'],
    "paribodha": ['mw'],
    "paribodhana": ['mw'],
    "paribodhanīya": ['mw'],
    "paribodhavat": ['mw'],
    "paribrū": ['mw'],
    "paribrūhati": ['cped'],
    "paribubhukṣita": ['bhs', 'mw'],
    "paribudhyati": ['bhs'],
    "paribādh": ['ap90', 'cae', 'gra', 'mw'],
    "paribādha": ['mw'],
    "paribādhā": ['ap90', 'cae', 'mw'],
    "paribāhira": ['bhs', 'cped'],
    "paribāhya": ['bhs'],
    "paribṛḍha": ['cae', 'mw'],
    "paribṛṃh": ['ap90', 'mw'],
    "paribṛṃhaṇa": ['cae', 'mw'],
    "paribṛṃhaṇaṃ": ['ap90'],
    "paribṛṃhita": ['ap90', 'mw'],
    "paricakra": ['mw'],
    "paricakrā": ['mw'],
    "paricakṣ": ['ap90', 'mw'],
    "paricakṣia": ['gra'],
    "paricakṣya": ['cae', 'gra', 'mw'],
    "paricakṣā": ['ap90', 'cae', 'mw'],
    "parical": ['mw'],
    "paricapala": ['mw'],
    "paricar": ['ap90', 'mw'],
    "paricara": ['ap90', 'cae', 'mw'],
    "paricarati": ['cped'],
    "paricaraṇa": ['cae', 'cped', 'mw'],
    "paricaraṇaḥ": ['ap90'],
    "paricaraṇā": ['bhs'],
    "paricaraṇīya": ['mw'],
    "paricari": ['cped'],
    "paricaritavya": ['mw'],
    "paricaritvā": ['cped'],
    "paricaritṛ": ['ap90', 'mw'],
    "paricarmaṇya": ['mw'],
    "paricarmaṇyaṃ": ['ap90'],
    "paricartana": ['mw'],
    "paricarya": ['cae', 'mw'],
    "paricaryā": ['ap90', 'bhs', 'mw'],
    "paricaryāvat": ['mw'],
    "paricarā": ['mw'],
    "paricaturdaśa": ['mw'],
    "paricaturdaśan": ['ap90', 'mw'],
    "paricaya": ['cae', 'cped', 'ddsa', 'mw'],
    "paricayanīya": ['mw'],
    "paricayavant": ['cae'],
    "paricayavat": ['mw'],
    "paricayaḥ": ['ap90'],
    "paricayāvasthā": ['mw'],
    "paricca": ['cped'],
    "pariccajana": ['cped'],
    "pariccajanta": ['cped'],
    "pariccajati": ['cped'],
    "pariccaji": ['cped'],
    "pariccajituṁ": ['cped'],
    "pariccajitvā": ['cped'],
    "pariccatta": ['cped'],
    "paricchad": ['ap90', 'ddsa', 'mw'],
    "paricchada": ['cae', 'mw'],
    "paricchadaḥ": ['ap90'],
    "paricchanda": ['mw'],
    "paricchanna": ['ap90', 'cae', 'cped', 'mw'],
    "paricchaṃdaḥ": ['ap90'],
    "pariccheda": ['cae', 'cped', 'mw'],
    "paricchedaka": ['mw'],
    "paricchedakara": ['mw'],
    "paricchedakaṃ": ['ap90'],
    "paricchedana": ['mw'],
    "paricchedanaṃ": ['ap90'],
    "paricchedavyakti": ['mw'],
    "paricchedaḥ": ['ap90'],
    "paricchedya": ['ap90', 'mw'],
    "paricchedākula": ['mw'],
    "paricchedātīta": ['mw'],
    "paricchid": ['ap90', 'mw'],
    "paricchijja": ['cped'],
    "paricchindana": ['cped'],
    "paricchindati": ['cped'],
    "paricchindi": ['cped'],
    "paricchindiya": ['cped'],
    "paricchinna": ['ap90', 'cped', 'mw'],
    "paricchinnatva": ['mw'],
    "paricchitti": ['mw'],
    "paricchittiḥ": ['ap90'],
    "paricchādanā": ['cped'],
    "pariccāga": ['cped'],
    "paricetar": ['bhs'],
    "paricetas": ['mw'],
    "paricetavya": ['mw'],
    "pariceya": ['mw'],
    "parichedakara": ['bhs'],
    "parichinattī": ['bhs'],
    "parici": ['ap90', 'mw'],
    "paricihnita": ['mw'],
    "paricint": ['mw'],
    "paricintaka": ['mw'],
    "paricintanīya": ['mw'],
    "paricintita": ['mw'],
    "paricit": ['mw'],
    "paricita": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "paricitabhū": ['mw'],
    "paricitavivikta": ['mw'],
    "pariciti": ['cae', 'mw'],
    "paricitiḥ": ['ap90'],
    "pariciṃt": ['ap90'],
    "pariciṃtanaṃ": ['ap90'],
    "pariciṇṇa": ['cped'],
    "paricodita": ['mw'],
    "paricud": ['mw'],
    "paricumb": ['mw'],
    "paricumbana": ['mw'],
    "paricumbati": ['cped'],
    "paricumbi": ['cped'],
    "paricumbita": ['cped', 'mw'],
    "paricuṃb": ['ap90'],
    "paricuṃbanaṃ": ['ap90'],
    "paricyavana": ['mw'],
    "paricyu": ['ap90'],
    "paricyuta": ['mw'],
    "paricyuti": ['mw'],
    "paricyutiḥ": ['ap90'],
    "paricāra": ['cae', 'mw'],
    "paricāraka": ['cae', 'cped', 'mw'],
    "paricārakaḥ": ['ap90'],
    "paricāraya": ['mw'],
    "paricārayati": ['bhs'],
    "paricāraḥ": ['ap90'],
    "paricāraṇa": ['bhs', 'mw'],
    "paricāresi": ['cped'],
    "paricāreti": ['cped'],
    "paricāretvā": ['cped'],
    "paricārika": ['bhs', 'mw'],
    "paricārikā": ['ap90', 'mw'],
    "paricārin": ['cae', 'mw'],
    "paricārita": ['cped', 'mw'],
    "paricāritā": ['mw'],
    "paricāriṇī": ['mw'],
    "paricārya": ['mw'],
    "paricāyya": ['mw'],
    "paricāyyaḥ": ['ap90'],
    "paricīrṇa": ['mw'],
    "paricūrṇayati": ['bhs'],
    "paricṛt": ['mw'],
    "paridagdha": ['mw'],
    "paridah": ['ap90', 'mw'],
    "paridahana": ['bhs', 'cped', 'mw'],
    "paridahanaṃ": ['ap90'],
    "paridahati": ['cped'],
    "paridahi": ['cped'],
    "paridahita": ['cped'],
    "paridahitvā": ['cped'],
    "paridahyati": ['bhs'],
    "paridamana": ['bhs'],
    "paridara": ['mw'],
    "paridaraḥ": ['ap90'],
    "paridaśa": ['bhs', 'mw'],
    "paridaḍḍha": ['cped'],
    "paridaṃśita": ['ap90', 'mw'],
    "paridaṣṭa": ['mw'],
    "paridaṣṭadacchada": ['mw'],
    "parideva": ['cae', 'cped', 'mw'],
    "paridevaka": ['mw'],
    "paridevamāna": ['cped'],
    "paridevana": ['mw'],
    "paridevanaṃ": ['ap90'],
    "paridevanta": ['cped'],
    "paridevanā": ['cped', 'mw'],
    "paridevati": ['cped'],
    "paridevaḥ": ['ap90'],
    "paridevi": ['cped'],
    "paridevin": ['cae', 'mw'],
    "paridevita": ['cae', 'cped', 'mw'],
    "paridevitam": ['mw'],
    "paridevitvā": ['cped'],
    "paridharṣaṇa": ['mw'],
    "paridharṣaṇaṃ": ['ap90'],
    "paridhauta": ['bhs'],
    "paridhaṁsaka": ['cped'],
    "paridheya": ['mw'],
    "paridheyaṃ": ['ap90'],
    "paridhi": ['cae', 'gra', 'mw'],
    "paridhin": ['mw'],
    "paridhisaṃdhi": ['mw'],
    "paridhistha": ['mw'],
    "paridhiḥ": ['ap90'],
    "paridhota": ['cped'],
    "paridhovati": ['cped'],
    "paridhovi": ['cped'],
    "paridhvasta": ['cae', 'mw'],
    "paridhvaṃsa": ['cae', 'mw'],
    "paridhvaṃsaḥ": ['ap90'],
    "paridhvaṃsin": ['cae', 'mw'],
    "paridhyupānta": ['mw'],
    "paridhā": ['ap90', 'mw'],
    "paridhāna": ['cae', 'ddsa', 'mw'],
    "paridhānavastra": ['mw'],
    "paridhānaṃ": ['ap90'],
    "paridhānā": ['mw'],
    "paridhānīkṛ": ['mw'],
    "paridhānīya": ['mw'],
    "paridhānīyaṃ": ['ap90'],
    "paridhānīyā": ['mw'],
    "paridhāpana": ['mw'],
    "paridhāpanīya": ['mw'],
    "paridhāraṇa": ['mw'],
    "paridhāraṇaṃ": ['ap90'],
    "paridhāraṇā": ['mw'],
    "paridhārya": ['mw'],
    "paridhāv": ['ap90', 'mw'],
    "paridhāvana": ['bhs', 'mw'],
    "paridhāvati": ['cped'],
    "paridhāvi": ['cped'],
    "paridhāvin": ['ap90', 'mw'],
    "paridhāvita": ['cped'],
    "paridhāvitvā": ['cped'],
    "paridhāya": ['mw'],
    "paridhāyaka": ['mw'],
    "paridhāyakaḥ": ['ap90'],
    "paridhāyaḥ": ['ap90'],
    "paridhīkṛ": ['mw'],
    "paridhīra": ['mw'],
    "paridhū": ['mw'],
    "paridhūmana": ['mw'],
    "paridhūmāyana": ['mw'],
    "paridhūpana": ['mw'],
    "paridhūpita": ['ap90'],
    "paridhūsara": ['ap90', 'cae', 'mw'],
    "paridhūsaratva": ['mw'],
    "paridhṛ": ['mw'],
    "paridhṛta": ['mw'],
    "paridhṛṣ": ['mw'],
    "paridigdha": ['mw'],
    "paridih": ['mw'],
    "paridiv": ['ap90', 'mw'],
    "paridiś": ['mw'],
    "paridiṣṭa": ['mw'],
    "paridrava": ['bhs'],
    "paridraḍhaya": ['mw'],
    "paridraṣṭṛ": ['ap90', 'mw'],
    "paridru": ['mw'],
    "paridu": ['mw'],
    "paridurbala": ['mw'],
    "paridurbalatva": ['mw'],
    "paridveṣas": ['gra', 'mw'],
    "paridvīpa": ['mw'],
    "paridyāna": ['bhs'],
    "paridyūna": ['ap90', 'cae', 'mw'],
    "paridā": ['ap90', 'cae', 'mw'],
    "paridāgha": ['bhs'],
    "paridāha": ['bhs', 'ddsa', 'mw'],
    "paridāhaḥ": ['ap90'],
    "paridāhin": ['mw'],
    "paridāna": ['mw'],
    "paridānaṃ": ['ap90'],
    "paridāyin": ['ap90', 'mw'],
    "paridīna": ['mw'],
    "paridīnamānasa": ['mw'],
    "paridīnasattva": ['mw'],
    "paridīp": ['mw'],
    "paridīpaka": ['cped'],
    "paridīpana": ['bhs', 'cped'],
    "paridīpanā": ['cped'],
    "paridīpayati": ['bhs'],
    "paridīpenta": ['cped'],
    "paridīpesi": ['cped'],
    "paridīpeti": ['cped'],
    "paridīpetvā": ['cped'],
    "paridīpita": ['cped'],
    "paridīrṇa": ['cae', 'mw'],
    "paridūsesi": ['cped'],
    "paridūseti": ['cped'],
    "paridūsetvā": ['cped'],
    "paridūsita": ['cped'],
    "paridṛś": ['ap90', 'mw'],
    "paridṛḍha": ['mw'],
    "paridṛṃhaṇa": ['mw'],
    "paridṛṣṭa": ['mw'],
    "paridṛṣṭakarman": ['mw'],
    "paridṛṣṭakarmatā": ['mw'],
    "paridṝ": ['mw'],
    "parietṛ": ['gra'],
    "pariga": ['bhs', 'mw'],
    "parigad": ['mw'],
    "parigadhitā": ['mw'],
    "parigaditin": ['mw'],
    "parigaggahita": ['cped'],
    "parigahana": ['mw'],
    "parigai": ['ap90', 'mw'],
    "parigalita": ['ap90', 'cae', 'mw'],
    "parigam": ['ap90', 'mw'],
    "parigama": ['cae', 'mw'],
    "parigamana": ['mw'],
    "parigamaḥ": ['ap90'],
    "parigamita": ['mw'],
    "parigamya": ['mw'],
    "parigantavya": ['mw'],
    "parigardha": ['bhs'],
    "parigarh": ['mw'],
    "parigarhaṇa": ['mw'],
    "parigarhaṇaṃ": ['ap90'],
    "parigarj": ['mw'],
    "parigarvita": ['mw'],
    "parigata": ['ap90', 'cae', 'mw'],
    "parigatārtha": ['cae', 'mw'],
    "parigaveṣate": ['bhs'],
    "parigaveṣatā": ['bhs'],
    "parigaveṣaṇa": ['bhs'],
    "parigaṇ": ['ap90', 'mw'],
    "parigaṇa": ['bhs', 'mw'],
    "parigaṇana": ['cae', 'ddsa', 'mw'],
    "parigaṇanaṃ": ['ap90'],
    "parigaṇanā": ['mw'],
    "parigaṇanīya": ['mw'],
    "parigaṇhana": ['cped'],
    "parigaṇhanta": ['cped'],
    "parigaṇhetvā": ['cped'],
    "parigaṇhi": ['cped'],
    "parigaṇhitvā": ['cped'],
    "parigaṇhāti": ['cped'],
    "parigaṇita": ['mw'],
    "parigaṇitin": ['cae', 'mw'],
    "parigaṇya": ['mw'],
    "pariggaha": ['cped'],
    "pariggahita": ['cped'],
    "pariggayha": ['cped'],
    "parigha": ['cae', 'ddsa', 'mw'],
    "parighabāhu": ['mw'],
    "parighaguru": ['mw'],
    "parighaprāṃśubāhu": ['mw'],
    "parighareti": ['bhs'],
    "parighargharam": ['mw'],
    "parigharmaḥ": ['ap90'],
    "parigharmya": ['cae', 'mw'],
    "parighasaṃkāśa": ['mw'],
    "parighastambha": ['cae', 'mw'],
    "parighaḥ": ['ap90'],
    "parighaṭ": ['mw'],
    "parighaṭṭ": ['ap90', 'mw'],
    "parighaṭṭana": ['mw'],
    "parighaṭṭanaṃ": ['ap90'],
    "parighaṭṭanā": ['mw'],
    "parighaṭṭita": ['mw'],
    "parighopama": ['mw'],
    "parighoṣa": ['mw'],
    "parighoṣaḥ": ['ap90'],
    "parighrā": ['mw'],
    "parighuṣ": ['mw'],
    "parighāta": ['mw'],
    "parighātana": ['mw'],
    "parighātaḥ": ['ap90'],
    "parighātin": ['mw'],
    "parighūrṇ": ['mw'],
    "parighṛṣ": ['mw'],
    "parighṛṣṭika": ['mw'],
    "parigilati": ['cped'],
    "parigili": ['cped'],
    "parigilita": ['cped'],
    "parigilitvā": ['cped'],
    "pariglāna": ['ap90', 'cae', 'mw'],
    "parigodha": ['bhs'],
    "parigohya": ['bhs'],
    "parigrah": ['ap90', 'mw'],
    "parigraha": ['bhs', 'cae', 'mw'],
    "parigrahabahutva": ['mw'],
    "parigrahadvitīya": ['mw'],
    "parigrahaka": ['mw'],
    "parigrahamaya": ['mw'],
    "parigrahatva": ['mw'],
    "parigrahavat": ['mw'],
    "parigrahaḥ": ['ap90'],
    "parigrahaṇa": ['cae', 'mw'],
    "parigrahaṇaṃ": ['ap90'],
    "parigrahin": ['mw'],
    "parigrahārthīya": ['mw'],
    "parigrahītavya": ['mw'],
    "parigrahītṛ": ['ap90', 'cae', 'mw'],
    "parigras": ['mw'],
    "parigredha": ['bhs', 'mw'],
    "parigrāha": ['cae', 'mw'],
    "parigrāhaka": ['bhs', 'mw'],
    "parigrāhaḥ": ['ap90'],
    "parigrāhya": ['mw'],
    "parigup": ['mw'],
    "pariguṇita": ['mw'],
    "pariguṇḍita": ['mw'],
    "pariguṇṭhita": ['mw'],
    "parigā": ['mw'],
    "parigāḍham": ['cae'],
    "parigīta": ['mw'],
    "parigīti": ['ap90', 'mw'],
    "parigūhanā": ['cped'],
    "parigūhati": ['cped'],
    "parigūhi": ['cped'],
    "parigūhita": ['cped'],
    "parigūhitvā": ['cped'],
    "parigūhiya": ['cped'],
    "parigūḍha": ['ap90'],
    "parigūḍhaka": ['mw'],
    "parigūḷha": ['cped'],
    "parigṛddha": ['bhs', 'mw'],
    "parigṛhya": ['cae', 'mw'],
    "parigṛhyavat": ['mw'],
    "parigṛhyā": ['ap90', 'mw'],
    "parigṛhīta": ['ap90', 'bhs', 'cae', 'mw'],
    "parigṛhīti": ['cae', 'mw'],
    "parigṛhītiḥ": ['ap90'],
    "parigṛhītṛ": ['mw'],
    "parihan": ['mw'],
    "parihara": ['cae', 'ddsa', 'mw'],
    "pariharaka": ['mw'],
    "pariharati": ['bhs', 'cped'],
    "pariharaṇa": ['cae', 'cped', 'mw'],
    "pariharaṇaṃ": ['ap90'],
    "pariharaṇā": ['cped'],
    "pariharaṇīya": ['cae', 'mw'],
    "pariharaṇīyatā": ['mw'],
    "parihari": ['cped'],
    "pariharita": ['cped'],
    "pariharitabba": ['cped'],
    "pariharitvā": ['cped'],
    "parihartavya": ['cae', 'mw'],
    "pariharṣaṇa": ['mw'],
    "pariharṣin": ['mw'],
    "pariharṣita": ['mw'],
    "parihas": ['ap90', 'mw'],
    "parihasati": ['cped'],
    "parihasi": ['cped'],
    "parihasita": ['mw'],
    "parihasitvā": ['cped'],
    "parihasta": ['mw'],
    "parihastaḥ": ['ap90'],
    "parihata": ['ap90', 'mw'],
    "parihava": ['mw'],
    "parihaṇana": ['mw'],
    "parihaṭa": ['cped'],
    "parihi": ['mw'],
    "parihita": ['cae', 'mw'],
    "parihiṃsā": ['mw'],
    "parihiṇḍ": ['mw'],
    "parihrut": ['cae', 'gra', 'mw'],
    "parihvālam": ['mw'],
    "parihvṛt": ['gra'],
    "parihvṛta": ['mw'],
    "parihvṛti": ['cae', 'gra', 'mw'],
    "parihā": ['ap90', 'mw'],
    "parihāni": ['cae', 'cped', 'mw'],
    "parihāniya": ['cped'],
    "parihāniḥ": ['ap90'],
    "parihāpaṇa": ['bhs'],
    "parihāpaṇīya": ['mw'],
    "parihāpesi": ['cped'],
    "parihāpeti": ['cped'],
    "parihāpetvā": ['cped'],
    "parihāpita": ['bhs', 'cped', 'mw'],
    "parihāpya": ['mw'],
    "parihāra": ['bhs', 'cae', 'cped', 'mw'],
    "parihāraka": ['bhs', 'cped', 'mw'],
    "parihārapatha": ['cped'],
    "parihārasthāna": ['mw'],
    "parihārasū": ['mw'],
    "parihāravat": ['mw'],
    "parihāraviśuddhi": ['mw'],
    "parihāraḥ": ['ap90'],
    "parihārika": ['cped'],
    "parihārikā": ['mw'],
    "parihārin": ['cae', 'mw'],
    "parihārya": ['ap90', 'bhs', 'cae', 'mw'],
    "parihāsa": ['cae', 'cped', 'ddsa', 'mw'],
    "parihāsahari": ['mw'],
    "parihāsakathā": ['mw'],
    "parihāsanimittam": ['cae'],
    "parihāsapura": ['mw'],
    "parihāsapūrvam": ['mw'],
    "parihāsavastu": ['mw'],
    "parihāsavastutā": ['mw'],
    "parihāsavedin": ['mw'],
    "parihāsavijalpita": ['mw'],
    "parihāsaśīla": ['cae', 'mw'],
    "parihāsaśīlatā": ['mw'],
    "parihāsaḥ": ['ap90'],
    "parihāsya": ['mw'],
    "parihāyamāna": ['cped'],
    "parihāyati": ['cped'],
    "parihāyi": ['cped'],
    "parihāyitvā": ['cped'],
    "parihāṇa": ['bhs', 'mw'],
    "parihāṇaṃ": ['ap90'],
    "parihāṇi": ['cae', 'mw'],
    "parihāṇikā": ['bhs'],
    "parihāṇiḥ": ['ap90'],
    "parihāṭaka": ['bhs', 'mw'],
    "parihīna": ['cped'],
    "parihīṇa": ['ap90', 'cae', 'mw'],
    "parihūta": ['mw'],
    "parihṇuta": ['mw'],
    "parihṛ": ['ap90', 'mw'],
    "parihṛta": ['ap90', 'mw'],
    "parihṛti": ['cae', 'mw'],
    "parihṛtiḥ": ['ap90'],
    "parihṛtya": ['mw'],
    "parihṛṣ": ['mw'],
    "parihṛṣita": ['cae', 'mw'],
    "parihṛṣṭa": ['cae', 'mw'],
    "parihṛṣṭamānasa": ['mw'],
    "parijagdha": ['mw'],
    "parijalp": ['mw'],
    "parijalpita": ['mw'],
    "parijalpitaṃ": ['ap90'],
    "parijana": ['cae', 'cped', 'ddsa', 'mw'],
    "parijanatā": ['mw'],
    "parijanaḥ": ['ap90'],
    "parijanman": ['ap90', 'mw'],
    "parijapati": ['bhs'],
    "parijapita": ['mw'],
    "parijapta": ['mw'],
    "parijarbhurāṇa": ['mw'],
    "parijaya": ['bhs'],
    "parijayati": ['bhs'],
    "parijayya": ['mw'],
    "parijetar": ['bhs'],
    "parijetṛ": ['mw'],
    "pariji": ['mw'],
    "parijihīrṣita": ['mw'],
    "parijihīrṣu": ['mw'],
    "parijihīrṣā": ['mw'],
    "parijita": ['bhs'],
    "parijjiṇṇa": ['cped'],
    "parijman": ['ap90', 'cae', 'gra', 'mw'],
    "parijri": ['ap90', 'cae', 'gra', 'mw'],
    "parijval": ['mw'],
    "parijvan": ['ap90', 'mw'],
    "parijyāni": ['mw'],
    "parijñapti": ['mw'],
    "parijñaptiḥ": ['ap90'],
    "parijñeya": ['ap90', 'cae', 'mw'],
    "parijñā": ['ap90', 'bhs', 'mw'],
    "parijñāna": ['cae', 'mw'],
    "parijñānamaya": ['mw'],
    "parijñānatā": ['bhs'],
    "parijñānin": ['mw'],
    "parijñāta": ['bhs', 'cae', 'mw'],
    "parijñātabhojana": ['bhs'],
    "parijñātāvin": ['bhs'],
    "parijñātṛ": ['mw'],
    "parijā": ['mw'],
    "parijāgarati": ['bhs'],
    "parijānana": ['cped'],
    "parijānanta": ['cped'],
    "parijānanā": ['cped'],
    "parijāni": ['cped'],
    "parijānitvā": ['cped'],
    "parijānāti": ['cped'],
    "parijāta": ['bhs', 'mw'],
    "parijātaka": ['mw'],
    "parijīryat": ['mw'],
    "parijīrṇa": ['mw'],
    "parijūna": ['bhs'],
    "parijūnya": ['bhs'],
    "parijṛmbh": ['mw'],
    "parijṝ": ['mw'],
    "parikal": ['ap90', 'mw'],
    "parikalayitṛ": ['mw'],
    "parikalitaṃ": ['ap90'],
    "parikalitin": ['mw'],
    "parikalkana": ['mw'],
    "parikalkanaṃ": ['ap90'],
    "parikalpa": ['bhs', 'mw'],
    "parikalpana": ['mw'],
    "parikalpanaṃ": ['ap90'],
    "parikalpanā": ['cae', 'mw'],
    "parikalpayati": ['bhs'],
    "parikalpita": ['ap90', 'mw'],
    "parikalpya": ['mw'],
    "parikamma": ['cped'],
    "parikammakata": ['cped'],
    "parikammakāraka": ['cped'],
    "parikamp": ['mw'],
    "parikampa": ['mw'],
    "parikampin": ['ddsa', 'mw'],
    "parikandala": ['mw'],
    "parikantati": ['cped'],
    "parikanti": ['cped'],
    "parikantita": ['cped'],
    "parikantitvā": ['cped'],
    "parikappa": ['cped'],
    "parikappesi": ['cped'],
    "parikappeti": ['cped'],
    "parikappetvā": ['cped'],
    "parikappita": ['cped'],
    "parikara": ['cae', 'mw'],
    "parikarabandha": ['mw'],
    "parikarabhūta": ['mw'],
    "parikarati": ['bhs'],
    "parikaravijaya": ['mw'],
    "parikaraśloka": ['mw'],
    "parikaraḥ": ['ap90'],
    "parikaraṇa": ['bhs'],
    "parikarita": ['mw'],
    "parikarkaśa": ['mw'],
    "parikarmakathā": ['bhs', 'mw'],
    "parikarman": ['ap90', 'cae', 'mw'],
    "parikarmaya": ['mw'],
    "parikarmayati": ['ap90'],
    "parikarmaṇa": ['bhs'],
    "parikarmin": ['ap90', 'cae', 'mw'],
    "parikarmita": ['mw'],
    "parikarmāṣṭaka": ['mw'],
    "parikarmīkaroti": ['bhs'],
    "parikarta": ['mw'],
    "parikartana": ['mw'],
    "parikartanaṃ": ['ap90'],
    "parikartikā": ['ap90', 'mw'],
    "parikartṛ": ['ap90', 'mw'],
    "parikarṣa": ['cae', 'mw'],
    "parikarṣaka": ['bhs'],
    "parikarṣayati": ['bhs'],
    "parikarṣaḥ": ['ap90'],
    "parikarṣaṇa": ['bhs', 'mw'],
    "parikarṣin": ['mw'],
    "parikarṣita": ['ap90', 'mw'],
    "parikassati": ['cped'],
    "parikassi": ['cped'],
    "parikassita": ['cped'],
    "parikath": ['mw'],
    "parikathā": ['ap90', 'bhs', 'cped', 'mw'],
    "parikaḍḍhana": ['cped'],
    "parikaḍḍhati": ['cped'],
    "parikaḍḍhi": ['cped'],
    "parikaḍḍhita": ['cped'],
    "parikaḍḍhitvā": ['cped'],
    "parikaṃpaḥ": ['ap90'],
    "parikaṭṭaka": ['bhs'],
    "parikaṭṭati": ['bhs'],
    "parikeśa": ['mw'],
    "parikha": ['bhs'],
    "parikhacita": ['cae', 'mw'],
    "parikhan": ['mw'],
    "parikhanati": ['bhs'],
    "parikhata": ['cped'],
    "parikhaṃḍayati": ['ap90'],
    "parikhaṇati": ['cped'],
    "parikhaṇi": ['cped'],
    "parikhaṇitvā": ['cped'],
    "parikhaṇḍa": ['bhs', 'mw'],
    "parikhaṇḍana": ['ddsa', 'mw'],
    "parikhaṇḍaya": ['mw'],
    "parikheda": ['cae', 'mw'],
    "parikhedaḥ": ['ap90'],
    "parikhedita": ['mw'],
    "parikhid": ['ap90', 'mw'],
    "parikhinna": ['ap90', 'cae', 'mw'],
    "parikhyā": ['ap90', 'mw'],
    "parikhyāta": ['mw'],
    "parikhyāti": ['mw'],
    "parikhyātiḥ": ['ap90'],
    "parikhā": ['ap90', 'cae', 'cped', 'mw'],
    "parikhāsthita": ['mw'],
    "parikhāta": ['mw'],
    "parikhātaṃ": ['ap90'],
    "parikhīkṛta": ['mw'],
    "parikilamati": ['cped'],
    "parikilami": ['cped'],
    "parikilamitvā": ['cped'],
    "parikilanta": ['cped'],
    "parikilinna": ['cped'],
    "parikilissana": ['cped'],
    "parikilissati": ['cped'],
    "parikilissi": ['cped'],
    "parikilissitvā": ['cped'],
    "parikiliṭṭha": ['cped'],
    "parikirati": ['cped'],
    "parikiraṇa": ['mw'],
    "parikiri": ['cped'],
    "parikiritvā": ['cped'],
    "parikiriya": ['cped'],
    "parikittesi": ['cped'],
    "parikitteti": ['cped'],
    "parikittita": ['cped'],
    "parikiṇṇa": ['cped'],
    "parikkamana": ['cped'],
    "parikkhaka": ['cped'],
    "parikkhata": ['cped'],
    "parikkhati": ['cped'],
    "parikkhaya": ['cped'],
    "parikkhaṇa": ['cped'],
    "parikkhepa": ['cped'],
    "parikkhi": ['cped'],
    "parikkhipanta": ['cped'],
    "parikkhipati": ['cped'],
    "parikkhipi": ['cped'],
    "parikkhipitabba": ['cped'],
    "parikkhipitvā": ['cped'],
    "parikkhipāpeti": ['cped'],
    "parikkhita": ['cped'],
    "parikkhitta": ['cped'],
    "parikkhitvā": ['cped'],
    "parikkhā": ['cped'],
    "parikkhāra": ['cped'],
    "parikkhīṇa": ['cped'],
    "pariklam": ['mw'],
    "parikleda": ['mw'],
    "parikledaḥ": ['ap90'],
    "parikledin": ['mw'],
    "pariklesa": ['cped'],
    "parikleśa": ['cae', 'mw'],
    "parikleśaḥ": ['ap90'],
    "parikleṣṭṛ": ['cae', 'mw'],
    "pariklinna": ['cae', 'mw'],
    "parikliś": ['ap90', 'mw'],
    "parikliśa": ['mw'],
    "parikliṣṭa": ['ap90', 'cae', 'mw'],
    "parikliṣṭam": ['mw'],
    "pariklānta": ['mw'],
    "pariklāṃta": ['ap90'],
    "parikopa": ['cae', 'mw'],
    "parikopaḥ": ['ap90'],
    "parikopesi": ['cped'],
    "parikopeti": ['cped'],
    "parikopetvā": ['cped'],
    "parikopita": ['cped', 'mw'],
    "parikram": ['ap90', 'mw'],
    "parikrama": ['cae', 'mw'],
    "parikramasaha": ['mw'],
    "parikramaḥ": ['ap90'],
    "parikramaṇa": ['mw'],
    "parikrand": ['mw'],
    "parikraya": ['cae', 'mw'],
    "parikrayaḥ": ['ap90'],
    "parikrayaṇa": ['cae', 'mw'],
    "parikriyā": ['ap90', 'mw'],
    "parikrośa": ['gra', 'mw'],
    "parikrudh": ['mw'],
    "parikruś": ['mw'],
    "parikruṣṭa": ['mw'],
    "parikrāmitaka": ['cae', 'mw'],
    "parikrāmitakena": ['mw'],
    "parikrānta": ['mw'],
    "parikrānti": ['mw'],
    "parikrāṃta": ['ap90'],
    "parikrāṃtiḥ": ['ap90'],
    "parikrī": ['ap90', 'mw'],
    "parikrīta": ['mw'],
    "parikrīḍ": ['mw'],
    "parikrūḍyate": ['bhs'],
    "parikuddāleti": ['bhs'],
    "parikup": ['mw'],
    "parikupita": ['cped', 'mw'],
    "parikuppati": ['cped'],
    "parikuppi": ['cped'],
    "parikuḍyeti": ['bhs'],
    "parikuṭṭaka": ['bhs'],
    "parikvath": ['mw'],
    "parikvaṇana": ['ap90', 'mw'],
    "parikāla": ['bhs'],
    "parikālita": ['mw'],
    "parikāsana": ['mw'],
    "parikātara": ['bhs', 'mw'],
    "parikāyana": ['mw'],
    "parikāṃkṣitaḥ": ['ap90'],
    "parikāṅkṣin": ['bhs'],
    "parikāṅkṣita": ['mw'],
    "parikīleti": ['bhs'],
    "parikīrt": ['mw'],
    "parikīrtana": ['cae', 'mw'],
    "parikīrtanaṃ": ['ap90'],
    "parikīrtita": ['ap90', 'mw'],
    "parikīrṇa": ['ap90', 'mw'],
    "parikīṭa": ['bhs'],
    "parikūla": ['mw'],
    "parikūṭa": ['bhs', 'mw'],
    "parikūṭaṃ": ['ap90'],
    "parikḷp": ['ap90', 'mw'],
    "parikḷpta": ['mw'],
    "parikṛ": ['mw'],
    "parikṛt": ['mw'],
    "parikṛta": ['mw'],
    "parikṛtta": ['mw'],
    "parikṛś": ['mw'],
    "parikṛśa": ['ap90', 'mw'],
    "parikṛśatva": ['mw'],
    "parikṛṣ": ['ap90', 'mw'],
    "parikṛṣṭa": ['mw'],
    "parikṝ": ['ap90', 'mw'],
    "parikṝt": ['ap90'],
    "parikṣal": ['mw'],
    "parikṣar": ['mw'],
    "parikṣata": ['cae', 'mw'],
    "parikṣatavrata": ['mw'],
    "parikṣati": ['cae', 'mw'],
    "parikṣatiḥ": ['ap90'],
    "parikṣava": ['mw'],
    "parikṣaya": ['cae', 'mw'],
    "parikṣayaḥ": ['ap90'],
    "parikṣepa": ['cae', 'mw'],
    "parikṣepaka": ['mw'],
    "parikṣepaḥ": ['ap90'],
    "parikṣepin": ['mw'],
    "parikṣi": ['ap90', 'mw'],
    "parikṣip": ['ap90', 'mw'],
    "parikṣipta": ['ap90', 'mw'],
    "parikṣit": ['ap90', 'cae', 'gra', 'mw'],
    "parikṣita": ['mw'],
    "parikṣā": ['ap90', 'mw'],
    "parikṣālana": ['mw'],
    "parikṣālanaṃ": ['ap90'],
    "parikṣāma": ['ap90', 'cae', 'mw'],
    "parikṣāṇa": ['mw'],
    "parikṣība": ['mw'],
    "parikṣīva": ['ap90', 'mw'],
    "parikṣīṇa": ['ap90', 'cae', 'mw'],
    "parila": ['mw'],
    "parilabh": ['mw'],
    "parilaghu": ['ap90', 'cae', 'ddsa', 'mw'],
    "parilagna": ['cae', 'mw'],
    "parilamb": ['mw'],
    "parilamba": ['cae', 'mw'],
    "parilambana": ['mw'],
    "parilambya": ['mw'],
    "parilas": ['mw'],
    "parilaṅgh": ['mw'],
    "parilaṅghana": ['cae', 'mw'],
    "parilaṣ": ['mw'],
    "parilehin": ['mw'],
    "parilekha": ['cae', 'mw'],
    "parilekhana": ['mw'],
    "parilekhanaṃ": ['ap90'],
    "parilekhaḥ": ['ap90'],
    "parilekhādhikāra": ['mw'],
    "parileśa": ['mw'],
    "parilih": ['mw'],
    "parilikh": ['mw'],
    "parilikhana": ['mw'],
    "parilikhita": ['mw'],
    "parilip": ['mw'],
    "parilok": ['mw'],
    "parilolita": ['mw'],
    "parilopa": ['mw'],
    "parilopaḥ": ['ap90'],
    "parilubh": ['mw'],
    "parilup": ['ap90', 'mw'],
    "parilupta": ['ap90', 'mw'],
    "pariluptasaṃjña": ['mw'],
    "pariluḍ": ['mw'],
    "pariluṭh": ['mw'],
    "parilābha": ['bhs'],
    "parilīḍha": ['mw'],
    "parilūna": ['mw'],
    "parima": ['bhs'],
    "parimaddana": ['cped'],
    "parimaddati": ['cped'],
    "parimaddi": ['cped'],
    "parimaddita": ['cped'],
    "parimadditvā": ['cped'],
    "parimajjaka": ['cped'],
    "parimajjana": ['cped'],
    "parimajjati": ['cped'],
    "parimajji": ['cped'],
    "parimajjita": ['cped'],
    "parimajjitvā": ['cped'],
    "parimala": ['cae', 'mw'],
    "parimalabhṛt": ['mw'],
    "parimalaja": ['mw'],
    "parimalasamā": ['mw'],
    "parimalay": ['cae'],
    "parimalaya": ['mw'],
    "parimalaḥ": ['ap90'],
    "parimalita": ['ap90', 'mw'],
    "pariman": ['mw'],
    "parimanda": ['cae', 'mw'],
    "parimandatā": ['mw'],
    "parimanthara": ['cae', 'mw'],
    "parimantharatā": ['mw'],
    "parimantrita": ['mw'],
    "parimanyu": ['cae', 'gra', 'mw'],
    "parimara": ['cae', 'mw'],
    "parimaraḥ": ['ap90'],
    "parimarda": ['cae', 'mw'],
    "parimardana": ['bhs', 'cae', 'mw'],
    "parimardaḥ": ['ap90'],
    "parimarśa": ['cae', 'mw'],
    "parimarśaḥ": ['ap90'],
    "parimarṣa": ['mw'],
    "parimarṣaḥ": ['ap90'],
    "parimat": ['mw'],
    "parimath": ['mw'],
    "parimathita": ['mw'],
    "parimaṃda": ['ap90'],
    "parimaṃthara": ['ap90'],
    "parimaṃḍala": ['ap90'],
    "parimaṇḍala": ['cae', 'cped', 'ddsa', 'mw'],
    "parimaṇḍalakuṣṭha": ['mw'],
    "parimaṇḍalatā": ['mw'],
    "parimaṇḍalatātva": ['mw'],
    "parimaṇḍalaṁ": ['cped'],
    "parimaṇḍalita": ['mw'],
    "parimaṇḍanārtha": ['bhs'],
    "parimaṇḍita": ['mw'],
    "parimaṭṭha": ['cped'],
    "parimeha": ['mw'],
    "parimeya": ['ap90', 'cae', 'mw'],
    "parimeyapuraḥsara": ['mw'],
    "parimeyatā": ['mw'],
    "parimi": ['mw'],
    "parimilana": ['cae', 'mw'],
    "parimilanaṃ": ['ap90'],
    "parimilita": ['ap90', 'mw'],
    "parimit": ['mw'],
    "parimita": ['ap90', 'cae', 'cped', 'mw'],
    "parimitabhojana": ['mw'],
    "parimitabhuj": ['mw'],
    "parimitakatha": ['mw'],
    "parimitatva": ['mw'],
    "parimitecchatā": ['mw'],
    "parimiti": ['cae', 'mw'],
    "parimitimat": ['mw'],
    "parimitiḥ": ['ap90'],
    "parimitābharaṇa": ['mw'],
    "parimitāhāra": ['mw'],
    "parimitāyus": ['mw'],
    "parimlai": ['ap90', 'mw'],
    "parimlāna": ['ap90', 'cae', 'mw'],
    "parimlāyin": ['mw'],
    "parimlāyitva": ['mw'],
    "parimocaka": ['bhs'],
    "parimocana": ['bhs'],
    "parimocayati": ['bhs'],
    "parimocayitar": ['bhs'],
    "parimocesi": ['cped'],
    "parimoceti": ['cped'],
    "parimocetvā": ['cped'],
    "parimocita": ['cped', 'mw'],
    "parimohana": ['cae', 'mw'],
    "parimohanaṃ": ['ap90'],
    "parimohin": ['cae', 'mw'],
    "parimohita": ['mw'],
    "parimokṣ": ['mw'],
    "parimokṣa": ['cae', 'mw'],
    "parimokṣaḥ": ['ap90'],
    "parimokṣaṇa": ['mw'],
    "parimokṣaṇaṃ": ['ap90'],
    "parimoṣa": ['cae', 'mw'],
    "parimoṣaka": ['cae', 'mw'],
    "parimoṣaḥ": ['ap90'],
    "parimoṣaṇa": ['cae', 'mw'],
    "parimoṣin": ['ap90', 'cae', 'mw'],
    "parimoṭana": ['mw'],
    "parimrakṣaṇa": ['bhs'],
    "parimuc": ['ap90', 'mw'],
    "parimuccana": ['cped'],
    "parimuccati": ['cped'],
    "parimucci": ['cped'],
    "parimuccitvā": ['cped'],
    "parimugdha": ['ap90', 'mw'],
    "parimugdhatā": ['mw'],
    "parimuh": ['ap90', 'mw'],
    "parimukham": ['mw'],
    "parimukhaṁ": ['cped'],
    "parimukhaṃ": ['ap90'],
    "parimukta": ['mw'],
    "parimuktabandhana": ['mw'],
    "parimukti": ['ap90', 'mw'],
    "parimutta": ['cped'],
    "parimutti": ['cped'],
    "parimuṣ": ['mw'],
    "parimā": ['ap90', 'cae', 'mw'],
    "parimād": ['mw'],
    "parimāda": ['mw'],
    "parimārg": ['ap90', 'mw'],
    "parimārga": ['cae', 'mw'],
    "parimārgaḥ": ['ap90'],
    "parimārgaṇa": ['bhs', 'mw'],
    "parimārgin": ['mw'],
    "parimārgitavya": ['mw'],
    "parimārgya": ['mw'],
    "parimārja": ['mw'],
    "parimārjaka": ['bhs', 'mw'],
    "parimārjana": ['cae', 'mw'],
    "parimārjanaṃ": ['ap90'],
    "parimārjaḥ": ['ap90'],
    "parimārjita": ['mw'],
    "parimārkṣṇu": ['mw'],
    "parimāthin": ['ap90', 'cae', 'mw'],
    "parimāṇa": ['cae', 'cped', 'mw'],
    "parimāṇaka": ['mw'],
    "parimāṇakaṃ": ['ap90'],
    "parimāṇatas": ['mw'],
    "parimāṇavant": ['bhs'],
    "parimāṇavat": ['mw'],
    "parimāṇavattva": ['mw'],
    "parimāṇaṃ": ['ap90'],
    "parimāṇin": ['mw'],
    "parimīmāṃsate": ['bhs'],
    "parimīmāṃsā": ['bhs'],
    "parimīḍha": ['mw'],
    "parimūrṇa": ['mw'],
    "parimūḍha": ['ap90', 'cae', 'mw'],
    "parimūḍhatā": ['mw'],
    "parimṛ": ['mw'],
    "parimṛd": ['ap90', 'mw'],
    "parimṛdita": ['ap90', 'mw'],
    "parimṛg": ['mw'],
    "parimṛj": ['ap90', 'mw'],
    "parimṛja": ['mw'],
    "parimṛjita": ['mw'],
    "parimṛjya": ['mw'],
    "parimṛś": ['ap90', 'mw'],
    "parimṛṣ": ['ap90', 'mw'],
    "parimṛṣṭa": ['ap90', 'cae', 'mw'],
    "parimṛṣṭaparicchada": ['mw'],
    "parinaiṣṭhika": ['mw'],
    "parinand": ['mw'],
    "parinartana": ['mw'],
    "parinaṣṭa": ['mw'],
    "parindanā": ['bhs'],
    "parinditārtha": ['bhs'],
    "parindāmi": ['bhs'],
    "parindāyin": ['bhs'],
    "parinibbuta": ['cped'],
    "parinibbāna": ['cped'],
    "parinibbāpana": ['cped'],
    "parinibbāti": ['cped'],
    "parinibbāyi": ['cped'],
    "parinibbāyitvā": ['cped'],
    "parinibbāyī": ['cped'],
    "parinikāsa": ['bhs'],
    "parinikṣepa": ['bhs'],
    "parinikṣipta": ['bhs'],
    "parinimna": ['mw'],
    "parinind": ['mw'],
    "parinindana": ['mw'],
    "parinindā": ['cae', 'mw'],
    "parinirhan": ['mw'],
    "parinirjita": ['mw'],
    "parinirluṭh": ['mw'],
    "parinirmita": ['cae', 'mw'],
    "parinirmitavaśavartin": ['mw'],
    "parinirvapaṇa": ['mw'],
    "parinirvapaṇaṃ": ['ap90'],
    "parinirvivapsu": ['mw'],
    "parinirvivapsā": ['mw'],
    "parinirviṇṇa": ['mw'],
    "parinirvā": ['mw'],
    "parinirvāpayitavya": ['mw'],
    "parinirvāti": ['bhs'],
    "parinirvāyin": ['bhs', 'mw'],
    "parinirvāṇa": ['ap90', 'bhs', 'mw'],
    "parinirvṛta": ['bhs', 'mw'],
    "parinirvṛti": ['mw'],
    "parinirvṛttiḥ": ['ap90'],
    "parinirṇij": ['mw'],
    "parinivṛt": ['mw'],
    "pariniścaya": ['mw'],
    "pariniśnath": ['mw'],
    "pariniḥstan": ['mw'],
    "pariniḥśvasati": ['bhs'],
    "pariniṣad": ['mw'],
    "pariniṣev": ['mw'],
    "pariniṣic": ['mw'],
    "pariniṣpad": ['mw'],
    "pariniṣpadyati": ['bhs'],
    "pariniṣpanna": ['bhs', 'mw'],
    "pariniṣpannatva": ['mw'],
    "pariniṣpatti": ['bhs', 'mw'],
    "pariniṣpādana": ['bhs'],
    "pariniṣpādita": ['bhs', 'mw'],
    "pariniṣṭhita": ['ap90', 'cae', 'mw'],
    "pariniṣṭhura": ['bhs'],
    "pariniṣṭhā": ['ap90', 'cae', 'mw'],
    "pariniṣṭhāna": ['mw'],
    "pariniṣṭhāpanīya": ['mw'],
    "pariniṭṭhāna": ['cped'],
    "pariniṭṭhāpesi": ['cped'],
    "pariniṭṭhāpeti": ['cped'],
    "pariniṭṭhāpetvā": ['cped'],
    "pariniṭṭhāpita": ['cped'],
    "parinyasta": ['mw'],
    "parinyāsa": ['mw'],
    "parinyāsaḥ": ['ap90'],
    "parinābhi": ['ddsa', 'mw'],
    "parināyaka": ['cped'],
    "parināyakaratana": ['cped'],
    "parināyikā": ['cped'],
    "parinṛt": ['mw'],
    "paripac": ['mw'],
    "paripacana": ['mw'],
    "paripad": ['ap90', 'gra', 'mw'],
    "paripadin": ['mw'],
    "paripakka": ['cped'],
    "paripakva": ['ap90', 'bhs', 'cae', 'mw'],
    "paripakvakaṣāya": ['mw'],
    "paripakvatā": ['mw'],
    "paripakvaśāli": ['mw'],
    "paripanaṃ": ['ap90'],
    "paripanna": ['mw'],
    "paripantha": ['bhs', 'cped'],
    "paripanthaka": ['mw'],
    "paripantham": ['mw'],
    "paripanthaya": ['mw'],
    "paripanthika": ['cped', 'mw'],
    "paripanthin": ['cae', 'gra', 'mw'],
    "paripanthitva": ['mw'],
    "paripanthībhū": ['mw'],
    "paripara": ['mw'],
    "pariparaḥ": ['ap90'],
    "pariparin": ['ap90', 'mw'],
    "paripat": ['ap90', 'mw'],
    "paripatana": ['cae', 'mw'],
    "paripatanaṃ": ['ap90'],
    "paripatati": ['cped'],
    "paripathaka": ['ap90'],
    "paripati": ['cped', 'gra', 'mw'],
    "paripatita": ['cped'],
    "paripatiḥ": ['ap90'],
    "paripavana": ['mw'],
    "paripavanaḥ": ['ap90'],
    "paripaś": ['mw'],
    "paripaśavya": ['mw'],
    "paripaṃthaḥ": ['ap90'],
    "paripaṃthin": ['ap90'],
    "paripaṇa": ['ddsa', 'mw'],
    "paripaṇana": ['mw'],
    "paripaṇanaṃ": ['ap90'],
    "paripaṇaṃ": ['ap90'],
    "paripaṇita": ['ap90', 'mw'],
    "paripaṇḍiman": ['mw'],
    "paripaṇḍita": ['bhs'],
    "paripaṭati": ['cped'],
    "paripaṭh": ['mw'],
    "paripelava": ['ap90', 'cae', 'mw'],
    "pariphandati": ['cped'],
    "pariphandi": ['cped'],
    "pariphandita": ['cped'],
    "pariphulla": ['ddsa', 'mw'],
    "paripiccha": ['mw'],
    "paripipālayiṣā": ['mw'],
    "paripiñja": ['mw'],
    "paripiñjara": ['mw'],
    "paripiṅga": ['mw'],
    "paripiṅgīkṛ": ['mw'],
    "paripiṇḍa": ['bhs'],
    "paripiṇḍayati": ['bhs'],
    "paripiṇḍīkṛta": ['bhs', 'mw'],
    "paripiṣ": ['mw'],
    "paripiṣṭa": ['mw'],
    "paripiṣṭaka": ['mw'],
    "paripiṣṭakaṃ": ['ap90'],
    "pariplava": ['ap90', 'cae', 'cped', 'mw'],
    "pariplavati": ['cped'],
    "pariplavi": ['cped'],
    "pariplavita": ['cped'],
    "pariplavā": ['mw'],
    "pariploṣa": ['mw'],
    "pariplu": ['ap90', 'mw'],
    "paripluta": ['ap90', 'mw'],
    "pariplutā": ['mw'],
    "paripluṣṭa": ['ap90', 'mw'],
    "pariplāvya": ['mw'],
    "paripoṣa": ['mw'],
    "paripoṣaka": ['mw'],
    "paripoṣaṇa": ['mw'],
    "paripoṣaṇaṃ": ['ap90'],
    "paripoṣaṇīya": ['mw'],
    "paripoṭa": ['mw'],
    "paripoṭaka": ['mw'],
    "paripoṭana": ['mw'],
    "paripoṭavat": ['mw'],
    "paripoṭaḥ": ['ap90'],
    "paripphuta": ['cped'],
    "paripracch": ['ap90'],
    "pariprach": ['mw'],
    "paripradhanv": ['mw'],
    "paripragrah": ['mw'],
    "pariprakāśa": ['bhs'],
    "paripramuc": ['mw'],
    "pariprasyand": ['mw'],
    "pariprath": ['mw'],
    "paripravac": ['mw'],
    "paripravṛt": ['mw'],
    "pariprayā": ['mw'],
    "paripraśna": ['cae', 'mw'],
    "paripraśnati": ['bhs'],
    "paripraśnaḥ": ['ap90'],
    "paripraśnīkaraṇa": ['bhs'],
    "paripraśnīkaroti": ['bhs'],
    "paripraṇī": ['mw'],
    "paripre": ['mw'],
    "pariprepsu": ['cae', 'mw'],
    "paripreraka": ['mw'],
    "paripreṣ": ['mw'],
    "paripreṣaṇa": ['mw'],
    "paripreṣaṇaṃ": ['ap90'],
    "paripreṣita": ['mw'],
    "paripreṣya": ['mw'],
    "paripreṣyaḥ": ['ap90'],
    "pariprokṣate": ['bhs'],
    "paripruṣ": ['cae', 'gra', 'mw'],
    "pariprāp": ['mw'],
    "pariprāpayati": ['bhs'],
    "pariprāpaṇa": ['mw'],
    "pariprāpti": ['mw'],
    "pariprāptiḥ": ['ap90'],
    "pariprāpya": ['mw'],
    "pariprārdha": ['mw'],
    "pariprī": ['cae', 'gra', 'mw'],
    "pariprīta": ['mw'],
    "pariprīṇayati": ['bhs'],
    "paripucchaka": ['cped'],
    "paripucchati": ['cped'],
    "paripucchaya": ['mw'],
    "paripucchi": ['cped'],
    "paripucchita": ['cped'],
    "paripucchitvā": ['cped'],
    "paripucchā": ['cped'],
    "paripuṅkhita": ['mw'],
    "paripuṇṇa": ['cped'],
    "paripuṇṇatā": ['cped'],
    "paripuṣ": ['mw'],
    "paripuṣkarā": ['mw'],
    "paripuṣṭa": ['cae', 'mw'],
    "paripuṣṭatā": ['mw'],
    "paripuṭ": ['mw'],
    "paripuṭana": ['mw'],
    "paripuṭanavat": ['mw'],
    "paripuṭanaṃ": ['ap90'],
    "paripuṭṭha": ['cped'],
    "paripā": ['ap90', 'mw'],
    "paripācaka": ['bhs'],
    "paripācana": ['bhs', 'cped', 'mw'],
    "paripācanatā": ['mw'],
    "paripācayati": ['bhs'],
    "paripācayitṛ": ['mw'],
    "paripācesi": ['cped'],
    "paripāceti": ['cped'],
    "paripācita": ['cped', 'mw'],
    "paripāda": ['mw'],
    "paripāka": ['cae', 'cped', 'mw'],
    "paripākaḥ": ['ap90'],
    "paripākin": ['mw'],
    "paripākinī": ['mw'],
    "paripālaka": ['cae', 'mw'],
    "paripālana": ['cae', 'mw'],
    "paripālanaṃ": ['ap90'],
    "paripālanā": ['mw'],
    "paripālanīya": ['cae', 'mw'],
    "paripālayitṛ": ['mw'],
    "paripālesi": ['cped'],
    "paripāleti": ['cped'],
    "paripāletvā": ['cped'],
    "paripālita": ['cped'],
    "paripālya": ['cae', 'mw'],
    "paripāna": ['cae', 'gra', 'mw'],
    "paripārayati": ['bhs'],
    "paripārśva": ['ap90', 'cae', 'mw'],
    "paripārśvacara": ['mw'],
    "paripārśvatas": ['mw'],
    "paripārśvavartin": ['mw'],
    "paripātesi": ['cped'],
    "paripāteti": ['cped'],
    "paripātetvā": ['cped'],
    "paripātita": ['cped'],
    "paripātrikā": ['bhs'],
    "paripāṇa": ['cae', 'mw'],
    "paripāṇḍiman": ['mw'],
    "paripāṇḍu": ['cae', 'mw'],
    "paripāṇḍura": ['cae', 'mw'],
    "paripāṇḍurita": ['mw'],
    "paripāṭala": ['ap90', 'mw'],
    "paripāṭalita": ['mw'],
    "paripāṭana": ['bhs'],
    "paripāṭayati": ['bhs'],
    "paripāṭha": ['cae', 'mw'],
    "paripāṭhaka": ['mw'],
    "paripāṭhayati": ['bhs'],
    "paripāṭhaḥ": ['ap90'],
    "paripāṭhena": ['mw'],
    "paripāṭi": ['cae', 'mw'],
    "paripāṭiḥ": ['ap90'],
    "paripāṭī": ['cae'],
    "paripīta": ['mw'],
    "paripīvara": ['mw'],
    "paripīḍ": ['ap90', 'mw'],
    "paripīḍana": ['cae', 'mw'],
    "paripīḍanaṃ": ['ap90'],
    "paripīḍita": ['mw'],
    "paripīḍā": ['mw'],
    "paripīḷesi": ['cped'],
    "paripīḷeti": ['cped'],
    "paripīḷita": ['cped'],
    "paripū": ['ap90', 'mw'],
    "paripūj": ['mw'],
    "paripūjana": ['mw'],
    "paripūjanaṃ": ['ap90'],
    "paripūjita": ['mw'],
    "paripūjā": ['mw'],
    "paripūra": ['cped'],
    "paripūraka": ['cae', 'cped', 'mw'],
    "paripūrakāritā": ['cped'],
    "paripūrakārī": ['cped'],
    "paripūrati": ['cped'],
    "paripūrayati": ['bhs'],
    "paripūrayitavya": ['mw'],
    "paripūraṇa": ['cped', 'mw'],
    "paripūraṇaṃ": ['ap90'],
    "paripūraṇīya": ['mw'],
    "paripūrenta": ['cped'],
    "paripūresi": ['cped'],
    "paripūretabba": ['cped'],
    "paripūreti": ['cped'],
    "paripūretvā": ['cped'],
    "paripūri": ['bhs', 'cped'],
    "paripūrika": ['bhs'],
    "paripūrin": ['mw'],
    "paripūrita": ['cped', 'mw'],
    "paripūritvā": ['cped'],
    "paripūriya": ['cped'],
    "paripūrti": ['cae', 'mw'],
    "paripūrtiḥ": ['ap90'],
    "paripūryābhayaprada": ['bhs'],
    "paripūrṇa": ['ap90', 'cae', 'mw'],
    "paripūrṇabhāṣin": ['mw'],
    "paripūrṇacandravimalaprabha": ['bhs', 'mw'],
    "paripūrṇamanoratha": ['bhs'],
    "paripūrṇamukha": ['mw'],
    "paripūrṇamānasa": ['mw'],
    "paripūrṇasahasracandravatī": ['mw'],
    "paripūrṇasattva": ['mw'],
    "paripūrṇatva": ['mw'],
    "paripūrṇatā": ['cae', 'mw'],
    "paripūrṇavyañjanatā": ['mw'],
    "paripūrṇaśubha": ['bhs'],
    "paripūrṇendu": ['cae', 'mw'],
    "paripūrṇārtha": ['mw'],
    "paripūta": ['ap90', 'cae', 'mw'],
    "paripūti": ['mw'],
    "paripṛcchaka": ['mw'],
    "paripṛcchana": ['bhs'],
    "paripṛcchanikā": ['bhs', 'mw'],
    "paripṛcchatā": ['bhs'],
    "paripṛcchika": ['mw'],
    "paripṛcchā": ['ap90', 'bhs', 'mw'],
    "paripṛṣṭika": ['mw'],
    "paripṝ": ['mw'],
    "parirabdha": ['mw'],
    "parirabh": ['ap90', 'mw'],
    "parirakkhana": ['cped'],
    "parirakkhati": ['cped'],
    "parirakṣ": ['ap90', 'mw'],
    "parirakṣaka": ['cae', 'mw'],
    "parirakṣakaḥ": ['ap90'],
    "parirakṣaṇa": ['cae', 'ddsa', 'mw'],
    "parirakṣaṇaṃ": ['ap90'],
    "parirakṣaṇīya": ['mw'],
    "parirakṣin": ['mw'],
    "parirakṣita": ['mw'],
    "parirakṣitavya": ['mw'],
    "parirakṣitin": ['ap90', 'mw'],
    "parirakṣitṛ": ['cae', 'mw'],
    "parirakṣya": ['mw'],
    "parirakṣā": ['cae', 'mw'],
    "pariram": ['mw'],
    "parirambha": ['cae', 'mw'],
    "parirambhaṇa": ['mw'],
    "parirambhin": ['cae', 'mw'],
    "parirambhita": ['mw'],
    "pariramita": ['mw'],
    "parirandhita": ['mw'],
    "parirathya": ['mw'],
    "parirathyā": ['ap90', 'mw'],
    "pariraṃbhaḥ": ['ap90'],
    "pariraṭana": ['mw'],
    "paririh": ['mw'],
    "pariripsu": ['mw'],
    "parirodha": ['cae', 'mw'],
    "pariruc": ['mw'],
    "pariruddha": ['bhs', 'mw'],
    "parirudh": ['mw'],
    "pariruj": ['mw'],
    "parirāj": ['mw'],
    "parirāp": ['gra', 'mw'],
    "parirāpin": ['mw'],
    "parirāṭaka": ['mw'],
    "parirāṭin": ['ap90', 'mw'],
    "parisabhya": ['mw'],
    "parisabhyaḥ": ['ap90'],
    "parisadūsaka": ['cped'],
    "parisagata": ['cped'],
    "parisahasra": ['cae', 'mw'],
    "parisahati": ['cped'],
    "parisahi": ['cped'],
    "parisakhya": ['mw'],
    "parisakkana": ['cped'],
    "parisakkati": ['bhs', 'cped'],
    "parisakki": ['cped'],
    "parisakkita": ['cped'],
    "parisamanta": ['bhs', 'mw'],
    "parisamantato": ['cped'],
    "parisambhū": ['mw'],
    "parisame": ['mw'],
    "parisamohana": ['mw'],
    "parisamutsuka": ['mw'],
    "parisamāp": ['mw'],
    "parisamāpana": ['mw'],
    "parisamāpanaṃ": ['ap90'],
    "parisamāpanīya": ['mw'],
    "parisamāpayitavya": ['mw'],
    "parisamāpta": ['ap90', 'cae', 'mw'],
    "parisamāpti": ['cae', 'mw'],
    "parisamūh": ['mw'],
    "parisamūhana": ['mw'],
    "parisamūhanaṃ": ['ap90'],
    "parisappanā": ['cped'],
    "parisappati": ['cped'],
    "parisappi": ['cped'],
    "parisappita": ['cped'],
    "parisara": ['bhs', 'cae', 'mw'],
    "parisaraviṣaya": ['mw'],
    "parisaraḥ": ['ap90'],
    "parisaraṇa": ['cae', 'mw'],
    "parisaraṇaśīla": ['mw'],
    "parisaraṇaṃ": ['ap90'],
    "parisarpa": ['mw'],
    "parisarpaḥ": ['ap90'],
    "parisarpaṇa": ['cae', 'mw'],
    "parisarpaṇaṃ": ['ap90'],
    "parisarpikā": ['bhs'],
    "parisarpin": ['cae', 'mw'],
    "parisarpita": ['mw'],
    "parisarpyaka": ['bhs'],
    "parisaryā": ['ap90', 'mw'],
    "parisatya": ['mw'],
    "parisauvīram": ['mw'],
    "parisaṃbhavati": ['bhs'],
    "parisaṃcakṣ": ['mw'],
    "parisaṃcakṣya": ['mw'],
    "parisaṃcara": ['mw'],
    "parisaṃcaraḥ": ['ap90'],
    "parisaṃcita": ['mw'],
    "parisaṃghuṣṭa": ['cae', 'mw'],
    "parisaṃhā": ['mw'],
    "parisaṃhṛṣṭa": ['mw'],
    "parisaṃkhyā": ['ap90', 'cae', 'mw'],
    "parisaṃkhyāna": ['mw'],
    "parisaṃkhyānaṃ": ['ap90'],
    "parisaṃkhyāta": ['ap90', 'mw'],
    "parisaṃkrīḍ": ['mw'],
    "parisaṃkṣip": ['mw'],
    "parisaṃlih": ['mw'],
    "parisaṃspṛś": ['mw'],
    "parisaṃstambh": ['mw'],
    "parisaṃsthita": ['bhs', 'mw'],
    "parisaṃsthāpanatā": ['bhs'],
    "parisaṃsthāpayati": ['bhs'],
    "parisaṃstu": ['mw'],
    "parisaṃstuta": ['bhs'],
    "parisaṃstṛ": ['mw'],
    "parisaṃsṛṣṭa": ['mw'],
    "parisaṃtap": ['mw'],
    "parisaṃtapta": ['mw'],
    "parisaṃtuṣṭa": ['bhs'],
    "parisaṃtāna": ['mw'],
    "parisaṃvad": ['mw'],
    "parisaṃvatsara": ['ap90', 'cae', 'ddsa', 'mw'],
    "parisaṃśuddha": ['mw'],
    "parisaṅga": ['bhs'],
    "parisaṅkati": ['cped'],
    "parisaṅki": ['cped'],
    "parisaṅkita": ['cped'],
    "parisaṅkitvā": ['cped'],
    "parisaṅkā": ['cped'],
    "parisedeti": ['cped'],
    "parisedita": ['cped'],
    "parisiddhikā": ['mw'],
    "parisidh": ['mw'],
    "parisitta": ['cped'],
    "parisiñcati": ['cped'],
    "parisiñci": ['cped'],
    "parisiñcitvā": ['cped'],
    "pariskad": ['ap90'],
    "pariskand": ['mw'],
    "pariskanda": ['ddsa'],
    "pariskanna": ['cae', 'mw'],
    "pariskaṃda": ['ap90'],
    "pariskaṃdat": ['ap90'],
    "pariskhal": ['mw'],
    "pariskhalita": ['mw'],
    "pariskāra": ['bhs'],
    "parismāpana": ['mw'],
    "parisnāti": ['bhs'],
    "parisodhana": ['cped'],
    "parisodhesi": ['cped'],
    "parisodheti": ['cped'],
    "parisodhetvā": ['cped'],
    "parisodhita": ['cped'],
    "parisodhiya": ['cped'],
    "parisosesi": ['cped'],
    "parisoseti": ['cped'],
    "parisosita": ['cped'],
    "parispand": ['mw'],
    "parispanda": ['cae', 'mw'],
    "parispandana": ['mw'],
    "parispandita": ['mw'],
    "parispardhin": ['cae', 'mw'],
    "parispaṃdaḥ": ['ap90'],
    "parisphar": ['mw'],
    "parispharayati": ['bhs'],
    "parisphur": ['ap90', 'mw'],
    "parisphuraṇa": ['mw'],
    "parisphuraṇaṃ": ['ap90'],
    "parisphurita": ['mw'],
    "parisphuṭ": ['mw'],
    "parisphuṭa": ['ap90', 'bhs', 'cae', 'mw'],
    "parisphuṭam": ['mw'],
    "parisphīta": ['mw'],
    "parisphūrti": ['mw'],
    "parisphūṭa": ['bhs'],
    "parispṛdh": ['cae', 'gra', 'mw'],
    "parispṛś": ['mw'],
    "parispṛṣṭa": ['mw'],
    "parisraj": ['cae', 'mw'],
    "parisrajin": ['mw'],
    "parisrasā": ['mw'],
    "parisrava": ['bhs', 'cae', 'mw'],
    "parisravaḥ": ['ap90'],
    "parisraṣṭṛ": ['mw'],
    "parisru": ['mw'],
    "parisrunmat": ['mw'],
    "parisrut": ['ap90', 'cae', 'gra', 'mw'],
    "parisruta": ['bhs', 'mw'],
    "parisrutā": ['mw'],
    "parisrāva": ['bhs', 'cae', 'mw'],
    "parisrāvakalpa": ['mw'],
    "parisrāvaḥ": ['ap90'],
    "parisrāvaṇa": ['bhs', 'mw'],
    "parisrāvaṇaṃ": ['ap90'],
    "parisrāvin": ['ap90', 'bhs', 'mw'],
    "parisrāvita": ['bhs'],
    "parissajana": ['cped'],
    "parissajanta": ['cped'],
    "parissajati": ['cped'],
    "parissaji": ['cped'],
    "parissajita": ['cped'],
    "parissajitvā": ['cped'],
    "parissama": ['cped'],
    "parissanta": ['cped'],
    "parissaya": ['cped'],
    "parissāvana": ['cped'],
    "parissāvesi": ['cped'],
    "parissāveti": ['cped'],
    "parissāvetvā": ['cped'],
    "parissāvita": ['cped'],
    "paristara": ['cae', 'mw'],
    "paristaraḥ": ['ap90'],
    "paristaraṇa": ['mw'],
    "paristaraṇaṃ": ['ap90'],
    "paristaraṇikā": ['mw'],
    "paristaraṇī": ['mw'],
    "paristaraṇīya": ['mw'],
    "paristaritṛ": ['mw'],
    "paristhita": ['bhs', 'cae'],
    "paristhā": ['mw'],
    "paristhāna": ['mw'],
    "paristhānaṃ": ['ap90'],
    "paristoma": ['cae', 'mw'],
    "paristomaḥ": ['ap90'],
    "paristīrṇa": ['mw'],
    "paristṛ": ['ap90', 'mw'],
    "paristṛta": ['mw'],
    "parisuddha": ['cped'],
    "parisuddhi": ['cped'],
    "parisujjhanta": ['cped'],
    "parisujjhati": ['cped'],
    "parisujjhi": ['cped'],
    "parisujjhitvā": ['cped'],
    "parisukkha": ['cped'],
    "parisussana": ['cped'],
    "parisussati": ['cped'],
    "parisussi": ['cped'],
    "parisussitvā": ['cped'],
    "parisvid": ['mw'],
    "parisvāra": ['mw'],
    "parisyanda": ['cae', 'mw'],
    "parisyandana": ['mw'],
    "parisyandin": ['mw'],
    "parisyaṃdaḥ": ['ap90'],
    "parisā": ['cped'],
    "parisādh": ['mw'],
    "parisādhana": ['cae', 'mw'],
    "parisāman": ['mw'],
    "parisāmanta": ['bhs'],
    "parisāmantaka": ['bhs'],
    "parisāntv": ['mw'],
    "parisāntvana": ['mw'],
    "parisāntvita": ['mw'],
    "parisāra": ['mw'],
    "parisāraka": ['mw'],
    "parisārin": ['mw'],
    "parisāvacara": ['cped'],
    "parisāvakīya": ['mw'],
    "parisīman": ['mw'],
    "parisīram": ['mw'],
    "parisīrya": ['mw'],
    "parisṛ": ['ap90', 'mw'],
    "parisṛj": ['mw'],
    "parisṛp": ['ap90', 'mw'],
    "parisṛpta": ['mw'],
    "parisṛta": ['mw'],
    "parisṛṣṭa": ['bhs', 'mw'],
    "paritakana": ['mw'],
    "paritakmia": ['gra'],
    "paritakmiā": ['gra'],
    "paritakmya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "paritakmyā": ['gra', 'mw'],
    "paritam": ['mw'],
    "paritamana": ['bhs'],
    "paritan": ['mw'],
    "paritap": ['ap90', 'mw'],
    "paritappati": ['cped'],
    "paritappi": ['cped'],
    "paritapta": ['ap90', 'mw'],
    "paritaptamukha": ['mw'],
    "paritapti": ['mw'],
    "paritaptiḥ": ['ap90'],
    "paritarj": ['mw'],
    "paritark": ['ap90', 'mw'],
    "paritarkaṇa": ['ddsa', 'mw'],
    "paritarkaṇaṃ": ['ap90'],
    "paritarkita": ['mw'],
    "paritarpaṇa": ['mw'],
    "paritarpaṇaṃ": ['ap90'],
    "paritarṣaṇa": ['bhs'],
    "paritas": ['ap90', 'cae', 'ddsa', 'mw'],
    "paritasana": ['bhs'],
    "paritassanā": ['cped'],
    "paritassati": ['cped'],
    "paritassi": ['cped'],
    "paritassita": ['cped'],
    "paritasyana": ['bhs'],
    "paritasyati": ['bhs'],
    "paritatnu": ['ddsa', 'mw'],
    "paritaḍ": ['mw'],
    "paritaṃs": ['mw'],
    "paritikta": ['bhs', 'mw'],
    "parito": ['cped'],
    "paritosesi": ['cped'],
    "paritoseti": ['cped'],
    "paritosetvā": ['cped'],
    "paritosita": ['cped'],
    "paritoṣa": ['cae', 'mw'],
    "paritoṣaka": ['cae', 'mw'],
    "paritoṣavat": ['mw'],
    "paritoṣayitṛ": ['mw'],
    "paritoṣaḥ": ['ap90'],
    "paritoṣaṇa": ['ap90', 'cae', 'mw'],
    "paritoṣin": ['mw'],
    "paritoṣita": ['mw'],
    "paritrai": ['ap90', 'mw'],
    "paritrasta": ['ap90', 'cae', 'mw'],
    "paritrasyana": ['bhs'],
    "paritrasyati": ['bhs'],
    "paritrigartam": ['mw'],
    "paritrāsa": ['mw'],
    "paritrāsaḥ": ['ap90'],
    "paritrāta": ['mw'],
    "paritrātavya": ['cae', 'mw'],
    "paritrātṛ": ['cae', 'mw'],
    "paritrāyaka": ['bhs'],
    "paritrāyaṇa": ['bhs'],
    "paritrāṇa": ['cae', 'mw'],
    "paritrāṇaṃ": ['ap90'],
    "paritta": ['bhs', 'cped'],
    "parittaka": ['cped'],
    "parittasutta": ['cped'],
    "parittāyaka": ['cped'],
    "parittāṇa": ['cped'],
    "paritud": ['mw'],
    "paritulana": ['bhs'],
    "paritulayati": ['bhs'],
    "paritulesi": ['cped'],
    "parituleti": ['cped'],
    "parituletvā": ['cped'],
    "paritulita": ['cped'],
    "parituṣ": ['ap90', 'mw'],
    "parituṣya": ['mw'],
    "parituṣṭa": ['ap90', 'cae', 'mw'],
    "parituṣṭi": ['cae', 'mw'],
    "parituṣṭiḥ": ['ap90'],
    "parituṣṭārtha": ['mw'],
    "parituṣṭātman": ['mw'],
    "parityaj": ['ap90', 'mw'],
    "parityajana": ['bhs', 'mw'],
    "parityajanaṃ": ['ap90'],
    "parityajya": ['cae', 'mw'],
    "parityakta": ['ap90', 'bhs', 'cae', 'mw'],
    "parityaktam": ['mw'],
    "parityaktṛ": ['cae', 'mw'],
    "parityāga": ['cae', 'mw'],
    "parityāgaḥ": ['ap90'],
    "parityāgin": ['cae', 'mw'],
    "parityājana": ['mw'],
    "parityājya": ['cae', 'mw'],
    "paritāpa": ['cae', 'cped', 'ddsa', 'mw'],
    "paritāpana": ['bhs', 'cped'],
    "paritāpaḥ": ['ap90'],
    "paritāpesi": ['cped'],
    "paritāpeti": ['cped'],
    "paritāpetvā": ['cped'],
    "paritāpin": ['cae', 'mw'],
    "paritāpita": ['cped'],
    "paritārayati": ['bhs'],
    "paritāraṇīya": ['mw'],
    "paritāsa": ['bhs'],
    "paritāyati": ['bhs'],
    "paritāḍin": ['mw'],
    "paritīra": ['mw'],
    "paritṛd": ['mw'],
    "paritṛp": ['ap90', 'mw'],
    "paritṛpta": ['mw'],
    "paritṛpti": ['mw'],
    "paritṛṣita": ['bhs', 'mw'],
    "paritṛṣyate": ['bhs'],
    "parivaccha": ['cped'],
    "parivad": ['ap90', 'mw'],
    "parivadana": ['mw'],
    "parivadanaṃ": ['ap90'],
    "parivah": ['ap90', 'mw'],
    "parivaha": ['cae', 'mw'],
    "parivahaḥ": ['ap90'],
    "parivahin": ['bhs'],
    "parivajjana": ['cped'],
    "parivajjenta": ['cped'],
    "parivajjesi": ['cped'],
    "parivajjeti": ['cped'],
    "parivajjetvā": ['cped'],
    "parivajjita": ['cped'],
    "parivakrā": ['mw'],
    "parivalana": ['mw'],
    "parivalliya": ['bhs'],
    "parivambhita": ['bhs'],
    "parivand": ['mw'],
    "parivandita": ['bhs'],
    "parivap": ['mw'],
    "parivapaṇa": ['mw'],
    "parivapya": ['mw'],
    "parivardhaka": ['mw'],
    "parivardhana": ['cae', 'mw'],
    "parivardhanaṃ": ['ap90'],
    "parivardhita": ['ap90', 'mw'],
    "parivarga": ['cae', 'gra', 'mw'],
    "parivargaḥ": ['ap90'],
    "parivargya": ['cae', 'mw'],
    "parivarha": ['mw'],
    "parivarhaḥ": ['ap90'],
    "parivarhaṇaṃ": ['ap90'],
    "parivarjaka": ['cae', 'mw'],
    "parivarjana": ['cae', 'mw'],
    "parivarjanatā": ['bhs'],
    "parivarjanaṃ": ['ap90'],
    "parivarjanīya": ['cae', 'mw'],
    "parivarjayati": ['bhs'],
    "parivarjita": ['ap90', 'mw'],
    "parivarman": ['ap90', 'mw'],
    "parivarta": ['bhs', 'cae', 'mw'],
    "parivartaka": ['ap90', 'bhs', 'mw'],
    "parivartakaṃ": ['cae'],
    "parivartana": ['bhs', 'cae', 'mw'],
    "parivartanaṃ": ['ap90'],
    "parivartanī": ['mw'],
    "parivartanīya": ['mw'],
    "parivartati": ['bhs'],
    "parivartaḥ": ['ap90'],
    "parivartikā": ['ap90', 'bhs', 'mw'],
    "parivartin": ['ap90', 'cae', 'mw'],
    "parivartita": ['ap90', 'mw'],
    "parivartman": ['mw'],
    "parivartula": ['mw'],
    "parivarṇayati": ['bhs'],
    "parivas": ['mw'],
    "parivasatha": ['mw'],
    "parivasathaḥ": ['ap90'],
    "parivasati": ['cped'],
    "parivasi": ['cped'],
    "parivastrā": ['mw'],
    "parivat": ['mw'],
    "parivatsa": ['mw'],
    "parivatsaka": ['mw'],
    "parivatsara": ['cae', 'ddsa', 'gra', 'mw'],
    "parivatsaraḥ": ['ap90'],
    "parivatsarīya": ['mw'],
    "parivatsarīṇa": ['gra', 'mw'],
    "parivatta": ['cped'],
    "parivattaka": ['cped'],
    "parivattamāna": ['cped'],
    "parivattana": ['cped'],
    "parivattati": ['cped'],
    "parivattesi": ['cped'],
    "parivatteti": ['cped'],
    "parivattetvā": ['cped'],
    "parivatti": ['cped'],
    "parivattita": ['cped'],
    "parivattitvā": ['cped'],
    "parivattiya": ['cped'],
    "parivañc": ['mw'],
    "parivañcana": ['mw'],
    "parivañcanā": ['mw'],
    "parivañcita": ['mw'],
    "parivaṃśa": ['mw'],
    "parivaṃśaka": ['mw'],
    "parivaṭṭa": ['cped'],
    "parivaṭṭaka": ['cped'],
    "parive": ['mw'],
    "pariveda": ['cae', 'mw'],
    "parivedaka": ['mw'],
    "parivedana": ['cae', 'mw'],
    "parivedanaṃ": ['ap90'],
    "parivedanā": ['mw'],
    "parivedanīyā": ['ap90', 'mw'],
    "parivedaḥ": ['ap90'],
    "parivedin": ['mw'],
    "parivedinī": ['mw'],
    "parivedita": ['mw'],
    "parivedya": ['mw'],
    "parivellayati": ['bhs'],
    "parivelliya": ['bhs'],
    "parivep": ['mw'],
    "parivesaka": ['cped'],
    "parivesanā": ['cped'],
    "parivettṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "pariveśa": ['mw'],
    "pariveśana": ['mw'],
    "pariveśas": ['mw'],
    "pariveśaḥ": ['ap90'],
    "pariveṇa": ['bhs', 'cped'],
    "pariveṣa": ['cae', 'mw'],
    "pariveṣabandhin": ['mw'],
    "pariveṣaka": ['cae', 'mw'],
    "pariveṣakaḥ": ['ap90'],
    "pariveṣavat": ['mw'],
    "pariveṣaṇa": ['cae', 'mw'],
    "pariveṣaṇaṃ": ['ap90'],
    "pariveṣin": ['mw'],
    "pariveṣya": ['mw'],
    "pariveṣṭ": ['ap90', 'mw'],
    "pariveṣṭana": ['cae', 'mw'],
    "pariveṣṭanaṃ": ['ap90'],
    "pariveṣṭanā": ['mw'],
    "pariveṣṭavya": ['mw'],
    "pariveṣṭita": ['mw'],
    "pariveṣṭitavat": ['mw'],
    "pariveṣṭitṛ": ['mw'],
    "pariveṣṭrīmat": ['mw'],
    "pariveṣṭṛ": ['ap90', 'cae', 'mw'],
    "pariveṭheti": ['bhs'],
    "parivicar": ['mw'],
    "parivid": ['mw'],
    "parividdha": ['mw'],
    "parividdhaḥ": ['ap90'],
    "parividhāv": ['mw'],
    "parividita": ['bhs'],
    "parivighaṭṭana": ['mw'],
    "parivihvala": ['ap90', 'mw'],
    "parivihvalatā": ['mw'],
    "parivihāra": ['mw'],
    "parivihāraḥ": ['ap90'],
    "parivijñapanin": ['bhs'],
    "parivikrayin": ['mw'],
    "parivikṣata": ['mw'],
    "parivikṣobha": ['mw'],
    "parivindaka": ['mw'],
    "parivindat": ['mw'],
    "parivinna": ['cae', 'mw'],
    "parivisati": ['cped'],
    "parivisi": ['cped'],
    "parivisitvā": ['cped'],
    "parivitakka": ['cped'],
    "parivitakkesi": ['cped'],
    "parivitakketi": ['cped'],
    "parivitakketvā": ['cped'],
    "parivitakkita": ['cped'],
    "parivitarka": ['bhs', 'mw'],
    "parivitta": ['cae', 'mw'],
    "parivitti": ['cae', 'ddsa', 'mw'],
    "parivittitva": ['mw'],
    "parivittitā": ['mw'],
    "parivivadiṣu": ['mw'],
    "parivivas": ['mw'],
    "parivividāna": ['mw'],
    "parivividānaḥ": ['ap90'],
    "pariviś": ['mw'],
    "pariviśiṣṭa": ['bhs'],
    "pariviśrānta": ['cae', 'mw'],
    "pariviśuddha": ['bhs'],
    "pariviśvas": ['mw'],
    "pariviśvasta": ['mw'],
    "pariviṃdakaḥ": ['ap90'],
    "pariviṃśat": ['cae', 'mw'],
    "pariviṇṇa": ['mw'],
    "pariviṇṇaḥ": ['ap90'],
    "pariviṣ": ['ap90', 'mw'],
    "pariviṣati": ['bhs'],
    "pariviṣyamāṇa": ['mw'],
    "pariviṣṇu": ['mw'],
    "pariviṣṭa": ['mw'],
    "pariviṣṭi": ['ap90', 'cae', 'gra', 'mw'],
    "parivraj": ['ap90', 'mw'],
    "parivrajya": ['mw'],
    "parivrajyā": ['ap90', 'cae', 'mw'],
    "parivraśc": ['mw'],
    "parivraḍhaya": ['mw'],
    "parivraḍhiman": ['mw'],
    "parivraḍhiṣṭha": ['mw'],
    "parivraḍhīyas": ['mw'],
    "parivrāj": ['ap90', 'cae', 'mw'],
    "parivrāja": ['mw'],
    "parivrājaka": ['cae', 'mw'],
    "parivrāji": ['mw'],
    "parivrājya": ['mw'],
    "parivrājī": ['mw'],
    "parivuta": ['cped'],
    "parivuttha": ['cped'],
    "parivyadh": ['mw'],
    "parivyakta": ['bhs', 'mw'],
    "parivyaktam": ['mw'],
    "parivyath": ['mw'],
    "parivyaya": ['bhs', 'cae', 'ddsa', 'mw'],
    "parivyayaḥ": ['ap90'],
    "parivyayaṇa": ['cae', 'mw'],
    "parivyayaṇīya": ['mw'],
    "parivye": ['mw'],
    "parivyādha": ['mw'],
    "parivyādhaḥ": ['ap90'],
    "parivyādhi": ['mw'],
    "parivyākula": ['bhs', 'mw'],
    "parivyākulīkṛ": ['mw'],
    "parivyāvṛj": ['mw'],
    "parivyāṇa": ['cae', 'mw'],
    "parivāda": ['cae', 'ddsa', 'mw'],
    "parivādagir": ['mw'],
    "parivādaka": ['bhs', 'mw'],
    "parivādakara": ['cae', 'mw'],
    "parivādakathā": ['mw'],
    "parivādakaḥ": ['ap90'],
    "parivādanī": ['bhs'],
    "parivādaḥ": ['ap90'],
    "parivādin": ['ap90', 'cae', 'mw'],
    "parivādita": ['mw'],
    "parivāditin": ['mw'],
    "parivāha": ['cae', 'mw'],
    "parivāhavat": ['mw'],
    "parivāhaḥ": ['ap90'],
    "parivāhin": ['ap90', 'mw'],
    "parivāhita": ['mw'],
    "parivāhya": ['bhs'],
    "parivāpa": ['mw'],
    "parivāpaḥ": ['ap90'],
    "parivāpaṇa": ['mw'],
    "parivāpaṇaṃ": ['ap90'],
    "parivāpika": ['mw'],
    "parivāpin": ['mw'],
    "parivāpita": ['ap90', 'mw'],
    "parivāpya": ['mw'],
    "parivāpī": ['mw'],
    "parivāra": ['bhs', 'cae', 'cped', 'mw'],
    "parivāraka": ['cped'],
    "parivārapāṭha": ['mw'],
    "parivāratā": ['mw'],
    "parivāravat": ['mw'],
    "parivārayati": ['bhs'],
    "parivāraśobhin": ['mw'],
    "parivāraḥ": ['ap90'],
    "parivāraṇa": ['ap90', 'cae', 'cped', 'mw'],
    "parivāresi": ['cped'],
    "parivāreti": ['cped'],
    "parivāretvā": ['cped'],
    "parivārita": ['ap90', 'cped', 'mw'],
    "parivārīkṛ": ['mw'],
    "parivāsa": ['bhs', 'cae', 'mw'],
    "parivāsana": ['cae', 'mw'],
    "parivāsas": ['mw'],
    "parivāsaḥ": ['ap90'],
    "parivāsita": ['bhs', 'cped', 'mw'],
    "parivāś": ['mw'],
    "parivāṇa": ['mw'],
    "parivāṇavaipulyasūtra": ['mw'],
    "parivī": ['cae', 'mw'],
    "parivīj": ['mw'],
    "parivījita": ['mw'],
    "parivīmaṁsati": ['cped'],
    "parivīmaṁsi": ['cped'],
    "parivīta": ['ap90', 'cae', 'mw'],
    "parivṛ": ['ap90', 'mw'],
    "parivṛddha": ['mw'],
    "parivṛddhatā": ['mw'],
    "parivṛddhi": ['cae', 'mw'],
    "parivṛddhiḥ": ['ap90'],
    "parivṛdh": ['ap90', 'mw'],
    "parivṛh": ['mw'],
    "parivṛj": ['cae', 'gra', 'mw'],
    "parivṛkta": ['cae', 'mw'],
    "parivṛktā": ['mw'],
    "parivṛktī": ['mw'],
    "parivṛkṇa": ['mw'],
    "parivṛsti": ['mw'],
    "parivṛt": ['ap90', 'mw'],
    "parivṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "parivṛti": ['mw'],
    "parivṛtiḥ": ['ap90'],
    "parivṛtta": ['ap90', 'cae', 'mw'],
    "parivṛttabhāgya": ['mw'],
    "parivṛttanetra": ['mw'],
    "parivṛttaphalā": ['mw'],
    "parivṛttatejas": ['mw'],
    "parivṛtti": ['cae', 'mw'],
    "parivṛttiḥ": ['ap90'],
    "parivṛttyā": ['mw'],
    "parivṛttārdhamukha": ['mw'],
    "parivṛttī": ['mw'],
    "parivṛḍha": ['ap90', 'cae', 'ddsa', 'mw'],
    "parivṛḍhatama": ['mw'],
    "parivṛṃh": ['ap90', 'mw'],
    "parivṛṃhaṇaṃ": ['ap90'],
    "parivṛṃhita": ['ap90'],
    "parivṛṣ": ['mw'],
    "pariyaj": ['mw'],
    "pariyajña": ['cae', 'mw'],
    "pariyajñaḥ": ['ap90'],
    "pariyam": ['mw'],
    "pariyanta": ['bhs', 'cped'],
    "pariyantakata": ['cped'],
    "pariyantika": ['cped'],
    "pariyat": ['mw'],
    "pariyatta": ['mw'],
    "pariyatti": ['cped'],
    "pariyattidhamma": ['cped'],
    "pariyattidhara": ['cped'],
    "pariyattisāsana": ['cped'],
    "pariyaṣṭṛ": ['mw'],
    "pariyesamāna": ['cped'],
    "pariyesanta": ['cped'],
    "pariyesanā": ['cped'],
    "pariyesati": ['cped'],
    "pariyesi": ['cped'],
    "pariyesita": ['cped'],
    "pariyesitvā": ['cped'],
    "pariyeṣate": ['bhs'],
    "pariyeṭṭhi": ['cped'],
    "pariyodapanā": ['cped'],
    "pariyodapesi": ['cped'],
    "pariyodapeti": ['cped'],
    "pariyodapita": ['cped'],
    "pariyodāta": ['cped'],
    "pariyoga": ['cped', 'mw'],
    "pariyogaḷha": ['cped'],
    "pariyogya": ['mw'],
    "pariyogāhana": ['cped'],
    "pariyogāhati": ['cped'],
    "pariyogāhi": ['cped'],
    "pariyogāhitvā": ['cped'],
    "pariyonaddha": ['cped'],
    "pariyonahana": ['cped'],
    "pariyonandhati": ['cped'],
    "pariyonandhi": ['cped'],
    "pariyonāha": ['cped'],
    "pariyosita": ['cped'],
    "pariyosāna": ['cped'],
    "pariyosāpesi": ['cped'],
    "pariyosāpeti": ['cped'],
    "pariyosāpetvā": ['cped'],
    "pariyu": ['mw'],
    "pariyuta": ['mw'],
    "pariyuṭṭhita": ['cped'],
    "pariyuṭṭhāna": ['cped'],
    "pariyuṭṭhāsi": ['cped'],
    "pariyuṭṭhāti": ['cped'],
    "pariyā": ['mw'],
    "pariyādinna": ['cped'],
    "pariyādiyati": ['cped'],
    "pariyādiyi": ['cped'],
    "pariyādiyitvā": ['cped'],
    "pariyādāti": ['cped'],
    "pariyādāya": ['cped'],
    "pariyāhanana": ['cped'],
    "pariyāhanati": ['cped'],
    "pariyāhani": ['cped'],
    "pariyāhata": ['cped'],
    "pariyāpanna": ['cped'],
    "pariyāputa": ['cped'],
    "pariyāpuṇana": ['cped'],
    "pariyāpuṇi": ['cped'],
    "pariyāpuṇitvā": ['cped'],
    "pariyāpuṇāti": ['cped'],
    "pariyāta": ['mw'],
    "pariyāti": ['cped'],
    "pariyāya": ['cped'],
    "pariyāyakathā": ['cped'],
    "pariyāṇa": ['mw'],
    "pariyāṇi": ['mw'],
    "pariyāṇika": ['mw'],
    "pariyāṇīya": ['mw'],
    "pariññeyya": ['cped'],
    "pariññā": ['cped'],
    "pariññāta": ['cped'],
    "pariññāya": ['cped'],
    "pariśabdita": ['mw'],
    "pariśaktave": ['mw'],
    "pariśakti": ['bhs'],
    "pariśamita": ['mw'],
    "pariśanna": ['mw'],
    "pariśap": ['mw'],
    "pariśapta": ['cae', 'mw'],
    "pariśara": ['bhs'],
    "pariśaṃk": ['ap90'],
    "pariśaṃkin": ['ap90'],
    "pariśaṅk": ['mw'],
    "pariśaṅkanīya": ['cae', 'ddsa', 'mw'],
    "pariśaṅkin": ['cae', 'mw'],
    "pariśaṅkita": ['cae', 'mw'],
    "pariśaṅkā": ['bhs', 'mw'],
    "pariśaṭha": ['mw'],
    "pariśeṣa": ['cae', 'mw'],
    "pariśeṣakhaṇḍa": ['mw'],
    "pariśeṣavat": ['mw'],
    "pariśeṣaśāstra": ['mw'],
    "pariśeṣaḥ": ['ap90'],
    "pariśeṣaṇa": ['mw'],
    "pariśeṣaṇaṃ": ['ap90'],
    "pariśeṣeṇa": ['mw'],
    "pariśeṣita": ['mw'],
    "pariśeṣāt": ['mw'],
    "pariśithila": ['bhs', 'mw'],
    "pariśiñjita": ['mw'],
    "pariśiṣ": ['ap90', 'mw'],
    "pariśiṣṭa": ['ap90', 'cae', 'mw'],
    "pariśiṣṭakadamba": ['mw'],
    "pariśiṣṭaparvan": ['mw'],
    "pariśiṣṭaparyāya": ['mw'],
    "pariśiṣṭaprabodha": ['mw'],
    "pariśiṣṭaprakāśa": ['mw'],
    "pariśiṣṭaprakāśasyasāramañjarī": ['mw'],
    "pariśiṣṭasaṃgraha": ['mw'],
    "pariśiṣṭasiddhāntaratnākara": ['mw'],
    "pariśiṣṭasūtrapattra": ['mw'],
    "pariślatha": ['mw'],
    "pariśleṣa": ['mw'],
    "pariśleṣaḥ": ['ap90'],
    "pariśliṣṭa": ['mw'],
    "pariśobhita": ['mw'],
    "pariśobhitakāyā": ['bhs', 'mw'],
    "pariśodha": ['mw'],
    "pariśodhaka": ['bhs'],
    "pariśodhana": ['cae', 'mw'],
    "pariśodhaḥ": ['ap90'],
    "pariśodhika": ['bhs'],
    "pariśoṣa": ['cae', 'mw'],
    "pariśoṣaḥ": ['ap90'],
    "pariśoṣaṇa": ['cae', 'mw'],
    "pariśoṣin": ['cae', 'mw'],
    "pariśoṣita": ['mw'],
    "pariśraddhāḥ": ['bhs'],
    "pariśram": ['mw'],
    "pariśrama": ['cae', 'ddsa', 'mw'],
    "pariśramaḥ": ['ap90'],
    "pariśramaṇa": ['mw'],
    "pariśramāpaha": ['mw'],
    "pariśraya": ['bhs', 'cae', 'mw'],
    "pariśrayaḥ": ['ap90'],
    "pariśrayaṇa": ['mw'],
    "pariśrayaṇaṃ": ['ap90'],
    "pariśri": ['mw'],
    "pariśrit": ['ap90', 'cae', 'mw'],
    "pariśrita": ['mw'],
    "pariśru": ['mw'],
    "pariśrut": ['mw'],
    "pariśruta": ['cae', 'mw'],
    "pariśrāma": ['mw'],
    "pariśrānta": ['cae', 'mw'],
    "pariśrānti": ['mw'],
    "pariśrāvaṇa": ['bhs'],
    "pariśrāṃtiḥ": ['ap90'],
    "pariśubh": ['mw'],
    "pariśuc": ['mw'],
    "pariśuddha": ['ap90', 'cae', 'mw'],
    "pariśuddhakarma": ['bhs'],
    "pariśuddhasuviśālābha": ['bhs'],
    "pariśuddhi": ['bhs', 'cae', 'mw'],
    "pariśuddhiḥ": ['ap90'],
    "pariśudh": ['ap90', 'mw'],
    "pariśuśrūṣā": ['mw'],
    "pariśuṣ": ['ap90', 'mw'],
    "pariśuṣka": ['ap90', 'cae', 'mw'],
    "pariśuṣkapalāśa": ['mw'],
    "pariśuṣkatālu": ['mw'],
    "pariśāpa": ['mw'],
    "pariśāyana": ['mw'],
    "pariśāśvata": ['ap90', 'mw'],
    "pariśī": ['mw'],
    "pariśīl": ['mw'],
    "pariśīlana": ['cae', 'mw'],
    "pariśīlanaṃ": ['ap90'],
    "pariśīlita": ['mw'],
    "pariśūnya": ['ap90', 'mw'],
    "pariśṛta": ['mw'],
    "pariśṛtaḥ": ['ap90'],
    "pariśṝ": ['mw'],
    "pariḍayhana": ['cped'],
    "pariḍayhati": ['cped'],
    "pariḍayhi": ['cped'],
    "pariḍayhitvā": ['cped'],
    "pariḍīna": ['mw'],
    "pariḍīnaka": ['mw'],
    "pariḍīnaṃ": ['ap90'],
    "pariṃśa": ['gra', 'mw'],
    "pariṇad": ['mw'],
    "pariṇaddha": ['ap90', 'cae', 'mw'],
    "pariṇah": ['ap90', 'mw'],
    "pariṇahana": ['mw'],
    "pariṇahanaṃ": ['ap90'],
    "pariṇam": ['ap90', 'mw'],
    "pariṇamana": ['bhs', 'mw'],
    "pariṇamanaṃ": ['ap90'],
    "pariṇamanā": ['mw'],
    "pariṇamati": ['cped'],
    "pariṇamayitṛ": ['cae', 'mw'],
    "pariṇata": ['ap90', 'cae', 'cped', 'mw'],
    "pariṇatadikkarika": ['mw'],
    "pariṇatadvirada": ['mw'],
    "pariṇataprajña": ['mw'],
    "pariṇatapratyaya": ['mw'],
    "pariṇatavayas": ['ddsa', 'mw'],
    "pariṇataśarad": ['mw'],
    "pariṇati": ['cae', 'mw'],
    "pariṇatiḥ": ['ap90'],
    "pariṇatāruṇa": ['mw'],
    "pariṇaya": ['cae', 'cped', 'mw'],
    "pariṇayana": ['mw'],
    "pariṇayavidhi": ['mw'],
    "pariṇayaḥ": ['ap90'],
    "pariṇayena": ['mw'],
    "pariṇaś": ['mw'],
    "pariṇetavya": ['mw'],
    "pariṇetṛ": ['ap90', 'cae', 'mw'],
    "pariṇeya": ['mw'],
    "pariṇeyā": ['mw'],
    "pariṇi": ['mw'],
    "pariṇidhā": ['mw'],
    "pariṇihan": ['mw'],
    "pariṇinaṃsu": ['mw'],
    "pariṇiviś": ['mw'],
    "pariṇiṃsaka": ['ap90', 'mw'],
    "pariṇiṃsā": ['mw'],
    "pariṇiṣpanna": ['bhs'],
    "pariṇiṣṭhā": ['ap90', 'mw'],
    "pariṇud": ['mw'],
    "pariṇuta": ['mw'],
    "pariṇāha": ['cae', 'cped', 'mw'],
    "pariṇāhavant": ['cae'],
    "pariṇāhavat": ['ap90', 'mw'],
    "pariṇāhaḥ": ['ap90'],
    "pariṇāhin": ['ap90', 'cae', 'mw'],
    "pariṇāma": ['bhs', 'cae', 'cped', 'mw'],
    "pariṇāmadarśin": ['mw'],
    "pariṇāmadṛṣṭi": ['mw'],
    "pariṇāmaka": ['ap90', 'mw'],
    "pariṇāmamukha": ['cae', 'mw'],
    "pariṇāmana": ['bhs', 'cped', 'mw'],
    "pariṇāmanirodha": ['mw'],
    "pariṇāmapathya": ['mw'],
    "pariṇāmaramaṇīya": ['mw'],
    "pariṇāmavat": ['mw'],
    "pariṇāmavattva": ['mw'],
    "pariṇāmavāda": ['mw'],
    "pariṇāmayati": ['bhs'],
    "pariṇāmaśūla": ['mw'],
    "pariṇāmaḥ": ['ap90'],
    "pariṇāme": ['mw'],
    "pariṇāmesi": ['cped'],
    "pariṇāmeti": ['cped'],
    "pariṇāmetvā": ['cped'],
    "pariṇāmi": ['cped'],
    "pariṇāmika": ['mw'],
    "pariṇāmin": ['cae', 'mw'],
    "pariṇāminitya": ['mw'],
    "pariṇāmita": ['cped'],
    "pariṇāmitva": ['mw'],
    "pariṇāya": ['mw'],
    "pariṇāyaka": ['bhs', 'cae', 'mw'],
    "pariṇāyakaḥ": ['ap90'],
    "pariṇāyaḥ": ['ap90'],
    "pariṇī": ['ap90', 'mw'],
    "pariṇīta": ['ap90', 'cae', 'mw'],
    "pariṇītabhartṛ": ['mw'],
    "pariṇītapūrvā": ['cae', 'mw'],
    "pariṇītaratna": ['mw'],
    "pariṣad": ['ap90', 'cae', 'gra', 'mw'],
    "pariṣada": ['mw'],
    "pariṣadaḥ": ['ap90'],
    "pariṣadvala": ['mw'],
    "pariṣadvan": ['gra', 'mw'],
    "pariṣadya": ['bhs', 'mw'],
    "pariṣadā": ['bhs'],
    "pariṣah": ['mw'],
    "pariṣahā": ['mw'],
    "pariṣakta": ['bhs'],
    "pariṣanna": ['mw'],
    "pariṣattva": ['cae', 'ddsa', 'mw'],
    "pariṣavaṇa": ['mw'],
    "pariṣaya": ['mw'],
    "pariṣañj": ['mw'],
    "pariṣaṇḍa": ['bhs', 'mw'],
    "pariṣaṇḍavārika": ['mw'],
    "pariṣaṇḍā": ['mw'],
    "pariṣecaka": ['mw'],
    "pariṣecana": ['cae', 'mw'],
    "pariṣeka": ['cae', 'mw'],
    "pariṣekaḥ": ['ap90'],
    "pariṣev": ['mw'],
    "pariṣeṇa": ['mw'],
    "pariṣeṇaya": ['mw'],
    "pariṣic": ['mw'],
    "pariṣidh": ['mw'],
    "pariṣikta": ['bhs', 'mw'],
    "pariṣita": ['mw'],
    "pariṣiv": ['mw'],
    "pariṣiñcana": ['bhs'],
    "pariṣkand": ['mw'],
    "pariṣkanda": ['mw'],
    "pariṣkanna": ['ap90'],
    "pariṣkara": ['mw'],
    "pariṣkaraḥ": ['ap90'],
    "pariṣkaṃd": ['ap90'],
    "pariṣkaṃda": ['ap90'],
    "pariṣkaṃdat": ['ap90'],
    "pariṣkaṇṇa": ['ap90', 'mw'],
    "pariṣkriyā": ['ap90', 'mw'],
    "pariṣkāra": ['bhs', 'cae', 'mw'],
    "pariṣkāracīvara": ['mw'],
    "pariṣkāraḥ": ['ap90'],
    "pariṣkārika": ['bhs'],
    "pariṣkṛ": ['ap90', 'mw'],
    "pariṣkṛta": ['ap90', 'cae', 'mw'],
    "pariṣkṛti": ['mw'],
    "pariṣkṛtiḥ": ['ap90'],
    "pariṣo": ['mw'],
    "pariṣoḍaśa": ['cae', 'mw'],
    "pariṣpaṃdaḥ": ['ap90'],
    "pariṣu": ['mw'],
    "pariṣvaj": ['mw'],
    "pariṣvajana": ['cae', 'mw'],
    "pariṣvajya": ['cae', 'mw'],
    "pariṣvajīyas": ['mw'],
    "pariṣvakta": ['ap90', 'mw'],
    "pariṣvan": ['mw'],
    "pariṣvañjalya": ['mw'],
    "pariṣvañjana": ['cae', 'mw'],
    "pariṣvaṃgaḥ": ['ap90'],
    "pariṣvaṃj": ['ap90'],
    "pariṣvaṅga": ['cae', 'mw'],
    "pariṣvaṅgin": ['mw'],
    "pariṣvaṣkita": ['mw'],
    "pariṣvedana": ['bhs'],
    "pariṣyanda": ['bhs', 'cae', 'ddsa', 'mw'],
    "pariṣyandana": ['bhs', 'mw'],
    "pariṣyandayati": ['bhs'],
    "pariṣyandin": ['mw'],
    "pariṣyaṃdaḥ": ['ap90'],
    "pariṣā": ['bhs'],
    "pariṣīvaṇa": ['mw'],
    "pariṣīvaṇaṃ": ['ap90'],
    "pariṣū": ['mw'],
    "pariṣūta": ['mw'],
    "pariṣūti": ['cae', 'gra', 'mw'],
    "pariṣūtiḥ": ['ap90'],
    "pariṣṭambh": ['mw'],
    "pariṣṭavana": ['mw'],
    "pariṣṭavanīya": ['mw'],
    "pariṣṭhala": ['mw'],
    "pariṣṭhalaṃ": ['ap90'],
    "pariṣṭhita": ['bhs', 'cae'],
    "pariṣṭhiti": ['mw'],
    "pariṣṭhā": ['cae', 'gra', 'mw'],
    "pariṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "pariṣṭiḥ": ['ap90'],
    "pariṣṭobha": ['mw'],
    "pariṣṭoma": ['mw'],
    "pariṣṭomaḥ": ['ap90'],
    "pariṣṭu": ['mw'],
    "pariṣṭubh": ['cae', 'gra', 'mw'],
    "pariṣṭuta": ['mw'],
    "pariṣṭuti": ['cae', 'gra', 'mw'],
    "parjanya": ['cae', 'ddsa', 'gra', 'mw'],
    "parjanyajinvita": ['cae', 'gra', 'mw'],
    "parjanyakrandia": ['gra'],
    "parjanyakrandya": ['gra', 'mw'],
    "parjanyaninada": ['mw'],
    "parjanyanātha": ['mw'],
    "parjanyapatnī": ['mw'],
    "parjanyaprayoga": ['mw'],
    "parjanyaretas": ['gra', 'mw'],
    "parjanyasūkta": ['mw'],
    "parjanyavṛddha": ['cae', 'gra', 'mw'],
    "parjanyaśānti": ['mw'],
    "parjanyaḥ": ['ap90'],
    "parjanyā": ['mw'],
    "parjanyātman": ['mw'],
    "parjanyāvāta": ['gra', 'mw'],
    "parjanī": ['mw'],
    "parka": ['cae', 'ddsa', 'mw'],
    "parkaṭa": ['mw'],
    "parkaṭaḥ": ['ap90'],
    "parkaṭiḥ": ['ap90'],
    "parkaṭī": ['cae', 'ddsa', 'mw'],
    "parmakanaka": ['bhs'],
    "parmāḍi": ['ddsa', 'mw'],
    "paro": ['cped', 'mw'],
    "parobāhu": ['mw'],
    "parocya": ['mw'],
    "parodati": ['cped'],
    "parodi": ['cped'],
    "paroditvā": ['cped'],
    "parodvaha": ['mw'],
    "parogavyūti": ['gra', 'mw'],
    "parogoṣṭham": ['mw'],
    "parohavis": ['mw'],
    "parohu": ['mw'],
    "parojaras": ['ap90'],
    "parokkha": ['cped'],
    "parokkhe": ['cped'],
    "parokta": ['mw'],
    "paroktakhaṇḍana": ['mw'],
    "parokṣa": ['ap90', 'cae', 'mw'],
    "parokṣabandhu": ['mw'],
    "parokṣabhoga": ['mw'],
    "parokṣabuddhi": ['mw'],
    "parokṣajit": ['mw'],
    "parokṣakāma": ['mw'],
    "parokṣakṛta": ['mw'],
    "parokṣam": ['mw'],
    "parokṣamanmatha": ['mw'],
    "parokṣapriya": ['mw'],
    "parokṣapṛṣṭha": ['mw'],
    "parokṣatva": ['mw'],
    "parokṣatā": ['cae', 'mw'],
    "parokṣavṛtti": ['mw'],
    "parokṣe": ['mw'],
    "parokṣeṇa": ['mw'],
    "parokṣā": ['ddsa', 'mw'],
    "parokṣānurāga": ['cae'],
    "parokṣārtha": ['ddsa', 'mw'],
    "parokṣāt": ['mw'],
    "parolakṣa": ['mw'],
    "paromātra": ['ap90', 'gra', 'mw'],
    "paropadeśa": ['mw'],
    "paropaga": ['ddsa', 'mw'],
    "paropajāpa": ['mw'],
    "paropakaraṇa": ['ddsa', 'mw'],
    "paropakaraṇīkṛ": ['mw'],
    "paropakāra": ['cae', 'mw'],
    "paropakāradharmakṣānti": ['mw'],
    "paropakāraikarasa": ['mw'],
    "paropakāraikarasā": ['mw'],
    "paropakārin": ['cae', 'mw'],
    "paropakāritva": ['mw'],
    "paropakṛta": ['mw'],
    "paropakṛti": ['cae', 'mw'],
    "paropara": ['bhs'],
    "paroparuddha": ['mw'],
    "paropasarpaṇa": ['mw'],
    "paropavāsa": ['mw'],
    "parorajas": ['ddsa', 'mw'],
    "parosahassa": ['cped'],
    "parosata": ['cped'],
    "parovara": ['cped'],
    "parovaram": ['ap90', 'mw'],
    "parovariya": ['cped'],
    "parovarīyas": ['ap90', 'mw'],
    "parovarīyastva": ['mw'],
    "parovarīṇa": ['ap90', 'mw'],
    "paroviṃśa": ['cae', 'mw'],
    "paroyogāhitvā": ['cped'],
    "parośīta": ['cae', 'mw'],
    "paroḍhā": ['mw'],
    "paroṃhu": ['mw'],
    "paroṣṇih": ['ddsa'],
    "paroṣṇī": ['ddsa', 'mw'],
    "paroṣṭiḥ": ['ap90'],
    "paro’kṣa": ['ddsa'],
    "paro’varam": ['ddsa'],
    "parp": ['ap90', 'mw'],
    "parpa": ['mw'],
    "parparī": ['ap90', 'mw'],
    "parparīka": ['mw'],
    "parparīkaḥ": ['ap90'],
    "parparīṇa": ['mw'],
    "parpaḥ": ['ap90'],
    "parpaṭa": ['cae', 'mw'],
    "parpaṭadruma": ['mw'],
    "parpaṭaka": ['bhs', 'mw'],
    "parpaṭakī": ['mw'],
    "parpaṭaḥ": ['ap90'],
    "parpaṭi": ['mw'],
    "parpaṭī": ['mw'],
    "parpharīka": ['gra', 'mw'],
    "parpika": ['mw'],
    "parpikaḥ": ['ap90'],
    "partṛ": ['ap90', 'cae', 'gra', 'mw'],
    "paru": ['cae', 'ddsa', 'mw'],
    "parucchepa": ['cae', 'ddsa', 'mw'],
    "parudvāra": ['ddsa', 'mw'],
    "parudvāraḥ": ['ap90'],
    "parula": ['mw'],
    "parus": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "parut": ['ap90', 'cae', 'mw'],
    "parutka": ['cae', 'ddsa', 'mw'],
    "paruttna": ['mw'],
    "paruśas": ['cae', 'mw'],
    "paruśśas": ['cae', 'mw'],
    "paruḥ": ['ap90'],
    "paruḥśraṃsa": ['mw'],
    "paruṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "paruṣacarman": ['mw'],
    "paruṣaghana": ['mw'],
    "paruṣam": ['mw'],
    "paruṣatara": ['mw'],
    "paruṣatva": ['mw'],
    "paruṣavacana": ['mw'],
    "paruṣavāc": ['mw'],
    "paruṣavādin": ['mw'],
    "paruṣetara": ['ddsa', 'mw'],
    "paruṣiman": ['ap90', 'mw'],
    "paruṣita": ['ap90', 'ddsa', 'mw'],
    "paruṣmat": ['mw'],
    "paruṣokti": ['cae', 'mw'],
    "paruṣoktika": ['mw'],
    "paruṣya": ['ddsa', 'mw'],
    "paruṣā": ['mw'],
    "paruṣāhva": ['mw'],
    "paruṣākṣara": ['cae', 'mw'],
    "paruṣākṣaram": ['mw'],
    "paruṣākṣepa": ['mw'],
    "paruṣī": ['mw'],
    "paruṣībhū": ['mw'],
    "paruṣīkṛ": ['ddsa'],
    "paruṣīkṛta": ['mw'],
    "paruṣṇī": ['ddsa', 'mw'],
    "parv": ['ap90', 'mw'],
    "parva": ['bhs', 'cae', 'ddsa', 'mw'],
    "parvabheda": ['mw'],
    "parvabhāga": ['mw'],
    "parvadakṣiṇā": ['mw'],
    "parvadhi": ['mw'],
    "parvadivasa": ['mw'],
    "parvagupta": ['mw'],
    "parvagāmin": ['mw'],
    "parvaka": ['mw'],
    "parvakaṃ": ['ap90'],
    "parvakāla": ['cae', 'mw'],
    "parvakālanirṇaya": ['mw'],
    "parvakālarāśi": ['mw'],
    "parvakāra": ['mw'],
    "parvakārin": ['mw'],
    "parvamitra": ['mw'],
    "parvamālā": ['mw'],
    "parvamūla": ['mw'],
    "parvamūlā": ['mw'],
    "parvan": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "parvanirṇaya": ['mw'],
    "parvanāḍī": ['mw'],
    "parvaprabodha": ['mw'],
    "parvaprakāśa": ['mw'],
    "parvapuṣpikā": ['mw'],
    "parvapuṣpī": ['mw'],
    "parvapūrṇatā": ['mw'],
    "parvaratnāvalī": ['mw'],
    "parvaruh": ['mw'],
    "parvarīṇa": ['mw'],
    "parvasa": ['mw'],
    "parvasambhava": ['mw'],
    "parvasaṃdhi": ['cae', 'mw'],
    "parvasaṃgraha": ['mw'],
    "parvasā": ['mw'],
    "parvata": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "parvatacyut": ['cae', 'gra', 'mw'],
    "parvatadhātu": ['mw'],
    "parvatadurga": ['mw'],
    "parvatadāna": ['mw'],
    "parvatadānapaddhati": ['mw'],
    "parvataja": ['mw'],
    "parvatajā": ['mw'],
    "parvatajāla": ['mw'],
    "parvataka": ['mw'],
    "parvatakandara": ['mw'],
    "parvatakāka": ['mw'],
    "parvatakīlā": ['mw'],
    "parvatamastaka": ['cae', 'mw'],
    "parvatamocā": ['mw'],
    "parvatamālā": ['mw'],
    "parvatanivāsa": ['mw'],
    "parvatantravidhi": ['mw'],
    "parvatapati": ['cae', 'mw'],
    "parvatapūruṣa": ['mw'],
    "parvatarodhas": ['mw'],
    "parvatarāj": ['cae', 'mw'],
    "parvatarāja": ['cae', 'mw'],
    "parvatarājakanyā": ['mw'],
    "parvatarājaputrī": ['mw'],
    "parvatasaṃnirodha": ['mw'],
    "parvatastha": ['mw'],
    "parvatatṛṇa": ['mw'],
    "parvatavarṇanastotra": ['mw'],
    "parvatavāsin": ['mw'],
    "parvatavāsinī": ['mw'],
    "parvataśikhara": ['cae', 'mw'],
    "parvataśreṣṭha": ['mw'],
    "parvataśrī": ['bhs'],
    "parvataḥ": ['ap90'],
    "parvateśvara": ['cae', 'mw'],
    "parvateṣṭhā": ['cae', 'gra', 'mw'],
    "parvati": ['cae', 'mw'],
    "parvatia": ['gra'],
    "parvatopatyakā": ['cae', 'mw'],
    "parvatya": ['cae', 'gra', 'mw'],
    "parvatādhārā": ['mw'],
    "parvatāgra": ['cae', 'mw'],
    "parvatākāra": ['mw'],
    "parvatāri": ['mw'],
    "parvatātmajā": ['cae', 'mw'],
    "parvatāvṛdh": ['gra', 'mw'],
    "parvatāyana": ['cae', 'mw'],
    "parvatāśaya": ['mw'],
    "parvatāśraya": ['mw'],
    "parvatāśrayin": ['mw'],
    "parvatī": ['mw'],
    "parvatīkṛ": ['ap90', 'mw'],
    "parvatīya": ['ap90', 'cae', 'mw'],
    "parvavallī": ['mw'],
    "parvavarja": ['mw'],
    "parvavat": ['mw'],
    "parvavipad": ['mw'],
    "parvayoni": ['mw'],
    "parvaśarkaraka": ['mw'],
    "parvaśas": ['cae', 'gra', 'mw'],
    "parvaśāka": ['mw'],
    "parvaṇa": ['cae', 'mw'],
    "parvaṇī": ['ap90', 'mw'],
    "parveśa": ['mw'],
    "parvita": ['mw'],
    "parviṇī": ['ddsa', 'mw'],
    "parvāsphoṭa": ['mw'],
    "parvātyaya": ['ddsa'],
    "parvāvadhi": ['mw'],
    "parvāṅgula": ['mw'],
    "paryadhigacchati": ['bhs'],
    "paryadhyayana": ['mw'],
    "paryagni": ['cae', 'ddsa', 'mw'],
    "paryagnikaraṇa": ['cae', 'mw'],
    "paryagnikaraṇīya": ['mw'],
    "paryagnikartṛ": ['mw'],
    "paryagnikriyamāṇa": ['mw'],
    "paryagnikriyamāṇe": ['mw'],
    "paryagnikṛ": ['mw'],
    "paryagnikṛta": ['mw'],
    "paryagniḥ": ['ap90'],
    "paryagu": ['mw'],
    "paryahna": ['mw'],
    "paryak": ['ap90', 'cae', 'ddsa', 'mw'],
    "paryan": ['mw'],
    "paryanta": ['bhs', 'cae', 'mw'],
    "paryantabhū": ['mw'],
    "paryantadeśa": ['mw'],
    "paryantaka": ['bhs'],
    "paryantam": ['mw'],
    "paryantaparvata": ['mw'],
    "paryantasaṃsthita": ['mw'],
    "paryantastha": ['cae', 'mw'],
    "paryantasthita": ['mw'],
    "paryante": ['mw'],
    "paryantika": ['bhs'],
    "paryantikā": ['mw'],
    "paryantīkṛ": ['mw'],
    "paryantīkṛta": ['bhs', 'mw'],
    "paryantīya": ['mw'],
    "paryanubandha": ['mw'],
    "paryanuyoga": ['mw'],
    "paryanuyogaḥ": ['ap90'],
    "paryanuyojya": ['mw'],
    "paryanuyojyopekṣaṇa": ['mw'],
    "paryanuyoktavya": ['mw'],
    "paryanuyuj": ['mw'],
    "paryanuyukta": ['mw'],
    "paryanviṣ": ['mw'],
    "paryanya": ['ap90', 'mw'],
    "paryarṣaṇa": ['mw'],
    "paryas": ['ap90', 'mw'],
    "paryasana": ['cae', 'mw'],
    "paryasanaṃ": ['ap90'],
    "paryasta": ['ap90', 'cae', 'mw'],
    "paryastamayam": ['cae', 'mw'],
    "paryastavat": ['mw'],
    "paryastavilocana": ['mw'],
    "paryasti": ['mw'],
    "paryastikā": ['mw'],
    "paryastikākṛti": ['mw'],
    "paryastiḥ": ['ap90'],
    "paryastākṣa": ['mw'],
    "paryavacchid": ['mw'],
    "paryavadhāraṇa": ['ddsa', 'mw'],
    "paryavado": ['mw'],
    "paryavadāna": ['bhs', 'mw'],
    "paryavadāpaka": ['bhs'],
    "paryavadāpana": ['bhs'],
    "paryavadāpayati": ['bhs'],
    "paryavadāpayitar": ['bhs'],
    "paryavadāpayitṛ": ['mw'],
    "paryavadāta": ['ap90', 'bhs', 'mw'],
    "paryavadātatva": ['mw'],
    "paryavadātaśruta": ['mw'],
    "paryavadātaśrutatā": ['mw'],
    "paryavagāhayati": ['bhs'],
    "paryavakṝ": ['mw'],
    "paryavanaddha": ['bhs', 'mw'],
    "paryavanahati": ['bhs'],
    "paryavanud": ['mw'],
    "paryavanāha": ['bhs'],
    "paryavapanna": ['mw'],
    "paryavapāda": ['mw'],
    "paryavapādya": ['mw'],
    "paryavarodha": ['bhs', 'mw'],
    "paryavarodhaḥ": ['ap90'],
    "paryavasita": ['ap90', 'cae', 'mw'],
    "paryavasitamati": ['mw'],
    "paryavaskanda": ['mw'],
    "paryavaso": ['ap90', 'mw'],
    "paryavasthita": ['bhs', 'mw'],
    "paryavasthā": ['ap90', 'mw'],
    "paryavasthāna": ['bhs', 'mw'],
    "paryavasthātṛ": ['ap90', 'mw'],
    "paryavasāna": ['cae', 'mw'],
    "paryavasānaṃ": ['ap90'],
    "paryavasānika": ['mw'],
    "paryavasānāt": ['mw'],
    "paryavasāya": ['mw'],
    "paryavasāyin": ['mw'],
    "paryavasāyitva": ['mw'],
    "paryavasṛp": ['mw'],
    "paryavaśeṣa": ['mw'],
    "paryavaśeṣaḥ": ['ap90'],
    "paryavaśeṣita": ['mw'],
    "paryavaśiṣ": ['mw'],
    "paryavaṣṭabdha": ['mw'],
    "paryavaṣṭambh": ['mw'],
    "paryavaṣṭambhana": ['mw'],
    "paryavaṣṭaṃbh": ['ap90'],
    "paryavaṣṭaṃbhanaṃ": ['ap90'],
    "paryave": ['mw'],
    "paryavekṣ": ['mw'],
    "paryaveta": ['mw'],
    "paryavāp": ['mw'],
    "paryavāpnoti": ['bhs'],
    "paryavāpti": ['bhs'],
    "paryaya": ['bhs', 'cae', 'ddsa', 'mw'],
    "paryayana": ['cae'],
    "paryayaḥ": ['ap90'],
    "paryayaṇa": ['mw'],
    "paryayaṇaṃ": ['ap90'],
    "paryañc": ['mw'],
    "paryaś": ['mw'],
    "paryaśru": ['ap90', 'cae', 'ddsa', 'mw'],
    "paryaśrunayana": ['cae'],
    "paryaṃkaḥ": ['ap90'],
    "paryaṃta": ['ap90'],
    "paryaṃtikā": ['ap90'],
    "paryaṅgya": ['mw'],
    "paryaṅka": ['cae', 'ddsa', 'mw'],
    "paryaṅkabaddha": ['mw'],
    "paryaṅkabandha": ['mw'],
    "paryaṅkabandhana": ['mw'],
    "paryaṅkabhogin": ['mw'],
    "paryaṅkagranthibandha": ['mw'],
    "paryaṅkapaṭṭikā": ['mw'],
    "paryaṅkapādikā": ['mw'],
    "paryaṅkastha": ['mw'],
    "paryaṅkh": ['mw'],
    "paryaṅkikā": ['ddsa', 'mw'],
    "paryaṅkin": ['bhs'],
    "paryaṅkīkṛ": ['ddsa'],
    "paryaṅkīkṛta": ['mw'],
    "paryaṇvati": ['bhs'],
    "paryaṇṭhate": ['bhs'],
    "paryaṭ": ['mw'],
    "paryaṭa": ['mw'],
    "paryaṭaka": ['ddsa', 'mw'],
    "paryaṭana": ['cae', 'mw'],
    "paryaṭanaṃ": ['ap90'],
    "paryaṭita": ['mw'],
    "parye": ['mw'],
    "paryehi": ['mw'],
    "paryehī": ['mw'],
    "paryetṛ": ['cae', 'gra', 'mw'],
    "paryeṣa": ['bhs'],
    "paryeṣaka": ['bhs'],
    "paryeṣati": ['bhs'],
    "paryeṣaṇa": ['cae', 'mw'],
    "paryeṣaṇaṃ": ['ap90'],
    "paryeṣaṇā": ['bhs', 'mw'],
    "paryeṣyati": ['bhs'],
    "paryeṣṭavya": ['cae', 'ddsa', 'mw'],
    "paryeṣṭi": ['bhs', 'cae', 'mw'],
    "paryeṣṭiḥ": ['ap90'],
    "paryoga": ['mw'],
    "paryoṣṭham": ['mw'],
    "paryudas": ['ap90', 'mw'],
    "paryudasana": ['mw'],
    "paryudasitavya": ['mw'],
    "paryudasta": ['ap90', 'mw'],
    "paryudastatva": ['mw'],
    "paryudayam": ['mw'],
    "paryudañcana": ['mw'],
    "paryudaṃcanaṃ": ['ap90'],
    "paryudbhṛta": ['mw'],
    "paryudita": ['mw'],
    "paryudvas": ['mw'],
    "paryudvij": ['mw'],
    "paryudāsa": ['mw'],
    "paryudāsaḥ": ['ap90'],
    "paryuka": ['ddsa', 'mw'],
    "paryukta": ['mw'],
    "paryukṣ": ['mw'],
    "paryukṣaṇa": ['cae', 'mw'],
    "paryukṣaṇaṃ": ['ap90'],
    "paryukṣaṇī": ['mw'],
    "paryulūkhalam": ['mw'],
    "paryupahve": ['mw'],
    "paryupalip": ['mw'],
    "paryupaspṛś": ['mw'],
    "paryupasthita": ['cae', 'mw'],
    "paryupasthā": ['mw'],
    "paryupasthāna": ['bhs', 'mw'],
    "paryupasthānaṃ": ['ap90'],
    "paryupasthāpaka": ['mw'],
    "paryupaveśana": ['mw'],
    "paryupaviś": ['mw'],
    "paryupta": ['mw'],
    "paryupti": ['mw'],
    "paryuptiḥ": ['ap90'],
    "paryupāgata": ['mw'],
    "paryupās": ['ap90', 'mw'],
    "paryupāsaka": ['ap90', 'mw'],
    "paryupāsana": ['bhs', 'cae', 'mw'],
    "paryupāsanaṃ": ['ap90'],
    "paryupāsita": ['bhs', 'mw'],
    "paryupāsitapūrvatva": ['mw'],
    "paryupāsitāvin": ['bhs'],
    "paryupāsitṛ": ['mw'],
    "paryupāsya": ['mw'],
    "paryupāsīna": ['mw'],
    "paryupāvṛtta": ['mw'],
    "paryuta": ['mw'],
    "paryutsuka": ['ap90', 'cae', 'mw'],
    "paryutsukatva": ['mw'],
    "paryutsukībhū": ['mw'],
    "paryutsṛj": ['mw'],
    "paryutthā": ['mw'],
    "paryutthāna": ['bhs', 'mw'],
    "paryutthānaṃ": ['ap90'],
    "paryuṣaṇa": ['mw'],
    "paryuṣaṇaṃ": ['ap90'],
    "paryuṣaṇādaśaśatakavṛtti": ['mw'],
    "paryuṣaṇāṣṭāhnikā": ['mw'],
    "paryuṣita": ['ap90', 'bhs', 'cae', 'mw'],
    "paryuṣitabhojin": ['mw'],
    "paryuṣitavya": ['mw'],
    "paryuṣṭa": ['mw'],
    "paryābhū": ['mw'],
    "paryābhṛ": ['mw'],
    "paryābhṛta": ['mw'],
    "paryācar": ['mw'],
    "paryācita": ['mw'],
    "paryācānta": ['cae', 'mw'],
    "paryādadāti": ['bhs'],
    "paryādhā": ['mw'],
    "paryādhānejya": ['mw'],
    "paryādhātṛ": ['ddsa', 'mw'],
    "paryādinna": ['bhs'],
    "paryādru": ['mw'],
    "paryādā": ['mw'],
    "paryādāna": ['bhs', 'mw'],
    "paryāgal": ['mw'],
    "paryāgam": ['ap90', 'mw'],
    "paryāgata": ['ap90', 'mw'],
    "paryāgā": ['mw'],
    "paryāhita": ['mw'],
    "paryāhiṇḍati": ['bhs'],
    "paryāhve": ['mw'],
    "paryāhāra": ['mw'],
    "paryāhāraḥ": ['ap90'],
    "paryāhāva": ['ddsa', 'mw'],
    "paryāhṛ": ['mw'],
    "paryākhyāna": ['mw'],
    "paryākula": ['ap90', 'cae', 'ddsa', 'mw'],
    "paryākulatva": ['mw'],
    "paryākulatā": ['ap90'],
    "paryākulay": ['cae'],
    "paryākulaya": ['mw'],
    "paryākulībhū": ['mw'],
    "paryākulīkṛ": ['cae', 'mw'],
    "paryākṛ": ['mw'],
    "paryākṣip": ['mw'],
    "paryāloc": ['ap90', 'mw'],
    "paryāloca": ['cae', 'mw'],
    "paryālocana": ['ddsa', 'mw'],
    "paryālocanaṃ": ['ap90'],
    "paryālocanā": ['cae', 'mw'],
    "paryālocita": ['mw'],
    "paryālocitavat": ['mw'],
    "paryālī": ['ap90', 'mw'],
    "paryāmuc": ['mw'],
    "paryāmṛś": ['mw'],
    "paryāntam": ['mw'],
    "paryāp": ['ap90', 'mw'],
    "paryāpanna": ['bhs'],
    "paryāpat": ['mw'],
    "paryāpatat": ['mw'],
    "paryāplu": ['mw'],
    "paryāpluta": ['mw'],
    "paryāplāva": ['mw'],
    "paryāplāvaḥ": ['ap90'],
    "paryāpnoti": ['bhs'],
    "paryāpta": ['ap90', 'cae', 'ddsa', 'mw'],
    "paryāptabhoga": ['cae', 'mw'],
    "paryāptacandra": ['mw'],
    "paryāptadakṣiṇa": ['mw'],
    "paryāptakala": ['mw'],
    "paryāptakāma": ['mw'],
    "paryāptam": ['mw'],
    "paryāptanayana": ['mw'],
    "paryāptatā": ['mw'],
    "paryāptavat": ['mw'],
    "paryāptaṃ": ['bhs'],
    "paryāpti": ['ap90', 'cae', 'mw'],
    "paryāpuṇati": ['bhs'],
    "paryārin": ['mw'],
    "paryāriṇī": ['ap90'],
    "paryāruh": ['mw'],
    "paryās": ['mw'],
    "paryāsa": ['cae', 'ddsa', 'mw'],
    "paryāsana": ['mw'],
    "paryāsanaṃ": ['ap90'],
    "paryāsaḥ": ['ap90'],
    "paryāsita": ['mw'],
    "paryātan": ['mw'],
    "paryāvadāna": ['mw'],
    "paryāvap": ['mw'],
    "paryāvarta": ['cae', 'ddsa', 'mw'],
    "paryāvartana": ['mw'],
    "paryāvartaḥ": ['ap90'],
    "paryāvartita": ['mw'],
    "paryāvasatha": ['mw'],
    "paryāvila": ['ap90', 'mw'],
    "paryāvāpti": ['bhs'],
    "paryāvṛt": ['mw'],
    "paryāvṛta": ['mw'],
    "paryāya": ['bhs', 'cae', 'ddsa', 'mw'],
    "paryāyacyuta": ['mw'],
    "paryāyakrama": ['mw'],
    "paryāyamuktāvalī": ['mw'],
    "paryāyapadamañjarī": ['mw'],
    "paryāyaratnamālā": ['mw'],
    "paryāyasaṃgrahaṇī": ['bhs'],
    "paryāyasevā": ['mw'],
    "paryāyasūkta": ['mw'],
    "paryāyata": ['mw'],
    "paryāyatva": ['mw'],
    "paryāyatā": ['mw'],
    "paryāyavacana": ['mw'],
    "paryāyavācaka": ['mw'],
    "paryāyavākya": ['mw'],
    "paryāyavṛtti": ['mw'],
    "paryāyaśabda": ['mw'],
    "paryāyaśas": ['mw'],
    "paryāyaśastra": ['mw'],
    "paryāyaśayana": ['mw'],
    "paryāyaḥ": ['ap90'],
    "paryāyeṇa": ['mw'],
    "paryāyika": ['mw'],
    "paryāyin": ['mw'],
    "paryāyokta": ['mw'],
    "paryāyokti": ['mw'],
    "paryāyā": ['mw'],
    "paryāyānna": ['mw'],
    "paryāyārṇava": ['mw'],
    "paryāyātman": ['mw'],
    "paryāśvas": ['mw'],
    "paryāśvasta": ['mw'],
    "paryāṇa": ['ddsa', 'mw'],
    "paryāṇaddha": ['mw'],
    "paryāṇah": ['mw'],
    "paryāṇahana": ['mw'],
    "paryāṇaya": ['mw'],
    "paryāṇaṃ": ['ap90'],
    "paryāṇita": ['mw'],
    "paryāṇī": ['mw'],
    "paryūh": ['mw'],
    "paryūhana": ['mw'],
    "paryūrṇu": ['mw'],
    "paryṛṣ": ['mw'],
    "parā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "parābaba": ['mw'],
    "parābhava": ['cae', 'cped', 'ddsa', 'mw'],
    "parābhavanta": ['cped'],
    "parābhavapada": ['mw'],
    "parābhavati": ['cped'],
    "parābhavaḥ": ['ap90'],
    "parābhavi": ['cped'],
    "parābhikṣa": ['mw'],
    "parābhāva": ['cae', 'mw'],
    "parābhāvana": ['mw'],
    "parābhāvuka": ['mw'],
    "parābhū": ['ap90', 'mw'],
    "parābhūta": ['ap90', 'cped', 'mw'],
    "parābhūti": ['cae', 'mw'],
    "parābhūtiḥ": ['ap90'],
    "parābhṛta": ['mw'],
    "parāc": ['ap90', 'gra'],
    "parāca": ['gra'],
    "parācais": ['cae', 'ddsa', 'mw'],
    "parācar": ['mw'],
    "parācintāmaṇi": ['mw'],
    "parācita": ['mw'],
    "parācī": ['ddsa', 'mw'],
    "parācīkarman": ['mw'],
    "parācīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "parācīnam": ['mw'],
    "parācīnarātra": ['mw'],
    "parādadi": ['cae', 'gra', 'mw'],
    "parādana": ['mw'],
    "parādevī": ['mw'],
    "parādevīrahasyatantra": ['mw'],
    "parādha": ['bhs'],
    "parādhi": ['mw'],
    "parādhikāra": ['ddsa'],
    "parādhiḥ": ['ap90'],
    "parādhmā": ['mw'],
    "parādhāv": ['mw'],
    "parādhīna": ['cae', 'cped', 'mw'],
    "parādhīnatva": ['mw'],
    "parādhīnatā": ['mw'],
    "parādiś": ['mw'],
    "parādru": ['mw'],
    "parādā": ['ap90', 'mw'],
    "parādāna": ['cae', 'mw'],
    "parādānaṃ": ['ap90'],
    "parādṛś": ['mw'],
    "parāg": ['mw'],
    "parāga": ['cae', 'ddsa', 'mw'],
    "parāgam": ['ap90', 'mw'],
    "parāgama": ['cae', 'mw'],
    "parāgantṛ": ['mw'],
    "parāgapuṣpa": ['mw'],
    "parāgata": ['ap90', 'mw'],
    "parāgavat": ['mw'],
    "parāgaḥ": ['ap90'],
    "parāgdṛś": ['mw'],
    "parāghātana": ['mw'],
    "parāgin": ['mw'],
    "parāgvadana": ['cae'],
    "parāgvadanaśālin": ['cae'],
    "parāgvasu": ['mw'],
    "parāgā": ['mw'],
    "parāha": ['mw'],
    "parāhan": ['ap90', 'mw'],
    "parāhanati": ['bhs'],
    "parāhata": ['ap90', 'mw'],
    "parāhati": ['mw'],
    "parāhaṇana": ['bhs'],
    "parāhla": ['ddsa'],
    "parāhā": ['mw'],
    "parāhṇa": ['cae', 'mw'],
    "parāhṛta": ['mw'],
    "parājaya": ['cae', 'cped', 'ddsa', 'mw'],
    "parājayaḥ": ['ap90'],
    "parājenta": ['cped'],
    "parājesi": ['cped'],
    "parājeti": ['cped'],
    "parājetvā": ['cped'],
    "parāji": ['ap90', 'mw'],
    "parājinati": ['bhs'],
    "parājit": ['mw'],
    "parājita": ['ap90', 'cae', 'cped', 'mw'],
    "parājiṣṇu": ['ap90', 'cae', 'mw'],
    "parājīyati": ['cped'],
    "parājīyi": ['cped'],
    "parāk": ['ddsa', 'mw'],
    "parāka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "parākaraṇa": ['mw'],
    "parākaraṇaṃ": ['ap90'],
    "parākarṣayati": ['bhs'],
    "parāke": ['ap90'],
    "parākhyā": ['mw'],
    "parākpuṣpī": ['mw'],
    "parākram": ['ap90', 'mw'],
    "parākrama": ['cae', 'ddsa', 'mw'],
    "parākramabāhu": ['mw'],
    "parākramajña": ['mw'],
    "parākramakesarin": ['mw'],
    "parākramavat": ['mw'],
    "parākramavikrama": ['bhs'],
    "parākramaḥ": ['ap90'],
    "parākramin": ['ap90', 'mw'],
    "parākrānta": ['mw'],
    "parākrānti": ['mw'],
    "parākrāntṛ": ['mw'],
    "parākrāṃta": ['ap90'],
    "parāktva": ['mw'],
    "parākāttāt": ['cae', 'gra', 'mw'],
    "parākāśa": ['mw'],
    "parākāśaḥ": ['ap90'],
    "parākṛ": ['ap90', 'mw'],
    "parākṛta": ['mw'],
    "parākṛṣ": ['mw'],
    "parākṛṣṭa": ['mw'],
    "parākṝ": ['mw'],
    "parākṣip": ['mw'],
    "parākṣipta": ['mw'],
    "parākṣiptamanas": ['mw'],
    "parāmarśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "parāmarśagrantha": ['mw'],
    "parāmarśagrantharahasya": ['mw'],
    "parāmarśahetutāvicāra": ['mw'],
    "parāmarśakaryakāraṇabhāvavicāra": ['mw'],
    "parāmarśakāraṇapakṣatāvāda": ['mw'],
    "parāmarśana": ['mw'],
    "parāmarśanaṃ": ['ap90'],
    "parāmarśapūrvapakṣagranthadīdhitiṭīkā": ['mw'],
    "parāmarśapūrvapakṣagranthakroḍa": ['mw'],
    "parāmarśapūrvapakṣagranthaprakāśa": ['mw'],
    "parāmarśapūrvapakṣagranthavivecana": ['mw'],
    "parāmarśapūrvapakṣagranthaṭīkā": ['mw'],
    "parāmarśapūrvapakṣagranthānugama": ['mw'],
    "parāmarśapūrvapakṣarahasya": ['mw'],
    "parāmarśarahasya": ['mw'],
    "parāmarśasiddhāntagranthakroḍa": ['mw'],
    "parāmarśasiddhāntagranthaprakāśa": ['mw'],
    "parāmarśasiddhāntagranthavivecana": ['mw'],
    "parāmarśasiddhāntagranthaṭīkā": ['mw'],
    "parāmarśasiddhāntagranthāloka": ['mw'],
    "parāmarśasiddhāntarahasya": ['mw'],
    "parāmarśavicāra": ['mw'],
    "parāmarśavāda": ['mw'],
    "parāmarśavādārtha": ['mw'],
    "parāmarśaḥ": ['ap90'],
    "parāmarśaṭippanī": ['mw'],
    "parāmarśin": ['mw'],
    "parāmarśitva": ['mw'],
    "parāmasana": ['cped'],
    "parāmasanta": ['cped'],
    "parāmasati": ['cped'],
    "parāmasi": ['cped'],
    "parāmasita": ['cped'],
    "parāmasitvā": ['cped'],
    "parāmaṭṭha": ['cped'],
    "parāmi": ['mw'],
    "parāmāsa": ['cped'],
    "parāmī": ['mw'],
    "parāmṛta": ['ap90', 'mw'],
    "parāmṛś": ['ap90', 'mw'],
    "parāmṛśati": ['bhs'],
    "parāmṛṣṭa": ['ap90', 'bhs', 'mw'],
    "parāmṛṣṭi": ['bhs'],
    "parānanda": ['mw'],
    "parānandapurāṇa": ['mw'],
    "parānasā": ['ap90', 'mw'],
    "parānna": ['ddsa', 'mw'],
    "parānnabhojin": ['mw'],
    "parānnaparipuṣṭatā": ['mw'],
    "parānta": ['cae', 'mw'],
    "parāntaka": ['bhs', 'mw'],
    "parāntakāla": ['mw'],
    "parānude": ['cae'],
    "parānīka": ['cae', 'mw'],
    "parāpa": ['mw'],
    "parāpara": ['cae', 'ddsa', 'mw'],
    "parāparadṛṣṭārtha": ['mw'],
    "parāparaguru": ['mw'],
    "parāparaitṛ": ['mw'],
    "parāparajña": ['mw'],
    "parāparajñatā": ['bhs'],
    "parāparatva": ['mw'],
    "parāparatā": ['mw'],
    "parāpareśa": ['mw'],
    "parāpat": ['ap90', 'mw'],
    "parāpata": ['bhs'],
    "parāpavana": ['mw'],
    "parāpaś": ['mw'],
    "parāprasādamantra": ['mw'],
    "parāpraveśikā": ['mw'],
    "parāpur": ['mw'],
    "parāpātin": ['mw'],
    "parāpātuka": ['mw'],
    "parāpū": ['mw'],
    "parāpūjā": ['mw'],
    "parāpṛṣṭhībhavati": ['bhs'],
    "parāpṛṣṭhībhūtvā": ['mw'],
    "parāpṛṣṭhīkaraṇa": ['bhs'],
    "parāpṛṣṭhīkṛta": ['bhs'],
    "parārahasya": ['mw'],
    "parārbuda": ['mw'],
    "parārdha": ['cae', 'ddsa', 'mw'],
    "parārdhaka": ['mw'],
    "parārdhya": ['cae', 'mw'],
    "parāri": ['ap90', 'mw'],
    "parāritna": ['mw'],
    "parārtha": ['cae', 'ddsa', 'mw'],
    "parārthacara": ['mw'],
    "parārthacaryā": ['mw'],
    "parārtham": ['mw'],
    "parārthaniṣṭha": ['mw'],
    "parārthasavihāraśrī": ['bhs'],
    "parārthatva": ['mw'],
    "parārthatā": ['mw'],
    "parārthavādin": ['cae', 'mw'],
    "parārthe": ['mw'],
    "parārthin": ['ddsa', 'mw'],
    "parāru": ['mw'],
    "parāruka": ['mw'],
    "parārukaḥ": ['ap90'],
    "parāruḥ": ['ap90'],
    "parārīka": ['mw'],
    "parās": ['ap90', 'mw'],
    "parāsa": ['mw'],
    "parāsana": ['mw'],
    "parāsanaṃ": ['ap90'],
    "parāsaḥ": ['ap90'],
    "parāsaṅga": ['mw'],
    "parāsedha": ['cae', 'ddsa', 'mw'],
    "parāsic": ['mw'],
    "parāsikta": ['mw'],
    "parāsin": ['mw'],
    "parāsisiṣu": ['mw'],
    "parāskandin": ['mw'],
    "parāskaṃdin": ['ap90'],
    "parāsta": ['ap90', 'mw'],
    "parāstambh": ['mw'],
    "parāstotra": ['mw'],
    "parāsu": ['ap90', 'cae', 'ddsa', 'mw'],
    "parāsukarṇa": ['mw'],
    "parāsutva": ['mw'],
    "parāsutā": ['mw'],
    "parāsya": ['cae', 'mw'],
    "parāsū": ['mw'],
    "parāsṛ": ['mw'],
    "parāsṛj": ['mw'],
    "parāt": ['mw'],
    "parātaram": ['cae', 'gra', 'mw'],
    "parātaṃsa": ['mw'],
    "parātman": ['cae', 'ddsa', 'mw'],
    "parātpara": ['mw'],
    "parātparaguru": ['mw'],
    "parātparaḥ": ['ap90'],
    "parātpriya": ['mw'],
    "parātras": ['mw'],
    "parātriṃśikā": ['mw'],
    "parātta": ['mw'],
    "parāvac": ['mw'],
    "parāvad": ['mw'],
    "parāvadh": ['mw'],
    "parāvah": ['mw'],
    "parāvaha": ['mw'],
    "parāvajñā": ['mw'],
    "parāvalg": ['mw'],
    "parāvam": ['mw'],
    "parāvap": ['mw'],
    "parāvara": ['cae', 'ddsa', 'mw'],
    "parāvaradṛś": ['mw'],
    "parāvarajña": ['mw'],
    "parāvaratva": ['mw'],
    "parāvaravibhāgavid": ['mw'],
    "parāvaravid": ['mw'],
    "parāvareśa": ['mw'],
    "parāvarta": ['mw'],
    "parāvartana": ['ddsa', 'mw'],
    "parāvartaḥ": ['ap90'],
    "parāvartin": ['mw'],
    "parāvartya": ['mw'],
    "parāvartyavyavahāra": ['mw'],
    "parāvasathaśāyin": ['ddsa', 'mw'],
    "parāvasu": ['mw'],
    "parāvat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "parāvata": ['mw'],
    "parāvedī": ['mw'],
    "parāviddha": ['mw'],
    "parāviddhaḥ": ['ap90'],
    "parāvyadh": ['mw'],
    "parāvyādha": ['mw'],
    "parāvyādhaḥ": ['ap90'],
    "parāvā": ['mw'],
    "parāvāka": ['mw'],
    "parāvākaḥ": ['ap90'],
    "parāvṛj": ['cae', 'gra', 'mw'],
    "parāvṛkta": ['mw'],
    "parāvṛt": ['ap90', 'mw'],
    "parāvṛtta": ['ap90', 'bhs', 'mw'],
    "parāvṛtti": ['mw'],
    "parāvṛttiḥ": ['ap90'],
    "parāyati": ['gra', 'mw'],
    "parāyatta": ['cae', 'cped', 'ddsa', 'mw'],
    "parāyatī": ['ddsa'],
    "parāyaṇa": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "parāyaṇatā": ['mw'],
    "parāyaṇavat": ['mw'],
    "parāyaṇīya": ['bhs'],
    "parāyus": ['mw'],
    "parāyā": ['mw'],
    "parāñc": ['cae', 'ddsa', 'mw'],
    "parāñcana": ['mw'],
    "parāñcin": ['ddsa', 'mw'],
    "parāñja": ['mw'],
    "parāśakti": ['mw'],
    "parāśara": ['cae', 'ddsa', 'gra', 'mw'],
    "parāśaradharma": ['mw'],
    "parāśarakṣetramāhātmya": ['mw'],
    "parāśaramādhavīya": ['mw'],
    "parāśarapurāṇa": ['mw'],
    "parāśarasampāta": ['mw'],
    "parāśarasaṃhitā": ['mw'],
    "parāśarasiddhānta": ['mw'],
    "parāśarasmṛti": ['mw'],
    "parāśarasmṛtisaṃgraha": ['mw'],
    "parāśarasūtravṛtti": ['mw'],
    "parāśaratantra": ['mw'],
    "parāśaravaṃśavarṇana": ['mw'],
    "parāśaravijaya": ['mw'],
    "parāśaraḥ": ['ap90'],
    "parāśareśvara": ['mw'],
    "parāśareśvaratīrtha": ['mw'],
    "parāśarin": ['ap90', 'mw'],
    "parāśaropapurāṇa": ['mw'],
    "parāśas": ['mw'],
    "parāśraya": ['cae', 'ddsa', 'mw'],
    "parāśrayā": ['mw'],
    "parāśrita": ['mw'],
    "parāśvas": ['mw'],
    "parāśātayitṛ": ['mw'],
    "parāśīrṇa": ['mw'],
    "parāśṝ": ['mw'],
    "parāṃc": ['ap90'],
    "parāṃgavaḥ": ['ap90'],
    "parāṃjaḥ": ['ap90'],
    "parāṅ": ['mw'],
    "parāṅga": ['cae', 'ddsa', 'mw'],
    "parāṅgada": ['mw'],
    "parāṅgava": ['mw'],
    "parāṅkuśa": ['mw'],
    "parāṅkuśapañcaviṃśati": ['mw'],
    "parāṅkuśapādukāpañcāśat": ['mw'],
    "parāṅkuśāṣṭaka": ['mw'],
    "parāṅmanas": ['cae', 'mw'],
    "parāṅmukha": ['cae', 'ddsa', 'mw'],
    "parāṅmukhabhūta": ['mw'],
    "parāṅmukham": ['mw'],
    "parāṅmukhatva": ['mw'],
    "parāṅmukhatā": ['mw'],
    "parāṅmukhaya": ['mw'],
    "parāṅmukhībhū": ['mw'],
    "parāṅmukhīkṛ": ['cae', 'mw'],
    "parāṅāvṛtta": ['mw'],
    "parāṇ": ['mw'],
    "parāṇa": ['mw'],
    "parāṇasā": ['ap90'],
    "parāṇud": ['mw'],
    "parāṇutti": ['mw'],
    "parāṇuttiḥ": ['ap90'],
    "parāṇī": ['mw'],
    "parī": ['ap90', 'mw'],
    "parībhavaḥ": ['ap90'],
    "parībhāva": ['mw'],
    "parīcikṣiṣu": ['mw'],
    "parīdhya": ['mw'],
    "parīdhyai": ['mw'],
    "parīdhāna": ['mw'],
    "parīdhānaṃ": ['ap90'],
    "parīdhāvin": ['mw'],
    "parīdā": ['mw'],
    "parīdāha": ['mw'],
    "parīdāhaḥ": ['ap90'],
    "parīhāra": ['cae', 'mw'],
    "parīhāraḥ": ['ap90'],
    "parīhāsa": ['cae', 'ddsa', 'mw'],
    "parīhāsakeśava": ['mw'],
    "parīhāsakṣama": ['mw'],
    "parīhāsaśīla": ['mw'],
    "parīhāsaḥ": ['ap90'],
    "parījyā": ['mw'],
    "parīkṣ": ['ap90', 'mw'],
    "parīkṣaka": ['cae', 'ddsa', 'mw'],
    "parīkṣakaḥ": ['ap90'],
    "parīkṣaṇa": ['cae', 'mw'],
    "parīkṣaṇaṃ": ['ap90'],
    "parīkṣaṇīya": ['mw'],
    "parīkṣaṇīyatva": ['mw'],
    "parīkṣin": ['cae', 'ddsa', 'mw'],
    "parīkṣit": ['ap90', 'ddsa', 'mw'],
    "parīkṣita": ['ap90', 'ddsa', 'mw'],
    "parīkṣitavya": ['mw'],
    "parīkṣiti": ['ddsa', 'mw'],
    "parīkṣya": ['mw'],
    "parīkṣyate": ['bhs'],
    "parīkṣā": ['ap90', 'bhs', 'cae', 'mw'],
    "parīkṣākṣama": ['mw'],
    "parīkṣāpaddhati": ['mw'],
    "parīkṣārtha": ['mw'],
    "parīkṣātattva": ['mw'],
    "parīman": ['cae', 'gra', 'mw'],
    "parīmaṇi": ['mw'],
    "parīmāṇa": ['cae', 'ddsa', 'mw'],
    "parīmāṇaṃ": ['ap90'],
    "parīndana": ['mw'],
    "parīndanā": ['bhs'],
    "parīndita": ['mw'],
    "parīndāmi": ['bhs'],
    "parīps": ['mw'],
    "parīpsu": ['mw'],
    "parīpsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "parīpāka": ['cae', 'mw'],
    "parīpākaḥ": ['ap90'],
    "parīra": ['mw'],
    "parīrambha": ['cae', 'mw'],
    "parīraṃ": ['ap90'],
    "parīraṇa": ['mw'],
    "parīraṇaṃ": ['ap90'],
    "parīsara": ['cae', 'mw'],
    "parīsarpa": ['mw'],
    "parīsaryā": ['mw'],
    "parīsāra": ['ddsa', 'mw'],
    "parīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "parītat": ['mw'],
    "parītatā": ['mw'],
    "parīti": ['mw'],
    "parītin": ['mw'],
    "parītoyoni": ['mw'],
    "parītoṣa": ['cae', 'mw'],
    "parītta": ['bhs', 'cae', 'mw'],
    "parīttaka": ['bhs'],
    "parīttaśubha": ['bhs', 'mw'],
    "parītti": ['cae', 'mw'],
    "parīttābha": ['bhs', 'mw'],
    "parītya": ['mw'],
    "parītāna": ['mw'],
    "parītāpa": ['ap90', 'cae', 'ddsa', 'mw'],
    "parīvarta": ['cae', 'mw'],
    "parīvartam": ['mw'],
    "parīvartaḥ": ['ap90'],
    "parīvettṛ": ['cae', 'mw'],
    "parīveśaḥ": ['ap90'],
    "parīveṣa": ['mw'],
    "parīvāda": ['cae', 'mw'],
    "parīvādaḥ": ['ap90'],
    "parīvāha": ['cae', 'mw'],
    "parīvāhaḥ": ['ap90'],
    "parīvāpa": ['mw'],
    "parīvāpaḥ": ['ap90'],
    "parīvāpya": ['mw'],
    "parīvāra": ['cae', 'mw'],
    "parīvāraḥ": ['ap90'],
    "parīvṛta": ['cae', 'gra', 'mw'],
    "parīś": ['mw'],
    "parīśeṣa": ['mw'],
    "parīśeṣaḥ": ['ap90'],
    "parīśāsa": ['cae', 'mw'],
    "parīṇah": ['cae', 'gra', 'mw'],
    "parīṇas": ['cae', 'gra', 'mw'],
    "parīṇasa": ['cae', 'gra', 'mw'],
    "parīṇasā": ['mw'],
    "parīṇaśe": ['mw'],
    "parīṇāha": ['cae', 'mw'],
    "parīṇāhaḥ": ['ap90'],
    "parīṇāma": ['cae', 'mw'],
    "parīṇāmaḥ": ['ap90'],
    "parīṇāya": ['mw'],
    "parīṇāyaḥ": ['ap90'],
    "parīṣ": ['mw'],
    "parīṣahā": ['mw'],
    "parīṣeka": ['cae', 'mw'],
    "parīṣṭa": ['mw'],
    "parīṣṭi": ['cae', 'ddsa', 'mw'],
    "parīṣṭiḥ": ['ap90'],
    "parśu": ['cae', 'ddsa', 'gra', 'mw'],
    "parśukā": ['ap90', 'mw'],
    "parśumaya": ['mw'],
    "parśupāṇi": ['mw'],
    "parśurāma": ['mw'],
    "parśuḥ": ['ap90'],
    "parśvadha": ['mw'],
    "parśvadhaḥ": ['ap90'],
    "parśāna": ['cae', 'ddsa', 'gra', 'mw'],
    "parśūla": ['mw'],
    "parśūmat": ['mw'],
    "parūpaghāta": ['cped'],
    "parūpakkama": ['cped'],
    "parūpavāda": ['cped'],
    "parūḷha": ['cped'],
    "parūḷhakesa": ['cped'],
    "parūṣa": ['mw'],
    "parūṣaka": ['mw'],
    "parṇ": ['ap90', 'mw'],
    "parṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "parṇabhakṣa": ['mw'],
    "parṇabhedinī": ['mw'],
    "parṇabhojana": ['mw'],
    "parṇacara": ['mw'],
    "parṇacoraka": ['mw'],
    "parṇacīrapaṭa": ['mw'],
    "parṇadatta": ['mw'],
    "parṇadhi": ['cae', 'mw'],
    "parṇadhvas": ['mw'],
    "parṇaka": ['bhs', 'mw'],
    "parṇakaṣāyaniṣpakva": ['mw'],
    "parṇakaṣāyapakva": ['mw'],
    "parṇakhaṇḍa": ['mw'],
    "parṇakula": ['bhs'],
    "parṇakuṭikā": ['mw'],
    "parṇakuṭī": ['mw'],
    "parṇakāra": ['mw'],
    "parṇakṛcchra": ['mw'],
    "parṇala": ['ap90', 'mw'],
    "parṇalatā": ['mw'],
    "parṇalībhūta": ['mw'],
    "parṇamaya": ['cae', 'mw'],
    "parṇamayītva": ['mw'],
    "parṇamaṇi": ['mw'],
    "parṇamuc": ['mw'],
    "parṇamācāla": ['mw'],
    "parṇamṛga": ['mw'],
    "parṇanara": ['mw'],
    "parṇanāla": ['mw'],
    "parṇaprātyika": ['mw'],
    "parṇaprāśanin": ['mw'],
    "parṇapuruṣa": ['mw'],
    "parṇapuṭa": ['mw'],
    "parṇaruh": ['mw'],
    "parṇasa": ['mw'],
    "parṇasaṃstara": ['mw'],
    "parṇasi": ['mw'],
    "parṇatva": ['mw'],
    "parṇavalka": ['mw'],
    "parṇavallī": ['mw'],
    "parṇavant": ['cae'],
    "parṇavat": ['mw'],
    "parṇavilāsinī": ['mw'],
    "parṇavādya": ['mw'],
    "parṇavī": ['gra', 'mw'],
    "parṇavīṭikā": ['mw'],
    "parṇaya": ['gra', 'mw'],
    "parṇayaghna": ['gra', 'mw'],
    "parṇaśabara": ['mw'],
    "parṇaśabarī": ['bhs', 'mw'],
    "parṇaśabda": ['mw'],
    "parṇaśada": ['mw'],
    "parṇaśadya": ['mw'],
    "parṇaśar": ['mw'],
    "parṇaśayyā": ['cae', 'mw'],
    "parṇaśuṣ": ['mw'],
    "parṇaśāda": ['mw'],
    "parṇaśākhā": ['mw'],
    "parṇaśālā": ['mw'],
    "parṇaśālāgra": ['mw'],
    "parṇaśālāya": ['mw'],
    "parṇaṃ": ['ap90'],
    "parṇika": ['mw'],
    "parṇikā": ['mw'],
    "parṇila": ['ap90', 'mw'],
    "parṇilatā": ['mw'],
    "parṇin": ['ap90', 'cae', 'gra', 'mw'],
    "parṇinī": ['mw'],
    "parṇotsa": ['mw'],
    "parṇoṭaja": ['ddsa', 'mw'],
    "parṇya": ['cae', 'mw'],
    "parṇāda": ['cae', 'ddsa', 'mw'],
    "parṇāhāra": ['mw'],
    "parṇāla": ['mw'],
    "parṇāsaḥ": ['ap90'],
    "parṇāsi": ['mw'],
    "parṇāśa": ['mw'],
    "parṇāśana": ['cae', 'mw'],
    "parṇāśin": ['cae', 'mw'],
    "parṇāśā": ['mw'],
    "parṇāḍhaka": ['mw'],
    "parṇī": ['mw'],
    "parṇīya": ['mw'],
    "parṣ": ['ap90', 'gra', 'mw'],
    "parṣa": ['cae', 'gra', 'mw'],
    "parṣacchāradya": ['bhs'],
    "parṣad": ['ap90', 'cae', 'ddsa', 'mw'],
    "parṣadasādya": ['bhs'],
    "parṣadbhīru": ['mw'],
    "parṣadvala": ['mw'],
    "parṣadya": ['bhs'],
    "parṣadā": ['bhs'],
    "parṣatka": ['bhs', 'mw'],
    "parṣavant": ['bhs'],
    "parṣaḥ": ['ap90'],
    "parṣaṇi": ['cae', 'gra', 'mw'],
    "parṣi": ['ddsa'],
    "parṣika": ['mw'],
    "parṣin": ['mw'],
    "parṣiṣṭha": ['cae', 'gra', 'mw'],
    "parṣā": ['bhs'],
    "pas": ['mw'],
    "pasada": ['cped'],
    "pasahana": ['cped'],
    "pasahati": ['cped'],
    "pasahi": ['cped'],
    "pasahitvā": ['cped'],
    "pasanna": ['cped'],
    "pasannacitta": ['cped'],
    "pasannamānasa": ['cped'],
    "pasas": ['ap90', 'cae', 'mw'],
    "pasata": ['cped'],
    "pasattha": ['cped'],
    "pasava": ['cped'],
    "pasavanta": ['cped'],
    "pasavati": ['cped'],
    "pasavi": ['cped'],
    "pasavita": ['cped'],
    "pasavitvā": ['cped'],
    "pasayha": ['cped'],
    "pasaṁsaka": ['cped'],
    "pasaṁsana": ['cped'],
    "pasaṁsanta": ['cped'],
    "pasaṁsati": ['cped'],
    "pasaṁsi": ['cped'],
    "pasaṁsita": ['cped'],
    "pasaṁsitabba": ['cped'],
    "pasaṁsituṁ": ['cped'],
    "pasaṁsitvā": ['cped'],
    "pasaṁsiya": ['cped'],
    "pasaṁsā": ['cped'],
    "pasaṅga": ['cped'],
    "pasaṇḍika": ['cped'],
    "pasaṭa": ['cped'],
    "pasaṭṭha": ['cped'],
    "pasibbaka": ['cped'],
    "paspaśa": ['mw'],
    "paspaśaḥ": ['ap90'],
    "paspaśā": ['mw'],
    "paspṛdhāna": ['mw'],
    "passa": ['cped'],
    "passaddha": ['cped'],
    "passaddhi": ['cped'],
    "passambhanā": ['cped'],
    "passambhati": ['cped'],
    "passambhenta": ['cped'],
    "passambhesi": ['cped'],
    "passambheti": ['cped'],
    "passambhetvā": ['cped'],
    "passambhi": ['cped'],
    "passambhita": ['cped'],
    "passambhitvā": ['cped'],
    "passamāna": ['cped'],
    "passanta": ['cped'],
    "passasanta": ['cped'],
    "passasati": ['cped'],
    "passasi": ['cped'],
    "passasita": ['cped'],
    "passasitvā": ['cped'],
    "passati": ['cped'],
    "passi": ['cped'],
    "passitabba": ['cped'],
    "passituṁ": ['cped'],
    "passitvā": ['cped'],
    "passiya": ['cped'],
    "passāsa": ['cped'],
    "passāsī": ['cped'],
    "passāva": ['cped'],
    "pastia": ['gra'],
    "pastiasad": ['gra'],
    "pastiā": ['gra'],
    "pastiāvat": ['gra'],
    "pastya": ['cae', 'ddsa', 'gra', 'mw'],
    "pastyasad": ['cae', 'gra', 'mw'],
    "pastyaṃ": ['ap90'],
    "pastyā": ['gra', 'mw'],
    "pastyāvant": ['cae'],
    "pastyāvat": ['ap90', 'gra', 'mw'],
    "pasu": ['cped'],
    "pasupati": ['cped'],
    "pasuta": ['cped'],
    "pasāda": ['cped'],
    "pasādaka": ['cped'],
    "pasādaniya": ['cped'],
    "pasādenta": ['cped'],
    "pasādesi": ['cped'],
    "pasādetabba": ['cped'],
    "pasādeti": ['cped'],
    "pasādetvā": ['cped'],
    "pasādhana": ['cped'],
    "pasādhesi": ['cped'],
    "pasādheti": ['cped'],
    "pasādhetvā": ['cped'],
    "pasādhita": ['cped'],
    "pasādhiya": ['cped'],
    "pasādita": ['cped'],
    "pasākha": ['cped'],
    "pasākhā": ['cped'],
    "pasāraṇa": ['cped'],
    "pasāresi": ['cped'],
    "pasāreti": ['cped'],
    "pasāretvā": ['cped'],
    "pasārita": ['cped'],
    "pasāsati": ['cped'],
    "pasāsi": ['cped'],
    "pasāsita": ['cped'],
    "pasīdana": ['cped'],
    "pasīdanā": ['cped'],
    "pasīdati": ['cped'],
    "pasīdi": ['cped'],
    "pasīditabba": ['cped'],
    "pasīditvā": ['cped'],
    "pasūta": ['cped'],
    "pasūti": ['cped'],
    "pasūtighara": ['cped'],
    "pasūtikā": ['cped'],
    "pat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pata": ['ap90', 'ddsa', 'gra', 'mw'],
    "patad": ['mw'],
    "patadbhīru": ['mw'],
    "patadgraha": ['cae', 'ddsa', 'mw'],
    "patadgrāha": ['cae'],
    "pataga": ['cae', 'mw'],
    "patagapannaga": ['mw'],
    "patagapati": ['cae', 'mw'],
    "patagarāja": ['cae', 'mw'],
    "patagavara": ['mw'],
    "patageśvara": ['cae', 'mw'],
    "patagoraga": ['mw'],
    "pataka": ['ap90', 'mw'],
    "patama": ['mw'],
    "patamaḥ": ['ap90'],
    "patana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "patanadharmin": ['mw'],
    "patanadharmitva": ['mw'],
    "patanaśīla": ['mw'],
    "patanaṃ": ['ap90'],
    "patant": ['cae'],
    "patanta": ['cped'],
    "patantaka": ['mw'],
    "patanu": ['cped', 'mw'],
    "patanīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "patappanti": ['bhs'],
    "patara": ['cae', 'gra', 'mw'],
    "pataru": ['cae', 'gra', 'mw'],
    "patasa": ['mw'],
    "patat": ['ap90', 'ddsa', 'mw'],
    "patati": ['cped'],
    "patatpataṃga": ['mw'],
    "patatprakarṣa": ['mw'],
    "patatprakarṣatā": ['mw'],
    "patatra": ['cae', 'ddsa', 'gra', 'mw'],
    "patatraṃ": ['ap90'],
    "patatri": ['mw'],
    "patatriketana": ['mw'],
    "patatrin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "patatrirāj": ['cae', 'mw'],
    "patatrirāja": ['cae', 'mw'],
    "patatrivara": ['mw'],
    "patatriḥ": ['ap90'],
    "patay": ['cae'],
    "pataya": ['ddsa'],
    "patayatsakha": ['gra'],
    "patayiṣṇu": ['cae', 'gra', 'mw'],
    "patayiṣṇuka": ['cae', 'mw'],
    "patayālu": ['ap90', 'cae', 'mw'],
    "patañcala": ['mw'],
    "patañcikā": ['mw'],
    "patañjala": ['cae', 'mw'],
    "patañjali": ['cae', 'ddsa', 'mw'],
    "patañjalicarita": ['mw'],
    "patañjalikāvya": ['mw'],
    "patañjalisūtra": ['mw'],
    "patañjaliyoga": ['mw'],
    "pataṃ": ['mw'],
    "pataṃcikā": ['ap90'],
    "pataṃga": ['bhs', 'cae', 'gra', 'mw'],
    "pataṃgacara": ['bhs'],
    "pataṃgagrāma": ['mw'],
    "pataṃgaka": ['mw'],
    "pataṃgakānta": ['mw'],
    "pataṃgama": ['mw'],
    "pataṃgamaḥ": ['ap90'],
    "pataṃgara": ['cae', 'gra', 'mw'],
    "pataṃgarāja": ['cae', 'mw'],
    "pataṃgatā": ['mw'],
    "pataṃgavat": ['mw'],
    "pataṃgavṛtti": ['cae', 'mw'],
    "pataṃgaḥ": ['ap90'],
    "pataṃgikā": ['ap90', 'mw'],
    "pataṃgin": ['ap90', 'mw'],
    "pataṃginī": ['mw'],
    "pataṃgā": ['bhs', 'mw'],
    "pataṃgāśman": ['mw'],
    "pataṃgī": ['bhs', 'mw'],
    "pataṃjali": ['ap90'],
    "pataṃjaliḥ": ['ap90'],
    "pataṅga": ['ddsa'],
    "pataṅgama": ['ddsa'],
    "pataṅgara": ['ddsa'],
    "pataṅgavṛtti": ['ddsa'],
    "pateka": ['bhs'],
    "patera": ['ap90', 'mw'],
    "path": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "patha": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "pathadarśaka": ['mw'],
    "pathaka": ['mw'],
    "pathakalpanā": ['mw'],
    "pathakaḥ": ['ap90'],
    "pathanvat": ['mw'],
    "pathasundara": ['mw'],
    "pathat": ['ap90', 'mw'],
    "pathavī": ['cped'],
    "pathaḥ": ['ap90'],
    "patheṣṭhā": ['cae', 'gra', 'mw'],
    "pathi": ['cae', 'gra', 'mw'],
    "pathideya": ['mw'],
    "pathidruma": ['mw'],
    "pathika": ['cae', 'cped', 'ddsa', 'mw'],
    "pathikajana": ['mw'],
    "pathikasaṃhati": ['mw'],
    "pathikasaṃtati": ['mw'],
    "pathikasārtha": ['cae', 'mw'],
    "pathikaḥ": ['ap90'],
    "pathikā": ['ap90', 'mw'],
    "pathikāra": ['mw'],
    "pathikāya": ['mw'],
    "pathikāyita": ['mw'],
    "pathikāśraya": ['mw'],
    "pathikṛt": ['cae', 'ddsa', 'gra', 'mw'],
    "pathila": ['mw'],
    "pathilaḥ": ['ap90'],
    "pathimadhye": ['mw'],
    "pathimat": ['mw'],
    "pathin": ['ap90', 'mw'],
    "pathiprajña": ['mw'],
    "pathipriya": ['mw'],
    "pathipā": ['cae', 'mw'],
    "pathirakṣas": ['cae', 'mw'],
    "pathirakṣi": ['cae', 'gra', 'mw'],
    "pathistha": ['cae', 'mw'],
    "pathivāhaka": ['mw'],
    "pathiā": ['gra'],
    "pathiṣad": ['mw'],
    "pathiṣadi": ['mw'],
    "pathiṣṭhā": ['cae', 'mw'],
    "pathopadeśaka": ['cae', 'ddsa', 'mw'],
    "pathya": ['ap90', 'cae', 'ddsa', 'mw'],
    "pathyadana": ['bhs'],
    "pathyaśana": ['ddsa', 'mw'],
    "pathyaśāka": ['mw'],
    "pathyodana": ['mw'],
    "pathyā": ['gra', 'mw'],
    "pathyāpathya": ['mw'],
    "pathyāpathyanighaṇṭu": ['mw'],
    "pathyāpathyanirṇaya": ['mw'],
    "pathyāpathyavibodha": ['mw'],
    "pathyāpathyavidhi": ['mw'],
    "pathyāpathyavidhāna": ['mw'],
    "pathyāpathyaviniścaya": ['mw'],
    "pathyāśin": ['mw'],
    "pathājīva": ['bhs'],
    "pathātithi": ['ddsa', 'mw'],
    "pathāvī": ['cped'],
    "pathī": ['gra', 'mw'],
    "pati": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "patibbatā": ['cped'],
    "patidarśanalālasa": ['mw'],
    "patidevatā": ['cae', 'mw'],
    "patidevā": ['cae', 'mw'],
    "patidhara": ['bhs'],
    "patidharma": ['mw'],
    "patidharmavatī": ['mw'],
    "patidviṣ": ['gra', 'mw'],
    "patigaṇitaṭīkā": ['mw'],
    "patighna": ['mw'],
    "patighnī": ['cae'],
    "patighnīlakṣaṇa": ['mw'],
    "patighnīpāṇilekhā": ['mw'],
    "patighātinī": ['cae', 'mw'],
    "patihan": ['gra'],
    "patijuṣṭa": ['cae', 'gra'],
    "patijuṣṭā": ['mw'],
    "patika": ['bhs', 'cae', 'ddsa'],
    "patikhecara": ['mw'],
    "patikula": ['cped'],
    "patikāma": ['mw'],
    "patilaṅghana": ['mw'],
    "patiloka": ['cae', 'gra', 'mw'],
    "patilālasa": ['mw'],
    "patimatī": ['cae', 'mw'],
    "patimoka": ['bhs'],
    "patiprāṇā": ['cae', 'mw'],
    "patirip": ['gra', 'mw'],
    "patirūpa": ['cped'],
    "patirūpaka": ['cped'],
    "patisahagamananiṣedhanirāsaprakāśa": ['mw'],
    "patisevā": ['cae', 'mw'],
    "patissata": ['cped'],
    "patita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "patitagarbhā": ['mw'],
    "patitamūrdhaja": ['mw'],
    "patitasthita": ['mw'],
    "patitasāvitrīka": ['cae', 'mw'],
    "patitatva": ['mw'],
    "patitatyāgavidhi": ['mw'],
    "patitavya": ['mw'],
    "patitavṛtta": ['mw'],
    "patitekṣita": ['mw'],
    "patitiṭṭhati": ['cped'],
    "patitotpanna": ['mw'],
    "patitotthita": ['cae', 'mw'],
    "patitotthitadanta": ['mw'],
    "patitva": ['cae', 'ddsa', 'gra', 'mw'],
    "patitvana": ['cae', 'gra', 'mw'],
    "patitvaṃ": ['ap90'],
    "patitvā": ['cped'],
    "patitānna": ['cae', 'mw'],
    "pativat": ['gra'],
    "pativatnī": ['ap90', 'cae', 'mw'],
    "pativattenta": ['cped'],
    "pativatī": ['ap90', 'cae', 'mw'],
    "pativayas": ['mw'],
    "pativaṃsya": ['mw'],
    "pativedana": ['mw'],
    "patividya": ['gra', 'mw'],
    "pativrata": ['cae', 'mw'],
    "pativrataguṇa": ['mw'],
    "pativratopākhyāna": ['mw'],
    "pativratā": ['cae', 'mw'],
    "pativratādhyāya": ['mw'],
    "pativratāmaya": ['mw'],
    "pativratāmāhātmya": ['mw'],
    "pativratātva": ['mw'],
    "patiyāna": ['mw'],
    "patiśoka": ['mw'],
    "patiśokākula": ['mw'],
    "patiśuc": ['mw'],
    "patiḥ": ['ap90'],
    "patiṃvarā": ['ap90', 'cae', 'ddsa', 'mw'],
    "patiṣṭha": ['cae', 'gra', 'mw'],
    "patiṭṭhahati": ['cped'],
    "patiṭṭhahi": ['cped'],
    "patiṭṭhahitvā": ['cped'],
    "patiṭṭhanta": ['cped'],
    "patiṭṭhita": ['cped'],
    "patiṭṭhitabba": ['cped'],
    "patiṭṭhituṁ": ['cped'],
    "patiṭṭhā": ['cped'],
    "patiṭṭhāna": ['cped'],
    "patiṭṭhāpenta": ['cped'],
    "patiṭṭhāpesi": ['cped'],
    "patiṭṭhāpetar": ['cped'],
    "patiṭṭhāpeti": ['cped'],
    "patiṭṭhāpetvā": ['cped'],
    "patiṭṭhāpita": ['cped'],
    "patiṭṭhāpiya": ['cped'],
    "patiṭṭhāsi": ['cped'],
    "patiṭṭhātabba": ['cped'],
    "patiṭṭhāti": ['cped'],
    "patiṭṭhātuṁ": ['cped'],
    "patiṭṭhāya": ['cped'],
    "patka": ['bhs'],
    "patkāṣin": ['mw'],
    "patman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "patmin": ['mw'],
    "patni": ['mw'],
    "patnyodana": ['mw'],
    "patnyāṭa": ['mw'],
    "patnī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "patnīka": ['cae', 'mw'],
    "patnīkarman": ['mw'],
    "patnīmantra": ['mw'],
    "patnīsaṃnahana": ['mw'],
    "patnīsaṃyāja": ['mw'],
    "patnīsaṃyājana": ['mw'],
    "patnītva": ['mw'],
    "patnīvant": ['cae'],
    "patnīvat": ['gra', 'mw'],
    "patnīy": ['cae'],
    "patnīya": ['bhs'],
    "patnīyūpa": ['mw'],
    "patnīśāla": ['mw'],
    "patnīśālā": ['mw'],
    "patoda": ['cped'],
    "patodaka": ['cped'],
    "patodalaṭṭhi": ['cped'],
    "patra": ['gra'],
    "patrakaṃ": ['ap90'],
    "patraṃ": ['ap90'],
    "patraṇā": ['ap90'],
    "patrikā": ['ap90'],
    "patrin": ['ap90'],
    "patriṇī": ['ap90'],
    "patrī": ['ap90'],
    "patsala": ['mw'],
    "patsalaḥ": ['ap90'],
    "patsaṅgin": ['mw'],
    "patsukha": ['mw'],
    "patsutas": ['cae', 'gra', 'mw'],
    "patsutaḥ": ['ddsa'],
    "patsutaḥśī": ['cae', 'gra', 'mw'],
    "patta": ['cped'],
    "pattabba": ['cped'],
    "pattagandha": ['cped'],
    "pattagata": ['cped'],
    "pattagāhaka": ['cped'],
    "pattakkhandha": ['cped'],
    "pattalaka": ['mw'],
    "pattalā": ['mw'],
    "pattalīkṛ": ['mw'],
    "pattana": ['cae', 'ddsa', 'mw'],
    "pattanavaṇij": ['mw'],
    "pattanaṃ": ['ap90'],
    "pattanā": ['mw'],
    "pattanādhipati": ['mw'],
    "pattapiṇdika": ['cped'],
    "pattapāṇī": ['cped'],
    "pattaraṅga": ['mw'],
    "pattas": ['cae', 'gra', 'mw'],
    "pattastodāśa": ['mw'],
    "pattatas": ['cae'],
    "pattathavikā": ['cped'],
    "pattave": ['cae', 'mw'],
    "pattaṅga": ['mw'],
    "pattha": ['cped'],
    "patthaddha": ['cped'],
    "patthanā": ['cped'],
    "patthara": ['cped'],
    "pattharanta": ['cped'],
    "pattharati": ['cped'],
    "patthari": ['cped'],
    "pattharitvā": ['cped'],
    "patthayanta": ['cped'],
    "patthayati": ['cped'],
    "patthayi": ['cped'],
    "patthayitvā": ['cped'],
    "patthayāna": ['cped'],
    "patthaṭa": ['cped'],
    "patthenta": ['cped'],
    "patthesi": ['cped'],
    "pattheti": ['cped'],
    "patthetvā": ['cped'],
    "patthita": ['cped'],
    "patthiva": ['cped'],
    "patti": ['cae', 'cped', 'ddsa', 'mw'],
    "pattidāna": ['cped'],
    "pattigaṇaka": ['mw'],
    "pattika": ['ap90', 'cae', 'cped', 'mw'],
    "pattikarman": ['mw'],
    "pattikā": ['bhs'],
    "pattikāra": ['mw'],
    "pattikāya": ['mw'],
    "pattin": ['ap90', 'mw'],
    "pattipaṅkti": ['mw'],
    "pattisainya": ['mw'],
    "pattisaṃhati": ['mw'],
    "pattiḥ": ['ap90'],
    "pattorṇa": ['mw'],
    "pattra": ['cae', 'mw'],
    "pattrabandha": ['mw'],
    "pattrabhadrā": ['mw'],
    "pattrabhaṅga": ['cae', 'mw'],
    "pattrabhaṅgi": ['mw'],
    "pattrabhaṅgī": ['mw'],
    "pattrabāla": ['mw'],
    "pattracchaṭā": ['mw'],
    "pattraccheda": ['mw'],
    "pattracchedabhakti": ['cae', 'mw'],
    "pattracchedaka": ['mw'],
    "pattracchedya": ['cae', 'mw'],
    "pattrachedaka": ['bhs'],
    "pattracārika": ['bhs'],
    "pattracārikā": ['mw'],
    "pattradevī": ['mw'],
    "pattradhārā": ['mw'],
    "pattradāraka": ['mw'],
    "pattraghanā": ['mw'],
    "pattragupta": ['bhs', 'mw'],
    "pattrahasta": ['mw'],
    "pattrahima": ['mw'],
    "pattrajhaṃkāra": ['mw'],
    "pattraka": ['cae', 'mw'],
    "pattrakartarī": ['mw'],
    "pattrakaumudī": ['mw'],
    "pattrakāhalā": ['mw'],
    "pattrakṛcchra": ['mw'],
    "pattrala": ['cae', 'mw'],
    "pattralatā": ['mw'],
    "pattralavaṇa": ['mw'],
    "pattralekhā": ['cae', 'mw'],
    "pattramañjarī": ['mw'],
    "pattramukha": ['bhs'],
    "pattramāla": ['mw'],
    "pattramūlaka": ['mw'],
    "pattranyāsa": ['mw'],
    "pattranāmaka": ['mw'],
    "pattranāḍikā": ['mw'],
    "pattraparaśu": ['mw'],
    "pattraparśu": ['mw'],
    "pattrapati": ['mw'],
    "pattrapiśācikā": ['mw'],
    "pattraprakāśa": ['mw'],
    "pattrapuṣpa": ['mw'],
    "pattrapuṣpaka": ['mw'],
    "pattrapuṣpā": ['mw'],
    "pattrapuṭa": ['mw'],
    "pattrapuṭikā": ['mw'],
    "pattrapāka": ['mw'],
    "pattrapāla": ['mw'],
    "pattrapālī": ['mw'],
    "pattrapāśyā": ['cae', 'mw'],
    "pattrapāṭha": ['mw'],
    "pattraratha": ['cae', 'mw'],
    "pattrarathaśreṣṭha": ['mw'],
    "pattrarathendra": ['mw'],
    "pattrarathendraketu": ['mw'],
    "pattraratheśvara": ['mw'],
    "pattrarañjana": ['mw'],
    "pattrarekhā": ['mw'],
    "pattrasaṃskāra": ['mw'],
    "pattrasirā": ['mw'],
    "pattrasundara": ['mw'],
    "pattrasūci": ['mw'],
    "pattrataru": ['mw'],
    "pattrataṇḍulā": ['mw'],
    "pattravallarī": ['mw'],
    "pattravalli": ['mw'],
    "pattraveṣṭa": ['mw'],
    "pattraviśeṣaka": ['cae', 'mw'],
    "pattravāha": ['mw'],
    "pattravāja": ['mw'],
    "pattravṛścika": ['mw'],
    "pattray": ['cae'],
    "pattraya": ['mw'],
    "pattrayauvana": ['mw'],
    "pattrayāna": ['bhs'],
    "pattraśabara": ['mw'],
    "pattraśreṇī": ['mw'],
    "pattraśreṣṭha": ['mw'],
    "pattraśāka": ['cae', 'mw'],
    "pattraśākatṛṇa": ['mw'],
    "pattraśṛṅgī": ['mw'],
    "pattraṅga": ['mw'],
    "pattraṇā": ['mw'],
    "pattreśvaratīrtha": ['mw'],
    "pattri": ['mw'],
    "pattrika": ['mw'],
    "pattrikā": ['mw'],
    "pattrikākhya": ['mw'],
    "pattrikāpraveśa": ['mw'],
    "pattrin": ['cae', 'mw'],
    "pattrita": ['cae', 'mw'],
    "pattrivāha": ['mw'],
    "pattriṇī": ['mw'],
    "pattrollāsa": ['mw'],
    "pattropaskara": ['mw'],
    "pattrorṇa": ['cae', 'mw'],
    "pattrorṇaka": ['mw'],
    "pattrāhāra": ['mw'],
    "pattrākhya": ['mw'],
    "pattrālu": ['mw'],
    "pattrālī": ['mw'],
    "pattrāmlā": ['mw'],
    "pattrārūḍha": ['cae', 'mw'],
    "pattrāsura": ['mw'],
    "pattrāvalambana": ['mw'],
    "pattrāvali": ['cae', 'mw'],
    "pattrāvalī": ['cae'],
    "pattrāya": ['mw'],
    "pattrāñjana": ['mw'],
    "pattrāḍhya": ['mw'],
    "pattrāṅga": ['cae', 'mw'],
    "pattrāṅguli": ['cae', 'mw'],
    "pattrāṅgulī": ['cae', 'mw'],
    "pattrāṇya": ['mw'],
    "pattuṁ": ['cped'],
    "pattuṇṇa": ['cped'],
    "pattādhāraka": ['cped'],
    "pattānumodanā": ['cped'],
    "pattīyati": ['bhs'],
    "pattūra": ['mw'],
    "patvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "patvā": ['cped'],
    "paty": ['cae'],
    "patya": ['ddsa', 'mw'],
    "patāka": ['mw'],
    "patākika": ['ap90', 'mw'],
    "patākin": ['ap90', 'cae', 'ddsa', 'mw'],
    "patākinī": ['mw'],
    "patākocchrāyavat": ['mw'],
    "patākā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "patākādaṇḍa": ['cae', 'mw'],
    "patākādhvajamālin": ['mw'],
    "patākāsthāna": ['mw'],
    "patākāsthānaka": ['mw'],
    "patākāya": ['mw'],
    "patākāṃśuka": ['cae', 'mw'],
    "patāpa": ['cped'],
    "patāpata": ['ap90', 'mw'],
    "patāpavant": ['cped'],
    "patāpesi": ['cped'],
    "patāpeti": ['cped'],
    "patāpita": ['cped'],
    "patāvant": ['cped'],
    "patīci": ['cped'],
    "patīy": ['cae'],
    "patīya": ['mw'],
    "patīyas": ['cae', 'mw'],
    "patīyati": ['ap90', 'bhs'],
    "patīyaṃtī": ['ap90'],
    "pat‍tra": ['ddsa'],
    "pat‍tri": ['ddsa'],
    "pat‍trikā": ['ddsa'],
    "pat‍trorṇa": ['ddsa'],
    "pauccha": ['cae', 'ddsa', 'mw'],
    "paudanya": ['mw'],
    "paudgalika": ['bhs', 'mw'],
    "paugaṃḍa": ['ap90'],
    "paugaṇḍa": ['ddsa', 'mw'],
    "paukkasa": ['mw'],
    "paula": ['mw'],
    "paulahasti": ['mw'],
    "paulastya": ['cae', 'ddsa', 'mw'],
    "paulastyasmṛti": ['mw'],
    "paulastyaḥ": ['ap90'],
    "paulastī": ['ap90', 'mw'],
    "paulava": ['mw'],
    "pauli": ['mw'],
    "paulikā": ['mw'],
    "paulinya": ['mw'],
    "pauliśa": ['mw'],
    "pauliśamata": ['mw'],
    "pauliśasiddhānta": ['mw'],
    "pauliḥ": ['ap90'],
    "paulkasa": ['mw'],
    "pauloma": ['ap90', 'cae', 'ddsa', 'mw'],
    "paulomī": ['ap90', 'mw'],
    "paulomīpati": ['mw'],
    "paulomīvallabha": ['mw'],
    "paulomīśa": ['mw'],
    "pauluṣi": ['mw'],
    "pauluṣita": ['mw'],
    "paulāka": ['mw'],
    "paulāsa": ['mw'],
    "paumpā": ['mw'],
    "paumpāmāhātmya": ['mw'],
    "paunar": ['mw'],
    "paunarbhava": ['ap90', 'cae', 'ddsa', 'mw'],
    "paunarbhavika": ['bhs', 'mw'],
    "paunarnava": ['mw'],
    "paunarukta": ['mw'],
    "paunaruktaṃ": ['ap90'],
    "paunaruktika": ['mw'],
    "paunaruktya": ['cae', 'ddsa', 'mw'],
    "paunarvasava": ['mw'],
    "paunarvācanika": ['mw'],
    "paunarvācika": ['mw'],
    "paunarādheyika": ['mw'],
    "paunaḥ": ['mw'],
    "paunaḥpunika": ['ap90', 'mw'],
    "paunaḥpunya": ['cae', 'ddsa', 'mw'],
    "paunaḥpunyaṃ": ['ap90'],
    "paunaḥpunyena": ['mw'],
    "paupika": ['mw'],
    "paura": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "pauragīya": ['mw'],
    "paurajana": ['cae', 'mw'],
    "paurajānapada": ['mw'],
    "pauraka": ['mw'],
    "paurakanyā": ['mw'],
    "paurakaṃ": ['ap90'],
    "paurakutsī": ['mw'],
    "paurakārya": ['cae', 'mw'],
    "pauraloka": ['mw'],
    "pauramukhya": ['ddsa', 'mw'],
    "paurandara": ['ddsa'],
    "paurarucideva": ['mw'],
    "paurasakhya": ['ddsa', 'mw'],
    "paurastrī": ['mw'],
    "paurastya": ['ap90', 'cae', 'ddsa', 'mw'],
    "paurastyapavana": ['cae', 'mw'],
    "paurava": ['ap90', 'cae', 'ddsa', 'mw'],
    "pauravaka": ['mw'],
    "pauravatantava": ['mw'],
    "pauravī": ['mw'],
    "pauravīya": ['ap90', 'mw'],
    "pauravṛddha": ['mw'],
    "paurayoṣit": ['mw'],
    "pauraścaraṇika": ['mw'],
    "pauraṃdara": ['ap90', 'cae', 'mw'],
    "pauraṃdhra": ['mw'],
    "pauraṃjana": ['mw'],
    "pauraṇa": ['mw'],
    "pauraṇī": ['mw'],
    "pauraṇṭaka": ['mw'],
    "pauraṇṭhaka": ['mw'],
    "paureya": ['ap90', 'mw'],
    "paurika": ['cae', 'ddsa', 'mw'],
    "paurikaḥ": ['ap90'],
    "pauriṇa": ['mw'],
    "pauro": ['mw'],
    "paurobhāgya": ['cae', 'mw'],
    "paurobhāgyaṃ": ['ap90'],
    "paurodhasa": ['mw'],
    "paurodhasaṃ": ['ap90'],
    "paurodāśa": ['mw'],
    "paurodāśika": ['mw'],
    "paurodāśīya": ['mw'],
    "paurogava": ['cae', 'ddsa', 'mw'],
    "paurogavaḥ": ['ap90'],
    "paurohita": ['mw'],
    "paurohitika": ['mw'],
    "paurohitya": ['cae', 'mw'],
    "paurohityaṃ": ['ap90'],
    "pauroḍāśaḥ": ['ap90'],
    "pauroḍāśikaḥ": ['ap90'],
    "paurta": ['cae', 'mw'],
    "paurti": ['mw'],
    "paurtika": ['ap90', 'cae', 'ddsa', 'mw'],
    "pauru": ['mw'],
    "pauruhanmana": ['mw'],
    "pauruhūta": ['ap90', 'cae', 'ddsa', 'mw'],
    "paurukutsa": ['mw'],
    "paurukutsi": ['gra', 'mw'],
    "paurukutsia": ['gra'],
    "paurukutsya": ['gra', 'mw'],
    "paurumadga": ['mw'],
    "paurumīl̤ha": ['mw'],
    "paurumīḍha": ['mw'],
    "pauruśiṣṭi": ['mw'],
    "pauruṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "pauruṣaka": ['bhs'],
    "pauruṣamedhika": ['mw'],
    "pauruṣatva": ['mw'],
    "pauruṣatā": ['mw'],
    "pauruṣavidhika": ['mw'],
    "pauruṣeya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "pauruṣeyatva": ['mw'],
    "pauruṣeyavedavādin": ['mw'],
    "pauruṣika": ['mw'],
    "pauruṣikaḥ": ['ap90'],
    "pauruṣya": ['bhs', 'ddsa', 'mw'],
    "pauruṣyaṃ": ['ap90'],
    "pauruṣāda": ['mw'],
    "pauruṣāsakin": ['mw'],
    "pauruṣī": ['mw'],
    "paurva": ['ap90', 'mw'],
    "paurvabhaktika": ['mw'],
    "paurvadaihika": ['ap90', 'cae', 'mw'],
    "paurvadehika": ['ap90', 'cae', 'mw'],
    "paurvajanmika": ['bhs', 'mw'],
    "paurvaka": ['bhs', 'ddsa'],
    "paurvakālya": ['mw'],
    "paurvamadrika": ['mw'],
    "paurvanagareya": ['mw'],
    "paurvapadika": ['ap90', 'mw'],
    "paurvapañcālaka": ['mw'],
    "paurvavarṣika": ['mw'],
    "paurvaśāla": ['mw'],
    "paurvika": ['ap90', 'cae', 'ddsa', 'mw'],
    "paurvikī": ['mw'],
    "paurvāhlika": ['cae'],
    "paurvāhṇika": ['ap90', 'mw'],
    "paurvāntika": ['bhs'],
    "paurvāparya": ['cae', 'ddsa', 'mw'],
    "paurvāparyaṃ": ['ap90'],
    "paurvārdhaka": ['mw'],
    "paurvārdhika": ['mw'],
    "paurvātitha": ['mw'],
    "paurya": ['mw'],
    "paurāgragaṇya": ['ddsa', 'mw'],
    "paurāṅganā": ['mw'],
    "paurāṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "paurāṇaka": ['bhs'],
    "paurāṇika": ['ap90', 'cae', 'mw'],
    "paurī": ['mw'],
    "paurūravasa": ['cae', 'mw'],
    "paurṇa": ['mw'],
    "paurṇadarva": ['mw'],
    "paurṇamāsa": ['ap90', 'cae', 'ddsa', 'mw'],
    "paurṇamāsadharma": ['mw'],
    "paurṇamāsaka": ['mw'],
    "paurṇamāsasthālīpākaprayoga": ['mw'],
    "paurṇamāsavat": ['mw'],
    "paurṇamāseṣṭi": ['mw'],
    "paurṇamāseṣṭiprayoga": ['mw'],
    "paurṇamāsika": ['mw'],
    "paurṇamāsya": ['cae', 'mw'],
    "paurṇamāsyadhikaraṇa": ['mw'],
    "paurṇamāsyaṃ": ['ap90'],
    "paurṇamāsāyana": ['mw'],
    "paurṇamāsī": ['ap90', 'mw'],
    "paurṇamī": ['mw'],
    "paurṇasaugandhi": ['mw'],
    "paurṇavatsa": ['mw'],
    "paurṇima": ['mw'],
    "paurṇimaḥ": ['ap90'],
    "paurṇimā": ['ap90', 'mw'],
    "pauskara": ['mw'],
    "pautakrata": ['gra', 'mw'],
    "pautalaka": ['bhs'],
    "pautana": ['cae', 'ddsa', 'mw'],
    "pautanya": ['mw'],
    "pautarīya": ['mw'],
    "pautava": ['mw'],
    "pautavaṃ": ['ap90'],
    "pauti": ['mw'],
    "pautika": ['mw'],
    "pautikya": ['mw'],
    "pautikī": ['mw'],
    "pautimāṣa": ['mw'],
    "pautimāṣya": ['mw'],
    "pautimāṣyā": ['mw'],
    "pautimāṣyāyaṇa": ['mw'],
    "pautimāṣyāyaṇī": ['mw'],
    "pautināsikya": ['cae', 'ddsa', 'mw'],
    "pautra": ['ap90', 'cae', 'ddsa', 'mw'],
    "pautrajīvika": ['mw'],
    "pautraka": ['cae'],
    "pautramartya": ['mw'],
    "pautramṛtyu": ['mw'],
    "pautrika": ['ap90', 'mw'],
    "pautrikeya": ['ddsa', 'mw'],
    "pautrikeyavat": ['mw'],
    "pautrikeyaḥ": ['ap90'],
    "pautrikya": ['mw'],
    "pautrin": ['ddsa', 'mw'],
    "pautrya": ['mw'],
    "pautrādya": ['mw'],
    "pautrāgha": ['mw'],
    "pautrāyaṇa": ['mw'],
    "pautrī": ['ddsa', 'mw'],
    "pauttika": ['mw'],
    "pauttikaṃ": ['ap90'],
    "pautudruva": ['mw'],
    "pautṛka": ['mw'],
    "pauyamāni": ['mw'],
    "pauñjiṣṭa": ['cae'],
    "pauñjiṣṭha": ['cae', 'mw'],
    "pauḍa": ['mw'],
    "pauṃsavana": ['mw'],
    "pauṃsavanaṃ": ['ap90'],
    "pauṃsia": ['gra'],
    "pauṃsna": ['ap90', 'cae', 'ddsa', 'mw'],
    "pauṃsya": ['cae', 'ddsa', 'gra', 'mw'],
    "pauṃsyaṃ": ['ap90'],
    "pauṃsāyana": ['mw'],
    "pauṃścaleya": ['cae', 'mw'],
    "pauṃścaleyaḥ": ['ap90'],
    "pauṃścalya": ['cae', 'mw'],
    "pauṃścalyaṃ": ['ap90'],
    "pauṃścalīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "pauṃścalīyavidyā": ['mw'],
    "pauṃḍaryaṃ": ['ap90'],
    "pauṃḍarīka": ['ap90'],
    "pauṃḍrakaḥ": ['ap90'],
    "pauṃḍraḥ": ['ap90'],
    "pauṃḍrikaḥ": ['ap90'],
    "pauṇaki": ['ddsa', 'mw'],
    "pauṇikera": ['mw'],
    "pauṇiki": ['mw'],
    "pauṇya": ['ap90', 'cae', 'mw'],
    "pauṇḍarya": ['mw'],
    "pauṇḍarīka": ['bhs', 'cae', 'ddsa', 'mw'],
    "pauṇḍarīkadaśadivasapaddhati": ['mw'],
    "pauṇḍarīkahautraprayoga": ['mw'],
    "pauṇḍarīkahotṛsaptaka": ['mw'],
    "pauṇḍarīkakārikā": ['mw'],
    "pauṇḍarīkakḷptiprayoga": ['mw'],
    "pauṇḍarīkapaddhati": ['mw'],
    "pauṇḍarīkaprayoga": ['mw'],
    "pauṇḍarīkaratnākara": ['mw'],
    "pauṇḍarīkasāman": ['mw'],
    "pauṇḍarīya": ['mw'],
    "pauṇḍarīyaka": ['mw'],
    "pauṇḍhra": ['mw'],
    "pauṇḍra": ['bhs', 'cae', 'ddsa', 'mw'],
    "pauṇḍraka": ['cae', 'mw'],
    "pauṇḍramatsyaka": ['mw'],
    "pauṇḍranāgara": ['mw'],
    "pauṇḍrarāja": ['mw'],
    "pauṇḍravardhana": ['mw'],
    "pauṇḍravatsa": ['mw'],
    "pauṇḍraviṣaya": ['mw'],
    "pauṇḍrika": ['mw'],
    "pauṣa": ['cae', 'ddsa', 'mw'],
    "pauṣadha": ['mw'],
    "pauṣadhadina": ['mw'],
    "pauṣamāhātmya": ['mw'],
    "pauṣaḥ": ['ap90'],
    "pauṣkajiti": ['mw'],
    "pauṣkala": ['mw'],
    "pauṣkalaḥ": ['ap90'],
    "pauṣkaleyaka": ['mw'],
    "pauṣkalya": ['ddsa', 'mw'],
    "pauṣkalyaṃ": ['ap90'],
    "pauṣkalāvata": ['mw'],
    "pauṣkara": ['ap90', 'ddsa', 'mw'],
    "pauṣkaraka": ['mw'],
    "pauṣkarasaṃhitā": ['mw'],
    "pauṣkarasādi": ['mw'],
    "pauṣkaratantra": ['mw'],
    "pauṣkareyaka": ['mw'],
    "pauṣkariṇī": ['ap90', 'mw'],
    "pauṣki": ['mw'],
    "pauṣpa": ['ap90', 'ddsa', 'mw'],
    "pauṣpaka": ['bhs', 'mw'],
    "pauṣpakaṃ": ['ap90'],
    "pauṣpaketava": ['mw'],
    "pauṣpañji": ['mw'],
    "pauṣpi": ['mw'],
    "pauṣpidya": ['mw'],
    "pauṣpiñji": ['mw'],
    "pauṣpiñjin": ['mw'],
    "pauṣpiṇḍi": ['mw'],
    "pauṣpiṇḍya": ['mw'],
    "pauṣpāyaṇa": ['mw'],
    "pauṣpī": ['mw'],
    "pauṣpīya": ['mw'],
    "pauṣya": ['cae', 'ddsa', 'mw'],
    "pauṣyañji": ['mw'],
    "pauṣyiñji": ['mw'],
    "pauṣyopākhyāna": ['mw'],
    "pauṣī": ['mw'],
    "pauṣṇa": ['cae', 'ddsa', 'mw'],
    "pauṣṇaṃ": ['ap90'],
    "pauṣṇāvata": ['mw'],
    "pauṣṭhimera": ['mw'],
    "pauṣṭika": ['ap90', 'cae', 'ddsa', 'mw'],
    "pauṣṭī": ['mw'],
    "pauṭali": ['mw'],
    "pauṭāyana": ['mw'],
    "pav": ['mw'],
    "pava": ['cae', 'mw'],
    "pavaddha": ['cped'],
    "pavakkhati": ['cped'],
    "pavamāna": ['cae', 'ddsa', 'mw'],
    "pavamānahavis": ['mw'],
    "pavamānahoma": ['mw'],
    "pavamānahomapaddhati": ['mw'],
    "pavamānahomaprayoga": ['mw'],
    "pavamānahomavidhi": ['mw'],
    "pavamānapaddhati": ['mw'],
    "pavamānapañcasūkta": ['mw'],
    "pavamānasakha": ['mw'],
    "pavamānasomayajña": ['mw'],
    "pavamānasūkta": ['mw'],
    "pavamānavat": ['mw'],
    "pavamānaḥ": ['ap90'],
    "pavamānaṭippana": ['mw'],
    "pavamāneṣṭi": ['mw'],
    "pavamānoktha": ['mw'],
    "pavamānādhyāya": ['mw'],
    "pavana": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "pavanabhū": ['mw'],
    "pavanacakra": ['mw'],
    "pavanadūta": ['mw'],
    "pavanaja": ['cae', 'mw'],
    "pavanajava": ['mw'],
    "pavanakṣipta": ['mw'],
    "pavanapadavī": ['mw'],
    "pavanapañcāśikā": ['mw'],
    "pavanaprabhava": ['mw'],
    "pavanapāvana": ['mw'],
    "pavanaraṃhas": ['mw'],
    "pavanatanaya": ['cae', 'mw'],
    "pavanavijaya": ['mw'],
    "pavanavyādhi": ['mw'],
    "pavanavāhana": ['mw'],
    "pavanayogasaṃgraha": ['mw'],
    "pavaneṣṭa": ['mw'],
    "pavanodbhrānta": ['mw'],
    "pavanodbhrāntavīci": ['mw'],
    "pavanombuja": ['mw'],
    "pavanotkampin": ['cae', 'mw'],
    "pavanāghāta": ['mw'],
    "pavanāhata": ['mw'],
    "pavanāla": ['mw'],
    "pavanātmaja": ['mw'],
    "pavanāśa": ['mw'],
    "pavanāśana": ['cae', 'mw'],
    "pavanāśanāsa": ['mw'],
    "pavanāśin": ['cae', 'mw'],
    "pavanī": ['mw'],
    "pavara": ['bhs', 'cped'],
    "pavarga": ['mw'],
    "pavaru": ['mw'],
    "pavasati": ['cped'],
    "pavasi": ['cped'],
    "pavasitvā": ['cped'],
    "pavassana": ['cped'],
    "pavassati": ['cped'],
    "pavassi": ['cped'],
    "pavasta": ['cae', 'gra', 'mw'],
    "pavatta": ['cped'],
    "pavattana": ['cped'],
    "pavattati": ['cped'],
    "pavattenta": ['cped'],
    "pavattesi": ['cped'],
    "pavattetar": ['cped'],
    "pavatteti": ['cped'],
    "pavattetuṁ": ['cped'],
    "pavattetvā": ['cped'],
    "pavatti": ['cped'],
    "pavattita": ['cped'],
    "pavattitvā": ['cped'],
    "pavattāpana": ['cped'],
    "pavayitṛ": ['cae', 'mw'],
    "pavaḍḍha": ['cped'],
    "pavaḍḍhana": ['cped'],
    "pavaḍḍhati": ['cped'],
    "pavaḍḍhi": ['cped'],
    "pavaḍḍhita": ['cped'],
    "pavaḍḍhitvā": ['cped'],
    "pavaḥ": ['ap90'],
    "pavaṣṭurika": ['mw'],
    "pavedana": ['cped'],
    "pavedenta": ['cped'],
    "pavedesi": ['cped'],
    "pavedeti": ['cped'],
    "pavedetvā": ['cped'],
    "pavedhamāna": ['cped'],
    "pavedhati": ['cped'],
    "pavedhi": ['cped'],
    "pavedhita": ['cped'],
    "pavedhitvā": ['cped'],
    "pavedita": ['cped'],
    "pavediyamāna": ['cped'],
    "pavesa": ['cped'],
    "pavesaka": ['cped'],
    "pavesana": ['cped'],
    "pavesenta": ['cped'],
    "pavesesi": ['cped'],
    "pavesetar": ['cped'],
    "paveseti": ['cped'],
    "pavesetuṁ": ['cped'],
    "pavesetvā": ['cped'],
    "pavesita": ['cped'],
    "paveṇī": ['cped'],
    "pavi": ['cae', 'ddsa', 'gra', 'mw'],
    "paviddha": ['cped'],
    "pavijjhati": ['cped'],
    "pavijjhi": ['cped'],
    "pavijjhitvā": ['cped'],
    "pavimat": ['mw'],
    "pavinda": ['mw'],
    "pavisanta": ['cped'],
    "pavisati": ['cped'],
    "pavisi": ['cped'],
    "pavisituṁ": ['cped'],
    "pavisitvā": ['cped'],
    "pavita": ['ap90', 'mw'],
    "pavitra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pavitradarbha": ['mw'],
    "pavitradhara": ['mw'],
    "pavitradhānya": ['mw'],
    "pavitragiri": ['mw'],
    "pavitraka": ['mw'],
    "pavitrakaṃ": ['ap90'],
    "pavitrakāma": ['mw'],
    "pavitrakīrti": ['cae', 'mw'],
    "pavitrapati": ['mw'],
    "pavitrapaṭhana": ['mw'],
    "pavitrapāṇi": ['mw'],
    "pavitrapūta": ['cae', 'mw'],
    "pavitraratha": ['gra', 'mw'],
    "pavitrarogaparihāraprayoga": ['mw'],
    "pavitratarīkṛ": ['mw'],
    "pavitratva": ['mw'],
    "pavitratā": ['mw'],
    "pavitravat": ['ap90', 'ddsa', 'gra', 'mw'],
    "pavitravatī": ['mw'],
    "pavitray": ['cae'],
    "pavitraya": ['ddsa', 'mw'],
    "pavitrayati": ['ap90'],
    "pavitrayoni": ['mw'],
    "pavitreṣṭi": ['mw'],
    "pavitreṣṭihautra": ['mw'],
    "pavitreṣṭipaddhati": ['mw'],
    "pavitreṣṭiprayoga": ['mw'],
    "pavitreṣṭisūtra": ['mw'],
    "pavitrin": ['ap90', 'ddsa', 'mw'],
    "pavitrita": ['mw'],
    "pavitrā": ['mw'],
    "pavitrārohaṇa": ['mw'],
    "pavitrāropaṇa": ['ddsa', 'mw'],
    "pavitrāropaṇaputradaikādaśī": ['mw'],
    "pavitrāropaṇavidhāna": ['mw'],
    "pavitrātipavitra": ['mw'],
    "pavitrī": ['mw'],
    "pavitrībhū": ['mw'],
    "pavitrīkaraṇa": ['mw'],
    "pavitrīkṛ": ['cae', 'ddsa', 'mw'],
    "pavitrīkṛta": ['mw'],
    "pavitṛ": ['cae', 'mw'],
    "paviveka": ['cped'],
    "pavivitta": ['cped'],
    "paviḥ": ['ap90'],
    "paviṭṭha": ['cped'],
    "pavuccati": ['cped'],
    "pavutta": ['cped'],
    "pavuttha": ['cped'],
    "pavuṭṭha": ['cped'],
    "pavyaya": ['gra'],
    "pavyā": ['cae', 'mw'],
    "pavā": ['gra', 'mw'],
    "pavāha": ['cped'],
    "pavāhaka": ['cped'],
    "pavāhesi": ['cped'],
    "pavāheti": ['cped'],
    "pavāhetvā": ['cped'],
    "pavāhita": ['cped'],
    "pavākā": ['ap90', 'mw'],
    "pavāraṇā": ['cped'],
    "pavāresi": ['cped'],
    "pavāreti": ['cped'],
    "pavāretvā": ['cped'],
    "pavārita": ['cped'],
    "pavāru": ['mw'],
    "pavāruka": ['mw'],
    "pavāsa": ['cped'],
    "pavāsī": ['cped'],
    "pavāta": ['cped'],
    "pavāti": ['cped'],
    "pavāyati": ['cped'],
    "pavāyi": ['cped'],
    "pavāyita": ['cped'],
    "pavāyitvā": ['cped'],
    "pavāḷa": ['cped'],
    "pavāḷha": ['cped'],
    "pavīnasa": ['mw'],
    "pavīra": ['gra', 'mw'],
    "pavīrava": ['gra', 'mw'],
    "pavīravat": ['gra', 'mw'],
    "pavīraṃ": ['ap90'],
    "pavīru": ['gra', 'mw'],
    "pavītṛ": ['cae', 'gra', 'mw'],
    "pavīṇa": ['cped'],
    "pay": ['ap90', 'mw'],
    "paya": ['mw'],
    "payas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "payasa": ['mw'],
    "payasiṣṭha": ['mw'],
    "payaska": ['mw'],
    "payaskarṇī": ['mw'],
    "payaskaṃsa": ['mw'],
    "payaskumbha": ['mw'],
    "payaskuśā": ['mw'],
    "payaskāma": ['mw'],
    "payaskāmya": ['mw'],
    "payaskāra": ['mw'],
    "payaspa": ['mw'],
    "payaspati": ['mw'],
    "payaspā": ['cae', 'gra', 'mw'],
    "payaspātra": ['mw'],
    "payasvala": ['ap90', 'mw'],
    "payasvant": ['cae'],
    "payasvat": ['ddsa', 'gra', 'mw'],
    "payasvatī": ['mw'],
    "payasvin": ['ap90', 'cae', 'ddsa', 'mw'],
    "payasvinī": ['mw'],
    "payasya": ['ap90', 'cae', 'ddsa', 'mw'],
    "payasyati": ['ap90'],
    "payasyā": ['mw'],
    "payata": ['cped'],
    "payatana": ['cped'],
    "payaāhuti": ['mw'],
    "payaś": ['mw'],
    "payaścaya": ['mw'],
    "payaḥ": ['mw'],
    "payaḥkandā": ['mw'],
    "payaḥkṣīra": ['mw'],
    "payaḥpayoṣṇī": ['mw'],
    "payaḥphenī": ['mw'],
    "payaḥprasravin": ['mw'],
    "payaḥpratibimba": ['mw'],
    "payaḥpāna": ['ddsa', 'mw'],
    "payaḥpārāvara": ['mw'],
    "payaḥpāyikā": ['mw'],
    "payaḥpūra": ['cae', 'mw'],
    "payaḥsphāti": ['mw'],
    "payaḥsāman": ['mw'],
    "payaḥvikāra": ['mw'],
    "payirupāsanā": ['cped'],
    "payirupāsati": ['cped'],
    "payirupāsi": ['cped'],
    "payirupāsita": ['cped'],
    "payirupāsitvā": ['cped'],
    "payiṣṭha": ['mw'],
    "payo": ['cped', 'mw'],
    "payobhakṣa": ['mw'],
    "payobhṛt": ['cae', 'mw'],
    "payoda": ['cae', 'ddsa', 'mw'],
    "payodasuhṛd": ['mw'],
    "payodhara": ['cae', 'cped', 'mw'],
    "payodharonnati": ['ddsa', 'mw'],
    "payodharībhū": ['mw'],
    "payodhas": ['mw'],
    "payodhi": ['cae', 'mw'],
    "payodhija": ['mw'],
    "payodhika": ['mw'],
    "payodhikaṃ": ['ap90'],
    "payodhra": ['mw'],
    "payodhā": ['cae', 'gra', 'mw'],
    "payodhārā": ['cae', 'ddsa', 'mw'],
    "payodhārāgṛha": ['mw'],
    "payoduh": ['cae', 'gra', 'mw'],
    "payodā": ['mw'],
    "payoga": ['cped'],
    "payogakaraṇa": ['cped'],
    "payogarbha": ['mw'],
    "payogasampatti": ['cped'],
    "payogavipatti": ['cped'],
    "payogaḍa": ['mw'],
    "payoghana": ['mw'],
    "payograha": ['cae', 'mw'],
    "payograhasamarthanaprakāra": ['mw'],
    "payojaka": ['cped'],
    "payojana": ['cped'],
    "payojanman": ['mw'],
    "payojenta": ['cped'],
    "payojesi": ['cped'],
    "payojeta": ['cped'],
    "payojetar": ['cped'],
    "payojeti": ['cped'],
    "payojetvā": ['cped'],
    "payojita": ['cped'],
    "payojiya": ['cped'],
    "payolatā": ['mw'],
    "payomaya": ['cae', 'mw'],
    "payomuc": ['cae', 'mw'],
    "payomukha": ['cae', 'mw'],
    "payomānuṣī": ['mw'],
    "payomṛtatīrtha": ['mw'],
    "payonidhana": ['mw'],
    "payonidhi": ['cae', 'mw'],
    "payopavasana": ['mw'],
    "payora": ['mw'],
    "payoraya": ['mw'],
    "payoraḥ": ['ap90'],
    "payoruha": ['mw'],
    "payorāśi": ['cae', 'mw'],
    "payovidārikā": ['mw'],
    "payovrata": ['cae', 'mw'],
    "payovratatā": ['mw'],
    "payovāha": ['cae', 'mw'],
    "payovṛdh": ['cae', 'gra', 'mw'],
    "payoṣṇijātā": ['mw'],
    "payoṣṇikā": ['mw'],
    "payoṣṇī": ['ap90', 'cae', 'ddsa', 'mw'],
    "payutta": ['cped'],
    "payuttaka": ['cped'],
    "payuñjamāna": ['cped'],
    "payuñjati": ['cped'],
    "payuñji": ['cped'],
    "payuñjitvā": ['cped'],
    "payyaka": ['bhs', 'cped'],
    "payāsi": ['cped'],
    "payāta": ['cped'],
    "payāti": ['cped'],
    "payāya": ['mw'],
    "payāyate": ['ap90'],
    "pañc": ['ddsa', 'mw'],
    "pañca": ['cped', 'ddsa', 'mw'],
    "pañcabaddha": ['mw'],
    "pañcabala": ['cped', 'mw'],
    "pañcabalā": ['mw'],
    "pañcabandha": ['mw'],
    "pañcabandhana": ['cped'],
    "pañcabandhura": ['mw'],
    "pañcabhadra": ['mw'],
    "pañcabhautika": ['mw'],
    "pañcabhaṅga": ['mw'],
    "pañcabhaṭṭīya": ['mw'],
    "pañcabhuja": ['mw'],
    "pañcabhāra": ['mw'],
    "pañcabhāṣāmaṇi": ['mw'],
    "pañcabhūryābhimukhā": ['bhs', 'mw'],
    "pañcabhūta": ['cae', 'mw'],
    "pañcabhūtaparityakta": ['mw'],
    "pañcabhūtaviveka": ['mw'],
    "pañcabhūtavādārtha": ['mw'],
    "pañcabhūtātmaka": ['mw'],
    "pañcabhṛṅga": ['mw'],
    "pañcabila": ['mw'],
    "pañcabinduprasṛta": ['mw'],
    "pañcabodha": ['mw'],
    "pañcabrahmamantra": ['mw'],
    "pañcabrahmavidyopaniṣad": ['mw'],
    "pañcabrahmopaniṣad": ['mw'],
    "pañcabāhu": ['mw'],
    "pañcabāṇa": ['cae', 'mw'],
    "pañcabāṇavijaya": ['mw'],
    "pañcabāṇavilāsa": ['mw'],
    "pañcabāṇī": ['mw'],
    "pañcabīja": ['mw'],
    "pañcacakṣus": ['bhs', 'mw'],
    "pañcacandra": ['mw'],
    "pañcacatvāriṃśa": ['mw'],
    "pañcacatvāriṃśat": ['cae', 'mw'],
    "pañcacitika": ['mw'],
    "pañcacitīka": ['mw'],
    "pañcacola": ['mw'],
    "pañcacoḍā": ['mw'],
    "pañcacāmara": ['mw'],
    "pañcacāmarastotra": ['mw'],
    "pañcacīra": ['bhs', 'mw'],
    "pañcacīraka": ['bhs'],
    "pañcacīrā": ['bhs'],
    "pañcacūḍa": ['bhs', 'mw'],
    "pañcacūḍā": ['mw'],
    "pañcacūḍāmaṇi": ['mw'],
    "pañcadaivata": ['mw'],
    "pañcadaivatya": ['mw'],
    "pañcadaka": ['mw'],
    "pañcadasa": ['cped'],
    "pañcadaśa": ['cae', 'gra', 'mw'],
    "pañcadaśacchadi": ['mw'],
    "pañcadaśadhā": ['cae', 'mw'],
    "pañcadaśakarman": ['mw'],
    "pañcadaśakṛtvas": ['cae', 'mw'],
    "pañcadaśama": ['mw'],
    "pañcadaśamālāmantravidhi": ['mw'],
    "pañcadaśan": ['cae', 'gra', 'mw'],
    "pañcadaśarca": ['cae', 'mw'],
    "pañcadaśarātra": ['mw'],
    "pañcadaśavartani": ['mw'],
    "pañcadaśavarṇamālikā": ['mw'],
    "pañcadaśavat": ['mw'],
    "pañcadaśavārṣika": ['cae', 'mw'],
    "pañcadaśika": ['mw'],
    "pañcadaśin": ['cae', 'mw'],
    "pañcadaśāha": ['cae', 'mw'],
    "pañcadaśāhika": ['mw'],
    "pañcadaśākṣara": ['mw'],
    "pañcadaśī": ['mw'],
    "pañcadaśīprakaraṇa": ['mw'],
    "pañcadaśīsamāsa": ['mw'],
    "pañcadaśītantra": ['mw'],
    "pañcadaśīviveka": ['mw'],
    "pañcadaśīvyākhyā": ['mw'],
    "pañcadaśīyantravidhāna": ['mw'],
    "pañcadaṇḍa": ['mw'],
    "pañcadaṇḍacchattraprabandha": ['cae', 'mw'],
    "pañcadhanus": ['mw'],
    "pañcadhā": ['cae', 'cped', 'mw'],
    "pañcadhābandhyāprakāśa": ['mw'],
    "pañcadhāraṇaka": ['mw'],
    "pañcadhātu": ['cae'],
    "pañcadhīva": ['mw'],
    "pañcadrauṇika": ['mw'],
    "pañcadrāviḍajāti": ['mw'],
    "pañcadāman": ['mw'],
    "pañcadīrgha": ['mw'],
    "pañcagata": ['mw'],
    "pañcagatika": ['bhs'],
    "pañcagatisamatikrānta": ['mw'],
    "pañcagauḍabrāhmaṇajāti": ['mw'],
    "pañcagava": ['mw'],
    "pañcagavadhana": ['mw'],
    "pañcagavya": ['cae', 'mw'],
    "pañcagavyaghṛta": ['mw'],
    "pañcagavyamelanaprakāra": ['mw'],
    "pañcagavyāpānavat": ['mw'],
    "pañcagavī": ['mw'],
    "pañcagaṅga": ['mw'],
    "pañcagaṅgā": ['mw'],
    "pañcagaṇayoga": ['mw'],
    "pañcagaṇḍa": ['bhs'],
    "pañcagaṇḍaka": ['mw'],
    "pañcaghāta": ['mw'],
    "pañcagorasa": ['cped'],
    "pañcagoṇi": ['mw'],
    "pañcagrahayogaśānti": ['mw'],
    "pañcagranthī": ['mw'],
    "pañcagrāmī": ['mw'],
    "pañcagu": ['mw'],
    "pañcagupta": ['mw'],
    "pañcagupti": ['mw'],
    "pañcaguṇa": ['mw'],
    "pañcagārgya": ['mw'],
    "pañcagūḍha": ['mw'],
    "pañcagṛhitin": ['mw'],
    "pañcagṛhīta": ['mw'],
    "pañcahasta": ['mw'],
    "pañcahattha": ['cped'],
    "pañcahavis": ['mw'],
    "pañcahotra": ['mw'],
    "pañcahotṛ": ['gra', 'mw'],
    "pañcahradatīrtha": ['mw'],
    "pañcahāva": ['mw'],
    "pañcahāyana": ['cae', 'mw'],
    "pañcajana": ['cae', 'mw'],
    "pañcajanendra": ['mw'],
    "pañcajanī": ['mw'],
    "pañcajanīna": ['mw'],
    "pañcajitaṃte": ['mw'],
    "pañcajñāna": ['mw'],
    "pañcajñānika": ['bhs'],
    "pañcaka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "pañcakalpa": ['mw'],
    "pañcakalpī": ['mw'],
    "pañcakalyāṇa": ['cped'],
    "pañcakalyāṇaka": ['mw'],
    "pañcakamālā": ['mw'],
    "pañcakamāsika": ['mw'],
    "pañcakapāla": ['mw'],
    "pañcakarma": ['mw'],
    "pañcakarman": ['mw'],
    "pañcakarmavidhi": ['mw'],
    "pañcakarmādhikāra": ['mw'],
    "pañcakarmī": ['mw'],
    "pañcakarpaṭa": ['mw'],
    "pañcakarṇa": ['mw'],
    "pañcakavidhi": ['mw'],
    "pañcakavidhāna": ['mw'],
    "pañcakaśata": ['mw'],
    "pañcakaśānti": ['mw'],
    "pañcakaśāntividhi": ['mw'],
    "pañcakaṣāya": ['mw'],
    "pañcakaṣāyaja": ['mw'],
    "pañcakaṣāyottha": ['mw'],
    "pañcakhaṭva": ['mw'],
    "pañcakhaṭvī": ['mw'],
    "pañcakkhandha": ['cped'],
    "pañcakkhattuṁ": ['cped'],
    "pañcakkhu": ['cped'],
    "pañcakleśabheda": ['mw'],
    "pañcakola": ['mw'],
    "pañcakolaka": ['mw'],
    "pañcakośa": ['mw'],
    "pañcakośasaṃnyāsācāra": ['mw'],
    "pañcakośaviveka": ['mw'],
    "pañcakoṇa": ['cae', 'mw'],
    "pañcakrama": ['mw'],
    "pañcakramaṭippanī": ['mw'],
    "pañcakrośa": ['mw'],
    "pañcakrośamañjarī": ['mw'],
    "pañcakrośamañjarīsudarśana": ['mw'],
    "pañcakrośamāhātmya": ['mw'],
    "pañcakrośayātrā": ['mw'],
    "pañcakrośī": ['mw'],
    "pañcakrośīyātrāvidhi": ['mw'],
    "pañcakroṣṭṛ": ['mw'],
    "pañcakālakriyādīpa": ['mw'],
    "pañcakālapaddhati": ['mw'],
    "pañcakālapravartana": ['mw'],
    "pañcakāmaguṇa": ['cped'],
    "pañcakāpittha": ['mw'],
    "pañcakārukī": ['mw'],
    "pañcakāvalī": ['mw'],
    "pañcakāṣṭakacayanasūtra": ['mw'],
    "pañcakāṭhakaprayogavṛtti": ['mw'],
    "pañcakūrca": ['mw'],
    "pañcakṛtvas": ['cae', 'mw'],
    "pañcakṛtya": ['mw'],
    "pañcakṛṣṇa": ['mw'],
    "pañcakṛṣṇala": ['mw'],
    "pañcakṛṣṇalaka": ['cae', 'mw'],
    "pañcakṣāra": ['mw'],
    "pañcalakṣaṇa": ['mw'],
    "pañcalakṣaṇavidhi": ['mw'],
    "pañcalakṣaṇyanugama": ['mw'],
    "pañcalakṣaṇī": ['mw'],
    "pañcalakṣaṇīkroḍa": ['mw'],
    "pañcalakṣaṇīprakāśa": ['mw'],
    "pañcalakṣaṇīvivecana": ['mw'],
    "pañcalakṣaṇīṭīkā": ['mw'],
    "pañcalambaka": ['mw'],
    "pañcalavaṇa": ['mw'],
    "pañcaloha": ['mw'],
    "pañcalohaka": ['mw'],
    "pañcalāṅgala": ['mw'],
    "pañcalāṅgaladānavidhi": ['mw'],
    "pañcama": ['cae', 'ddsa', 'mw'],
    "pañcamabhāgīya": ['mw'],
    "pañcamahiṣa": ['mw'],
    "pañcamahābhūtamaya": ['mw'],
    "pañcamahākalpa": ['mw'],
    "pañcamahāpariccāga": ['cped'],
    "pañcamahāpātakin": ['mw'],
    "pañcamahāvilokana": ['cped'],
    "pañcamahāyajña": ['mw'],
    "pañcamahāyajñavidhi": ['mw'],
    "pañcamaka": ['mw'],
    "pañcamakāra": ['mw'],
    "pañcamam": ['mw'],
    "pañcamantratanu": ['mw'],
    "pañcamarāga": ['mw'],
    "pañcamasvara": ['mw'],
    "pañcamasārasaṃhitā": ['mw'],
    "pañcamavat": ['mw'],
    "pañcamavilāsa": ['mw'],
    "pañcamaya": ['ddsa', 'mw'],
    "pañcamaṇḍalanamaskāra": ['mw'],
    "pañcameni": ['mw'],
    "pañcamin": ['mw'],
    "pañcamithyātvaṭīkā": ['mw'],
    "pañcamudrā": ['mw'],
    "pañcamukha": ['cae', 'mw'],
    "pañcamukhī": ['mw'],
    "pañcamuṣṭi": ['mw'],
    "pañcamuṣṭika": ['mw'],
    "pañcamuṣṭī": ['mw'],
    "pañcamāra": ['mw'],
    "pañcamāsya": ['cae', 'mw'],
    "pañcamāṣaka": ['mw'],
    "pañcamāṣika": ['cae', 'mw'],
    "pañcamī": ['mw'],
    "pañcamīkalpa": ['mw'],
    "pañcamīkramakalpalatā": ['mw'],
    "pañcamīstava": ['mw'],
    "pañcamīstavarāja": ['mw'],
    "pañcamīsudhodaya": ['mw'],
    "pañcamīsādhana": ['mw'],
    "pañcamīvarivasyārahasya": ['mw'],
    "pañcamūla": ['mw'],
    "pañcamūrti": ['mw'],
    "pañcamūrtika": ['mw'],
    "pañcamūtra": ['mw'],
    "pañcan": ['cae', 'ddsa', 'gra', 'mw'],
    "pañcanada": ['cae', 'mw'],
    "pañcanadakṣetramāhātmya": ['mw'],
    "pañcanadamāhātmya": ['mw'],
    "pañcanadatīrtha": ['mw'],
    "pañcanakha": ['cae', 'ddsa', 'mw'],
    "pañcanalīya": ['mw'],
    "pañcanavata": ['mw'],
    "pañcanavati": ['mw'],
    "pañcanavatitama": ['mw'],
    "pañcanavuti": ['cped'],
    "pañcanetta": ['cped'],
    "pañcanidhana": ['mw'],
    "pañcanimba": ['mw'],
    "pañcanirgranthīsūtra": ['mw'],
    "pañcanāli": ['mw'],
    "pañcanāman": ['cae', 'mw'],
    "pañcanāmāvalī": ['mw'],
    "pañcanātha": ['mw'],
    "pañcanī": ['mw'],
    "pañcanīrājana": ['mw'],
    "pañcanīvaraṇa": ['cped'],
    "pañcapada": ['cae', 'mw'],
    "pañcapadārthī": ['mw'],
    "pañcapadī": ['mw'],
    "pañcapadīvivṛti": ['mw'],
    "pañcapakṣin": ['mw'],
    "pañcapakṣiśāstra": ['mw'],
    "pañcapakṣī": ['mw'],
    "pañcapakṣīṭīkā": ['mw'],
    "pañcapala": ['mw'],
    "pañcapalika": ['mw'],
    "pañcapallava": ['mw'],
    "pañcapalī": ['mw'],
    "pañcapariṣad": ['mw'],
    "pañcaparva": ['mw'],
    "pañcaparvamāhātmya": ['mw'],
    "pañcaparvan": ['mw'],
    "pañcaparvata": ['mw'],
    "pañcaparvīmāhātmya": ['mw'],
    "pañcaparvīyavidhi": ['mw'],
    "pañcaparṇikā": ['mw'],
    "pañcaparṇī": ['mw'],
    "pañcapatiṭṭhita": ['cped'],
    "pañcapattra": ['mw'],
    "pañcapañcaka": ['mw'],
    "pañcapañcan": ['mw'],
    "pañcapañcanakha": ['mw'],
    "pañcapañcin": ['mw'],
    "pañcapañcāśa": ['mw'],
    "pañcapañcāśat": ['cae', 'mw'],
    "pañcapaññāsati": ['cped'],
    "pañcapaśu": ['mw'],
    "pañcapaṭala": ['mw'],
    "pañcapaṭalikā": ['mw'],
    "pañcapaṭu": ['mw'],
    "pañcapaṭṭika": ['cae'],
    "pañcaphuṭṭika": ['mw'],
    "pañcapitta": ['mw'],
    "pañcapraharaṇa": ['mw'],
    "pañcaprakaraṇa": ['mw'],
    "pañcaprakaraṇī": ['mw'],
    "pañcaprastha": ['mw'],
    "pañcaprayoga": ['mw'],
    "pañcaprayāga": ['mw'],
    "pañcaprādeśa": ['mw'],
    "pañcaprāsāda": ['mw'],
    "pañcaprāṇa": ['mw'],
    "pañcaprāṇāhutikhaṇḍa": ['mw'],
    "pañcapura": ['mw'],
    "pañcapuruṣam": ['mw'],
    "pañcapurāṇīya": ['mw'],
    "pañcaputra": ['mw'],
    "pañcapuṣpamaya": ['mw'],
    "pañcapāda": ['cae', 'gra', 'mw'],
    "pañcapādikā": ['mw'],
    "pañcapādikādhyāsabhāṣyavyākhyā": ['mw'],
    "pañcapādikāvivaraṇa": ['mw'],
    "pañcapādikāvivaraṇaprakāśikā": ['mw'],
    "pañcapādikāvyākhyā": ['mw'],
    "pañcapādikāśāstradarpaṇa": ['mw'],
    "pañcapādikāṭīkā": ['mw'],
    "pañcapādikāṭīkātattvadīpana": ['mw'],
    "pañcapādī": ['mw'],
    "pañcapātra": ['mw'],
    "pañcapūlī": ['mw'],
    "pañcarakṣaka": ['mw'],
    "pañcarakṣā": ['mw'],
    "pañcarasā": ['mw'],
    "pañcaratna": ['mw'],
    "pañcaratnakalā": ['mw'],
    "pañcaratnakiraṇāvali": ['mw'],
    "pañcaratnamaya": ['mw'],
    "pañcaratnamālikā": ['mw'],
    "pañcaratnaprakāśa": ['mw'],
    "pañcaratnastava": ['mw'],
    "pañcaratnākarastotra": ['mw'],
    "pañcaraśmi": ['gra', 'mw'],
    "pañcarca": ['cae', 'mw'],
    "pañcarudra": ['mw'],
    "pañcarudropaniṣadbhāṣya": ['mw'],
    "pañcarudrīya": ['mw'],
    "pañcarājīphala": ['mw'],
    "pañcarātra": ['cae', 'mw'],
    "pañcarātradīpikā": ['mw'],
    "pañcarātraka": ['mw'],
    "pañcarātrakadīpikā": ['mw'],
    "pañcarātrakanaivedyavidhāna": ['mw'],
    "pañcarātrakapakvānnavidhāna": ['mw'],
    "pañcarātrakaprāyaścitta": ['mw'],
    "pañcarātrakarakṣā": ['mw'],
    "pañcarātranaivedyavidhāna": ['mw'],
    "pañcarātrapakvānnavidhāna": ['mw'],
    "pañcarātraprāyaścitta": ['mw'],
    "pañcarātrarakṣā": ['mw'],
    "pañcarātrika": ['mw'],
    "pañcarāśika": ['mw'],
    "pañcarūpakośa": ['mw'],
    "pañcasahasrī": ['cae', 'mw'],
    "pañcasahassa": ['cped'],
    "pañcasamāsīya": ['mw'],
    "pañcasapta": ['mw'],
    "pañcasaptata": ['mw'],
    "pañcasaptati": ['mw'],
    "pañcasaptatitama": ['mw'],
    "pañcasasya": ['mw'],
    "pañcasata": ['cped'],
    "pañcasattati": ['cped'],
    "pañcasattra": ['mw'],
    "pañcasavana": ['mw'],
    "pañcasaṃdhi": ['mw'],
    "pañcasaṃskāra": ['mw'],
    "pañcasaṃskāramahiman": ['mw'],
    "pañcasaṃskāraprayoga": ['mw'],
    "pañcasaṃskāravidhi": ['mw'],
    "pañcasaṭṭhi": ['cped'],
    "pañcasiddhauṣadhika": ['mw'],
    "pañcasiddhauṣadhī": ['mw'],
    "pañcasiddhānta": ['mw'],
    "pañcasiddhāntikā": ['mw'],
    "pañcaskandha": ['mw'],
    "pañcaskandhaka": ['mw'],
    "pañcaskandhavimocaka": ['mw'],
    "pañcaskandhī": ['mw'],
    "pañcasmṛti": ['mw'],
    "pañcaso": ['cped'],
    "pañcasrotas": ['mw'],
    "pañcastava": ['mw'],
    "pañcastavavyākhyā": ['mw'],
    "pañcastavī": ['mw'],
    "pañcasugandhaka": ['mw'],
    "pañcasvarodaya": ['mw'],
    "pañcasvarā": ['mw'],
    "pañcasvarānirṇaya": ['mw'],
    "pañcasvastyayana": ['mw'],
    "pañcasāmaka": ['mw'],
    "pañcasāra": ['mw'],
    "pañcasāyaka": ['mw'],
    "pañcasāṃvatsarika": ['cae', 'mw'],
    "pañcasīla": ['cped'],
    "pañcasūkta": ['mw'],
    "pañcasūnā": ['mw'],
    "pañcasūryābhimukhā": ['bhs'],
    "pañcasūtra": ['mw'],
    "pañcat": ['mw'],
    "pañcatakṣa": ['mw'],
    "pañcatakṣī": ['mw'],
    "pañcatanmātra": ['mw'],
    "pañcatantra": ['cae', 'mw'],
    "pañcatantraka": ['cae'],
    "pañcatantrakāvyadarpaṇa": ['mw'],
    "pañcatapa": ['mw'],
    "pañcatapas": ['cae', 'mw'],
    "pañcataponvita": ['mw'],
    "pañcatattva": ['mw'],
    "pañcatattvaprakāśa": ['mw'],
    "pañcatattvātmakastotra": ['mw'],
    "pañcataya": ['cae', 'mw'],
    "pañcatha": ['cae', 'mw'],
    "pañcathu": ['mw'],
    "pañcatikta": ['mw'],
    "pañcatiktaghṛta": ['mw'],
    "pañcatiṁsati": ['cped'],
    "pañcatrika": ['mw'],
    "pañcatriṃśa": ['cae', 'mw'],
    "pañcatriṃśacchlokī": ['mw'],
    "pañcatriṃśat": ['cae', 'mw'],
    "pañcatriṃśati": ['cae', 'mw'],
    "pañcatriṃśatpīṭhikā": ['mw'],
    "pañcatriṃśika": ['mw'],
    "pañcattāḷīsati": ['cped'],
    "pañcatva": ['cae', 'mw'],
    "pañcatā": ['cae', 'mw'],
    "pañcatāra": ['mw'],
    "pañcatīrthī": ['mw'],
    "pañcaudana": ['mw'],
    "pañcavadanastotra": ['mw'],
    "pañcavaggiya": ['cped'],
    "pañcavaktra": ['cae', 'mw'],
    "pañcavaktrarasa": ['mw'],
    "pañcavaktrastotra": ['mw'],
    "pañcavaktrā": ['mw'],
    "pañcavali": ['mw'],
    "pañcavalkala": ['mw'],
    "pañcavallabhā": ['mw'],
    "pañcavandhura": ['mw'],
    "pañcavardhana": ['mw'],
    "pañcavarga": ['bhs', 'cae', 'mw'],
    "pañcavarṇa": ['cae', 'mw'],
    "pañcavarṇatā": ['mw'],
    "pañcavarṣa": ['cae', 'mw'],
    "pañcavarṣadeśīya": ['mw'],
    "pañcavarṣaka": ['cae', 'mw'],
    "pañcavarṣakadeśīya": ['mw'],
    "pañcavarṣika": ['bhs'],
    "pañcavarṣikamaha": ['mw'],
    "pañcavarṣīya": ['cae', 'mw'],
    "pañcavastu": ['mw'],
    "pañcavaṇṇa": ['cped'],
    "pañcavaṭa": ['mw'],
    "pañcavaṭamāhātmya": ['mw'],
    "pañcavaṭuka": ['bhs'],
    "pañcavaṭī": ['mw'],
    "pañcavaṭīmāhātmya": ['mw'],
    "pañcavidha": ['cae', 'cped', 'mw'],
    "pañcavidhanāmabhāṣya": ['mw'],
    "pañcavidhasūtra": ['mw'],
    "pañcavidheya": ['mw'],
    "pañcavigrāham": ['mw'],
    "pañcavijaya": ['mw'],
    "pañcavikrama": ['mw'],
    "pañcaviṃśa": ['cae', 'mw'],
    "pañcaviṃśabrāhmaṇa": ['cae', 'mw'],
    "pañcaviṃśaka": ['mw'],
    "pañcaviṃśat": ['cae', 'mw'],
    "pañcaviṃśati": ['cae', 'mw'],
    "pañcaviṃśatigaṇa": ['mw'],
    "pañcaviṃśatika": ['mw'],
    "pañcaviṃśatikā": ['mw'],
    "pañcaviṃśatima": ['mw'],
    "pañcaviṃśatirātra": ['mw'],
    "pañcaviṃśatisāhasrikā": ['bhs', 'mw'],
    "pañcaviṃśatitama": ['mw'],
    "pañcavāda": ['mw'],
    "pañcavādakroḍapattra": ['mw'],
    "pañcavādaṭīkā": ['mw'],
    "pañcavāhin": ['mw'],
    "pañcavārṣika": ['cae', 'mw'],
    "pañcavātīya": ['mw'],
    "pañcavīragoṣṭha": ['mw'],
    "pañcavīrakumāra": ['bhs'],
    "pañcavīsati": ['cped'],
    "pañcavṛkṣa": ['mw'],
    "pañcavṛt": ['mw'],
    "pañcavṛtam": ['mw'],
    "pañcayajña": ['mw'],
    "pañcayajñaparibhraṣṭa": ['mw'],
    "pañcayakṣā": ['mw'],
    "pañcayojana": ['mw'],
    "pañcayojanī": ['mw'],
    "pañcayuga": ['mw'],
    "pañcayāma": ['gra', 'mw'],
    "pañcaśaila": ['mw'],
    "pañcaśairīṣaka": ['mw'],
    "pañcaśala": ['mw'],
    "pañcaśara": ['cae', 'mw'],
    "pañcaśaranirṇaya": ['mw'],
    "pañcaśaravijaya": ['mw'],
    "pañcaśaravyākhyā": ['mw'],
    "pañcaśarāva": ['mw'],
    "pañcaśas": ['cae', 'mw'],
    "pañcaśasya": ['mw'],
    "pañcaśata": ['cae', 'mw'],
    "pañcaśatatama": ['mw'],
    "pañcaśatika": ['mw'],
    "pañcaśatī": ['mw'],
    "pañcaśatīprabandha": ['mw'],
    "pañcaśikha": ['bhs', 'mw'],
    "pañcaśikhin": ['mw'],
    "pañcaśikhīkṛta": ['mw'],
    "pañcaśila": ['mw'],
    "pañcaśirīṣa": ['mw'],
    "pañcaślokī": ['mw'],
    "pañcaśukla": ['mw'],
    "pañcaśākha": ['cae', 'mw'],
    "pañcaśāradīya": ['mw'],
    "pañcaśāstra": ['mw'],
    "pañcaśīla": ['mw'],
    "pañcaśīrṣa": ['cae', 'mw'],
    "pañcaśīrṣaka": ['bhs'],
    "pañcaśūraṇa": ['mw'],
    "pañcaḍākinī": ['mw'],
    "pañcaṅga": ['cped'],
    "pañcaṅgika": ['cped'],
    "pañcaṅgulika": ['cped'],
    "pañcaṣa": ['cae', 'ddsa', 'mw'],
    "pañcaṣaṣṭa": ['mw'],
    "pañcaṣaṣṭi": ['mw'],
    "pañcaṣaṣṭitama": ['mw'],
    "pañcedhmīya": ['mw'],
    "pañcendra": ['mw'],
    "pañcendrakalpa": ['mw'],
    "pañcendriya": ['cae', 'mw'],
    "pañcendropākhyāna": ['mw'],
    "pañceṣu": ['cae', 'ddsa', 'mw'],
    "pañchīhila": ['mw'],
    "pañci": ['mw'],
    "pañcika": ['bhs', 'mw'],
    "pañcikā": ['mw'],
    "pañcin": ['cae', 'ddsa', 'mw'],
    "pañcopacāraka": ['mw'],
    "pañcopākhyāna": ['mw'],
    "pañcopākhyānasaṃgraha": ['mw'],
    "pañcābdākhya": ['cae', 'mw'],
    "pañcābhiññā": ['cped'],
    "pañcābhyadhika": ['cae'],
    "pañcābjamaṇḍala": ['mw'],
    "pañcācalāṅka": ['mw'],
    "pañcādhyāyī": ['mw'],
    "pañcāgni": ['cae', 'mw'],
    "pañcāgnika": ['mw'],
    "pañcāgnisādhana": ['mw'],
    "pañcāgnitva": ['mw'],
    "pañcāgnividyā": ['mw'],
    "pañcāgnividyāprakaraṇa": ['mw'],
    "pañcāgnyādhāna": ['mw'],
    "pañcāha": ['cped', 'mw'],
    "pañcāhika": ['bhs', 'mw'],
    "pañcāja": ['mw'],
    "pañcākhyāna": ['mw'],
    "pañcākhyānavārttika": ['mw'],
    "pañcākṣa": ['mw'],
    "pañcākṣara": ['cae', 'ddsa', 'mw'],
    "pañcākṣarakalpa": ['mw'],
    "pañcākṣaramaya": ['mw'],
    "pañcākṣaramāhātmya": ['mw'],
    "pañcākṣaraśas": ['mw'],
    "pañcākṣarī": ['mw'],
    "pañcākṣarīstotra": ['mw'],
    "pañcākṣarīvidhāna": ['mw'],
    "pañcākṣarīyantropadeśa": ['mw'],
    "pañcākṣarīṣaṭprayoga": ['mw'],
    "pañcāla": ['bhs', 'cae', 'ddsa', 'mw'],
    "pañcālacaṇḍa": ['mw'],
    "pañcālagaṇḍa": ['bhs'],
    "pañcālaka": ['mw'],
    "pañcālapadavṛtti": ['mw'],
    "pañcālarāja": ['mw'],
    "pañcālarājan": ['mw'],
    "pañcālikā": ['mw'],
    "pañcālā": ['bhs'],
    "pañcālī": ['mw'],
    "pañcāmla": ['mw'],
    "pañcāmṛta": ['cae', 'mw'],
    "pañcāmṛtābhiṣekaprakāra": ['mw'],
    "pañcānana": ['mw'],
    "pañcānanadeśa": ['mw'],
    "pañcānandamāhātmya": ['mw'],
    "pañcānantariya": ['cped'],
    "pañcānanī": ['mw'],
    "pañcānugāna": ['mw'],
    "pañcāpañcīnā": ['mw'],
    "pañcāpsaras": ['mw'],
    "pañcāpsarasa": ['mw'],
    "pañcāpūpa": ['mw'],
    "pañcāra": ['cae', 'gra', 'mw'],
    "pañcārcis": ['mw'],
    "pañcārtha": ['mw'],
    "pañcārthabhāṣyadīpikā": ['mw'],
    "pañcārī": ['mw'],
    "pañcārṣeya": ['mw'],
    "pañcāstikāya": ['mw'],
    "pañcāstikāyabālāvabodha": ['mw'],
    "pañcāstikāyasaṃgrahasūtra": ['mw'],
    "pañcāsuvandhura": ['mw'],
    "pañcāsva": ['mw'],
    "pañcāsya": ['cae', 'ddsa', 'mw'],
    "pañcāsīti": ['cped'],
    "pañcātapika": ['bhs'],
    "pañcātapā": ['mw'],
    "pañcātmaka": ['cae', 'mw'],
    "pañcātmakatva": ['mw'],
    "pañcāvadāna": ['mw'],
    "pañcāvaraṇastotra": ['mw'],
    "pañcāvarta": ['mw'],
    "pañcāvastha": ['mw'],
    "pañcāvatta": ['mw'],
    "pañcāvattatva": ['mw'],
    "pañcāvattatā": ['mw'],
    "pañcāvattin": ['mw'],
    "pañcāvattīya": ['mw'],
    "pañcāvayava": ['cae', 'ddsa', 'mw'],
    "pañcāvaṭa": ['mw'],
    "pañcāvika": ['mw'],
    "pañcāvudha": ['cped'],
    "pañcāyatana": ['mw'],
    "pañcāyatanapaddhati": ['mw'],
    "pañcāyatanapratiṣṭhāpaddhati": ['mw'],
    "pañcāyatanārthavarṇaśīrṣopaniṣad": ['mw'],
    "pañcāyudha": ['mw'],
    "pañcāyudhaprapañca": ['mw'],
    "pañcāyudharatnamālā": ['mw'],
    "pañcāyudhastava": ['mw'],
    "pañcāyudhastotra": ['mw'],
    "pañcāśa": ['ddsa', 'mw'],
    "pañcāśac": ['mw'],
    "pañcāśacchas": ['mw'],
    "pañcāśad": ['mw'],
    "pañcāśadbhāga": ['cae', 'mw'],
    "pañcāśaddhā": ['mw'],
    "pañcāśadgāthā": ['mw'],
    "pañcāśadvarṣa": ['mw'],
    "pañcāśadvarṣatā": ['mw'],
    "pañcāśaka": ['cae', 'mw'],
    "pañcāśat": ['cae', 'ddsa', 'gra', 'mw'],
    "pañcāśata": ['mw'],
    "pañcāśati": ['bhs', 'mw'],
    "pañcāśatka": ['mw'],
    "pañcāśatpalika": ['mw'],
    "pañcāśatpaṇika": ['mw'],
    "pañcāśatsahasrīmahākālasaṃhitā": ['mw'],
    "pañcāśattama": ['mw'],
    "pañcāśattamavārṣa": ['mw'],
    "pañcāśikā": ['mw'],
    "pañcāśima": ['bhs'],
    "pañcāśra": ['mw'],
    "pañcāśā": ['mw'],
    "pañcāśīta": ['mw'],
    "pañcāśīti": ['mw'],
    "pañcāśītitama": ['mw'],
    "pañcāṃśa": ['cae', 'mw'],
    "pañcāṅga": ['bhs', 'cae', 'mw'],
    "pañcāṅgagaṇita": ['mw'],
    "pañcāṅgagupta": ['mw'],
    "pañcāṅgakaumudī": ['mw'],
    "pañcāṅgakautuka": ['mw'],
    "pañcāṅgapattra": ['mw'],
    "pañcāṅgaphala": ['mw'],
    "pañcāṅgaratnāvalī": ['mw'],
    "pañcāṅgarudranyāsa": ['mw'],
    "pañcāṅgasaralī": ['mw'],
    "pañcāṅgasādhana": ['mw'],
    "pañcāṅgasādhanagrahodāharaṇa": ['mw'],
    "pañcāṅgasādhanasāraṇī": ['mw'],
    "pañcāṅgasāraṇī": ['mw'],
    "pañcāṅgatattva": ['mw'],
    "pañcāṅgavinoda": ['mw'],
    "pañcāṅgaviprahīna": ['mw'],
    "pañcāṅgavipratihīna": ['mw'],
    "pañcāṅgaśodhana": ['mw'],
    "pañcāṅgaśuddhi": ['mw'],
    "pañcāṅgika": ['bhs'],
    "pañcāṅgula": ['bhs', 'mw'],
    "pañcāṅguli": ['mw'],
    "pañcāṅgulī": ['mw'],
    "pañcāṅguri": ['mw'],
    "pañcāṅgādika": ['mw'],
    "pañcāṅgānayana": ['mw'],
    "pañcāṅgī": ['mw'],
    "pañcī": ['mw'],
    "pañcīkaraṇa": ['ddsa', 'mw'],
    "pañcīkaraṇamahāvākyārtha": ['mw'],
    "pañcīkaraṇamahāvākyārthabodha": ['mw'],
    "pañcīkaraṇaprakriyā": ['mw'],
    "pañcīkaraṇatātparyacandrikā": ['mw'],
    "pañcīkaraṇavivaraṇa": ['mw'],
    "pañcīkaraṇaviveka": ['mw'],
    "pañcīkaraṇavārttika": ['mw'],
    "pañcīkaraṇavārttikābharaṇa": ['mw'],
    "pañcīkaraṇānandākhyā": ['mw'],
    "pañcīkṛ": ['cae', 'ddsa'],
    "pañcīkṛta": ['mw'],
    "pañcīkṛtaṭīkā": ['mw'],
    "pañcūḷaka": ['cped'],
    "pañha": ['cped'],
    "pañhavissajjana": ['cped'],
    "pañhavyākaraṇa": ['cped'],
    "pañj": ['mw'],
    "pañjaka": ['ddsa', 'mw'],
    "pañjala": ['bhs', 'mw'],
    "pañjali": ['cped'],
    "pañjalika": ['cped'],
    "pañjara": ['cae', 'cped', 'ddsa', 'mw'],
    "pañjarabhāj": ['mw'],
    "pañjaracālananyāya": ['mw'],
    "pañjaraka": ['mw'],
    "pañjarakapiñjala": ['cae', 'mw'],
    "pañjarakapota": ['cae', 'mw'],
    "pañjarakesarin": ['mw'],
    "pañjaraśuka": ['cae', 'mw'],
    "pañjarākheṭa": ['mw'],
    "pañji": ['mw'],
    "pañjikā": ['cae', 'ddsa', 'mw'],
    "pañjikākāraka": ['mw'],
    "pañjikāpradīpa": ['mw'],
    "pañjikāraka": ['mw'],
    "pañjī": ['cae', 'mw'],
    "pañjīkara": ['mw'],
    "pañña": ['cped'],
    "paññapeti": ['cped'],
    "paññata": ['cped'],
    "paññatta": ['cped'],
    "paññatti": ['cped'],
    "paññatā": ['cped'],
    "paññavant": ['cped'],
    "paññā": ['cped'],
    "paññābala": ['cped'],
    "paññācakkhu": ['cped'],
    "paññādhana": ['cped'],
    "paññākkhandha": ['cped'],
    "paññāpaka": ['cped'],
    "paññāpana": ['cped'],
    "paññāpenta": ['cped'],
    "paññāpesi": ['cped'],
    "paññāpetar": ['cped'],
    "paññāpeti": ['cped'],
    "paññāpetvā": ['cped'],
    "paññāpita": ['cped'],
    "paññāsampadā": ['cped'],
    "paññāvimutti": ['cped'],
    "paññāvuddhi": ['cped'],
    "paññāyamāna": ['cped'],
    "paññāyati": ['cped'],
    "paññāyi": ['cped'],
    "paññāyitvā": ['cped'],
    "paññāṇa": ['cped'],
    "paś": ['cae', 'ddsa', 'gra', 'mw'],
    "paśavya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "paśavyatama": ['mw'],
    "paśavyavāhana": ['mw'],
    "paśca": ['ap90', 'bhs', 'ddsa', 'gra', 'mw'],
    "paścama": ['bhs'],
    "paścima": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "paścimabhāga": ['mw'],
    "paścimadakṣiṇa": ['cae', 'mw'],
    "paścimadarśana": ['mw'],
    "paścimadeśa": ['mw'],
    "paścimadikpati": ['mw'],
    "paścimadvāra": ['mw'],
    "paścimadvārika": ['mw'],
    "paścimajana": ['mw'],
    "paścimaka": ['bhs'],
    "paścimaraṅga": ['mw'],
    "paścimaraṅgamāhātmya": ['mw'],
    "paścimaraṅganāthastotra": ['mw'],
    "paścimaraṅgarājastava": ['mw'],
    "paścimatantra": ['mw'],
    "paścimatas": ['mw'],
    "paścimatāna": ['mw'],
    "paścime": ['mw'],
    "paścimena": ['mw'],
    "paścimetara": ['mw'],
    "paścimottara": ['cae', 'mw'],
    "paścimottaradikpati": ['mw'],
    "paścimottarapūrva": ['mw'],
    "paścimā": ['ap90'],
    "paścimābhimukha": ['mw'],
    "paścimācala": ['ddsa', 'mw'],
    "paścimāmbudhi": ['mw'],
    "paścimānupāka": ['mw'],
    "paścimārdha": ['mw'],
    "paścimāśāpati": ['mw'],
    "paścā": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "paścābhakta": ['bhs'],
    "paścāc": ['mw'],
    "paścāccara": ['mw'],
    "paścācchirāśayana": ['bhs'],
    "paścācchramaṇa": ['bhs', 'mw'],
    "paścād": ['mw'],
    "paścādahas": ['mw'],
    "paścādakṣam": ['mw'],
    "paścādanvavasāyin": ['mw'],
    "paścādapavarga": ['mw'],
    "paścādbaddhapuruṣa": ['mw'],
    "paścādbhakta": ['bhs'],
    "paścādbhāga": ['mw'],
    "paścādbāhubaddha": ['mw'],
    "paścāddaghvan": ['gra', 'mw'],
    "paścāddvārika": ['mw'],
    "paścādghāṭa": ['mw'],
    "paścādoṣa": ['mw'],
    "paścādukti": ['mw'],
    "paścādvartin": ['mw'],
    "paścādvāta": ['cae', 'mw'],
    "paścāja": ['mw'],
    "paścāl": ['mw'],
    "paścālloka": ['mw'],
    "paścān": ['mw'],
    "paścānmukha": ['bhs'],
    "paścānmukhāśrita": ['mw'],
    "paścānmāruta": ['mw'],
    "paścānnata": ['mw'],
    "paścānutāpa": ['mw'],
    "paścāpin": ['mw'],
    "paścārdha": ['cae', 'ddsa', 'mw'],
    "paścārdhaḥ": ['ap90'],
    "paścārdhe": ['mw'],
    "paścārdhya": ['cae', 'mw'],
    "paścāsomapa": ['mw'],
    "paścāsomapītha": ['mw'],
    "paścāt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "paścātkarṇam": ['mw'],
    "paścātkāla": ['cae', 'mw'],
    "paścātkāle": ['mw'],
    "paścātkṛta": ['mw'],
    "paścātpariveṣya": ['mw'],
    "paścātpuromāruta": ['mw'],
    "paścātpuroḍāśa": ['mw'],
    "paścātpādadviguṇa": ['mw'],
    "paścātsad": ['mw'],
    "paścāttara": ['mw'],
    "paścāttiryakpramāṇa": ['mw'],
    "paścāttāpa": ['cae', 'ddsa', 'mw'],
    "paścāttāpahata": ['mw'],
    "paścāttāpasamanvita": ['mw'],
    "paścāttāpin": ['cae', 'mw'],
    "paścātāt": ['cae', 'gra', 'mw'],
    "paśu": ['cae', 'ddsa', 'gra', 'mw'],
    "paśubali": ['mw'],
    "paśubandha": ['cae', 'mw'],
    "paśubandhaka": ['mw'],
    "paśubandhakārikā": ['mw'],
    "paśubandhapaddhati": ['mw'],
    "paśubandhaprayoga": ['mw'],
    "paśubandhaprayogapaddhati": ['mw'],
    "paśubandhayājin": ['mw'],
    "paśubandhayūpa": ['mw'],
    "paśubhartṛ": ['mw'],
    "paśubheda": ['mw'],
    "paśucaryā": ['mw'],
    "paśucit": ['mw'],
    "paśuda": ['mw'],
    "paśudevata": ['mw'],
    "paśudevatā": ['mw'],
    "paśudharma": ['mw'],
    "paśudharman": ['mw'],
    "paśudhānyadhanarddhimat": ['mw'],
    "paśudā": ['mw'],
    "paśudāvan": ['mw'],
    "paśugaṇa": ['mw'],
    "paśughna": ['cae', 'mw'],
    "paśughnatva": ['mw'],
    "paśughāta": ['cae', 'mw'],
    "paśugāyatrī": ['mw'],
    "paśuhan": ['mw'],
    "paśuharītakī": ['mw'],
    "paśuhautra": ['mw'],
    "paśuhautraprayoga": ['mw'],
    "paśuhavya": ['cae', 'mw'],
    "paśuiṣ": ['gra'],
    "paśujanana": ['mw'],
    "paśujāta": ['mw'],
    "paśujātīya": ['mw'],
    "paśuka": ['mw'],
    "paśukalpa": ['mw'],
    "paśukalpapaddhati": ['mw'],
    "paśukarman": ['cae', 'mw'],
    "paśukriyā": ['mw'],
    "paśukā": ['ap90', 'mw'],
    "paśukāma": ['mw'],
    "paśukḷpti": ['mw'],
    "paśumaitrāvaruṇaprayoga": ['mw'],
    "paśumant": ['cae'],
    "paśumat": ['gra', 'mw'],
    "paśumata": ['mw'],
    "paśumedha": ['mw'],
    "paśumeḍhra": ['mw'],
    "paśumohanikā": ['mw'],
    "paśumāra": ['cae', 'mw'],
    "paśumāraka": ['mw'],
    "paśumāram": ['mw'],
    "paśumāraṇa": ['cae'],
    "paśumāreṇa": ['mw'],
    "paśunātha": ['mw'],
    "paśupa": ['cae', 'mw'],
    "paśupakṣīya": ['mw'],
    "paśupalvala": ['mw'],
    "paśupati": ['cae', 'mw'],
    "paśupatidhara": ['mw'],
    "paśupatinagara": ['mw'],
    "paśupatinātha": ['mw'],
    "paśupatipurāṇa": ['mw'],
    "paśupatiśarman": ['mw'],
    "paśupatiśāstra": ['mw'],
    "paśupatyaṣkṭaka": ['mw'],
    "paśupatīśvaramāhātmya": ['mw'],
    "paśupratiprasthātṛprayoga": ['mw'],
    "paśuprayoga": ['mw'],
    "paśupraśna": ['mw'],
    "paśupreraṇa": ['mw'],
    "paśuprāyaścitta": ['mw'],
    "paśupuroḍāśa": ['mw'],
    "paśupuroḍāśamimaṃsā": ['mw'],
    "paśupā": ['cae', 'gra', 'mw'],
    "paśupāla": ['cae', 'mw'],
    "paśupālaka": ['mw'],
    "paśupālana": ['mw'],
    "paśupālavat": ['mw'],
    "paśupālikā": ['mw'],
    "paśupālya": ['mw'],
    "paśupāśa": ['cae', 'mw'],
    "paśupāśaka": ['mw'],
    "paśurajju": ['mw'],
    "paśurakṣaṇa": ['mw'],
    "paśurakṣi": ['cae', 'gra', 'mw'],
    "paśurakṣin": ['cae', 'mw'],
    "paśurathagatika": ['bhs'],
    "paśurāja": ['mw'],
    "paśurūpa": ['mw'],
    "paśusakha": ['mw'],
    "paśusambhava": ['mw'],
    "paśusamāmnāya": ['mw'],
    "paśusamāmnāyika": ['mw'],
    "paśusani": ['cae', 'mw'],
    "paśusaṃbhava": ['cae'],
    "paśusaṃkhya": ['mw'],
    "paśusaṃsthā": ['mw'],
    "paśusoma": ['cae', 'mw'],
    "paśustoma": ['mw'],
    "paśusādhana": ['gra', 'mw'],
    "paśusādhanaka": ['mw'],
    "paśusūtra": ['mw'],
    "paśutantra": ['mw'],
    "paśutas": ['mw'],
    "paśutva": ['mw'],
    "paśutā": ['ap90', 'mw'],
    "paśutṛp": ['cae', 'gra', 'mw'],
    "paśuvardhana": ['gra', 'mw'],
    "paśuvat": ['cae', 'mw'],
    "paśuvedi": ['mw'],
    "paśuvid": ['cae', 'mw'],
    "paśuvrata": ['cae', 'mw'],
    "paśuvāṭi": ['mw'],
    "paśuvīrya": ['mw'],
    "paśuvṛddhikara": ['mw'],
    "paśuyajña": ['cae', 'mw'],
    "paśuyāga": ['mw'],
    "paśuyājin": ['cae', 'mw'],
    "paśuyūka": ['mw'],
    "paśuśiras": ['cae', 'mw'],
    "paśuśrapaṇa": ['mw'],
    "paśuśrautasūtra": ['mw'],
    "paśuśīrṣa": ['cae', 'mw'],
    "paśuśṛṅga": ['cae'],
    "paśuḥ": ['ap90'],
    "paśuṣa": ['cae', 'mw'],
    "paśuṣad": ['mw'],
    "paśuṣā": ['cae', 'gra', 'mw'],
    "paśuṣṭha": ['mw'],
    "paśv": ['mw'],
    "paśvaiṣṭi": ['gra', 'mw'],
    "paśvanṛta": ['cae'],
    "paśvavadāna": ['mw'],
    "paśvayana": ['mw'],
    "paśvayantra": ['gra', 'mw'],
    "paśvaṅga": ['cae', 'mw'],
    "paśvaṅgatā": ['mw'],
    "paśvekādaśinī": ['mw'],
    "paśvijyā": ['cae', 'mw'],
    "paśviḍā": ['mw'],
    "paśviṣ": ['cae', 'gra', 'mw'],
    "paśviṣṭakā": ['mw'],
    "paśviṣṭi": ['mw'],
    "paśvācāra": ['mw'],
    "paśya": ['cae', 'gra', 'mw'],
    "paśyaka": ['bhs'],
    "paśyana": ['bhs'],
    "paśyantī": ['mw'],
    "paśyanā": ['mw'],
    "paśyat": ['ap90', 'mw'],
    "paśyata": ['cae', 'mw'],
    "paśyatohara": ['mw'],
    "paśyatoharaḥ": ['ap90'],
    "paśyaṃtī": ['ap90'],
    "paśyin": ['bhs'],
    "paśānupūrvī": ['mw'],
    "paśūdbhavā": ['mw'],
    "paśūkhā": ['cae', 'mw'],
    "paśūkṛ": ['ddsa', 'mw'],
    "paḍ": ['gra', 'mw'],
    "paḍbīśa": ['cae', 'gra', 'mw'],
    "paḍbīśaśaṅku": ['mw'],
    "paḍgṛbhi": ['gra', 'mw'],
    "paḍumaka": ['bhs'],
    "paḍviṃśa": ['cae', 'mw'],
    "paḍviṃśaśaṅku": ['mw'],
    "paḍvīśa": ['cae', 'mw'],
    "paḍvīśaśaṅku": ['mw'],
    "paḷguṇṭhesi": ['cped'],
    "paḷi": ['cped'],
    "paḷibodha": ['cped'],
    "paḷibuddha": ['cped'],
    "paḷibujjhana": ['cped'],
    "paḷibujjhati": ['cped'],
    "paḷibujjhi": ['cped'],
    "paḷibujjhitvā": ['cped'],
    "paḷiguṇṭhesi": ['cped'],
    "paḷiguṇṭheti": ['cped'],
    "paḷiguṇṭhita": ['cped'],
    "paḷikhaṇati": ['cped'],
    "paḷiveṭhana": ['cped'],
    "paḷiveṭhesi": ['cped'],
    "paḷiveṭheti": ['cped'],
    "paḷiveṭhita": ['cped'],
    "paṁsu": ['cped'],
    "paṁsukūla": ['cped'],
    "paṁsukūlacīvara": ['cped'],
    "paṁsukūlika": ['cped'],
    "paṃc": ['ap90'],
    "paṃca": ['ap90'],
    "paṃcadhā": ['ap90'],
    "paṃcaka": ['ap90'],
    "paṃcama": ['ap90'],
    "paṃcamin": ['ap90'],
    "paṃcan": ['ap90'],
    "paṃcanī": ['ap90'],
    "paṃcat": ['ap90'],
    "paṃcataya": ['ap90'],
    "paṃcathuḥ": ['ap90'],
    "paṃcatā": ['ap90'],
    "paṃcavaṭī": ['ap90'],
    "paṃcaśaḥ": ['ap90'],
    "paṃcikā": ['ap90'],
    "paṃcāla": ['ap90'],
    "paṃcālikā": ['ap90'],
    "paṃcālāḥ": ['ap90'],
    "paṃcālī": ['ap90'],
    "paṃcāvaṭaḥ": ['ap90'],
    "paṃcāśa": ['ap90'],
    "paṃcāśat": ['ap90'],
    "paṃcāśikā": ['ap90'],
    "paṃgu": ['ap90'],
    "paṃguka": ['ap90'],
    "paṃgula": ['ap90'],
    "paṃjarakaḥ": ['ap90'],
    "paṃjaraṃ": ['ap90'],
    "paṃjikā": ['ap90'],
    "paṃjiḥ": ['ap90'],
    "paṃkajinī": ['ap90'],
    "paṃkaḥ": ['ap90'],
    "paṃkaṇaḥ": ['ap90'],
    "paṃkejaṃ": ['ap90'],
    "paṃkeruh": ['ap90'],
    "paṃkeśaya": ['ap90'],
    "paṃkila": ['ap90'],
    "paṃkin": ['ap90'],
    "paṃktikā": ['ap90'],
    "paṃktiḥ": ['ap90'],
    "paṃkāraḥ": ['ap90'],
    "paṃpā": ['ap90'],
    "paṃs": ['mw'],
    "paṃsaka": ['bhs', 'mw'],
    "paṃsana": ['bhs', 'mw'],
    "paṃsayati": ['bhs'],
    "paṃthaka": ['ap90'],
    "paṃś": ['mw'],
    "paṃḍ": ['ap90'],
    "paṃḍaḥ": ['ap90'],
    "paṃḍita": ['ap90'],
    "paṃḍitaka": ['ap90'],
    "paṃḍitiman": ['ap90'],
    "paṃḍā": ['ap90'],
    "paṃḍāvat": ['ap90'],
    "paṅgu": ['cae', 'cped', 'ddsa', 'mw'],
    "paṅgubhāva": ['mw'],
    "paṅgugraha": ['mw'],
    "paṅguka": ['mw'],
    "paṅgula": ['cped', 'mw'],
    "paṅgutva": ['mw'],
    "paṅgutā": ['mw'],
    "paṅgutāhāriṇī": ['mw'],
    "paṅguvakrakarmaprakāśa": ['mw'],
    "paṅguvāsara": ['mw'],
    "paṅgūyita": ['mw'],
    "paṅka": ['cae', 'cped', 'ddsa', 'mw'],
    "paṅkabhāj": ['mw'],
    "paṅkabhāraka": ['mw'],
    "paṅkabhāva": ['mw'],
    "paṅkacchid": ['cae', 'mw'],
    "paṅkadanta": ['mw'],
    "paṅkadigdha": ['mw'],
    "paṅkadigdhaśarīra": ['mw'],
    "paṅkadigdhāṅga": ['mw'],
    "paṅkagati": ['mw'],
    "paṅkagaḍaka": ['mw'],
    "paṅkagaṇḍī": ['mw'],
    "paṅkagrāha": ['mw'],
    "paṅkaja": ['cae', 'cped', 'ddsa', 'mw'],
    "paṅkajajanman": ['cae', 'mw'],
    "paṅkajalāvam": ['mw'],
    "paṅkajamālin": ['mw'],
    "paṅkajanayanā": ['mw'],
    "paṅkajanetra": ['mw'],
    "paṅkajanman": ['mw'],
    "paṅkajanābha": ['mw'],
    "paṅkajapattranetra": ['mw'],
    "paṅkajavat": ['mw'],
    "paṅkajin": ['ddsa', 'mw'],
    "paṅkajinī": ['mw'],
    "paṅkajit": ['mw'],
    "paṅkajākṣī": ['mw'],
    "paṅkajāsanastha": ['mw'],
    "paṅkajāta": ['mw'],
    "paṅkajāvalī": ['mw'],
    "paṅkajāṅghri": ['mw'],
    "paṅkakarvaṭa": ['mw'],
    "paṅkakrīḍa": ['mw'],
    "paṅkakrīḍanaka": ['mw'],
    "paṅkakīra": ['mw'],
    "paṅkalagna": ['mw'],
    "paṅkamagna": ['mw'],
    "paṅkamajjana": ['mw'],
    "paṅkamaya": ['mw'],
    "paṅkamaṇḍuka": ['mw'],
    "paṅkaprabhā": ['mw'],
    "paṅkaprakṣālananyāya": ['mw'],
    "paṅkapūra": ['ddsa'],
    "paṅkaruh": ['mw'],
    "paṅkaruha": ['mw'],
    "paṅkaruhiṇī": ['ddsa', 'mw'],
    "paṅkatā": ['ddsa', 'mw'],
    "paṅkavant": ['cae'],
    "paṅkavat": ['mw'],
    "paṅkavāri": ['mw'],
    "paṅkavāsa": ['mw'],
    "paṅkaya": ['ddsa', 'mw'],
    "paṅkaśukti": ['mw'],
    "paṅkaśūraṇa": ['mw'],
    "paṅkaṇa": ['mw'],
    "paṅke": ['mw'],
    "paṅkeja": ['mw'],
    "paṅkeruh": ['cae', 'ddsa', 'mw'],
    "paṅkeruha": ['cae', 'cped', 'mw'],
    "paṅkeruhavasati": ['mw'],
    "paṅkeruhiṇī": ['mw'],
    "paṅkeruhākṣī": ['mw'],
    "paṅkeśaya": ['mw'],
    "paṅkila": ['cae', 'ddsa', 'mw'],
    "paṅkin": ['cae', 'mw'],
    "paṅkti": ['cae', 'ddsa', 'gra', 'mw'],
    "paṅktibīja": ['mw'],
    "paṅkticara": ['mw'],
    "paṅktidoṣa": ['mw'],
    "paṅktidūṣa": ['mw'],
    "paṅktidūṣaka": ['mw'],
    "paṅktidūṣaṇa": ['mw'],
    "paṅktigrīva": ['mw'],
    "paṅktikanda": ['mw'],
    "paṅktikaṇṭaka": ['mw'],
    "paṅktikaṭa": ['mw'],
    "paṅktikrama": ['cae', 'mw'],
    "paṅktikā": ['mw'],
    "paṅktimālā": ['mw'],
    "paṅktipāvana": ['cae', 'mw'],
    "paṅktipāvanapāvana": ['mw'],
    "paṅktiratha": ['mw'],
    "paṅktirādhas": ['gra', 'mw'],
    "paṅktivihaṃgamanāmabhṛt": ['mw'],
    "paṅktiśas": ['ddsa', 'mw'],
    "paṅktyuttarā": ['mw'],
    "paṅktī": ['ddsa', 'mw'],
    "paṅktīhara": ['mw'],
    "paṅktīkṛta": ['mw'],
    "paṅkākta": ['mw'],
    "paṅkāra": ['mw'],
    "paṅkāvalī": ['mw'],
    "paṇ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "paṇa": ['cae', 'ddsa', 'mw'],
    "paṇabandha": ['cae', 'mw'],
    "paṇabandhana": ['mw'],
    "paṇadhā": ['mw'],
    "paṇagranthi": ['mw'],
    "paṇakriyā": ['mw'],
    "paṇakrīta": ['mw'],
    "paṇakāla": ['mw'],
    "paṇamati": ['cped'],
    "paṇami": ['cped'],
    "paṇamita": ['cped'],
    "paṇamitvā": ['cped'],
    "paṇana": ['bhs', 'cae', 'mw'],
    "paṇanaṃ": ['ap90'],
    "paṇanīya": ['mw'],
    "paṇaphara": ['mw'],
    "paṇasa": ['mw'],
    "paṇasaḥ": ['ap90'],
    "paṇastrī": ['cae', 'ddsa', 'mw'],
    "paṇasundarī": ['mw'],
    "paṇata": ['cped'],
    "paṇatva": ['mw'],
    "paṇatā": ['ap90', 'mw'],
    "paṇava": ['cae', 'ddsa', 'mw'],
    "paṇavaḥ": ['ap90'],
    "paṇavin": ['ap90', 'mw'],
    "paṇayati": ['bhs'],
    "paṇayitṛ": ['cae', 'ddsa', 'mw'],
    "paṇaḥ": ['ap90'],
    "paṇesi": ['cped'],
    "paṇeti": ['cped'],
    "paṇetvā": ['cped'],
    "paṇhi": ['cped'],
    "paṇi": ['cae', 'ddsa', 'gra', 'mw'],
    "paṇidahati": ['cped'],
    "paṇidahi": ['cped'],
    "paṇidahita": ['cped'],
    "paṇidahitvā": ['cped'],
    "paṇidhi": ['bhs', 'cped'],
    "paṇidhāna": ['cped'],
    "paṇidhāya": ['cped'],
    "paṇihita": ['cped'],
    "paṇika": ['ap90', 'mw'],
    "paṇin": ['mw'],
    "paṇipāta": ['cped'],
    "paṇita": ['ap90', 'cae', 'ddsa', 'mw'],
    "paṇitaka": ['bhs'],
    "paṇitavya": ['mw'],
    "paṇitṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "paṇiya": ['cped'],
    "paṇiḥ": ['ap90'],
    "paṇya": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "paṇyabhūmi": ['mw'],
    "paṇyabhūta": ['cae', 'mw'],
    "paṇyadāsī": ['mw'],
    "paṇyahoma": ['mw'],
    "paṇyajana": ['cae', 'mw'],
    "paṇyakambala": ['mw'],
    "paṇyamūlya": ['mw'],
    "paṇyapariṇītā": ['mw'],
    "paṇyapati": ['mw'],
    "paṇyapatitva": ['mw'],
    "paṇyaphalatva": ['mw'],
    "paṇyasiddhi": ['mw'],
    "paṇyastrī": ['cae', 'mw'],
    "paṇyatā": ['mw'],
    "paṇyavarcas": ['mw'],
    "paṇyavat": ['mw'],
    "paṇyavikraya": ['mw'],
    "paṇyavikrayaśālā": ['mw'],
    "paṇyavikrayin": ['mw'],
    "paṇyavilāsinī": ['mw'],
    "paṇyavīthikā": ['mw'],
    "paṇyavīthī": ['mw'],
    "paṇyayoṣit": ['cae', 'mw'],
    "paṇyaśālā": ['mw'],
    "paṇyaṃdha": ['mw'],
    "paṇyā": ['mw'],
    "paṇyājira": ['mw'],
    "paṇyājīva": ['mw'],
    "paṇyāndhā": ['mw'],
    "paṇyārha": ['mw'],
    "paṇyāṅganā": ['cae', 'mw'],
    "paṇāma": ['cped'],
    "paṇāmenta": ['cped'],
    "paṇāmesi": ['cped'],
    "paṇāmeti": ['cped'],
    "paṇāmetvā": ['cped'],
    "paṇāmita": ['cped'],
    "paṇārdha": ['mw'],
    "paṇārha": ['mw'],
    "paṇārpaṇa": ['mw'],
    "paṇāsthi": ['mw'],
    "paṇāsthika": ['mw'],
    "paṇāy": ['cae'],
    "paṇāya": ['ddsa', 'mw'],
    "paṇāyita": ['ap90', 'mw'],
    "paṇāyitṛ": ['cae', 'mw'],
    "paṇāyya": ['cae', 'mw'],
    "paṇāyā": ['ap90', 'mw'],
    "paṇāṅganā": ['mw'],
    "paṇīkṛ": ['cae', 'mw'],
    "paṇīta": ['cped'],
    "paṇītara": ['cped'],
    "paṇḍ": ['mw'],
    "paṇḍa": ['cae', 'ddsa', 'mw'],
    "paṇḍaga": ['cae', 'mw'],
    "paṇḍaka": ['cae', 'cped', 'mw'],
    "paṇḍakatva": ['mw'],
    "paṇḍara": ['bhs', 'cped'],
    "paṇḍaravāsinī": ['bhs'],
    "paṇḍicca": ['cped'],
    "paṇḍita": ['cae', 'cped', 'ddsa', 'mw'],
    "paṇḍitagarva": ['cae'],
    "paṇḍitajātīya": ['mw'],
    "paṇḍitaka": ['bhs', 'cped', 'mw'],
    "paṇḍitakarabhiṇḍipāla": ['mw'],
    "paṇḍitammanya": ['mw'],
    "paṇḍitammanyamāna": ['mw'],
    "paṇḍitamānika": ['cae', 'mw'],
    "paṇḍitamānin": ['cae', 'mw'],
    "paṇḍitaparitoṣa": ['mw'],
    "paṇḍitapraśnottara": ['mw'],
    "paṇḍitapīḍāviśārada": ['mw'],
    "paṇḍitarāja": ['mw'],
    "paṇḍitarājakṛti": ['mw'],
    "paṇḍitarājaśataka": ['mw'],
    "paṇḍitasabhā": ['mw'],
    "paṇḍitasarvasva": ['mw'],
    "paṇḍitasvāmin": ['mw'],
    "paṇḍitasūri": ['mw'],
    "paṇḍitatva": ['mw'],
    "paṇḍitatā": ['mw'],
    "paṇḍitavaidya": ['mw'],
    "paṇḍitavādin": ['mw'],
    "paṇḍitaśaśin": ['mw'],
    "paṇḍitaśiromaṇi": ['mw'],
    "paṇḍitaśrīvara": ['mw'],
    "paṇḍitaṃmanya": ['cae'],
    "paṇḍitaṃmanyamāna": ['cae'],
    "paṇḍitiman": ['mw'],
    "paṇḍitāhlādinī": ['mw'],
    "paṇḍitāya": ['mw'],
    "paṇḍra": ['cae', 'mw'],
    "paṇḍraka": ['cae', 'mw'],
    "paṇḍu": ['cped', 'mw'],
    "paṇḍukambala": ['cped'],
    "paṇḍulaka": ['bhs'],
    "paṇḍupalāsa": ['cped'],
    "paṇḍuroga": ['cped'],
    "paṇḍurogī": ['cped'],
    "paṇḍā": ['mw'],
    "paṇḍālu": ['mw'],
    "paṇḍāpūrva": ['mw'],
    "paṇḍāvat": ['mw'],
    "paṇṇa": ['cped'],
    "paṇṇacchatta": ['cped'],
    "paṇṇaka": ['cped'],
    "paṇṇakuṭi": ['cped'],
    "paṇṇarasa": ['cped'],
    "paṇṇasanthara": ['cped'],
    "paṇṇasālā": ['cped'],
    "paṇṇatti": ['cped'],
    "paṇṇika": ['cped'],
    "paṇṇākāra": ['cped'],
    "paṇṇāsā": ['cped'],
    "paṣ": ['mw'],
    "paṣṭhauhī": ['mw'],
    "paṣṭhavah": ['mw'],
    "paṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "paṭa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "paṭabhedaka": ['bhs'],
    "paṭabhedana": ['mw'],
    "paṭabhākṣa": ['ddsa', 'mw'],
    "paṭacaura": ['mw'],
    "paṭaccara": ['cae', 'ddsa', 'mw'],
    "paṭaccaraḥ": ['ap90'],
    "paṭagata": ['cae', 'mw'],
    "paṭaggi": ['cped'],
    "paṭaha": ['cae', 'cped', 'ddsa', 'mw'],
    "paṭahabhramaṇa": ['mw'],
    "paṭahadhvani": ['mw'],
    "paṭahaghoṣaka": ['cae', 'mw'],
    "paṭahaghoṣaṇā": ['cae', 'mw'],
    "paṭahaprodghoṣaṇa": ['mw'],
    "paṭahatā": ['mw'],
    "paṭahaśabda": ['mw'],
    "paṭahaḥ": ['ap90'],
    "paṭahikā": ['bhs'],
    "paṭahānantara": ['mw'],
    "paṭahīvādaka": ['mw'],
    "paṭaka": ['bhs', 'mw'],
    "paṭakaḥ": ['ap90'],
    "paṭakuṭī": ['mw'],
    "paṭakāra": ['mw'],
    "paṭala": ['cae', 'cped', 'ddsa', 'mw'],
    "paṭalaka": ['mw'],
    "paṭalaprānta": ['mw'],
    "paṭalaṃ": ['ap90'],
    "paṭalikā": ['cped', 'mw'],
    "paṭalānta": ['mw'],
    "paṭalāṃśuka": ['mw'],
    "paṭamaya": ['ap90', 'mw'],
    "paṭamaṇḍapa": ['mw'],
    "paṭapaṃsin": ['bhs'],
    "paṭapaṭā": ['ap90', 'mw'],
    "paṭapaṭāya": ['mw'],
    "paṭara": ['cae', 'mw'],
    "paṭaraka": ['mw'],
    "paṭarī": ['mw'],
    "paṭat": ['mw'],
    "paṭatkakantha": ['mw'],
    "paṭatkaḥ": ['ap90'],
    "paṭatta": ['cped'],
    "paṭauka": ['mw'],
    "paṭaukas": ['mw'],
    "paṭaukaśrīdarpaṇa": ['mw'],
    "paṭaura": ['cae', 'mw'],
    "paṭavardhana": ['mw'],
    "paṭaveśman": ['cae', 'mw'],
    "paṭavādya": ['mw'],
    "paṭavāpa": ['mw'],
    "paṭavāsa": ['cae', 'ddsa', 'mw'],
    "paṭavāsaka": ['mw'],
    "paṭavāsatā": ['mw'],
    "paṭavāsinī": ['mw'],
    "paṭaśātaka": ['mw'],
    "paṭaḥ": ['ap90'],
    "paṭaṅga": ['cped'],
    "paṭh": ['ap90', 'cae', 'ddsa', 'mw'],
    "paṭha": ['mw'],
    "paṭhahaṃsikā": ['mw'],
    "paṭhaka": ['cae', 'mw'],
    "paṭhakaḥ": ['ap90'],
    "paṭhama": ['cped'],
    "paṭhamataraṁ": ['cped'],
    "paṭhamañjarī": ['mw'],
    "paṭhamaṁ": ['cped'],
    "paṭhana": ['cae', 'cped', 'ddsa', 'mw'],
    "paṭhanaṃ": ['ap90'],
    "paṭhanādhinātha": ['mw'],
    "paṭhanīya": ['cae', 'mw'],
    "paṭharvan": ['gra', 'mw'],
    "paṭhasamañjarī": ['mw'],
    "paṭhati": ['cped'],
    "paṭhavī": ['cped'],
    "paṭhavīcalana": ['cped'],
    "paṭhavīcāla": ['cped'],
    "paṭhavīdhātu": ['cped'],
    "paṭhavīkampana": ['cped'],
    "paṭhavīkasiṇa": ['cped'],
    "paṭhavīsama": ['cped'],
    "paṭhavīvojā": ['cped'],
    "paṭhi": ['cped', 'mw'],
    "paṭhita": ['ap90', 'bhs', 'cped', 'mw'],
    "paṭhitasiddha": ['cae', 'ddsa', 'mw'],
    "paṭhitasiddhasārasvatastotra": ['mw'],
    "paṭhitatva": ['mw'],
    "paṭhitavya": ['cae', 'mw'],
    "paṭhitavyatva": ['mw'],
    "paṭhiti": ['mw'],
    "paṭhitvā": ['cped'],
    "paṭhitāṅga": ['mw'],
    "paṭhitṛ": ['mw'],
    "paṭhiḥ": ['ap90'],
    "paṭi": ['cae', 'cped', 'ddsa', 'mw'],
    "paṭibaddha": ['cped'],
    "paṭibaddhacitta": ['cped'],
    "paṭibala": ['cped'],
    "paṭibhaya": ['cped'],
    "paṭibhāga": ['cped'],
    "paṭibhāsati": ['cped'],
    "paṭibhāsi": ['cped'],
    "paṭibhāti": ['cped'],
    "paṭibhāṇa": ['cped'],
    "paṭibhāṇavant": ['cped'],
    "paṭibimba": ['cped'],
    "paṭibimbita": ['cped'],
    "paṭibuddha": ['cped'],
    "paṭibujjhati": ['cped'],
    "paṭibujjhi": ['cped'],
    "paṭibujjhitvā": ['cped'],
    "paṭibāhaka": ['cped'],
    "paṭibāhanta": ['cped'],
    "paṭibāhati": ['cped'],
    "paṭibāhi": ['cped'],
    "paṭibāhita": ['cped'],
    "paṭibāhitvā": ['cped'],
    "paṭibāhiya": ['cped'],
    "paṭicarati": ['cped'],
    "paṭicari": ['cped'],
    "paṭicca": ['cped'],
    "paṭiccasamuppanna": ['cped'],
    "paṭiccasamuppāda": ['cped'],
    "paṭicchanna": ['cped'],
    "paṭicchati": ['cped'],
    "paṭicchi": ['cped'],
    "paṭicchita": ['cped'],
    "paṭicchitvā": ['cped'],
    "paṭicchiya": ['cped'],
    "paṭicchādaka": ['cped'],
    "paṭicchādana": ['cped'],
    "paṭicchādaniya": ['cped'],
    "paṭicchādenta": ['cped'],
    "paṭicchādesi": ['cped'],
    "paṭicchādeti": ['cped'],
    "paṭicchādetvā": ['cped'],
    "paṭicchādita": ['cped'],
    "paṭicchādiya": ['cped'],
    "paṭicchādī": ['cped'],
    "paṭicodesi": ['cped'],
    "paṭicodeti": ['cped'],
    "paṭicodetvā": ['cped'],
    "paṭicodita": ['cped'],
    "paṭidadi": ['cped'],
    "paṭidadāti": ['cped'],
    "paṭidassesi": ['cped'],
    "paṭidasseti": ['cped'],
    "paṭidassetvā": ['cped'],
    "paṭidassita": ['cped'],
    "paṭidatvā": ['cped'],
    "paṭidaṇḍa": ['cped'],
    "paṭidesesi": ['cped'],
    "paṭideseti": ['cped'],
    "paṭidesetvā": ['cped'],
    "paṭidesita": ['cped'],
    "paṭidhāvati": ['cped'],
    "paṭidhāvi": ['cped'],
    "paṭidhāvitvā": ['cped'],
    "paṭidinna": ['cped'],
    "paṭidissati": ['cped'],
    "paṭidissi": ['cped'],
    "paṭidāna": ['cped'],
    "paṭigacca": ['cped'],
    "paṭiggaha": ['cped'],
    "paṭiggahaṇa": ['cped'],
    "paṭiggahetu": ['cped'],
    "paṭiggahetvā": ['cped'],
    "paṭiggayha": ['cped'],
    "paṭiggaṇhana": ['cped'],
    "paṭiggaṇhanaka": ['cped'],
    "paṭiggaṇhanta": ['cped'],
    "paṭiggaṇhi": ['cped'],
    "paṭiggaṇhita": ['cped'],
    "paṭiggaṇhiya": ['cped'],
    "paṭiggaṇhāti": ['cped'],
    "paṭiggāhaka": ['cped'],
    "paṭigha": ['cped'],
    "paṭighosa": ['cped'],
    "paṭighāta": ['cped'],
    "paṭigiddha": ['cped'],
    "paṭigijjhati": ['cped'],
    "paṭigijjhi": ['cped'],
    "paṭigūhati": ['cped'],
    "paṭigūhi": ['cped'],
    "paṭigūhita": ['cped'],
    "paṭigūhitvā": ['cped'],
    "paṭihanana": ['cped'],
    "paṭihanati": ['cped'],
    "paṭihani": ['cped'],
    "paṭihantvā": ['cped'],
    "paṭiharitvā": ['cped'],
    "paṭihata": ['cped'],
    "paṭihaññati": ['cped'],
    "paṭihaññi": ['cped'],
    "paṭihaññitvā": ['cped'],
    "paṭijaggaka": ['cped'],
    "paṭijaggana": ['cped'],
    "paṭijagganaka": ['cped'],
    "paṭijaggati": ['cped'],
    "paṭijaggi": ['cped'],
    "paṭijaggita": ['cped'],
    "paṭijaggitvā": ['cped'],
    "paṭijaggiya": ['cped'],
    "paṭijāgareti": ['bhs'],
    "paṭijānanta": ['cped'],
    "paṭijāni": ['cped'],
    "paṭijānitvā": ['cped'],
    "paṭijānāti": ['cped'],
    "paṭikamanta": ['cped'],
    "paṭikamma": ['cped'],
    "paṭikara": ['cped'],
    "paṭikari": ['cped'],
    "paṭikaronta": ['cped'],
    "paṭikaroti": ['cped'],
    "paṭikassati": ['cped'],
    "paṭikassi": ['cped'],
    "paṭikassita": ['cped'],
    "paṭikata": ['cped'],
    "paṭikaṅkhati": ['cped'],
    "paṭikaṅkhi": ['cped'],
    "paṭikaṅkhita": ['cped'],
    "paṭikaṇṭaka": ['cped'],
    "paṭikkama": ['cped'],
    "paṭikkamana": ['cped'],
    "paṭikkamanasālā": ['cped'],
    "paṭikkamanta": ['cped'],
    "paṭikkamati": ['cped'],
    "paṭikkami": ['cped'],
    "paṭikkamitvā": ['cped'],
    "paṭikkamma": ['cped'],
    "paṭikkanta": ['cped'],
    "paṭikkhepa": ['cped'],
    "paṭikkhipati": ['cped'],
    "paṭikkhipi": ['cped'],
    "paṭikkhipitvā": ['cped'],
    "paṭikkhippa": ['cped'],
    "paṭikkhitta": ['cped'],
    "paṭikkhitvā": ['cped'],
    "paṭikkosanā": ['cped'],
    "paṭikkosati": ['cped'],
    "paṭikkosi": ['cped'],
    "paṭikkositvā": ['cped'],
    "paṭikkuṭṭha": ['cped'],
    "paṭikkūla": ['cped'],
    "paṭikkūlasaññā": ['cped'],
    "paṭikkūlatā": ['cped'],
    "paṭikujetvā": ['cped'],
    "paṭikujitvā": ['cped'],
    "paṭikujjana": ['cped'],
    "paṭikujjesi": ['cped'],
    "paṭikujjeti": ['cped'],
    "paṭikujjetvā": ['cped'],
    "paṭikujjhati": ['cped'],
    "paṭikujjita": ['cped'],
    "paṭikujjitvā": ['cped'],
    "paṭikujjiya": ['cped'],
    "paṭikuṭṭha": ['cped'],
    "paṭikā": ['ap90', 'cae', 'mw'],
    "paṭikāra": ['cped'],
    "paṭikāvetravānavikalpa": ['mw'],
    "paṭilabhanta": ['cped'],
    "paṭilabhati": ['cped'],
    "paṭilabhi": ['cped'],
    "paṭilabhitvā": ['cped'],
    "paṭiladdha": ['cped'],
    "paṭiladdhā": ['cped'],
    "paṭiloma": ['cped'],
    "paṭilomapakka": ['cped'],
    "paṭilābha": ['cped'],
    "paṭilīna": ['cped'],
    "paṭilīyana": ['cped'],
    "paṭilīyati": ['cped'],
    "paṭilīyi": ['cped'],
    "paṭilīyitvā": ['cped'],
    "paṭimagga": ['cped'],
    "paṭimalla": ['cped'],
    "paṭiman": ['ap90', 'mw'],
    "paṭimaṇḍita": ['cped'],
    "paṭimoka": ['bhs'],
    "paṭimukka": ['cped'],
    "paṭimuñcati": ['cped'],
    "paṭimuñci": ['cped'],
    "paṭimuñcitvā": ['cped'],
    "paṭimā": ['cped'],
    "paṭimānesi": ['cped'],
    "paṭimāneti": ['cped'],
    "paṭimānetvā": ['cped'],
    "paṭimānita": ['cped'],
    "paṭinandanā": ['cped'],
    "paṭinandati": ['cped'],
    "paṭinandi": ['cped'],
    "paṭinandita": ['cped'],
    "paṭinanditvā": ['cped'],
    "paṭinesi": ['cped'],
    "paṭineti": ['cped'],
    "paṭinetvā": ['cped'],
    "paṭinissagga": ['cped'],
    "paṭinissajjati": ['cped'],
    "paṭinissajji": ['cped'],
    "paṭinissajjitvā": ['cped'],
    "paṭinissajjiya": ['cped'],
    "paṭinissaṭṭha": ['cped'],
    "paṭinivatta": ['cped'],
    "paṭinivattati": ['cped'],
    "paṭinivatti": ['cped'],
    "paṭinivattitvā": ['cped'],
    "paṭināsikā": ['cped'],
    "paṭinīta": ['cped'],
    "paṭipadā": ['cped'],
    "paṭipaharati": ['cped'],
    "paṭipahari": ['cped'],
    "paṭipaharitvā": ['cped'],
    "paṭipahaṭa": ['cped'],
    "paṭipahita": ['cped'],
    "paṭipahiṇi": ['cped'],
    "paṭipahiṇitvā": ['cped'],
    "paṭipahiṇāti": ['cped'],
    "paṭipajjamāna": ['cped'],
    "paṭipajjana": ['cped'],
    "paṭipajjati": ['cped'],
    "paṭipajji": ['cped'],
    "paṭipajjitvā": ['cped'],
    "paṭipakkha": ['cped'],
    "paṭipakkhika": ['cped'],
    "paṭipanna": ['cped'],
    "paṭipatha": ['cped'],
    "paṭipatti": ['cped'],
    "paṭipaṇṇa": ['cped'],
    "paṭipeseti": ['cped'],
    "paṭippassaddha": ['cped'],
    "paṭippassaddhi": ['cped'],
    "paṭippassambhanā": ['cped'],
    "paṭippassambhati": ['cped'],
    "paṭippassambhi": ['cped'],
    "paṭipucchati": ['cped'],
    "paṭipucchi": ['cped'],
    "paṭipucchita": ['cped'],
    "paṭipucchā": ['cped'],
    "paṭipuggala": ['cped'],
    "paṭipādaka": ['cped'],
    "paṭipādesi": ['cped'],
    "paṭipādeti": ['cped'],
    "paṭipādetvā": ['cped'],
    "paṭipādita": ['cped'],
    "paṭipākaroti": ['bhs'],
    "paṭipāṭi": ['bhs', 'cped'],
    "paṭipāṭiyā": ['cped'],
    "paṭipīḷana": ['cped'],
    "paṭipīḷesi": ['cped'],
    "paṭipīḷeti": ['cped'],
    "paṭipīḷetvā": ['cped'],
    "paṭipīḷita": ['cped'],
    "paṭipūjanā": ['cped'],
    "paṭipūjesi": ['cped'],
    "paṭipūjeti": ['cped'],
    "paṭipūjetvā": ['cped'],
    "paṭipūjita": ['cped'],
    "paṭirāja": ['cped'],
    "paṭirūpa": ['cped'],
    "paṭirūpaka": ['cped'],
    "paṭirūpatā": ['cped'],
    "paṭisa": ['mw'],
    "paṭisallāna": ['cped'],
    "paṭisallānasāruppa": ['cped'],
    "paṭisallīna": ['cped'],
    "paṭisallīyati": ['cped'],
    "paṭisallīyi": ['cped'],
    "paṭisallīyitvā": ['cped'],
    "paṭisambhidā": ['cped'],
    "paṭisammodati": ['cped'],
    "paṭisammodi": ['cped'],
    "paṭisammodita": ['cped'],
    "paṭisammoditvā": ['cped'],
    "paṭisandahati": ['cped'],
    "paṭisandahi": ['cped'],
    "paṭisandahita": ['cped'],
    "paṭisandhi": ['cped'],
    "paṭisandhita": ['cped'],
    "paṭisandhāna": ['cped'],
    "paṭisandhātar": ['cped'],
    "paṭisanthāra": ['cped'],
    "paṭisaraṇa": ['cped'],
    "paṭisañcikkhati": ['cped'],
    "paṭisañcikkhi": ['cped'],
    "paṭisañcikkhita": ['cped'],
    "paṭisaṁharati": ['cped'],
    "paṭisaṁharaṇa": ['cped'],
    "paṭisaṁhari": ['cped'],
    "paṭisaṁharita": ['cped'],
    "paṭisaṁharitvā": ['cped'],
    "paṭisaṁhaṭa": ['cped'],
    "paṭisaṁhāra": ['cped'],
    "paṭisaṁkharaṇa": ['cped'],
    "paṭisaṁkhāra": ['cped'],
    "paṭisaṁvedesi": ['cped'],
    "paṭisaṁvedeti": ['cped'],
    "paṭisaṁvedetvā": ['cped'],
    "paṭisaṁvedita": ['cped'],
    "paṭisaṁvedī": ['cped'],
    "paṭisaṁvidita": ['cped'],
    "paṭisaṁyutta": ['cped'],
    "paṭisaṃdheti": ['bhs'],
    "paṭisaṅkhari": ['cped'],
    "paṭisaṅkharitvā": ['cped'],
    "paṭisaṅkharoti": ['cped'],
    "paṭisaṅkhata": ['cped'],
    "paṭisaṅkhā": ['cped'],
    "paṭisaṅkhāna": ['cped'],
    "paṭisaṅkhāra": ['cped'],
    "paṭisaṅkhāya": ['cped'],
    "paṭisedha": ['cped'],
    "paṭisedhaka": ['cped'],
    "paṭisedhana": ['cped'],
    "paṭisedhesi": ['cped'],
    "paṭisedheti": ['cped'],
    "paṭisedhetvā": ['cped'],
    "paṭisedhita": ['cped'],
    "paṭisedhiya": ['cped'],
    "paṭisevana": ['cped'],
    "paṭisevanta": ['cped'],
    "paṭisevati": ['cped'],
    "paṭisevi": ['cped'],
    "paṭisevita": ['cped'],
    "paṭisevitvā": ['cped'],
    "paṭiseviya": ['cped'],
    "paṭisotaṁ": ['cped'],
    "paṭissava": ['cped'],
    "paṭissuta": ['cped'],
    "paṭissuṇi": ['cped'],
    "paṭissuṇitvā": ['cped'],
    "paṭissuṇāti": ['cped'],
    "paṭisubhati": ['bhs'],
    "paṭisāmesi": ['cped'],
    "paṭisāmeti": ['cped'],
    "paṭisāmetvā": ['cped'],
    "paṭisāmita": ['cped'],
    "paṭisāsana": ['cped'],
    "paṭivacana": ['cped'],
    "paṭivadati": ['cped'],
    "paṭivadi": ['cped'],
    "paṭivaditvā": ['cped'],
    "paṭivasati": ['cped'],
    "paṭivasi": ['cped'],
    "paṭivasitvā": ['cped'],
    "paṭivattana": ['cped'],
    "paṭivattar": ['cped'],
    "paṭivattesi": ['cped'],
    "paṭivatteti": ['cped'],
    "paṭivattetvā": ['cped'],
    "paṭivattita": ['cped'],
    "paṭivattiya": ['cped'],
    "paṭivatvā": ['cped'],
    "paṭivedesi": ['cped'],
    "paṭivedeti": ['cped'],
    "paṭivedetvā": ['cped'],
    "paṭivedha": ['cped'],
    "paṭivedita": ['cped'],
    "paṭivibhajati": ['cped'],
    "paṭivibhaji": ['cped'],
    "paṭivibhajitvā": ['cped'],
    "paṭivibhatta": ['cped'],
    "paṭividdha": ['cped'],
    "paṭividita": ['cped'],
    "paṭivijjha": ['cped'],
    "paṭivijjhati": ['cped'],
    "paṭivijjhi": ['cped'],
    "paṭivijjhitvā": ['cped'],
    "paṭivijāni": ['cped'],
    "paṭivijānāti": ['cped'],
    "paṭivinodana": ['cped'],
    "paṭivinodesi": ['cped'],
    "paṭivinodeti": ['cped'],
    "paṭivinodetvā": ['cped'],
    "paṭivinodita": ['cped'],
    "paṭiviramanta": ['cped'],
    "paṭiviramati": ['cped'],
    "paṭivirami": ['cped'],
    "paṭiviramitvā": ['cped'],
    "paṭivirata": ['cped'],
    "paṭivirodha": ['cped'],
    "paṭiviruddha": ['cped'],
    "paṭivirujjhati": ['cped'],
    "paṭivirujjhi": ['cped'],
    "paṭivirujjhitvā": ['cped'],
    "paṭivirūhati": ['cped'],
    "paṭivirūhi": ['cped'],
    "paṭivirūhitvā": ['cped'],
    "paṭivirūḷha": ['cped'],
    "paṭivissaka": ['cped'],
    "paṭiviṁsa": ['cped'],
    "paṭivutta": ['cped'],
    "paṭivuttha": ['cped'],
    "paṭivāda": ['cped'],
    "paṭivātaṁ": ['cped'],
    "paṭiyatta": ['cped'],
    "paṭiyodha": ['cped'],
    "paṭiyādesi": ['cped'],
    "paṭiyādeti": ['cped'],
    "paṭiyādetvā": ['cped'],
    "paṭiyādita": ['cped'],
    "paṭiñña": ['cped'],
    "paṭiññā": ['cped'],
    "paṭiññāta": ['cped'],
    "paṭiḥ": ['ap90'],
    "paṭiṣṭha": ['cae', 'mw'],
    "paṭola": ['cae', 'cped', 'ddsa', 'mw'],
    "paṭolaka": ['mw'],
    "paṭolakaḥ": ['ap90'],
    "paṭolaḥ": ['ap90'],
    "paṭolikā": ['mw'],
    "paṭolī": ['mw'],
    "paṭottarīya": ['cae', 'mw'],
    "paṭoṭaja": ['mw'],
    "paṭu": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "paṭudeśya": ['mw'],
    "paṭudeśīya": ['mw'],
    "paṭughaṇṭā": ['mw'],
    "paṭujātīya": ['mw'],
    "paṭuka": ['mw'],
    "paṭukalpa": ['mw'],
    "paṭukaraṇa": ['mw'],
    "paṭula": ['mw'],
    "paṭumaka": ['bhs'],
    "paṭumat": ['mw'],
    "paṭumati": ['cae', 'mw'],
    "paṭumitra": ['mw'],
    "paṭuparṇikā": ['mw'],
    "paṭuparṇī": ['mw'],
    "paṭupattrikā": ['mw'],
    "paṭurūpa": ['mw'],
    "paṭusa": ['mw'],
    "paṭutara": ['mw'],
    "paṭutaragir": ['mw'],
    "paṭutaram": ['mw'],
    "paṭutaravanadāha": ['mw'],
    "paṭutaraviveka": ['mw'],
    "paṭutta": ['cped'],
    "paṭutva": ['mw'],
    "paṭutā": ['ap90', 'cae', 'cped', 'mw'],
    "paṭutṛṇaka": ['mw'],
    "paṭuśa": ['mw'],
    "paṭvijjhi": ['cped'],
    "paṭāka": ['mw'],
    "paṭākaḥ": ['ap90'],
    "paṭākā": ['bhs', 'mw'],
    "paṭākṣepa": ['mw'],
    "paṭālukā": ['ap90', 'mw'],
    "paṭānta": ['cae', 'ddsa', 'mw'],
    "paṭāntaram": ['mw'],
    "paṭāntare": ['mw'],
    "paṭāñcala": ['cae', 'mw'],
    "paṭī": ['ddsa', 'mw'],
    "paṭīkṣepa": ['cae', 'mw'],
    "paṭīra": ['ap90', 'cae', 'ddsa', 'mw'],
    "paṭīramāruta": ['mw'],
    "paṭīyas": ['ddsa', 'mw'],
    "paṭīyaṃs": ['cae'],
    "paṭūkṛ": ['mw'],
    "paṭṭa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "paṭṭabandha": ['mw'],
    "paṭṭabandhana": ['mw'],
    "paṭṭadevī": ['mw'],
    "paṭṭadola": ['cae', 'mw'],
    "paṭṭaja": ['mw'],
    "paṭṭaka": ['cae', 'cped', 'mw'],
    "paṭṭakarmakara": ['mw'],
    "paṭṭakarman": ['mw'],
    "paṭṭakaḥ": ['ap90'],
    "paṭṭakila": ['mw'],
    "paṭṭalakṣaṇa": ['mw'],
    "paṭṭalā": ['ap90', 'mw'],
    "paṭṭamahiṣī": ['mw'],
    "paṭṭamahādevī": ['mw'],
    "paṭṭana": ['cae', 'cped', 'ddsa', 'mw'],
    "paṭṭanaṃ": ['ap90'],
    "paṭṭanivasana": ['ddsa', 'mw'],
    "paṭṭanī": ['mw'],
    "paṭṭarañjaka": ['mw'],
    "paṭṭarañjana": ['mw'],
    "paṭṭarañjanaka": ['mw'],
    "paṭṭaraṅga": ['mw'],
    "paṭṭarāga": ['mw'],
    "paṭṭarājñī": ['mw'],
    "paṭṭastha": ['mw'],
    "paṭṭasūtra": ['mw'],
    "paṭṭasūtrakāra": ['mw'],
    "paṭṭasūtramaya": ['mw'],
    "paṭṭatalpa": ['mw'],
    "paṭṭava": ['ddsa', 'mw'],
    "paṭṭavastra": ['ddsa', 'mw'],
    "paṭṭavāsas": ['mw'],
    "paṭṭavāsitā": ['mw'],
    "paṭṭaśāka": ['mw'],
    "paṭṭaśālā": ['mw'],
    "paṭṭaśāṭaka": ['mw'],
    "paṭṭaḥ": ['ap90'],
    "paṭṭeraka": ['mw'],
    "paṭṭeśvaramāhātmya": ['mw'],
    "paṭṭhapesi": ['cped'],
    "paṭṭhapeti": ['cped'],
    "paṭṭhapetvā": ['cped'],
    "paṭṭhapita": ['cped'],
    "paṭṭhāna": ['cped'],
    "paṭṭhāya": ['cped'],
    "paṭṭi": ['mw'],
    "paṭṭikā": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "paṭṭikākhya": ['mw'],
    "paṭṭikālodhra": ['mw'],
    "paṭṭikāra": ['mw'],
    "paṭṭikāvetrabāṇavikalpa": ['mw'],
    "paṭṭikāvāpaka": ['mw'],
    "paṭṭikāvāyaka": ['mw'],
    "paṭṭila": ['mw'],
    "paṭṭilodhra": ['mw'],
    "paṭṭilodhraka": ['mw'],
    "paṭṭin": ['mw'],
    "paṭṭiśa": ['cae', 'ddsa', 'mw'],
    "paṭṭiśaḥ": ['ap90'],
    "paṭṭiśin": ['mw'],
    "paṭṭolikā": ['ap90', 'mw'],
    "paṭṭopadhāna": ['mw'],
    "paṭṭopādhyāya": ['ddsa', 'mw'],
    "paṭṭubhaṭṭa": ['mw'],
    "paṭṭābhirāma": ['mw'],
    "paṭṭābhirāmatippaṇī": ['mw'],
    "paṭṭābhirāmaśāstripattra": ['mw'],
    "paṭṭābhirāmīya": ['mw'],
    "paṭṭābhiṣeka": ['mw'],
    "paṭṭāra": ['mw'],
    "paṭṭārhā": ['mw'],
    "paṭṭārohā": ['mw'],
    "paṭṭāvali": ['mw'],
    "paṭṭāya": ['ddsa', 'mw'],
    "paṭṭāṃśuka": ['cae', 'mw'],
    "paṭṭī": ['mw'],
    "paṭṭīśaḥ": ['ap90'],
    "pe": ['bhs'],
    "peb": ['mw'],
    "pecaka": ['ddsa', 'mw'],
    "pecakaḥ": ['ap90'],
    "pecakin": ['ap90', 'mw'],
    "pecca": ['cped'],
    "pecikā": ['mw'],
    "pecila": ['mw'],
    "pecu": ['mw'],
    "pecuka": ['mw'],
    "peculī": ['mw'],
    "pedu": ['cae', 'ddsa', 'gra', 'mw'],
    "peja": ['bhs', 'mw'],
    "pejā": ['mw'],
    "pekhuṇa": ['cped'],
    "peki": ['mw'],
    "pekkhaka": ['cped'],
    "pekkhamāna": ['cped'],
    "pekkhati": ['cped'],
    "pekkhaṇa": ['cped'],
    "pekkhi": ['cped'],
    "pekkhita": ['cped'],
    "pekkhitvā": ['cped'],
    "pel": ['ap90', 'mw'],
    "pela": ['bhs', 'mw'],
    "pelaka": ['cped', 'mw'],
    "pelalaka": ['bhs'],
    "pelava": ['ap90', 'cae', 'ddsa', 'mw'],
    "pelavaka": ['bhs'],
    "pelavakṣauma": ['mw'],
    "pelavapuṣpapattrin": ['mw'],
    "pelaḥ": ['ap90'],
    "peli": ['mw'],
    "pelin": ['mw'],
    "peliyakṣa": ['bhs'],
    "peliśālā": ['mw'],
    "peliḥ": ['ap90'],
    "pelu": ['bhs'],
    "peluvāsa": ['mw'],
    "pelā": ['bhs'],
    "pelāṅka": ['bhs'],
    "pema": ['cped'],
    "pemanīya": ['cped'],
    "pepiśat": ['cae'],
    "pepiśāna": ['cae'],
    "pepīyamāna": ['mw'],
    "peraja": ['mw'],
    "peralasthalamāhātmya": ['mw'],
    "peramabhaṭṭa": ['mw'],
    "peraṇi": ['mw'],
    "peraṇī": ['mw'],
    "peroja": ['mw'],
    "peru": ['cae', 'ddsa', 'gra', 'mw'],
    "perubhaṭṭa": ['mw'],
    "peruka": ['gra', 'mw'],
    "peruḥ": ['ap90'],
    "perā": ['ap90', 'cae', 'mw'],
    "pes": ['ap90', 'mw'],
    "pesaka": ['cped'],
    "pesakāra": ['cped'],
    "pesala": ['cped'],
    "pesana": ['cped'],
    "pesanakāraka": ['cped'],
    "pesanakārikā": ['cped'],
    "pesenta": ['cped'],
    "pesesi": ['cped'],
    "pesetabba": ['cped'],
    "peseti": ['cped'],
    "pesetvā": ['cped'],
    "pesi": ['cped'],
    "pesikā": ['cped'],
    "pesita": ['cped'],
    "pesiya": ['cped'],
    "pesiyamāna": ['cped'],
    "pessa": ['cped'],
    "pessika": ['cped'],
    "pessiya": ['cped'],
    "pesuka": ['cae', 'mw'],
    "pesuñña": ['cped'],
    "pesuṇa": ['cped'],
    "pesuṇakāraka": ['cped'],
    "pesuṇika": ['cped'],
    "pesvara": ['ap90', 'mw'],
    "pesīyati": ['cped'],
    "peta": ['cped'],
    "petakicca": ['cped'],
    "petaloka": ['cped'],
    "petavatthu": ['cped'],
    "petayoni": ['cped'],
    "pettaṇika": ['cped'],
    "petteyya": ['cped'],
    "petteyyatā": ['cped'],
    "pettika": ['cped'],
    "pettivisaya": ['cped'],
    "petua": ['gra'],
    "petva": ['cae', 'ddsa', 'gra', 'mw'],
    "petvaṃ": ['ap90'],
    "pev": ['mw'],
    "peya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "peyuḥ": ['ap90'],
    "peyya": ['bhs', 'cped'],
    "peyyavajja": ['cped'],
    "peyyāla": ['cped'],
    "peyā": ['bhs', 'mw'],
    "peyāla": ['bhs'],
    "peyālam": ['mw'],
    "peyūṣa": ['cae', 'ddsa', 'mw'],
    "peyūṣaḥ": ['ap90'],
    "peñjūṣā": ['mw'],
    "peśa": ['cae', 'ddsa', 'gra', 'mw'],
    "peśala": ['ap90', 'cae', 'ddsa', 'mw'],
    "peśalam": ['mw'],
    "peśalamadhya": ['mw'],
    "peśalatva": ['mw'],
    "peśalākṣa": ['mw'],
    "peśalākṣatā": ['mw'],
    "peśalīkṛ": ['ddsa', 'mw'],
    "peśana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "peśas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "peśaskarī": ['mw'],
    "peśaskārin": ['ddsa', 'mw'],
    "peśaskārī": ['mw'],
    "peśaskṛt": ['mw'],
    "peśasvat": ['mw'],
    "peśaḥ": ['ap90'],
    "peśi": ['mw'],
    "peśikā": ['mw'],
    "peśitṛ": ['cae', 'mw'],
    "peśiḥ": ['ap90'],
    "peśvara": ['mw'],
    "peśyaṇḍa": ['mw'],
    "peśī": ['ddsa', 'mw'],
    "peśīkośa": ['mw'],
    "peśīkṛta": ['mw'],
    "peśītva": ['mw'],
    "peḍhāla": ['mw'],
    "peḍā": ['ap90', 'cae', 'ddsa', 'mw'],
    "peḍḍabhaṭṭa": ['mw'],
    "peḍḍanācārya": ['mw'],
    "peḷā": ['cped'],
    "peṃjūṣaḥ": ['ap90'],
    "peṇ": ['ap90', 'mw'],
    "peṇḍa": ['mw'],
    "peṣ": ['ap90', 'mw'],
    "peṣa": ['cae', 'ddsa', 'mw'],
    "peṣaka": ['ap90', 'mw'],
    "peṣaḥ": ['ap90'],
    "peṣaṇa": ['cae', 'mw'],
    "peṣaṇavat": ['mw'],
    "peṣaṇaṃ": ['ap90'],
    "peṣaṇi": ['mw'],
    "peṣaṇiḥ": ['ap90'],
    "peṣaṇī": ['mw'],
    "peṣaṇīputraka": ['mw'],
    "peṣaṇīya": ['mw'],
    "peṣi": ['mw'],
    "peṣiḥ": ['ap90'],
    "peṣya": ['cae', 'mw'],
    "peṣāka": ['mw'],
    "peṣī": ['gra', 'mw'],
    "peṣīkṛ": ['cae', 'mw'],
    "peṣṭra": ['cae', 'mw'],
    "peṣṭṛ": ['cae', 'mw'],
    "peṭa": ['cae', 'ddsa', 'mw'],
    "peṭaka": ['cae', 'ddsa', 'mw'],
    "peṭakandaka": ['mw'],
    "peṭakaḥ": ['ap90'],
    "peṭaḥ": ['ap90'],
    "peṭikā": ['ap90', 'mw'],
    "peṭāka": ['mw'],
    "peṭālu": ['mw'],
    "peṭṭibhaṭṭa": ['mw'],
    "peṭṭāla": ['ddsa', 'mw'],
    "peṭṭālaka": ['cae'],
    "pha": ['ap90', 'mw'],
    "phaggu": ['cped'],
    "phagguṇa": ['cped'],
    "phagguṇī": ['cped'],
    "phagula": ['mw'],
    "phakk": ['ap90', 'cae', 'ddsa', 'mw'],
    "phakka": ['bhs', 'mw'],
    "phakkaḥ": ['ap90'],
    "phakkikā": ['ap90', 'ddsa', 'mw'],
    "phakkikāprakāśa": ['mw'],
    "phakkikāvyākhyāna": ['mw'],
    "phakāra": ['mw'],
    "phakīracandra": ['mw'],
    "phal": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "phala": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "phalabandhin": ['cae', 'mw'],
    "phalabhakṣa": ['mw'],
    "phalabhakṣatā": ['mw'],
    "phalabhoga": ['mw'],
    "phalabhogin": ['mw'],
    "phalabhogya": ['mw'],
    "phalabhuj": ['mw'],
    "phalabhāga": ['cae', 'mw'],
    "phalabhāgin": ['mw'],
    "phalabhāj": ['mw'],
    "phalabhūmi": ['cae', 'mw'],
    "phalabhūti": ['mw'],
    "phalabhūyastva": ['mw'],
    "phalabhṛt": ['cae', 'mw'],
    "phalacamasa": ['mw'],
    "phalacandrikā": ['mw'],
    "phalacchadana": ['mw'],
    "phalacitta": ['cped'],
    "phalacoraka": ['mw'],
    "phalacāraka": ['mw'],
    "phalada": ['cae', 'mw'],
    "phaladantavat": ['mw'],
    "phaladarbhodaka": ['cae'],
    "phaladharman": ['mw'],
    "phaladharā": ['bhs'],
    "phaladātṛ": ['mw'],
    "phaladāyin": ['mw'],
    "phaladāyī": ['cped'],
    "phaladīpikā": ['mw'],
    "phalaghṛta": ['mw'],
    "phalagraha": ['cae', 'mw'],
    "phalagrahi": ['cae', 'mw'],
    "phalagrahiṣṇu": ['cae', 'mw'],
    "phalagrantha": ['mw'],
    "phalagrāhin": ['mw'],
    "phalaha": ['bhs'],
    "phalahaka": ['cae', 'ddsa', 'mw'],
    "phalahakaḥ": ['ap90'],
    "phalahetu": ['cae', 'mw'],
    "phalahāni": ['mw'],
    "phalahārin": ['mw'],
    "phalahārī": ['mw'],
    "phalahī": ['ap90', 'mw'],
    "phalahīna": ['mw'],
    "phalaka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "phalakakṣa": ['mw'],
    "phalakalpalatā": ['mw'],
    "phalakaparidhāna": ['mw'],
    "phalakapura": ['mw'],
    "phalakapāṇi": ['mw'],
    "phalakasaktha": ['mw'],
    "phalakatva": ['mw'],
    "phalakayantra": ['mw'],
    "phalakaṃ": ['ap90'],
    "phalakaṇṭakā": ['mw'],
    "phalakesara": ['mw'],
    "phalakha": ['bhs'],
    "phalakhaṇḍana": ['mw'],
    "phalakhaṇḍava": ['mw'],
    "phalakhelā": ['mw'],
    "phalakin": ['ap90', 'mw'],
    "phalakinī": ['bhs', 'mw'],
    "phalakośa": ['cae', 'mw'],
    "phalakośaka": ['mw'],
    "phalakriyā": ['mw'],
    "phalakā": ['mw'],
    "phalakākhyayantra": ['mw'],
    "phalakāla": ['mw'],
    "phalakāma": ['mw'],
    "phalakāmanā": ['mw'],
    "phalakāsādana": ['mw'],
    "phalakāvana": ['mw'],
    "phalakāṅkṣin": ['mw'],
    "phalakṛṣṇa": ['mw'],
    "phalakṛṣṇapāka": ['mw'],
    "phalamatsyā": ['mw'],
    "phalamaya": ['mw'],
    "phalamiśra": ['cae'],
    "phalamudgarikā": ['mw'],
    "phalamukhyā": ['mw'],
    "phalamūla": ['mw'],
    "phalamūlamaya": ['mw'],
    "phalamūlavat": ['mw'],
    "phalamūlin": ['mw'],
    "phalana": ['mw'],
    "phalanaṃ": ['ap90'],
    "phalanirvṛtti": ['cae', 'mw'],
    "phalanivṛtti": ['mw'],
    "phalaniṣpatti": ['mw'],
    "phalanta": ['cped'],
    "phalaparivṛtti": ['mw'],
    "phalapariṇati": ['mw'],
    "phalapariṇāma": ['mw'],
    "phalapañcāmla": ['mw'],
    "phalapracayana": ['mw'],
    "phalaprada": ['cae', 'mw'],
    "phalapradāna": ['mw'],
    "phalapradīpa": ['mw'],
    "phalaprajanana": ['mw'],
    "phalaprakarṣa": ['mw'],
    "phalaprasūti": ['mw'],
    "phalapravṛtti": ['mw'],
    "phalaprayukta": ['mw'],
    "phalaprepsu": ['mw'],
    "phalapriyā": ['mw'],
    "phalaprāpti": ['cae', 'mw'],
    "phalapuccha": ['mw'],
    "phalapura": ['mw'],
    "phalapuṣpa": ['mw'],
    "phalapuṣpavat": ['mw'],
    "phalapuṣpavṛddhi": ['mw'],
    "phalapuṣpita": ['mw'],
    "phalapuṣpopaśobhita": ['mw'],
    "phalapuṣpā": ['mw'],
    "phalapuṣpī": ['mw'],
    "phalapādapa": ['mw'],
    "phalapāka": ['cae', 'mw'],
    "phalapākaniṣṭhā": ['mw'],
    "phalapākin": ['mw'],
    "phalapākānta": ['cae'],
    "phalapākāntā": ['mw'],
    "phalapākāvasānikā": ['mw'],
    "phalapākāvasānā": ['mw'],
    "phalapātana": ['cae', 'mw'],
    "phalapūra": ['mw'],
    "phalapūraka": ['mw'],
    "phalaruha": ['cped'],
    "phalarājan": ['mw'],
    "phalarāśi": ['mw'],
    "phalasa": ['mw'],
    "phalasahasra": ['mw'],
    "phalasaka": ['bhs'],
    "phalasambaddha": ['mw'],
    "phalasambhava": ['mw'],
    "phalasambhārā": ['mw'],
    "phalasambhū": ['mw'],
    "phalasampad": ['mw'],
    "phalasatīṇa": ['mw'],
    "phalasaḥ": ['ap90'],
    "phalasaṃstha": ['mw'],
    "phalasaṃyoga": ['mw'],
    "phalasaṃyukta": ['mw'],
    "phalasiddhi": ['cae', 'mw'],
    "phalasneha": ['mw'],
    "phalastanavatī": ['mw'],
    "phalastha": ['mw'],
    "phalasthāna": ['mw'],
    "phalasādhana": ['cae', 'mw'],
    "phalasāṃkaryakhaṇḍana": ['mw'],
    "phalatantra": ['mw'],
    "phalatas": ['ap90', 'cae', 'mw'],
    "phalati": ['bhs', 'cped'],
    "phalatraya": ['mw'],
    "phalatrika": ['mw'],
    "phalatthika": ['cped'],
    "phalatva": ['mw'],
    "phalatā": ['cae', 'mw'],
    "phalavallī": ['mw'],
    "phalavandhya": ['mw'],
    "phalavant": ['cae', 'cped'],
    "phalavarti": ['mw'],
    "phalavartula": ['mw'],
    "phalavat": ['ap90', 'mw'],
    "phalavattva": ['mw'],
    "phalavattā": ['mw'],
    "phalavatī": ['mw'],
    "phalavikrayiṇī": ['mw'],
    "phalavākya": ['mw'],
    "phalavṛkṣa": ['mw'],
    "phalavṛkṣaka": ['mw'],
    "phalaya": ['mw'],
    "phalayoga": ['cae', 'mw'],
    "phalayogāt": ['mw'],
    "phalayukta": ['mw'],
    "phalaśaiśira": ['mw'],
    "phalaśaḥ": ['ap90'],
    "phalaśreṣṭha": ['mw'],
    "phalaśālin": ['mw'],
    "phalaśālitva": ['mw'],
    "phalaśāḍava": ['mw'],
    "phalaṃ": ['ap90'],
    "phalaṃdadā": ['bhs', 'mw'],
    "phalaṣāḍava": ['mw'],
    "phalaṭṭha": ['cped'],
    "phalegrahi": ['cae', 'ddsa', 'mw'],
    "phalegrāhi": ['mw'],
    "phalegrāhin": ['mw'],
    "phalelāṅku": ['mw'],
    "phalendrā": ['mw'],
    "phalenta": ['cped'],
    "phalepsā": ['mw'],
    "phalepuṣpā": ['mw'],
    "phalepāka": ['mw'],
    "phalepākin": ['mw'],
    "phalepāku": ['mw'],
    "phalepākā": ['mw'],
    "phaleruhā": ['mw'],
    "phaletara": ['ddsa'],
    "phaletaratā": ['mw'],
    "phaletvā": ['cped'],
    "phaleṣin": ['bhs'],
    "phalgu": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "phalgua": ['gra'],
    "phalguda": ['mw'],
    "phalgudā": ['mw'],
    "phalguhastinī": ['mw'],
    "phalguluka": ['mw'],
    "phalguna": ['ap90', 'cae', 'ddsa', 'mw'],
    "phalgunaka": ['mw'],
    "phalgunasvāmin": ['mw'],
    "phalgunāla": ['mw'],
    "phalgunī": ['ap90', 'mw'],
    "phalgunībhava": ['mw'],
    "phalgunīpūrvasamaya": ['mw'],
    "phalgunīpūrṇamāsa": ['mw'],
    "phalguprāsaha": ['ddsa', 'mw'],
    "phalgurakṣita": ['mw'],
    "phalgutva": ['mw'],
    "phalgutā": ['ap90', 'mw'],
    "phalgutīrtha": ['mw'],
    "phalguvāṭikā": ['mw'],
    "phalguvṛnta": ['mw'],
    "phalguvṛntāka": ['mw'],
    "phalguśrāddha": ['mw'],
    "phalguṇa": ['mw'],
    "phalguṇaka": ['mw'],
    "phalguṇī": ['mw'],
    "phalgva": ['cae', 'gra', 'mw'],
    "phalgūtsava": ['mw'],
    "phali": ['cped', 'mw'],
    "phaliga": ['cae', 'gra', 'mw'],
    "phalika": ['bhs', 'cped', 'mw'],
    "phalikha": ['bhs'],
    "phalikā": ['mw'],
    "phalikāstaraṇa": ['bhs'],
    "phalin": ['ap90', 'cae', 'gra', 'mw'],
    "phalina": ['ap90', 'cae', 'mw'],
    "phalinī": ['ap90', 'mw'],
    "phalita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "phalitavya": ['mw'],
    "phalitvā": ['cped'],
    "phalitā": ['mw'],
    "phalka": ['mw'],
    "phallakin": ['mw'],
    "phallaphala": ['mw'],
    "phaloccaya": ['mw'],
    "phalodaka": ['mw'],
    "phalodaya": ['cae', 'mw'],
    "phalodbhava": ['mw'],
    "phaloddeśa": ['mw'],
    "phalodgama": ['cae', 'mw'],
    "phaloni": ['mw'],
    "phalonmukha": ['mw'],
    "phalopabhoga": ['mw'],
    "phalopagama": ['mw'],
    "phalopajīvin": ['mw'],
    "phalopeta": ['mw'],
    "phalotpati": ['mw'],
    "phalotpatti": ['mw'],
    "phalotprekṣā": ['ddsa', 'mw'],
    "phalottamā": ['mw'],
    "phalph": ['mw'],
    "phalpha": ['mw'],
    "phalu": ['cped'],
    "phalubīja": ['cped'],
    "phalya": ['mw'],
    "phalyaṃ": ['ap90'],
    "phalā": ['mw'],
    "phalābdhi": ['mw'],
    "phalābhiṣeka": ['mw'],
    "phalābhoga": ['mw'],
    "phalādana": ['mw'],
    "phalādhikāra": ['mw'],
    "phalādhyakṣa": ['mw'],
    "phalāgama": ['cae', 'ddsa', 'mw'],
    "phalāgra": ['mw'],
    "phalāgraśākhin": ['mw'],
    "phalāhāra": ['cae', 'mw'],
    "phalākāṅkṣin": ['cae', 'mw'],
    "phalākāṅkṣā": ['mw'],
    "phalāmla": ['mw'],
    "phalāmlapañcaka": ['mw'],
    "phalāmlika": ['mw'],
    "phalānta": ['mw'],
    "phalānubandha": ['mw'],
    "phalānumeya": ['mw'],
    "phalānusaraṇa": ['mw'],
    "phalānveṣin": ['mw'],
    "phalāpekṣā": ['mw'],
    "phalāpeta": ['mw'],
    "phalāphala": ['bhs', 'cped'],
    "phalāphalikā": ['mw'],
    "phalāpūrva": ['mw'],
    "phalārthin": ['cae', 'ddsa', 'mw'],
    "phalārthitva": ['mw'],
    "phalārāma": ['mw'],
    "phalāsakta": ['mw'],
    "phalāsava": ['cped', 'mw'],
    "phalāsthi": ['mw'],
    "phalāvandhya": ['mw'],
    "phalāya": ['ddsa', 'mw'],
    "phalāyoṣit": ['mw'],
    "phalāśana": ['mw'],
    "phalāśin": ['cae', 'mw'],
    "phalāḍhya": ['cae', 'mw'],
    "phalāḍhyā": ['mw'],
    "phalī": ['cped', 'mw'],
    "phalībhū": ['mw'],
    "phalīkaraṇa": ['cae', 'ddsa', 'mw'],
    "phalīkaraṇahoma": ['mw'],
    "phalīkaraṇamiśra": ['mw'],
    "phalīkaraṇamuṣṭi": ['mw'],
    "phalīkaraṇaṃ": ['ap90'],
    "phalīkāra": ['mw'],
    "phalīkṛ": ['ap90', 'cae', 'mw'],
    "phalīkṛta": ['ap90', 'mw'],
    "phalīya": ['mw'],
    "phalīśa": ['mw'],
    "phalūṣa": ['mw'],
    "phana": ['bhs'],
    "phandamāna": ['cped'],
    "phandana": ['cped'],
    "phandanā": ['cped'],
    "phandati": ['cped'],
    "phandi": ['cped'],
    "phandita": ['cped'],
    "phanditvā": ['cped'],
    "phar": ['ddsa', 'gra', 'mw'],
    "phara": ['bhs', 'mw'],
    "pharanta": ['cped'],
    "pharapharāyate": ['bhs'],
    "pharasaka": ['bhs'],
    "pharasu": ['cped'],
    "pharati": ['bhs', 'cped'],
    "pharañja": ['mw'],
    "pharaṃ": ['ap90'],
    "pharaṇa": ['bhs', 'cped'],
    "pharaṇaka": ['cped'],
    "pharendra": ['mw'],
    "phari": ['cped'],
    "pharita": ['cped'],
    "pharitvā": ['cped'],
    "phariva": ['mw'],
    "pharpharāya": ['ddsa', 'mw'],
    "pharpharāyate": ['ap90'],
    "pharpharīka": ['mw'],
    "pharpharīkaḥ": ['ap90'],
    "pharpharīkā": ['mw'],
    "pharubakaṃ": ['ap90'],
    "pharusa": ['cped'],
    "pharusavacana": ['cped'],
    "pharusāvācā": ['cped'],
    "pharuvaka": ['mw'],
    "pharuṇḍa": ['mw'],
    "pharv": ['mw'],
    "pharvara": ['gra', 'mw'],
    "pharvī": ['gra', 'mw'],
    "phassa": ['cped'],
    "phassesi": ['cped'],
    "phasseti": ['cped'],
    "phassita": ['cped'],
    "phassitvā": ['cped'],
    "phat": ['mw'],
    "phatepura": ['mw'],
    "phatihabhūpati": ['mw'],
    "phatihaśāha": ['mw'],
    "phatkārin": ['ap90', 'mw'],
    "phattesāhaprakāśa": ['mw'],
    "phaulli": ['mw'],
    "phañjikā": ['mw'],
    "phañjipattrikā": ['mw'],
    "phañjiputtrikā": ['mw'],
    "phañjī": ['cae', 'mw'],
    "phaḍiṃgā": ['ap90'],
    "phaḍiṅgā": ['mw'],
    "phaṃḍaḥ": ['ap90'],
    "phaṇ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "phaṇa": ['cae', 'cped', 'ddsa', 'mw'],
    "phaṇabhṛt": ['cae', 'mw'],
    "phaṇadhara": ['cae', 'mw'],
    "phaṇaka": ['cped'],
    "phaṇakara": ['mw'],
    "phaṇamaṇi": ['mw'],
    "phaṇamaṇḍala": ['mw'],
    "phaṇastha": ['mw'],
    "phaṇavant": ['cae'],
    "phaṇavat": ['ap90', 'mw'],
    "phaṇaśreṇī": ['mw'],
    "phaṇaḥ": ['ap90'],
    "phaṇi": ['cae', 'ddsa', 'mw'],
    "phaṇibhuj": ['mw'],
    "phaṇibhārikā": ['mw'],
    "phaṇibhāṣitabhāṣyābdhi": ['mw'],
    "phaṇibhāṣya": ['mw'],
    "phaṇibhāṣyābdhi": ['mw'],
    "phaṇihantrī": ['mw'],
    "phaṇihṛt": ['mw'],
    "phaṇijihvikā": ['mw'],
    "phaṇijihvā": ['mw'],
    "phaṇijjha": ['mw'],
    "phaṇijjhaka": ['mw'],
    "phaṇijjhakaḥ": ['ap90'],
    "phaṇijjhakā": ['mw'],
    "phaṇijā": ['mw'],
    "phaṇika": ['bhs'],
    "phaṇikanyā": ['mw'],
    "phaṇikesara": ['mw'],
    "phaṇikeśvara": ['mw'],
    "phaṇikhela": ['mw'],
    "phaṇikā": ['mw'],
    "phaṇikāra": ['mw'],
    "phaṇilatā": ['mw'],
    "phaṇimukha": ['mw'],
    "phaṇin": ['ap90', 'cae', 'mw'],
    "phaṇināyaka": ['ddsa', 'mw'],
    "phaṇipati": ['cae', 'mw'],
    "phaṇipheṇa": ['mw'],
    "phaṇipriya": ['mw'],
    "phaṇita": ['mw'],
    "phaṇitalpaga": ['mw'],
    "phaṇivallī": ['mw'],
    "phaṇivīrudh": ['mw'],
    "phaṇā": ['ddsa', 'mw'],
    "phaṇābhara": ['mw'],
    "phaṇābhṛt": ['cae', 'mw'],
    "phaṇādhara": ['mw'],
    "phaṇākara": ['mw'],
    "phaṇāmaṇisahasraruc": ['mw'],
    "phaṇāphalaka": ['mw'],
    "phaṇātapatra": ['mw'],
    "phaṇāvant": ['cae'],
    "phaṇāvat": ['ap90', 'mw'],
    "phaṇāṭopa": ['mw'],
    "phaṇāṭopin": ['mw'],
    "phaṇī": ['cped', 'mw'],
    "phaṇīcakra": ['mw'],
    "phaṇīndra": ['cae', 'ddsa', 'mw'],
    "phaṇīndreśvara": ['mw'],
    "phaṇīya": ['mw'],
    "phaṇīśa": ['cae', 'mw'],
    "phaṇīśvara": ['cae', 'mw'],
    "phaṇḍa": ['mw'],
    "phaṣājiga": ['mw'],
    "phaṣājima": ['mw'],
    "phaṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "phaṭa": ['mw'],
    "phaṭaḥ": ['ap90'],
    "phaṭika": ['bhs'],
    "phaṭā": ['cae', 'ddsa', 'mw'],
    "phaṭāṭopa": ['mw'],
    "phaṭāṭopin": ['mw'],
    "pheggu": ['cped'],
    "phel": ['ap90', 'mw'],
    "phela": ['bhs', 'mw'],
    "phelaṃ": ['ap90'],
    "pheli": ['mw'],
    "phelikā": ['bhs', 'mw'],
    "pheluka": ['mw'],
    "phelā": ['bhs', 'mw'],
    "phelī": ['mw'],
    "phena": ['cae', 'ddsa', 'gra', 'mw'],
    "phenadharman": ['mw'],
    "phenadugdhā": ['mw'],
    "phenagiri": ['mw'],
    "phenaka": ['ap90', 'mw'],
    "phenala": ['ap90', 'mw'],
    "phenamehin": ['mw'],
    "phenapa": ['cae', 'mw'],
    "phenapiṇḍa": ['mw'],
    "phenaprakhya": ['mw'],
    "phenatā": ['mw'],
    "phenavant": ['cae'],
    "phenavat": ['mw'],
    "phenavāhin": ['mw'],
    "phenila": ['ap90', 'cae', 'ddsa', 'mw'],
    "phenilā": ['mw'],
    "phenopama": ['mw'],
    "phenya": ['cae', 'mw'],
    "phenā": ['mw'],
    "phenāgra": ['mw'],
    "phenāhāra": ['ddsa', 'mw'],
    "phenāya": ['ddsa', 'mw'],
    "phenāśani": ['mw'],
    "phenī": ['mw'],
    "phera": ['mw'],
    "pherala": ['mw'],
    "pherava": ['cae', 'ddsa', 'mw'],
    "pheravaḥ": ['ap90'],
    "pheravītantra": ['mw'],
    "pheraḥ": ['ap90'],
    "pheraṇḍa": ['mw'],
    "pheru": ['cae', 'mw'],
    "pheruvinnā": ['mw'],
    "pheruḥ": ['ap90'],
    "phet": ['mw'],
    "phetkāra": ['cae', 'ddsa', 'mw'],
    "phetkārin": ['cae', 'mw'],
    "phetkāriṇītantra": ['mw'],
    "phetkārīyatantra": ['mw'],
    "phetkṛta": ['mw'],
    "pheñcaka": ['cae', 'mw'],
    "pheñjaka": ['ddsa'],
    "pheṇa": ['cped', 'ddsa', 'mw'],
    "pheṇaka": ['ap90'],
    "pheṇapiṇḍa": ['cped'],
    "pheṇaḥ": ['ap90'],
    "pheṇila": ['cped'],
    "pheṇuddehaka": ['cped'],
    "pheṇṭa": ['ddsa', 'mw'],
    "pheṭ": ['mw'],
    "pheṭkāra": ['cae', 'ddsa', 'mw'],
    "pheṭkāraḥ": ['ap90'],
    "phi": ['mw'],
    "phiraṃgaḥ": ['ap90'],
    "phiraṃgin": ['ap90'],
    "phiraṅga": ['ddsa', 'mw'],
    "phiraṅgaroṭī": ['mw'],
    "phiraṅgin": ['mw'],
    "phiraṅgāmaya": ['mw'],
    "phiriṇḍa": ['mw'],
    "phirāla": ['mw'],
    "phiya": ['cped'],
    "phiḥ": ['ap90'],
    "phiṃgakaḥ": ['ap90'],
    "phiṅgaka": ['mw'],
    "phiṭsūtra": ['cae', 'ddsa', 'mw'],
    "phiṭsūtravṛtti": ['mw'],
    "phosita": ['cped'],
    "phoṭa": ['cped'],
    "phoṭaka": ['cped'],
    "phoṭṭhabba": ['cped'],
    "phu": ['mw'],
    "phuka": ['mw'],
    "phukaḥ": ['ap90'],
    "phuliṅga": ['mw'],
    "phull": ['ap90', 'cae', 'ddsa', 'mw'],
    "phulla": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "phulladāman": ['mw'],
    "phulladṛṣṭi": ['mw'],
    "phullaka": ['mw'],
    "phullalocana": ['mw'],
    "phullana": ['mw'],
    "phullanalinī": ['cae', 'mw'],
    "phullanayana": ['mw'],
    "phullanaṃ": ['ap90'],
    "phullanetra": ['mw'],
    "phullapadmotpalavat": ['mw'],
    "phullaphāla": ['mw'],
    "phullapura": ['mw'],
    "phullarīka": ['mw'],
    "phullarīkaḥ": ['ap90'],
    "phullasūtra": ['mw'],
    "phullatubarī": ['mw'],
    "phullavadana": ['mw'],
    "phullavat": ['mw'],
    "phulli": ['mw'],
    "phullita": ['bhs', 'cped', 'mw'],
    "phullitaka": ['bhs'],
    "phulliḥ": ['ap90'],
    "phullotpala": ['cae', 'mw'],
    "phullāmbikā": ['mw'],
    "phullāraṇyamāhātmya": ['mw'],
    "phulti": ['mw'],
    "phuluphulu": ['bhs'],
    "phumphuā": ['mw'],
    "phuphukāra": ['bhs'],
    "phuphusa": ['mw'],
    "phupphu": ['ap90', 'mw'],
    "phupphukāraka": ['mw'],
    "phupphusa": ['bhs', 'mw'],
    "phupphusaḥ": ['ap90'],
    "phurāphurāy": ['cae'],
    "phurāphurāya": ['mw'],
    "phusamāna": ['cped'],
    "phusana": ['cped'],
    "phusanta": ['cped'],
    "phusanā": ['cped'],
    "phusati": ['cped'],
    "phusi": ['cped'],
    "phusita": ['cped'],
    "phusitaka": ['cped'],
    "phusitvā": ['cped'],
    "phussa": ['cped'],
    "phussaratha": ['cped'],
    "phussarāga": ['cped'],
    "phusīyati": ['cped'],
    "phut": ['ap90', 'cae', 'ddsa', 'mw'],
    "phutkara": ['mw'],
    "phutkartumanas": ['mw'],
    "phutkāra": ['cae', 'mw'],
    "phutkārarandhra": ['mw'],
    "phutkāravat": ['mw'],
    "phutkārya": ['mw'],
    "phutkṛ": ['mw'],
    "phutkṛta": ['cae', 'mw'],
    "phutkṛti": ['mw'],
    "phutphu": ['bhs'],
    "phuḍut": ['mw'],
    "phuḥ": ['ap90'],
    "phuṃphuā": ['ap90'],
    "phuṣphasa": ['bhs'],
    "phuṭa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "phuṭaḥ": ['ap90'],
    "phuṭāṭopa": ['mw'],
    "phuṭṭaka": ['bhs', 'mw'],
    "phuṭṭakavastra": ['mw'],
    "phuṭṭha": ['cped'],
    "phuṭṭikā": ['mw'],
    "phā": ['mw'],
    "phāla": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "phālacamasa": ['mw'],
    "phāladatī": ['mw'],
    "phālagupta": ['mw'],
    "phālaka": ['cped'],
    "phālakhelā": ['ap90', 'mw'],
    "phālakuddālalāṅgalin": ['mw'],
    "phālakṛṣṭa": ['cae', 'mw'],
    "phālana": ['cped'],
    "phālaḥ": ['ap90'],
    "phālesi": ['cped'],
    "phāleti": ['cped'],
    "phāletuṁ": ['cped'],
    "phālguna": ['cae', 'ddsa', 'mw'],
    "phālgunamāhātmya": ['mw'],
    "phālgunaḥ": ['ap90'],
    "phālguni": ['mw'],
    "phālgunika": ['mw'],
    "phālgunya": ['mw'],
    "phālgunāla": ['mw'],
    "phālgunālaḥ": ['ap90'],
    "phālgunānuja": ['mw'],
    "phālgunī": ['ap90', 'mw'],
    "phālgunībhava": ['mw'],
    "phālgunīpakṣa": ['mw'],
    "phālgunīpaurṇamāsī": ['mw'],
    "phālguṇa": ['mw'],
    "phālguṇī": ['mw'],
    "phāli": ['mw'],
    "phālita": ['cped', 'mw'],
    "phālāhata": ['mw'],
    "phālīkaraṇa": ['mw'],
    "phāriva": ['gra', 'mw'],
    "phārusaka": ['cped'],
    "phārī": ['mw'],
    "phāsa": ['bhs'],
    "phāsu": ['bhs', 'cped'],
    "phāsuka": ['cped'],
    "phāsukā": ['cped'],
    "phāsulikā": ['cped'],
    "phātikamma": ['cped'],
    "phāṃḍaṃ": ['ap90'],
    "phāṃṭa": ['ap90'],
    "phāṃṭakaḥ": ['ap90'],
    "phāṇi": ['ap90', 'mw'],
    "phāṇita": ['cped', 'ddsa', 'mw'],
    "phāṇitapuṭa": ['cped'],
    "phāṇitaṃ": ['ap90'],
    "phāṇitībhūta": ['mw'],
    "phāṇī": ['bhs'],
    "phāṇḍa": ['mw'],
    "phāṇḍin": ['mw'],
    "phāṇṭa": ['ddsa', 'mw'],
    "phāṇṭaka": ['mw'],
    "phāṇṭaya": ['mw'],
    "phāṇṭāhṛta": ['mw'],
    "phāṇṭāhṛti": ['mw'],
    "phāṇṭāhṛtāyani": ['mw'],
    "phāṣa": ['bhs'],
    "phāṣaka": ['bhs'],
    "phāṭ": ['ap90', 'mw'],
    "phāṭakī": ['ap90', 'mw'],
    "phīta": ['cped'],
    "phūt": ['ap90', 'ddsa', 'mw'],
    "phūtkāra": ['cae'],
    "phūtkṛ": ['cae'],
    "pi": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "piba": ['cae', 'ddsa', 'mw'],
    "pibadhyai": ['cae'],
    "pibana": ['bhs'],
    "pibati": ['cped'],
    "pibavat": ['mw'],
    "pibd": ['cae', 'ddsa', 'gra', 'mw'],
    "pibdana": ['cae', 'gra', 'mw'],
    "picavya": ['mw'],
    "picavyaḥ": ['ap90'],
    "picaṃḍakaḥ": ['ap90'],
    "picaṃḍaḥ": ['ap90'],
    "picaṃḍin": ['ap90'],
    "picaṇḍa": ['mw'],
    "picaṇḍaka": ['mw'],
    "picaṇḍika": ['mw'],
    "picaṇḍikā": ['mw'],
    "picaṇḍila": ['mw'],
    "picaṇḍin": ['mw'],
    "picc": ['ap90', 'mw'],
    "piccayati": ['bhs'],
    "piccaṭa": ['ap90', 'bhs', 'mw'],
    "picch": ['ap90'],
    "piccha": ['cae', 'cped', 'ddsa', 'mw'],
    "picchabāṇa": ['mw'],
    "picchaka": ['cae', 'mw'],
    "picchakaḥ": ['ap90'],
    "picchakā": ['ap90'],
    "picchala": ['ap90', 'cae', 'ddsa', 'mw'],
    "picchaladalā": ['mw'],
    "picchalatikā": ['mw'],
    "picchalā": ['mw'],
    "picchalāṅga": ['mw'],
    "picchana": ['mw'],
    "picchavat": ['mw'],
    "picchaṃ": ['ap90'],
    "picchikā": ['mw'],
    "picchila": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "picchilabīja": ['mw'],
    "picchilacchadā": ['mw'],
    "picchilaka": ['mw'],
    "picchilasāra": ['mw'],
    "picchilatva": ['mw'],
    "picchilatvac": ['mw'],
    "picchilā": ['mw'],
    "picchilātantra": ['mw'],
    "picchilīkṛ": ['mw'],
    "picchitikā": ['mw'],
    "piccholā": ['cae', 'mw'],
    "picchorā": ['cae', 'mw'],
    "picchā": ['mw'],
    "picchāsrāva": ['mw'],
    "piccita": ['mw'],
    "picciṭa": ['ap90', 'mw'],
    "picciṭaka": ['mw'],
    "piccā": ['ap90', 'mw'],
    "pich": ['mw'],
    "pici": ['bhs'],
    "picila": ['mw'],
    "piciṃḍikā": ['ap90'],
    "piciṇḍa": ['mw'],
    "piciṇḍavat": ['mw'],
    "piciṇḍikā": ['mw'],
    "piciṇḍila": ['mw'],
    "picu": ['cae', 'cped', 'ddsa', 'mw'],
    "picuka": ['mw'],
    "picukīya": ['mw'],
    "picula": ['cae', 'mw'],
    "piculaḥ": ['ap90'],
    "picumanda": ['bhs', 'mw'],
    "picumarda": ['mw'],
    "picupaṭala": ['cped'],
    "picutkāra": ['bhs'],
    "picutūla": ['mw'],
    "picuvaktrā": ['mw'],
    "picuvā": ['bhs'],
    "picuḥ": ['ap90'],
    "pidadhat": ['mw'],
    "pidahana": ['cped'],
    "pidahati": ['cped'],
    "pidahi": ['cped'],
    "pidahita": ['cped'],
    "pidahitvā": ['cped'],
    "pidhayati": ['bhs'],
    "pidhitsu": ['cae', 'ddsa', 'mw'],
    "pidhā": ['ap90', 'mw'],
    "pidhāna": ['cae', 'cped', 'mw'],
    "pidhānaka": ['mw'],
    "pidhānakaṃ": ['ap90'],
    "pidhānavat": ['mw'],
    "pidhānaṃ": ['ap90'],
    "pidhānikā": ['mw'],
    "pidhānī": ['mw'],
    "pidhātavya": ['cae', 'ddsa', 'mw'],
    "pidhāya": ['cped', 'mw'],
    "pidhāyaka": ['ap90', 'cae', 'mw'],
    "pidhāyakatā": ['mw'],
    "pidhāyin": ['mw'],
    "pidva": ['cae', 'mw'],
    "pidāku": ['mw'],
    "pidṛbh": ['mw'],
    "pihaka": ['cped'],
    "pihayati": ['cped'],
    "pihayi": ['cped'],
    "pihita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "pihiti": ['cae', 'mw'],
    "pihuli": ['mw'],
    "pihālu": ['cped'],
    "pihāyanā": ['cped'],
    "pihāyita": ['cped'],
    "pijavana": ['gra', 'mw'],
    "pijūla": ['mw'],
    "pika": ['cae', 'cped', 'ddsa', 'mw'],
    "pikabandhu": ['mw'],
    "pikabhakṣā": ['mw'],
    "pikabāndhava": ['mw'],
    "pikanikara": ['mw'],
    "pikapriyā": ['mw'],
    "pikarāga": ['mw'],
    "pikasvarā": ['mw'],
    "pikavallabha": ['mw'],
    "pikaḥ": ['ap90'],
    "pikekṣaṇā": ['mw'],
    "pikka": ['mw'],
    "pikkaḥ": ['ap90'],
    "pikkā": ['mw'],
    "pikākṣa": ['mw'],
    "pikānanda": ['mw'],
    "pikāṅga": ['mw'],
    "pikī": ['mw'],
    "pil": ['ap90', 'mw'],
    "pilakkha": ['cped'],
    "pilakṣa": ['bhs'],
    "pilandhana": ['cped'],
    "pilandhati": ['cped'],
    "pilandhi": ['cped'],
    "pilandhita": ['cped'],
    "pilandhitvā": ['cped'],
    "pilandhiya": ['cped'],
    "pilavati": ['cped'],
    "pili": ['mw'],
    "pilindavatsa": ['bhs', 'mw'],
    "pilipalipāyeti": ['bhs'],
    "pilipiccha": ['mw'],
    "pilipicchi": ['mw'],
    "pilipicchika": ['mw'],
    "pilipiñja": ['mw'],
    "pilippila": ['mw'],
    "pilla": ['ap90', 'mw'],
    "pillaka": ['cped'],
    "pillakā": ['ap90', 'mw'],
    "pilotika": ['bhs'],
    "pilotikā": ['cped'],
    "pilpila": ['mw'],
    "pilpilā": ['mw'],
    "pilu": ['mw'],
    "piluka": ['mw'],
    "piluparṇi": ['mw'],
    "piluḥ": ['ap90'],
    "pimpalā": ['ddsa', 'mw'],
    "pimpari": ['mw'],
    "pimparī": ['mw'],
    "pinaddha": ['ap90', 'cae', 'mw'],
    "pinaddhaka": ['mw'],
    "pinah": ['ap90', 'mw'],
    "pinahya": ['mw'],
    "pinasa": ['mw'],
    "pinv": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pinva": ['cae', 'mw'],
    "pinvamāna": ['mw'],
    "pinvana": ['cae', 'mw'],
    "pinvantyapīyā": ['mw'],
    "pinvita": ['mw'],
    "pinya": ['bhs'],
    "pinyāsa": ['mw'],
    "pināka": ['cae', 'ddsa', 'mw'],
    "pinākabhṛt": ['mw'],
    "pinākadhṛk": ['mw'],
    "pinākagoptṛ": ['mw'],
    "pinākahasta": ['mw'],
    "pinākapāṇi": ['mw'],
    "pinākasena": ['mw'],
    "pinākaḥ": ['ap90'],
    "pināki": ['mw'],
    "pinākidiś": ['mw'],
    "pinākin": ['ap90', 'cae', 'ddsa', 'mw'],
    "pinākinī": ['mw'],
    "pinākinīmāhātmya": ['mw'],
    "pinākāvasa": ['mw'],
    "pinākī": ['mw'],
    "pināsa": ['cped'],
    "pinī": ['mw'],
    "pipakṣ": ['mw'],
    "pipatiṣat": ['ap90', 'mw'],
    "pipatiṣu": ['ap90', 'cae', 'ddsa', 'mw'],
    "pipatiṣā": ['mw'],
    "pipaviṣu": ['mw'],
    "pipaṭhiṣ": ['mw'],
    "pipillikā": ['cped'],
    "pipilī": ['mw'],
    "pipiṣvant": ['cae'],
    "pipiṣvat": ['gra', 'mw'],
    "piplu": ['cae', 'ddsa', 'mw'],
    "piplukarṇa": ['mw'],
    "piplupracchādana": ['mw'],
    "pipluḥ": ['ap90'],
    "pippakā": ['cae', 'mw'],
    "pippala": ['cae', 'ddsa', 'gra', 'mw'],
    "pippalaka": ['mw'],
    "pippalamātra": ['mw'],
    "pippalanātha": ['mw'],
    "pippalaḥ": ['ap90'],
    "pippaleśa": ['mw'],
    "pippali": ['mw'],
    "pippaliśroṇi": ['mw'],
    "pippaliḥ": ['ap90'],
    "pippalā": ['mw'],
    "pippalāda": ['cae', 'mw'],
    "pippalādasūtra": ['mw'],
    "pippalādatīrtha": ['mw'],
    "pippalādaśruti": ['mw'],
    "pippalādaśrāddhakalpa": ['mw'],
    "pippalādi": ['mw'],
    "pippalādopaniṣad": ['mw'],
    "pippalāvatī": ['mw'],
    "pippalāyana": ['bhs', 'mw'],
    "pippalāyani": ['mw'],
    "pippalāśana": ['mw'],
    "pippalī": ['mw'],
    "pippalīkā": ['mw'],
    "pippalīlavaṇa": ['mw'],
    "pippalīmūla": ['mw'],
    "pippalīmūlīya": ['mw'],
    "pippalīvardhamāna": ['mw'],
    "pippalīvardhamānaka": ['mw'],
    "pippalīya": ['mw'],
    "pippalū": ['mw'],
    "pippaṭā": ['mw'],
    "pipphala": ['cped'],
    "pipphalaka": ['cped'],
    "pipphalī": ['cped'],
    "pippikā": ['ap90', 'mw'],
    "pippīkā": ['mw'],
    "pipru": ['cae', 'ddsa', 'gra', 'mw'],
    "piprīṣu": ['cae', 'mw'],
    "piprīṣā": ['cae', 'mw'],
    "pipyaṭā": ['mw'],
    "pipāsant": ['cae'],
    "pipāsat": ['ddsa', 'mw'],
    "pipāsavant": ['cae'],
    "pipāsin": ['bhs', 'mw'],
    "pipāsita": ['ap90', 'cae', 'cped', 'mw'],
    "pipāsu": ['cae', 'mw'],
    "pipāsā": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "pipāsāla": ['mw'],
    "pipāsārta": ['cae'],
    "pipāsāvat": ['mw'],
    "pipāṭhaka": ['mw'],
    "pipīla": ['cae', 'ddsa', 'gra', 'mw'],
    "pipīlaka": ['cae', 'mw'],
    "pipīlakaḥ": ['ap90'],
    "pipīlaḥ": ['ap90'],
    "pipīlika": ['cae', 'mw'],
    "pipīlikamadhya": ['mw'],
    "pipīlikamadhyama": ['mw'],
    "pipīlikamadhyamā": ['mw'],
    "pipīlikamadhyā": ['mw'],
    "pipīlikapuṭa": ['mw'],
    "pipīlikaḥ": ['ap90'],
    "pipīlikodvāpa": ['mw'],
    "pipīlikotkiraṇa": ['mw'],
    "pipīlikotsaraṇa": ['mw'],
    "pipīlikā": ['ap90', 'cped', 'ddsa', 'mw'],
    "pipīlikāmadhya": ['mw'],
    "pipīlikāparisarpaṇa": ['mw'],
    "pipīlikāvat": ['mw'],
    "pipīlī": ['mw'],
    "pipītaka": ['mw'],
    "pipītakadvādaśīvrata": ['mw'],
    "pipītakī": ['ap90', 'mw'],
    "pipīṣat": ['mw'],
    "pipīṣu": ['cae', 'gra', 'mw'],
    "pipṛcchiṣu": ['cae'],
    "pipṛkṣu": ['mw'],
    "piroja": ['mw'],
    "pis": ['ap90', 'cae', 'ddsa', 'mw'],
    "pisana": ['cped'],
    "pisati": ['cped'],
    "pisita": ['cped'],
    "pispṛkṣu": ['cae', 'mw'],
    "pisuṇa": ['cped'],
    "pisuṇāvācā": ['cped'],
    "pisāca": ['cped'],
    "pisācaka": ['cped'],
    "pit": ['mw'],
    "pitar": ['cped'],
    "pitari": ['mw'],
    "pitariśūra": ['mw'],
    "pithana": ['bhs'],
    "pithati": ['bhs'],
    "pithaya": ['mw'],
    "pithita": ['mw'],
    "pithānita": ['bhs'],
    "pithīyati": ['cped'],
    "pithīyi": ['cped'],
    "pitika": ['cped'],
    "pitipakkha": ['cped'],
    "pitr": ['mw'],
    "pitrarjita": ['mw'],
    "pitrartham": ['mw'],
    "pitria": ['gra'],
    "pitriāvat": ['gra'],
    "pitrya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pitryupavīta": ['mw'],
    "pitryupavītin": ['mw'],
    "pitryā": ['mw'],
    "pitryāvat": ['gra', 'mw'],
    "pitrādyanta": ['cae', 'mw'],
    "pitsa": ['ddsa'],
    "pitsala": ['mw'],
    "pitsalaḥ": ['ap90'],
    "pitsaru": ['mw'],
    "pitsat": ['ap90', 'mw'],
    "pitsu": ['mw'],
    "pitta": ['cae', 'cped', 'ddsa', 'mw'],
    "pittadhara": ['mw'],
    "pittadrāvin": ['mw'],
    "pittadāha": ['mw'],
    "pittagadin": ['mw'],
    "pittaghna": ['mw'],
    "pittaghnī": ['mw'],
    "pittagulma": ['mw'],
    "pittahan": ['mw'],
    "pittahara": ['mw'],
    "pittajvara": ['cae', 'mw'],
    "pittakośa": ['mw'],
    "pittakoṣa": ['mw'],
    "pittakuṣṭha": ['mw'],
    "pittakṣobha": ['mw'],
    "pittala": ['ap90', 'cae', 'mw'],
    "pittalā": ['mw'],
    "pittalī": ['mw'],
    "pittanibarhaṇa": ['mw'],
    "pittaprakopa": ['mw'],
    "pittaprakṛti": ['mw'],
    "pittarakta": ['mw'],
    "pittarogin": ['mw'],
    "pittasthāna": ['mw'],
    "pittasyanda": ['mw'],
    "pittasāraka": ['mw'],
    "pittavat": ['mw'],
    "pittavidagdha": ['mw'],
    "pittavināśana": ['mw'],
    "pittavāyu": ['mw'],
    "pittaśamana": ['mw'],
    "pittaśleṣmala": ['mw'],
    "pittaśopha": ['mw'],
    "pittaśoṇita": ['mw'],
    "pittaṃ": ['ap90'],
    "pittha": ['ddsa', 'mw'],
    "pitthaka": ['mw'],
    "pittodara": ['mw'],
    "pittodarin": ['mw'],
    "pittopahata": ['mw'],
    "pittopasṛṣṭa": ['mw'],
    "pittābhiṣyanda": ['mw'],
    "pittādhika": ['cped'],
    "pittāntakarasa": ['mw'],
    "pittāri": ['mw'],
    "pittāsra": ['mw'],
    "pittātīsāra": ['mw'],
    "pittātīsārin": ['mw'],
    "pitu": ['cae', 'ddsa', 'gra', 'mw'],
    "pitubhaj": ['gra'],
    "pitubhāj": ['cae', 'mw'],
    "pitubhṛt": ['cae', 'gra', 'mw'],
    "pitucchā": ['cped'],
    "pitucchāputta": ['cped'],
    "pitughāta": ['cped'],
    "pitukicca": ['cped'],
    "pitukṛt": ['cae', 'gra', 'mw'],
    "pitumant": ['cae'],
    "pitumat": ['gra', 'mw'],
    "pitusantaka": ['cped'],
    "pitustoma": ['mw'],
    "pituḥ": ['mw'],
    "pituḥputra": ['mw'],
    "pituḥsvasṛ": ['mw'],
    "pituḥṣvasṛ": ['mw'],
    "pituṣaṇi": ['cae', 'gra', 'mw'],
    "pitva": ['cae', 'gra'],
    "pitā": ['mw'],
    "pitāmaha": ['cae', 'cped', 'mw'],
    "pitāmahasaras": ['mw'],
    "pitāmahasaṃhitā": ['mw'],
    "pitāmahasmṛti": ['mw'],
    "pitāmahaḥ": ['ap90'],
    "pitāmahī": ['mw'],
    "pitānandin": ['bhs'],
    "pitāputra": ['cae', 'ddsa', 'mw'],
    "pitāputrasamāgama": ['bhs', 'mw'],
    "pitāputravirodha": ['mw'],
    "pitāputrīya": ['mw'],
    "pitāsumatisaṃvāda": ['mw'],
    "pitūy": ['gra'],
    "pitūya": ['mw'],
    "pitṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pitṛbandhu": ['cae', 'mw'],
    "pitṛbhakta": ['mw'],
    "pitṛbhakti": ['cae', 'mw'],
    "pitṛbhaktitaraṃgiṇī": ['mw'],
    "pitṛbhogīṇa": ['mw'],
    "pitṛbhojana": ['mw'],
    "pitṛbhrātṛ": ['mw'],
    "pitṛbhūti": ['mw'],
    "pitṛbāndhava": ['mw'],
    "pitṛceṭa": ['mw'],
    "pitṛdaivata": ['cae', 'mw'],
    "pitṛdaivatya": ['mw'],
    "pitṛdatta": ['mw'],
    "pitṛdayitā": ['mw'],
    "pitṛdeva": ['cae', 'mw'],
    "pitṛdevata": ['cae', 'mw'],
    "pitṛdevatya": ['cae', 'mw'],
    "pitṛdevatā": ['cae', 'mw'],
    "pitṛdina": ['mw'],
    "pitṛdravya": ['mw'],
    "pitṛdrohin": ['mw'],
    "pitṛdāna": ['mw'],
    "pitṛdānaka": ['mw'],
    "pitṛdāya": ['cae', 'mw'],
    "pitṛgaṇa": ['mw'],
    "pitṛgaṇā": ['mw'],
    "pitṛghna": ['cae', 'mw'],
    "pitṛghātaka": ['cae', 'mw'],
    "pitṛghātin": ['cae', 'mw'],
    "pitṛgraha": ['mw'],
    "pitṛgrāma": ['mw'],
    "pitṛgāmin": ['mw'],
    "pitṛgāthā": ['mw'],
    "pitṛgīta": ['mw'],
    "pitṛgītākathana": ['mw'],
    "pitṛgṛha": ['mw'],
    "pitṛhan": ['cae', 'ddsa', 'mw'],
    "pitṛhatyā": ['mw'],
    "pitṛhū": ['mw'],
    "pitṛhūya": ['cae', 'mw'],
    "pitṛjña": ['bhs'],
    "pitṛka": ['ap90', 'cae', 'mw'],
    "pitṛkalpa": ['mw'],
    "pitṛkarman": ['cae', 'mw'],
    "pitṛkilbiṣa": ['mw'],
    "pitṛkriyā": ['mw'],
    "pitṛkulyā": ['mw'],
    "pitṛkānana": ['cae', 'mw'],
    "pitṛkārya": ['cae', 'mw'],
    "pitṛkāṇḍa": ['mw'],
    "pitṛkṛta": ['mw'],
    "pitṛkṛtya": ['cae', 'mw'],
    "pitṛliṅga": ['mw'],
    "pitṛloka": ['cae', 'mw'],
    "pitṛmandira": ['mw'],
    "pitṛmant": ['cae'],
    "pitṛmat": ['ap90', 'mw'],
    "pitṛmedha": ['cae', 'mw'],
    "pitṛmedhasāra": ['mw'],
    "pitṛmedhasūtra": ['mw'],
    "pitṛmātrartha": ['cae', 'mw'],
    "pitṛmātṛguruśuśrūṣādhyānavat": ['mw'],
    "pitṛmātṛhīna": ['mw'],
    "pitṛmātṛmaya": ['mw'],
    "pitṛnāman": ['mw'],
    "pitṛpada": ['mw'],
    "pitṛpaddhati": ['mw'],
    "pitṛpaitāmaha": ['cae', 'mw'],
    "pitṛpaitāmahika": ['mw'],
    "pitṛpakṣa": ['ddsa', 'mw'],
    "pitṛpati": ['mw'],
    "pitṛpaṅktividhāna": ['mw'],
    "pitṛpitṛ": ['mw'],
    "pitṛprasū": ['mw'],
    "pitṛpriya": ['mw'],
    "pitṛprāpta": ['mw'],
    "pitṛputrasamāgama": ['bhs'],
    "pitṛpātra": ['mw'],
    "pitṛpāṇa": ['mw'],
    "pitṛpīta": ['cae', 'mw'],
    "pitṛpūjana": ['cae', 'mw'],
    "pitṛrāj": ['mw'],
    "pitṛrāja": ['cae', 'mw'],
    "pitṛrājan": ['cae', 'mw'],
    "pitṛrūpa": ['mw'],
    "pitṛsadman": ['cae', 'mw'],
    "pitṛsaṃhitā": ['mw'],
    "pitṛsaṃnibha": ['mw'],
    "pitṛsaṃyukta": ['mw'],
    "pitṛsthāna": ['mw'],
    "pitṛsvasrīya": ['mw'],
    "pitṛsvasṛ": ['mw'],
    "pitṛsāmānya": ['mw'],
    "pitṛsū": ['mw'],
    "pitṛsūkta": ['mw'],
    "pitṛtama": ['cae', 'gra', 'mw'],
    "pitṛtarpaṇa": ['cae', 'ddsa', 'mw'],
    "pitṛtas": ['cae', 'mw'],
    "pitṛtithi": ['mw'],
    "pitṛtva": ['cae', 'mw'],
    "pitṛtīrtha": ['mw'],
    "pitṛtīrthamāhātmya": ['mw'],
    "pitṛvadha": ['cae', 'mw'],
    "pitṛvana": ['cae', 'mw'],
    "pitṛvanecara": ['mw'],
    "pitṛvartin": ['mw'],
    "pitṛvasati": ['mw'],
    "pitṛvat": ['ap90', 'cae', 'mw'],
    "pitṛvaṃśa": ['cae', 'mw'],
    "pitṛvaṃśya": ['mw'],
    "pitṛveśman": ['cae', 'mw'],
    "pitṛvitta": ['cae', 'gra', 'mw'],
    "pitṛvrata": ['cae', 'mw'],
    "pitṛvya": ['cae', 'ddsa', 'mw'],
    "pitṛvyaghātin": ['mw'],
    "pitṛvyaputra": ['cae', 'mw'],
    "pitṛvyaḥ": ['ap90'],
    "pitṛvākpara": ['mw'],
    "pitṛyajña": ['cae', 'ddsa', 'gra', 'mw'],
    "pitṛyāna": ['cae', 'mw'],
    "pitṛyāṇa": ['cae', 'gra', 'mw'],
    "pitṛśarman": ['ddsa', 'mw'],
    "pitṛśravaṇa": ['gra', 'mw'],
    "pitṛśrāddha": ['mw'],
    "pitṛṣad": ['cae', 'gra', 'mw'],
    "pitṛṣadana": ['mw'],
    "pitṛṣvasrīya": ['cae', 'mw'],
    "pitṛṣvasāmātula": ['mw'],
    "pitṛṣvasṛ": ['cae', 'mw'],
    "pivana": ['cped'],
    "pivanta": ['cped'],
    "pivati": ['cped'],
    "pivatimāna": ['cped'],
    "pivi": ['cped'],
    "pivituṁ": ['cped'],
    "pivitvā": ['cped'],
    "piya": ['cped'],
    "piyabhāṇī": ['cped'],
    "piyadasana": ['cped'],
    "piyakamyatā": ['cped'],
    "piyaroja": ['mw'],
    "piyarūpa": ['cped'],
    "piyatama": ['cped'],
    "piyatara": ['cped'],
    "piyatā": ['cped'],
    "piyavacana": ['cped'],
    "piyavippayoga": ['cped'],
    "piyavādī": ['cped'],
    "piyaṅgu": ['cped'],
    "piyā": ['cped'],
    "piyāka": ['mw'],
    "piyāla": ['bhs', 'ddsa', 'mw'],
    "piyālabīja": ['mw'],
    "piyālamajjā": ['mw'],
    "piyālaḥ": ['ap90'],
    "piyāpāya": ['cped'],
    "piyāru": ['ddsa', 'gra', 'mw'],
    "piyāyamāna": ['cped'],
    "piyāyanta": ['cped'],
    "piyāyanā": ['cped'],
    "piyāyati": ['cped'],
    "piyāyi": ['cped'],
    "piyāyita": ['cped'],
    "piyāyitvā": ['cped'],
    "piñcadeva": ['ddsa', 'mw'],
    "piñcha": ['mw'],
    "piñj": ['ddsa', 'mw'],
    "piñja": ['cped', 'mw'],
    "piñjala": ['bhs', 'mw'],
    "piñjalaka": ['mw'],
    "piñjalā": ['cae', 'mw'],
    "piñjalī": ['ddsa', 'mw'],
    "piñjana": ['mw'],
    "piñjara": ['cae', 'cped', 'ddsa', 'mw'],
    "piñjaraka": ['mw'],
    "piñjaratva": ['mw'],
    "piñjaratā": ['mw'],
    "piñjaray": ['cae'],
    "piñjaraya": ['ddsa', 'mw'],
    "piñjarika": ['ddsa', 'mw'],
    "piñjariman": ['mw'],
    "piñjarita": ['mw'],
    "piñjarīkṛ": ['cae', 'mw'],
    "piñjaṭa": ['mw'],
    "piñjeṭa": ['mw'],
    "piñjikā": ['mw'],
    "piñjotā": ['mw'],
    "piñjula": ['cae', 'mw'],
    "piñjā": ['mw'],
    "piñjāna": ['mw'],
    "piñjī": ['mw'],
    "piñjūla": ['cae', 'mw'],
    "piñjūlaka": ['mw'],
    "piñjūṣa": ['mw'],
    "piññāka": ['cped'],
    "piś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "piśa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "piśaṃga": ['ap90'],
    "piśaṃgakaḥ": ['ap90'],
    "piśaṃgilā": ['ap90'],
    "piśaṃgin": ['ap90'],
    "piśaṅga": ['cae', 'ddsa', 'gra', 'mw'],
    "piśaṅgabhṛṣṭi": ['gra', 'mw'],
    "piśaṅgajaṭa": ['mw'],
    "piśaṅgaka": ['mw'],
    "piśaṅgarāti": ['gra', 'mw'],
    "piśaṅgarūpa": ['gra', 'mw'],
    "piśaṅgasaṃdṛś": ['gra', 'mw'],
    "piśaṅgatva": ['mw'],
    "piśaṅgatā": ['mw'],
    "piśaṅgaya": ['mw'],
    "piśaṅgila": ['mw'],
    "piśaṅgita": ['mw'],
    "piśaṅgāśva": ['cae', 'gra', 'mw'],
    "piśaṅgīkṛ": ['mw'],
    "piśaṅka": ['mw'],
    "piśika": ['mw'],
    "piśita": ['cae', 'ddsa', 'mw'],
    "piśitabhuj": ['mw'],
    "piśitalocana": ['mw'],
    "piśitanibha": ['mw'],
    "piśitapaṅkāvanaddhāsthipañjaramaya": ['mw'],
    "piśitapiṇḍa": ['mw'],
    "piśitapraroha": ['mw'],
    "piśitaudana": ['mw'],
    "piśitavasāmaya": ['mw'],
    "piśitaṃ": ['ap90'],
    "piśitepsu": ['mw'],
    "piśitā": ['mw'],
    "piśitākāṅkṣin": ['mw'],
    "piśitāma": ['mw'],
    "piśitāsana": ['mw'],
    "piśitāśa": ['cae', 'mw'],
    "piśitāśana": ['cae', 'mw'],
    "piśitāśin": ['cae', 'mw'],
    "piśitāśā": ['mw'],
    "piśuna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "piśunatā": ['cae', 'mw'],
    "piśunavacana": ['mw'],
    "piśunavāda": ['mw'],
    "piśunavākya": ['mw'],
    "piśunay": ['cae'],
    "piśunaya": ['ddsa', 'mw'],
    "piśunayati": ['ap90'],
    "piśunita": ['mw'],
    "piśunā": ['mw'],
    "piśunī": ['mw'],
    "piśāca": ['cae', 'ddsa', 'mw'],
    "piśācabhikṣā": ['mw'],
    "piśācabhāṣya": ['mw'],
    "piśācabhāṣā": ['mw'],
    "piśācabādhā": ['mw'],
    "piśācacaryā": ['mw'],
    "piśācacātana": ['mw'],
    "piśācadakṣiṇā": ['mw'],
    "piśācadru": ['mw'],
    "piśācadīpikā": ['mw'],
    "piśācagṛhītaka": ['mw'],
    "piśācahan": ['mw'],
    "piśācajambhana": ['mw'],
    "piśācaka": ['cae', 'ddsa', 'mw'],
    "piśācakapura": ['mw'],
    "piśācakin": ['ap90', 'mw'],
    "piśācakālacakrayuddhavarṇana": ['mw'],
    "piśācakṣayaṇa": ['mw'],
    "piśācamocana": ['mw'],
    "piśācamocanakathana": ['mw'],
    "piśācamocanatīrtha": ['mw'],
    "piśācapati": ['mw'],
    "piśācasabha": ['mw'],
    "piśācasaṃcāra": ['mw'],
    "piśācatva": ['mw'],
    "piśācatā": ['mw'],
    "piśācavadana": ['mw'],
    "piśācaveda": ['mw'],
    "piśācavidyāveda": ['mw'],
    "piśācavṛkṣa": ['mw'],
    "piśācaśvan": ['mw'],
    "piśācaḥ": ['ap90'],
    "piśāci": ['cae', 'gra', 'mw'],
    "piśācikā": ['ap90', 'mw'],
    "piśācikī": ['mw'],
    "piśācinī": ['bhs'],
    "piśāciḥ": ['ap90'],
    "piśācodumbara": ['mw'],
    "piśācoragarākṣasa": ['mw'],
    "piśācā": ['mw'],
    "piśācālaya": ['mw'],
    "piśācāṅganā": ['cae', 'mw'],
    "piśācī": ['mw'],
    "piśācīkaraṇa": ['mw'],
    "piśī": ['mw'],
    "piśīla": ['cae', 'mw'],
    "piśīlamātra": ['mw'],
    "piśīlavīṇā": ['mw'],
    "piśīlaṃ": ['ap90'],
    "piśīlī": ['mw'],
    "piḍaka": ['cae', 'mw'],
    "piḍakaḥ": ['ap90'],
    "piḍakin": ['mw'],
    "piḍakā": ['ddsa'],
    "piḍakāvat": ['mw'],
    "piḥpala": ['mw'],
    "piḷakā": ['cped'],
    "piṁsana": ['cped'],
    "piṁsati": ['cped'],
    "piṁsetvā": ['cped'],
    "piṁsi": ['cped'],
    "piṁsita": ['cped'],
    "piṃcchaṃ": ['ap90'],
    "piṃga": ['ap90'],
    "piṃgala": ['ap90'],
    "piṃgalikā": ['ap90'],
    "piṃgalita": ['ap90'],
    "piṃgāśaḥ": ['ap90'],
    "piṃj": ['ap90'],
    "piṃja": ['ap90'],
    "piṃjala": ['ap90'],
    "piṃjanaṃ": ['ap90'],
    "piṃjara": ['ap90'],
    "piṃjarakaṃ": ['ap90'],
    "piṃjarita": ['ap90'],
    "piṃjaṭaḥ": ['ap90'],
    "piṃjeṭaḥ": ['ap90'],
    "piṃjikā": ['ap90'],
    "piṃjolā": ['ap90'],
    "piṃjulaṃ": ['ap90'],
    "piṃjālaṃ": ['ap90'],
    "piṃjūṣaḥ": ['ap90'],
    "piṃm, piṃṣ": ['ddsa'],
    "piṃs": ['ap90', 'mw'],
    "piṃś": ['cae', 'mw'],
    "piṃḍ": ['ap90'],
    "piṃḍa": ['ap90'],
    "piṃḍakaḥ": ['ap90'],
    "piṃḍalaḥ": ['ap90'],
    "piṃḍanaṃ": ['ap90'],
    "piṃḍasaḥ": ['ap90'],
    "piṃḍikā": ['ap90'],
    "piṃḍila": ['ap90'],
    "piṃḍin": ['ap90'],
    "piṃḍita": ['ap90'],
    "piṃḍiḥ": ['ap90'],
    "piṃḍoliḥ": ['ap90'],
    "piṃḍāraḥ": ['ap90'],
    "piṃḍātaḥ": ['ap90'],
    "piṃḍībhū": ['ap90'],
    "piṃḍīkṛ": ['ap90'],
    "piṃḍīra": ['ap90'],
    "piṃṣ": ['cae', 'mw'],
    "piṅga": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "piṅgacakṣus": ['mw'],
    "piṅgadanta": ['mw'],
    "piṅgadeha": ['mw'],
    "piṅgadṛś": ['mw'],
    "piṅgajaṭa": ['mw'],
    "piṅgakapiśā": ['mw'],
    "piṅgala": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "piṅgalabhāvoddyota": ['mw'],
    "piṅgalacchandaḥsūtra": ['mw'],
    "piṅgalacchandovṛtti": ['mw'],
    "piṅgalacchandovṛttivyākhyā": ['mw'],
    "piṅgalagāndhāra": ['mw'],
    "piṅgalajya": ['mw'],
    "piṅgalaka": ['cae', 'mw'],
    "piṅgalakāṇva": ['mw'],
    "piṅgalaloha": ['mw'],
    "piṅgalamakkhikā": ['cped'],
    "piṅgalamataprakāśa": ['mw'],
    "piṅgalanetta": ['cped'],
    "piṅgalanāga": ['mw'],
    "piṅgalapradīpa": ['mw'],
    "piṅgalaprakāśa": ['mw'],
    "piṅgalapraṇavopaniṣad": ['mw'],
    "piṅgalaroman": ['mw'],
    "piṅgalasāra": ['mw'],
    "piṅgalasāravikāśinī": ['mw'],
    "piṅgalasūtra": ['mw'],
    "piṅgalatattvaprakāśikā": ['mw'],
    "piṅgalatattvaprakāśinī": ['mw'],
    "piṅgalatva": ['mw'],
    "piṅgalavatsājīva": ['bhs', 'mw'],
    "piṅgalavārttika": ['mw'],
    "piṅgalavṛtti": ['mw'],
    "piṅgaleśvara": ['mw'],
    "piṅgaleśvaramāhātmya": ['mw'],
    "piṅgaleśvaratīrtha": ['mw'],
    "piṅgaleśvarī": ['mw'],
    "piṅgalikā": ['mw'],
    "piṅgaliman": ['cae', 'mw'],
    "piṅgalin": ['mw'],
    "piṅgalita": ['ddsa', 'mw'],
    "piṅgalocana": ['cae', 'mw'],
    "piṅgalā": ['bhs', 'mw'],
    "piṅgalākṣa": ['cae', 'mw'],
    "piṅgalāmata": ['mw'],
    "piṅgalāmṛta": ['mw'],
    "piṅgalārthadīpa": ['mw'],
    "piṅgalāryā": ['mw'],
    "piṅgalātantra": ['mw'],
    "piṅgalāyanī": ['bhs'],
    "piṅgamūla": ['mw'],
    "piṅgara": ['mw'],
    "piṅgasphaṭika": ['mw'],
    "piṅgasāra": ['mw'],
    "piṅgatīrtha": ['mw'],
    "piṅgavarṇavatī": ['mw'],
    "piṅgekṣaṇa": ['mw'],
    "piṅgeśa": ['mw'],
    "piṅgeśvara": ['mw'],
    "piṅgiman": ['mw'],
    "piṅgā": ['gra', 'mw'],
    "piṅgākṣa": ['cae', 'ddsa', 'mw'],
    "piṅgākṣī": ['mw'],
    "piṅgāsya": ['mw'],
    "piṅgāśa": ['mw'],
    "piṅgāśī": ['mw'],
    "piṅgī": ['mw'],
    "piṇyā": ['mw'],
    "piṇyāka": ['cae', 'ddsa', 'mw'],
    "piṇyākaḥ": ['ap90'],
    "piṇyākā": ['mw'],
    "piṇḍ": ['mw'],
    "piṇḍa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "piṇḍabhañjanaśānti": ['mw'],
    "piṇḍabhāj": ['cae', 'mw'],
    "piṇḍabhāktva": ['mw'],
    "piṇḍabhṛti": ['mw'],
    "piṇḍabīja": ['mw'],
    "piṇḍabījaka": ['mw'],
    "piṇḍacārika": ['bhs', 'cped'],
    "piṇḍada": ['cae', 'mw'],
    "piṇḍadā": ['mw'],
    "piṇḍadāna": ['cae', 'mw'],
    "piṇḍadātṛ": ['mw'],
    "piṇḍadāyaka": ['cped'],
    "piṇḍagosa": ['mw'],
    "piṇḍaharitāla": ['mw'],
    "piṇḍaka": ['cae', 'cped', 'mw'],
    "piṇḍakanda": ['mw'],
    "piṇḍakaraṇa": ['mw'],
    "piṇḍakayuddha": ['bhs'],
    "piṇḍakharjūra": ['cae', 'mw'],
    "piṇḍakā": ['bhs'],
    "piṇḍala": ['mw'],
    "piṇḍalakṣaṇa": ['mw'],
    "piṇḍalepa": ['mw'],
    "piṇḍalopa": ['mw'],
    "piṇḍamaya": ['cae', 'mw'],
    "piṇḍamustā": ['mw'],
    "piṇḍamātropajīvin": ['mw'],
    "piṇḍamūla": ['mw'],
    "piṇḍamūlaka": ['mw'],
    "piṇḍana": ['mw'],
    "piṇḍanidhāna": ['mw'],
    "piṇḍanirvapana": ['cae'],
    "piṇḍanirvapaṇa": ['mw'],
    "piṇḍaniryukti": ['mw'],
    "piṇḍanivṛtti": ['mw'],
    "piṇḍapada": ['mw'],
    "piṇḍaphala": ['mw'],
    "piṇḍaphalā": ['mw'],
    "piṇḍapitṛyajña": ['cae', 'mw'],
    "piṇḍapitṛyajñaprayoga": ['mw'],
    "piṇḍaprada": ['mw'],
    "piṇḍapuṣpa": ['mw'],
    "piṇḍapuṣpaka": ['mw'],
    "piṇḍapāda": ['mw'],
    "piṇḍapādya": ['mw'],
    "piṇḍapāta": ['bhs', 'cae', 'cped', 'mw'],
    "piṇḍapātavelā": ['mw'],
    "piṇḍapātika": ['bhs', 'cped', 'mw'],
    "piṇḍapātra": ['mw'],
    "piṇḍapātranirhāraka": ['mw'],
    "piṇḍaraka": ['mw'],
    "piṇḍarohiṇika": ['mw'],
    "piṇḍasambandha": ['mw'],
    "piṇḍasambandhin": ['mw'],
    "piṇḍasektṛ": ['mw'],
    "piṇḍastha": ['mw'],
    "piṇḍasveda": ['mw'],
    "piṇḍataila": ['mw'],
    "piṇḍatailaka": ['mw'],
    "piṇḍatarkaka": ['mw'],
    "piṇḍatas": ['mw'],
    "piṇḍatva": ['mw'],
    "piṇḍatā": ['mw'],
    "piṇḍavaṃśa": ['bhs'],
    "piṇḍaveṇu": ['bhs', 'mw'],
    "piṇḍaviśuddhidīpikā": ['mw'],
    "piṇḍay": ['cae'],
    "piṇḍaya": ['ddsa', 'mw'],
    "piṇḍayajña": ['ddsa', 'mw'],
    "piṇḍayati": ['mw'],
    "piṇḍaśa": ['mw'],
    "piṇḍaśarkarā": ['mw'],
    "piṇḍaśikṣā": ['mw'],
    "piṇḍaśīrṣa": ['mw'],
    "piṇḍesi": ['cped'],
    "piṇḍeti": ['cped'],
    "piṇḍetvā": ['cped'],
    "piṇḍi": ['mw'],
    "piṇḍika": ['mw'],
    "piṇḍikamaṁsa": ['cped'],
    "piṇḍikā": ['bhs', 'ddsa', 'mw'],
    "piṇḍila": ['mw'],
    "piṇḍilā": ['mw'],
    "piṇḍin": ['mw'],
    "piṇḍinī": ['mw'],
    "piṇḍipāla": ['mw'],
    "piṇḍita": ['bhs', 'cped', 'mw'],
    "piṇḍitadruma": ['mw'],
    "piṇḍitailika": ['mw'],
    "piṇḍitamūlya": ['mw'],
    "piṇḍitasneha": ['mw'],
    "piṇḍitārtha": ['cae', 'mw'],
    "piṇḍiyālopabhojana": ['cped'],
    "piṇḍodakakriyā": ['mw'],
    "piṇḍoddharaṇa": ['mw'],
    "piṇḍoddāna": ['bhs'],
    "piṇḍola": ['mw'],
    "piṇḍolabharadvāja": ['bhs'],
    "piṇḍolakapila": ['bhs'],
    "piṇḍoli": ['mw'],
    "piṇḍolikā": ['mw'],
    "piṇḍolya": ['cped'],
    "piṇḍopadhāna": ['bhs'],
    "piṇḍopajīvin": ['ddsa', 'mw'],
    "piṇḍopaniṣad": ['cae', 'mw'],
    "piṇḍā": ['mw'],
    "piṇḍābhra": ['mw'],
    "piṇḍācāra": ['cped'],
    "piṇḍāgra": ['cae', 'mw'],
    "piṇḍāhvā": ['mw'],
    "piṇḍākṣara": ['mw'],
    "piṇḍālaktaka": ['cae', 'mw'],
    "piṇḍālu": ['bhs', 'mw'],
    "piṇḍāluka": ['mw'],
    "piṇḍālūka": ['mw'],
    "piṇḍānvāhārya": ['mw'],
    "piṇḍānvāhāryaka": ['cae', 'mw'],
    "piṇḍāra": ['cae', 'mw'],
    "piṇḍāraka": ['bhs', 'cae', 'mw'],
    "piṇḍārtha": ['bhs'],
    "piṇḍāta": ['mw'],
    "piṇḍāya": ['cped'],
    "piṇḍāyasa": ['mw'],
    "piṇḍāśa": ['mw'],
    "piṇḍāśaka": ['mw'],
    "piṇḍāśin": ['mw'],
    "piṇḍāśma": ['mw'],
    "piṇḍī": ['bhs', 'cped', 'ddsa', 'mw'],
    "piṇḍībhāva": ['mw'],
    "piṇḍībhū": ['mw'],
    "piṇḍībhūta": ['mw'],
    "piṇḍījaṅgha": ['mw'],
    "piṇḍīkaraṇa": ['ddsa', 'mw'],
    "piṇḍīkhaṇḍa": ['mw'],
    "piṇḍīkṛ": ['cae', 'mw'],
    "piṇḍīkṛta": ['mw'],
    "piṇḍīlepa": ['mw'],
    "piṇḍīpuṣpa": ['mw'],
    "piṇḍīra": ['mw'],
    "piṇḍītagara": ['mw'],
    "piṇḍītagaraka": ['mw'],
    "piṇḍītaka": ['mw'],
    "piṇḍītaru": ['mw'],
    "piṇḍīśūra": ['mw'],
    "piṇḍūṣa": ['mw'],
    "piṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "piṣpala": ['mw'],
    "piṣyala": ['mw'],
    "piṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "piṣṭabhuj": ['mw'],
    "piṣṭabhājana": ['mw'],
    "piṣṭaja": ['mw'],
    "piṣṭaka": ['bhs', 'cae', 'mw'],
    "piṣṭakasaṃkrānti": ['mw'],
    "piṣṭakaḥ": ['ap90'],
    "piṣṭalepa": ['mw'],
    "piṣṭamaya": ['cae', 'mw'],
    "piṣṭameha": ['mw'],
    "piṣṭamehin": ['mw'],
    "piṣṭapa": ['cae', 'ddsa', 'mw'],
    "piṣṭapacana": ['ddsa', 'mw'],
    "piṣṭapaśu": ['cae', 'mw'],
    "piṣṭapaśukhaṇḍanamīmāṃsā": ['mw'],
    "piṣṭapaśunirṇaya": ['mw'],
    "piṣṭapaśusaraṇi": ['mw'],
    "piṣṭapaśusādhakagrantha": ['mw'],
    "piṣṭapaśutiraskariṇī": ['mw'],
    "piṣṭapaḥ": ['ap90'],
    "piṣṭapeṣa": ['mw'],
    "piṣṭapeṣaṇa": ['mw'],
    "piṣṭapeṣaṇanyāya": ['mw'],
    "piṣṭapiṇḍa": ['mw'],
    "piṣṭapācaka": ['mw'],
    "piṣṭapācanika": ['bhs'],
    "piṣṭapāka": ['mw'],
    "piṣṭapākabhṛt": ['mw'],
    "piṣṭapātrī": ['mw'],
    "piṣṭapūra": ['mw'],
    "piṣṭarasa": ['mw'],
    "piṣṭarātryāḥkalpa": ['mw'],
    "piṣṭarātrī": ['mw'],
    "piṣṭasaurabha": ['mw'],
    "piṣṭasaṃyavana": ['mw'],
    "piṣṭasvedam": ['mw'],
    "piṣṭauṇḍī": ['mw'],
    "piṣṭavarti": ['mw'],
    "piṣṭi": ['cae', 'mw'],
    "piṣṭika": ['mw'],
    "piṣṭikaṃ": ['ap90'],
    "piṣṭikā": ['mw'],
    "piṣṭodaka": ['cae', 'mw'],
    "piṣṭodvapanī": ['mw'],
    "piṣṭāda": ['mw'],
    "piṣṭānna": ['cae', 'mw'],
    "piṣṭānnadāna": ['mw'],
    "piṣṭāpaḥ": ['ap90'],
    "piṣṭāta": ['cae', 'mw'],
    "piṣṭātaka": ['cae', 'ddsa', 'mw'],
    "piṣṭī": ['mw'],
    "piṣṭīkṛ": ['mw'],
    "piṣṭīrasa": ['mw'],
    "piṭ": ['ap90', 'mw'],
    "piṭa": ['bhs', 'ddsa', 'mw'],
    "piṭaka": ['bhs', 'cae', 'cped', 'mw'],
    "piṭakadhara": ['cped'],
    "piṭakattaya": ['cped'],
    "piṭakaḥ": ['ap90'],
    "piṭakyā": ['ap90', 'mw'],
    "piṭakīya": ['bhs'],
    "piṭaḥ": ['ap90'],
    "piṭaṅkokī": ['mw'],
    "piṭaṅkākī": ['mw'],
    "piṭaṅkāśa": ['mw'],
    "piṭh": ['ap90', 'mw'],
    "piṭha": ['mw'],
    "piṭhaka": ['bhs', 'mw'],
    "piṭhana": ['mw'],
    "piṭhara": ['cae', 'cped', 'ddsa', 'mw'],
    "piṭharaka": ['cae', 'mw'],
    "piṭharakakapāla": ['mw'],
    "piṭharakaḥ": ['ap90'],
    "piṭharapāka": ['mw'],
    "piṭharaḥ": ['ap90'],
    "piṭharikā": ['bhs'],
    "piṭhaḥ": ['ap90'],
    "piṭhīnas": ['cae', 'gra', 'mw'],
    "piṭākaḥ": ['ap90'],
    "piṭākyā": ['mw'],
    "piṭṭaka": ['bhs', 'mw'],
    "piṭṭakaṃ": ['ap90'],
    "piṭṭakā": ['bhs'],
    "piṭṭaya": ['ddsa', 'mw'],
    "piṭṭha": ['cped'],
    "piṭṭhadhītalikā": ['cped'],
    "piṭṭhakhādaniya": ['cped'],
    "piṭṭhapiṇḍī": ['cped'],
    "piṭṭhi": ['cped'],
    "piṭṭhigata": ['cped'],
    "piṭṭhikaṇṭaka": ['cped'],
    "piṭṭhimaṁsika": ['cped'],
    "piṭṭhipassa": ['cped'],
    "piṭṭhipāsāṇa": ['cped'],
    "piṭṭhivaṁsa": ['cped'],
    "piṭṭita": ['mw'],
    "plab": ['mw'],
    "plaka": ['gra', 'mw'],
    "plakaḥ": ['ap90'],
    "plakṣ": ['ap90', 'mw'],
    "plakṣa": ['cae', 'ddsa', 'mw'],
    "plakṣadvīpa": ['mw'],
    "plakṣagā": ['mw'],
    "plakṣajātā": ['mw'],
    "plakṣakīya": ['mw'],
    "plakṣanyagrodha": ['mw'],
    "plakṣapraroha": ['mw'],
    "plakṣaprasravaṇa": ['mw'],
    "plakṣar": ['mw'],
    "plakṣarāj": ['mw'],
    "plakṣarāja": ['mw'],
    "plakṣasamudbhavā": ['mw'],
    "plakṣasamudravācakā": ['mw'],
    "plakṣasravaṇa": ['mw'],
    "plakṣatva": ['mw'],
    "plakṣatīrtha": ['mw'],
    "plakṣavat": ['mw'],
    "plakṣavatī": ['mw'],
    "plakṣaśākhā": ['mw'],
    "plakṣaśākhāvat": ['mw'],
    "plakṣaḥ": ['ap90'],
    "plakṣodumbara": ['mw'],
    "plakṣā": ['mw'],
    "plakṣāvataraṇa": ['mw'],
    "plati": ['cae', 'gra', 'mw'],
    "plav": ['mw'],
    "plava": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "plavaga": ['cae', 'mw'],
    "plavagati": ['mw'],
    "plavagendra": ['mw'],
    "plavagā": ['mw'],
    "plavaka": ['mw'],
    "plavakaḥ": ['ap90'],
    "plavana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "plavati": ['cped'],
    "plavatva": ['mw'],
    "plavavat": ['ddsa', 'mw'],
    "plavaṃga": ['cae', 'mw'],
    "plavaṃgama": ['mw'],
    "plavaṃgamaḥ": ['ap90'],
    "plavaṃgamendu": ['mw'],
    "plavaṃgamā": ['mw'],
    "plavaṃgaḥ": ['ap90'],
    "plavaṅga": ['ddsa'],
    "plavaṅgama": ['cped'],
    "plavi": ['cped'],
    "plavika": ['ap90', 'mw'],
    "plavita": ['bhs', 'cped', 'ddsa', 'mw'],
    "plavitvā": ['cped'],
    "plavitṛ": ['cae', 'mw'],
    "plavākā": ['ap90', 'mw'],
    "playoga": ['mw'],
    "plev": ['ap90', 'mw'],
    "pleṅkha": ['cae', 'ddsa', 'mw'],
    "plih": ['ap90', 'mw'],
    "plihan": ['cae', 'ddsa', 'mw'],
    "plok": ['mw'],
    "plota": ['cae', 'ddsa', 'mw'],
    "plotaḥ": ['ap90'],
    "ploti": ['bhs', 'mw'],
    "plotikā": ['bhs'],
    "ploṣa": ['cae', 'ddsa', 'mw'],
    "ploṣaḥ": ['ap90'],
    "ploṣaṇa": ['ap90', 'cae', 'mw'],
    "ploṣin": ['cae', 'mw'],
    "ploṣṭa": ['bhs'],
    "ploṣṭṛ": ['mw'],
    "plu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "plugi": ['mw'],
    "plukṣi": ['mw'],
    "plukṣiḥ": ['ap90'],
    "plus": ['ap90', 'mw'],
    "pluta": ['ap90', 'cae', 'ddsa', 'mw'],
    "plutagati": ['mw'],
    "plutameru": ['mw'],
    "plutatva": ['mw'],
    "plutavat": ['mw'],
    "pluti": ['cae', 'ddsa', 'mw'],
    "plutiḥ": ['ap90'],
    "pluṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pluṣaḥ": ['ap90'],
    "pluṣi": ['cae', 'gra', 'mw'],
    "pluṣṭa": ['ap90', 'mw'],
    "pluṣṭāya": ['mw'],
    "plākṣa": ['cae', 'ddsa', 'mw'],
    "plākṣaki": ['mw'],
    "plākṣaṃ": ['ap90'],
    "plākṣi": ['mw'],
    "plākṣāyaṇa": ['mw'],
    "plākṣī": ['mw'],
    "plāta": ['ddsa', 'mw'],
    "plāva": ['cae', 'ddsa', 'mw'],
    "plāvana": ['cae', 'mw'],
    "plāvanaṃ": ['ap90'],
    "plāvayitṛ": ['mw'],
    "plāvaḥ": ['ap90'],
    "plāvin": ['ap90', 'cae', 'mw'],
    "plāvita": ['ap90', 'mw'],
    "plāvya": ['mw'],
    "plāvīkṛta": ['bhs'],
    "plāy": ['mw'],
    "plāya": ['ddsa', 'mw'],
    "plāyogi": ['gra', 'mw'],
    "plāśi": ['cae', 'ddsa', 'gra', 'mw'],
    "plāśucit": ['mw'],
    "plāśuka": ['cae', 'ddsa', 'mw'],
    "plī": ['ap90', 'mw'],
    "plīha": ['bhs', 'mw'],
    "plīhaghna": ['mw'],
    "plīhaka": ['bhs'],
    "plīhakānanda": ['bhs'],
    "plīhan": ['ap90', 'cae', 'ddsa', 'mw'],
    "plīhapuṣā": ['mw'],
    "plīhaśatru": ['mw'],
    "plīhodara": ['mw'],
    "plīhodarin": ['mw'],
    "plīhā": ['ap90', 'ddsa', 'mw'],
    "plīhāhantrī": ['mw'],
    "plīhākarṇa": ['mw'],
    "plīhāri": ['mw'],
    "plīhāśatru": ['mw'],
    "plīthā": ['mw'],
    "po": ['ap90', 'mw'],
    "pogaṃḍa": ['ap90'],
    "pogaṇḍa": ['ddsa', 'mw'],
    "pohala": ['bhs'],
    "pokkhara": ['cped'],
    "pokkharamadhu": ['cped'],
    "pokkharapatta": ['cped'],
    "pokkharatā": ['cped'],
    "pokkharavassa": ['cped'],
    "pokkharaṇī": ['cped'],
    "pola": ['mw'],
    "polaḥ": ['ap90'],
    "polikā": ['ap90', 'cae', 'mw'],
    "polinda": ['mw'],
    "poliṃdaḥ": ['ap90'],
    "polī": ['mw'],
    "poma": ['bhs'],
    "ponaka": ['mw'],
    "ponnūrusthalamāhātmya": ['mw'],
    "ponobbhavika": ['cped'],
    "ponobhavika": ['cped'],
    "pontī": ['bhs'],
    "popphala": ['bhs'],
    "popuva": ['mw'],
    "pora": ['mw'],
    "poraka": ['mw'],
    "porisa": ['cped'],
    "porisāda": ['cped'],
    "porohicca": ['cped'],
    "porāṇa": ['cped'],
    "porāṇaka": ['cped'],
    "porī": ['cped'],
    "posa": ['cped'],
    "posaka": ['cped'],
    "posana": ['cped'],
    "posatha": ['bhs', 'cped'],
    "posathika": ['cped'],
    "posenta": ['cped'],
    "posesi": ['cped'],
    "posetabba": ['cped'],
    "poseti": ['cped'],
    "posetuṁ": ['cped'],
    "posetvā": ['cped'],
    "posikā": ['cped'],
    "posita": ['cped'],
    "posāvanika": ['cped'],
    "pota": ['cae', 'cped', 'ddsa', 'mw'],
    "potabaṇij": ['mw'],
    "potabhaṅga": ['cae', 'mw'],
    "potadhāra": ['mw'],
    "potadhārin": ['mw'],
    "potaja": ['mw'],
    "potaka": ['cae', 'cped', 'mw'],
    "potakaḥ": ['ap90'],
    "potakī": ['mw'],
    "potala": ['mw'],
    "potalaka": ['bhs', 'mw'],
    "potalakapriya": ['mw'],
    "potalikā": ['mw'],
    "potana": ['ap90', 'bhs', 'mw'],
    "potaplava": ['cae', 'ddsa', 'mw'],
    "potaraka": ['mw'],
    "potarakṣa": ['mw'],
    "potatva": ['mw'],
    "potavaṇij": ['cae', 'mw'],
    "potavāha": ['cped', 'mw'],
    "potavāhaka": ['mw'],
    "potaśāli": ['mw'],
    "potaḥ": ['ap90'],
    "potha": ['cae', 'ddsa', 'mw'],
    "pothaki": ['mw'],
    "pothakī": ['ap90', 'mw'],
    "pothikā": ['mw'],
    "pothita": ['mw'],
    "pothujjanika": ['cped'],
    "potika": ['cped'],
    "potikā": ['ddsa', 'mw'],
    "potimatsaka": ['mw'],
    "potra": ['cae', 'ddsa', 'gra', 'mw'],
    "potramaṇḍala": ['mw'],
    "potraṃ": ['ap90'],
    "potri": ['mw'],
    "potridaṃṣṭrāja": ['mw'],
    "potrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "potrirathā": ['mw'],
    "potrāyudha": ['mw'],
    "potrī": ['mw'],
    "potrīya": ['cae', 'ddsa', 'mw'],
    "potthaka": ['cped'],
    "potthalikā": ['cped'],
    "potthanikā": ['cped'],
    "potu": ['mw'],
    "potyā": ['ap90', 'mw'],
    "potābha": ['mw'],
    "potācchādana": ['mw'],
    "potādhāna": ['mw'],
    "potāla": ['mw'],
    "potāra": ['bhs'],
    "potāsa": ['ddsa', 'mw'],
    "potāsaḥ": ['ap90'],
    "potāya": ['mw'],
    "potṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "potṛprayoga": ['mw'],
    "potṛtvaprayoga": ['mw'],
    "poviya": ['mw'],
    "poyā": ['cae', 'mw'],
    "poyāladaha": ['mw'],
    "poñch": ['mw'],
    "poñchate": ['bhs'],
    "poḍu": ['mw'],
    "poḍuḥ": ['ap90'],
    "poṅkha": ['cped'],
    "poṇa": ['bhs', 'cped'],
    "poṇika": ['bhs'],
    "poṣa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "poṣadha": ['bhs', 'mw'],
    "poṣadheya": ['bhs', 'mw'],
    "poṣadhika": ['bhs', 'mw'],
    "poṣadhin": ['bhs'],
    "poṣadhotsava": ['mw'],
    "poṣadhoṣita": ['mw'],
    "poṣaka": ['cae', 'ddsa', 'mw'],
    "poṣakaḥ": ['ap90'],
    "poṣam": ['mw'],
    "poṣas": ['gra', 'mw'],
    "poṣayitnu": ['cae', 'gra', 'mw'],
    "poṣayitnuḥ": ['ap90'],
    "poṣayitṛ": ['mw'],
    "poṣayiṣṇu": ['cae', 'mw'],
    "poṣaḥ": ['ap90'],
    "poṣaṇa": ['cae', 'mw'],
    "poṣaṇakara": ['cae'],
    "poṣaṇaṃ": ['ap90'],
    "poṣaṇīya": ['cae', 'mw'],
    "poṣia": ['gra'],
    "poṣin": ['ap90', 'cae', 'gra', 'mw'],
    "poṣita": ['ap90', 'mw'],
    "poṣitavya": ['mw'],
    "poṣitṛ": ['ap90', 'cae', 'mw'],
    "poṣiāvat": ['gra'],
    "poṣuka": ['cae', 'mw'],
    "poṣya": ['ap90', 'cae', 'gra', 'mw'],
    "poṣyaputra": ['mw'],
    "poṣyaputraka": ['mw'],
    "poṣyaputrakaraṇa": ['mw'],
    "poṣyavarga": ['mw'],
    "poṣyāvant": ['cae'],
    "poṣyāvat": ['gra', 'mw'],
    "poṣṭṛ": ['cae', 'mw'],
    "poṣṭṛvara": ['mw'],
    "poṭa": ['mw'],
    "poṭagala": ['mw'],
    "poṭaka": ['cae', 'mw'],
    "poṭakaḥ": ['ap90'],
    "poṭala": ['cae', 'mw'],
    "poṭalaka": ['cae', 'mw'],
    "poṭalikā": ['mw'],
    "poṭaḥ": ['ap90'],
    "poṭhana": ['cped'],
    "poṭhesi": ['cped'],
    "poṭheti": ['cped'],
    "poṭhetvā": ['cped'],
    "poṭhita": ['cped'],
    "poṭhiyamāna": ['cped'],
    "poṭhīyati": ['cped'],
    "poṭika": ['mw'],
    "poṭikaḥ": ['ap90'],
    "poṭikā": ['mw'],
    "poṭā": ['ap90', 'mw'],
    "poṭāya": ['mw'],
    "poṭī": ['ap90', 'cae', 'ddsa', 'mw'],
    "poṭṭala": ['mw'],
    "poṭṭalaka": ['mw'],
    "poṭṭalikā": ['ap90', 'bhs'],
    "poṭṭalī": ['mw'],
    "poṭṭalīkṛ": ['mw'],
    "poṭṭhapāda": ['cped'],
    "poṭṭila": ['mw'],
    "pra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prababhra": ['mw'],
    "prababhraḥ": ['ap90'],
    "prabaddha": ['ap90', 'cae', 'mw'],
    "prabaddhamūtra": ['mw'],
    "prabaddhavilūna": ['mw'],
    "prabahlikā": ['ap90', 'mw'],
    "prabala": ['ap90', 'cae', 'mw'],
    "prabalam": ['mw'],
    "prabalanatā": ['mw'],
    "prabalanirṇayavyākhyā": ['mw'],
    "prabalarudita": ['mw'],
    "prabalatara": ['mw'],
    "prabalati": ['ap90'],
    "prabalatoya": ['mw'],
    "prabalatva": ['mw'],
    "prabalatā": ['mw'],
    "prabalavat": ['mw'],
    "prabalavirasā": ['mw'],
    "prabalaya": ['mw'],
    "prabalā": ['mw'],
    "prabalī": ['mw'],
    "prabalībhū": ['mw'],
    "prabanddhṛ": ['cae', 'ddsa', 'mw'],
    "prabanddhṛtā": ['mw'],
    "prabandh": ['mw'],
    "prabandha": ['bhs', 'cae', 'mw'],
    "prabandhacintāmaṇi": ['mw'],
    "prabandhakalpanā": ['mw'],
    "prabandhakośa": ['mw'],
    "prabandhana": ['mw'],
    "prabandhavarṣa": ['mw'],
    "prabandhādhyāya": ['mw'],
    "prabandhārtha": ['mw'],
    "prabarha": ['ap90', 'mw'],
    "prabarham": ['mw'],
    "prabarhaṇa": ['mw'],
    "prabaṃddhṛ": ['ap90'],
    "prabaṃdh": ['ap90'],
    "prabaṃdhanaṃ": ['ap90'],
    "prabaṃdhaḥ": ['ap90'],
    "prabha": ['bhs'],
    "prabhadra": ['mw'],
    "prabhadraka": ['mw'],
    "prabhadraḥ": ['ap90'],
    "prabhadrikā": ['bhs'],
    "prabhadrā": ['mw'],
    "prabhagna": ['mw'],
    "prabhaj": ['mw'],
    "prabhakara": ['bhs'],
    "prabhaketurājamati": ['bhs'],
    "prabhaketuśirī": ['bhs'],
    "prabharman": ['cae', 'gra', 'mw'],
    "prabhartavya": ['mw'],
    "prabhartṛ": ['cae', 'mw'],
    "prabhava": ['ap90', 'cae', 'gra', 'mw'],
    "prabhavana": ['mw'],
    "prabhavanaṃ": ['ap90'],
    "prabhavanīya": ['mw'],
    "prabhavaprabhu": ['mw'],
    "prabhavasvāmin": ['mw'],
    "prabhavat": ['mw'],
    "prabhavitṛ": ['ap90', 'cae', 'mw'],
    "prabhaviṣṇu": ['ap90', 'cae', 'mw'],
    "prabhaviṣṇutā": ['mw'],
    "prabhavya": ['mw'],
    "prabhayanti": ['bhs'],
    "prabhañj": ['mw'],
    "prabhañjaka": ['bhs'],
    "prabhañjana": ['bhs', 'cae', 'mw'],
    "prabhaṃgaḥ": ['ap90'],
    "prabhaṃj": ['ap90'],
    "prabhaṃjanaṃ": ['ap90'],
    "prabhaṃkara": ['bhs'],
    "prabhaṅga": ['cae', 'ddsa', 'gra', 'mw'],
    "prabhaṅgin": ['cae', 'gra', 'mw'],
    "prabhaṅgura": ['bhs', 'mw'],
    "prabhaṣati": ['bhs'],
    "prabheda": ['bhs', 'cae', 'ddsa', 'mw'],
    "prabhedaka": ['ap90', 'cae', 'mw'],
    "prabhedana": ['cae', 'mw'],
    "prabhedatā": ['bhs'],
    "prabhedaḥ": ['ap90'],
    "prabhemi": ['bhs'],
    "prabheśvaratīrtha": ['mw'],
    "prabhid": ['ap90', 'mw'],
    "prabhinna": ['ap90', 'bhs', 'ddsa', 'mw'],
    "prabhinnakaraṭa": ['mw'],
    "prabhinnakaraṭāmukha": ['mw'],
    "prabhinnaviṣ": ['mw'],
    "prabhinnāñjana": ['mw'],
    "prabhram": ['mw'],
    "prabhraṃś": ['ap90', 'mw'],
    "prabhraṃśa": ['mw'],
    "prabhraṃśana": ['mw'],
    "prabhraṃśathu": ['mw'],
    "prabhraṃśathuḥ": ['ap90'],
    "prabhraṃśaḥ": ['ap90'],
    "prabhraṃśin": ['ap90', 'mw'],
    "prabhraṃśita": ['ap90', 'mw'],
    "prabhraṃśuka": ['mw'],
    "prabhraṣṭa": ['ap90', 'cae', 'mw'],
    "prabhraṣṭaka": ['cae', 'mw'],
    "prabhraṣṭakaṃ": ['ap90'],
    "prabhraṣṭaśīla": ['mw'],
    "prabhrāj": ['mw'],
    "prabhu": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "prabhubhakta": ['mw'],
    "prabhubhakti": ['mw'],
    "prabhudeva": ['mw'],
    "prabhudevī": ['mw'],
    "prabhugna": ['mw'],
    "prabhuj": ['mw'],
    "prabhukathā": ['mw'],
    "prabhukta": ['mw'],
    "prabhuliṅgacaritra": ['mw'],
    "prabhuliṅgalīlā": ['mw'],
    "prabhutva": ['mw'],
    "prabhutvabodhi": ['mw'],
    "prabhutvākṣepa": ['mw'],
    "prabhutā": ['ap90', 'cae', 'mw'],
    "prabhuvaṃśa": ['mw'],
    "prabhuvidehakarṇa": ['bhs'],
    "prabhuśabdaśeṣa": ['mw'],
    "prabhvī": ['mw'],
    "prabhā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "prabhācandra": ['mw'],
    "prabhāga": ['mw'],
    "prabhāgajāti": ['mw'],
    "prabhāgatā": ['bhs'],
    "prabhāgaḥ": ['ap90'],
    "prabhāj": ['mw'],
    "prabhākara": ['bhs', 'cae', 'mw'],
    "prabhākarakīrti": ['bhs'],
    "prabhākarapariccheda": ['mw'],
    "prabhākarasiddhi": ['bhs', 'mw'],
    "prabhākarasvāmin": ['mw'],
    "prabhākaravardhana": ['mw'],
    "prabhākaravarman": ['mw'],
    "prabhākarāhnika": ['mw'],
    "prabhākarāhnikī": ['mw'],
    "prabhākarī": ['bhs'],
    "prabhāketu": ['bhs'],
    "prabhāketuśrī": ['bhs'],
    "prabhākīṭa": ['mw'],
    "prabhālepin": ['mw'],
    "prabhālocana": ['mw'],
    "prabhāmaya": ['cae', 'mw'],
    "prabhāmaṇḍala": ['cae', 'mw'],
    "prabhāmaṇḍalaka": ['cae', 'mw'],
    "prabhāmaṇḍalaśobhin": ['mw'],
    "prabhāna": ['mw'],
    "prabhānanā": ['mw'],
    "prabhānaṃ": ['ap90'],
    "prabhānu": ['mw'],
    "prabhānīya": ['mw'],
    "prabhāpadaśakti": ['mw'],
    "prabhāpallavita": ['mw'],
    "prabhāpana": ['mw'],
    "prabhāpanīya": ['mw'],
    "prabhāpraroha": ['mw'],
    "prabhāpāla": ['mw'],
    "prabhāraka": ['mw'],
    "prabhās": ['ap90', 'mw'],
    "prabhāsa": ['cae', 'mw'],
    "prabhāsadeśa": ['mw'],
    "prabhāsakhaṇḍa": ['mw'],
    "prabhāsakṣetra": ['mw'],
    "prabhāsakṣetramāhātmya": ['mw'],
    "prabhāsakṣetratīrtha": ['mw'],
    "prabhāsakṣetratīrthayātrānukrama": ['mw'],
    "prabhāsana": ['cae', 'mw'],
    "prabhāsanaṃ": ['ap90'],
    "prabhāsaśrī": ['bhs'],
    "prabhāsaḥ": ['ap90'],
    "prabhāseśvaramāhātmya": ['mw'],
    "prabhāsura": ['cae', 'mw'],
    "prabhāsvant": ['cae'],
    "prabhāsvara": ['ap90', 'bhs', 'cae', 'mw'],
    "prabhāsvarā": ['mw'],
    "prabhāsvat": ['mw'],
    "prabhāta": ['ap90', 'bhs', 'cae', 'mw'],
    "prabhātakalpa": ['cae', 'mw'],
    "prabhātakaraṇīya": ['cae', 'mw'],
    "prabhātakāla": ['mw'],
    "prabhātaprāya": ['mw'],
    "prabhātarala": ['mw'],
    "prabhātasamaya": ['mw'],
    "prabhātā": ['mw'],
    "prabhātīrtha": ['mw'],
    "prabhāva": ['cae', 'mw'],
    "prabhāvaja": ['mw'],
    "prabhāvaka": ['ap90', 'mw'],
    "prabhāvalī": ['mw'],
    "prabhāvana": ['mw'],
    "prabhāvant": ['cae'],
    "prabhāvanā": ['ap90', 'mw'],
    "prabhāvat": ['ap90', 'mw'],
    "prabhāvatas": ['mw'],
    "prabhāvatpariṇaya": ['mw'],
    "prabhāvatva": ['mw'],
    "prabhāvatī": ['bhs', 'mw'],
    "prabhāvavat": ['ap90', 'mw'],
    "prabhāvaya": ['mw'],
    "prabhāvayitṛ": ['mw'],
    "prabhāvaḥ": ['ap90'],
    "prabhāveṇa": ['mw'],
    "prabhāvin": ['mw'],
    "prabhāvita": ['mw'],
    "prabhāvyūha": ['bhs', 'mw'],
    "prabhāvāt": ['mw'],
    "prabhāñjana": ['mw'],
    "prabhāśrī": ['bhs'],
    "prabhāṃkara": ['bhs'],
    "prabhāṣ": ['ap90', 'mw'],
    "prabhāṣa": ['mw'],
    "prabhāṣaṇa": ['mw'],
    "prabhāṣaṇaṃ": ['ap90'],
    "prabhāṣaṇīya": ['mw'],
    "prabhāṣin": ['mw'],
    "prabhāṣita": ['cae', 'mw'],
    "prabhī": ['mw'],
    "prabhīta": ['cae', 'mw'],
    "prabhū": ['ap90', 'ddsa', 'mw'],
    "prabhūta": ['ap90', 'cae', 'mw'],
    "prabhūtabhrānta": ['mw'],
    "prabhūtadhanadhānyavat": ['mw'],
    "prabhūtadhanaskandha": ['bhs'],
    "prabhūtajihva": ['bhs'],
    "prabhūtajihvatā": ['mw'],
    "prabhūtaka": ['mw'],
    "prabhūtanāgāśvaratha": ['mw'],
    "prabhūtaratna": ['bhs', 'mw'],
    "prabhūtarūpa": ['mw'],
    "prabhūtataraka": ['bhs'],
    "prabhūtatva": ['mw'],
    "prabhūtatā": ['ap90', 'cae', 'mw'],
    "prabhūtavarṇa": ['bhs'],
    "prabhūtavarṣa": ['mw'],
    "prabhūtavayas": ['mw'],
    "prabhūtayavasendhana": ['mw'],
    "prabhūtaśas": ['mw'],
    "prabhūti": ['bhs', 'cae', 'gra', 'mw'],
    "prabhūtiḥ": ['ap90'],
    "prabhūtotka": ['mw'],
    "prabhūtva": ['mw'],
    "prabhūtā": ['bhs'],
    "prabhūvarī": ['mw'],
    "prabhūvasu": ['gra', 'mw'],
    "prabhūṣ": ['mw'],
    "prabhūṣan": ['gra'],
    "prabhūṣṇu": ['ap90', 'mw'],
    "prabhṛ": ['mw'],
    "prabhṛta": ['mw'],
    "prabhṛtha": ['cae', 'ddsa', 'gra', 'mw'],
    "prabhṛti": ['cae', 'ddsa', 'gra', 'mw'],
    "prabhṛtiḥ": ['ap90'],
    "prabodha": ['cae', 'ddsa', 'mw'],
    "prabodhacandra": ['cae', 'mw'],
    "prabodhacandrikā": ['mw'],
    "prabodhacandrodaya": ['mw'],
    "prabodhacandrodayasaṃgraha": ['mw'],
    "prabodhacandrodayāmalaka": ['mw'],
    "prabodhacintāmaṇi": ['mw'],
    "prabodhadīpikā": ['mw'],
    "prabodhaka": ['cae', 'mw'],
    "prabodhakaḥ": ['ap90'],
    "prabodhamañjarī": ['mw'],
    "prabodhamānasollāsa": ['mw'],
    "prabodhana": ['ap90', 'bhs', 'cae', 'mw'],
    "prabodhanī": ['ap90', 'mw'],
    "prabodhaprakāśa": ['mw'],
    "prabodharatnākara": ['mw'],
    "prabodhasiddhi": ['mw'],
    "prabodhasudhākara": ['mw'],
    "prabodhasūktivyākhyā": ['mw'],
    "prabodhavatī": ['mw'],
    "prabodhaḥ": ['ap90'],
    "prabodhin": ['mw'],
    "prabodhinī": ['ap90', 'mw'],
    "prabodhita": ['ap90', 'mw'],
    "prabodhitā": ['mw'],
    "prabodhodaya": ['mw'],
    "prabodhotsava": ['mw'],
    "prabodhya": ['mw'],
    "prabodhānanda": ['mw'],
    "prabrū": ['ap90', 'mw'],
    "prabuddha": ['ap90', 'cae', 'ddsa', 'mw'],
    "prabuddhatā": ['mw'],
    "prabuddhaśīla": ['bhs'],
    "prabudh": ['ap90', 'cae', 'gra', 'mw'],
    "prabudha": ['mw'],
    "prabudhaḥ": ['ap90'],
    "prabudhyati": ['bhs'],
    "prabābadhāna": ['mw'],
    "prabādh": ['ap90', 'mw'],
    "prabādhaka": ['ap90', 'ddsa', 'mw'],
    "prabādhana": ['mw'],
    "prabādhanaṃ": ['ap90'],
    "prabādhin": ['mw'],
    "prabādhita": ['ap90', 'mw'],
    "prabāhu": ['mw'],
    "prabāhuk": ['ap90', 'mw'],
    "prabāhukam": ['mw'],
    "prabāhukaṃ": ['ap90'],
    "prabāhuḥ": ['ap90'],
    "prabāla": ['mw'],
    "prabālaka": ['mw'],
    "prabālaḥ": ['ap90'],
    "prabālika": ['mw'],
    "prabālikā": ['mw'],
    "praca": ['mw'],
    "pracakita": ['mw'],
    "pracakra": ['mw'],
    "pracakraṃ": ['ap90'],
    "pracakṣ": ['ap90', 'mw'],
    "pracakṣas": ['ap90', 'mw'],
    "pracakṣaṇam": ['mw'],
    "pracal": ['ap90', 'mw'],
    "pracala": ['ap90', 'bhs', 'cae', 'mw'],
    "pracaladāsa": ['mw'],
    "pracalaka": ['mw'],
    "pracalakin": ['mw'],
    "pracalakāñcanakuṇḍala": ['mw'],
    "pracalalatābhuja": ['mw'],
    "pracalana": ['cae', 'mw'],
    "pracalanaṃ": ['ap90'],
    "pracalasiṃha": ['mw'],
    "pracalat": ['ap90', 'mw'],
    "pracalita": ['ap90', 'mw'],
    "pracalāka": ['mw'],
    "pracalākaḥ": ['ap90'],
    "pracalākin": ['ap90', 'mw'],
    "pracalākā": ['mw'],
    "pracalāya": ['mw'],
    "pracalāyana": ['mw'],
    "pracalāyati": ['bhs'],
    "pracalāyita": ['ap90', 'mw'],
    "pracalāṅga": ['mw'],
    "pracapala": ['mw'],
    "pracar": ['ap90', 'mw'],
    "pracara": ['mw'],
    "pracaraḥ": ['ap90'],
    "pracaraṇa": ['cae', 'mw'],
    "pracaraṇaṃ": ['ap90'],
    "pracaraṇī": ['mw'],
    "pracaraṇīya": ['mw'],
    "pracarita": ['ap90', 'mw'],
    "pracaritavya": ['mw'],
    "pracaritos": ['mw'],
    "pracaryā": ['cae', 'mw'],
    "pracat": ['gra', 'mw'],
    "pracatā": ['cae', 'ddsa', 'mw'],
    "pracaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "pracayakāṣṭhāgata": ['mw'],
    "pracayana": ['mw'],
    "pracayanaṃ": ['ap90'],
    "pracayasvara": ['cae', 'mw'],
    "pracayaḥ": ['ap90'],
    "pracaṃḍa": ['ap90'],
    "pracaṃḍatā": ['ap90'],
    "pracaṅkaśa": ['mw'],
    "pracaṇḍa": ['cae', 'ddsa', 'mw'],
    "pracaṇḍabhairava": ['mw'],
    "pracaṇḍabhairavarasa": ['mw'],
    "pracaṇḍacaṇḍikā": ['mw'],
    "pracaṇḍacaṇḍikāsahasranāmastotra": ['mw'],
    "pracaṇḍadeva": ['mw'],
    "pracaṇḍaghoṇa": ['mw'],
    "pracaṇḍamādhava": ['mw'],
    "pracaṇḍamūrti": ['mw'],
    "pracaṇḍapāṇḍava": ['cae', 'mw'],
    "pracaṇḍasena": ['mw'],
    "pracaṇḍasūrya": ['mw'],
    "pracaṇḍatarībhū": ['mw'],
    "pracaṇḍatā": ['mw'],
    "pracaṇḍavadana": ['mw'],
    "pracaṇḍavarman": ['mw'],
    "pracaṇḍaśakti": ['mw'],
    "pracaṇḍaśarakārmuka": ['mw'],
    "pracaṇḍaśephas": ['mw'],
    "pracaṇḍogrā": ['mw'],
    "pracaṇḍā": ['bhs', 'mw'],
    "pracaṇḍātapa": ['cae', 'mw'],
    "pracaṣāla": ['mw'],
    "praccaya": ['bhs'],
    "pracch": ['ap90'],
    "pracchad": ['ap90', 'cae', 'mw'],
    "pracchada": ['cae', 'ddsa', 'mw'],
    "pracchadapaṭa": ['cae', 'mw'],
    "pracchadavāsas": ['mw'],
    "pracchadaḥ": ['ap90'],
    "pracchana": ['mw'],
    "pracchanaṃ": ['ap90'],
    "pracchandikatā": ['bhs'],
    "pracchanna": ['ap90', 'cae', 'mw'],
    "pracchannabhartṛ": ['bhs'],
    "pracchannacāraka": ['mw'],
    "pracchannacārin": ['mw'],
    "pracchannagupta": ['mw'],
    "pracchannam": ['mw'],
    "pracchannapāpa": ['cae', 'mw'],
    "pracchannataskara": ['mw'],
    "pracchannavañcaka": ['mw'],
    "pracchannavṛtti": ['mw'],
    "pracchannībhū": ['mw'],
    "pracchardana": ['mw'],
    "pracchardanaṃ": ['ap90'],
    "pracchardi": ['mw'],
    "pracchardikā": ['ap90', 'mw'],
    "praccheda": ['cae', 'mw'],
    "pracchedaka": ['mw'],
    "pracchedana": ['mw'],
    "pracchedya": ['mw'],
    "pracchid": ['cae', 'mw'],
    "pracchila": ['ap90'],
    "pracchindyākarṇa": ['mw'],
    "pracchita": ['mw'],
    "praccho": ['mw'],
    "pracchuḍ": ['mw'],
    "pracchādaka": ['ap90', 'cae', 'mw'],
    "pracchādana": ['cae', 'mw'],
    "pracchādanapaṭa": ['mw'],
    "pracchādanaṃ": ['ap90'],
    "pracchādita": ['ap90', 'mw'],
    "pracchādya": ['mw'],
    "pracchāna": ['mw'],
    "pracchānaṃ": ['ap90'],
    "pracchāya": ['cae', 'mw'],
    "pracchāyaṃ": ['ap90'],
    "pracchāyā": ['bhs'],
    "pracchṛd": ['mw'],
    "praccopaka": ['bhs'],
    "pracela": ['mw'],
    "pracelaka": ['mw'],
    "pracelakaḥ": ['ap90'],
    "pracelaṃ": ['ap90'],
    "praceluka": ['mw'],
    "pracerita": ['mw'],
    "pracetana": ['mw'],
    "pracetas": ['ap90', 'cae', 'gra', 'mw'],
    "pracetasa": ['mw'],
    "pracetassmṛti": ['mw'],
    "pracetasī": ['mw'],
    "pracetita": ['mw'],
    "pracetuna": ['cae', 'gra', 'mw'],
    "pracetṛ": ['ap90', 'mw'],
    "praceya": ['mw'],
    "prach": ['cae', 'ddsa', 'gra', 'mw'],
    "prachoḍayati": ['bhs'],
    "praci": ['ap90', 'mw'],
    "pracika": ['mw'],
    "pracikita": ['mw'],
    "pracikīrṣu": ['mw'],
    "pracint": ['mw'],
    "pracintya": ['mw'],
    "pracinvat": ['mw'],
    "pracit": ['mw'],
    "pracita": ['ap90', 'cae', 'mw'],
    "pracitasvara": ['mw'],
    "praciti": ['mw'],
    "pracoda": ['cae', 'mw'],
    "pracodaka": ['mw'],
    "pracodana": ['mw'],
    "pracodanaṃ": ['ap90'],
    "pracodanī": ['mw'],
    "pracodaḥ": ['ap90'],
    "pracodikā": ['mw'],
    "pracodin": ['ap90', 'mw'],
    "pracodinī": ['mw'],
    "pracodita": ['ap90', 'mw'],
    "pracoḍaka": ['bhs'],
    "pracud": ['ap90', 'mw'],
    "pracudita": ['mw'],
    "pracupita": ['mw'],
    "pracura": ['ap90', 'cae', 'mw'],
    "pracuracandana": ['mw'],
    "pracuracchala": ['mw'],
    "pracuraloma": ['mw'],
    "pracuranityadhanāgama": ['mw'],
    "pracuraparibhava": ['mw'],
    "pracurapuruṣa": ['mw'],
    "pracurapādapa": ['mw'],
    "pracuraratnadhanāgama": ['mw'],
    "pracuratva": ['mw'],
    "pracuratā": ['ap90', 'mw'],
    "pracurī": ['mw'],
    "pracurībhū": ['ap90', 'mw'],
    "pracurīkaraṇa": ['mw'],
    "pracurīkaraṇaṃ": ['ap90'],
    "pracurīkṛta": ['ap90', 'mw'],
    "pracyava": ['cae', 'mw'],
    "pracyavana": ['cae', 'ddsa', 'mw'],
    "pracyavanaṃ": ['ap90'],
    "pracyavaḥ": ['ap90'],
    "pracyotos": ['cae'],
    "pracyu": ['ap90', 'mw'],
    "pracyuta": ['ap90', 'mw'],
    "pracyutatva": ['mw'],
    "pracyuti": ['mw'],
    "pracyutiḥ": ['ap90'],
    "pracyāvana": ['mw'],
    "pracyāvanaṃ": ['ap90'],
    "pracyāvanī": ['mw'],
    "pracyāvuka": ['mw'],
    "pracāla": ['mw'],
    "pracālaka": ['bhs', 'mw'],
    "pracālana": ['mw'],
    "pracālanaṃ": ['ap90'],
    "pracālaḥ": ['ap90'],
    "pracāra": ['bhs', 'cae', 'mw'],
    "pracāraḥ": ['ap90'],
    "pracāraṇa": ['mw'],
    "pracāraṇā": ['bhs'],
    "pracārika": ['bhs'],
    "pracārin": ['ap90', 'mw'],
    "pracārita": ['ap90', 'bhs', 'mw'],
    "pracāya": ['ap90', 'mw'],
    "pracāyaḥ": ['ap90'],
    "pracāyikā": ['ap90', 'mw'],
    "pracībala": ['mw'],
    "pracīra": ['mw'],
    "pracīrṇa": ['mw'],
    "pracūrṇ": ['mw'],
    "pracṛt": ['mw'],
    "pracṛtta": ['mw'],
    "pracṛttaśikha": ['mw'],
    "prada": ['ap90', 'cae', 'ddsa', 'mw'],
    "pradadhāti": ['bhs'],
    "pradadi": ['mw'],
    "pradagdha": ['ap90', 'mw'],
    "pradagdhavya": ['mw'],
    "pradagdhāhuti": ['mw'],
    "pradaghas": ['mw'],
    "pradah": ['ap90', 'mw'],
    "pradakṣinit": ['gra'],
    "pradakṣiṇa": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "pradakṣiṇagrāhatā": ['bhs'],
    "pradakṣiṇagrāhin": ['bhs'],
    "pradakṣiṇagrāhitā": ['bhs'],
    "pradakṣiṇagāmitā": ['mw'],
    "pradakṣiṇakriyā": ['mw'],
    "pradakṣiṇam": ['mw'],
    "pradakṣiṇapaṭṭikā": ['mw'],
    "pradakṣiṇatas": ['bhs'],
    "pradakṣiṇaya": ['ddsa', 'mw'],
    "pradakṣiṇeṇa": ['mw'],
    "pradakṣiṇit": ['cae', 'ddsa', 'mw'],
    "pradakṣiṇānuloma": ['mw'],
    "pradakṣiṇārcis": ['cae', 'ddsa', 'mw'],
    "pradakṣiṇārtha": ['bhs'],
    "pradakṣiṇāvarta": ['mw'],
    "pradakṣiṇāvartaikaromatā": ['mw'],
    "pradakṣiṇāvartanābhitā": ['mw'],
    "pradakṣiṇāvartaśikha": ['mw'],
    "pradakṣiṇāvṛtka": ['mw'],
    "pradakṣiṇīkṛ": ['cae', 'mw'],
    "pradakṣiṇīya": ['bhs'],
    "pradala": ['mw'],
    "pradalaḥ": ['ap90'],
    "pradalita": ['bhs'],
    "pradam": ['mw'],
    "pradara": ['cae', 'mw'],
    "pradaraḥ": ['ap90'],
    "pradarpa": ['mw'],
    "pradarpaḥ": ['ap90'],
    "pradarvidā": ['mw'],
    "pradarśa": ['cae', 'mw'],
    "pradarśaka": ['ap90', 'cae', 'mw'],
    "pradarśana": ['cae', 'mw'],
    "pradarśanaka": ['bhs'],
    "pradarśanaṃ": ['ap90'],
    "pradarśaniya": ['bhs'],
    "pradarśanā": ['mw'],
    "pradarśaḥ": ['ap90'],
    "pradarśin": ['cae', 'mw'],
    "pradarśita": ['ap90', 'mw'],
    "pradas": ['mw'],
    "pradatta": ['mw'],
    "pradattaka": ['bhs'],
    "pradattanayanotsava": ['mw'],
    "pradava": ['mw'],
    "pradavaḥ": ['ap90'],
    "pradavya": ['mw'],
    "pradavyaḥ": ['ap90'],
    "pradaṇḍavat": ['mw'],
    "pradeha": ['mw'],
    "pradehana": ['mw'],
    "pradehaḥ": ['ap90'],
    "pradeva": ['bhs'],
    "pradeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "pradeyā": ['mw'],
    "pradeśa": ['bhs', 'cae', 'mw'],
    "pradeśabhāj": ['mw'],
    "pradeśakālaka": ['bhs'],
    "pradeśakārin": ['mw'],
    "pradeśana": ['mw'],
    "pradeśanaṃ": ['ap90'],
    "pradeśanī": ['ap90', 'mw'],
    "pradeśarājan": ['bhs'],
    "pradeśastha": ['mw'],
    "pradeśavartin": ['mw'],
    "pradeśavartitvā": ['mw'],
    "pradeśavat": ['mw'],
    "pradeśaśāstra": ['mw'],
    "pradeśaḥ": ['ap90'],
    "pradeśeti": ['bhs'],
    "pradeśinī": ['ap90', 'mw'],
    "pradeśita": ['mw'],
    "pradeṣṭṛ": ['mw'],
    "pradha": ['mw'],
    "pradham": ['mw'],
    "pradhamana": ['mw'],
    "pradhamanaṃ": ['ap90'],
    "pradhana": ['cae', 'ddsa', 'gra', 'mw'],
    "pradhanaṃ": ['ap90'],
    "pradhania": ['gra'],
    "pradhanottama": ['mw'],
    "pradhanya": ['gra', 'mw'],
    "pradhanāghātaka": ['mw'],
    "pradhanāṅgaṇa": ['mw'],
    "pradharṣa": ['mw'],
    "pradharṣaka": ['ap90', 'bhs', 'cae', 'mw'],
    "pradharṣaḥ": ['ap90'],
    "pradharṣaṇa": ['cae', 'mw'],
    "pradharṣaṇaṃ": ['ap90'],
    "pradharṣaṇīya": ['mw'],
    "pradharṣin": ['mw'],
    "pradharṣita": ['ap90', 'mw'],
    "pradharṣitavat": ['mw'],
    "pradhe": ['mw'],
    "pradhi": ['cae', 'ddsa', 'gra', 'mw'],
    "pradhimaṇḍala": ['mw'],
    "pradhiḥ": ['ap90'],
    "pradhmā": ['ap90', 'mw'],
    "pradhmāpana": ['mw'],
    "pradhmāpanaṃ": ['ap90'],
    "pradhmāpita": ['mw'],
    "pradhraj": ['mw'],
    "pradhura": ['cae', 'mw'],
    "pradhvan": ['mw'],
    "pradhvasta": ['ap90', 'mw'],
    "pradhvaṃs": ['ap90', 'mw'],
    "pradhvaṃsa": ['cae', 'mw'],
    "pradhvaṃsana": ['cae', 'mw'],
    "pradhvaṃsanaḥ": ['ap90'],
    "pradhvaṃsatva": ['mw'],
    "pradhvaṃsaḥ": ['ap90'],
    "pradhvaṃsin": ['ap90', 'cae', 'mw'],
    "pradhvaṃsita": ['mw'],
    "pradhvaṃsābhāva": ['mw'],
    "pradhvopaka": ['bhs'],
    "pradhvāna": ['mw'],
    "pradhyai": ['mw'],
    "pradhyanīka": ['mw'],
    "pradhyāna": ['cae', 'ddsa', 'mw'],
    "pradhyānaṃ": ['ap90'],
    "pradhā": ['mw'],
    "pradhāna": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "pradhānabhāj": ['mw'],
    "pradhānabhūta": ['cae', 'mw'],
    "pradhānadhātu": ['mw'],
    "pradhānaka": ['ap90', 'mw'],
    "pradhānakarman": ['mw'],
    "pradhānakāraṇavāda": ['mw'],
    "pradhānakārya": ['mw'],
    "pradhānamantrin": ['mw'],
    "pradhānamitra": ['mw'],
    "pradhānaprakṛti": ['cae'],
    "pradhānapuruṣa": ['cae', 'mw'],
    "pradhānapuruṣātīta": ['mw'],
    "pradhānasabhika": ['cae', 'mw'],
    "pradhānasevā": ['mw'],
    "pradhānatama": ['mw'],
    "pradhānatara": ['mw'],
    "pradhānatas": ['cae', 'mw'],
    "pradhānatva": ['mw'],
    "pradhānatā": ['ap90', 'cae', 'mw'],
    "pradhānavādin": ['mw'],
    "pradhānavāsas": ['cae', 'mw'],
    "pradhānavṛṣṭi": ['mw'],
    "pradhānaśiṣṭa": ['mw'],
    "pradhānottama": ['mw'],
    "pradhānya": ['mw'],
    "pradhānā": ['mw'],
    "pradhānādhyakṣa": ['mw'],
    "pradhānādhyakṣatā": ['mw'],
    "pradhānāhuti": ['mw'],
    "pradhānāmātya": ['mw'],
    "pradhānātman": ['mw'],
    "pradhānāṅga": ['mw'],
    "pradhāraṇa": ['ap90', 'mw'],
    "pradhāraṇā": ['mw'],
    "pradhārya": ['mw'],
    "pradhāv": ['ap90', 'mw'],
    "pradhāvana": ['ddsa', 'mw'],
    "pradhāvanaḥ": ['ap90'],
    "pradhāvita": ['mw'],
    "pradhī": ['ap90', 'mw'],
    "pradhū": ['mw'],
    "pradhūmita": ['mw'],
    "pradhūpayati": ['bhs'],
    "pradhūpita": ['ap90', 'mw'],
    "pradhūpitā": ['mw'],
    "pradhṛ": ['ap90', 'mw'],
    "pradhṛṣ": ['ap90', 'mw'],
    "pradhṛṣya": ['mw'],
    "pradhṛṣṭa": ['ap90', 'mw'],
    "pradhṛṣṭi": ['cae', 'mw'],
    "pradi": ['mw'],
    "pradigdha": ['ap90', 'mw'],
    "pradih": ['ap90', 'mw'],
    "praditsu": ['ddsa', 'mw'],
    "praditsā": ['mw'],
    "pradiv": ['ap90', 'cae', 'gra', 'mw'],
    "pradivas": ['mw'],
    "pradivi": ['mw'],
    "pradiś": ['ap90', 'cae', 'gra', 'mw'],
    "pradiḥ": ['ap90'],
    "pradiṣṭa": ['ap90', 'mw'],
    "pradoha": ['mw'],
    "pradohana": ['mw'],
    "pradohaḥ": ['ap90'],
    "pradoṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pradoṣaka": ['ap90', 'mw'],
    "pradoṣakāla": ['mw'],
    "pradoṣam": ['mw'],
    "pradoṣamahiman": ['mw'],
    "pradoṣamāhātmya": ['mw'],
    "pradoṣanirṇaya": ['mw'],
    "pradoṣapūjāvidhi": ['mw'],
    "pradoṣaramaṇīya": ['mw'],
    "pradoṣasamaya": ['mw'],
    "pradoṣastotra": ['mw'],
    "pradoṣatimira": ['mw'],
    "pradoṣavelā": ['mw'],
    "pradoṣaśivapūjā": ['mw'],
    "pradoṣaśānti": ['mw'],
    "pradoṣin": ['bhs'],
    "pradoṣodyāpana": ['mw'],
    "pradoṣāgama": ['cae', 'mw'],
    "pradoṣānila": ['cae', 'mw'],
    "pradrava": ['ap90', 'ddsa', 'mw'],
    "pradrek": ['mw'],
    "pradru": ['ap90', 'mw'],
    "pradruh": ['mw'],
    "pradruta": ['mw'],
    "pradrāva": ['mw'],
    "pradrāvaḥ": ['ap90'],
    "pradrāvin": ['ap90', 'mw'],
    "pradrāṇaka": ['ap90', 'mw'],
    "pradu": ['mw'],
    "pradugdha": ['bhs', 'mw'],
    "praduh": ['mw'],
    "praduṣ": ['ap90', 'mw'],
    "praduṣṭa": ['ap90', 'cae', 'mw'],
    "pradveṣa": ['cae', 'mw'],
    "pradveṣaka": ['bhs'],
    "pradveṣaḥ": ['ap90'],
    "pradveṣaṇa": ['mw'],
    "pradveṣī": ['mw'],
    "pradveṣṭṛ": ['mw'],
    "pradviṣ": ['ap90', 'mw'],
    "pradvār": ['ap90', 'ddsa', 'mw'],
    "pradvāra": ['mw'],
    "pradyota": ['bhs', 'cae', 'mw'],
    "pradyotana": ['mw'],
    "pradyotanaṃ": ['ap90'],
    "pradyotaḥ": ['ap90'],
    "pradyotin": ['mw'],
    "pradyotita": ['mw'],
    "pradyu": ['mw'],
    "pradyumna": ['bhs', 'cae', 'ddsa', 'mw'],
    "pradyumnaka": ['mw'],
    "pradyumnapura": ['mw'],
    "pradyumnarahasya": ['mw'],
    "pradyumnavijaya": ['mw'],
    "pradyumnaśikhara": ['mw'],
    "pradyumnaśikharapīṭhāṣṭaka": ['mw'],
    "pradyumnaḥ": ['ap90'],
    "pradyumnopākhyāna": ['mw'],
    "pradyumnottaracarita": ['mw'],
    "pradyumnābhyudaya": ['mw'],
    "pradyumnācārya": ['mw'],
    "pradyumnāgamana": ['mw'],
    "pradyumnāgamanīya": ['mw'],
    "pradyumnānanda": ['mw'],
    "pradyumnānandīya": ['mw'],
    "pradyumnāstra": ['mw'],
    "pradyut": ['ap90', 'mw'],
    "pradyutita": ['ap90', 'mw'],
    "pradā": ['ap90', 'mw'],
    "pradāha": ['cae', 'mw'],
    "pradālana": ['bhs'],
    "pradālayati": ['bhs'],
    "pradām": ['mw'],
    "pradāna": ['bhs', 'cae', 'mw'],
    "pradānaka": ['mw'],
    "pradānakaṃ": ['ap90'],
    "pradānakṛpaṇa": ['mw'],
    "pradānapūrvam": ['mw'],
    "pradānaruci": ['bhs', 'mw'],
    "pradānavat": ['mw'],
    "pradānaśūra": ['bhs', 'mw'],
    "pradānaṃ": ['ap90'],
    "pradānika": ['mw'],
    "pradānta": ['mw'],
    "pradāpayitṛ": ['mw'],
    "pradāpya": ['mw'],
    "pradāraṇa": ['bhs'],
    "pradāsa": ['bhs', 'mw'],
    "pradātavya": ['ddsa', 'mw'],
    "pradātrikā": ['mw'],
    "pradātṛ": ['ap90', 'cae', 'mw'],
    "pradāva": ['mw'],
    "pradāvya": ['mw'],
    "pradāya": ['cae', 'mw'],
    "pradāyaka": ['cae', 'mw'],
    "pradāyakatva": ['mw'],
    "pradāyaṃ": ['ap90'],
    "pradāyin": ['ap90', 'cae', 'mw'],
    "pradāyitva": ['mw'],
    "pradī": ['mw'],
    "pradīdhyāna": ['ddsa'],
    "pradīdhī": ['mw'],
    "pradīkṣate": ['bhs'],
    "pradīp": ['ap90', 'mw'],
    "pradīpa": ['bhs', 'cae', 'mw'],
    "pradīpaka": ['ap90', 'cae', 'mw'],
    "pradīpamañjarī": ['mw'],
    "pradīpana": ['ap90', 'cae', 'mw'],
    "pradīpasiṃha": ['mw'],
    "pradīpasāha": ['mw'],
    "pradīpaśaraṇadhvaja": ['bhs', 'mw'],
    "pradīpaḥ": ['ap90'],
    "pradīpta": ['ap90', 'cae', 'mw'],
    "pradīptabhās": ['mw'],
    "pradīptaśiras": ['cae', 'mw'],
    "pradīpti": ['mw'],
    "pradīptimat": ['mw'],
    "pradīptiḥ": ['ap90'],
    "pradīptākṣa": ['mw'],
    "pradīpya": ['mw'],
    "pradīpāy": ['cae'],
    "pradīpāya": ['mw'],
    "pradīpīya": ['mw'],
    "pradīrgha": ['mw'],
    "pradīrghaka": ['bhs'],
    "pradūṣaka": ['mw'],
    "pradūṣayati": ['bhs'],
    "pradūṣaṇa": ['bhs', 'mw'],
    "pradūṣaṇaṃ": ['ap90'],
    "pradūṣita": ['ap90', 'mw'],
    "pradṛpita": ['mw'],
    "pradṛpta": ['mw'],
    "pradṛpti": ['gra', 'mw'],
    "pradṛś": ['ap90', 'mw'],
    "pradṝ": ['mw'],
    "praga": ['mw'],
    "pragadita": ['mw'],
    "pragai": ['mw'],
    "pragal": ['mw'],
    "pragalbh": ['ap90', 'cae', 'mw'],
    "pragalbha": ['ap90', 'cae', 'mw'],
    "pragalbhakulāla": ['mw'],
    "pragalbhalakṣaṇa": ['mw'],
    "pragalbhalakṣaṇaprakāśa": ['mw'],
    "pragalbham": ['mw'],
    "pragalbhamanas": ['mw'],
    "pragalbhatva": ['mw'],
    "pragalbhatā": ['ap90', 'mw'],
    "pragalbhavāc": ['mw'],
    "pragalbhita": ['ap90', 'mw'],
    "pragalbhā": ['mw'],
    "pragalbhāyate": ['bhs'],
    "pragalita": ['mw'],
    "pragam": ['ap90', 'mw'],
    "pragama": ['ddsa', 'mw'],
    "pragamana": ['mw'],
    "pragamanaṃ": ['ap90'],
    "pragamanīya": ['mw'],
    "pragamaḥ": ['ap90'],
    "pragardhin": ['cae', 'gra', 'mw'],
    "pragarj": ['mw'],
    "pragarjana": ['mw'],
    "pragarjanaṃ": ['ap90'],
    "pragarjita": ['mw'],
    "pragata": ['ap90', 'mw'],
    "pragatajānu": ['mw'],
    "pragatajānuka": ['mw'],
    "pragayaṇa": ['mw'],
    "pragaṃḍaḥ": ['ap90'],
    "pragaṃḍī": ['ap90'],
    "pragaṇ": ['mw'],
    "pragaṇikā": ['mw'],
    "pragaṇḍa": ['mw'],
    "pragaṇḍī": ['mw'],
    "pragaṭa": ['mw'],
    "prage": ['ap90', 'cae', 'ddsa', 'mw'],
    "prageniśa": ['mw'],
    "pragetana": ['cae', 'mw'],
    "prageśaya": ['mw'],
    "praggharati": ['bhs'],
    "praghana": ['mw'],
    "pragharati": ['bhs'],
    "pragharā": ['bhs'],
    "pragharṣa": ['mw'],
    "pragharṣaṇa": ['mw'],
    "praghasa": ['ap90', 'cae', 'mw'],
    "praghasā": ['mw'],
    "praghaṇa": ['ddsa', 'mw'],
    "praghaṇaḥ": ['ap90'],
    "praghaṭ": ['ap90', 'mw'],
    "praghaṭaka": ['mw'],
    "praghaṭakaḥ": ['ap90'],
    "praghaṭā": ['ap90', 'mw'],
    "praghaṭāvid": ['mw'],
    "praghaṭṭaka": ['mw'],
    "praghoṣa": ['cae', 'mw'],
    "praghoṣaḥ": ['ap90'],
    "praghoṣin": ['mw'],
    "praghuṇa": ['mw'],
    "praghuṇaḥ": ['ap90'],
    "praghuṣ": ['mw'],
    "praghuṣṭa": ['mw'],
    "praghāna": ['mw'],
    "praghāsa": ['mw'],
    "praghāsin": ['cae', 'mw'],
    "praghāsya": ['cae', 'mw'],
    "praghāta": ['mw'],
    "praghātana": ['bhs'],
    "praghātaya": ['mw'],
    "praghātayati": ['bhs'],
    "praghātaḥ": ['ap90'],
    "praghāṇa": ['mw'],
    "praghūrṇa": ['ap90', 'mw'],
    "praghṛ": ['mw'],
    "praghṛṣ": ['mw'],
    "praghṛṣṭa": ['mw'],
    "pragla": ['mw'],
    "praglai": ['mw'],
    "pragopana": ['mw'],
    "pragopanaṃ": ['ap90'],
    "pragrah": ['ap90', 'mw'],
    "pragraha": ['bhs', 'cae', 'ddsa', 'mw'],
    "pragrahatva": ['mw'],
    "pragrahavant": ['cae'],
    "pragrahavat": ['mw'],
    "pragrahaḥ": ['ap90'],
    "pragrahaṇa": ['bhs', 'cae', 'mw'],
    "pragrahaṇaṃ": ['ap90'],
    "pragrahin": ['mw'],
    "pragrahādidarpaṇa": ['mw'],
    "pragrahītavya": ['mw'],
    "pragras": ['mw'],
    "pragrath": ['mw'],
    "pragrathana": ['mw'],
    "pragrathanaṃ": ['ap90'],
    "pragrāha": ['mw'],
    "pragrāham": ['mw'],
    "pragrāhavat": ['mw'],
    "pragrāhaḥ": ['ap90'],
    "pragrīva": ['mw'],
    "pragrīvaḥ": ['ap90'],
    "pragup": ['mw'],
    "pragur": ['mw'],
    "praguṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "praguṇana": ['mw'],
    "praguṇanaṃ": ['ap90'],
    "praguṇaracanā": ['mw'],
    "praguṇay": ['cae'],
    "praguṇaya": ['mw'],
    "praguṇayati": ['ap90'],
    "praguṇin": ['mw'],
    "praguṇita": ['ap90', 'mw'],
    "praguṇya": ['ap90', 'mw'],
    "praguṇī": ['mw'],
    "praguṇībhū": ['mw'],
    "praguṇīkaraṇa": ['mw'],
    "praguṇīkṛ": ['cae', 'mw'],
    "pragā": ['mw'],
    "pragādya": ['mw'],
    "pragāh": ['mw'],
    "pragāhana": ['mw'],
    "pragāman": ['gra', 'mw'],
    "pragāmin": ['mw'],
    "pragātha": ['cae', 'mw'],
    "pragāthakāram": ['mw'],
    "pragāthaḥ": ['ap90'],
    "pragātṛ": ['ap90', 'mw'],
    "pragāyin": ['mw'],
    "pragāḍha": ['ap90', 'cae', 'mw'],
    "pragāḍham": ['mw'],
    "pragāḍhatva": ['mw'],
    "pragāḍhatā": ['mw'],
    "pragāṇa": ['cae', 'gra', 'mw'],
    "pragīta": ['ap90', 'cae', 'mw'],
    "pragīti": ['ap90', 'mw'],
    "pragṛhya": ['cae', 'mw'],
    "pragṛhyaṃ": ['ap90'],
    "pragṛhīta": ['ap90', 'bhs', 'mw'],
    "pragṛhītapada": ['mw'],
    "pragṛhṇāti": ['bhs'],
    "pragṝ": ['mw'],
    "prahan": ['ap90', 'gra', 'mw'],
    "prahanemi": ['mw'],
    "prahanemiḥ": ['ap90'],
    "prahantavya": ['mw'],
    "prahantṛ": ['gra', 'mw'],
    "prahara": ['cae', 'mw'],
    "praharaka": ['mw'],
    "praharakaḥ": ['ap90'],
    "praharakuṭumbī": ['mw'],
    "praharavirati": ['mw'],
    "praharaḥ": ['ap90'],
    "praharaṇa": ['cae', 'mw'],
    "praharaṇakalikā": ['mw'],
    "praharaṇakalitā": ['mw'],
    "praharaṇavat": ['mw'],
    "praharaṇaṃ": ['ap90'],
    "praharaṇīya": ['mw'],
    "praharaṇīyaṃ": ['ap90'],
    "praharin": ['ap90', 'mw'],
    "praharita": ['mw'],
    "prahartavya": ['cae', 'mw'],
    "prahartṛ": ['ap90', 'cae', 'mw'],
    "praharāja": ['bhs'],
    "praharṣa": ['cae', 'mw'],
    "praharṣavat": ['mw'],
    "praharṣaḥ": ['ap90'],
    "praharṣaṇa": ['cae', 'mw'],
    "praharṣaṇakara": ['mw'],
    "praharṣaṇaṃ": ['ap90'],
    "praharṣaṇī": ['ap90', 'mw'],
    "praharṣin": ['cae', 'mw'],
    "praharṣita": ['mw'],
    "praharṣitatejas": ['bhs'],
    "praharṣiṇī": ['ap90', 'mw'],
    "praharṣula": ['mw'],
    "praharṣulaḥ": ['ap90'],
    "praharṣā": ['bhs'],
    "prahas": ['ap90', 'mw'],
    "prahasa": ['mw'],
    "prahasana": ['cae', 'mw'],
    "prahasananāṭaka": ['mw'],
    "prahasanaṃ": ['ap90'],
    "prahasantī": ['mw'],
    "prahasat": ['mw'],
    "prahasaṃtī": ['ap90'],
    "prahasita": ['ap90', 'bhs', 'mw'],
    "prahasitanetra": ['bhs', 'mw'],
    "prahasitanetranihitarāgarajas": ['bhs'],
    "prahasitavadana": ['mw'],
    "prahasitānana": ['mw'],
    "prahasta": ['cae', 'mw'],
    "prahastaka": ['mw'],
    "prahastavāda": ['mw'],
    "prahastaḥ": ['ap90'],
    "prahata": ['ap90', 'bhs', 'mw'],
    "prahatamuraja": ['mw'],
    "prahati": ['cae', 'mw'],
    "prahaṇa": ['mw'],
    "prahaṇana": ['ddsa', 'mw'],
    "prahaṇanaṃ": ['ap90'],
    "prahaṇemi": ['mw'],
    "prahaṇemiḥ": ['ap90'],
    "prahelaka": ['mw'],
    "prahelakaḥ": ['ap90'],
    "prahelayā": ['mw'],
    "praheli": ['mw'],
    "prahelika": ['bhs'],
    "prahelikā": ['mw'],
    "praheliḥ": ['ap90'],
    "prahelā": ['ap90', 'ddsa', 'mw'],
    "prahelī": ['mw'],
    "prahelījñāna": ['mw'],
    "prahetavya": ['mw'],
    "praheti": ['bhs', 'cae', 'mw'],
    "prahetṛ": ['cae', 'gra', 'mw'],
    "praheya": ['mw'],
    "praheṇaka": ['bhs', 'mw'],
    "praheṇakaṃ": ['ap90'],
    "prahi": ['ap90', 'cae', 'ddsa', 'mw'],
    "prahima": ['mw'],
    "prahita": ['ap90', 'bhs', 'mw'],
    "prahitaṃgama": ['mw'],
    "prahitaṃgamavat": ['mw'],
    "prahitu": ['mw'],
    "prahitātman": ['mw'],
    "prahiḥ": ['ap90'],
    "prahla": ['mw'],
    "prahlanna": ['ap90', 'mw'],
    "prahlanni": ['mw'],
    "prahlanniḥ": ['ap90'],
    "prahlatti": ['mw'],
    "prahlād": ['ap90', 'mw'],
    "prahlāda": ['cae', 'mw'],
    "prahlādacampū": ['mw'],
    "prahlādacarita": ['mw'],
    "prahlādaka": ['mw'],
    "prahlādana": ['ap90', 'cae', 'mw'],
    "prahlādanīya": ['bhs', 'mw'],
    "prahlādastotra": ['mw'],
    "prahlādastuti": ['mw'],
    "prahlādavijaya": ['mw'],
    "prahlādaḥ": ['ap90'],
    "prahlādin": ['cae', 'mw'],
    "prahlādita": ['mw'],
    "prahlādīya": ['mw'],
    "prahoṣa": ['cae', 'gra', 'mw'],
    "prahoṣin": ['gra', 'mw'],
    "prahruta": ['bhs'],
    "prahrāda": ['cae', 'ddsa', 'mw'],
    "prahrādana": ['ap90'],
    "prahrādaḥ": ['ap90'],
    "prahrādi": ['mw'],
    "prahrāsa": ['mw'],
    "prahrāsaḥ": ['ap90'],
    "prahu": ['mw'],
    "prahuta": ['cae', 'ddsa', 'mw'],
    "prahutaḥ": ['ap90'],
    "prahuti": ['cae', 'gra', 'mw'],
    "prahutiḥ": ['ap90'],
    "prahva": ['ap90', 'cae', 'ddsa', 'mw'],
    "prahval": ['mw'],
    "prahvala": ['mw'],
    "prahvalikā": ['ap90'],
    "prahvalīkā": ['mw'],
    "prahvatva": ['mw'],
    "prahvaya": ['mw'],
    "prahvayati": ['ap90'],
    "prahvaṇa": ['mw'],
    "prahve": ['mw'],
    "prahvāya": ['mw'],
    "prahvāyaḥ": ['ap90'],
    "prahvāñjali": ['mw'],
    "prahvāṇa": ['mw'],
    "prahvī": ['mw'],
    "prahvībhūta": ['mw'],
    "prahvīkṛta": ['mw'],
    "prahye": ['mw'],
    "prahā": ['ap90', 'cae', 'gra', 'mw'],
    "prahāna": ['mw'],
    "prahāni": ['mw'],
    "prahāpaṇa": ['mw'],
    "prahāra": ['cae', 'mw'],
    "prahārada": ['mw'],
    "prahārakaraṇa": ['mw'],
    "prahāravallī": ['mw'],
    "prahāravarman": ['mw'],
    "prahāraḥ": ['ap90'],
    "prahāraṇa": ['mw'],
    "prahāraṇaṃ": ['ap90'],
    "prahārikā": ['bhs'],
    "prahārin": ['cae', 'mw'],
    "prahāritā": ['mw'],
    "prahāruka": ['mw'],
    "prahārya": ['mw'],
    "prahārā": ['bhs'],
    "prahārārta": ['mw'],
    "prahāsa": ['cae', 'mw'],
    "prahāsaka": ['mw'],
    "prahāsakaḥ": ['ap90'],
    "prahāsaḥ": ['ap90'],
    "prahāsin": ['ap90', 'mw'],
    "prahāsita": ['mw'],
    "prahātavya": ['mw'],
    "prahāvat": ['gra', 'mw'],
    "prahāyya": ['mw'],
    "prahāyyaḥ": ['ap90'],
    "prahāṇa": ['bhs', 'cae', 'mw'],
    "prahāṇaṃ": ['ap90'],
    "prahāṇi": ['mw'],
    "prahāṇika": ['bhs'],
    "prahāṇiḥ": ['ap90'],
    "prahīṇa": ['ap90', 'cae', 'mw'],
    "prahīṇadoṣa": ['mw'],
    "prahīṇajīvita": ['mw'],
    "prahṛ": ['ap90', 'mw'],
    "prahṛta": ['ap90', 'ddsa', 'mw'],
    "prahṛṣ": ['ap90', 'mw'],
    "prahṛṣṭa": ['ap90', 'cae', 'mw'],
    "prahṛṣṭacitta": ['mw'],
    "prahṛṣṭaka": ['mw'],
    "prahṛṣṭakaḥ": ['ap90'],
    "prahṛṣṭamanas": ['cae', 'mw'],
    "prahṛṣṭamudita": ['mw'],
    "prahṛṣṭamukha": ['mw'],
    "prahṛṣṭaroman": ['mw'],
    "prahṛṣṭarūpa": ['mw'],
    "prahṛṣṭavadana": ['mw'],
    "prahṛṣṭātman": ['mw'],
    "praidh": ['mw'],
    "praikīya": ['mw'],
    "praitos": ['ddsa', 'mw'],
    "praiya": ['mw'],
    "praiyaka": ['mw'],
    "praiyamedha": ['ddsa', 'mw'],
    "praiyarūpaka": ['ddsa', 'mw'],
    "praiyavrata": ['mw'],
    "praiyaṃ": ['ap90'],
    "praiyaṅgava": ['mw'],
    "praiyaṅgavika": ['mw'],
    "praiyyamedha": ['mw'],
    "praiṇ": ['mw'],
    "praiṇāna": ['mw'],
    "praiṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "praiṣakara": ['mw'],
    "praiṣakṛt": ['mw'],
    "praiṣam": ['mw'],
    "praiṣapratīkayājyā": ['mw'],
    "praiṣaḥ": ['ap90'],
    "praiṣaṇika": ['ap90', 'mw'],
    "praiṣika": ['mw'],
    "praiṣya": ['cae', 'ddsa', 'mw'],
    "praiṣyabhāva": ['cae', 'mw'],
    "praiṣyajana": ['cae', 'mw'],
    "praiṣyasaṃyuta": ['mw'],
    "praiṣyaḥ": ['ap90'],
    "praiṣyā": ['mw'],
    "praiṣādhyāya": ['mw'],
    "praja": ['cae', 'mw'],
    "prajahana": ['bhs'],
    "prajahita": ['mw'],
    "prajajñi": ['gra', 'mw'],
    "prajalp": ['ap90', 'mw'],
    "prajalpa": ['cae', 'mw'],
    "prajalpana": ['mw'],
    "prajalpanaṃ": ['ap90'],
    "prajalpaḥ": ['ap90'],
    "prajalpita": ['ap90', 'cae', 'mw'],
    "prajan": ['ap90', 'mw'],
    "prajana": ['cae', 'ddsa', 'mw'],
    "prajanana": ['ap90', 'cae', 'gra', 'mw'],
    "prajananakuśala": ['mw'],
    "prajananakāma": ['mw'],
    "prajananavant": ['cae'],
    "prajananavat": ['mw'],
    "prajanayitṛ": ['cae', 'mw'],
    "prajanaḥ": ['ap90'],
    "prajanikā": ['ap90', 'mw'],
    "prajaniṣyamāṇā": ['mw'],
    "prajaniṣṇu": ['ap90', 'cae', 'mw'],
    "prajanu": ['cae', 'mw'],
    "prajanuka": ['mw'],
    "prajanukaḥ": ['ap90'],
    "prajanārtham": ['mw'],
    "prajanīyām": ['bhs'],
    "prajanūḥ": ['ap90'],
    "prajap": ['mw'],
    "prajas": ['cae', 'mw'],
    "prajava": ['cae', 'gra', 'mw'],
    "prajavam": ['mw'],
    "prajavana": ['ap90', 'cae', 'mw'],
    "prajavaḥ": ['ap90'],
    "prajavin": ['ap90', 'cae', 'mw'],
    "prajavita": ['mw'],
    "prajaya": ['cae', 'mw'],
    "prajaḥ": ['ap90'],
    "prajaṅgha": ['mw'],
    "prajaṅghā": ['mw'],
    "prajehā": ['mw'],
    "prajepsu": ['mw'],
    "prajeśa": ['cae', 'ddsa', 'mw'],
    "prajeśvara": ['cae', 'mw'],
    "praji": ['mw'],
    "prajihīrṣu": ['ddsa', 'mw'],
    "prajijanayiṣitavya": ['mw'],
    "prajijaniṣamāṇa": ['mw'],
    "prajina": ['mw'],
    "prajinaḥ": ['ap90'],
    "prajinv": ['mw'],
    "prajit": ['mw'],
    "prajita": ['mw'],
    "prajjaṭikā": ['mw'],
    "prajji": ['ddsa', 'mw'],
    "prajotpatti": ['mw'],
    "prajotpattyānupūrvyeṇa": ['mw'],
    "prajotpādana": ['mw'],
    "prajuṣṭa": ['ap90', 'cae', 'mw'],
    "prajval": ['ap90', 'mw'],
    "prajvalana": ['cae', 'ddsa', 'mw'],
    "prajvalanaṃ": ['ap90'],
    "prajvalanīya": ['mw'],
    "prajvalita": ['ap90', 'cae', 'mw'],
    "prajvara": ['bhs'],
    "prajvālana": ['cae', 'mw'],
    "prajvālita": ['mw'],
    "prajvālā": ['cae', 'mw'],
    "prajvāra": ['mw'],
    "prajña": ['ap90', 'cae', 'ddsa', 'mw'],
    "prajñaka": ['mw'],
    "prajñapayati": ['bhs'],
    "prajñapta": ['bhs', 'mw'],
    "prajñaptaka": ['bhs'],
    "prajñapti": ['bhs', 'cae', 'mw'],
    "prajñaptikauśika": ['mw'],
    "prajñaptivādin": ['mw'],
    "prajñaptiśāstra": ['mw'],
    "prajñaptiḥ": ['ap90'],
    "prajñaptāpayati": ['bhs'],
    "prajñatā": ['cae', 'mw'],
    "prajñila": ['mw'],
    "prajñin": ['mw'],
    "prajñopaka": ['bhs'],
    "prajñu": ['ap90', 'mw'],
    "prajñā": ['ap90', 'bhs', 'ddsa', 'mw'],
    "prajñābhadra": ['mw'],
    "prajñācakṣus": ['cae', 'mw'],
    "prajñācandra": ['mw'],
    "prajñādeva": ['mw'],
    "prajñāditya": ['mw'],
    "prajñāghana": ['mw'],
    "prajñāgupta": ['mw'],
    "prajñāhīna": ['mw'],
    "prajñākara": ['mw'],
    "prajñākośa": ['mw'],
    "prajñākāya": ['mw'],
    "prajñākūṭa": ['bhs', 'mw'],
    "prajñāla": ['ap90', 'mw'],
    "prajñāmaya": ['mw'],
    "prajñāmātrā": ['mw'],
    "prajñāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "prajñānaghana": ['cae', 'mw'],
    "prajñānakumudacandrikā": ['mw'],
    "prajñānasaṃtati": ['mw'],
    "prajñānatṛpta": ['mw'],
    "prajñānendra": ['mw'],
    "prajñāntaka": ['bhs', 'mw'],
    "prajñānānanda": ['mw'],
    "prajñānāśrama": ['mw'],
    "prajñāpana": ['mw'],
    "prajñāpanapradeśavyākhyā": ['mw'],
    "prajñāpanopāṅga": ['mw'],
    "prajñāpanīya": ['mw'],
    "prajñāpayati": ['bhs'],
    "prajñāpayitavya": ['mw'],
    "prajñāpeta": ['mw'],
    "prajñāpita": ['mw'],
    "prajñāpradīpa": ['bhs'],
    "prajñāpradīpaprabhaketuśri": ['bhs'],
    "prajñāprakāśa": ['mw'],
    "prajñāpratibhāsita": ['mw'],
    "prajñāpti": ['bhs'],
    "prajñāptivādin": ['bhs'],
    "prajñāptiśāstra": ['bhs'],
    "prajñāpāramitā": ['bhs', 'ddsa', 'mw'],
    "prajñāpāramitāpañcaśatikā": ['bhs'],
    "prajñāpāramitāsūtra": ['mw'],
    "prajñāsahāya": ['mw'],
    "prajñāsāgara": ['mw'],
    "prajñāsūktamuktāvalī": ['mw'],
    "prajñāta": ['ap90', 'cae', 'ddsa', 'mw'],
    "prajñātavya": ['mw'],
    "prajñāti": ['mw'],
    "prajñātman": ['ddsa', 'mw'],
    "prajñātra": ['mw'],
    "prajñātāgra": ['mw'],
    "prajñātṛ": ['gra', 'mw'],
    "prajñāvabhāsaśrī": ['bhs'],
    "prajñāvant": ['bhs'],
    "prajñāvardhanastotra": ['mw'],
    "prajñāvarman": ['mw'],
    "prajñāvat": ['ap90', 'mw'],
    "prajñāvimukta": ['bhs'],
    "prajñāvimukti": ['bhs'],
    "prajñāvāda": ['cae', 'mw'],
    "prajñāvṛddha": ['mw'],
    "prajñāyate": ['bhs'],
    "prajñāḍhya": ['mw'],
    "prajā": ['ap90', 'ddsa', 'gra', 'mw'],
    "prajācandra": ['mw'],
    "prajādhara": ['mw'],
    "prajādharma": ['cae'],
    "prajādhyakṣa": ['mw'],
    "prajādvāra": ['mw'],
    "prajādā": ['mw'],
    "prajādāna": ['cae', 'ddsa', 'mw'],
    "prajāgara": ['cae', 'ddsa', 'mw'],
    "prajāgaraḥ": ['ap90'],
    "prajāgaraṇa": ['mw'],
    "prajāgarā": ['mw'],
    "prajāgarūka": ['mw'],
    "prajāghnī": ['mw'],
    "prajāgu": ['bhs'],
    "prajāgupti": ['ddsa', 'mw'],
    "prajāgṛ": ['ap90', 'mw'],
    "prajāhan": ['mw'],
    "prajāhita": ['cae', 'mw'],
    "prajākalpa": ['mw'],
    "prajākara": ['mw'],
    "prajākāma": ['cae', 'mw'],
    "prajākāra": ['mw'],
    "prajāmṛtatva": ['mw'],
    "prajānant": ['cae'],
    "prajānatā": ['bhs'],
    "prajāni": ['mw'],
    "prajāniṣeka": ['mw'],
    "prajāntaka": ['mw'],
    "prajānuka": ['mw'],
    "prajānā": ['mw'],
    "prajānātha": ['mw'],
    "prajānāti": ['bhs'],
    "prajāpa": ['mw'],
    "prajāpaddhati": ['mw'],
    "prajāparipālana": ['mw'],
    "prajāpati": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "prajāpatibhakṣita": ['mw'],
    "prajāpaticarita": ['mw'],
    "prajāpaticita": ['mw'],
    "prajāpaticiti": ['mw'],
    "prajāpatidatta": ['mw'],
    "prajāpatigṛhīta": ['mw'],
    "prajāpatihṛdaya": ['mw'],
    "prajāpatika": ['mw'],
    "prajāpatiloka": ['mw'],
    "prajāpatimukha": ['mw'],
    "prajāpatimātra": ['mw'],
    "prajāpatinivāsinī": ['bhs', 'mw'],
    "prajāpatipati": ['mw'],
    "prajāpatismṛti": ['mw'],
    "prajāpatisṛṣṭa": ['mw'],
    "prajāpatiyajña": ['mw'],
    "prajāpatiśarman": ['mw'],
    "prajāpatya": ['mw'],
    "prajāpatī": ['bhs', 'mw'],
    "prajāpayitṛ": ['mw'],
    "prajāpāla": ['cae', 'ddsa', 'mw'],
    "prajāpālana": ['cae', 'mw'],
    "prajāpāli": ['mw'],
    "prajāpālya": ['mw'],
    "prajārtham": ['mw'],
    "prajārthe": ['ddsa', 'mw'],
    "prajāsani": ['mw'],
    "prajāsṛj": ['mw'],
    "prajāta": ['ap90', 'cae', 'mw'],
    "prajātantu": ['mw'],
    "prajāti": ['cae', 'ddsa', 'mw'],
    "prajātikāma": ['mw'],
    "prajātimat": ['mw'],
    "prajātiḥ": ['ap90'],
    "prajātyānanda": ['mw'],
    "prajātā": ['mw'],
    "prajātīrtha": ['mw'],
    "prajāvant": ['cae'],
    "prajāvarī": ['mw'],
    "prajāvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "prajāvatī": ['mw'],
    "prajāvid": ['mw'],
    "prajāvyāpāra": ['mw'],
    "prajāvyṛddhapaśuvyṛddha": ['mw'],
    "prajāvṛddhi": ['ddsa', 'mw'],
    "prajāyin": ['ap90'],
    "prajāyinī": ['cae', 'ddsa', 'mw'],
    "prajāśānti": ['mw'],
    "prajīrṇa": ['mw'],
    "prajīvana": ['cae', 'mw'],
    "prajīvanaṃ": ['ap90'],
    "prajīvin": ['mw'],
    "prajū": ['ap90', 'mw'],
    "prajṛmbh": ['mw'],
    "prajṝ": ['mw'],
    "prakaca": ['bhs', 'mw'],
    "prakal": ['ap90', 'mw'],
    "prakalavid": ['gra', 'mw'],
    "prakalpaka": ['mw'],
    "prakalpana": ['mw'],
    "prakalpanā": ['ap90', 'cae', 'mw'],
    "prakalpayitṛ": ['mw'],
    "prakalpita": ['ap90', 'mw'],
    "prakalpitā": ['mw'],
    "prakalpya": ['mw'],
    "prakalyāṇa": ['mw'],
    "prakalā": ['ap90', 'gra', 'mw'],
    "prakamana": ['mw'],
    "prakamanīya": ['mw'],
    "prakamp": ['mw'],
    "prakampa": ['cae', 'ddsa', 'mw'],
    "prakampana": ['cae', 'mw'],
    "prakampanīya": ['mw'],
    "prakampin": ['cae', 'mw'],
    "prakampita": ['cae', 'mw'],
    "prakampya": ['mw'],
    "prakara": ['cae', 'ddsa', 'mw'],
    "prakaraḥ": ['ap90'],
    "prakaraṇa": ['cae', 'mw'],
    "prakaraṇapañcikā": ['mw'],
    "prakaraṇapāda": ['bhs', 'mw'],
    "prakaraṇasama": ['mw'],
    "prakaraṇatas": ['mw'],
    "prakaraṇatva": ['mw'],
    "prakaraṇavādārtha": ['mw'],
    "prakaraṇaśas": ['mw'],
    "prakaraṇaṃ": ['ap90'],
    "prakaraṇikā": ['ap90', 'bhs', 'mw'],
    "prakaraṇī": ['mw'],
    "prakarikā": ['ap90', 'mw'],
    "prakaritṛ": ['mw'],
    "prakartavya": ['mw'],
    "prakartṛ": ['mw'],
    "prakarī": ['ap90', 'mw'],
    "prakarṣa": ['cae', 'mw'],
    "prakarṣagamana": ['mw'],
    "prakarṣaka": ['mw'],
    "prakarṣakaḥ": ['ap90'],
    "prakarṣatantra": ['mw'],
    "prakarṣavat": ['mw'],
    "prakarṣaḥ": ['ap90'],
    "prakarṣaṇa": ['ap90', 'cae', 'mw'],
    "prakarṣaṇīya": ['mw'],
    "prakarṣeṇa": ['mw'],
    "prakarṣin": ['ap90', 'bhs', 'mw'],
    "prakarṣita": ['ap90', 'mw'],
    "prakarṣāt": ['mw'],
    "prakas": ['mw'],
    "prakath": ['ap90', 'mw'],
    "prakathana": ['mw'],
    "prakathanam": ['mw'],
    "prakathanaṃ": ['ap90'],
    "prakaśa": ['mw'],
    "prakaṃp": ['ap90'],
    "prakaṃpana": ['ap90'],
    "prakaṃpaḥ": ['ap90'],
    "prakaṃpin": ['ap90'],
    "prakaṅkata": ['gra', 'mw'],
    "prakaṇva": ['mw'],
    "prakaṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "prakaṭam": ['mw'],
    "prakaṭana": ['cae', 'mw'],
    "prakaṭanaṃ": ['ap90'],
    "prakaṭaprītivardhana": ['mw'],
    "prakaṭaraktāntanayana": ['mw'],
    "prakaṭati": ['ap90'],
    "prakaṭavaikṛta": ['mw'],
    "prakaṭay": ['cae'],
    "prakaṭaya": ['ddsa', 'mw'],
    "prakaṭayati": ['ap90'],
    "prakaṭaśīrṣa": ['cae', 'mw'],
    "prakaṭita": ['ap90', 'mw'],
    "prakaṭitahatāśeṣatamas": ['mw'],
    "prakaṭāprakaṭa": ['mw'],
    "prakaṭāya": ['mw'],
    "prakaṭī": ['mw'],
    "prakaṭībhū": ['mw'],
    "prakaṭībhūta": ['mw'],
    "prakaṭīkaraṇa": ['cae', 'mw'],
    "prakaṭīkṛ": ['cae', 'ddsa', 'mw'],
    "prakaṭīkṛta": ['mw'],
    "praketa": ['ap90', 'cae', 'gra', 'mw'],
    "praketana": ['mw'],
    "prakhala": ['cae', 'mw'],
    "prakhalati": ['bhs'],
    "prakhan": ['mw'],
    "prakhara": ['ap90', 'ddsa', 'mw'],
    "prakharati": ['bhs'],
    "prakhid": ['mw'],
    "prakhud": ['mw'],
    "prakhya": ['ap90', 'cae', 'mw'],
    "prakhyas": ['mw'],
    "prakhyā": ['ap90', 'mw'],
    "prakhyālana": ['bhs'],
    "prakhyāna": ['mw'],
    "prakhyānaṃ": ['ap90'],
    "prakhyānīya": ['mw'],
    "prakhyāpana": ['mw'],
    "prakhyāpanaṃ": ['ap90'],
    "prakhyāpanīya": ['mw'],
    "prakhyāpita": ['mw'],
    "prakhyāta": ['ap90', 'cae', 'mw'],
    "prakhyātabalavīrya": ['mw'],
    "prakhyātabhāṇḍa": ['mw'],
    "prakhyātasadbhartṛ": ['mw'],
    "prakhyātavaptṛka": ['mw'],
    "prakhyāti": ['mw'],
    "prakhyātiḥ": ['ap90'],
    "prakhyāyamāna": ['mw'],
    "prakhād": ['mw'],
    "prakhāda": ['gra', 'mw'],
    "prakiraṇa": ['cae', 'ddsa', 'mw'],
    "prakiraṇaṃ": ['ap90'],
    "prakkhara": ['ap90', 'mw'],
    "prakleda": ['cae', 'mw'],
    "prakledana": ['ap90', 'mw'],
    "prakledavat": ['mw'],
    "prakledaḥ": ['ap90'],
    "prakledin": ['mw'],
    "prakleditva": ['mw'],
    "praklid": ['mw'],
    "praklinna": ['ap90', 'mw'],
    "praklinnahṛdayekṣaṇa": ['mw'],
    "praklinnatva": ['mw'],
    "praklinnavartman": ['mw'],
    "prakliś": ['mw'],
    "prakopa": ['cae', 'mw'],
    "prakopana": ['ap90', 'cae', 'mw'],
    "prakopanīya": ['mw'],
    "prakopaḥ": ['ap90'],
    "prakopaṇa": ['cae', 'mw'],
    "prakopaṇī": ['cae'],
    "prakopaṇīya": ['mw'],
    "prakopin": ['mw'],
    "prakopita": ['ap90', 'mw'],
    "prakopitṛ": ['mw'],
    "prakotha": ['mw'],
    "prakothaḥ": ['ap90'],
    "prakothodaka": ['mw'],
    "prakoṣṇā": ['mw'],
    "prakoṣṭha": ['cae', 'mw'],
    "prakoṣṭhaka": ['mw'],
    "prakoṣṭhakaḥ": ['ap90'],
    "prakoṣṭhaḥ": ['ap90'],
    "prakram": ['ap90', 'mw'],
    "prakrama": ['cae', 'ddsa', 'mw'],
    "prakramabhaṅga": ['mw'],
    "prakramabhaṅgavat": ['mw'],
    "prakramatṛtīya": ['mw'],
    "prakramaviruddha": ['mw'],
    "prakramaḥ": ['ap90'],
    "prakramaṇa": ['cae', 'mw'],
    "prakramaṇaṃ": ['ap90'],
    "prakramaṇīya": ['mw'],
    "prakramitavya": ['mw'],
    "prakramitṛ": ['mw'],
    "prakramya": ['mw'],
    "prakrand": ['mw'],
    "prakrantṛ": ['mw'],
    "prakraya": ['mw'],
    "prakraṃtṛ": ['ap90'],
    "prakriyā": ['ap90', 'cae', 'mw'],
    "prakriyābhūṣaṇa": ['mw'],
    "prakriyākaumudī": ['mw'],
    "prakriyākaumudīvṛtti": ['mw'],
    "prakriyāmañjarī": ['mw'],
    "prakriyāpradīpa": ['mw'],
    "prakriyāratna": ['mw'],
    "prakriyārūpāvalī": ['mw'],
    "prakriyārṇava": ['mw'],
    "prakriyāsarvasva": ['mw'],
    "prakriyāsaṃgraha": ['mw'],
    "prakriyāsāra": ['mw'],
    "prakriyāñjanaṭīkā": ['mw'],
    "prakrośa": ['cae', 'mw'],
    "prakruś": ['mw'],
    "prakrāmaṇī": ['bhs', 'mw'],
    "prakrānta": ['cae', 'mw'],
    "prakrāntatva": ['mw'],
    "prakrāṃta": ['ap90'],
    "prakrī": ['cae', 'mw'],
    "prakrīḍ": ['mw'],
    "prakrīḍa": ['cae', 'mw'],
    "prakrīḍaḥ": ['ap90'],
    "prakrīḍin": ['cae', 'gra', 'mw'],
    "prakrīḍita": ['mw'],
    "prakubratā": ['mw'],
    "prakula": ['mw'],
    "prakulaṃ": ['ap90'],
    "prakup": ['ap90', 'mw'],
    "prakupita": ['ap90', 'mw'],
    "prakupta": ['mw'],
    "prakusumita": ['bhs'],
    "prakuthita": ['mw'],
    "prakuñca": ['mw'],
    "prakuṃcaḥ": ['ap90'],
    "prakuṭ": ['mw'],
    "prakvaṇ": ['mw'],
    "prakvaṇa": ['mw'],
    "prakvaṇaḥ": ['ap90'],
    "prakvātha": ['mw'],
    "prakvāṇa": ['mw'],
    "prakālana": ['ap90', 'mw'],
    "prakāma": ['ap90', 'cae', 'mw'],
    "prakāmabhuj": ['mw'],
    "prakāmam": ['mw'],
    "prakāmatas": ['mw'],
    "prakāmataḥ": ['ap90'],
    "prakāmavikasat": ['mw'],
    "prakāmavinata": ['mw'],
    "prakāmavistāra": ['mw'],
    "prakāmodya": ['cae', 'mw'],
    "prakāmālokanīyatā": ['mw'],
    "prakāmāntastapta": ['mw'],
    "prakānta": ['bhs'],
    "prakāra": ['bhs', 'cae', 'mw'],
    "prakāraka": ['mw'],
    "prakāratā": ['mw'],
    "prakāravat": ['mw'],
    "prakāraḥ": ['ap90'],
    "prakārya": ['mw'],
    "prakāś": ['ap90', 'mw'],
    "prakāśa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "prakāśadatta": ['mw'],
    "prakāśadevī": ['mw'],
    "prakāśadhara": ['mw'],
    "prakāśadharma": ['bhs'],
    "prakāśaka": ['ap90', 'cae', 'mw'],
    "prakāśakajñātṛ": ['mw'],
    "prakāśakaprajñātṛ": ['mw'],
    "prakāśakarman": ['mw'],
    "prakāśakartṛ": ['mw'],
    "prakāśakatva": ['mw'],
    "prakāśakraya": ['mw'],
    "prakāśakāma": ['mw'],
    "prakāśam": ['mw'],
    "prakāśana": ['ap90', 'cae', 'mw'],
    "prakāśanavat": ['mw'],
    "prakāśanā": ['bhs', 'mw'],
    "prakāśanārī": ['cae', 'mw'],
    "prakāśanīya": ['mw'],
    "prakāśasaptati": ['mw'],
    "prakāśasaṃhitā": ['mw'],
    "prakāśasūtra": ['mw'],
    "prakāśatva": ['mw'],
    "prakāśatā": ['ap90', 'mw'],
    "prakāśavant": ['cae'],
    "prakāśavarṇa": ['bhs'],
    "prakāśavarṣa": ['mw'],
    "prakāśavat": ['mw'],
    "prakāśavattva": ['mw'],
    "prakāśavañcaka": ['mw'],
    "prakāśavāda": ['mw'],
    "prakāśay": ['cae'],
    "prakāśe": ['mw'],
    "prakāśendra": ['mw'],
    "prakāśetara": ['cae', 'mw'],
    "prakāśikā": ['mw'],
    "prakāśin": ['ap90', 'cae', 'mw'],
    "prakāśita": ['ap90', 'mw'],
    "prakāśitaviruddhatva": ['mw'],
    "prakāśitaviruddhatā": ['mw'],
    "prakāśitva": ['mw'],
    "prakāśitā": ['cae', 'mw'],
    "prakāśodaya": ['mw'],
    "prakāśya": ['ap90', 'cae', 'mw'],
    "prakāśyatā": ['mw'],
    "prakāśāditya": ['mw'],
    "prakāśākāśakānti": ['mw'],
    "prakāśānanda": ['mw'],
    "prakāśātmaka": ['mw'],
    "prakāśātmakatva": ['mw'],
    "prakāśātman": ['mw'],
    "prakāśībhāva": ['mw'],
    "prakāśīkaraṇa": ['mw'],
    "prakāśīkṛ": ['cae', 'mw'],
    "prakāṃḍakaḥ": ['ap90'],
    "prakāṃḍaraḥ": ['ap90'],
    "prakāṃḍaḥ": ['ap90'],
    "prakāṅkṣ": ['mw'],
    "prakāṅkṣā": ['mw'],
    "prakāṇḍa": ['cae', 'mw'],
    "prakāṇḍara": ['mw'],
    "prakīrt": ['mw'],
    "prakīrtana": ['cae', 'ddsa', 'mw'],
    "prakīrtanaṃ": ['ap90'],
    "prakīrtanā": ['mw'],
    "prakīrti": ['cae', 'mw'],
    "prakīrtita": ['ap90', 'mw'],
    "prakīrtiḥ": ['ap90'],
    "prakīrya": ['mw'],
    "prakīrṇa": ['ap90', 'cae', 'mw'],
    "prakīrṇaka": ['ap90', 'cae', 'mw'],
    "prakīrṇakadāna": ['mw'],
    "prakīrṇakeśa": ['mw'],
    "prakīrṇakeśī": ['mw'],
    "prakīrṇalapitā": ['bhs'],
    "prakīrṇamaithuna": ['mw'],
    "prakīrṇamantra": ['mw'],
    "prakīrṇapūjā": ['mw'],
    "prakīrṇasaṃgraha": ['mw'],
    "prakīrṇavāc": ['mw'],
    "prakīrṇādhyāya": ['mw'],
    "prakīrṇāmbaramūrdhaja": ['mw'],
    "prakūj": ['mw'],
    "prakūjana": ['mw'],
    "prakūrd": ['mw'],
    "prakūṣmāṃḍī": ['ap90'],
    "prakūṣmāṇḍī": ['mw'],
    "prakūṭā": ['mw'],
    "prakḷp": ['ap90', 'mw'],
    "prakḷpta": ['ap90', 'cae', 'mw'],
    "prakḷptam": ['mw'],
    "prakḷptasnānamaṇḍana": ['mw'],
    "prakḷptatva": ['mw'],
    "prakḷpti": ['mw'],
    "prakṛ": ['ap90', 'mw'],
    "prakṛnta": ['mw'],
    "prakṛt": ['mw'],
    "prakṛta": ['ap90', 'bhs', 'cae', 'mw'],
    "prakṛtatva": ['mw'],
    "prakṛtatā": ['mw'],
    "prakṛti": ['bhs', 'cae', 'ddsa', 'mw'],
    "prakṛtibhava": ['mw'],
    "prakṛtibhojana": ['mw'],
    "prakṛtibhāva": ['mw'],
    "prakṛtibhūman": ['mw'],
    "prakṛtibhūta": ['mw'],
    "prakṛtibhūtekāra": ['mw'],
    "prakṛtiguṇa": ['mw'],
    "prakṛtigāna": ['mw'],
    "prakṛtihautra": ['mw'],
    "prakṛtija": ['cae', 'mw'],
    "prakṛtikalyāṇa": ['mw'],
    "prakṛtikhaṇḍa": ['mw'],
    "prakṛtikṛpaṇa": ['mw'],
    "prakṛtilaya": ['mw'],
    "prakṛtimant": ['cae'],
    "prakṛtimat": ['mw'],
    "prakṛtimaya": ['mw'],
    "prakṛtimañjarī": ['mw'],
    "prakṛtimaṇḍala": ['mw'],
    "prakṛtiniṣṭhura": ['mw'],
    "prakṛtipralaya": ['mw'],
    "prakṛtipuruṣa": ['cae', 'mw'],
    "prakṛtipāṭha": ['mw'],
    "prakṛtisampanna": ['mw'],
    "prakṛtisiddha": ['mw'],
    "prakṛtistha": ['cae', 'mw'],
    "prakṛtisthadarśana": ['cae', 'mw'],
    "prakṛtisthaka": ['bhs'],
    "prakṛtisthita": ['mw'],
    "prakṛtisubhaga": ['mw'],
    "prakṛtitarala": ['mw'],
    "prakṛtitattvanirūpaṇa": ['mw'],
    "prakṛtitva": ['mw'],
    "prakṛtivat": ['mw'],
    "prakṛtivihārakārikā": ['mw'],
    "prakṛtivikṛti": ['mw'],
    "prakṛtivikṛtisvabhāva": ['mw'],
    "prakṛtivikṛtiyāgakālaviveka": ['mw'],
    "prakṛtiviṣama": ['mw'],
    "prakṛtiśraiṣṭhya": ['mw'],
    "prakṛtiḥ": ['ap90'],
    "prakṛtiṣṭha": ['cae', 'mw'],
    "prakṛtokta": ['mw'],
    "prakṛtyā": ['mw'],
    "prakṛtyṛc": ['mw'],
    "prakṛtārtha": ['mw'],
    "prakṛtījana": ['mw'],
    "prakṛtīśa": ['mw'],
    "prakṛtīśarīraśiribhadra": ['bhs'],
    "prakṛtīṣṭinirṇaya": ['mw'],
    "prakṛśita": ['mw'],
    "prakṛṣ": ['ap90', 'mw'],
    "prakṛṣya": ['mw'],
    "prakṛṣyakutsita": ['mw'],
    "prakṛṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "prakṛṣṭakeśākhya": ['mw'],
    "prakṛṣṭatama": ['mw'],
    "prakṛṣṭatara": ['mw'],
    "prakṛṣṭatva": ['mw'],
    "prakṛṣṭatā": ['mw'],
    "prakṝ": ['ap90', 'mw'],
    "prakṝt": ['ap90', 'mw'],
    "prakṣ": ['ddsa', 'gra'],
    "prakṣa": ['mw'],
    "prakṣai": ['mw'],
    "prakṣal": ['ap90', 'mw'],
    "prakṣapaṇa": ['ddsa', 'mw'],
    "prakṣar": ['mw'],
    "prakṣara": ['ap90', 'mw'],
    "prakṣaraṇa": ['mw'],
    "prakṣaraṇaṃ": ['ap90'],
    "prakṣaya": ['cae', 'mw'],
    "prakṣayaḥ": ['ap90'],
    "prakṣayaṇa": ['mw'],
    "prakṣepa": ['cae', 'mw'],
    "prakṣepaka": ['mw'],
    "prakṣepalipi": ['bhs', 'mw'],
    "prakṣepaḥ": ['ap90'],
    "prakṣepaṇa": ['mw'],
    "prakṣepaṇaṃ": ['ap90'],
    "prakṣepaṇīya": ['mw'],
    "prakṣepin": ['mw'],
    "prakṣeptavya": ['mw'],
    "prakṣepya": ['mw'],
    "prakṣeḍā": ['bhs'],
    "prakṣi": ['ap90', 'mw'],
    "prakṣin": ['mw'],
    "prakṣip": ['ap90', 'mw'],
    "prakṣipta": ['ap90', 'mw'],
    "prakṣiptavat": ['mw'],
    "prakṣipya": ['mw'],
    "prakṣobhaṇa": ['mw'],
    "prakṣobhaṇaṃ": ['ap90'],
    "prakṣubh": ['ap90', 'mw'],
    "prakṣud": ['ap90', 'mw'],
    "prakṣuṇṇa": ['ap90', 'mw'],
    "prakṣvedana": ['mw'],
    "prakṣveḍana": ['bhs', 'mw'],
    "prakṣveḍanaḥ": ['ap90'],
    "prakṣveḍayati": ['bhs'],
    "prakṣveḍita": ['ap90', 'mw'],
    "prakṣveḍitavat": ['mw'],
    "prakṣveḍā": ['cae', 'mw'],
    "prakṣālaka": ['cae', 'mw'],
    "prakṣālana": ['cae', 'mw'],
    "prakṣālanaṃ": ['ap90'],
    "prakṣālanārthāya": ['mw'],
    "prakṣālanīya": ['mw'],
    "prakṣālayitṛ": ['mw'],
    "prakṣālita": ['ap90', 'mw'],
    "prakṣālitapāda": ['mw'],
    "prakṣālitapāṇi": ['mw'],
    "prakṣālya": ['mw'],
    "prakṣāma": ['mw'],
    "prakṣībita": ['mw'],
    "prakṣīvita": ['ap90', 'mw'],
    "prakṣīṇa": ['ap90', 'cae', 'mw'],
    "prakṣīṇacandra": ['mw'],
    "prakṣīṇapāpa": ['cae'],
    "prakṣṇu": ['mw'],
    "pralabdha": ['ap90', 'mw'],
    "pralabdhavya": ['mw'],
    "pralabdhṛ": ['mw'],
    "pralabh": ['ap90', 'mw'],
    "pralaghu": ['ddsa', 'mw'],
    "pralaghutā": ['mw'],
    "pralagna": ['bhs'],
    "pralalita": ['bhs'],
    "pralalāṭa": ['ap90', 'ddsa', 'mw'],
    "pralamb": ['mw'],
    "pralamba": ['cae', 'mw'],
    "pralambabhid": ['mw'],
    "pralambabhuja": ['mw'],
    "pralambabāhu": ['bhs', 'mw'],
    "pralambabāhutā": ['mw'],
    "pralambaghna": ['mw'],
    "pralambahan": ['mw'],
    "pralambahantṛ": ['mw'],
    "pralambaka": ['mw'],
    "pralambakeśa": ['cae', 'mw'],
    "pralambamathana": ['mw'],
    "pralambana": ['bhs', 'mw'],
    "pralambanāsika": ['mw'],
    "pralambatā": ['mw'],
    "pralambayati": ['bhs'],
    "pralambha": ['bhs', 'cae', 'mw'],
    "pralambhana": ['cae', 'mw'],
    "pralambin": ['cae', 'mw'],
    "pralambita": ['mw'],
    "pralambodara": ['bhs', 'mw'],
    "pralambojjvalacārughoṇa": ['mw'],
    "pralambā": ['bhs'],
    "pralambāri": ['mw'],
    "pralambāṇḍa": ['mw'],
    "pralambīkṛ": ['mw'],
    "pralamphana": ['mw'],
    "pralap": ['ap90', 'mw'],
    "pralapana": ['cae', 'mw'],
    "pralapanaṃ": ['ap90'],
    "pralapita": ['ap90', 'cae', 'mw'],
    "pralava": ['cae', 'mw'],
    "pralavana": ['cae', 'mw'],
    "pralavaḥ": ['ap90'],
    "pralavitra": ['mw'],
    "pralavitraṃ": ['ap90'],
    "pralavitṛ": ['mw'],
    "pralaya": ['cae', 'mw'],
    "pralayadahana": ['mw'],
    "pralayaghana": ['mw'],
    "pralayajaladharadhvāna": ['mw'],
    "pralayakevala": ['mw'],
    "pralayakāla": ['mw'],
    "pralayana": ['cae', 'mw'],
    "pralayasthitisarga": ['mw'],
    "pralayatva": ['mw'],
    "pralayatā": ['mw'],
    "pralayaḥ": ['ap90'],
    "pralayaṃkara": ['mw'],
    "pralayodaya": ['mw'],
    "pralayākala": ['mw'],
    "pralayāntaga": ['mw'],
    "pralaṃba": ['ap90'],
    "pralaṃbanaṃ": ['ap90'],
    "pralaṃbhanaṃ": ['ap90'],
    "pralaṃbhaḥ": ['ap90'],
    "pralaṃbita": ['ap90'],
    "pralaṃbīkṛ": ['ap90'],
    "praleha": ['mw'],
    "pralehaka": ['bhs'],
    "pralehana": ['mw'],
    "pralehaḥ": ['ap90'],
    "pralepa": ['ddsa', 'mw'],
    "pralepaka": ['ap90', 'bhs', 'mw'],
    "pralepana": ['mw'],
    "pralepaḥ": ['ap90'],
    "pralepikā": ['mw'],
    "pralepya": ['mw'],
    "pralhāda": ['ddsa'],
    "pralih": ['mw'],
    "pralikh": ['mw'],
    "pralip": ['mw'],
    "pralipa": ['mw'],
    "pralipta": ['mw'],
    "praliśa": ['mw'],
    "pralkārīya": ['mw'],
    "pralobha": ['cae', 'mw'],
    "pralobhaka": ['cae', 'mw'],
    "pralobhana": ['cae', 'mw'],
    "pralobhanaṃ": ['ap90'],
    "pralobhanī": ['ap90', 'mw'],
    "pralobhaḥ": ['ap90'],
    "pralobhin": ['ap90', 'mw'],
    "pralobhita": ['mw'],
    "pralobhya": ['ap90', 'cae', 'mw'],
    "pralola": ['ap90', 'mw'],
    "pralolupa": ['mw'],
    "pralopa": ['bhs', 'ddsa', 'mw'],
    "praloṭhana": ['mw'],
    "praloṭhanaṃ": ['ap90'],
    "praloṭhita": ['mw'],
    "pralubdha": ['mw'],
    "pralubdhā": ['mw'],
    "pralubh": ['ap90', 'mw'],
    "pralugna": ['bhs'],
    "pralujja": ['bhs'],
    "pralujjati": ['bhs'],
    "pralulita": ['bhs'],
    "pralup": ['mw'],
    "pralupta": ['mw'],
    "praluḍita": ['bhs'],
    "praluṭh": ['ap90', 'mw'],
    "praluṭhita": ['mw'],
    "pralāpa": ['cae', 'ddsa', 'mw'],
    "pralāpahan": ['mw'],
    "pralāpaikamaya": ['mw'],
    "pralāpaka": ['mw'],
    "pralāpana": ['mw'],
    "pralāpavant": ['cae'],
    "pralāpavat": ['mw'],
    "pralāpaḥ": ['ap90'],
    "pralāpin": ['ap90', 'cae', 'mw'],
    "pralāpitva": ['mw'],
    "pralāpitā": ['mw'],
    "pralāyam": ['mw'],
    "pralī": ['ap90', 'mw'],
    "pralīna": ['ap90', 'bhs', 'cae', 'mw'],
    "pralīnabhūpāla": ['mw'],
    "pralīnatva": ['mw'],
    "pralīnatā": ['mw'],
    "pralīnendriya": ['mw'],
    "pralīnendriyatva": ['mw'],
    "pralīyati": ['bhs'],
    "pralū": ['mw'],
    "pralūna": ['ap90', 'mw'],
    "pram": ['mw'],
    "pramad": ['ap90', 'cae', 'mw'],
    "pramada": ['ap90', 'bhs', 'cae', 'mw'],
    "pramadaka": ['ap90'],
    "pramadakaṇṭha": ['mw'],
    "pramadakānana": ['mw'],
    "pramadana": ['cae', 'mw'],
    "pramadanaṃ": ['ap90'],
    "pramadaropya": ['mw'],
    "pramadavana": ['cae', 'mw'],
    "pramaditavya": ['mw'],
    "pramadvara": ['ap90', 'cae', 'mw'],
    "pramadvarā": ['mw'],
    "pramadā": ['ap90', 'bhs', 'mw'],
    "pramadājana": ['cae', 'mw'],
    "pramadākānana": ['mw'],
    "pramadānana": ['mw'],
    "pramadāspada": ['mw'],
    "pramadāvana": ['cae', 'mw'],
    "pramadāvanapālikā": ['cae', 'mw'],
    "pramadāya": ['mw'],
    "pramaganda": ['gra', 'mw'],
    "pramagna": ['ap90', 'mw'],
    "pramahas": ['cae', 'gra', 'mw'],
    "pramajj": ['mw'],
    "praman": ['mw'],
    "pramanas": ['ap90', 'cae', 'mw'],
    "pramand": ['mw'],
    "pramanda": ['mw'],
    "pramandanī": ['mw'],
    "pramanth": ['mw'],
    "pramantha": ['cae', 'mw'],
    "pramanthu": ['mw'],
    "pramantra": ['mw'],
    "pramantā": ['bhs'],
    "pramanyu": ['ap90', 'cae', 'mw'],
    "pramara": ['cae', 'gra', 'mw'],
    "pramaraṇa": ['mw'],
    "pramarda": ['mw'],
    "pramardaka": ['bhs', 'mw'],
    "pramardana": ['bhs', 'cae', 'mw'],
    "pramardanaṃ": ['ap90'],
    "pramardin": ['cae', 'mw'],
    "pramardita": ['mw'],
    "pramarditṛ": ['cae', 'mw'],
    "pramata": ['ap90', 'mw'],
    "pramataka": ['mw'],
    "pramath": ['ap90', 'mw'],
    "pramatha": ['cae', 'mw'],
    "pramathaka": ['bhs'],
    "pramathana": ['cae', 'mw'],
    "pramathanaṃ": ['ap90'],
    "pramathanātha": ['mw'],
    "pramathapati": ['mw'],
    "pramathaprathama": ['mw'],
    "pramathaḥ": ['ap90'],
    "pramathin": ['ap90', 'mw'],
    "pramathita": ['ap90', 'mw'],
    "pramathitapuraḥsara": ['mw'],
    "pramathyā": ['mw'],
    "pramathā": ['mw'],
    "pramathādhipa": ['mw'],
    "pramathālaya": ['mw'],
    "pramati": ['cae', 'gra', 'mw'],
    "pramatta": ['ap90', 'cae', 'mw'],
    "pramattabandhu": ['bhs'],
    "pramattacitta": ['mw'],
    "pramattagīta": ['mw'],
    "pramattaka": ['bhs'],
    "pramattarajju": ['mw'],
    "pramattatā": ['ap90', 'mw'],
    "pramattavat": ['ap90', 'mw'],
    "pramattaśramaṇa": ['mw'],
    "pramaya": ['cae', 'mw'],
    "pramayaḥ": ['ap90'],
    "pramayu": ['cae', 'mw'],
    "pramayā": ['mw'],
    "pramaṃhiṣṭhīya": ['ddsa', 'mw'],
    "pramaṅgana": ['mw'],
    "pramaṅkana": ['mw'],
    "pramaṇas": ['ap90', 'cae', 'mw'],
    "pramaṇḍala": ['mw'],
    "pramaṇḍita": ['bhs'],
    "prame": ['mw'],
    "pramedita": ['ap90', 'mw'],
    "prameditavat": ['mw'],
    "prameha": ['mw'],
    "pramehana": ['mw'],
    "pramehaḥ": ['ap90'],
    "pramehaṇa": ['mw'],
    "pramehin": ['mw'],
    "prametos": ['mw'],
    "prameya": ['ap90', 'cae', 'ddsa', 'mw'],
    "prameyadīpikā": ['mw'],
    "prameyakamalamārtaṇḍa": ['mw'],
    "prameyamuktāvalī": ['mw'],
    "prameyamālā": ['mw'],
    "prameyanavamālikā": ['mw'],
    "prameyapariccheda": ['mw'],
    "prameyaratnāvalī": ['mw'],
    "prameyasaṃgraha": ['mw'],
    "prameyasaṃgrahavivaraṇa": ['mw'],
    "prameyasāra": ['mw'],
    "prameyasārasaṃgraha": ['mw'],
    "prameyatattvabodha": ['mw'],
    "prameyatva": ['mw'],
    "prameyaṭīkā": ['mw'],
    "prami": ['mw'],
    "pramid": ['ap90', 'mw'],
    "pramih": ['mw'],
    "pramilāyita": ['bhs'],
    "praminna": ['mw'],
    "pramita": ['ap90', 'cae', 'ddsa', 'mw'],
    "pramiti": ['cae', 'mw'],
    "pramitiḥ": ['ap90'],
    "pramitābha": ['mw'],
    "pramitākṣara": ['mw'],
    "pramitākṣarā": ['cae', 'mw'],
    "pramiya": ['gra'],
    "pramiyam": ['mw'],
    "pramiye": ['mw'],
    "pramlai": ['ap90', 'mw'],
    "pramlocantī": ['mw'],
    "pramlocā": ['mw'],
    "pramluc": ['mw'],
    "pramlāna": ['ap90', 'mw'],
    "pramlānavadana": ['mw'],
    "pramlānaśarīra": ['mw'],
    "pramlānībhū": ['mw'],
    "pramocaka": ['bhs'],
    "pramocana": ['cae', 'mw'],
    "pramocanaṃ": ['ap90'],
    "pramocanī": ['mw'],
    "pramocara": ['bhs'],
    "pramocin": ['bhs'],
    "pramoda": ['cae', 'mw'],
    "pramodacārin": ['mw'],
    "pramodaka": ['mw'],
    "pramodam": ['mw'],
    "pramodamāna": ['mw'],
    "pramodamānā": ['mw'],
    "pramodana": ['cae', 'mw'],
    "pramodanaṃ": ['ap90'],
    "pramodanṛtya": ['cae', 'mw'],
    "pramodatīrtha": ['mw'],
    "pramodaḥ": ['ap90'],
    "pramodin": ['ap90', 'cae', 'mw'],
    "pramodinī": ['mw'],
    "pramodita": ['ap90', 'mw'],
    "pramoditā": ['mw'],
    "pramodā": ['bhs'],
    "pramodāḍhyā": ['mw'],
    "pramoha": ['cae', 'mw'],
    "pramohacitta": ['mw'],
    "pramohana": ['cae', 'mw'],
    "pramohayitvā": ['bhs'],
    "pramohaḥ": ['ap90'],
    "pramohin": ['mw'],
    "pramohita": ['ap90', 'mw'],
    "pramoka": ['cae', 'ddsa', 'mw'],
    "pramoktavya": ['mw'],
    "pramokṣa": ['cae', 'mw'],
    "pramokṣaka": ['bhs', 'mw'],
    "pramokṣaḥ": ['ap90'],
    "pramokṣaṇa": ['bhs', 'mw'],
    "pramota": ['mw'],
    "pramoṣa": ['cae', 'mw'],
    "pramrad": ['mw'],
    "pramuc": ['ap90', 'mw'],
    "pramuca": ['mw'],
    "pramuci": ['mw'],
    "pramucu": ['mw'],
    "pramucyamānahoma": ['mw'],
    "pramud": ['ap90', 'cae', 'gra', 'mw'],
    "pramudita": ['ap90', 'cae', 'mw'],
    "pramuditahṛdaya": ['mw'],
    "pramuditanayanajagadvirocanā": ['bhs'],
    "pramuditapralambasunayana": ['bhs', 'mw'],
    "pramuditavadanā": ['mw'],
    "pramuditavat": ['mw'],
    "pramuditā": ['bhs', 'mw'],
    "pramugdha": ['ap90', 'cae', 'mw'],
    "pramuh": ['ap90', 'mw'],
    "pramukha": ['ap90', 'cae', 'mw'],
    "pramukhatas": ['mw'],
    "pramukhatva": ['mw'],
    "pramukhatā": ['mw'],
    "pramukhe": ['mw'],
    "pramukhī": ['bhs'],
    "pramukta": ['ap90', 'mw'],
    "pramuktaka": ['bhs'],
    "pramukti": ['cae', 'ddsa', 'mw'],
    "pramurch": ['mw'],
    "pramuñca": ['bhs'],
    "pramuñcaka": ['bhs'],
    "pramuñcana": ['bhs'],
    "pramuñcati": ['bhs'],
    "pramuṣ": ['ap90', 'mw'],
    "pramuṣita": ['ap90', 'mw'],
    "pramuṣitā": ['mw'],
    "pramā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pramāda": ['bhs', 'cae', 'gra', 'mw'],
    "pramādabandhu": ['bhs'],
    "pramādacārin": ['mw'],
    "pramādapāṭha": ['mw'],
    "pramādavat": ['ap90', 'mw'],
    "pramādaḥ": ['ap90'],
    "pramādikā": ['ap90', 'mw'],
    "pramādin": ['ap90', 'cae', 'mw'],
    "pramādita": ['ap90', 'mw'],
    "pramāditā": ['mw'],
    "pramāpaka": ['ap90', 'mw'],
    "pramāpayitṛ": ['ap90', 'mw'],
    "pramāpayitṛtva": ['mw'],
    "pramāpaṇa": ['cae', 'mw'],
    "pramāpaṇaṃ": ['ap90'],
    "pramāpin": ['mw'],
    "pramāpita": ['mw'],
    "pramāra": ['cae', 'mw'],
    "pramārjaka": ['cae', 'mw'],
    "pramārjana": ['cae', 'mw'],
    "pramārjanaṃ": ['ap90'],
    "pramātavya": ['mw'],
    "pramātha": ['cae', 'ddsa', 'mw'],
    "pramāthaḥ": ['ap90'],
    "pramāthin": ['ap90', 'bhs', 'cae', 'mw'],
    "pramāthinī": ['mw'],
    "pramāthita": ['ap90', 'mw'],
    "pramātra": ['bhs', 'mw'],
    "pramātva": ['ddsa', 'mw'],
    "pramātvacihna": ['mw'],
    "pramātāmaha": ['ddsa', 'mw'],
    "pramātāmahaḥ": ['ap90'],
    "pramātāmahī": ['mw'],
    "pramātṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "pramātṛtva": ['mw'],
    "pramātṛtā": ['mw'],
    "pramāyu": ['cae', 'mw'],
    "pramāyuka": ['cae', 'mw'],
    "pramāṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "pramāṇabhakti": ['mw'],
    "pramāṇabhāṣyaṭīkā": ['mw'],
    "pramāṇabhūta": ['mw'],
    "pramāṇadarpaṇa": ['mw'],
    "pramāṇadṛṣṭa": ['mw'],
    "pramāṇajña": ['mw'],
    "pramāṇajāla": ['mw'],
    "pramāṇaka": ['ap90', 'mw'],
    "pramāṇakhaṇḍana": ['mw'],
    "pramāṇakoṭi": ['mw'],
    "pramāṇakuśala": ['mw'],
    "pramāṇalakṣaṇa": ['mw'],
    "pramāṇalakṣaṇaparīkṣā": ['mw'],
    "pramāṇamañjarī": ['mw'],
    "pramāṇamālā": ['mw'],
    "pramāṇanirṇaya": ['mw'],
    "pramāṇanāmamālā": ['mw'],
    "pramāṇapaddhati": ['mw'],
    "pramāṇapadārtha": ['mw'],
    "pramāṇapallava": ['mw'],
    "pramāṇapatha": ['mw'],
    "pramāṇapattra": ['mw'],
    "pramāṇapramoda": ['mw'],
    "pramāṇapravīṇa": ['mw'],
    "pramāṇapuruṣa": ['mw'],
    "pramāṇapārāyaṇa": ['mw'],
    "pramāṇaratnamālā": ['mw'],
    "pramāṇarāśi": ['mw'],
    "pramāṇasamuccaya": ['mw'],
    "pramāṇasaṃgraha": ['mw'],
    "pramāṇasiddhi": ['mw'],
    "pramāṇastha": ['mw'],
    "pramāṇasāra": ['mw'],
    "pramāṇasāraprakāśikā": ['mw'],
    "pramāṇasūtra": ['cae', 'mw'],
    "pramāṇatara": ['mw'],
    "pramāṇataratva": ['mw'],
    "pramāṇatas": ['mw'],
    "pramāṇatattva": ['mw'],
    "pramāṇatva": ['mw'],
    "pramāṇatā": ['mw'],
    "pramāṇavat": ['mw'],
    "pramāṇaviniścaya": ['mw'],
    "pramāṇavākya": ['mw'],
    "pramāṇavārttika": ['mw'],
    "pramāṇay": ['cae'],
    "pramāṇaya": ['ddsa', 'mw'],
    "pramāṇayati": ['ap90'],
    "pramāṇayukta": ['mw'],
    "pramāṇaśāstra": ['mw'],
    "pramāṇaṃ": ['ap90'],
    "pramāṇaṭīkā": ['mw'],
    "pramāṇika": ['ap90', 'bhs'],
    "pramāṇikā": ['mw'],
    "pramāṇin": ['bhs'],
    "pramāṇita": ['mw'],
    "pramāṇābhyadhika": ['mw'],
    "pramāṇābhāva": ['mw'],
    "pramāṇādarśa": ['mw'],
    "pramāṇādhika": ['cae', 'mw'],
    "pramāṇādinirūpaṇa": ['mw'],
    "pramāṇādiprakāśikā": ['mw'],
    "pramāṇāntara": ['mw'],
    "pramāṇāntaratā": ['mw'],
    "pramāṇānurūpa": ['mw'],
    "pramāṇāyāmatas": ['mw'],
    "pramāṇī": ['mw'],
    "pramāṇībhūta": ['mw'],
    "pramāṇīkaraṇa": ['ddsa', 'mw'],
    "pramāṇīkṛ": ['ap90', 'cae'],
    "pramāṇīkṛta": ['mw'],
    "pramī": ['ap90', 'mw'],
    "pramīl": ['mw'],
    "pramīlaka": ['mw'],
    "pramīlikā": ['mw'],
    "pramīlin": ['mw'],
    "pramīlita": ['ap90', 'mw'],
    "pramīlā": ['ap90', 'mw'],
    "pramīta": ['ap90', 'cae', 'mw'],
    "pramītapatikā": ['ddsa', 'mw'],
    "pramīti": ['cae', 'mw'],
    "pramītiḥ": ['ap90'],
    "pramīv": ['mw'],
    "pramīya": ['mw'],
    "pramīḍha": ['ap90', 'mw'],
    "pramīṇat": ['mw'],
    "pramūra": ['gra', 'mw'],
    "pramūrch": ['mw'],
    "pramūrchita": ['bhs'],
    "pramūrṇa": ['mw'],
    "pramūtrita": ['mw'],
    "pramūḍha": ['ap90', 'cae', 'mw'],
    "pramūḍhasaṃjña": ['mw'],
    "pramūṣikā": ['mw'],
    "pramṛ": ['mw'],
    "pramṛd": ['mw'],
    "pramṛgam": ['mw'],
    "pramṛgya": ['ddsa', 'mw'],
    "pramṛj": ['ap90', 'mw'],
    "pramṛta": ['ap90', 'cae', 'mw'],
    "pramṛtaka": ['mw'],
    "pramṛś": ['mw'],
    "pramṛśa": ['cae', 'mw'],
    "pramṛḍa": ['cae', 'mw'],
    "pramṛṇ": ['mw'],
    "pramṛṇa": ['cae', 'gra', 'mw'],
    "pramṛṣ": ['mw'],
    "pramṛṣya": ['mw'],
    "pramṛṣṭa": ['ap90', 'cae', 'mw'],
    "pramṛṣṭi": ['cae', 'mw'],
    "pramṝ": ['mw'],
    "pranabh": ['mw'],
    "pranakṣ": ['mw'],
    "pranapti": ['bhs'],
    "pranaptṛ": ['ap90', 'mw'],
    "pranard": ['mw'],
    "pranardaka": ['mw'],
    "pranartita": ['ap90', 'mw'],
    "pranaṣṭa": ['ap90', 'cae', 'mw'],
    "pranaṣṭaduḥkha": ['bhs'],
    "pranaṣṭajñānika": ['mw'],
    "pranaṣṭasvāmika": ['cae', 'mw'],
    "pranaṣṭavinaya": ['mw'],
    "pranaṣṭādhigata": ['cae', 'mw'],
    "pranibhid": ['mw'],
    "pranighātana": ['mw'],
    "pranighātanaṃ": ['ap90'],
    "pranikṣaṇa": ['mw'],
    "pranindana": ['mw'],
    "pranirakṣ": ['mw'],
    "praniṃsita": ['mw'],
    "praniṃsitavya": ['mw'],
    "pranud": ['mw'],
    "pranāla": ['mw'],
    "pranālaḥ": ['ap90'],
    "pranāyaka": ['ap90', 'mw'],
    "pranāśin": ['mw'],
    "pranīḍa": ['mw'],
    "pranṛt": ['ap90', 'mw'],
    "pranṛtta": ['ap90', 'ddsa', 'mw'],
    "pranṛttavat": ['mw'],
    "pranṛtya": ['mw'],
    "pranṛtyavat": ['mw'],
    "prapac": ['mw'],
    "prapad": ['ap90', 'cae', 'mw'],
    "prapada": ['cae', 'gra', 'mw'],
    "prapadais": ['mw'],
    "prapadam": ['mw'],
    "prapadana": ['mw'],
    "prapadanaṃ": ['ap90'],
    "prapadaṃ": ['ap90'],
    "prapadīna": ['ap90', 'mw'],
    "prapakva": ['ddsa', 'mw'],
    "prapakṣa": ['mw'],
    "prapakṣaḥ": ['ap90'],
    "prapalāna": ['bhs'],
    "prapalāy": ['mw'],
    "prapalāyana": ['cae', 'mw'],
    "prapalāyanaṃ": ['ap90'],
    "prapalāyin": ['ap90', 'mw'],
    "prapalāyita": ['ap90', 'mw'],
    "prapalāśa": ['mw'],
    "prapanna": ['ap90', 'cae', 'mw'],
    "prapannadinacaryā": ['mw'],
    "prapannaduṣṭāriṣṭaśānti": ['mw'],
    "prapannagatidīpikā": ['mw'],
    "prapannalakṣaṇa": ['mw'],
    "prapannamālikā": ['mw'],
    "prapannapāla": ['mw'],
    "prapannapārijāta": ['mw'],
    "prapannāmṛta": ['mw'],
    "prapannārtihara": ['mw'],
    "prapannāḍa": ['mw'],
    "prapannāḍaḥ": ['ap90'],
    "praparīkṣ": ['mw'],
    "praparīkṣate": ['bhs'],
    "praparṇa": ['ap90', 'mw'],
    "prapat": ['ap90', 'mw'],
    "prapata": ['bhs'],
    "prapatana": ['cae', 'mw'],
    "prapatanaṃ": ['ap90'],
    "prapatha": ['ap90', 'cae', 'gra', 'mw'],
    "prapathin": ['cae', 'gra', 'mw'],
    "prapathya": ['ap90', 'mw'],
    "prapathyā": ['mw'],
    "prapathā": ['mw'],
    "prapati": ['bhs'],
    "prapatita": ['ap90', 'mw'],
    "prapatiṣṇu": ['mw'],
    "prapatnī": ['bhs'],
    "prapatti": ['mw'],
    "prapattipariśīlana": ['mw'],
    "prapattyupādhitvaniṣedha": ['mw'],
    "prapautra": ['cae', 'ddsa', 'mw'],
    "prapautraḥ": ['ap90'],
    "prapautrī": ['mw'],
    "prapauṇḍarīka": ['mw'],
    "prapavana": ['mw'],
    "prapavanīya": ['mw'],
    "prapavaṇa": ['mw'],
    "prapavaṇīya": ['mw'],
    "prapañc": ['mw'],
    "prapañca": ['bhs', 'cae', 'mw'],
    "prapañcabuddhi": ['mw'],
    "prapañcacatura": ['mw'],
    "prapañcaka": ['mw'],
    "prapañcamithyātva": ['mw'],
    "prapañcamithyātvānumāna": ['mw'],
    "prapañcamithyātvānumānakhaṇḍana": ['mw'],
    "prapañcamithyātvānumānakhaṇḍanaparaśu": ['mw'],
    "prapañcana": ['bhs', 'cae', 'mw'],
    "prapañcanirmāṇa": ['mw'],
    "prapañcasāra": ['mw'],
    "prapañcasārasārasaṃgraha": ['mw'],
    "prapañcasāraviveka": ['mw'],
    "prapañcatas": ['mw'],
    "prapañcatva": ['mw'],
    "prapañcavacana": ['mw'],
    "prapañcaviveka": ['mw'],
    "prapañcay": ['cae'],
    "prapañcaya": ['mw'],
    "prapañcayati": ['bhs'],
    "prapañcena": ['mw'],
    "prapañcikā": ['mw'],
    "prapañcita": ['bhs', 'mw'],
    "prapañcāmṛtasāra": ['mw'],
    "prapañcāsya": ['mw'],
    "prapaś": ['mw'],
    "prapaśyamāna": ['mw'],
    "prapaśyat": ['mw'],
    "prapaṃcaka": ['ap90'],
    "prapaṃcanaṃ": ['ap90'],
    "prapaṃcayati": ['ap90'],
    "prapaṃcaḥ": ['ap90'],
    "prapaṃcita": ['ap90'],
    "prapaṇa": ['mw'],
    "prapaṇaḥ": ['ap90'],
    "prapaṭh": ['ap90', 'mw'],
    "prapharvidā": ['mw'],
    "prapharvī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prapharvīdā": ['mw'],
    "praphulla": ['ap90', 'cae', 'mw'],
    "praphullana": ['bhs'],
    "praphullanagavat": ['mw'],
    "praphullanayana": ['mw'],
    "praphullanetra": ['mw'],
    "praphullavadana": ['mw'],
    "praphullin": ['bhs'],
    "praphullita": ['bhs'],
    "praphulta": ['ap90', 'mw'],
    "praphulti": ['mw'],
    "praphultiḥ": ['ap90'],
    "prapinv": ['mw'],
    "prapitsu": ['mw'],
    "prapitva": ['cae', 'gra', 'mw'],
    "prapitāmaha": ['cae', 'ddsa', 'mw'],
    "prapitāmahaḥ": ['ap90'],
    "prapitāmahī": ['mw'],
    "prapitṛvya": ['mw'],
    "prapitṛvyaḥ": ['ap90'],
    "prapiṣ": ['mw'],
    "prapiṣṭa": ['cae', 'mw'],
    "prapiṣṭabhāga": ['mw'],
    "praplu": ['mw'],
    "prapluta": ['cae', 'mw'],
    "praplāvana": ['mw'],
    "praprajan": ['mw'],
    "praprapṝ": ['mw'],
    "praprarṣ": ['mw'],
    "praprasthā": ['mw'],
    "prapravī": ['mw'],
    "prapraśaṃs": ['mw'],
    "prapraśru": ['mw'],
    "prapre": ['mw'],
    "praprotha": ['cae', 'mw'],
    "prapruth": ['mw'],
    "praprās": ['mw'],
    "praprī": ['mw'],
    "praprīṇayati": ['bhs'],
    "prapunāḍa": ['mw'],
    "prapunāṭa": ['mw'],
    "prapunāṭaḥ": ['ap90'],
    "prapurāṇa": ['mw'],
    "praputh": ['mw'],
    "praputra": ['mw'],
    "praputraḥ": ['ap90'],
    "prapuṃnaḍa": ['mw'],
    "prapuṃnāla": ['mw'],
    "prapuṃnāḍa": ['mw'],
    "prapuṃnāṭa": ['mw'],
    "prapuṇḍarīka": ['mw'],
    "prapuṣ": ['mw'],
    "prapuṣpaka": ['bhs'],
    "prapuṣpita": ['ap90', 'mw'],
    "prapuṭa": ['mw'],
    "prapyai": ['mw'],
    "prapyasa": ['mw'],
    "prapyāna": ['mw'],
    "prapyāta": ['mw'],
    "prapyāyana": ['mw'],
    "prapyāyanaṃ": ['ap90'],
    "prapyāyanīya": ['mw'],
    "prapyāyayitṛ": ['mw'],
    "prapā": ['ap90', 'cae', 'gra', 'mw'],
    "prapācayati": ['bhs'],
    "prapāda": ['mw'],
    "prapādaḥ": ['ap90'],
    "prapādika": ['mw'],
    "prapādikaḥ": ['ap90'],
    "prapāduka": ['mw'],
    "prapādīka": ['mw'],
    "prapāka": ['mw'],
    "prapākaḥ": ['ap90'],
    "prapālaka": ['cae', 'mw'],
    "prapālana": ['cae', 'mw'],
    "prapālanaṃ": ['ap90'],
    "prapālin": ['ap90', 'mw'],
    "prapāmaṇḍapa": ['mw'],
    "prapāna": ['cae', 'mw'],
    "prapānaka": ['mw'],
    "prapānakaṃ": ['ap90'],
    "prapānaṃ": ['ap90'],
    "prapāpālikā": ['cae', 'mw'],
    "prapāpālī": ['mw'],
    "prapāpūraṇa": ['mw'],
    "prapāpūraṇīya": ['mw'],
    "prapāta": ['bhs', 'cae', 'mw'],
    "prapātam": ['mw'],
    "prapātana": ['cae', 'mw'],
    "prapātanaṃ": ['ap90'],
    "prapātaḥ": ['ap90'],
    "prapātha": ['mw'],
    "prapāthaḥ": ['ap90'],
    "prapātin": ['ap90', 'mw'],
    "prapātābhimukha": ['mw'],
    "prapātāmbu": ['mw'],
    "prapāvana": ['mw'],
    "prapāyin": ['mw'],
    "prapāṇa": ['cae', 'gra', 'mw'],
    "prapāṇi": ['mw'],
    "prapāṇika": ['mw'],
    "prapāṇiḥ": ['ap90'],
    "prapāṇīya": ['mw'],
    "prapāṇḍara": ['bhs'],
    "prapāṇḍu": ['mw'],
    "prapāṇḍura": ['mw'],
    "prapāṭha": ['cae', 'mw'],
    "prapāṭhaka": ['cae', 'mw'],
    "prapāṭhakaḥ": ['ap90'],
    "prapāṭhita": ['mw'],
    "prapāṭikā": ['bhs', 'mw'],
    "prapī": ['mw'],
    "prapīna": ['ap90', 'mw'],
    "prapīta": ['ap90', 'mw'],
    "prapīti": ['mw'],
    "prapīḍ": ['ap90', 'mw'],
    "prapīḍana": ['bhs', 'mw'],
    "prapīḍanaṃ": ['ap90'],
    "prapīḍita": ['mw'],
    "prapūj": ['mw'],
    "prapūjita": ['mw'],
    "prapūra": ['bhs'],
    "prapūraka": ['ap90', 'mw'],
    "prapūraṇa": ['mw'],
    "prapūraṇaṃ": ['ap90'],
    "prapūrikā": ['mw'],
    "prapūrita": ['ap90', 'mw'],
    "prapūrvagaḥ": ['ap90'],
    "prapṛ": ['mw'],
    "prapṛc": ['mw'],
    "prapṛthak": ['mw'],
    "prapṛṣṭha": ['ap90', 'mw'],
    "prapṝ": ['ap90', 'mw'],
    "prarad": ['mw'],
    "prarakṣ": ['mw'],
    "prarakṣa": ['mw'],
    "prarakṣaṇa": ['cae', 'ddsa', 'mw'],
    "prarakṣaṇaṃ": ['ap90'],
    "prarakṣita": ['mw'],
    "praram": ['mw'],
    "prarap": ['mw'],
    "prarapś": ['mw'],
    "praratham": ['mw'],
    "praraṇati": ['bhs'],
    "prarcchaka": ['mw'],
    "prarecana": ['gra', 'mw'],
    "prarej": ['mw'],
    "prareka": ['cae', 'gra', 'mw'],
    "praric": ['mw'],
    "prarikvan": ['gra', 'mw'],
    "prarkṣīya": ['mw'],
    "prarocana": ['ap90', 'cae', 'mw'],
    "prarocanā": ['mw'],
    "prarocita": ['mw'],
    "prarodana": ['bhs'],
    "prarodhana": ['cae', 'mw'],
    "praroha": ['cae', 'mw'],
    "prarohaka": ['mw'],
    "prarohavat": ['mw'],
    "prarohaḥ": ['ap90'],
    "prarohaṇa": ['mw'],
    "prarohaṇaṃ": ['ap90'],
    "prarohin": ['ap90', 'cae', 'mw'],
    "prarohiśākhin": ['mw'],
    "praropita": ['mw'],
    "praru": ['mw'],
    "praruc": ['ap90', 'mw'],
    "prarucira": ['bhs'],
    "prarud": ['mw'],
    "prarudh": ['mw'],
    "prarudita": ['ap90', 'mw'],
    "praruh": ['ap90', 'mw'],
    "praruj": ['mw'],
    "praruja": ['cae', 'mw'],
    "praruṇḍa": ['bhs'],
    "prarādhas": ['mw'],
    "prarādhya": ['mw'],
    "prarī": ['mw'],
    "prarūp": ['mw'],
    "prarūpaṇa": ['mw'],
    "prarūḍha": ['ap90', 'cae', 'mw'],
    "prarūḍhakakṣa": ['mw'],
    "prarūḍhakeśa": ['mw'],
    "prarūḍhamūla": ['mw'],
    "prarūḍhaśāli": ['mw'],
    "prarūḍhi": ['cae', 'mw'],
    "prarūḍhiḥ": ['ap90'],
    "prarṣabhīya": ['mw'],
    "pras": ['ap90', 'mw'],
    "prasabha": ['bhs', 'cae', 'mw'],
    "prasabhadamana": ['cae', 'mw'],
    "prasabhaharaṇa": ['mw'],
    "prasabham": ['mw'],
    "prasabhaḥ": ['ap90'],
    "prasabhoddhṛta": ['mw'],
    "prasabhoddhṛtāri": ['mw'],
    "prasac": ['mw'],
    "prasad": ['ap90', 'mw'],
    "prasadaniya": ['bhs'],
    "prasadman": ['gra', 'mw'],
    "prasah": ['ap90', 'cae', 'gra', 'mw'],
    "prasaha": ['ap90', 'cae', 'mw'],
    "prasahana": ['mw'],
    "prasahanaḥ": ['ap90'],
    "prasahiṣṇu": ['mw'],
    "prasahvan": ['cae', 'mw'],
    "prasahya": ['ap90', 'cae', 'mw'],
    "prasahyacaura": ['mw'],
    "prasahyaharaṇa": ['mw'],
    "prasahyakārin": ['mw'],
    "prasahyoḍhā": ['mw'],
    "prasahā": ['mw'],
    "prasajya": ['ap90', 'mw'],
    "prasajyapratiṣedha": ['mw'],
    "prasajyapratiṣedhatva": ['mw'],
    "prasajyatā": ['mw'],
    "prasakala": ['ddsa', 'mw'],
    "prasakta": ['ap90', 'cae', 'mw'],
    "prasaktadhī": ['mw'],
    "prasaktahṛdaya": ['mw'],
    "prasaktam": ['mw'],
    "prasaktavya": ['mw'],
    "prasakti": ['cae', 'mw'],
    "prasaktiḥ": ['ap90'],
    "prasaktāśrumukha": ['mw'],
    "prasakṣin": ['gra', 'mw'],
    "prasala": ['mw'],
    "prasalavi": ['cae', 'mw'],
    "prasalaḥ": ['ap90'],
    "prasameti": ['bhs'],
    "prasampaś": ['mw'],
    "prasamīkṣ": ['mw'],
    "prasamīkṣaṇa": ['mw'],
    "prasamīkṣaṇaṃ": ['ap90'],
    "prasamīkṣita": ['mw'],
    "prasamīkṣya": ['mw'],
    "prasamīkṣyaparīkṣaka": ['mw'],
    "prasamīkṣā": ['mw'],
    "prasamīḍ": ['mw'],
    "prasan": ['mw'],
    "prasanna": ['ap90', 'bhs', 'cae', 'mw'],
    "prasannabuddhi": ['bhs'],
    "prasannacandra": ['mw'],
    "prasannacaṇḍikā": ['mw'],
    "prasannagātra": ['bhs'],
    "prasannagātratā": ['mw'],
    "prasannajala": ['cae', 'mw'],
    "prasannakalpa": ['mw'],
    "prasannamukha": ['cae', 'mw'],
    "prasannaprāya": ['cae', 'mw'],
    "prasannapāda": ['mw'],
    "prasannarasa": ['cae', 'mw'],
    "prasannarāghava": ['mw'],
    "prasannasalila": ['cae', 'mw'],
    "prasannatarka": ['cae', 'mw'],
    "prasannateyu": ['mw'],
    "prasannatva": ['mw'],
    "prasannatā": ['mw'],
    "prasannavadanotpalagandhakūṭa": ['bhs'],
    "prasannavarṇa": ['bhs'],
    "prasannaveṅkaṭeśvaramāhātmya": ['mw'],
    "prasannerā": ['mw'],
    "prasannā": ['mw'],
    "prasannātman": ['cae', 'mw'],
    "prasara": ['cae', 'mw'],
    "prasarayuta": ['mw'],
    "prasaraḥ": ['ap90'],
    "prasaraṇa": ['cae', 'mw'],
    "prasaraṇaṃ": ['ap90'],
    "prasaraṇi": ['mw'],
    "prasaraṇiḥ": ['ap90'],
    "prasaraṇī": ['mw'],
    "prasaraṇīya": ['bhs'],
    "prasarga": ['cae', 'gra', 'mw'],
    "prasargaḥ": ['ap90'],
    "prasarjana": ['mw'],
    "prasarpa": ['mw'],
    "prasarpaka": ['mw'],
    "prasarpaḥ": ['ap90'],
    "prasarpaṇa": ['gra', 'mw'],
    "prasarpaṇaṃ": ['ap90'],
    "prasarpin": ['ap90', 'mw'],
    "prasarpita": ['mw'],
    "prasarā": ['mw'],
    "prasatta": ['cae', 'mw'],
    "prasatti": ['cae', 'mw'],
    "prasattiḥ": ['ap90'],
    "prasava": ['cae', 'ddsa', 'gra', 'mw'],
    "prasavabandhana": ['mw'],
    "prasavadharman": ['mw'],
    "prasavadharmin": ['mw'],
    "prasavagṛha": ['mw'],
    "prasavaka": ['mw'],
    "prasavakarmakṛt": ['mw'],
    "prasavakaḥ": ['ap90'],
    "prasavakāla": ['mw'],
    "prasavamāsa": ['mw'],
    "prasavana": ['cae', 'mw'],
    "prasavanaṃ": ['ap90'],
    "prasavantī": ['mw'],
    "prasavasamaya": ['mw'],
    "prasavasthalī": ['mw'],
    "prasavasthāna": ['mw'],
    "prasavat": ['mw'],
    "prasavate": ['bhs'],
    "prasavati": ['bhs'],
    "prasavavedanā": ['cae', 'mw'],
    "prasavavikāra": ['mw'],
    "prasavaḥ": ['ap90'],
    "prasavaṃtī": ['ap90'],
    "prasavin": ['cae', 'mw'],
    "prasavitra": ['mw'],
    "prasavitrī": ['ap90', 'mw'],
    "prasavitṛ": ['ap90', 'cae', 'mw'],
    "prasavonmukha": ['mw'],
    "prasavotthāna": ['mw'],
    "prasavya": ['ap90', 'cae', 'mw'],
    "prasavyam": ['mw'],
    "prasavāpitā": ['mw'],
    "prasavāyitā": ['bhs'],
    "prasavītṛ": ['cae', 'gra', 'mw'],
    "prasayana": ['mw'],
    "prasayanaṃ": ['ap90'],
    "prasañj": ['mw'],
    "prasañjana": ['mw'],
    "prasañjayitavya": ['mw'],
    "prasaṃcakṣ": ['mw'],
    "prasaṃdhi": ['mw'],
    "prasaṃdhā": ['mw'],
    "prasaṃdhāna": ['mw'],
    "prasaṃdhānaṃ": ['ap90'],
    "prasaṃgaḥ": ['ap90'],
    "prasaṃgha": ['mw'],
    "prasaṃghaḥ": ['ap90'],
    "prasaṃgin": ['ap90'],
    "prasaṃj": ['ap90'],
    "prasaṃjanaṃ": ['ap90'],
    "prasaṃkhyā": ['ap90', 'mw'],
    "prasaṃkhyāna": ['mw'],
    "prasaṃkhyānapara": ['mw'],
    "prasaṃkhyānaḥ": ['ap90'],
    "prasaṅga": ['cae', 'mw'],
    "prasaṅganivāraṇa": ['mw'],
    "prasaṅgaproṣita": ['mw'],
    "prasaṅgaratnākara": ['mw'],
    "prasaṅgaratnāvalī": ['mw'],
    "prasaṅgasama": ['mw'],
    "prasaṅgatas": ['mw'],
    "prasaṅgavant": ['cae'],
    "prasaṅgavat": ['mw'],
    "prasaṅgavaśāt": ['mw'],
    "prasaṅgavinivṛtti": ['mw'],
    "prasaṅgena": ['mw'],
    "prasaṅgin": ['cae', 'mw'],
    "prasaṅgitā": ['mw'],
    "prasaṅgābharaṇa": ['mw'],
    "prasaṅgānusaṅgena": ['mw'],
    "prasaṅgāt": ['mw'],
    "prasaṅktavya": ['mw'],
    "prasecana": ['mw'],
    "prasecanavat": ['mw'],
    "prasedikā": ['ap90', 'mw'],
    "prasedivas": ['mw'],
    "praseka": ['cae', 'ddsa', 'mw'],
    "prasekam": ['mw'],
    "prasekatā": ['mw'],
    "prasekaḥ": ['ap90'],
    "prasekin": ['mw'],
    "prasena": ['bhs', 'cae', 'mw'],
    "prasenajit": ['bhs', 'cae', 'mw'],
    "praseva": ['mw'],
    "prasevaka": ['mw'],
    "prasevaḥ": ['ap90'],
    "prasevikā": ['mw'],
    "prasi": ['mw'],
    "prasic": ['mw'],
    "prasiddha": ['ap90', 'cae', 'mw'],
    "prasiddhaka": ['mw'],
    "prasiddhakarmānta": ['bhs'],
    "prasiddhakṣatriyaprāya": ['mw'],
    "prasiddharaṅga": ['bhs'],
    "prasiddhatva": ['mw'],
    "prasiddhatā": ['mw'],
    "prasiddhavedana": ['bhs'],
    "prasiddhi": ['ap90', 'cae', 'mw'],
    "prasiddhihata": ['mw'],
    "prasiddhimat": ['mw'],
    "prasiddhividyāviruddha": ['mw'],
    "prasiddhiviruddhatā": ['mw'],
    "prasiddhā": ['mw'],
    "prasidh": ['ap90', 'mw'],
    "prasikta": ['mw'],
    "prasita": ['ap90', 'cae', 'ddsa', 'mw'],
    "prasiti": ['cae', 'gra', 'mw'],
    "prasitiḥ": ['ap90'],
    "prasiv": ['mw'],
    "praskand": ['mw'],
    "praskanda": ['bhs', 'mw'],
    "praskandaka": ['bhs'],
    "praskandana": ['mw'],
    "praskandha": ['bhs'],
    "praskandikā": ['mw'],
    "praskandin": ['bhs', 'mw'],
    "praskanna": ['ap90', 'mw'],
    "praskaṃd": ['ap90'],
    "praskaṃdanaṃ": ['ap90'],
    "praskaṃdikā": ['ap90'],
    "praskaṇva": ['ddsa', 'gra', 'mw'],
    "praskhal": ['ap90', 'mw'],
    "praskhaladgati": ['mw'],
    "praskhalana": ['mw'],
    "praskhalanaṃ": ['ap90'],
    "praskhalat": ['mw'],
    "praskhalita": ['mw'],
    "praskunda": ['mw'],
    "praskuṃdaḥ": ['ap90'],
    "praskṛta": ['bhs'],
    "prasmartavya": ['ddsa', 'mw'],
    "prasmi": ['mw'],
    "prasmīkṣya": ['mw'],
    "prasmṛ": ['mw'],
    "prasmṛta": ['mw'],
    "prasmṛti": ['mw'],
    "prasmṛtiḥ": ['ap90'],
    "prasna": ['mw'],
    "prasnapita": ['mw'],
    "prasnava": ['cae', 'ddsa', 'mw'],
    "prasnavana": ['mw'],
    "prasnavasaṃyukta": ['mw'],
    "prasnavaḥ": ['ap90'],
    "prasnavitrīya": ['mw'],
    "prasnaḥ": ['ap90'],
    "prasneya": ['mw'],
    "prasnigdha": ['ap90', 'cae', 'mw'],
    "prasnu": ['ap90', 'mw'],
    "prasnuta": ['ap90', 'mw'],
    "prasnutastanī": ['mw'],
    "prasnuṣā": ['ap90', 'mw'],
    "prasnā": ['mw'],
    "prasnātṛ": ['mw'],
    "prasnāvin": ['mw'],
    "prasotar": ['bhs'],
    "praspand": ['mw'],
    "praspanda": ['bhs'],
    "praspandana": ['ddsa', 'mw'],
    "praspardh": ['mw'],
    "praspardhin": ['mw'],
    "praspaṃdanaṃ": ['ap90'],
    "prasphij": ['mw'],
    "prasphoṭa": ['bhs'],
    "prasphoṭaka": ['bhs', 'mw'],
    "prasphoṭana": ['bhs', 'mw'],
    "prasphoṭanaṃ": ['ap90'],
    "prasphulita": ['bhs'],
    "prasphuliṅga": ['mw'],
    "prasphur": ['ap90', 'mw'],
    "prasphurita": ['ap90', 'mw'],
    "prasphuritādhara": ['mw'],
    "prasphuṭ": ['ap90', 'mw'],
    "prasphuṭa": ['ap90', 'cae', 'mw'],
    "prasphāra": ['mw'],
    "prasrabdha": ['bhs'],
    "prasrava": ['cae', 'mw'],
    "prasravasaṃyukta": ['mw'],
    "prasravayukta": ['mw'],
    "prasravaḥ": ['ap90'],
    "prasravaṇa": ['cae', 'gra', 'mw'],
    "prasravaṇajala": ['mw'],
    "prasravaṇaṃ": ['ap90'],
    "prasravaṇī": ['bhs'],
    "prasravin": ['ap90', 'mw'],
    "prasraṃs": ['mw'],
    "prasraṃsa": ['ddsa', 'mw'],
    "prasraṃsana": ['mw'],
    "prasraṃsin": ['ap90', 'mw'],
    "prasru": ['ap90', 'mw'],
    "prasruta": ['ap90', 'mw'],
    "prasruti": ['mw'],
    "prasrāva": ['mw'],
    "prasrāvakaraṇa": ['mw'],
    "prasrāvakuṭī": ['bhs'],
    "prasrāvaḥ": ['ap90'],
    "prasrāviṇī": ['bhs'],
    "prastabdha": ['cae', 'mw'],
    "prastabdhagātra": ['mw'],
    "prastambha": ['ddsa', 'mw'],
    "prastan": ['mw'],
    "prastara": ['cae', 'gra', 'mw'],
    "prastarabhājana": ['mw'],
    "prastaraghatanopakaraṇa": ['mw'],
    "prastarasveda": ['mw'],
    "prastarasvedana": ['mw'],
    "prastaraḥ": ['ap90'],
    "prastaraṇa": ['mw'],
    "prastaraṇaṃ": ['ap90'],
    "prastareṣṭha": ['mw'],
    "prastariṇī": ['mw'],
    "prastava": ['cae', 'mw'],
    "prastavaḥ": ['ap90'],
    "prastha": ['ap90', 'cae', 'ddsa', 'mw'],
    "prasthakusuma": ['mw'],
    "prasthampaca": ['mw'],
    "prasthapuṣpa": ['mw'],
    "prasthavat": ['mw'],
    "prasthaṃpaca": ['ap90'],
    "prastheya": ['mw'],
    "prasthika": ['mw'],
    "prasthikā": ['mw'],
    "prasthita": ['ap90', 'cae', 'mw'],
    "prasthitam": ['mw'],
    "prasthitavat": ['mw'],
    "prasthitayājyā": ['mw'],
    "prasthitayājyāhoma": ['mw'],
    "prasthiti": ['cae', 'mw'],
    "prasthitiḥ": ['ap90'],
    "prasthā": ['ap90', 'mw'],
    "prasthāna": ['cae', 'mw'],
    "prasthānabheda": ['mw'],
    "prasthānadundubhi": ['mw'],
    "prasthānaka": ['mw'],
    "prasthānaratnākara": ['mw'],
    "prasthānatrayabhāṣya": ['mw'],
    "prasthānavat": ['mw'],
    "prasthānavighna": ['mw'],
    "prasthānavighnakṛt": ['mw'],
    "prasthānaviklavagati": ['mw'],
    "prasthānaṃ": ['ap90'],
    "prasthānika": ['mw'],
    "prasthānāvalī": ['mw'],
    "prasthānīya": ['mw'],
    "prasthāpana": ['mw'],
    "prasthāpanaṃ": ['ap90'],
    "prasthāpanīya": ['mw'],
    "prasthāpita": ['ap90', 'mw'],
    "prasthāpya": ['mw'],
    "prasthāvan": ['cae', 'gra', 'mw'],
    "prasthāvat": ['mw'],
    "prasthāvatī": ['mw'],
    "prasthāyin": ['ap90', 'mw'],
    "prasthāyya": ['mw'],
    "prasthāyīya": ['mw'],
    "prastigh": ['mw'],
    "prastira": ['mw'],
    "prastiraḥ": ['ap90'],
    "prastobha": ['mw'],
    "prastoka": ['gra'],
    "prastotrīya": ['mw'],
    "prastotṛ": ['cae', 'ddsa', 'mw'],
    "prastotṛprayoga": ['mw'],
    "prastotṛsāman": ['mw'],
    "prastu": ['ap90', 'mw'],
    "prastubh": ['mw'],
    "prastump": ['mw'],
    "prastuta": ['ap90', 'cae', 'ddsa', 'mw'],
    "prastutatva": ['mw'],
    "prastutayajña": ['mw'],
    "prastuti": ['cae', 'gra', 'mw'],
    "prastutiḥ": ['ap90'],
    "prastutāṅkura": ['mw'],
    "prastāra": ['cae', 'ddsa', 'mw'],
    "prastāracintāmaṇi": ['mw'],
    "prastāraka": ['bhs'],
    "prastārapattana": ['mw'],
    "prastārapaṅkti": ['cae', 'mw'],
    "prastāraḥ": ['ap90'],
    "prastārika": ['bhs'],
    "prastārin": ['cae', 'mw'],
    "prastāva": ['cae', 'mw'],
    "prastāvacintāmaṇi": ['mw'],
    "prastāvakrameṇa": ['mw'],
    "prastāvamuktāvatī": ['mw'],
    "prastāvanā": ['ap90', 'cae', 'mw'],
    "prastāvapāṭhaka": ['mw'],
    "prastāvaratnākara": ['mw'],
    "prastāvasadṛśa": ['mw'],
    "prastāvasūtra": ['mw'],
    "prastāvataraṃgiṇī": ['mw'],
    "prastāvatas": ['mw'],
    "prastāvayajña": ['mw'],
    "prastāvaśloka": ['mw'],
    "prastāvaḥ": ['ap90'],
    "prastāvita": ['ap90', 'mw'],
    "prastāvya": ['mw'],
    "prastāvāntaragata": ['mw'],
    "prastāvānugatam": ['mw'],
    "prastīma": ['mw'],
    "prastīrṇa": ['cae', 'mw'],
    "prastīta": ['ap90', 'mw'],
    "prastṛ": ['mw'],
    "prastṛta": ['mw'],
    "prasu": ['ap90', 'mw'],
    "prasuhma": ['mw'],
    "prasup": ['cae', 'ddsa', 'gra', 'mw'],
    "prasupta": ['ap90', 'cae', 'mw'],
    "prasuptatā": ['mw'],
    "prasupti": ['mw'],
    "prasuptiḥ": ['ap90'],
    "prasut": ['cae', 'mw'],
    "prasuta": ['bhs', 'cae', 'mw'],
    "prasuti": ['cae', 'mw'],
    "prasuva": ['mw'],
    "prasuśruta": ['mw'],
    "prasvana": ['ddsa', 'mw'],
    "prasvanaḥ": ['ap90'],
    "prasvanita": ['mw'],
    "prasvap": ['mw'],
    "prasveda": ['cae', 'mw'],
    "prasvedabindu": ['mw'],
    "prasvedajala": ['mw'],
    "prasvedakaṇikā": ['mw'],
    "prasvedaḥ": ['ap90'],
    "prasvedin": ['mw'],
    "prasvedita": ['ap90', 'mw'],
    "prasveditavat": ['mw'],
    "prasvid": ['mw'],
    "prasvinna": ['ap90', 'mw'],
    "prasvādas": ['ap90', 'cae', 'gra', 'mw'],
    "prasvāna": ['mw'],
    "prasvānaḥ": ['ap90'],
    "prasvāpa": ['mw'],
    "prasvāpaka": ['ap90', 'mw'],
    "prasvāpana": ['mw'],
    "prasvāpanaṃ": ['ap90'],
    "prasvāpaḥ": ['ap90'],
    "prasvāpinī": ['mw'],
    "prasvāra": ['mw'],
    "prasvāraḥ": ['ap90'],
    "prasvṛ": ['mw'],
    "prasyand": ['mw'],
    "prasyanda": ['cae', 'ddsa', 'mw'],
    "prasyandana": ['mw'],
    "prasyandin": ['cae', 'mw'],
    "prasyaṃd": ['ap90'],
    "prasyaṃdaḥ": ['ap90'],
    "prasāda": ['bhs', 'cae', 'ddsa', 'mw'],
    "prasādabhāj": ['mw'],
    "prasādabhūmi": ['mw'],
    "prasādacintaka": ['mw'],
    "prasādadāna": ['mw'],
    "prasādaka": ['ap90', 'cae', 'mw'],
    "prasādamālā": ['mw'],
    "prasādana": ['ap90', 'cae', 'mw'],
    "prasādanatā": ['bhs'],
    "prasādanā": ['mw'],
    "prasādanīya": ['bhs', 'mw'],
    "prasādaparāṅmukha": ['mw'],
    "prasādapaṭṭa": ['mw'],
    "prasādapaṭṭaka": ['mw'],
    "prasādapratilabdha": ['bhs', 'mw'],
    "prasādapuraga": ['mw'],
    "prasādapātra": ['mw'],
    "prasādastava": ['mw'],
    "prasādastha": ['mw'],
    "prasādasumukha": ['cae', 'mw'],
    "prasādavat": ['mw'],
    "prasādavatī": ['bhs'],
    "prasādavatīsamādhi": ['mw'],
    "prasādavitta": ['cae', 'mw'],
    "prasādavittaka": ['mw'],
    "prasādayati": ['bhs'],
    "prasādayitavya": ['cae', 'mw'],
    "prasādaḥ": ['ap90'],
    "prasādaṣaṭślokī": ['mw'],
    "prasādh": ['ap90', 'mw'],
    "prasādhaka": ['ap90', 'cae', 'mw'],
    "prasādhana": ['cae', 'gra', 'mw'],
    "prasādhanavidhi": ['mw'],
    "prasādhanaviśeṣa": ['mw'],
    "prasādhanaṃ": ['ap90'],
    "prasādhanī": ['mw'],
    "prasādhikā": ['ap90', 'mw'],
    "prasādhita": ['ap90', 'mw'],
    "prasādhitāṅga": ['mw'],
    "prasādhivārika": ['bhs'],
    "prasādhya": ['mw'],
    "prasādika": ['bhs'],
    "prasādin": ['cae', 'mw'],
    "prasādita": ['ap90', 'mw'],
    "prasādya": ['cae', 'mw'],
    "prasādānna": ['mw'],
    "prasādāntara": ['mw'],
    "prasādāt": ['mw'],
    "prasādīkṛ": ['ap90', 'cae', 'mw'],
    "prasāh": ['ap90', 'gra'],
    "prasāha": ['mw'],
    "prasāhaḥ": ['ap90'],
    "prasāmi": ['mw'],
    "prasāra": ['cae', 'mw'],
    "prasāraḥ": ['ap90'],
    "prasāraṇa": ['cae', 'mw'],
    "prasāraṇaṃ": ['ap90'],
    "prasāraṇin": ['mw'],
    "prasāraṇī": ['mw'],
    "prasārin": ['cae', 'mw'],
    "prasārita": ['ap90', 'bhs', 'mw'],
    "prasāritabhoga": ['mw'],
    "prasāritagātra": ['mw'],
    "prasāritva": ['mw'],
    "prasāritāgra": ['mw'],
    "prasāritāṅguli": ['mw'],
    "prasāriṇī": ['ap90', 'mw'],
    "prasārya": ['mw'],
    "prasātika": ['bhs'],
    "prasātikā": ['ap90', 'mw'],
    "prasīdikā": ['ap90', 'mw'],
    "prasū": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prasūc": ['mw'],
    "prasūkā": ['ap90', 'mw'],
    "prasūmant": ['cae'],
    "prasūmat": ['mw'],
    "prasūmaya": ['mw'],
    "prasūna": ['ap90', 'cae', 'mw'],
    "prasūnabāṇa": ['mw'],
    "prasūnaka": ['mw'],
    "prasūnakaṃ": ['ap90'],
    "prasūnamālā": ['cae', 'mw'],
    "prasūnastabaka": ['mw'],
    "prasūnavarṣa": ['mw'],
    "prasūnavitati": ['mw'],
    "prasūneṣu": ['mw'],
    "prasūnāñjali": ['mw'],
    "prasūnāśuga": ['mw'],
    "prasūta": ['ap90', 'cae', 'mw'],
    "prasūti": ['cae', 'mw'],
    "prasūtija": ['mw'],
    "prasūtikā": ['ap90', 'cae', 'mw'],
    "prasūtivikala": ['cae'],
    "prasūtivāyu": ['mw'],
    "prasūtiḥ": ['ap90'],
    "prasūtā": ['mw'],
    "prasūtāta": ['mw'],
    "prasūvan": ['cae', 'gra'],
    "prasūvara": ['mw'],
    "prasūyat": ['mw'],
    "prasūyata": ['bhs'],
    "prasṛ": ['ap90', 'mw'],
    "prasṛj": ['ap90', 'mw'],
    "prasṛmara": ['ap90', 'mw'],
    "prasṛp": ['ap90', 'mw'],
    "prasṛpta": ['mw'],
    "prasṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "prasṛtaja": ['mw'],
    "prasṛtamātra": ['mw'],
    "prasṛtayāvaka": ['mw'],
    "prasṛti": ['cae', 'mw'],
    "prasṛtimpaca": ['mw'],
    "prasṛtiyāvaka": ['mw'],
    "prasṛtiḥ": ['ap90'],
    "prasṛtvara": ['ap90', 'mw'],
    "prasṛtā": ['mw'],
    "prasṛtāgrabhuj": ['mw'],
    "prasṛtāgrapradāyin": ['mw'],
    "prasṛṣṭa": ['ap90', 'mw'],
    "prasṛṣṭavaira": ['mw'],
    "prasṛṣṭā": ['mw'],
    "pratadvasu": ['gra', 'mw'],
    "pratakvan": ['mw'],
    "pratakṣ": ['mw'],
    "pratala": ['mw'],
    "pratalaṃ": ['ap90'],
    "pratam": ['ap90', 'mw'],
    "pratamaka": ['mw'],
    "pratamakaḥ": ['ap90'],
    "pratamam": ['cae'],
    "pratamām": ['mw'],
    "pratan": ['ap90', 'mw'],
    "pratana": ['ap90', 'mw'],
    "pratanu": ['ap90', 'cae', 'mw'],
    "pratanukam": ['mw'],
    "pratanūkṛ": ['mw'],
    "pratap": ['ap90', 'mw'],
    "pratapa": ['mw'],
    "pratapana": ['mw'],
    "pratapanaṃ": ['ap90'],
    "pratapanekṛ": ['mw'],
    "pratapant": ['cae'],
    "pratapat": ['mw'],
    "pratapatra": ['mw'],
    "pratapta": ['ap90', 'cae', 'mw'],
    "prataptṛ": ['mw'],
    "pratara": ['bhs', 'mw'],
    "prataram": ['cae', 'gra', 'mw'],
    "prataraḥ": ['ap90'],
    "prataraṇa": ['cae', 'gra', 'mw'],
    "pratardana": ['cae', 'gra', 'mw'],
    "pratark": ['ap90', 'mw'],
    "pratarka": ['cae', 'mw'],
    "pratarkaḥ": ['ap90'],
    "pratarkaṇa": ['mw'],
    "pratarkaṇaṃ": ['ap90'],
    "pratarkya": ['bhs', 'mw'],
    "pratarām": ['cae', 'mw'],
    "pratarītṛ": ['gra', 'mw'],
    "pratarīya": ['mw'],
    "pratata": ['ap90', 'bhs', 'mw'],
    "pratatam": ['mw'],
    "pratati": ['mw'],
    "pratatiḥ": ['ap90'],
    "pratatāmaha": ['mw'],
    "pratavas": ['cae', 'gra', 'mw'],
    "prataḍ": ['mw'],
    "prataṅkam": ['ddsa', 'mw'],
    "prataṭa": ['cae', 'mw'],
    "prath": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pratha": ['bhs', 'cae', 'mw'],
    "prathama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prathamabhaj": ['gra'],
    "prathamabhakti": ['cae'],
    "prathamabhakṣa": ['mw'],
    "prathamabhakṣaṇa": ['mw'],
    "prathamabhāj": ['mw'],
    "prathamabhāvin": ['mw'],
    "prathamacchad": ['mw'],
    "prathamachad": ['gra'],
    "prathamacittotpādika": ['bhs', 'mw'],
    "prathamadarśana": ['mw'],
    "prathamadarśanadina": ['mw'],
    "prathamadarśane": ['mw'],
    "prathamadhāra": ['mw'],
    "prathamadivasa": ['mw'],
    "prathamadugdha": ['mw'],
    "prathamagarbha": ['mw'],
    "prathamagarbhā": ['mw'],
    "prathamagrantha": ['mw'],
    "prathamaikarekhā": ['mw'],
    "prathamaja": ['cae', 'mw'],
    "prathamajā": ['cae', 'gra', 'mw'],
    "prathamajāta": ['cae', 'mw'],
    "prathamaka": ['ap90', 'bhs', 'ddsa', 'mw'],
    "prathamakalpa": ['cae', 'mw'],
    "prathamakalpika": ['bhs', 'mw'],
    "prathamakalpita": ['cae', 'mw'],
    "prathamakathita": ['mw'],
    "prathamakusuma": ['mw'],
    "prathamam": ['mw'],
    "prathamamañjarī": ['mw'],
    "prathamamaṅgala": ['mw'],
    "prathamanirdiṣṭa": ['mw'],
    "prathamanirdiṣṭatā": ['mw'],
    "prathamaparigṛhīta": ['mw'],
    "prathamaparāpātin": ['mw'],
    "prathamapluta": ['mw'],
    "prathamaprasūtā": ['mw'],
    "prathamapravada": ['mw'],
    "prathamapuruṣa": ['mw'],
    "prathamarājan": ['bhs'],
    "prathamarātra": ['mw'],
    "prathamasamāvṛtta": ['mw'],
    "prathamasaṃgama": ['mw'],
    "prathamasoma": ['mw'],
    "prathamasomatā": ['mw'],
    "prathamasthāna": ['mw'],
    "prathamasukṛta": ['mw'],
    "prathamasvara": ['mw'],
    "prathamasāhasa": ['cae', 'mw'],
    "prathamataram": ['mw'],
    "prathamatas": ['cae', 'mw'],
    "prathamatrisauparṇa": ['mw'],
    "prathamavaiyākaraṇa": ['mw'],
    "prathamavasati": ['mw'],
    "prathamavayas": ['cae', 'mw'],
    "prathamavayasin": ['mw'],
    "prathamavaṣaṭkāra": ['mw'],
    "prathamaviraha": ['mw'],
    "prathamavirahe": ['mw'],
    "prathamavittā": ['mw'],
    "prathamavāsya": ['mw'],
    "prathamavṛttānta": ['mw'],
    "prathamayajña": ['mw'],
    "prathamayauvana": ['mw'],
    "prathamaśravas": ['gra', 'mw'],
    "prathamaśrī": ['cae', 'mw'],
    "prathametara": ['mw'],
    "prathamodbhava": ['mw'],
    "prathamodita": ['mw'],
    "prathamotpanna": ['mw'],
    "prathamotpatita": ['mw'],
    "prathamottama": ['mw'],
    "prathamā": ['mw'],
    "prathamābhidheya": ['mw'],
    "prathamābhidheyatā": ['mw'],
    "prathamābhitapta": ['mw'],
    "prathamādeśa": ['mw'],
    "prathamāgāmin": ['mw'],
    "prathamāham": ['mw'],
    "prathamāhāra": ['mw'],
    "prathamārdha": ['mw'],
    "prathamāstamita": ['mw'],
    "prathamāvaratva": ['mw'],
    "prathana": ['cae', 'ddsa', 'mw'],
    "prathanaṃ": ['ap90'],
    "prathas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prathasvat": ['mw'],
    "prathaya": ['mw'],
    "prathayat": ['mw'],
    "prathayitṛ": ['mw'],
    "prathiman": ['ap90', 'gra', 'mw'],
    "prathimin": ['mw'],
    "prathiminī": ['mw'],
    "prathita": ['ap90', 'cae', 'mw'],
    "prathitaprabodha": ['mw'],
    "prathitatithinirṇaya": ['mw'],
    "prathitatva": ['mw'],
    "prathitavidiśālakṣaṇa": ['mw'],
    "prathitayaśas": ['mw'],
    "prathiti": ['mw'],
    "prathitiḥ": ['ap90'],
    "prathitānurāga": ['mw'],
    "prathiviḥ": ['ap90'],
    "prathivī": ['mw'],
    "prathiṣṭha": ['ap90', 'cae', 'gra', 'mw'],
    "prathu": ['ap90', 'mw'],
    "prathuka": ['mw'],
    "prathukaḥ": ['ap90'],
    "prathā": ['ap90', 'mw'],
    "prathāpaha": ['mw'],
    "prathīyas": ['ap90', 'mw'],
    "prathīyaṃs": ['cae'],
    "prati": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pratiardhi": ['gra'],
    "pratibaddha": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratibaddhacitta": ['mw'],
    "pratibaddhaprasara": ['mw'],
    "pratibaddharāga": ['mw'],
    "pratibaddhatā": ['mw'],
    "pratibadhya": ['mw'],
    "pratibala": ['cae', 'mw'],
    "pratibanddhṛ": ['mw'],
    "pratibanddhṛtā": ['mw'],
    "pratibandh": ['mw'],
    "pratibandha": ['cae', 'mw'],
    "pratibandhaka": ['cae', 'mw'],
    "pratibandhakārin": ['mw'],
    "pratibandhamukta": ['mw'],
    "pratibandhana": ['mw'],
    "pratibandhavant": ['cae'],
    "pratibandhavat": ['mw'],
    "pratibandhi": ['mw'],
    "pratibandhikalpanā": ['mw'],
    "pratibandhin": ['cae', 'mw'],
    "pratibandhitā": ['mw'],
    "pratibandhu": ['mw'],
    "pratibaṃdh": ['ap90'],
    "pratibaṃdhaka": ['ap90'],
    "pratibaṃdhanaṃ": ['ap90'],
    "pratibaṃdhavat": ['ap90'],
    "pratibaṃdhaḥ": ['ap90'],
    "pratibaṃdhin": ['ap90'],
    "pratibaṃdhiḥ": ['ap90'],
    "pratibha": ['mw'],
    "pratibhairava": ['mw'],
    "pratibhaj": ['ap90', 'mw'],
    "pratibhajati": ['bhs'],
    "pratibhakṣ": ['mw'],
    "pratibharati": ['bhs'],
    "pratibhavam": ['mw'],
    "pratibhaya": ['cae', 'mw'],
    "pratibhayakara": ['mw'],
    "pratibhayam": ['mw'],
    "pratibhayaṃkara": ['mw'],
    "pratibhayākāra": ['mw'],
    "pratibhañj": ['mw'],
    "pratibhaṇ": ['mw'],
    "pratibhaṇati": ['bhs'],
    "pratibhaṇita": ['mw'],
    "pratibhaṇḍayati": ['bhs'],
    "pratibhaṇḍitavya": ['mw'],
    "pratibhaṭa": ['cae', 'ddsa', 'mw'],
    "pratibhaṭatā": ['mw'],
    "pratibhaṭīkṛ": ['mw'],
    "pratibheda": ['cae', 'ddsa', 'mw'],
    "pratibhedana": ['mw'],
    "pratibhedanaṃ": ['ap90'],
    "pratibhedaḥ": ['ap90'],
    "pratibhid": ['ap90', 'mw'],
    "pratibhinna": ['ap90', 'mw'],
    "pratibhinnaka": ['bhs', 'mw'],
    "pratibhoga": ['cae', 'mw'],
    "pratibhogaḥ": ['ap90'],
    "pratibhojana": ['mw'],
    "pratibhojin": ['mw'],
    "pratibhojita": ['mw'],
    "pratibhuj": ['mw'],
    "pratibhuja": ['mw'],
    "pratibhuka": ['bhs'],
    "pratibhukta": ['mw'],
    "pratibhā": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratibhābalāt": ['mw'],
    "pratibhāga": ['bhs', 'cae', 'mw'],
    "pratibhāgaśas": ['mw'],
    "pratibhāgaḥ": ['ap90'],
    "pratibhāgeti": ['bhs'],
    "pratibhāhāni": ['mw'],
    "pratibhākṣaya": ['mw'],
    "pratibhāmukha": ['mw'],
    "pratibhāna": ['bhs', 'cae', 'mw'],
    "pratibhānakūṭa": ['bhs', 'mw'],
    "pratibhānatā": ['bhs'],
    "pratibhānavant": ['bhs', 'cae'],
    "pratibhānavat": ['ap90', 'mw'],
    "pratibhānavattva": ['mw'],
    "pratibhānaṃ": ['ap90'],
    "pratibhānika": ['bhs'],
    "pratibhānvita": ['mw'],
    "pratibhās": ['ap90', 'mw'],
    "pratibhāsa": ['bhs', 'cae', 'mw'],
    "pratibhāsana": ['mw'],
    "pratibhāsanaṃ": ['ap90'],
    "pratibhāsaḥ": ['ap90'],
    "pratibhāta": ['ap90', 'mw'],
    "pratibhātas": ['mw'],
    "pratibhāti": ['bhs'],
    "pratibhāva": ['mw'],
    "pratibhāvant": ['cae'],
    "pratibhāvat": ['ap90', 'mw'],
    "pratibhāvatā": ['mw'],
    "pratibhāvavat": ['mw'],
    "pratibhāvaśāt": ['mw'],
    "pratibhāvaḥ": ['ap90'],
    "pratibhāvilāsa": ['mw'],
    "pratibhāṇa": ['bhs'],
    "pratibhāṇika": ['bhs'],
    "pratibhāṇita": ['bhs'],
    "pratibhāṣ": ['ap90', 'mw'],
    "pratibhāṣya": ['mw'],
    "pratibhāṣyate": ['bhs'],
    "pratibhāṣā": ['ap90', 'mw'],
    "pratibhī": ['mw'],
    "pratibhū": ['cae', 'ddsa', 'mw'],
    "pratibhūbhṛt": ['mw'],
    "pratibhūpāla": ['mw'],
    "pratibhūḥ": ['ap90'],
    "pratibhūṣ": ['mw'],
    "pratibhūṣyaṃ": ['bhs'],
    "pratibhṛ": ['mw'],
    "pratibhṛta": ['mw'],
    "pratibibharti": ['bhs'],
    "pratibimba": ['cae', 'ddsa', 'mw'],
    "pratibimbana": ['mw'],
    "pratibimbata": ['mw'],
    "pratibimbavartin": ['mw'],
    "pratibimbaya": ['mw'],
    "pratibimbita": ['cae', 'mw'],
    "pratibimbitatva": ['mw'],
    "pratibimbya": ['bhs'],
    "pratibimbīkṛ": ['mw'],
    "pratibiṃbanaṃ": ['ap90'],
    "pratibiṃbayati": ['ap90'],
    "pratibiṃbita": ['ap90'],
    "pratibodha": ['cae', 'mw'],
    "pratibodhaka": ['ap90', 'cae', 'mw'],
    "pratibodhana": ['ap90', 'cae', 'mw'],
    "pratibodhanā": ['mw'],
    "pratibodhanīya": ['cae', 'mw'],
    "pratibodhavat": ['mw'],
    "pratibodhaḥ": ['ap90'],
    "pratibodhi": ['bhs'],
    "pratibodhin": ['mw'],
    "pratibodhita": ['ap90', 'mw'],
    "pratibrū": ['mw'],
    "pratibuddha": ['ap90', 'cae', 'mw'],
    "pratibuddhaka": ['mw'],
    "pratibuddhavastu": ['mw'],
    "pratibuddhi": ['cae', 'ddsa', 'mw'],
    "pratibuddhivat": ['mw'],
    "pratibuddhiḥ": ['ap90'],
    "pratibuddhātman": ['mw'],
    "pratibudh": ['ap90', 'mw'],
    "pratibādh": ['ap90', 'mw'],
    "pratibādhaka": ['ap90', 'cae', 'mw'],
    "pratibādhana": ['cae', 'mw'],
    "pratibādhanaṃ": ['ap90'],
    "pratibādhin": ['ap90', 'mw'],
    "pratibādhita": ['mw'],
    "pratibāhu": ['mw'],
    "pratibāṇi": ['mw'],
    "pratibīja": ['mw'],
    "pratibījam": ['mw'],
    "praticakra": ['mw'],
    "praticakṣ": ['ap90', 'mw'],
    "praticakṣa": ['gra', 'mw'],
    "praticakṣaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "praticakṣaṇaṃ": ['ap90'],
    "praticakṣin": ['cae', 'mw'],
    "praticakṣya": ['cae', 'mw'],
    "praticandra": ['mw'],
    "praticar": ['mw'],
    "praticaraṇam": ['mw'],
    "praticchad": ['ap90', 'mw'],
    "praticchadana": ['mw'],
    "praticchadanaṃ": ['ap90'],
    "praticchanda": ['cae', 'mw'],
    "praticchandaka": ['cae', 'mw'],
    "praticchandakalyāṇa": ['mw'],
    "praticchanna": ['cae', 'mw'],
    "praticchati": ['bhs'],
    "praticchaṃdaḥ": ['ap90'],
    "praticcheda": ['mw'],
    "praticchedaḥ": ['ap90'],
    "praticchid": ['mw'],
    "praticchāyikā": ['mw'],
    "praticchāyā": ['cae', 'mw'],
    "praticchāyāmaya": ['mw'],
    "pratichadana": ['bhs'],
    "pratichanna": ['ap90'],
    "pratichāda": ['bhs'],
    "pratichādana": ['bhs'],
    "praticikīrṣ": ['mw'],
    "praticikīrṣu": ['mw'],
    "praticikīrṣā": ['ap90', 'mw'],
    "praticinoti": ['bhs'],
    "praticint": ['mw'],
    "praticintana": ['mw'],
    "praticintanīya": ['mw'],
    "praticiti": ['mw'],
    "praticiṃtanaṃ": ['ap90'],
    "praticodanam": ['mw'],
    "praticodanā": ['mw'],
    "praticodayati": ['bhs'],
    "praticodita": ['mw'],
    "praticud": ['mw'],
    "praticyavīyas": ['gra', 'mw'],
    "praticālayati": ['bhs'],
    "praticāra": ['bhs', 'mw'],
    "praticārin": ['bhs', 'mw'],
    "praticārita": ['ap90', 'mw'],
    "pratidah": ['mw'],
    "pratidaivatam": ['mw'],
    "pratidakṣiṇa": ['bhs'],
    "pratidantin": ['mw'],
    "pratidantyanīkam": ['mw'],
    "pratidarśa": ['cae', 'mw'],
    "pratidarśana": ['mw'],
    "pratidarśanaṃ": ['ap90'],
    "pratidarśanā": ['mw'],
    "pratidatta": ['ap90'],
    "pratidaṇḍa": ['ddsa', 'mw'],
    "pratideham": ['mw'],
    "pratidevatam": ['mw'],
    "pratidevatā": ['mw'],
    "pratideya": ['ap90', 'mw'],
    "pratideśa": ['bhs'],
    "pratideśam": ['mw'],
    "pratideśanikā": ['bhs'],
    "pratideśanā": ['bhs'],
    "pratideśanīya": ['bhs', 'mw'],
    "pratideśayati": ['bhs'],
    "pratidhartṛ": ['ddsa', 'mw'],
    "pratidhi": ['cae', 'gra', 'mw'],
    "pratidhiḥ": ['ap90'],
    "pratidhuktva": ['mw'],
    "pratidhura": ['mw'],
    "pratidhvani": ['mw'],
    "pratidhvaniḥ": ['ap90'],
    "pratidhvasta": ['ap90', 'mw'],
    "pratidhvāna": ['mw'],
    "pratidhvānin": ['mw'],
    "pratidhvānita": ['mw'],
    "pratidhyāta": ['mw'],
    "pratidhā": ['ap90', 'cae', 'gra', 'mw'],
    "pratidhāna": ['cae', 'mw'],
    "pratidhānaṃ": ['ap90'],
    "pratidhāv": ['mw'],
    "pratidhāvana": ['mw'],
    "pratidhāvanaṃ": ['ap90'],
    "pratidhī": ['mw'],
    "pratidhṛ": ['mw'],
    "pratidhṛṣ": ['mw'],
    "pratidinam": ['cae', 'mw'],
    "pratidiv": ['mw'],
    "pratidivan": ['ap90', 'mw'],
    "pratidivasam": ['cae', 'mw'],
    "pratidiś": ['mw'],
    "pratidiśam": ['cae', 'mw'],
    "pratidiśati": ['bhs'],
    "pratidoṣam": ['cae', 'gra', 'mw'],
    "pratidru": ['mw'],
    "pratidruh": ['mw'],
    "pratiduh": ['mw'],
    "pratidvandvayati": ['bhs'],
    "pratidvaṃdva": ['cae', 'mw'],
    "pratidvaṃdvaya": ['mw'],
    "pratidvaṃdvin": ['cae', 'mw'],
    "pratidvaṃdvībhūta": ['mw'],
    "pratidvipa": ['mw'],
    "pratidvirada": ['mw'],
    "pratidvādaśan": ['mw'],
    "pratidvāra": ['bhs'],
    "pratidvāram": ['mw'],
    "pratidvāri": ['mw'],
    "pratidvīpam": ['mw'],
    "pratidā": ['ap90', 'mw'],
    "pratidāna": ['cae', 'mw'],
    "pratidānaṃ": ['ap90'],
    "pratidāpya": ['mw'],
    "pratidāraṇa": ['mw'],
    "pratidāraṇaṃ": ['ap90'],
    "pratidātavya": ['mw'],
    "pratidīpta": ['mw'],
    "pratidīvan": ['cae', 'gra', 'mw'],
    "pratidūta": ['mw'],
    "pratidūṣita": ['cae', 'mw'],
    "pratidṛś": ['ap90', 'mw'],
    "pratidṛśam": ['mw'],
    "pratidṛṣṭa": ['ap90', 'mw'],
    "pratidṛṣṭānta": ['mw'],
    "pratidṛṣṭāntasama": ['mw'],
    "pratigad": ['mw'],
    "pratigaja": ['ddsa', 'mw'],
    "pratigam": ['ap90', 'mw'],
    "pratigamana": ['cae', 'mw'],
    "pratigamanaṃ": ['ap90'],
    "pratigara": ['cae', 'mw'],
    "pratigarhita": ['ap90'],
    "pratigaritṛ": ['mw'],
    "pratigarj": ['ap90', 'mw'],
    "pratigarjana": ['mw'],
    "pratigarjanā": ['ap90', 'mw'],
    "pratigarvita": ['bhs'],
    "pratigata": ['ap90', 'mw'],
    "pratigati": ['mw'],
    "pratigeham": ['mw'],
    "pratigha": ['ap90', 'bhs', 'ddsa', 'mw'],
    "pratighna": ['mw'],
    "pratighnaṃ": ['ap90'],
    "pratighoṣin": ['mw'],
    "pratighoṣiṇī": ['mw'],
    "pratighāta": ['bhs', 'cae', 'mw'],
    "pratighātaka": ['ap90', 'cae', 'mw'],
    "pratighātakṛt": ['mw'],
    "pratighātana": ['mw'],
    "pratighātanaṃ": ['ap90'],
    "pratighātavid": ['mw'],
    "pratighātaya": ['mw'],
    "pratighātaḥ": ['ap90'],
    "pratighātin": ['mw'],
    "pratigiri": ['mw'],
    "pratigopaka": ['bhs'],
    "pratigrah": ['ap90', 'mw'],
    "pratigraha": ['bhs', 'cae', 'ddsa', 'mw'],
    "pratigrahadhana": ['mw'],
    "pratigrahakalpa": ['mw'],
    "pratigrahaprāpta": ['mw'],
    "pratigrahaprāyaścittaprakāra": ['mw'],
    "pratigrahaḥ": ['ap90'],
    "pratigrahaṇa": ['cae', 'mw'],
    "pratigrahaṇaṃ": ['ap90'],
    "pratigrahaṇīya": ['mw'],
    "pratigrahetar": ['bhs'],
    "pratigrahin": ['ap90', 'mw'],
    "pratigrahītavya": ['cae', 'mw'],
    "pratigrahītṛ": ['ap90', 'cae', 'mw'],
    "pratigrāha": ['cae', 'mw'],
    "pratigrāhaka": ['ap90', 'bhs', 'mw'],
    "pratigrāhaḥ": ['ap90'],
    "pratigrāhin": ['cae', 'mw'],
    "pratigrāhita": ['bhs'],
    "pratigrāhya": ['ap90', 'mw'],
    "pratigrāmam": ['mw'],
    "pratigrāmasamīpam": ['mw'],
    "pratigu": ['cae', 'mw'],
    "pratigupta": ['mw'],
    "pratigupya": ['mw'],
    "pratigupyam": ['mw'],
    "pratigā": ['mw'],
    "pratigāh": ['mw'],
    "pratigātram": ['mw'],
    "pratigīrya": ['mw'],
    "pratigṛbhāya": ['mw'],
    "pratigṛdh": ['mw'],
    "pratigṛham": ['cae', 'mw'],
    "pratigṛhya": ['mw'],
    "pratigṛhīta": ['ap90', 'mw'],
    "pratigṛhītavya": ['mw'],
    "pratigṛhītṛ": ['mw'],
    "pratigṛhṇāti": ['bhs'],
    "pratigṝ": ['mw'],
    "pratihan": ['ap90', 'mw'],
    "pratihanana": ['mw'],
    "pratihananaṃ": ['ap90'],
    "pratihantavya": ['mw'],
    "pratihantṛ": ['mw'],
    "pratihanyanā": ['bhs'],
    "pratihanyate": ['bhs'],
    "pratiharaṇa": ['cae', 'mw'],
    "pratiharaṇaṃ": ['ap90'],
    "pratihartṛ": ['ap90', 'cae', 'mw'],
    "pratihary": ['mw'],
    "pratiharṣa": ['mw'],
    "pratiharṣaṇa": ['mw'],
    "pratihasta": ['cae', 'mw'],
    "pratihastaka": ['cae', 'mw'],
    "pratihastatva": ['mw'],
    "pratihasti": ['mw'],
    "pratihastin": ['mw'],
    "pratihata": ['ap90', 'mw'],
    "pratihatadhī": ['ddsa', 'mw'],
    "pratihatamati": ['mw'],
    "pratihataraya": ['mw'],
    "pratihati": ['mw'],
    "pratihatiḥ": ['ap90'],
    "pratihatya": ['mw'],
    "pratiheṣ": ['mw'],
    "pratihita": ['ap90', 'mw'],
    "pratihiteṣu": ['mw'],
    "pratihiti": ['mw'],
    "pratihitā": ['mw'],
    "pratihitāyin": ['mw'],
    "pratihiṃsita": ['ddsa', 'mw'],
    "pratihiṃsitaṃ": ['ap90'],
    "pratihiṃsā": ['ap90', 'mw'],
    "pratihoma": ['mw'],
    "pratihotavya": ['mw'],
    "pratihrāsa": ['mw'],
    "pratihu": ['mw'],
    "pratihvara": ['gra', 'mw'],
    "pratihve": ['mw'],
    "pratihā": ['mw'],
    "pratihāna": ['mw'],
    "pratihānākūṭa": ['mw'],
    "pratihāra": ['cae', 'ddsa', 'mw'],
    "pratihārabhūmi": ['cae', 'mw'],
    "pratihāragoptrī": ['mw'],
    "pratihāraka": ['mw'],
    "pratihārakapakṣa": ['bhs'],
    "pratihārakaḥ": ['ap90'],
    "pratihārapa": ['mw'],
    "pratihārarakṣī": ['mw'],
    "pratihārasūtra": ['mw'],
    "pratihāratara": ['mw'],
    "pratihāravat": ['mw'],
    "pratihārayati": ['bhs'],
    "pratihāraḥ": ['ap90'],
    "pratihāraṇaṃ": ['ap90'],
    "pratihārya": ['mw'],
    "pratihāryaṃ": ['ap90'],
    "pratihārāya": ['ddsa', 'mw'],
    "pratihāsa": ['mw'],
    "pratihāsaḥ": ['ap90'],
    "pratihṛ": ['ap90', 'mw'],
    "pratihṛdayam": ['mw'],
    "pratihṛta": ['mw'],
    "pratihṛṣ": ['mw'],
    "pratijagdha": ['mw'],
    "pratijalp": ['mw'],
    "pratijalpa": ['mw'],
    "pratijalpaka": ['mw'],
    "pratijalpakaḥ": ['ap90'],
    "pratijalpaḥ": ['ap90'],
    "pratijan": ['mw'],
    "pratijana": ['cae', 'gra', 'mw'],
    "pratijanam": ['mw'],
    "pratijaneti": ['bhs'],
    "pratijanman": ['cae', 'mw'],
    "pratijanya": ['ap90', 'cae', 'gra', 'mw'],
    "pratijap": ['mw'],
    "pratijaṅghā": ['mw'],
    "pratiji": ['mw'],
    "pratijihvikā": ['mw'],
    "pratijihvā": ['mw'],
    "pratijihīrṣu": ['mw'],
    "pratijuṣ": ['mw'],
    "pratijval": ['mw'],
    "pratijña": ['mw'],
    "pratijñeya": ['ap90', 'mw'],
    "pratijñottaraka": ['bhs'],
    "pratijñā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "pratijñābhaṅga": ['mw'],
    "pratijñābhaṅgabhīru": ['mw'],
    "pratijñāhāni": ['mw'],
    "pratijñākara": ['mw'],
    "pratijñākāraka": ['bhs'],
    "pratijñālakṣaṇa": ['mw'],
    "pratijñālakṣaṇadīdhitiṭīkā": ['mw'],
    "pratijñālakṣaṇakroḍa": ['mw'],
    "pratijñālakṣaṇarahasya": ['mw'],
    "pratijñālakṣaṇavivecana": ['mw'],
    "pratijñālakṣaṇaṭīkā": ['mw'],
    "pratijñālakṣaṇāloka": ['mw'],
    "pratijñālakṣaṇānugama": ['mw'],
    "pratijñāna": ['cae', 'mw'],
    "pratijñānavākya": ['mw'],
    "pratijñānaṃ": ['ap90'],
    "pratijñāntara": ['ddsa', 'mw'],
    "pratijñāparipālana": ['cae', 'mw'],
    "pratijñāpariśiṣṭa": ['mw'],
    "pratijñāpattra": ['mw'],
    "pratijñāpattraka": ['mw'],
    "pratijñāpita": ['mw'],
    "pratijñāpālana": ['mw'],
    "pratijñāpāraga": ['mw'],
    "pratijñāpāraṇa": ['mw'],
    "pratijñāpūrvakam": ['cae', 'mw'],
    "pratijñāsaṃnyāsa": ['mw'],
    "pratijñāsūtra": ['mw'],
    "pratijñāta": ['ap90', 'mw'],
    "pratijñātavya": ['mw'],
    "pratijñāti": ['mw'],
    "pratijñātārtha": ['mw'],
    "pratijñāvirodha": ['mw'],
    "pratijñāvivāhita": ['mw'],
    "pratijñāvāda": ['mw'],
    "pratijñāvādārtha": ['mw'],
    "pratijāgara": ['mw'],
    "pratijāgaraḥ": ['ap90'],
    "pratijāgaraṇa": ['mw'],
    "pratijāgaraṇaka": ['mw'],
    "pratijāgaraṇaṃ": ['ap90'],
    "pratijāgarti": ['bhs'],
    "pratijāgraka": ['bhs'],
    "pratijāgṛ": ['mw'],
    "pratijāgṛvi": ['mw'],
    "pratijāpa": ['mw'],
    "pratijāta": ['mw'],
    "pratijātakopa": ['mw'],
    "pratijīvana": ['mw'],
    "pratijīvanaṃ": ['ap90'],
    "pratijīvita": ['mw'],
    "pratijūtivarpas": ['gra', 'mw'],
    "pratijṛ": ['mw'],
    "pratijṛmbhitā": ['bhs'],
    "pratika": ['ap90', 'mw'],
    "pratikalam": ['mw'],
    "pratikalpa": ['mw'],
    "pratikalpam": ['mw'],
    "pratikalpya": ['mw'],
    "pratikamp": ['mw'],
    "pratikapālam": ['mw'],
    "pratikara": ['cae', 'mw'],
    "pratikaraḥ": ['ap90'],
    "pratikaraṇa": ['bhs'],
    "pratikaraṇīya": ['mw'],
    "pratikarkaśa": ['cae', 'mw'],
    "pratikarma": ['mw'],
    "pratikarman": ['ap90', 'cae', 'mw'],
    "pratikaroti": ['bhs'],
    "pratikartavya": ['ap90', 'mw'],
    "pratikartṛ": ['ap90', 'mw'],
    "pratikarṣa": ['mw'],
    "pratikarṣaḥ": ['ap90'],
    "pratikañcuka": ['ddsa', 'mw'],
    "pratikaśa": ['mw'],
    "pratikaṇṭham": ['mw'],
    "pratikaṇṭhikayā": ['mw'],
    "pratikaṇṭhukayā": ['bhs', 'mw'],
    "pratikaṣaḥ": ['ap90'],
    "pratikaṣṭa": ['mw'],
    "pratikheṭaka": ['mw'],
    "pratikhura": ['mw'],
    "pratikhyā": ['mw'],
    "pratikhyāti": ['mw'],
    "pratikhyātiḥ": ['ap90'],
    "pratikitava": ['mw'],
    "pratikopa": ['ddsa', 'mw'],
    "pratikopayati": ['bhs'],
    "pratikopaḥ": ['ap90'],
    "pratikoṇam": ['mw'],
    "pratikram": ['mw'],
    "pratikrama": ['cae', 'ddsa', 'mw'],
    "pratikramati": ['bhs'],
    "pratikramaḥ": ['ap90'],
    "pratikramaṇa": ['cae', 'mw'],
    "pratikramaṇasūtra": ['mw'],
    "pratikramaṇavidhi": ['mw'],
    "pratikramaṇaṃ": ['ap90'],
    "pratikriyam": ['mw'],
    "pratikriyā": ['ap90', 'cae', 'mw'],
    "pratikriyātva": ['mw'],
    "pratikriyāśūlinīstotra": ['mw'],
    "pratikrodha": ['mw'],
    "pratikrośa": ['bhs', 'mw'],
    "pratikrośati": ['bhs'],
    "pratikrudh": ['mw'],
    "pratikruṣṭa": ['ap90', 'bhs', 'mw'],
    "pratikrānta": ['bhs'],
    "pratikrūra": ['mw'],
    "pratikubjita": ['bhs'],
    "pratikuñcita": ['mw'],
    "pratikuñjara": ['mw'],
    "pratikuṃcita": ['ap90'],
    "pratikuṇḍam": ['mw'],
    "pratikāma": ['mw'],
    "pratikāmam": ['cae', 'gra', 'mw'],
    "pratikāmin": ['mw'],
    "pratikāminī": ['mw'],
    "pratikāmya": ['mw'],
    "pratikāra": ['cae', 'mw'],
    "pratikārajña": ['mw'],
    "pratikārakarman": ['mw'],
    "pratikāravidhāna": ['mw'],
    "pratikāraḥ": ['ap90'],
    "pratikārin": ['ap90', 'mw'],
    "pratikārya": ['mw'],
    "pratikāya": ['mw'],
    "pratikāśa": ['mw'],
    "pratikāśaḥ": ['ap90'],
    "pratikāṅkṣ": ['mw'],
    "pratikāṅkṣati": ['bhs'],
    "pratikāṅkṣaṇa": ['bhs'],
    "pratikāṅkṣin": ['bhs', 'mw'],
    "pratikāṅkṣitavya": ['mw'],
    "pratikāṅkṣā": ['bhs'],
    "pratikāṇḍam": ['mw'],
    "pratikīla": ['mw'],
    "pratikīrṇa": ['mw'],
    "pratikūj": ['mw'],
    "pratikūla": ['bhs', 'cae', 'ddsa', 'mw'],
    "pratikūlabhāṣin": ['mw'],
    "pratikūladaiva": ['mw'],
    "pratikūladaivatā": ['mw'],
    "pratikūladarśana": ['mw'],
    "pratikūlakārin": ['cae', 'mw'],
    "pratikūlakṛt": ['mw'],
    "pratikūlam": ['mw'],
    "pratikūlapravartin": ['mw'],
    "pratikūlatas": ['mw'],
    "pratikūlatva": ['mw'],
    "pratikūlatā": ['mw'],
    "pratikūlavacana": ['ddsa', 'mw'],
    "pratikūlavartin": ['mw'],
    "pratikūlavat": ['mw'],
    "pratikūlavedanīya": ['mw'],
    "pratikūlavisarpin": ['mw'],
    "pratikūlavāda": ['mw'],
    "pratikūlavādin": ['mw'],
    "pratikūlavṛtti": ['mw'],
    "pratikūlaya": ['ddsa', 'mw'],
    "pratikūlaśabda": ['mw'],
    "pratikūlika": ['ddsa', 'mw'],
    "pratikūlokta": ['mw'],
    "pratikūlācarita": ['mw'],
    "pratikūpa": ['mw'],
    "pratikḷp": ['mw'],
    "pratikṛ": ['ap90', 'mw'],
    "pratikṛta": ['ap90', 'ddsa', 'mw'],
    "pratikṛti": ['cae', 'mw'],
    "pratikṛtika": ['bhs'],
    "pratikṛtiḥ": ['ap90'],
    "pratikṛttikā": ['mw'],
    "pratikṛtya": ['bhs'],
    "pratikṛṣṭa": ['ap90', 'bhs', 'mw'],
    "pratikṝ": ['mw'],
    "pratikṣapam": ['mw'],
    "pratikṣatra": ['mw'],
    "pratikṣaya": ['bhs', 'mw'],
    "pratikṣayaḥ": ['ap90'],
    "pratikṣaṇam": ['cae', 'ddsa', 'mw'],
    "pratikṣepa": ['mw'],
    "pratikṣepaka": ['bhs'],
    "pratikṣepaḥ": ['ap90'],
    "pratikṣepaṇa": ['mw'],
    "pratikṣetra": ['mw'],
    "pratikṣetre": ['mw'],
    "pratikṣi": ['mw'],
    "pratikṣip": ['ap90', 'mw'],
    "pratikṣipta": ['ap90', 'mw'],
    "pratikṣiptatva": ['mw'],
    "pratikṣoṇibhṛt": ['mw'],
    "pratikṣuta": ['mw'],
    "pratikṣutaṃ": ['ap90'],
    "pratil": ['mw'],
    "pratilabh": ['ap90', 'mw'],
    "pratilabhya": ['cae', 'mw'],
    "pratilakṣaṇa": ['bhs', 'ddsa', 'mw'],
    "pratilamb": ['mw'],
    "pratilambha": ['cae', 'mw'],
    "pratilambhika": ['bhs'],
    "pratilambhita": ['mw'],
    "pratilayana": ['bhs'],
    "pratilaṃbhaḥ": ['ap90'],
    "pratilaṅgh": ['mw'],
    "pratilekha": ['bhs'],
    "pratilekhana": ['mw'],
    "pratilekhanā": ['mw'],
    "pratilih": ['mw'],
    "pratilikh": ['mw'],
    "pratilikhita": ['mw'],
    "pratilipi": ['mw'],
    "pratiliṅgam": ['mw'],
    "pratiloka": ['mw'],
    "pratiloma": ['cae', 'mw'],
    "pratilomaja": ['mw'],
    "pratilomaka": ['mw'],
    "pratilomam": ['mw'],
    "pratilomarūpa": ['mw'],
    "pratilomatas": ['mw'],
    "pratilomena": ['mw'],
    "pratilomā": ['mw'],
    "pratilomānuloma": ['mw'],
    "pratilomānulomam": ['mw'],
    "pratilomānulomatas": ['mw'],
    "pratiloḍita": ['mw'],
    "pratilubh": ['mw'],
    "pratilābha": ['cae', 'mw'],
    "pratilābhaḥ": ['ap90'],
    "pratilābhika": ['bhs'],
    "pratilābhin": ['bhs'],
    "pratilī": ['mw'],
    "pratilīna": ['bhs', 'mw'],
    "pratima": ['bhs'],
    "pratimahiṣa": ['mw'],
    "pratimahānasa": ['mw'],
    "pratimahāvyāhṛti": ['mw'],
    "pratimalla": ['cae', 'mw'],
    "pratimallatā": ['mw'],
    "pratiman": ['mw'],
    "pratimandiram": ['mw'],
    "pratimantr": ['mw'],
    "pratimantram": ['mw'],
    "pratimantrayitavya": ['mw'],
    "pratimantraṇa": ['mw'],
    "pratimantrita": ['mw'],
    "pratimanvantara": ['mw'],
    "pratimanvantaram": ['mw'],
    "pratimanvantare": ['mw'],
    "pratimanyūya": ['mw'],
    "pratimarśa": ['mw'],
    "pratimatsya": ['mw'],
    "pratimatva": ['mw'],
    "pratimatā": ['mw'],
    "pratimañca": ['mw'],
    "pratimañcaka": ['mw'],
    "pratimaṅgalavāra": ['ddsa', 'mw'],
    "pratimaṇḍala": ['mw'],
    "pratimaṇḍana": ['bhs'],
    "pratimaṇḍayati": ['bhs'],
    "pratimaṇḍita": ['mw'],
    "pratimaṇṭhaka": ['mw'],
    "pratimendu": ['mw'],
    "pratimeya": ['mw'],
    "pratimih": ['mw'],
    "pratimit": ['cae', 'mw'],
    "pratimita": ['ap90', 'cae', 'mw'],
    "pratimiti": ['mw'],
    "pratimitra": ['mw'],
    "pratimocana": ['cae', 'mw'],
    "pratimocanaṃ": ['ap90'],
    "pratimocita": ['mw'],
    "pratimodaka": ['bhs'],
    "pratimoka": ['bhs', 'mw'],
    "pratimokṣa": ['bhs', 'mw'],
    "pratimokṣasūtra": ['mw'],
    "pratimokṣaḥ": ['ap90'],
    "pratimokṣaṇa": ['ddsa', 'mw'],
    "pratimokṣita": ['bhs'],
    "pratimuc": ['ap90', 'mw'],
    "pratimud": ['mw'],
    "pratimudrā": ['bhs', 'mw'],
    "pratimuh": ['mw'],
    "pratimuhus": ['mw'],
    "pratimuhvati": ['bhs'],
    "pratimuhūrta": ['cae', 'mw'],
    "pratimuhūrtam": ['mw'],
    "pratimukha": ['cae', 'mw'],
    "pratimukham": ['mw'],
    "pratimukharī": ['mw'],
    "pratimukhāṅga": ['mw'],
    "pratimukhī": ['mw'],
    "pratimukta": ['ap90', 'mw'],
    "pratimukula": ['ddsa', 'mw'],
    "pratimuṭ": ['mw'],
    "pratimā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pratimācandra": ['mw'],
    "pratimādravyādivacana": ['mw'],
    "pratimādāna": ['mw'],
    "pratimāgata": ['mw'],
    "pratimālakṣaṇa": ['mw'],
    "pratimālā": ['mw'],
    "pratimāna": ['cae', 'gra', 'mw'],
    "pratimānabhāga": ['mw'],
    "pratimānakalpa": ['mw'],
    "pratimānanā": ['mw'],
    "pratimānayati": ['bhs'],
    "pratimānayitavya": ['mw'],
    "pratimānaṃ": ['ap90'],
    "pratimāparicāraka": ['mw'],
    "pratimāpratiṣṭhā": ['mw'],
    "pratimāpratiṣṭhāvidhi": ['mw'],
    "pratimāpūjā": ['mw'],
    "pratimārga": ['cae', 'mw'],
    "pratimārgaka": ['mw'],
    "pratimārge": ['mw'],
    "pratimārodanādiprāyaścittavidhi": ['mw'],
    "pratimāsa": ['mw'],
    "pratimāsam": ['mw'],
    "pratimāsamprokṣaṇa": ['mw'],
    "pratimāsya": ['mw'],
    "pratimātavya": ['mw'],
    "pratimātrā": ['mw'],
    "pratimātṛ": ['mw'],
    "pratimāviśeṣa": ['mw'],
    "pratimāyā": ['mw'],
    "pratimāśaśāṅka": ['mw'],
    "pratimāṃsa": ['mw'],
    "pratimīv": ['mw'],
    "pratimūrti": ['mw'],
    "pratimūṣikā": ['mw'],
    "pratinad": ['ap90', 'mw'],
    "pratinadi": ['mw'],
    "pratinagaram": ['ddsa', 'mw'],
    "pratinam": ['mw'],
    "pratinamaskāra": ['mw'],
    "pratinand": ['mw'],
    "pratinanda": ['mw'],
    "pratinandana": ['cae', 'mw'],
    "pratinandita": ['mw'],
    "pratinaptṛ": ['mw'],
    "pratinard": ['mw'],
    "pratinau": ['bhs'],
    "pratinava": ['cae', 'mw'],
    "pratinavajavāpuṣpa": ['mw'],
    "pratinaya": ['bhs'],
    "pratinayana": ['cae', 'mw'],
    "pratinaṃd": ['ap90'],
    "pratinaṃdanaṃ": ['ap90'],
    "pratinidheya": ['mw'],
    "pratinidhi": ['cae', 'mw'],
    "pratinidhiḥ": ['ap90'],
    "pratinidhā": ['ap90', 'mw'],
    "pratinidhāpayitavya": ['mw'],
    "pratinidhātavya": ['mw'],
    "pratinigad": ['mw'],
    "pratinigrah": ['mw'],
    "pratinigrāhya": ['mw'],
    "pratinihan": ['mw'],
    "pratinihata": ['mw'],
    "pratinikṣip": ['mw'],
    "pratininada": ['mw'],
    "pratinind": ['mw'],
    "pratinipāta": ['mw'],
    "pratiniras": ['mw'],
    "pratinirdeśa": ['mw'],
    "pratinirdeśaka": ['mw'],
    "pratinirdeśya": ['ap90', 'mw'],
    "pratinirdiś": ['mw'],
    "pratinirdiṣṭa": ['mw'],
    "pratinirgrāhya": ['mw'],
    "pratinirjita": ['ap90', 'mw'],
    "pratinirvap": ['mw'],
    "pratinirvāti": ['bhs'],
    "pratiniryat": ['mw'],
    "pratiniryā": ['mw'],
    "pratiniryātana": ['cae', 'mw'],
    "pratiniryātanaṃ": ['ap90'],
    "pratinisarga": ['bhs'],
    "pratinistarati": ['bhs'],
    "pratinistṝ": ['mw'],
    "pratinivartana": ['mw'],
    "pratinivartanaṃ": ['ap90'],
    "pratinivartita": ['mw'],
    "pratiniveśa": ['mw'],
    "pratiniviśati": ['bhs'],
    "pratiniviṣṭa": ['ap90', 'mw'],
    "pratiniviṣṭamūrkha": ['mw'],
    "pratinivārayate": ['bhs'],
    "pratinivāraṇa": ['mw'],
    "pratinivāsana": ['bhs', 'mw'],
    "pratinivṛt": ['mw'],
    "pratinivṛtta": ['mw'],
    "pratinivṛtti": ['cae', 'mw'],
    "pratiniyama": ['mw'],
    "pratiniyamaḥ": ['ap90'],
    "pratiniyata": ['ap90', 'mw'],
    "pratiniśam": ['mw'],
    "pratiniścaya": ['mw'],
    "pratiniḥsarati": ['bhs'],
    "pratiniḥsaraṇa": ['bhs'],
    "pratiniḥsarga": ['bhs', 'mw'],
    "pratiniḥsṛj": ['mw'],
    "pratiniḥsṛjati": ['bhs'],
    "pratiniḥsṛjya": ['mw'],
    "pratiniḥsṛṣṭa": ['mw'],
    "pratiniṣaṇṇa": ['bhs'],
    "pratiniṣevaṇa": ['bhs'],
    "pratiniṣka": ['mw'],
    "pratiniṣkraya": ['mw'],
    "pratiniṣkrānta": ['bhs'],
    "pratiniṣpū": ['mw'],
    "pratiniṣpūta": ['mw'],
    "pratiniṣṭha": ['mw'],
    "pratinoda": ['mw'],
    "pratinodaḥ": ['ap90'],
    "pratinu": ['mw'],
    "pratinud": ['ap90', 'mw'],
    "pratinyas": ['mw'],
    "pratinyāgam": ['mw'],
    "pratinyāsa": ['mw'],
    "pratinyāyam": ['mw'],
    "pratinyūṅkha": ['mw'],
    "pratinyūṅkhaya": ['mw'],
    "pratināda": ['mw'],
    "pratinādaḥ": ['ap90'],
    "pratinādita": ['ap90', 'mw'],
    "pratināga": ['mw'],
    "pratināha": ['mw'],
    "pratināhaḥ": ['ap90'],
    "pratināma": ['mw'],
    "pratināmagrahaṇam": ['mw'],
    "pratināman": ['mw'],
    "pratinārī": ['mw'],
    "pratināva": ['bhs'],
    "pratināyaka": ['cae', 'mw'],
    "pratināḍī": ['mw'],
    "pratinī": ['mw'],
    "pratinṛpati": ['mw'],
    "pratinṛt": ['mw'],
    "pratipa": ['mw'],
    "pratipacanam": ['mw'],
    "pratipaccandra": ['cae', 'mw'],
    "pratipad": ['ap90', 'bhs', 'cae', 'mw'],
    "pratipada": ['cae', 'mw'],
    "pratipadam": ['mw'],
    "pratipadatva": ['mw'],
    "pratipaddarśinī": ['mw'],
    "pratipadmam": ['mw'],
    "pratipadyanatā": ['bhs'],
    "pratipadyati": ['bhs'],
    "pratipadā": ['ap90', 'bhs', 'mw'],
    "pratipadī": ['mw'],
    "pratipakṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "pratipakṣacaṇḍabhairava": ['mw'],
    "pratipakṣagraha": ['mw'],
    "pratipakṣajanman": ['mw'],
    "pratipakṣatva": ['mw'],
    "pratipakṣatā": ['mw'],
    "pratipakṣika": ['bhs'],
    "pratipakṣin": ['cae', 'mw'],
    "pratipakṣita": ['mw'],
    "pratipakṣitā": ['mw'],
    "pratipalam": ['mw'],
    "pratipallava": ['mw'],
    "pratipanmaya": ['mw'],
    "pratipanna": ['ap90', 'bhs', 'cae', 'mw'],
    "pratipannaka": ['bhs', 'mw'],
    "pratipannaprayojana": ['mw'],
    "pratipare": ['mw'],
    "pratiparigamana": ['mw'],
    "pratiparva": ['mw'],
    "pratiparyāhṛ": ['mw'],
    "pratiparyāvṛt": ['mw'],
    "pratiparyāyam": ['mw'],
    "pratiparāhṛ": ['mw'],
    "pratiparāṇī": ['mw'],
    "pratiparī": ['mw'],
    "pratiparṇaśiphā": ['mw'],
    "pratipat": ['mw'],
    "pratipatha": ['ddsa', 'mw'],
    "pratipathagati": ['mw'],
    "pratipatham": ['mw'],
    "pratipathika": ['mw'],
    "pratipatni": ['mw'],
    "pratipattavya": ['bhs', 'mw'],
    "pratipatti": ['bhs', 'cae', 'mw'],
    "pratipattibheda": ['mw'],
    "pratipattidakṣa": ['mw'],
    "pratipattidarśin": ['mw'],
    "pratipattikarman": ['mw'],
    "pratipattimat": ['ap90', 'mw'],
    "pratipattiniṣṭhura": ['mw'],
    "pratipattiparāṅmukha": ['mw'],
    "pratipattipaṭaha": ['mw'],
    "pratipattipradāna": ['mw'],
    "pratipattiviśārada": ['mw'],
    "pratipattiḥ": ['ap90'],
    "pratipattraphalā": ['mw'],
    "pratipattūrya": ['mw'],
    "pratipattṛ": ['mw'],
    "pratipaś": ['mw'],
    "pratipaśu": ['mw'],
    "pratipaṃsayati": ['bhs'],
    "pratipaṇa": ['mw'],
    "pratipaṇya": ['bhs', 'mw'],
    "pratipeṣam": ['mw'],
    "pratiphal": ['ap90', 'mw'],
    "pratiphala": ['mw'],
    "pratiphalana": ['ddsa', 'mw'],
    "pratiphalaḥ": ['ap90'],
    "pratiphalita": ['ap90'],
    "pratiphalīkaraṇam": ['mw'],
    "pratiphullaka": ['ap90', 'mw'],
    "pratipibate": ['bhs'],
    "pratipipādayiṣu": ['mw'],
    "pratipipādayiṣā": ['mw'],
    "pratipitsu": ['mw'],
    "pratipitsā": ['ddsa', 'mw'],
    "pratipiṇḍam": ['mw'],
    "pratipiṣ": ['mw'],
    "pratipiṣṭa": ['mw'],
    "pratiplavana": ['mw'],
    "pratiplavanaṃ": ['ap90'],
    "pratiprabha": ['mw'],
    "pratiprabhā": ['mw'],
    "pratiprabhātam": ['mw'],
    "pratiprabrū": ['mw'],
    "pratiprach": ['mw'],
    "pratipradā": ['mw'],
    "pratipradāna": ['mw'],
    "pratipradānaṃ": ['ap90'],
    "pratipragrah": ['mw'],
    "pratiprahi": ['mw'],
    "pratiprahve": ['mw'],
    "pratiprahāra": ['mw'],
    "pratiprahāraḥ": ['ap90'],
    "pratiprahītavyam": ['bhs'],
    "pratipraiṣa": ['mw'],
    "pratiprajñā": ['mw'],
    "pratiprajñāti": ['ddsa', 'mw'],
    "pratiprakhyā": ['bhs'],
    "pratipramuc": ['mw'],
    "pratiprasava": ['mw'],
    "pratiprasavam": ['mw'],
    "pratiprasavaḥ": ['ap90'],
    "pratiprasthāna": ['mw'],
    "pratiprasthānaṃ": ['ap90'],
    "pratiprasthātṛ": ['ap90', 'cae', 'mw'],
    "pratiprasū": ['mw'],
    "pratiprasūta": ['mw'],
    "pratiprasṛp": ['mw'],
    "pratiprati": ['cae', 'mw'],
    "pratipratidivasam": ['bhs'],
    "pratipratta": ['mw'],
    "pratipratīka": ['mw'],
    "pratipratīkam": ['mw'],
    "pratipravac": ['mw'],
    "pratipravid": ['mw'],
    "pratipraviś": ['mw'],
    "pratipravṛt": ['mw'],
    "pratiprayam": ['mw'],
    "pratiprayavaṇa": ['mw'],
    "pratiprayoga": ['mw'],
    "pratiprayuj": ['mw'],
    "pratiprayā": ['mw'],
    "pratiprayāta": ['mw'],
    "pratiprayāṇa": ['mw'],
    "pratiprayāṇakam": ['mw'],
    "pratiprayāṇaṃ": ['ap90'],
    "pratipraśna": ['cae', 'mw'],
    "pratipraśnam": ['mw'],
    "pratipraśnaḥ": ['ap90'],
    "pratipraśrabdha": ['bhs'],
    "pratipraśrabdhi": ['bhs', 'mw'],
    "pratipraśrambhati": ['bhs'],
    "pratipraśrambhaṇa": ['bhs'],
    "pratipraṇavam": ['mw'],
    "pratipraṇavasaṃyukta": ['mw'],
    "pratipraṇāma": ['mw'],
    "pratipraṇāmaḥ": ['ap90'],
    "pratiprekṣaṇa": ['mw'],
    "pratipriya": ['bhs', 'cae', 'ddsa', 'mw'],
    "pratiprokta": ['mw'],
    "pratiprākaroti": ['bhs'],
    "pratiprākāra": ['bhs', 'mw'],
    "pratiprāni": ['mw'],
    "pratiprās": ['mw'],
    "pratiprāsthānika": ['mw'],
    "pratiprāyā": ['mw'],
    "pratiprāś": ['mw'],
    "pratiprāśita": ['mw'],
    "pratipudgala": ['bhs'],
    "pratipudgalika": ['bhs'],
    "pratipunniyata": ['ddsa'],
    "pratipur": ['mw'],
    "pratipura": ['mw'],
    "pratipuruṣa": ['cae', 'mw'],
    "pratipuruṣam": ['mw'],
    "pratipustaka": ['mw'],
    "pratipuṃniyata": ['mw'],
    "pratipuṣyam": ['mw'],
    "pratipuṣṭa": ['bhs'],
    "pratipādaka": ['ap90', 'bhs', 'cae', 'mw'],
    "pratipādakatva": ['mw'],
    "pratipādam": ['mw'],
    "pratipādana": ['cae', 'mw'],
    "pratipādanaka": ['bhs'],
    "pratipādanaṃ": ['ap90'],
    "pratipādanīya": ['cae', 'mw'],
    "pratipādapam": ['mw'],
    "pratipādayati": ['bhs'],
    "pratipādayitavya": ['mw'],
    "pratipādayitṛ": ['ap90', 'cae', 'mw'],
    "pratipādita": ['ap90', 'mw'],
    "pratipāditaka": ['bhs'],
    "pratipāditatva": ['mw'],
    "pratipāduka": ['ap90', 'mw'],
    "pratipādya": ['cae', 'mw'],
    "pratipādyatva": ['mw'],
    "pratipāl": ['ap90', 'mw'],
    "pratipālaka": ['bhs', 'mw'],
    "pratipālakaḥ": ['ap90'],
    "pratipālana": ['cae', 'mw'],
    "pratipālanaṃ": ['ap90'],
    "pratipālanīya": ['mw'],
    "pratipālayitavya": ['mw'],
    "pratipālin": ['cae', 'mw'],
    "pratipālita": ['ap90', 'mw'],
    "pratipālya": ['cae', 'mw'],
    "pratipāna": ['cae', 'mw'],
    "pratipānaṃ": ['ap90'],
    "pratipāpa": ['mw'],
    "pratipāpin": ['mw'],
    "pratipātram": ['cae', 'mw'],
    "pratipāṇa": ['cae', 'ddsa', 'mw'],
    "pratipīy": ['mw'],
    "pratipīḍ": ['mw'],
    "pratipīḍana": ['mw'],
    "pratipīḍanaṃ": ['ap90'],
    "pratipīḍā": ['bhs'],
    "pratipūj": ['ap90', 'mw'],
    "pratipūjaka": ['cae', 'mw'],
    "pratipūjana": ['cae', 'mw'],
    "pratipūjanaṃ": ['ap90'],
    "pratipūjita": ['ap90', 'mw'],
    "pratipūjya": ['cae', 'mw'],
    "pratipūjā": ['mw'],
    "pratipūra": ['bhs'],
    "pratipūraka": ['bhs'],
    "pratipūraṇa": ['cae', 'mw'],
    "pratipūraṇaṃ": ['ap90'],
    "pratipūri": ['bhs'],
    "pratipūrita": ['mw'],
    "pratipūrti": ['bhs', 'mw'],
    "pratipūruṣa": ['mw'],
    "pratipūruṣam": ['mw'],
    "pratipūrvāhṇam": ['mw'],
    "pratipūrṇa": ['cae', 'mw'],
    "pratipūrṇabimba": ['mw'],
    "pratipūrṇamānasa": ['mw'],
    "pratipṛṣṭhā": ['mw'],
    "pratipṝ": ['ap90', 'mw'],
    "pratira": ['cae', 'mw'],
    "pratirajani": ['ddsa', 'mw'],
    "pratirakṣ": ['mw'],
    "pratirakṣaṇa": ['mw'],
    "pratirakṣaṇaṃ": ['ap90'],
    "pratirakṣā": ['mw'],
    "pratirakṣārtham": ['mw'],
    "pratiram": ['mw'],
    "pratirambha": ['mw'],
    "pratirap": ['mw'],
    "pratiras": ['mw'],
    "pratirasita": ['mw'],
    "pratirata": ['mw'],
    "pratiratha": ['cae', 'mw'],
    "pratirathyam": ['mw'],
    "pratiraudrakarman": ['mw'],
    "pratirava": ['cae', 'mw'],
    "pratiravaḥ": ['ap90'],
    "pratirañjita": ['mw'],
    "pratiraṃbhaḥ": ['ap90'],
    "pratirih": ['mw'],
    "pratiripu": ['mw'],
    "pratirodana": ['bhs'],
    "pratiroddhṛ": ['cae', 'ddsa', 'mw'],
    "pratirodha": ['cae', 'mw'],
    "pratirodhaka": ['ap90', 'cae', 'mw'],
    "pratirodhakara": ['mw'],
    "pratirodhana": ['cae', 'mw'],
    "pratirodhanaṃ": ['ap90'],
    "pratirodhaḥ": ['ap90'],
    "pratirodhin": ['cae', 'mw'],
    "pratiropita": ['mw'],
    "pratiroṣayati": ['bhs'],
    "pratiroṣitavya": ['mw'],
    "pratiru": ['mw'],
    "pratiruc": ['mw'],
    "pratiruddha": ['ap90', 'mw'],
    "pratirudh": ['ap90', 'mw'],
    "pratiruh": ['mw'],
    "pratirurūṣu": ['mw'],
    "pratiruta": ['bhs', 'mw'],
    "pratiruṃṣita": ['mw'],
    "pratirāddha": ['mw'],
    "pratirādh": ['mw'],
    "pratirādha": ['mw'],
    "pratirāj": ['mw'],
    "pratirāja": ['cae', 'ddsa', 'mw'],
    "pratirājam": ['mw'],
    "pratirājan": ['cae', 'mw'],
    "pratirātram": ['cae', 'mw'],
    "pratirātri": ['cae', 'mw'],
    "pratirūpa": ['cae', 'gra', 'mw'],
    "pratirūpacarya": ['mw'],
    "pratirūpacaryā": ['mw'],
    "pratirūpadhṛk": ['mw'],
    "pratirūpaka": ['cae', 'mw'],
    "pratirūpatā": ['mw'],
    "pratirūpya": ['mw'],
    "pratirūpā": ['mw'],
    "pratirūḍha": ['mw'],
    "pratisac": ['mw'],
    "pratisad": ['mw'],
    "pratisadanam": ['mw'],
    "pratisadma": ['mw'],
    "pratisadṛkṣa": ['mw'],
    "pratisadṛś": ['mw'],
    "pratisah": ['mw'],
    "pratisama": ['mw'],
    "pratisamantam": ['mw'],
    "pratisamarpayati": ['bhs'],
    "pratisamas": ['mw'],
    "pratisamayati": ['bhs'],
    "pratisamayya": ['mw'],
    "pratisambandhi": ['mw'],
    "pratisambhū": ['mw'],
    "pratisambuddha": ['mw'],
    "pratisamindh": ['mw'],
    "pratisammodana": ['mw'],
    "pratisammodanakathā": ['mw'],
    "pratisammud": ['mw'],
    "pratisamādhā": ['mw'],
    "pratisamādhāna": ['mw'],
    "pratisamādhānaṃ": ['ap90'],
    "pratisamādiś": ['mw'],
    "pratisamādiṣṭa": ['mw'],
    "pratisamāhita": ['mw'],
    "pratisamāpana": ['mw'],
    "pratisamās": ['mw'],
    "pratisamāsana": ['mw'],
    "pratisamāsanaṃ": ['ap90'],
    "pratisamāsita": ['mw'],
    "pratisamāśrita": ['mw'],
    "pratisamīkṣ": ['mw'],
    "pratisamīkṣaṇa": ['mw'],
    "pratisara": ['ap90', 'cae', 'mw'],
    "pratisarabandha": ['mw'],
    "pratisarabandhā": ['mw'],
    "pratisarati": ['bhs'],
    "pratisaraṇa": ['bhs', 'mw'],
    "pratisaraṇatā": ['mw'],
    "pratisaraṇaṃ": ['ap90'],
    "pratisarga": ['mw'],
    "pratisargam": ['mw'],
    "pratisargaḥ": ['ap90'],
    "pratisarya": ['mw'],
    "pratisarā": ['bhs'],
    "pratisatkṛta": ['mw'],
    "pratisavya": ['mw'],
    "pratisaṃcar": ['mw'],
    "pratisaṃcara": ['mw'],
    "pratisaṃcaraḥ": ['ap90'],
    "pratisaṃdadhāti": ['bhs'],
    "pratisaṃdeśa": ['cae', 'mw'],
    "pratisaṃdeśaḥ": ['ap90'],
    "pratisaṃdeṣṭavya": ['mw'],
    "pratisaṃdheya": ['mw'],
    "pratisaṃdhi": ['bhs', 'mw'],
    "pratisaṃdhijñāna": ['mw'],
    "pratisaṃdhita": ['mw'],
    "pratisaṃdhiḥ": ['ap90'],
    "pratisaṃdhā": ['ap90', 'mw'],
    "pratisaṃdhāna": ['cae', 'mw'],
    "pratisaṃdhānaṃ": ['ap90'],
    "pratisaṃdhātṛ": ['mw'],
    "pratisaṃdiś": ['mw'],
    "pratisaṃgakṣikā": ['ap90'],
    "pratisaṃgin": ['ap90'],
    "pratisaṃgrah": ['mw'],
    "pratisaṃgraha": ['bhs'],
    "pratisaṃharaṇa": ['bhs'],
    "pratisaṃharaṇatā": ['bhs'],
    "pratisaṃharaṇīya": ['bhs', 'mw'],
    "pratisaṃhita": ['mw'],
    "pratisaṃhāra": ['cae', 'mw'],
    "pratisaṃhāraḥ": ['ap90'],
    "pratisaṃhṛ": ['ap90', 'mw'],
    "pratisaṃhṛta": ['ap90', 'bhs', 'mw'],
    "pratisaṃhṛṣ": ['mw'],
    "pratisaṃhṛṣṭa": ['mw'],
    "pratisaṃjihīrṣu": ['mw'],
    "pratisaṃjñā": ['mw'],
    "pratisaṃjāta": ['mw'],
    "pratisaṃkakṣikā": ['bhs'],
    "pratisaṃkhyā": ['ap90', 'bhs', 'mw'],
    "pratisaṃkhyāna": ['bhs', 'mw'],
    "pratisaṃkhyānirodha": ['mw'],
    "pratisaṃkhyāya": ['bhs'],
    "pratisaṃkram": ['mw'],
    "pratisaṃkrama": ['mw'],
    "pratisaṃkramaḥ": ['ap90'],
    "pratisaṃkramā": ['mw'],
    "pratisaṃkruddha": ['mw'],
    "pratisaṃkucita": ['mw'],
    "pratisaṃkāśa": ['mw'],
    "pratisaṃlapana": ['bhs'],
    "pratisaṃlayana": ['bhs', 'mw'],
    "pratisaṃlayati": ['bhs'],
    "pratisaṃlāna": ['bhs'],
    "pratisaṃlāpa": ['bhs'],
    "pratisaṃlīna": ['bhs', 'mw'],
    "pratisaṃlīyate": ['bhs'],
    "pratisaṃmodana": ['bhs'],
    "pratisaṃmodate": ['bhs'],
    "pratisaṃrabdha": ['mw'],
    "pratisaṃrabh": ['mw'],
    "pratisaṃruddha": ['mw'],
    "pratisaṃsarga": ['mw'],
    "pratisaṃskaraṇa": ['bhs'],
    "pratisaṃskāra": ['bhs', 'mw'],
    "pratisaṃskāram": ['mw'],
    "pratisaṃskārayati": ['bhs'],
    "pratisaṃskāraṇa": ['bhs'],
    "pratisaṃskāraṇā": ['mw'],
    "pratisaṃskṛ": ['mw'],
    "pratisaṃskṛta": ['mw'],
    "pratisaṃsmṛ": ['mw'],
    "pratisaṃstambh": ['mw'],
    "pratisaṃstara": ['bhs', 'mw'],
    "pratisaṃstaraṇa": ['bhs'],
    "pratisaṃsthāna": ['bhs', 'mw'],
    "pratisaṃsthānaṃ": ['ap90'],
    "pratisaṃsṛj": ['mw'],
    "pratisaṃsṛṣṭa": ['mw'],
    "pratisaṃsṛṣṭabhakta": ['mw'],
    "pratisaṃtuṣṭa": ['bhs'],
    "pratisaṃvad": ['mw'],
    "pratisaṃvartanīya": ['bhs'],
    "pratisaṃvatsaram": ['mw'],
    "pratisaṃveda": ['bhs'],
    "pratisaṃvedaka": ['ap90', 'bhs', 'mw'],
    "pratisaṃvedana": ['mw'],
    "pratisaṃvedanā": ['bhs'],
    "pratisaṃvedayati": ['bhs'],
    "pratisaṃvedin": ['bhs', 'mw'],
    "pratisaṃveṣṭ": ['mw'],
    "pratisaṃvid": ['ap90', 'bhs', 'mw'],
    "pratisaṃvidhāna": ['mw'],
    "pratisaṃvidita": ['bhs'],
    "pratisaṃvidā": ['bhs'],
    "pratisaṃvinniścayāvatārā": ['bhs', 'mw'],
    "pratisaṃvitprāpta": ['bhs', 'mw'],
    "pratisaṃvādin": ['mw'],
    "pratisaṃyat": ['mw'],
    "pratisaṃyatta": ['mw'],
    "pratisaṃyoddhṛ": ['ddsa', 'mw'],
    "pratisaṃyudh": ['mw'],
    "pratisaṃyukta": ['bhs', 'mw'],
    "pratisaṃyāta": ['mw'],
    "pratisaṃśikṣati": ['bhs'],
    "pratisaṃśri": ['mw'],
    "pratisaṃśru": ['mw'],
    "pratisaṅgakṣikā": ['mw'],
    "pratisaṅgin": ['mw'],
    "pratisenā": ['mw'],
    "pratisev": ['mw'],
    "pratisevati": ['bhs'],
    "pratisevin": ['bhs'],
    "pratisiṃha": ['mw'],
    "pratiskandha": ['ddsa', 'mw'],
    "pratiskandham": ['mw'],
    "pratiskhalita": ['mw'],
    "pratiskīrṇa": ['mw'],
    "pratiskṝ": ['mw'],
    "pratismṛ": ['mw'],
    "pratismṛta": ['bhs'],
    "pratismṛti": ['mw'],
    "pratisneha": ['mw'],
    "pratisnehaḥ": ['ap90'],
    "pratisnāta": ['ap90', 'mw'],
    "pratisomodakadvijam": ['mw'],
    "pratisomā": ['mw'],
    "pratispandana": ['mw'],
    "pratispardh": ['mw'],
    "pratispardhin": ['ap90', 'cae', 'mw'],
    "pratispardhā": ['ap90', 'mw'],
    "pratispaśa": ['mw'],
    "pratispaṃdanaṃ": ['ap90'],
    "pratisphur": ['mw'],
    "pratisphuṭa": ['bhs'],
    "pratispāśana": ['mw'],
    "pratisrota": ['mw'],
    "pratisrotam": ['mw'],
    "pratisrotas": ['mw'],
    "pratistabdha": ['mw'],
    "pratistambh": ['mw'],
    "pratisthānam": ['mw'],
    "pratistrī": ['mw'],
    "pratisubhati": ['bhs'],
    "pratisundarī": ['mw'],
    "pratisupta": ['mw'],
    "pratisvam": ['mw'],
    "pratisvan": ['mw'],
    "pratisvana": ['mw'],
    "pratisvanaḥ": ['ap90'],
    "pratisvara": ['mw'],
    "pratisvāhākāram": ['mw'],
    "pratisyandana": ['bhs'],
    "pratisāma": ['mw'],
    "pratisāmanta": ['mw'],
    "pratisāmarthya": ['mw'],
    "pratisāra": ['bhs'],
    "pratisāraṇa": ['mw'],
    "pratisāraṇaṃ": ['ap90'],
    "pratisāraṇīya": ['mw'],
    "pratisārin": ['bhs', 'mw'],
    "pratisārita": ['mw'],
    "pratisāyam": ['mw'],
    "pratisāṃdhānika": ['mw'],
    "pratisāṃdhānikaḥ": ['ap90'],
    "pratisīrā": ['ap90', 'bhs', 'cae', 'mw'],
    "pratisūrya": ['mw'],
    "pratisūryaka": ['mw'],
    "pratisūryam": ['mw'],
    "pratisūryamatsya": ['mw'],
    "pratisūryaśayānaka": ['mw'],
    "pratisṛ": ['ap90', 'mw'],
    "pratisṛj": ['mw'],
    "pratisṛjyati": ['bhs'],
    "pratisṛp": ['mw'],
    "pratisṛta": ['mw'],
    "pratisṛṣṭa": ['ap90', 'mw'],
    "pratitadvid": ['ddsa', 'mw'],
    "pratitantradarpaṇa": ['mw'],
    "pratitantram": ['mw'],
    "pratitantrasiddhānta": ['mw'],
    "pratitap": ['mw'],
    "pratitara": ['mw'],
    "pratitaraḥ": ['ap90'],
    "pratitarj": ['mw'],
    "pratitarkita": ['mw'],
    "pratitaru": ['mw'],
    "pratitarām": ['mw'],
    "pratitaḍ": ['mw'],
    "pratithi": ['ddsa', 'mw'],
    "pratitij": ['mw'],
    "pratitiṣṭhati": ['bhs'],
    "pratitryaham": ['mw'],
    "pratitāla": ['mw'],
    "pratitālaka": ['bhs', 'mw'],
    "pratitālī": ['ap90', 'mw'],
    "pratitāḍayati": ['bhs'],
    "pratitāḍitavya": ['mw'],
    "pratitūṇī": ['mw'],
    "prativac": ['ap90', 'mw'],
    "prativacana": ['cae', 'mw'],
    "prativacanaṃ": ['ap90'],
    "prativacanīkṛta": ['mw'],
    "prativacas": ['ap90', 'cae', 'mw'],
    "prativad": ['ap90', 'mw'],
    "prativadh": ['mw'],
    "prativaditavya": ['mw'],
    "prativah": ['mw'],
    "prativahana": ['bhs', 'mw'],
    "prativahanaṃ": ['ap90'],
    "prativahati": ['bhs'],
    "prativahnipradakṣiṇam": ['mw'],
    "prativaikārika": ['bhs'],
    "prativaira": ['mw'],
    "prativairamaṇa": ['bhs'],
    "prativaktavya": ['ddsa', 'mw'],
    "prativaktram": ['mw'],
    "prativaktṛ": ['mw'],
    "prativallabhā": ['mw'],
    "prativanam": ['mw'],
    "prativand": ['mw'],
    "prativanitā": ['mw'],
    "prativap": ['ap90', 'mw'],
    "prativargam": ['mw'],
    "prativarman": ['mw'],
    "prativartana": ['mw'],
    "prativartanaṃ": ['ap90'],
    "prativartman": ['mw'],
    "prativarṇa": ['mw'],
    "prativarṇam": ['mw'],
    "prativarṇika": ['bhs', 'mw'],
    "prativarṇita": ['bhs'],
    "prativarṣa": ['cae', 'mw'],
    "prativarṣam": ['mw'],
    "prativarṣaṇa": ['mw'],
    "prativas": ['mw'],
    "prativasatha": ['mw'],
    "prativasathaḥ": ['ap90'],
    "prativasati": ['mw'],
    "prativastu": ['bhs', 'cae', 'mw'],
    "prativastuka": ['bhs'],
    "prativastuvastūpamā": ['mw'],
    "prativastūpamā": ['cae'],
    "prativat": ['mw'],
    "prativatsara": ['cae', 'mw'],
    "prativatsaram": ['mw'],
    "prativaśa": ['bhs'],
    "prativaṣaṭkāram": ['mw'],
    "prativedam": ['mw'],
    "prativedaśākham": ['mw'],
    "prativedha": ['bhs'],
    "prativedin": ['bhs', 'mw'],
    "prativedita": ['mw'],
    "prativedāntam": ['mw'],
    "prativelam": ['mw'],
    "prativeśa": ['cae', 'gra', 'mw'],
    "prativeśaka": ['bhs'],
    "prativeśatas": ['mw'],
    "prativeśavāsin": ['mw'],
    "prativeśaḥ": ['ap90'],
    "prativeśin": ['ap90', 'cae', 'mw'],
    "prativeśma": ['mw'],
    "prativeśman": ['cae', 'mw'],
    "prativeśya": ['mw'],
    "prativeśyaḥ": ['ap90'],
    "prativeṣṭ": ['mw'],
    "prativeṣṭita": ['ap90'],
    "prativeṭhāpeti": ['bhs'],
    "prativibhaj": ['mw'],
    "prativibhinna": ['bhs'],
    "prativibhāga": ['mw'],
    "prativibhāvayati": ['bhs'],
    "prativibudh": ['mw'],
    "prativibudhyate": ['bhs'],
    "prativid": ['ap90', 'mw'],
    "pratividdha": ['mw'],
    "pratividh": ['mw'],
    "pratividheya": ['cae', 'mw'],
    "pratividhi": ['cae', 'mw'],
    "pratividhitsā": ['mw'],
    "pratividhiḥ": ['ap90'],
    "pratividhyana": ['bhs'],
    "pratividhyati": ['bhs'],
    "pratividhā": ['ap90', 'mw'],
    "pratividhāna": ['cae', 'mw'],
    "pratividhānaṃ": ['ap90'],
    "pratividhātavya": ['mw'],
    "pratividyam": ['mw'],
    "prativigacchati": ['bhs'],
    "prativighāta": ['ddsa', 'mw'],
    "prativighātaḥ": ['ap90'],
    "prativihita": ['mw'],
    "prativihā": ['mw'],
    "prativijñapayati": ['bhs'],
    "prativijñapti": ['bhs'],
    "prativijñā": ['mw'],
    "prativikalpa": ['bhs'],
    "prativikalpana": ['bhs'],
    "prativikalpayati": ['bhs'],
    "prativilomayati": ['bhs'],
    "prativimba": ['mw'],
    "prativimānanā": ['bhs'],
    "prativinaya": ['bhs'],
    "prativindhya": ['mw'],
    "prativinisṛjati": ['bhs'],
    "prativinodana": ['bhs'],
    "prativinud": ['mw'],
    "prativinudati": ['bhs'],
    "prativinīta": ['bhs'],
    "prativiparī": ['mw'],
    "prativiparīta": ['mw'],
    "prativipaśyati": ['bhs'],
    "prativipāśam": ['mw'],
    "prativirahita": ['bhs'],
    "prativiram": ['mw'],
    "prativiramati": ['bhs'],
    "prativiramaṇa": ['bhs'],
    "prativirata": ['bhs'],
    "prativirati": ['bhs', 'mw'],
    "prativirodha": ['bhs'],
    "prativiruddha": ['bhs', 'mw'],
    "prativisṛj": ['mw'],
    "prativiśeṣa": ['mw'],
    "prativiśeṣaṇa": ['mw'],
    "prativiśiṣṭa": ['ap90', 'mw'],
    "prativiśiṣṭataraka": ['bhs'],
    "prativiśodhayati": ['bhs'],
    "prativiśrabdha": ['mw'],
    "prativiśva": ['mw'],
    "prativiśveṣu": ['mw'],
    "prativiṣa": ['bhs', 'mw'],
    "prativiṣaya": ['mw'],
    "prativiṣayam": ['mw'],
    "prativiṣā": ['mw'],
    "prativiṣṇu": ['mw'],
    "prativiṣṇuka": ['mw'],
    "prativiṭapam": ['mw'],
    "prativodhavya": ['mw'],
    "prativoḍhavya": ['mw'],
    "prativraj": ['mw'],
    "prativrata": ['bhs'],
    "prativyadh": ['mw'],
    "prativyoma": ['mw'],
    "prativyoman": ['mw'],
    "prativyāhāra": ['ddsa', 'mw'],
    "prativyūh": ['mw'],
    "prativyūha": ['mw'],
    "prativyūhaḥ": ['ap90'],
    "prativyūḍha": ['ap90', 'mw'],
    "prativāc": ['ap90', 'mw'],
    "prativācika": ['mw'],
    "prativācya": ['mw'],
    "prativāda": ['cae', 'mw'],
    "prativādaḥ": ['ap90'],
    "prativādibhayaṃkara": ['mw'],
    "prativādin": ['ap90', 'cae', 'mw'],
    "prativāditā": ['mw'],
    "prativāha": ['mw'],
    "prativāhayati": ['bhs'],
    "prativākya": ['ap90', 'cae', 'mw'],
    "prativākyam": ['mw'],
    "prativāpa": ['mw'],
    "prativāpaḥ": ['ap90'],
    "prativāra": ['mw'],
    "prativāraḥ": ['ap90'],
    "prativāraṇa": ['cae', 'mw'],
    "prativārita": ['mw'],
    "prativārttā": ['mw'],
    "prativārtā": ['ap90'],
    "prativārya": ['mw'],
    "prativāsaram": ['cae', 'mw'],
    "prativāsare": ['mw'],
    "prativāsarika": ['mw'],
    "prativāsin": ['ap90', 'mw'],
    "prativāsita": ['mw'],
    "prativāsudeva": ['mw'],
    "prativāta": ['cae', 'mw'],
    "prativātam": ['mw'],
    "prativāte": ['mw'],
    "prativāś": ['mw'],
    "prativāśa": ['mw'],
    "prativāṇi": ['bhs', 'mw'],
    "prativāṇiḥ": ['ap90'],
    "prativī": ['mw'],
    "prativīkṣ": ['mw'],
    "prativīkṣaṇa": ['mw'],
    "prativīkṣaṇīya": ['mw'],
    "prativīkṣya": ['mw'],
    "prativīra": ['cae', 'mw'],
    "prativīratā": ['mw'],
    "prativīrya": ['mw'],
    "prativīta": ['mw'],
    "prativītatama": ['mw'],
    "prativṛ": ['mw'],
    "prativṛj": ['mw'],
    "prativṛt": ['mw'],
    "prativṛtta": ['mw'],
    "prativṛtti": ['mw'],
    "prativṛttāntam": ['mw'],
    "prativṛṣ": ['mw'],
    "prativṛṣa": ['mw'],
    "pratiyabh": ['mw'],
    "pratiyaj": ['mw'],
    "pratiyam": ['mw'],
    "pratiyat": ['ap90', 'mw'],
    "pratiyatna": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratiyatta": ['bhs'],
    "pratiyoddhavya": ['mw'],
    "pratiyoddhṛ": ['cae', 'mw'],
    "pratiyodha": ['cae', 'mw'],
    "pratiyodhana": ['cae', 'mw'],
    "pratiyodhaḥ": ['ap90'],
    "pratiyodhin": ['mw'],
    "pratiyoga": ['cae', 'mw'],
    "pratiyogam": ['mw'],
    "pratiyogaḥ": ['ap90'],
    "pratiyogi": ['mw'],
    "pratiyogijñānakāraṇatā": ['mw'],
    "pratiyogijñānakāraṇatāvāda": ['mw'],
    "pratiyogijñānasyahetutvakhaṇḍana": ['mw'],
    "pratiyogika": ['ap90', 'cae', 'mw'],
    "pratiyogikatva": ['mw'],
    "pratiyogin": ['ap90', 'cae', 'mw'],
    "pratiyoginirūpaṇa": ['mw'],
    "pratiyogitva": ['mw'],
    "pratiyogitā": ['ap90', 'mw'],
    "pratiyogitāvāda": ['mw'],
    "pratiyogyanadhikaraṇenāśasyotpattinirāsa": ['mw'],
    "pratiyojayitavya": ['mw'],
    "pratiyoni": ['mw'],
    "pratiyu": ['mw'],
    "pratiyuddha": ['cae', 'mw'],
    "pratiyuddhaṃ": ['ap90'],
    "pratiyudh": ['ap90', 'mw'],
    "pratiyuj": ['mw'],
    "pratiyuta": ['mw'],
    "pratiyuvam": ['mw'],
    "pratiyuvana": ['mw'],
    "pratiyuvati": ['mw'],
    "pratiyā": ['ap90', 'mw'],
    "pratiyācate": ['bhs'],
    "pratiyāga": ['mw'],
    "pratiyāmini": ['mw'],
    "pratiyānaṃ": ['ap90'],
    "pratiyāta": ['ap90', 'mw'],
    "pratiyātabuddhi": ['mw'],
    "pratiyātana": ['cae', 'mw'],
    "pratiyātanaṃ": ['ap90'],
    "pratiyātanidra": ['mw'],
    "pratiyātanā": ['ap90', 'mw'],
    "pratiyūpam": ['mw'],
    "pratiyūthapa": ['mw'],
    "pratiśabda": ['cae', 'mw'],
    "pratiśabdaga": ['mw'],
    "pratiśabdaka": ['cae', 'mw'],
    "pratiśabdavat": ['mw'],
    "pratiśak": ['mw'],
    "pratiśam": ['mw'],
    "pratiśama": ['mw'],
    "pratiśamayati": ['bhs'],
    "pratiśamaḥ": ['ap90'],
    "pratiśap": ['mw'],
    "pratiśara": ['mw'],
    "pratiśaraṇa": ['bhs', 'mw'],
    "pratiśaraṇabhūta": ['mw'],
    "pratiśarāsana": ['mw'],
    "pratiśarīram": ['mw'],
    "pratiśatru": ['cae', 'mw'],
    "pratiśaucam": ['mw'],
    "pratiśaya": ['bhs'],
    "pratiśayanaṃ": ['ap90'],
    "pratiśayita": ['ap90', 'mw'],
    "pratiśaśin": ['mw'],
    "pratiśaṃs": ['mw'],
    "pratiśaṅk": ['mw'],
    "pratiśaṅkanīya": ['mw'],
    "pratiśaṅkā": ['ddsa', 'mw'],
    "pratiśikṣ": ['mw'],
    "pratiśilpa": ['mw'],
    "pratiśiṣya": ['mw'],
    "pratiśiṣyakā": ['bhs'],
    "pratiśiṣṭa": ['ap90', 'mw'],
    "pratiśloka": ['mw'],
    "pratiślokam": ['mw'],
    "pratiśobhita": ['mw'],
    "pratiśodhayati": ['bhs'],
    "pratiśoka": ['bhs'],
    "pratiśrama": ['bhs', 'mw'],
    "pratiśrava": ['cae', 'mw'],
    "pratiśravas": ['mw'],
    "pratiśravaḥ": ['ap90'],
    "pratiśravaṇa": ['cae', 'mw'],
    "pratiśravaṇapūrva": ['mw'],
    "pratiśravaṇaṃ": ['ap90'],
    "pratiśravānte": ['mw'],
    "pratiśraya": ['cae', 'mw'],
    "pratiśrayaḥ": ['ap90'],
    "pratiśrita": ['mw'],
    "pratiśrotas": ['mw'],
    "pratiśrotṛ": ['mw'],
    "pratiśru": ['ap90', 'mw'],
    "pratiśrukā": ['bhs'],
    "pratiśrut": ['ap90', 'cae', 'mw'],
    "pratiśruta": ['ap90', 'mw'],
    "pratiśrutakā": ['bhs'],
    "pratiśruti": ['cae', 'mw'],
    "pratiśrutkā": ['bhs', 'mw'],
    "pratiśrāmayati": ['bhs'],
    "pratiśuc": ['mw'],
    "pratiśukrabudha": ['mw'],
    "pratiśukram": ['mw'],
    "pratiśulka": ['mw'],
    "pratiśuṣ": ['mw'],
    "pratiśvas": ['mw'],
    "pratiśyā": ['ap90', 'mw'],
    "pratiśyāya": ['mw'],
    "pratiśyāyin": ['mw'],
    "pratiśākham": ['mw'],
    "pratiśākhavat": ['mw'],
    "pratiśākhā": ['mw'],
    "pratiśākhānāḍī": ['mw'],
    "pratiśāmaka": ['bhs'],
    "pratiśāmayati": ['bhs'],
    "pratiśānta": ['mw'],
    "pratiśāntakopa": ['mw'],
    "pratiśāpa": ['cae', 'mw'],
    "pratiśāpaḥ": ['ap90'],
    "pratiśāsana": ['mw'],
    "pratiśāsanaṃ": ['ap90'],
    "pratiśāsti": ['mw'],
    "pratiśāstiḥ": ['ap90'],
    "pratiśī": ['mw'],
    "pratiśīna": ['ap90', 'mw'],
    "pratiśīnavat": ['mw'],
    "pratiśīta": ['mw'],
    "pratiśīvan": ['mw'],
    "pratiśṛṅgeṇa": ['mw'],
    "pratiśṛṇoti": ['bhs'],
    "pratiśṝ": ['mw'],
    "pratiṅgirā": ['mw'],
    "pratiṣañj": ['mw'],
    "pratiṣeddhavya": ['ddsa', 'mw'],
    "pratiṣeddhṛ": ['cae', 'mw'],
    "pratiṣedha": ['cae', 'mw'],
    "pratiṣedhaka": ['ap90', 'cae', 'mw'],
    "pratiṣedhana": ['cae', 'mw'],
    "pratiṣedhanaṃ": ['ap90'],
    "pratiṣedhanīya": ['mw'],
    "pratiṣedhayitṛ": ['mw'],
    "pratiṣedhaḥ": ['ap90'],
    "pratiṣedhokti": ['mw'],
    "pratiṣedhopamā": ['mw'],
    "pratiṣedhya": ['mw'],
    "pratiṣedhākṣara": ['mw'],
    "pratiṣedhāpavāda": ['mw'],
    "pratiṣedhārthīya": ['mw'],
    "pratiṣedhātmaka": ['cae', 'mw'],
    "pratiṣeka": ['cae', 'mw'],
    "pratiṣekya": ['mw'],
    "pratiṣevate": ['bhs'],
    "pratiṣevaṇa": ['mw'],
    "pratiṣic": ['mw'],
    "pratiṣicya": ['mw'],
    "pratiṣiddha": ['ap90', 'cae', 'mw'],
    "pratiṣiddhasevana": ['mw'],
    "pratiṣiddhasevin": ['mw'],
    "pratiṣiddhavat": ['mw'],
    "pratiṣiddhavāma": ['cae', 'mw'],
    "pratiṣidh": ['ap90', 'mw'],
    "pratiṣiv": ['mw'],
    "pratiṣka": ['mw'],
    "pratiṣkabh": ['mw'],
    "pratiṣkasa": ['mw'],
    "pratiṣkaśa": ['mw'],
    "pratiṣkaśaḥ": ['ap90'],
    "pratiṣkaḥ": ['ap90'],
    "pratiṣkaṣa": ['mw'],
    "pratiṣkaṣaḥ": ['ap90'],
    "pratiṣku": ['mw'],
    "pratiṣkuta": ['mw'],
    "pratiṣkūla": ['bhs'],
    "pratiṣvad": ['mw'],
    "pratiṣṇikā": ['mw'],
    "pratiṣṇā": ['mw'],
    "pratiṣṇāta": ['mw'],
    "pratiṣṭabdha": ['ap90', 'mw'],
    "pratiṣṭambha": ['mw'],
    "pratiṣṭambhin": ['mw'],
    "pratiṣṭaṃbhaḥ": ['ap90'],
    "pratiṣṭha": ['ap90', 'cae', 'mw'],
    "pratiṣṭhapayati": ['bhs'],
    "pratiṣṭheti": ['bhs'],
    "pratiṣṭhi": ['cae', 'gra', 'mw'],
    "pratiṣṭhikā": ['mw'],
    "pratiṣṭhita": ['ap90', 'cae', 'mw'],
    "pratiṣṭhitacāritra": ['bhs'],
    "pratiṣṭhitamātra": ['mw'],
    "pratiṣṭhitapada": ['mw'],
    "pratiṣṭhitasaṃtāna": ['mw'],
    "pratiṣṭhitayaśas": ['mw'],
    "pratiṣṭhiti": ['ap90', 'mw'],
    "pratiṣṭhiv": ['mw'],
    "pratiṣṭhoddyota": ['mw'],
    "pratiṣṭhā": ['ap90', 'gra', 'mw'],
    "pratiṣṭhācintāmaṇi": ['mw'],
    "pratiṣṭhādarpaṇa": ['mw'],
    "pratiṣṭhādarśa": ['mw'],
    "pratiṣṭhādyota": ['mw'],
    "pratiṣṭhādīdhiti": ['mw'],
    "pratiṣṭhāhemādri": ['mw'],
    "pratiṣṭhākalpalatā": ['mw'],
    "pratiṣṭhākalpādi": ['mw'],
    "pratiṣṭhākamalākara": ['mw'],
    "pratiṣṭhākaumudī": ['mw'],
    "pratiṣṭhākaustubha": ['mw'],
    "pratiṣṭhākāma": ['mw'],
    "pratiṣṭhālakṣaṇa": ['mw'],
    "pratiṣṭhāmayūkha": ['mw'],
    "pratiṣṭhāna": ['ap90', 'bhs', 'cae', 'mw'],
    "pratiṣṭhānaṃ": ['ap90'],
    "pratiṣṭhānirṇaya": ['mw'],
    "pratiṣṭhānvita": ['mw'],
    "pratiṣṭhāpaddhati": ['mw'],
    "pratiṣṭhāpaka": ['bhs'],
    "pratiṣṭhāpam": ['mw'],
    "pratiṣṭhāpana": ['bhs', 'mw'],
    "pratiṣṭhāpanapaddhati": ['mw'],
    "pratiṣṭhāpanaṃ": ['ap90'],
    "pratiṣṭhāpanā": ['mw'],
    "pratiṣṭhāpayitavya": ['mw'],
    "pratiṣṭhāpayitṛ": ['ap90', 'mw'],
    "pratiṣṭhāpita": ['mw'],
    "pratiṣṭhāpya": ['mw'],
    "pratiṣṭhārahasya": ['mw'],
    "pratiṣṭhāratna": ['mw'],
    "pratiṣṭhāsamuccaya": ['mw'],
    "pratiṣṭhāsaṃgraha": ['mw'],
    "pratiṣṭhāsu": ['mw'],
    "pratiṣṭhāsāra": ['mw'],
    "pratiṣṭhāsārasaṃgraha": ['mw'],
    "pratiṣṭhātantra": ['mw'],
    "pratiṣṭhātattva": ['mw'],
    "pratiṣṭhātilaka": ['mw'],
    "pratiṣṭhātva": ['mw'],
    "pratiṣṭhātṛ": ['mw'],
    "pratiṣṭhāvat": ['mw'],
    "pratiṣṭhāvidhi": ['mw'],
    "pratiṣṭhāviveka": ['mw'],
    "pratiṣṭotṛ": ['mw'],
    "pratiṣṭubh": ['mw'],
    "pratiṣṭuti": ['gra', 'mw'],
    "pratna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pratnathā": ['cae', 'gra', 'mw'],
    "pratnavat": ['cae', 'gra', 'mw'],
    "pratoda": ['cae', 'mw'],
    "pratodana": ['bhs'],
    "pratodayantra": ['mw'],
    "pratodayaṣṭi": ['mw'],
    "pratodaḥ": ['ap90'],
    "pratodin": ['mw'],
    "pratolī": ['ap90', 'cae', 'mw'],
    "pratolīdvāra": ['cae'],
    "pratoṣa": ['mw'],
    "pratras": ['mw'],
    "pratretu": ['bhs'],
    "pratrāsa": ['mw'],
    "pratta": ['ap90', 'ddsa', 'mw'],
    "prattavat": ['mw'],
    "pratti": ['cae', 'mw'],
    "pratud": ['ap90', 'cae', 'mw'],
    "pratuda": ['cae', 'ddsa', 'mw'],
    "pratudaḥ": ['ap90'],
    "pratur": ['gra', 'mw'],
    "praturv": ['mw'],
    "pratustuṣu": ['mw'],
    "pratuṣ": ['mw'],
    "pratuṣṭi": ['cae', 'mw'],
    "pratuṣṭida": ['mw'],
    "pratuṣṭiḥ": ['ap90'],
    "pratuṣṭuṣu": ['mw'],
    "pratvakṣ": ['mw'],
    "pratvakṣas": ['cae', 'ddsa', 'gra', 'mw'],
    "pratvakṣāṇa": ['cae'],
    "pratvar": ['mw'],
    "praty": ['mw'],
    "pratyabdam": ['ddsa', 'mw'],
    "pratyabhibhāṣin": ['mw'],
    "pratyabhibhūta": ['ap90', 'mw'],
    "pratyabhicar": ['mw'],
    "pratyabhicaraṇa": ['mw'],
    "pratyabhicita": ['mw'],
    "pratyabhidhā": ['mw'],
    "pratyabhidhāv": ['mw'],
    "pratyabhighāraṇa": ['cae', 'ddsa', 'mw'],
    "pratyabhighṛ": ['mw'],
    "pratyabhihita": ['mw'],
    "pratyabhihṛ": ['mw'],
    "pratyabhijñā": ['ap90', 'cae', 'mw'],
    "pratyabhijñādarśana": ['mw'],
    "pratyabhijñāhṛdaya": ['mw'],
    "pratyabhijñāna": ['mw'],
    "pratyabhijñānaratna": ['mw'],
    "pratyabhijñānaṃ": ['ap90'],
    "pratyabhijñāpana": ['mw'],
    "pratyabhijñāsūtra": ['mw'],
    "pratyabhijñāta": ['ap90', 'bhs', 'mw'],
    "pratyabhijñātavat": ['mw'],
    "pratyabhijñāvimarśinī": ['mw'],
    "pratyabhijñāyamānatva": ['mw'],
    "pratyabhijñāśāstra": ['mw'],
    "pratyabhilekhya": ['mw'],
    "pratyabhimarśa": ['mw'],
    "pratyabhimethana": ['mw'],
    "pratyabhimith": ['mw'],
    "pratyabhimṛś": ['mw'],
    "pratyabhimṛśana": ['mw'],
    "pratyabhimṛṣṭa": ['mw'],
    "pratyabhinand": ['mw'],
    "pratyabhinandin": ['mw'],
    "pratyabhinandita": ['mw'],
    "pratyabhiprasthā": ['mw'],
    "pratyabhiskandana": ['mw'],
    "pratyabhiskaṃdanaṃ": ['ap90'],
    "pratyabhivad": ['ap90', 'mw'],
    "pratyabhivāda": ['cae', 'mw'],
    "pratyabhivādaka": ['mw'],
    "pratyabhivādana": ['mw'],
    "pratyabhivādayitṛ": ['mw'],
    "pratyabhivādaḥ": ['ap90'],
    "pratyabhiyoga": ['cae', 'mw'],
    "pratyabhiyogaḥ": ['ap90'],
    "pratyabhiyuj": ['mw'],
    "pratyabhiyukta": ['ap90', 'mw'],
    "pratyabhiyuktavat": ['mw'],
    "pratyabhiyā": ['mw'],
    "pratyabhyanujñā": ['ddsa', 'mw'],
    "pratyabhyanujñāta": ['mw'],
    "pratyabhyutthāna": ['mw'],
    "pratyabhyāsam": ['mw'],
    "pratyac": ['gra'],
    "pratyad": ['mw'],
    "pratyadana": ['mw'],
    "pratyadhidevatā": ['mw'],
    "pratyadhikaraṇam": ['ddsa', 'mw'],
    "pratyadhiśri": ['mw'],
    "pratyadhiṣṭhāna": ['bhs'],
    "pratyadhī": ['mw'],
    "pratyag": ['mw'],
    "pratyagakṣa": ['ddsa', 'mw'],
    "pratyagakṣaja": ['mw'],
    "pratyagam": ['mw'],
    "pratyagapavarga": ['mw'],
    "pratyagdakṣiṇatas": ['cae', 'mw'],
    "pratyagdakṣiṇā": ['cae', 'mw'],
    "pratyagdakṣiṇāpravaṇa": ['mw'],
    "pratyagdhāman": ['mw'],
    "pratyagdiś": ['mw'],
    "pratyagdṛś": ['mw'],
    "pratyagekarasa": ['mw'],
    "pratyagjyotis": ['mw'],
    "pratyagni": ['ddsa', 'mw'],
    "pratyagra": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratyagragandhā": ['mw'],
    "pratyagraha": ['mw'],
    "pratyagrakṣarat": ['mw'],
    "pratyagram": ['mw'],
    "pratyagraprasavā": ['mw'],
    "pratyagrarūpa": ['bhs', 'mw'],
    "pratyagratha": ['mw'],
    "pratyagratva": ['mw'],
    "pratyagratā": ['mw'],
    "pratyagravayas": ['mw'],
    "pratyagrayauvana": ['mw'],
    "pratyagraśodhita": ['mw'],
    "pratyagudak": ['mw'],
    "pratyagvahanaprayoga": ['mw'],
    "pratyagānanda": ['cae', 'mw'],
    "pratyagātma": ['mw'],
    "pratyagātman": ['cae', 'mw'],
    "pratyagātmatva": ['mw'],
    "pratyagātmatā": ['mw'],
    "pratyagāśis": ['mw'],
    "pratyagāśāpati": ['mw'],
    "pratyah": ['mw'],
    "pratyaha": ['cae', 'mw'],
    "pratyaham": ['mw'],
    "pratyajati": ['bhs'],
    "pratyajira": ['mw'],
    "pratyak": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratyakcetana": ['mw'],
    "pratyakcetanā": ['mw'],
    "pratyakcintāmaṇi": ['mw'],
    "pratyakparṇī": ['mw'],
    "pratyakprakāśa": ['mw'],
    "pratyakpravaṇa": ['mw'],
    "pratyakpravaṇatā": ['mw'],
    "pratyakpuṣkara": ['mw'],
    "pratyakpuṣpī": ['mw'],
    "pratyaksarasvatī": ['ddsa', 'mw'],
    "pratyaksaṃstham": ['mw'],
    "pratyaksrotas": ['mw'],
    "pratyaksthalī": ['mw'],
    "pratyaksvarūpa": ['mw'],
    "pratyaktattvadīpikā": ['mw'],
    "pratyaktattvaviveka": ['mw'],
    "pratyaktva": ['mw'],
    "pratyakśiras": ['mw'],
    "pratyakśreṇī": ['mw'],
    "pratyakśrotas": ['mw'],
    "pratyakśīrṣī": ['mw'],
    "pratyakṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "pratyakṣabandhu": ['mw'],
    "pratyakṣabhakṣa": ['mw'],
    "pratyakṣabhoga": ['mw'],
    "pratyakṣabhūta": ['cae', 'mw'],
    "pratyakṣabṛhatī": ['mw'],
    "pratyakṣacārin": ['cae', 'mw'],
    "pratyakṣadarśana": ['cae', 'mw'],
    "pratyakṣadarśin": ['cae', 'mw'],
    "pratyakṣadarśivas": ['mw'],
    "pratyakṣadeva": ['bhs'],
    "pratyakṣadharman": ['bhs', 'mw'],
    "pratyakṣadviṣ": ['mw'],
    "pratyakṣadīpikā": ['mw'],
    "pratyakṣadṛś": ['mw'],
    "pratyakṣadṛśya": ['mw'],
    "pratyakṣadṛṣṭa": ['cae', 'mw'],
    "pratyakṣajñāna": ['mw'],
    "pratyakṣakaraṇa": ['mw'],
    "pratyakṣakhaṇḍa": ['mw'],
    "pratyakṣakhaṇḍacintāmaṇi": ['mw'],
    "pratyakṣakhaṇḍavyākhyā": ['mw'],
    "pratyakṣakṛta": ['mw'],
    "pratyakṣakṛtā": ['mw'],
    "pratyakṣam": ['mw'],
    "pratyakṣamaṇi": ['mw'],
    "pratyakṣamaṇiraśmicakra": ['mw'],
    "pratyakṣapara": ['mw'],
    "pratyakṣapariccheda": ['mw'],
    "pratyakṣaparicchedamañjūṣā": ['mw'],
    "pratyakṣaparicchedarahasya": ['mw'],
    "pratyakṣaparīkṣaṇa": ['mw'],
    "pratyakṣaphala": ['mw'],
    "pratyakṣaphalatva": ['mw'],
    "pratyakṣapramā": ['mw'],
    "pratyakṣapramāṇa": ['mw'],
    "pratyakṣapramāṇyālokaṭippaṇī": ['mw'],
    "pratyakṣapṛṣṭha": ['mw'],
    "pratyakṣara": ['mw'],
    "pratyakṣaraśleṣamaya": ['ddsa', 'mw'],
    "pratyakṣarucidattīya": ['mw'],
    "pratyakṣasiddha": ['mw'],
    "pratyakṣatamām": ['mw'],
    "pratyakṣatamāt": ['mw'],
    "pratyakṣatas": ['mw'],
    "pratyakṣatayā": ['mw'],
    "pratyakṣatva": ['mw'],
    "pratyakṣatā": ['ap90', 'cae', 'mw'],
    "pratyakṣavat": ['ddsa', 'mw'],
    "pratyakṣavidhāna": ['mw'],
    "pratyakṣavihita": ['mw'],
    "pratyakṣaviṣayībhū": ['mw'],
    "pratyakṣavāda": ['mw'],
    "pratyakṣavādin": ['mw'],
    "pratyakṣavṛtti": ['mw'],
    "pratyakṣaya": ['ddsa', 'mw'],
    "pratyakṣayati": ['ap90'],
    "pratyakṣe": ['mw'],
    "pratyakṣeṇa": ['mw'],
    "pratyakṣin": ['ap90', 'bhs', 'mw'],
    "pratyakṣāgamana": ['mw'],
    "pratyakṣānumāna": ['mw'],
    "pratyakṣānumānaśabdakhaṇḍana": ['mw'],
    "pratyakṣānumānaṭīkā": ['mw'],
    "pratyakṣāt": ['mw'],
    "pratyakṣāvagama": ['mw'],
    "pratyakṣāya": ['ddsa', 'mw'],
    "pratyakṣāyamāṇatva": ['mw'],
    "pratyakṣī": ['mw'],
    "pratyakṣībhū": ['mw'],
    "pratyakṣīkaraṇa": ['cae', 'ddsa', 'mw'],
    "pratyakṣīkṛ": ['ap90', 'cae', 'mw'],
    "pratyakṣīkṛta": ['mw'],
    "pratyamitra": ['ddsa', 'mw'],
    "pratyanantara": ['cae', 'ddsa', 'mw'],
    "pratyanantaram": ['mw'],
    "pratyanantarībhū": ['mw'],
    "pratyandhakāra": ['bhs', 'mw'],
    "pratyanilam": ['mw'],
    "pratyanta": ['bhs', 'mw'],
    "pratyantadeśa": ['mw'],
    "pratyantajanapada": ['mw'],
    "pratyantajanapadopapatti": ['mw'],
    "pratyantaparvata": ['mw'],
    "pratyantarāpatti": ['bhs'],
    "pratyantarībhū": ['mw'],
    "pratyantavāsa": ['mw'],
    "pratyantika": ['bhs', 'mw'],
    "pratyantima": ['bhs', 'mw'],
    "pratyantāt": ['mw'],
    "pratyanubhavati": ['bhs'],
    "pratyanubhāva": ['bhs'],
    "pratyanubhāṣati": ['bhs'],
    "pratyanubhū": ['mw'],
    "pratyanujñā": ['mw'],
    "pratyanukampate": ['bhs'],
    "pratyanumāna": ['mw'],
    "pratyanunī": ['mw'],
    "pratyanuprāsa": ['mw'],
    "pratyanusmṛ": ['mw'],
    "pratyanutap": ['mw'],
    "pratyanuvāśita": ['mw'],
    "pratyanuyoga": ['bhs', 'mw'],
    "pratyanuyujyate": ['bhs'],
    "pratyanuyukta": ['bhs'],
    "pratyanuyāc": ['mw'],
    "pratyanuśaṃsate": ['bhs'],
    "pratyanīka": ['cae', 'mw'],
    "pratyanīkabhāva": ['mw'],
    "pratyanīkatva": ['mw'],
    "pratyanūkāntam": ['mw'],
    "pratyapakāra": ['ddsa', 'mw'],
    "pratyapakṛ": ['mw'],
    "pratyapara": ['mw'],
    "pratyapasṛp": ['mw'],
    "pratyapavah": ['mw'],
    "pratyapayā": ['mw'],
    "pratyaporṇu": ['mw'],
    "pratyapāya": ['mw'],
    "pratyara": ['mw'],
    "pratyaraṇya": ['bhs', 'mw'],
    "pratyarc": ['mw'],
    "pratyarcana": ['mw'],
    "pratyarcita": ['mw'],
    "pratyard": ['mw'],
    "pratyardha": ['mw'],
    "pratyardhi": ['gra', 'mw'],
    "pratyargala": ['mw'],
    "pratyarha": ['bhs'],
    "pratyarham": ['mw'],
    "pratyari": ['ddsa', 'mw'],
    "pratyarka": ['mw'],
    "pratyarpaṇa": ['cae', 'mw'],
    "pratyarpaṇaṃ": ['ap90'],
    "pratyarpaṇīya": ['cae', 'mw'],
    "pratyarpita": ['ap90', 'mw'],
    "pratyarth": ['ap90', 'mw'],
    "pratyartha": ['ap90'],
    "pratyarthaka": ['mw'],
    "pratyarthakaḥ": ['ap90'],
    "pratyartham": ['mw'],
    "pratyarthibhūta": ['mw'],
    "pratyarthika": ['bhs', 'mw'],
    "pratyarthin": ['ap90', 'cae', 'mw'],
    "pratyarthitva": ['mw'],
    "pratyarthitā": ['cae', 'mw'],
    "pratyarthyāvedana": ['mw'],
    "pratyarā": ['mw'],
    "pratyarṇam": ['mw'],
    "pratyas": ['mw'],
    "pratyasta": ['mw'],
    "pratyastagamana": ['mw'],
    "pratyastam": ['mw'],
    "pratyastamaya": ['mw'],
    "pratyastamayaḥ": ['ap90'],
    "pratyastra": ['mw'],
    "pratyavabhuj": ['mw'],
    "pratyavabhāsa": ['mw'],
    "pratyavabhāṣ": ['mw'],
    "pratyavabhāṣa": ['mw'],
    "pratyavabhāṣati": ['bhs'],
    "pratyavabhāṣā": ['mw'],
    "pratyavadhā": ['mw'],
    "pratyavado": ['mw'],
    "pratyavagam": ['mw'],
    "pratyavagama": ['bhs'],
    "pratyavagrah": ['mw'],
    "pratyavahan": ['mw'],
    "pratyavahāra": ['cae', 'mw'],
    "pratyavahāraḥ": ['ap90'],
    "pratyavahṛ": ['mw'],
    "pratyavakarśana": ['mw'],
    "pratyavakrānta": ['bhs'],
    "pratyavamarśa": ['cae', 'mw'],
    "pratyavamarśana": ['mw'],
    "pratyavamarśavat": ['mw'],
    "pratyavamarśaḥ": ['ap90'],
    "pratyavamarṣa": ['mw'],
    "pratyavamarṣavat": ['mw'],
    "pratyavamṛś": ['mw'],
    "pratyavamṛṣ": ['mw'],
    "pratyavanejana": ['ddsa', 'mw'],
    "pratyavara": ['cae', 'ddsa', 'mw'],
    "pratyavarakālam": ['mw'],
    "pratyavarodhana": ['cae', 'ddsa', 'mw'],
    "pratyavarodhanaṃ": ['ap90'],
    "pratyavaroha": ['cae', 'mw'],
    "pratyavaroham": ['mw'],
    "pratyavarohaṇa": ['mw'],
    "pratyavarohaṇīya": ['mw'],
    "pratyavarohin": ['cae', 'mw'],
    "pratyavarohiṇī": ['mw'],
    "pratyavaruddha": ['mw'],
    "pratyavarudh": ['mw'],
    "pratyavaruh": ['mw'],
    "pratyavarūḍhi": ['cae', 'mw'],
    "pratyavasad": ['mw'],
    "pratyavasarati": ['bhs'],
    "pratyavasita": ['ap90', 'mw'],
    "pratyavaskanda": ['mw'],
    "pratyavaskandana": ['mw'],
    "pratyavaskaṃdaḥ": ['ap90'],
    "pratyavaso": ['mw'],
    "pratyavasthita": ['mw'],
    "pratyavasthā": ['ap90', 'mw'],
    "pratyavasthāna": ['bhs', 'mw'],
    "pratyavasthānaṃ": ['ap90'],
    "pratyavasthāpana": ['mw'],
    "pratyavasthātṛ": ['ap90', 'mw'],
    "pratyavasāna": ['cae', 'mw'],
    "pratyavasānaṃ": ['ap90'],
    "pratyavasṛj": ['mw'],
    "pratyavasṛp": ['mw'],
    "pratyavasṛta": ['mw'],
    "pratyavatarati": ['bhs'],
    "pratyavatṝ": ['mw'],
    "pratyavayava": ['mw'],
    "pratyavayavam": ['mw'],
    "pratyavayavavarṇanā": ['mw'],
    "pratyave": ['mw'],
    "pratyavekṣ": ['ap90', 'mw'],
    "pratyavekṣaṇa": ['cae', 'mw'],
    "pratyavekṣaṇatā": ['bhs'],
    "pratyavekṣaṇaṃ": ['ap90'],
    "pratyavekṣaṇā": ['bhs', 'cae', 'mw'],
    "pratyavekṣya": ['cae', 'mw'],
    "pratyavekṣā": ['cae', 'mw'],
    "pratyavāp": ['mw'],
    "pratyavāya": ['cae', 'ddsa', 'mw'],
    "pratyavāyaḥ": ['ap90'],
    "pratyaya": ['bhs', 'cae', 'ddsa', 'mw'],
    "pratyayadhātu": ['mw'],
    "pratyayakara": ['cae', 'mw'],
    "pratyayakāraka": ['cae', 'mw'],
    "pratyayakāraṇa": ['cae', 'mw'],
    "pratyayakārin": ['mw'],
    "pratyayakāriṇī": ['mw'],
    "pratyayalopa": ['mw'],
    "pratyayamauktikamālā": ['mw'],
    "pratyayana": ['bhs'],
    "pratyayanam": ['ddsa', 'mw'],
    "pratyayanastva": ['mw'],
    "pratyayaprativacana": ['cae', 'mw'],
    "pratyayasarga": ['ddsa', 'mw'],
    "pratyayasvara": ['mw'],
    "pratyayatattvaprakāśikā": ['mw'],
    "pratyayatva": ['mw'],
    "pratyayaḥ": ['ap90'],
    "pratyayika": ['mw'],
    "pratyayin": ['ap90', 'cae', 'mw'],
    "pratyayita": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratyayitavya": ['mw'],
    "pratyayādhi": ['mw'],
    "pratyayāntaśabdakṛdantavyūha": ['mw'],
    "pratyayātma": ['mw'],
    "pratyayāya": ['mw'],
    "pratyañc": ['cae', 'ddsa', 'mw'],
    "pratyañj": ['mw'],
    "pratyañjana": ['mw'],
    "pratyaśman": ['mw'],
    "pratyaṃc": ['ap90'],
    "pratyaṃcita": ['ap90'],
    "pratyaṃsa": ['mw'],
    "pratyaṃsam": ['ddsa', 'mw'],
    "pratyaṃśa": ['bhs', 'mw'],
    "pratyaṃśu": ['mw'],
    "pratyaṅ": ['mw'],
    "pratyaṅga": ['cae', 'ddsa', 'mw'],
    "pratyaṅgadakṣiṇā": ['cae', 'mw'],
    "pratyaṅgam": ['mw'],
    "pratyaṅgatva": ['mw'],
    "pratyaṅgavartin": ['mw'],
    "pratyaṅgiras": ['mw'],
    "pratyaṅgirasa": ['mw'],
    "pratyaṅgirā": ['mw'],
    "pratyaṅgirākalpa": ['mw'],
    "pratyaṅgirāmantra": ['mw'],
    "pratyaṅgirāmantraṛksamudāya": ['mw'],
    "pratyaṅgirāpañcāṅga": ['mw'],
    "pratyaṅgirāprayoga": ['mw'],
    "pratyaṅgirāsahasranāman": ['mw'],
    "pratyaṅgirāsahasranāmastotra": ['mw'],
    "pratyaṅgirāsiddhamantroddhāra": ['mw'],
    "pratyaṅgirāstotra": ['mw'],
    "pratyaṅgirāstotropāsanādi": ['mw'],
    "pratyaṅgirāsūkta": ['mw'],
    "pratyaṅgirātattva": ['mw'],
    "pratyaṅka": ['mw'],
    "pratyaṅkam": ['ddsa', 'mw'],
    "pratyaṅmukha": ['cae', 'ddsa', 'mw'],
    "pratyaṅmukhatva": ['mw'],
    "pratyaṣṭa": ['mw'],
    "pratyaṣṭhīlā": ['mw'],
    "pratye": ['mw'],
    "pratyeka": ['bhs', 'cae', 'ddsa', 'mw'],
    "pratyekabodhi": ['bhs', 'mw'],
    "pratyekabrahman": ['bhs'],
    "pratyekabuddha": ['bhs', 'mw'],
    "pratyekabuddhacatuṣṭaya": ['mw'],
    "pratyekabuddhakathā": ['mw'],
    "pratyekabuddhatva": ['mw'],
    "pratyekajina": ['bhs'],
    "pratyekakhaḍgin": ['bhs'],
    "pratyekam": ['mw'],
    "pratyekanaraka": ['bhs', 'mw'],
    "pratyekarājan": ['bhs'],
    "pratyekasatya": ['bhs'],
    "pratyekayāna": ['bhs'],
    "pratyekaśas": ['cae', 'mw'],
    "pratyenas": ['mw'],
    "pratyenasya": ['mw'],
    "pratyetavya": ['ddsa', 'mw'],
    "pratyetṛ": ['mw'],
    "pratyeṣ": ['mw'],
    "pratyeṣaka": ['bhs'],
    "pratyeṣita": ['bhs'],
    "pratyottareṇa": ['bhs'],
    "pratyuccar": ['mw'],
    "pratyucchri": ['mw'],
    "pratyucchrita": ['mw'],
    "pratyuccāra": ['bhs', 'mw'],
    "pratyuccāraḥ": ['ap90'],
    "pratyuccāraṇa": ['mw'],
    "pratyudadhi": ['mw'],
    "pratyuddeśa": ['bhs'],
    "pratyuddharati": ['bhs'],
    "pratyuddharaṇa": ['mw'],
    "pratyuddharaṇaṃ": ['ap90'],
    "pratyuddhā": ['mw'],
    "pratyuddhāra": ['bhs', 'mw'],
    "pratyuddhārya": ['bhs'],
    "pratyuddhṛta": ['mw'],
    "pratyuddīp": ['mw'],
    "pratyudgam": ['ap90', 'mw'],
    "pratyudgama": ['cae', 'mw'],
    "pratyudgamaka": ['bhs'],
    "pratyudgamana": ['mw'],
    "pratyudgamanīya": ['mw'],
    "pratyudgamanīyaṃ": ['ap90'],
    "pratyudgata": ['ap90', 'mw'],
    "pratyudgati": ['cae', 'mw'],
    "pratyudgatiḥ": ['ap90'],
    "pratyudghāta": ['mw'],
    "pratyudgrah": ['mw'],
    "pratyudgraha": ['mw'],
    "pratyudgrahaṇa": ['mw'],
    "pratyudgā": ['mw'],
    "pratyudgāra": ['mw'],
    "pratyudgīta": ['mw'],
    "pratyudi": ['mw'],
    "pratyudita": ['mw'],
    "pratyudvad": ['mw'],
    "pratyudvartavya": ['bhs'],
    "pratyudvraj": ['mw'],
    "pratyudyam": ['mw'],
    "pratyudyama": ['ap90', 'mw'],
    "pratyudyamin": ['mw'],
    "pratyudyata": ['mw'],
    "pratyudyā": ['mw'],
    "pratyudyāmin": ['mw'],
    "pratyudyāna": ['bhs', 'mw'],
    "pratyudyāta": ['ap90', 'mw'],
    "pratyudyātṛ": ['mw'],
    "pratyudāharaṇa": ['cae', 'mw'],
    "pratyudāharaṇaṃ": ['ap90'],
    "pratyudāhāra": ['bhs'],
    "pratyudāhārya": ['mw'],
    "pratyudāhṛ": ['mw'],
    "pratyudāhṛta": ['mw'],
    "pratyudāvarta": ['bhs'],
    "pratyudāvartana": ['bhs'],
    "pratyudāvartate": ['bhs'],
    "pratyudāvraj": ['mw'],
    "pratyudīkṣ": ['mw'],
    "pratyudīr": ['mw'],
    "pratyujjīv": ['ap90', 'mw'],
    "pratyujjīvana": ['cae', 'mw'],
    "pratyujjīvanaṃ": ['ap90'],
    "pratyukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratyukti": ['mw'],
    "pratyuktiḥ": ['ap90'],
    "pratyukṣ": ['mw'],
    "pratyulūka": ['mw'],
    "pratyulūkaka": ['mw'],
    "pratyunmiṣ": ['mw'],
    "pratyunnamana": ['mw'],
    "pratyunnamanaṃ": ['ap90'],
    "pratyupabhoga": ['mw'],
    "pratyupabhuj": ['mw'],
    "pratyupadeśa": ['mw'],
    "pratyupadeśaḥ": ['ap90'],
    "pratyupadhā": ['mw'],
    "pratyupadiś": ['mw'],
    "pratyupadiṣṭa": ['mw'],
    "pratyupadru": ['mw'],
    "pratyupagam": ['mw'],
    "pratyupagata": ['mw'],
    "pratyupahava": ['mw'],
    "pratyupahve": ['mw'],
    "pratyupahāra": ['cae', 'mw'],
    "pratyupahāraḥ": ['ap90'],
    "pratyupakram": ['mw'],
    "pratyupakriyā": ['ap90', 'mw'],
    "pratyupakāra": ['cae', 'ddsa', 'mw'],
    "pratyupakāraḥ": ['ap90'],
    "pratyupakārin": ['mw'],
    "pratyupakṛ": ['ap90', 'mw'],
    "pratyupalabdha": ['ap90', 'mw'],
    "pratyupalabdhacetas": ['mw'],
    "pratyupamāna": ['mw'],
    "pratyupamānaṃ": ['ap90'],
    "pratyupapanna": ['ap90', 'cae', 'mw'],
    "pratyuparuddha": ['mw'],
    "pratyupasadam": ['mw'],
    "pratyupasparśana": ['mw'],
    "pratyupaspṛś": ['mw'],
    "pratyupasthita": ['bhs', 'cae', 'mw'],
    "pratyupasthā": ['mw'],
    "pratyupasthāna": ['bhs', 'mw'],
    "pratyupasthānaṃ": ['ap90'],
    "pratyupasthāpana": ['mw'],
    "pratyupasṛ": ['mw'],
    "pratyupatiṣṭhati": ['bhs'],
    "pratyupaveśa": ['mw'],
    "pratyupaveśana": ['mw'],
    "pratyupaveśaḥ": ['ap90'],
    "pratyupaviś": ['mw'],
    "pratyupaviṣṭa": ['mw'],
    "pratyupavraj": ['mw'],
    "pratyupayā": ['mw'],
    "pratyupe": ['mw'],
    "pratyupekṣita": ['mw'],
    "pratyupeya": ['ddsa', 'mw'],
    "pratyupodita": ['mw'],
    "pratyupta": ['ap90', 'mw'],
    "pratyuptaka": ['bhs'],
    "pratyupādhā": ['mw'],
    "pratyupāhṛ": ['mw'],
    "pratyupākaraṇa": ['ddsa', 'mw'],
    "pratyupāsana": ['bhs'],
    "pratyupāsanam": ['mw'],
    "pratyurasa": ['mw'],
    "pratyurasam": ['mw'],
    "pratyuta": ['ap90', 'mw'],
    "pratyutkarṣa": ['mw'],
    "pratyutkrama": ['mw'],
    "pratyutkramaḥ": ['ap90'],
    "pratyutkramaṇa": ['mw'],
    "pratyutkrānta": ['mw'],
    "pratyutkrāntajīvita": ['mw'],
    "pratyutkrānti": ['mw'],
    "pratyutpanna": ['ap90', 'bhs', 'cae', 'mw'],
    "pratyutpannajāti": ['mw'],
    "pratyutpannamati": ['mw'],
    "pratyutpannamatitva": ['mw'],
    "pratyutpā": ['mw'],
    "pratyutsad": ['mw'],
    "pratyuttabdhi": ['mw'],
    "pratyuttambh": ['mw'],
    "pratyuttambha": ['mw'],
    "pratyuttambhana": ['mw'],
    "pratyuttara": ['cae', 'mw'],
    "pratyuttareṇa": ['bhs'],
    "pratyuttarīkaraṇa": ['mw'],
    "pratyuttarīkṛ": ['mw'],
    "pratyuttheya": ['mw'],
    "pratyutthita": ['ap90', 'mw'],
    "pratyutthā": ['mw'],
    "pratyutthāna": ['cae', 'mw'],
    "pratyutthānaṃ": ['ap90'],
    "pratyutthāyika": ['mw'],
    "pratyutthāyin": ['mw'],
    "pratyutthāyuka": ['mw'],
    "pratyuttṝ": ['mw'],
    "pratyuṣ": ['mw'],
    "pratyuṣaḥ": ['ap90'],
    "pratyuṣya": ['mw'],
    "pratyuṣṭa": ['mw'],
    "pratyuṣṭra": ['mw'],
    "pratyābhū": ['mw'],
    "pratyābrū": ['mw'],
    "pratyācakṣ": ['mw'],
    "pratyācakṣāṇaka": ['mw'],
    "pratyācchid": ['mw'],
    "pratyācikṣati": ['bhs'],
    "pratyācāra": ['mw'],
    "pratyādarśa": ['mw'],
    "pratyādeya": ['mw'],
    "pratyādeśa": ['bhs', 'cae', 'mw'],
    "pratyādeśana": ['bhs'],
    "pratyādeśaḥ": ['ap90'],
    "pratyādeśin": ['cae'],
    "pratyādeṣṭṛ": ['mw'],
    "pratyādhmāna": ['mw'],
    "pratyādhāna": ['ddsa', 'mw'],
    "pratyāditsu": ['mw'],
    "pratyāditya": ['mw'],
    "pratyādiś": ['ap90', 'mw'],
    "pratyādiṣṭa": ['ap90', 'mw'],
    "pratyādru": ['mw'],
    "pratyādā": ['ap90', 'mw'],
    "pratyādāna": ['cae', 'mw'],
    "pratyādānaṃ": ['ap90'],
    "pratyādṛ": ['mw'],
    "pratyāgacchati": ['bhs'],
    "pratyāgam": ['ap90', 'mw'],
    "pratyāgama": ['cae', 'mw'],
    "pratyāgamana": ['mw'],
    "pratyāgamaḥ": ['ap90'],
    "pratyāgamāvadhi": ['mw'],
    "pratyāgata": ['mw'],
    "pratyāgataprāṇa": ['mw'],
    "pratyāgatasmṛti": ['mw'],
    "pratyāgati": ['cae', 'mw'],
    "pratyāgatiḥ": ['ap90'],
    "pratyāgatāsu": ['mw'],
    "pratyāgāra": ['mw'],
    "pratyāgṝ": ['mw'],
    "pratyāha": ['ddsa', 'mw'],
    "pratyāhan": ['mw'],
    "pratyāharaṇa": ['cae', 'ddsa', 'mw'],
    "pratyāharaṇaṃ": ['ap90'],
    "pratyāharaṇīya": ['mw'],
    "pratyāhartavya": ['mw'],
    "pratyāhata": ['ap90', 'mw'],
    "pratyāhuti": ['mw'],
    "pratyāhvaya": ['mw'],
    "pratyāhve": ['mw'],
    "pratyāhvāna": ['mw'],
    "pratyāhāra": ['bhs', 'cae', 'mw'],
    "pratyāhāraḥ": ['ap90'],
    "pratyāhārya": ['mw'],
    "pratyāhṛ": ['ap90', 'mw'],
    "pratyāhṛta": ['ap90', 'mw'],
    "pratyājan": ['mw'],
    "pratyājaniṣyate": ['bhs'],
    "pratyājāti": ['bhs'],
    "pratyājāyate": ['bhs'],
    "pratyākalita": ['ap90', 'ddsa', 'mw'],
    "pratyākhyeya": ['cae', 'mw'],
    "pratyākhyā": ['ap90', 'mw'],
    "pratyākhyāna": ['cae', 'mw'],
    "pratyākhyānasaṃgraha": ['mw'],
    "pratyākhyānaṃ": ['ap90'],
    "pratyākhyāta": ['ap90', 'mw'],
    "pratyākhyātatva": ['mw'],
    "pratyākhyātavya": ['mw'],
    "pratyākhyātṛ": ['mw'],
    "pratyākhyāyam": ['mw'],
    "pratyākhyāyin": ['mw'],
    "pratyākram": ['mw'],
    "pratyākroṣṭavya": ['mw'],
    "pratyākruś": ['mw'],
    "pratyākāra": ['mw'],
    "pratyākāṅkṣ": ['mw'],
    "pratyākṛṣ": ['mw'],
    "pratyākṣepaka": ['ap90', 'mw'],
    "pratyākṣepakatva": ['mw'],
    "pratyālabh": ['mw'],
    "pratyālayam": ['mw'],
    "pratyālepana": ['bhs'],
    "pratyāliṅg": ['mw'],
    "pratyāliṅgana": ['ddsa'],
    "pratyālī": ['mw'],
    "pratyālīḍha": ['bhs', 'mw'],
    "pratyālīḍhaṃ": ['ap90'],
    "pratyāmnā": ['mw'],
    "pratyāmnāna": ['mw'],
    "pratyāmnātavya": ['mw'],
    "pratyāmnāya": ['mw'],
    "pratyāmnāyam": ['mw'],
    "pratyāmnāyaḥ": ['ap90'],
    "pratyānah": ['mw'],
    "pratyānayana": ['cae', 'mw'],
    "pratyānayanaṃ": ['ap90'],
    "pratyāneya": ['mw'],
    "pratyāninīṣu": ['mw'],
    "pratyānāha": ['mw'],
    "pratyānī": ['mw'],
    "pratyānīka": ['mw'],
    "pratyānīta": ['mw'],
    "pratyāp": ['mw'],
    "pratyāpanna": ['mw'],
    "pratyāpatti": ['ddsa', 'mw'],
    "pratyāpattiḥ": ['ap90'],
    "pratyāpibati": ['bhs'],
    "pratyāplavana": ['mw'],
    "pratyāpīḍa": ['mw'],
    "pratyārambha": ['ddsa', 'mw'],
    "pratyārdhapura": ['mw'],
    "pratyārdra": ['mw'],
    "pratyārdratara": ['mw'],
    "pratyārdrā": ['mw'],
    "pratyārdrīkṛ": ['ddsa', 'mw'],
    "pratyāruh": ['mw'],
    "pratyās": ['mw'],
    "pratyāsad": ['mw'],
    "pratyāsanna": ['ap90', 'mw'],
    "pratyāsannabuddhi": ['bhs'],
    "pratyāsannamṛtyu": ['mw'],
    "pratyāsaraḥ": ['ap90'],
    "pratyāsataraṇa": ['bhs'],
    "pratyāsatti": ['cae', 'mw'],
    "pratyāsattiḥ": ['ap90'],
    "pratyāsaṃkalita": ['mw'],
    "pratyāsaṅga": ['mw'],
    "pratyāsev": ['mw'],
    "pratyāsic": ['mw'],
    "pratyāsthā": ['mw'],
    "pratyāstāra": ['bhs'],
    "pratyāstīrṇa": ['bhs'],
    "pratyāstṛta": ['bhs'],
    "pratyāsvara": ['mw'],
    "pratyāsvādaka": ['mw'],
    "pratyāsāraḥ": ['ap90'],
    "pratyātan": ['mw'],
    "pratyātma": ['bhs', 'mw'],
    "pratyātmaka": ['bhs', 'mw'],
    "pratyātmam": ['mw'],
    "pratyātmaviniyata": ['mw'],
    "pratyātmika": ['bhs', 'mw'],
    "pratyātmya": ['mw'],
    "pratyātmyena": ['mw'],
    "pratyātāpa": ['ddsa', 'mw'],
    "pratyāvap": ['mw'],
    "pratyāvartana": ['mw'],
    "pratyāvartanaṃ": ['ap90'],
    "pratyāvraj": ['mw'],
    "pratyāvāsakam": ['mw'],
    "pratyāvāsam": ['mw'],
    "pratyāvṛt": ['mw'],
    "pratyāvṛtta": ['mw'],
    "pratyāvṛtti": ['cae', 'mw'],
    "pratyāya": ['bhs', 'mw'],
    "pratyāyaka": ['ap90', 'ddsa', 'mw'],
    "pratyāyakatva": ['mw'],
    "pratyāyana": ['cae', 'mw'],
    "pratyāyanam": ['mw'],
    "pratyāyanaṃ": ['ap90'],
    "pratyāyanā": ['mw'],
    "pratyāyayitavya": ['cae', 'mw'],
    "pratyāyaḥ": ['ap90'],
    "pratyāyita": ['mw'],
    "pratyāyitavya": ['mw'],
    "pratyāyitaḥ": ['ap90'],
    "pratyāyya": ['mw'],
    "pratyāyā": ['mw'],
    "pratyāśam": ['ddsa', 'mw'],
    "pratyāśatva": ['mw'],
    "pratyāśaṃs": ['mw'],
    "pratyāśin": ['mw'],
    "pratyāśraya": ['ddsa', 'mw'],
    "pratyāśru": ['mw'],
    "pratyāśruta": ['mw'],
    "pratyāśrāva": ['mw'],
    "pratyāśrāvaṇa": ['mw'],
    "pratyāśrāvita": ['mw'],
    "pratyāśvas": ['mw'],
    "pratyāśvasta": ['ap90', 'mw'],
    "pratyāśvāsa": ['cae', 'mw'],
    "pratyāśvāsana": ['cae', 'mw'],
    "pratyāśvāsanaṃ": ['ap90'],
    "pratyāśvāsaḥ": ['ap90'],
    "pratyāśā": ['cae', 'mw'],
    "pratyāśī": ['mw'],
    "pratyāṇī": ['bhs'],
    "pratyūh": ['ap90', 'mw'],
    "pratyūha": ['ap90', 'cae', 'mw'],
    "pratyūhana": ['mw'],
    "pratyūrdhvam": ['mw'],
    "pratyūḍha": ['mw'],
    "pratyūṣa": ['cae'],
    "pratyūṣas": ['ap90', 'cae'],
    "pratyūṣaḥ": ['ap90'],
    "pratyṛ": ['mw'],
    "pratyṛcam": ['cae', 'ddsa', 'mw'],
    "pratyṛta": ['mw'],
    "pratyṛtu": ['cae', 'mw'],
    "pratām": ['mw'],
    "pratāmaka": ['mw'],
    "pratāmra": ['cae', 'mw'],
    "pratāna": ['bhs', 'cae', 'mw'],
    "pratānavat": ['mw'],
    "pratānaḥ": ['ap90'],
    "pratānin": ['ap90', 'mw'],
    "pratāninī": ['mw'],
    "pratānita": ['mw'],
    "pratānā": ['mw'],
    "pratānī": ['mw'],
    "pratāpa": ['bhs', 'cae', 'mw'],
    "pratāpacandra": ['mw'],
    "pratāpadeva": ['mw'],
    "pratāpadhavala": ['mw'],
    "pratāpamukuṭa": ['cae', 'mw'],
    "pratāpamārtaṇḍa": ['mw'],
    "pratāpana": ['ap90', 'bhs', 'cae', 'mw'],
    "pratāpanāraśiṃha": ['mw'],
    "pratāpanṛsiṃha": ['mw'],
    "pratāpapura": ['mw'],
    "pratāpapāla": ['mw'],
    "pratāparudra": ['mw'],
    "pratāparudrakalyāṇa": ['mw'],
    "pratāparudrayaśobhūṣaṇa": ['mw'],
    "pratāparudrīya": ['cae', 'mw'],
    "pratāparāja": ['mw'],
    "pratāparāmapūjā": ['mw'],
    "pratāpasa": ['mw'],
    "pratāpasiṃha": ['mw'],
    "pratāpasiṃharāja": ['mw'],
    "pratāpavant": ['bhs', 'cae'],
    "pratāpavat": ['ap90', 'mw'],
    "pratāpavelāvalī": ['mw'],
    "pratāpavilāsa": ['mw'],
    "pratāpaśekhara": ['mw'],
    "pratāpaśīla": ['mw'],
    "pratāpaḥ": ['ap90'],
    "pratāpendra": ['mw'],
    "pratāpin": ['ap90', 'cae', 'mw'],
    "pratāpāditya": ['mw'],
    "pratāpādityatā": ['mw'],
    "pratāpālaṃkāra": ['mw'],
    "pratāra": ['cae', 'mw'],
    "pratāraka": ['cae', 'mw'],
    "pratārakaḥ": ['ap90'],
    "pratārayitṛ": ['mw'],
    "pratāraḥ": ['ap90'],
    "pratāraṇa": ['cae', 'mw'],
    "pratāraṇaṃ": ['ap90'],
    "pratāraṇīya": ['mw'],
    "pratārita": ['ap90', 'mw'],
    "pratī": ['ap90', 'mw'],
    "pratībodha": ['mw'],
    "pratīcchaka": ['ddsa', 'mw'],
    "pratīcchakaḥ": ['ap90'],
    "pratīcchana": ['bhs'],
    "pratīcchati": ['bhs'],
    "pratīcya": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratīcyavāṭa": ['mw'],
    "pratīcyā": ['mw'],
    "pratīcī": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratīcīna": ['ap90', 'cae', 'gra', 'mw'],
    "pratīcīnagrīva": ['cae', 'mw'],
    "pratīcīnam": ['mw'],
    "pratīcīnamukha": ['mw'],
    "pratīcīnaphala": ['mw'],
    "pratīcīnaprajanana": ['mw'],
    "pratīcīnastoma": ['mw'],
    "pratīcīnaśiras": ['mw'],
    "pratīcīneḍa": ['mw'],
    "pratīcīpati": ['mw'],
    "pratīcīśa": ['mw'],
    "pratīdarśa": ['mw'],
    "pratīghāta": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratīghātaḥ": ['ap90'],
    "pratīghātin": ['mw'],
    "pratīhartṛ": ['mw'],
    "pratīhāra": ['cae', 'mw'],
    "pratīhāradhuraṃdharā": ['mw'],
    "pratīhāram": ['mw'],
    "pratīhāratva": ['mw'],
    "pratīhāratā": ['mw'],
    "pratīhāraḥ": ['ap90'],
    "pratīhārī": ['ap90'],
    "pratīhāsa": ['mw'],
    "pratīhāsaḥ": ['ap90'],
    "pratīka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pratīkadarśana": ['mw'],
    "pratīkatva": ['mw'],
    "pratīkavat": ['mw'],
    "pratīkopāsana": ['mw'],
    "pratīkāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratīkāraḥ": ['ap90'],
    "pratīkārya": ['mw'],
    "pratīkāśa": ['ap90', 'cae', 'mw'],
    "pratīkāśaḥ": ['ap90'],
    "pratīkāśva": ['mw'],
    "pratīkṣ": ['ap90', 'mw'],
    "pratīkṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "pratīkṣaka": ['ap90'],
    "pratīkṣam": ['mw'],
    "pratīkṣaṇa": ['ap90', 'cae', 'mw'],
    "pratīkṣaṇīya": ['cae', 'mw'],
    "pratīkṣin": ['ap90', 'cae', 'mw'],
    "pratīkṣita": ['ap90', 'mw'],
    "pratīkṣya": ['ap90', 'cae', 'mw'],
    "pratīkṣā": ['mw'],
    "pratīmāna": ['cae', 'ddsa', 'mw'],
    "pratīndhaka": ['mw'],
    "pratīnv": ['mw'],
    "pratīnāha": ['ddsa', 'mw'],
    "pratīnāhabhājana": ['mw'],
    "pratīnāhaḥ": ['ap90'],
    "pratīpa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pratīpadarśanī": ['mw'],
    "pratīpadarśinī": ['mw'],
    "pratīpadīpaka": ['mw'],
    "pratīpaga": ['mw'],
    "pratīpagamana": ['mw'],
    "pratīpagati": ['mw'],
    "pratīpagāmin": ['mw'],
    "pratīpaka": ['ap90', 'mw'],
    "pratīpam": ['mw'],
    "pratīpataraṇa": ['mw'],
    "pratīpavacana": ['ddsa', 'mw'],
    "pratīpavipākin": ['cae'],
    "pratīpaya": ['ddsa', 'mw'],
    "pratīpayati": ['ap90'],
    "pratīpin": ['mw'],
    "pratīpokti": ['mw'],
    "pratīps": ['mw'],
    "pratīpāna": ['mw'],
    "pratīpāya": ['mw'],
    "pratīpāyate": ['ap90'],
    "pratīpāśva": ['mw'],
    "pratīr": ['mw'],
    "pratīra": ['mw'],
    "pratīraṃ": ['ap90'],
    "pratīrādha": ['mw'],
    "pratīrṇa": ['mw'],
    "pratīsāram": ['mw'],
    "pratīta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "pratītasena": ['mw'],
    "pratīti": ['cae', 'ddsa', 'gra', 'mw'],
    "pratītia": ['gra'],
    "pratītimat": ['mw'],
    "pratītiḥ": ['ap90'],
    "pratītoda": ['mw'],
    "pratītta": ['ap90', 'mw'],
    "pratītya": ['bhs', 'gra', 'mw'],
    "pratītyasamutpāda": ['bhs', 'mw'],
    "pratītyatā": ['bhs'],
    "pratītākṣarā": ['mw'],
    "pratītārtha": ['mw'],
    "pratītātman": ['cae', 'mw'],
    "pratītāśva": ['mw'],
    "pratīvarta": ['mw'],
    "pratīveśa": ['ap90', 'mw'],
    "pratīveśin": ['ap90', 'mw'],
    "pratīvāha": ['mw'],
    "pratīvāpa": ['mw'],
    "pratīvāpaḥ": ['ap90'],
    "pratīvī": ['gra', 'mw'],
    "pratīyapayitar": ['bhs'],
    "pratīyati": ['bhs'],
    "pratīśa": ['bhs'],
    "pratīḍ": ['mw'],
    "pratīṃdhakaḥ": ['ap90'],
    "pratīṣ": ['ap90', 'mw'],
    "pratīṣita": ['mw'],
    "pratīṣṭa": ['ap90'],
    "pratīṣṭam": ['cae'],
    "pratūrta": ['mw'],
    "pratūrtaka": ['mw'],
    "pratūrti": ['cae', 'gra', 'mw'],
    "pratūrṇa": ['ap90', 'mw'],
    "pratūṇī": ['mw'],
    "pratṛd": ['gra', 'mw'],
    "pratṛp": ['mw'],
    "pratṛṇṇa": ['mw'],
    "pratṝ": ['ap90', 'mw'],
    "prauga": ['cae', 'ddsa', 'gra', 'mw'],
    "praugacit": ['mw'],
    "praugaciti": ['mw'],
    "praugastotra": ['mw'],
    "praugaśastra": ['mw'],
    "praughīya": ['mw'],
    "praugya": ['mw'],
    "praugādhyāya": ['mw'],
    "prauha": ['ap90', 'mw'],
    "praukta": ['mw'],
    "prauḍha": ['ap90', 'cae', 'ddsa', 'mw'],
    "prauḍhacaritanāman": ['mw'],
    "prauḍhadordaṇḍa": ['mw'],
    "prauḍhajalada": ['mw'],
    "prauḍhamanoramā": ['mw'],
    "prauḍhamanoramākhaṇḍana": ['mw'],
    "prauḍhamanoramākucamardana": ['mw'],
    "prauḍhaprakāśikā": ['mw'],
    "prauḍhapratāpa": ['mw'],
    "prauḍhapratāpamārtaṇḍa": ['mw'],
    "prauḍhapriyā": ['mw'],
    "prauḍhapuṣpa": ['mw'],
    "prauḍhapāda": ['cae', 'mw'],
    "prauḍhasvaram": ['mw'],
    "prauḍhatva": ['cae', 'mw'],
    "prauḍhatvaṃ": ['ap90'],
    "prauḍhatātparyasaṃgraha": ['mw'],
    "prauḍhavatsā": ['mw'],
    "prauḍhavyañjaka": ['mw'],
    "prauḍhavāda": ['mw'],
    "prauḍhayauvana": ['mw'],
    "prauḍhi": ['cae', 'ddsa', 'mw'],
    "prauḍhiman": ['mw'],
    "prauḍhivāda": ['mw'],
    "prauḍhiḥ": ['ap90'],
    "prauḍhokti": ['ddsa', 'mw'],
    "prauḍhā": ['mw'],
    "prauḍhācāra": ['cae', 'mw'],
    "prauḍhākṛṣṭa": ['mw'],
    "prauḍhānta": ['mw'],
    "prauḍhāṅganā": ['mw'],
    "prauḍhībhū": ['ap90', 'ddsa', 'mw'],
    "prauṇa": ['ap90', 'mw'],
    "prauṣṭha": ['mw'],
    "prauṣṭhapada": ['cae', 'ddsa', 'mw'],
    "prauṣṭhapadaḥ": ['ap90'],
    "prauṣṭhapadika": ['mw'],
    "prauṣṭhapadā": ['mw'],
    "prauṣṭhapadī": ['mw'],
    "prauṣṭhaḥ": ['ap90'],
    "prauṣṭhika": ['mw'],
    "prava": ['cae', 'ddsa', 'gra', 'mw'],
    "pravabhra": ['mw'],
    "pravac": ['ap90', 'mw'],
    "pravacana": ['bhs', 'cae', 'mw'],
    "pravacanakartṛ": ['mw'],
    "pravacanapaṭu": ['cae', 'mw'],
    "pravacanasāragāthā": ['mw'],
    "pravacanasāroddhāra": ['mw'],
    "pravacanaṃ": ['ap90'],
    "pravacanīya": ['cae', 'mw'],
    "pravad": ['ap90', 'mw'],
    "pravada": ['cae', 'mw'],
    "pravadana": ['cae', 'mw'],
    "pravadanaṃ": ['ap90'],
    "pravadbhārgava": ['mw'],
    "pravadh": ['mw'],
    "pravaditṛ": ['mw'],
    "pravadiṣu": ['mw'],
    "pravadyāman": ['gra', 'mw'],
    "pravaga": ['mw'],
    "pravagaḥ": ['ap90'],
    "pravah": ['ap90', 'mw'],
    "pravaha": ['cae', 'mw'],
    "pravahaḥ": ['ap90'],
    "pravahaṇa": ['cae', 'mw'],
    "pravahaṇabalīvarda": ['cae'],
    "pravahaṇabhaṅga": ['cae', 'mw'],
    "pravahaṇaka": ['bhs'],
    "pravahaṇavāhaka": ['cae'],
    "pravahaṇaṃ": ['ap90'],
    "pravahaṇika": ['cae'],
    "pravahli": ['mw'],
    "pravahlikā": ['ap90', 'mw'],
    "pravahliḥ": ['ap90'],
    "pravahlī": ['mw'],
    "pravajita": ['bhs'],
    "pravaka": ['mw'],
    "pravaktavya": ['cae', 'ddsa', 'mw'],
    "pravaktṛ": ['ap90', 'cae', 'mw'],
    "pravaktṛtva": ['mw'],
    "pravalg": ['mw'],
    "pravalgita": ['mw'],
    "pravalh": ['mw'],
    "pravalha": ['mw'],
    "pravalhikā": ['mw'],
    "pravalhita": ['mw'],
    "pravalākin": ['ap90', 'mw'],
    "pravan": ['mw'],
    "pravant": ['cae'],
    "pravap": ['ap90', 'mw'],
    "pravapa": ['ap90', 'mw'],
    "pravapaṇa": ['cae', 'mw'],
    "pravapaṇaṃ": ['ap90'],
    "pravara": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "pravarabhūpati": ['mw'],
    "pravaradarpaṇa": ['mw'],
    "pravaradhātu": ['mw'],
    "pravaradīpikā": ['mw'],
    "pravarajana": ['cae', 'mw'],
    "pravarakalyāṇa": ['mw'],
    "pravarakhaṇḍa": ['mw'],
    "pravarakāṇḍa": ['mw'],
    "pravaralalita": ['mw'],
    "pravaramañjarī": ['mw'],
    "pravaramūrdhaja": ['mw'],
    "pravaranirṇaya": ['mw'],
    "pravaranṛpati": ['mw'],
    "pravarapura": ['mw'],
    "pravararatna": ['mw'],
    "pravararūpa": ['mw'],
    "pravarasena": ['mw'],
    "pravaravat": ['mw'],
    "pravaravaṃśaja": ['mw'],
    "pravaravāhana": ['mw'],
    "pravaraśrī": ['bhs'],
    "pravaraṇa": ['mw'],
    "pravaraṇaṃ": ['ap90'],
    "pravaraṇīya": ['mw'],
    "pravardhaka": ['cae', 'mw'],
    "pravardhana": ['cae', 'mw'],
    "pravardhanaṃ": ['ap90'],
    "pravarekṛtaśānti": ['mw'],
    "pravarendrarāja": ['bhs'],
    "pravareśa": ['mw'],
    "pravareśvara": ['mw'],
    "pravarga": ['cae', 'ddsa', 'gra', 'mw'],
    "pravargaḥ": ['ap90'],
    "pravargya": ['cae', 'mw'],
    "pravargyakāṇḍa": ['mw'],
    "pravargyaprayoga": ['mw'],
    "pravargyasāman": ['mw'],
    "pravargyavat": ['mw'],
    "pravargyaḥ": ['ap90'],
    "pravargāvartabhūṣaṇa": ['mw'],
    "pravarha": ['ap90'],
    "pravarham": ['mw'],
    "pravarjana": ['mw'],
    "pravarjanaṃ": ['ap90'],
    "pravarjanā": ['bhs'],
    "pravarta": ['mw'],
    "pravartaka": ['ap90', 'cae', 'mw'],
    "pravartakajñāna": ['mw'],
    "pravartakīya": ['mw'],
    "pravartamānaka": ['gra', 'mw'],
    "pravartana": ['cae', 'mw'],
    "pravartanatā": ['bhs'],
    "pravartanaṃ": ['ap90'],
    "pravartanā": ['mw'],
    "pravartanīya": ['cae', 'mw'],
    "pravartayitṛ": ['ap90', 'mw'],
    "pravartayitṛtva": ['mw'],
    "pravartaḥ": ['ap90'],
    "pravartin": ['ap90', 'cae', 'mw'],
    "pravartita": ['ap90', 'mw'],
    "pravartitavya": ['cae', 'mw'],
    "pravartitṛ": ['mw'],
    "pravartya": ['mw'],
    "pravarā": ['mw'],
    "pravarādhyāya": ['mw'],
    "pravarāgramati": ['bhs'],
    "pravarṇ": ['mw'],
    "pravarṣa": ['cae', 'mw'],
    "pravarṣaḥ": ['ap90'],
    "pravarṣaṇa": ['mw'],
    "pravarṣaṇaṃ": ['ap90'],
    "pravarṣin": ['ap90', 'mw'],
    "pravas": ['ap90', 'mw'],
    "pravasana": ['cae', 'mw'],
    "pravasanaṃ": ['ap90'],
    "pravasatha": ['cae', 'gra', 'mw'],
    "pravastavya": ['mw'],
    "pravasu": ['mw'],
    "pravat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pravatsyat": ['ap90', 'mw'],
    "pravatsyatpatikā": ['mw'],
    "pravatvant": ['cae'],
    "pravatvat": ['gra', 'mw'],
    "pravayas": ['ap90', 'cae', 'gra', 'mw'],
    "pravayati": ['bhs'],
    "pravayaṇa": ['mw'],
    "pravayaṇaṃ": ['ap90'],
    "pravayaṇīya": ['mw'],
    "pravayyā": ['mw'],
    "pravaṃga": ['mw'],
    "pravaṃgama": ['mw'],
    "pravaṅga": ['mw'],
    "pravaṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pravaṇapraharṣa": ['mw'],
    "pravaṇatā": ['ap90', 'mw'],
    "pravaṇavat": ['mw'],
    "pravaṇavidheyībhū": ['mw'],
    "pravaṇaya": ['mw'],
    "pravaṇe": ['mw'],
    "pravaṇeja": ['mw'],
    "pravaṇi": ['mw'],
    "pravaṇāyati": ['ap90'],
    "pravaṇāyita": ['mw'],
    "pravaṇībhū": ['mw'],
    "pravaṇīkṛ": ['ap90', 'mw'],
    "pravaṇṇa": ['bhs'],
    "pravaṭa": ['mw'],
    "pravaṭaḥ": ['ap90'],
    "prave": ['mw'],
    "praveda": ['mw'],
    "pravedakṛt": ['mw'],
    "pravedana": ['cae', 'mw'],
    "pravedanaṃ": ['ap90'],
    "pravedha": ['bhs', 'mw'],
    "pravedhati": ['bhs'],
    "pravedin": ['cae', 'mw'],
    "pravedya": ['mw'],
    "pravega": ['mw'],
    "pravegaḥ": ['ap90'],
    "pravegita": ['mw'],
    "pravejita": ['mw'],
    "praveka": ['ap90', 'ddsa', 'mw'],
    "pravela": ['mw'],
    "pravelaḥ": ['ap90'],
    "pravep": ['mw'],
    "pravepa": ['cae', 'gra', 'mw'],
    "pravepaka": ['mw'],
    "pravepana": ['gra', 'mw'],
    "pravepanin": ['gra', 'mw'],
    "pravepanīya": ['mw'],
    "pravepathu": ['mw'],
    "pravepaḥ": ['ap90'],
    "pravepin": ['cae', 'mw'],
    "pravepita": ['mw'],
    "praveraya": ['mw'],
    "praverita": ['ap90', 'mw'],
    "pravettṛ": ['mw'],
    "pravetṛ": ['ap90', 'mw'],
    "praveya": ['mw'],
    "praveśa": ['bhs', 'cae', 'mw'],
    "praveśabhāgika": ['mw'],
    "praveśaka": ['bhs', 'cae', 'mw'],
    "praveśakaḥ": ['ap90'],
    "praveśana": ['cae', 'mw'],
    "praveśanaṃ": ['ap90'],
    "praveśanīya": ['mw'],
    "praveśayitavya": ['mw'],
    "praveśaḥ": ['ap90'],
    "praveśin": ['cae', 'mw'],
    "praveśita": ['ap90', 'mw'],
    "praveśitā": ['bhs', 'mw'],
    "praveśya": ['ap90', 'cae', 'mw'],
    "praveṇiḥ": ['ap90'],
    "praveṇī": ['mw'],
    "praveṣye": ['bhs'],
    "praveṣṭ": ['mw'],
    "praveṣṭa": ['mw'],
    "praveṣṭaka": ['mw'],
    "praveṣṭavya": ['cae', 'mw'],
    "praveṣṭaḥ": ['ap90'],
    "praveṣṭita": ['mw'],
    "praveṣṭuka": ['bhs'],
    "praveṣṭṛ": ['cae', 'mw'],
    "praveṣṭṛtva": ['mw'],
    "praveṭa": ['mw'],
    "praveṭaḥ": ['ap90'],
    "pravibhaj": ['ap90', 'mw'],
    "pravibhakta": ['ap90', 'cae', 'mw'],
    "pravibhaktaraśmi": ['mw'],
    "pravibhakti": ['bhs'],
    "pravibhinna": ['mw'],
    "pravibhuj": ['mw'],
    "pravibhāga": ['cae', 'mw'],
    "pravibhāgavat": ['mw'],
    "pravibhāgaśas": ['mw'],
    "pravibhāgaḥ": ['ap90'],
    "pravibhāsayati": ['bhs'],
    "pravibhāvaka": ['mw'],
    "pravibhāvayati": ['bhs'],
    "pravicakṣ": ['mw'],
    "pravical": ['ap90', 'mw'],
    "pravicalita": ['ap90', 'mw'],
    "pravicar": ['ap90', 'mw'],
    "pravicaraḥ": ['ap90'],
    "pravicaya": ['bhs', 'mw'],
    "pravicayaḥ": ['ap90'],
    "pravicetana": ['mw'],
    "pravicetanaṃ": ['ap90'],
    "praviceṣṭ": ['mw'],
    "pravici": ['mw'],
    "pravicint": ['mw'],
    "pravicintaka": ['mw'],
    "pravicita": ['mw'],
    "pravicāra": ['bhs', 'mw'],
    "pravicāramārga": ['mw'],
    "pravicārayati": ['bhs'],
    "pravicāraṇa": ['bhs'],
    "pravicāraṇā": ['mw'],
    "pravicārita": ['mw'],
    "pravid": ['cae', 'gra', 'mw'],
    "pravidalana": ['mw'],
    "pravidarbhayati": ['bhs'],
    "pravidarśayati": ['bhs'],
    "praviddha": ['ap90', 'cae', 'mw'],
    "pravidhvasta": ['ap90', 'mw'],
    "pravidhā": ['ap90', 'mw'],
    "pravidhāna": ['ddsa', 'mw'],
    "pravidhānaṃ": ['ap90'],
    "praviditsu": ['mw'],
    "pravidruta": ['ap90', 'mw'],
    "praviduh": ['mw'],
    "pravidvas": ['cae', 'ddsa', 'mw'],
    "pravidāha": ['bhs'],
    "pravidāra": ['mw'],
    "pravidārayati": ['bhs'],
    "pravidāraḥ": ['ap90'],
    "pravidāraṇa": ['mw'],
    "pravidāraṇaṃ": ['ap90'],
    "pravigal": ['mw'],
    "pravigalita": ['mw'],
    "pravigata": ['mw'],
    "pravighaṭ": ['mw'],
    "pravighaṭana": ['mw'],
    "pravighaṭita": ['mw'],
    "pravigraha": ['ddsa', 'mw'],
    "pravigāh": ['mw'],
    "pravihata": ['mw'],
    "pravihā": ['mw'],
    "pravihāra": ['mw'],
    "pravij": ['mw'],
    "pravijahya": ['mw'],
    "pravijaya": ['mw'],
    "pravijñā": ['mw'],
    "pravijṛmbh": ['mw'],
    "pravijṛmbhitā": ['bhs'],
    "pravika": ['mw'],
    "pravikalpayati": ['bhs'],
    "pravikampati": ['bhs'],
    "pravikarṣa": ['mw'],
    "pravikarṣaṇa": ['bhs', 'mw'],
    "pravikas": ['mw'],
    "pravikatthate": ['bhs'],
    "pravikaṭa": ['mw'],
    "pravikhyāta": ['ap90', 'cae', 'mw'],
    "pravikhyāti": ['mw'],
    "pravikhyātiḥ": ['ap90'],
    "pravikta": ['cae', 'mw'],
    "pravikīrṇa": ['ap90', 'mw'],
    "pravikīrṇakāmā": ['mw'],
    "pravikṝ": ['mw'],
    "pravikṣipta": ['bhs'],
    "pravilabh": ['mw'],
    "pravilamb": ['mw'],
    "pravilambin": ['ddsa', 'mw'],
    "pravilambita": ['mw'],
    "pravilas": ['mw'],
    "pravilasena": ['mw'],
    "pravilaya": ['mw'],
    "pravilayana": ['mw'],
    "pravilayaḥ": ['ap90'],
    "pravillasena": ['mw'],
    "pravilok": ['mw'],
    "pravilola": ['mw'],
    "praviloma": ['bhs'],
    "pravilup": ['mw'],
    "pravilupta": ['ap90', 'mw'],
    "pravilāpana": ['mw'],
    "pravilāpayitavya": ['mw'],
    "pravilāpin": ['mw'],
    "pravilāpitatva": ['mw'],
    "pravilāpya": ['mw'],
    "pravilī": ['mw'],
    "pravimuc": ['mw'],
    "pravimṛś": ['mw'],
    "pravinaś": ['mw'],
    "pravinaṣṭa": ['mw'],
    "pravinirdhūta": ['mw'],
    "pravipala": ['mw'],
    "pravipalaḥ": ['ap90'],
    "pravira": ['mw'],
    "pravirala": ['ap90', 'cae', 'ddsa', 'mw'],
    "pravirata": ['mw'],
    "praviraḥ": ['ap90'],
    "pravirohati": ['bhs'],
    "pravirājate": ['bhs'],
    "pravirūḍha": ['mw'],
    "pravisarpin": ['bhs', 'mw'],
    "pravispaṣṭa": ['mw'],
    "pravistara": ['mw'],
    "pravistaraḥ": ['ap90'],
    "pravistaraṇa": ['bhs'],
    "pravistāra": ['mw'],
    "pravistāraḥ": ['ap90'],
    "pravistṛ": ['mw'],
    "pravisārayati": ['bhs'],
    "pravisṛta": ['mw'],
    "pravitapta": ['mw'],
    "pravitata": ['ap90', 'cae', 'mw'],
    "pravivardhita": ['mw'],
    "praviveka": ['bhs', 'mw'],
    "pravivepita": ['mw'],
    "pravivic": ['mw'],
    "pravivikta": ['ap90', 'cae', 'mw'],
    "praviviktabhuj": ['cae', 'mw'],
    "praviviktacakṣus": ['mw'],
    "praviviktatā": ['mw'],
    "praviviktāhāra": ['mw'],
    "pravivikṣu": ['mw'],
    "pravivrajiṣu": ['mw'],
    "pravivrājayiṣu": ['mw'],
    "pravivāda": ['mw'],
    "pravivādaḥ": ['ap90'],
    "praviyuta": ['mw'],
    "praviś": ['ap90', 'mw'],
    "praviśam": ['mw'],
    "praviśiṣ": ['mw'],
    "praviśiṣṭatara": ['bhs'],
    "praviśleṣa": ['mw'],
    "praviśleṣaḥ": ['ap90'],
    "praviśuddha": ['mw'],
    "praviśudh": ['mw'],
    "praviśālaya": ['mw'],
    "praviśāmayati": ['bhs'],
    "praviśīrṇa": ['mw'],
    "praviṇa": ['bhs'],
    "praviṣajati": ['bhs'],
    "praviṣaya": ['ddsa', 'mw'],
    "praviṣaṇṇa": ['ap90', 'mw'],
    "praviṣā": ['ap90', 'mw'],
    "praviṣṭa": ['ap90', 'cae', 'mw'],
    "praviṣṭadīkṣa": ['mw'],
    "praviṣṭaka": ['bhs', 'cae', 'mw'],
    "praviṣṭakaṃ": ['ap90'],
    "praviṣṭakena": ['mw'],
    "praviṣṭakāya": ['mw'],
    "praviṣṭamāna": ['bhs'],
    "praviṣṭā": ['mw'],
    "pravlaya": ['mw'],
    "pravlī": ['mw'],
    "pravlīna": ['mw'],
    "pravol̤hṛ": ['mw'],
    "pravoḍhṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "pravraj": ['ap90', 'mw'],
    "pravrajana": ['ddsa', 'mw'],
    "pravrajanaṃ": ['ap90'],
    "pravrajikā": ['mw'],
    "pravrajita": ['ap90', 'cae', 'mw'],
    "pravrajitā": ['mw'],
    "pravrajya": ['mw'],
    "pravrajyā": ['ap90', 'cae', 'mw'],
    "pravrajyāntarāyasūtra": ['bhs'],
    "pravrajyāvasita": ['mw'],
    "pravrajyāyoga": ['mw'],
    "pravraska": ['cae', 'mw'],
    "pravraśc": ['mw'],
    "pravraścana": ['mw'],
    "pravraścanaḥ": ['ap90'],
    "pravrāj": ['ap90', 'cae', 'mw'],
    "pravrāja": ['cae', 'gra', 'mw'],
    "pravrājaka": ['cae', 'mw'],
    "pravrājana": ['cae', 'mw'],
    "pravrājanaṃ": ['ap90'],
    "pravrājayati": ['bhs'],
    "pravrājikā": ['mw'],
    "pravrājin": ['cae', 'mw'],
    "pravrājita": ['mw'],
    "pravuccati": ['bhs'],
    "pravyadh": ['mw'],
    "pravyadhati": ['bhs'],
    "pravyakta": ['ap90', 'mw'],
    "pravyakti": ['ddsa', 'mw'],
    "pravyaktiḥ": ['ap90'],
    "pravyas": ['mw'],
    "pravyath": ['mw'],
    "pravyathita": ['mw'],
    "pravyathā": ['bhs'],
    "pravyādha": ['mw'],
    "pravyāharaṇa": ['bhs', 'mw'],
    "pravyāhāra": ['bhs', 'mw'],
    "pravyāhāraḥ": ['ap90'],
    "pravyāhṛ": ['mw'],
    "pravyāhṛta": ['mw'],
    "pravyāhṛtavatī": ['bhs'],
    "pravā": ['mw'],
    "pravāc": ['ap90', 'ddsa', 'mw'],
    "pravācaka": ['ap90', 'mw'],
    "pravācana": ['cae', 'gra', 'mw'],
    "pravācanaṃ": ['ap90'],
    "pravācya": ['cae', 'mw'],
    "pravācyaṃ": ['ap90'],
    "pravāda": ['cae', 'mw'],
    "pravādaka": ['ap90', 'mw'],
    "pravādaḥ": ['ap90'],
    "pravādin": ['ap90', 'cae', 'mw'],
    "pravādita": ['bhs'],
    "pravādya": ['mw'],
    "pravādā": ['mw'],
    "pravādī": ['bhs'],
    "pravāh": ['mw'],
    "pravāha": ['cae', 'mw'],
    "pravāhaka": ['ap90', 'mw'],
    "pravāhanaṃ": ['ap90'],
    "pravāhayitṛ": ['mw'],
    "pravāhayitṛtva": ['mw'],
    "pravāhaḥ": ['ap90'],
    "pravāhaṇa": ['cae', 'mw'],
    "pravāhaṇeya": ['mw'],
    "pravāhaṇeyaka": ['mw'],
    "pravāhaṇeyi": ['mw'],
    "pravāhaṇī": ['ap90', 'mw'],
    "pravāhemūtrita": ['mw'],
    "pravāhikā": ['ap90', 'mw'],
    "pravāhin": ['ap90', 'cae', 'mw'],
    "pravāhita": ['mw'],
    "pravāhotthā": ['mw'],
    "pravāhya": ['mw'],
    "pravāhī": ['ap90', 'mw'],
    "pravāka": ['mw'],
    "pravākaḥ": ['ap90'],
    "pravāla": ['ap90', 'cae', 'mw'],
    "pravālabhasman": ['mw'],
    "pravālaka": ['mw'],
    "pravālamaṇiśṛṅga": ['mw'],
    "pravālapadma": ['mw'],
    "pravālaphala": ['mw'],
    "pravālavarṇa": ['mw'],
    "pravālavat": ['mw'],
    "pravālika": ['mw'],
    "pravālāśmantaka": ['mw'],
    "pravāpayitṛ": ['mw'],
    "pravāpin": ['cae', 'mw'],
    "pravāra": ['cae', 'mw'],
    "pravāraka": ['bhs', 'mw'],
    "pravārayati": ['bhs'],
    "pravāraḥ": ['ap90'],
    "pravāraṇa": ['bhs', 'cae', 'mw'],
    "pravāraṇasūtra": ['bhs'],
    "pravāraṇaṃ": ['ap90'],
    "pravārika": ['bhs'],
    "pravārita": ['bhs', 'mw'],
    "pravārya": ['cae', 'mw'],
    "pravāsa": ['cae', 'gra', 'mw'],
    "pravāsagamanavidhi": ['mw'],
    "pravāsagata": ['mw'],
    "pravāsakṛtya": ['mw'],
    "pravāsana": ['cae', 'mw'],
    "pravāsanaṃ": ['ap90'],
    "pravāsanā": ['bhs'],
    "pravāsanīya": ['bhs', 'mw'],
    "pravāsapara": ['mw'],
    "pravāsapariśiṣṭa": ['mw'],
    "pravāsastha": ['mw'],
    "pravāsasthita": ['mw'],
    "pravāsavidhi": ['mw'],
    "pravāsayati": ['bhs'],
    "pravāsaḥ": ['ap90'],
    "pravāsin": ['ap90', 'cae', 'mw'],
    "pravāsita": ['ap90', 'mw'],
    "pravāsopasthāna": ['mw'],
    "pravāsopasthānahaviryajñaprāyaścitta": ['mw'],
    "pravāsopasthānaprayoga": ['mw'],
    "pravāsopasthānavidhi": ['mw'],
    "pravāsya": ['cae', 'mw'],
    "pravāta": ['ap90', 'cae', 'gra', 'mw'],
    "pravātadīpacapala": ['mw'],
    "pravātanīlotpala": ['mw'],
    "pravātasubhaga": ['mw'],
    "pravātasāra": ['mw'],
    "pravātaśayana": ['cae', 'mw'],
    "pravāteja": ['cae', 'gra', 'mw'],
    "pravātejā": ['cae', 'mw'],
    "pravāyaka": ['mw'],
    "pravāyya": ['mw'],
    "pravāś": ['mw'],
    "pravāḍa": ['bhs', 'mw'],
    "pravāḍasāgara": ['bhs', 'mw'],
    "pravāṇa": ['mw'],
    "pravāṇaṃ": ['ap90'],
    "pravāṇi": ['mw'],
    "pravāṇiḥ": ['ap90'],
    "pravāṇī": ['mw'],
    "pravī": ['mw'],
    "pravīra": ['ap90', 'cae', 'gra', 'mw'],
    "pravīrabāhu": ['mw'],
    "pravīraka": ['mw'],
    "pravīravara": ['mw'],
    "pravīta": ['mw'],
    "pravītin": ['mw'],
    "pravīvivikṣu": ['mw'],
    "pravīṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "pravīṇatva": ['mw'],
    "pravīṇatā": ['mw'],
    "pravīṇīkṛ": ['mw'],
    "pravṛ": ['ap90', 'mw'],
    "pravṛddha": ['ap90', 'cae', 'mw'],
    "pravṛddhakāyarāja": ['bhs'],
    "pravṛddhi": ['cae', 'mw'],
    "pravṛddhiḥ": ['ap90'],
    "pravṛdh": ['ap90', 'gra', 'mw'],
    "pravṛh": ['mw'],
    "pravṛj": ['mw'],
    "pravṛjya": ['mw'],
    "pravṛkta": ['mw'],
    "pravṛkṇa": ['mw'],
    "pravṛt": ['ap90', 'mw'],
    "pravṛta": ['ap90', 'mw'],
    "pravṛtahoma": ['mw'],
    "pravṛtahomīya": ['mw'],
    "pravṛtta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "pravṛttacakra": ['mw'],
    "pravṛttacakratā": ['mw'],
    "pravṛttaka": ['bhs', 'mw'],
    "pravṛttakarman": ['mw'],
    "pravṛttakaṃ": ['ap90'],
    "pravṛttapānīya": ['mw'],
    "pravṛttapāraṇa": ['cae', 'mw'],
    "pravṛttasamprahāra": ['mw'],
    "pravṛttasamprahāratva": ['mw'],
    "pravṛttatva": ['mw'],
    "pravṛttavat": ['mw'],
    "pravṛttavāc": ['mw'],
    "pravṛtti": ['cae', 'ddsa', 'mw'],
    "pravṛttijña": ['mw'],
    "pravṛttijñāna": ['mw'],
    "pravṛttimat": ['mw'],
    "pravṛttimārga": ['mw'],
    "pravṛttinimitta": ['mw'],
    "pravṛttinivṛttimat": ['mw'],
    "pravṛttiparāṅmukha": ['mw'],
    "pravṛttipratyaya": ['mw'],
    "pravṛttivacana": ['cae', 'mw'],
    "pravṛttivijñāna": ['bhs', 'mw'],
    "pravṛttiḥ": ['ap90'],
    "pravṛttyaṅga": ['mw'],
    "pravṛttā": ['mw'],
    "pravṛttāśin": ['mw'],
    "pravṛtāhuti": ['mw'],
    "pravṛñjana": ['mw'],
    "pravṛñjanīya": ['mw'],
    "pravṛścya": ['mw'],
    "pravṛḍha": ['mw'],
    "pravṛṣ": ['ap90', 'mw'],
    "pravṛṣṭa": ['mw'],
    "pravṛṣṭe": ['mw'],
    "prayabh": ['mw'],
    "prayai": ['mw'],
    "prayaj": ['cae', 'ddsa', 'gra', 'mw'],
    "prayajyu": ['cae', 'gra', 'mw'],
    "prayakṣ": ['mw'],
    "prayakṣa": ['gra', 'mw'],
    "prayam": ['ap90', 'mw'],
    "prayamaṇa": ['cae', 'mw'],
    "prayantṛ": ['cae', 'gra', 'mw'],
    "prayas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prayasta": ['ap90', 'cae', 'mw'],
    "prayasvant": ['cae'],
    "prayasvat": ['gra', 'mw'],
    "prayat": ['ap90', 'mw'],
    "prayata": ['ap90', 'cae', 'mw'],
    "prayatadakṣiṇa": ['gra', 'mw'],
    "prayatamānasa": ['mw'],
    "prayatana": ['mw'],
    "prayataparigrahadvitīya": ['mw'],
    "prayatatva": ['mw'],
    "prayatatā": ['cae', 'mw'],
    "prayatavastra": ['mw'],
    "prayati": ['cae', 'gra', 'mw'],
    "prayatita": ['mw'],
    "prayatitavya": ['mw'],
    "prayatiḥ": ['ap90'],
    "prayatna": ['cae', 'mw'],
    "prayatnacchid": ['mw'],
    "prayatnamuktāsana": ['mw'],
    "prayatnaprekṣaṇīya": ['mw'],
    "prayatnatas": ['mw'],
    "prayatnavant": ['cae'],
    "prayatnavat": ['ap90', 'mw'],
    "prayatnaḥ": ['ap90'],
    "prayatnā": ['mw'],
    "prayatnānanda": ['mw'],
    "prayatnāt": ['mw'],
    "prayatta": ['mw'],
    "prayattavya": ['mw'],
    "prayatātman": ['cae', 'mw'],
    "prayatātmavat": ['mw'],
    "prayatāñjali": ['mw'],
    "prayiyu": ['gra', 'mw'],
    "prayoddhṛ": ['mw'],
    "prayoga": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "prayogacandrikā": ['mw'],
    "prayogacintāmaṇi": ['mw'],
    "prayogacūḍāmaṇi": ['mw'],
    "prayogadarpaṇa": ['mw'],
    "prayogadīpa": ['mw'],
    "prayogadīpikā": ['mw'],
    "prayogadīpikāvṛtti": ['mw'],
    "prayogagrahaṇa": ['mw'],
    "prayogajña": ['mw'],
    "prayogakaustubha": ['mw'],
    "prayogakārikā": ['mw'],
    "prayogamantra": ['mw'],
    "prayogamayūkha": ['mw'],
    "prayogamañjarī": ['mw'],
    "prayogamaṇimālikā": ['mw'],
    "prayogamukhavyākaraṇa": ['mw'],
    "prayogamuktāvalī": ['mw'],
    "prayoganipuṇa": ['cae', 'mw'],
    "prayogapaddhati": ['mw'],
    "prayogapañcaratna": ['mw'],
    "prayogapradhāna": ['mw'],
    "prayogapustaka": ['mw'],
    "prayogapāda": ['mw'],
    "prayogapārijāta": ['mw'],
    "prayogaratna": ['mw'],
    "prayogaratnakroḍa": ['mw'],
    "prayogaratnamālikā": ['mw'],
    "prayogaratnamālā": ['mw'],
    "prayogaratnasaṃskāra": ['mw'],
    "prayogaratnākara": ['mw'],
    "prayogaratnāvalī": ['mw'],
    "prayogasaraṇi": ['mw'],
    "prayogasaṃgraha": ['mw'],
    "prayogasaṃgrahaviveka": ['mw'],
    "prayogasāra": ['mw'],
    "prayogasārasamuccaya": ['mw'],
    "prayogasāraṇī": ['mw'],
    "prayogatattva": ['mw'],
    "prayogataḥ": ['ap90'],
    "prayogavaijayantī": ['mw'],
    "prayogavidhi": ['mw'],
    "prayogaviveka": ['mw'],
    "prayogavivekasaṃgraha": ['mw'],
    "prayogavīrya": ['mw'],
    "prayogavṛtti": ['mw'],
    "prayogaśikhāmaṇi": ['mw'],
    "prayogaḥ": ['ap90'],
    "prayogin": ['ap90', 'cae', 'mw'],
    "prayogitva": ['mw'],
    "prayogya": ['mw'],
    "prayogyaḥ": ['ap90'],
    "prayogāmṛta": ['mw'],
    "prayogārtha": ['mw'],
    "prayogātiśaya": ['mw'],
    "prayogāṇḍabilā": ['mw'],
    "prayogīya": ['mw'],
    "prayojaka": ['ap90', 'cae', 'mw'],
    "prayojakakartṛtva": ['mw'],
    "prayojakatva": ['mw'],
    "prayojakatā": ['mw'],
    "prayojakādhyāyabhāṣya": ['mw'],
    "prayojana": ['cae', 'mw'],
    "prayojanavat": ['ap90', 'mw'],
    "prayojanavattva": ['mw'],
    "prayojanaṃ": ['ap90'],
    "prayojayitṛ": ['mw'],
    "prayojya": ['ap90', 'cae', 'mw'],
    "prayojyatva": ['mw'],
    "prayoktavya": ['cae', 'ddsa', 'mw'],
    "prayoktra": ['mw'],
    "prayoktṛ": ['ap90', 'cae', 'mw'],
    "prayoktṛtva": ['mw'],
    "prayoktṛtā": ['mw'],
    "prayotṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "prayu": ['mw'],
    "prayuch": ['mw'],
    "prayuddha": ['cae', 'mw'],
    "prayuddhaṃ": ['ap90'],
    "prayuddhārtha": ['mw'],
    "prayudh": ['cae', 'gra', 'mw'],
    "prayuga": ['mw'],
    "prayuj": ['ap90', 'cae', 'gra', 'mw'],
    "prayujyate": ['bhs'],
    "prayukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "prayuktasaṃskāra": ['mw'],
    "prayuktatama": ['mw'],
    "prayukti": ['cae', 'gra', 'mw'],
    "prayuktikā": ['bhs'],
    "prayuktiḥ": ['ap90'],
    "prayut": ['mw'],
    "prayuta": ['ap90', 'cae', 'mw'],
    "prayuteśvaratīrtha": ['mw'],
    "prayuti": ['gra', 'mw'],
    "prayutsu": ['mw'],
    "prayutsuḥ": ['ap90'],
    "prayutvan": ['gra', 'mw'],
    "prayuvana": ['mw'],
    "prayyamedha": ['mw'],
    "prayā": ['ap90', 'cae', 'gra', 'mw'],
    "prayāc": ['mw'],
    "prayācaka": ['mw'],
    "prayācana": ['cae', 'mw'],
    "prayācanaṃ": ['ap90'],
    "prayāga": ['cae', 'ddsa', 'mw'],
    "prayāgabhaya": ['mw'],
    "prayāgadāsa": ['mw'],
    "prayāgakṛtya": ['mw'],
    "prayāgamāhātmya": ['mw'],
    "prayāgapraghaṭṭaka": ['mw'],
    "prayāgaprakaraṇa": ['mw'],
    "prayāgaratnakroḍa": ['mw'],
    "prayāgarājāṣṭaka": ['mw'],
    "prayāgasetu": ['mw'],
    "prayāgatīrtha": ['mw'],
    "prayāgavana": ['mw'],
    "prayāgaḥ": ['ap90'],
    "prayāja": ['cae', 'gra', 'mw'],
    "prayājatva": ['mw'],
    "prayājavat": ['mw'],
    "prayājaḥ": ['ap90'],
    "prayājyā": ['mw'],
    "prayājāhuti": ['mw'],
    "prayājānuyāja": ['mw'],
    "prayāma": ['bhs', 'mw'],
    "prayāman": ['cae', 'gra', 'mw'],
    "prayāmaḥ": ['ap90'],
    "prayāmya": ['mw'],
    "prayānīya": ['mw'],
    "prayāpana": ['mw'],
    "prayāpanaṃ": ['ap90'],
    "prayāpanīya": ['mw'],
    "prayāpaṇa": ['mw'],
    "prayāpaṇaṃ": ['ap90'],
    "prayāpaṇi": ['mw'],
    "prayāpaṇīya": ['mw'],
    "prayāpin": ['mw'],
    "prayāpita": ['ap90', 'mw'],
    "prayāpya": ['mw'],
    "prayāpyamāna": ['mw'],
    "prayāpyamāṇa": ['mw'],
    "prayāsa": ['cae', 'mw'],
    "prayāsabhāj": ['mw'],
    "prayāsaḥ": ['ap90'],
    "prayāsita": ['mw'],
    "prayāta": ['ap90', 'ddsa', 'mw'],
    "prayātavya": ['mw'],
    "prayātrā": ['mw'],
    "prayātṛ": ['mw'],
    "prayāvan": ['gra', 'mw'],
    "prayāyin": ['mw'],
    "prayāṇa": ['cae', 'gra', 'mw'],
    "prayāṇabhaṅga": ['mw'],
    "prayāṇaka": ['mw'],
    "prayāṇakaṃ": ['ap90'],
    "prayāṇakāla": ['mw'],
    "prayāṇapaṭaha": ['mw'],
    "prayāṇapurī": ['mw'],
    "prayāṇapurīmāhātmya": ['mw'],
    "prayāṇavicāra": ['mw'],
    "prayāṇaṃ": ['ap90'],
    "prayāṇi": ['mw'],
    "prayāṇārha": ['mw'],
    "prayāṇīya": ['mw'],
    "praśabdha": ['bhs'],
    "praśad": ['mw'],
    "praśak": ['mw'],
    "praśaka": ['mw'],
    "praśakya": ['mw'],
    "praśala": ['mw'],
    "praśalaḥ": ['ap90'],
    "praśam": ['ap90', 'mw'],
    "praśama": ['cae', 'mw'],
    "praśamagandhasunābha": ['bhs'],
    "praśamaka": ['mw'],
    "praśamana": ['ap90', 'cae', 'mw'],
    "praśamaratisūsra": ['mw'],
    "praśamarūpagati": ['bhs'],
    "praśamasthita": ['mw'],
    "praśamasukhābhijñā": ['bhs'],
    "praśamaḥ": ['ap90'],
    "praśamaṃkara": ['mw'],
    "praśamita": ['ap90', 'mw'],
    "praśamitaripu": ['mw'],
    "praśamitopadrava": ['mw'],
    "praśamitāri": ['mw'],
    "praśamāyana": ['mw'],
    "praśamī": ['mw'],
    "praśardha": ['cae', 'gra', 'mw'],
    "praśas": ['cae', 'mw'],
    "praśasta": ['ap90', 'bhs', 'cae', 'mw'],
    "praśastabhāṣya": ['mw'],
    "praśastaguṇarāśi": ['bhs'],
    "praśastakalaśa": ['mw'],
    "praśastakara": ['mw'],
    "praśastaparibhāṣā": ['mw'],
    "praśastapāda": ['mw'],
    "praśastatva": ['mw'],
    "praśastatā": ['mw'],
    "praśastavacana": ['cae', 'mw'],
    "praśastavarṇa": ['bhs'],
    "praśastavya": ['mw'],
    "praśasti": ['cae', 'gra', 'mw'],
    "praśastigāthā": ['mw'],
    "praśastikāśikā": ['mw'],
    "praśastikṛt": ['cae', 'gra', 'mw'],
    "praśastipaṭṭa": ['mw'],
    "praśastiprakāśikā": ['mw'],
    "praśastiratnākara": ['mw'],
    "praśastiratnāvalī": ['mw'],
    "praśastitaraṃga": ['mw'],
    "praśastiḥ": ['ap90'],
    "praśastā": ['mw'],
    "praśastādri": ['mw'],
    "praśasya": ['ap90', 'cae', 'mw'],
    "praśasyatā": ['mw'],
    "praśattvan": ['ap90', 'mw'],
    "praśattvarī": ['ap90', 'mw'],
    "praśaṃs": ['ap90', 'mw'],
    "praśaṃsaka": ['ap90', 'ddsa', 'mw'],
    "praśaṃsana": ['cae', 'mw'],
    "praśaṃsanaṃ": ['ap90'],
    "praśaṃsanīya": ['mw'],
    "praśaṃsin": ['cae', 'mw'],
    "praśaṃsita": ['ap90', 'mw'],
    "praśaṃsitavya": ['mw'],
    "praśaṃsiya": ['bhs'],
    "praśaṃsopamā": ['cae', 'mw'],
    "praśaṃstavya": ['mw'],
    "praśaṃsya": ['cae', 'mw'],
    "praśaṃsā": ['ap90', 'mw'],
    "praśaṃsālāpa": ['mw'],
    "praśaṃsāmukhara": ['mw'],
    "praśaṃsāmukharānana": ['mw'],
    "praśaṃsānāman": ['mw'],
    "praśaṃsāvacana": ['mw'],
    "praśaṃsāvali": ['mw'],
    "praśaṃyuvāka": ['mw'],
    "praśaṭha": ['bhs', 'mw'],
    "praśaṭhatā": ['mw'],
    "praścotana": ['ddsa', 'mw'],
    "praścotanaṃ": ['ap90'],
    "praścut": ['mw'],
    "praścutita": ['mw'],
    "praścyut": ['mw'],
    "praśis": ['cae', 'gra', 'mw'],
    "praśithila": ['ap90', 'cae', 'ddsa', 'mw'],
    "praśithilabhujagranthi": ['mw'],
    "praśithilī": ['mw'],
    "praśithilībhūta": ['mw'],
    "praśithilīkṛta": ['mw'],
    "praśiṣa": ['mw'],
    "praśiṣya": ['mw'],
    "praśiṣyatva": ['mw'],
    "praśiṣyaḥ": ['ap90'],
    "praśiṣṭa": ['ap90', 'mw'],
    "praśiṣṭi": ['cae', 'mw'],
    "praśiṣṭiḥ": ['ap90'],
    "praślatha": ['ap90', 'mw'],
    "praśleṣa": ['cae', 'mw'],
    "praśleṣaḥ": ['ap90'],
    "praślita": ['ddsa', 'mw'],
    "praśliṣṭa": ['ap90', 'cae', 'mw'],
    "praśna": ['cae', 'ddsa', 'gra', 'mw'],
    "praśnabhairava": ['mw'],
    "praśnabhāga": ['mw'],
    "praśnabhārgavakerala": ['mw'],
    "praśnabrahmārka": ['mw'],
    "praśnacandrikā": ['mw'],
    "praśnacaṇḍeśvara": ['mw'],
    "praśnacintāmaṇi": ['mw'],
    "praśnacūḍāmaṇi": ['mw'],
    "praśnadīpikā": ['mw'],
    "praśnadūtī": ['mw'],
    "praśnagrantha": ['mw'],
    "praśnajñāna": ['mw'],
    "praśnakalpalatā": ['mw'],
    "praśnakathā": ['cae', 'ddsa', 'mw'],
    "praśnakaumudī": ['mw'],
    "praśnakoṣṭhī": ['mw'],
    "praśnakṛṣṇīya": ['mw'],
    "praśnalakṣaṇa": ['mw'],
    "praśnamanoramā": ['mw'],
    "praśnamañjūṣā": ['mw'],
    "praśnamokṣa": ['mw'],
    "praśnamārga": ['mw'],
    "praśnamārtaṇḍa": ['mw'],
    "praśnamāṇikyamālā": ['mw'],
    "praśnanidhi": ['mw'],
    "praśnanirvācana": ['mw'],
    "praśnanīlakaṇṭha": ['mw'],
    "praśnapañjikā": ['mw'],
    "praśnapradīpa": ['mw'],
    "praśnaprakaraṇa": ['mw'],
    "praśnaprakāśa": ['mw'],
    "praśnapūrvaka": ['cae', 'mw'],
    "praśnapūrvakam": ['mw'],
    "praśnapūrvam": ['mw'],
    "praśnarahasya": ['mw'],
    "praśnaratna": ['mw'],
    "praśnaratnasāgara": ['mw'],
    "praśnaratnāvalī": ['mw'],
    "praśnaratnāṅkura": ['mw'],
    "praśnasamuccaya": ['mw'],
    "praśnasaptati": ['mw'],
    "praśnasaṃgraha": ['mw'],
    "praśnasudhākara": ['mw'],
    "praśnasāra": ['mw'],
    "praśnasārasamudra": ['mw'],
    "praśnasāroddhāra": ['mw'],
    "praśnasārāmnāya": ['mw'],
    "praśnatantra": ['mw'],
    "praśnati": ['bhs'],
    "praśnatilaka": ['mw'],
    "praśnavaiṣṇava": ['mw'],
    "praśnavidyā": ['mw'],
    "praśnavinoda": ['mw'],
    "praśnaviveka": ['mw'],
    "praśnavivāda": ['ddsa', 'mw'],
    "praśnavivāka": ['mw'],
    "praśnavyākaraṇa": ['mw'],
    "praśnavādin": ['mw'],
    "praśnay": ['cae'],
    "praśnaya": ['ddsa', 'mw'],
    "praśnayati": ['ap90'],
    "praśnaśataka": ['mw'],
    "praśnaśekhara": ['mw'],
    "praśnaśiromaṇi": ['mw'],
    "praśnaślokāvalī": ['mw'],
    "praśnaśāstra": ['mw'],
    "praśnaḥ": ['ap90'],
    "praśni": ['mw'],
    "praśnin": ['cae', 'ddsa', 'mw'],
    "praśnopadeśa": ['mw'],
    "praśnopaniṣad": ['mw'],
    "praśnottara": ['cae', 'ddsa', 'mw'],
    "praśnottaramaṇimālā": ['mw'],
    "praśnottaramālikā": ['mw'],
    "praśnottaramālā": ['cae', 'mw'],
    "praśnottararatnamālā": ['mw'],
    "praśnottararatnāvalī": ['mw'],
    "praśnottaratantra": ['mw'],
    "praśnādika": ['mw'],
    "praśnākhyāna": ['cae', 'mw'],
    "praśnānuṣṭhānapaddhati": ['mw'],
    "praśnāryā": ['mw'],
    "praśnārṇava": ['mw'],
    "praśnāvalī": ['mw'],
    "praśnī": ['mw'],
    "praśobhita": ['bhs'],
    "praśocana": ['mw'],
    "praśoṣa": ['ddsa', 'mw'],
    "praśoṣaḥ": ['ap90'],
    "praśoṣaṇa": ['mw'],
    "praśoṣita": ['bhs'],
    "praśrabdha": ['bhs'],
    "praśrabdhi": ['bhs', 'mw'],
    "praśrabdhiḥ": ['ap90'],
    "praśrabhyate": ['bhs'],
    "praśraddadhāti": ['bhs'],
    "praśranthana": ['mw'],
    "praśratha": ['mw'],
    "praśrathaḥ": ['ap90'],
    "praśravas": ['gra', 'mw'],
    "praśravaṇa": ['mw'],
    "praśraya": ['cae', 'ddsa', 'mw'],
    "praśrayavant": ['cae'],
    "praśrayavat": ['mw'],
    "praśrayaḥ": ['ap90'],
    "praśrayaṇa": ['mw'],
    "praśrayin": ['ap90', 'cae', 'mw'],
    "praśrayitā": ['mw'],
    "praśrayottara": ['mw'],
    "praśrayāvanata": ['mw'],
    "praśreṣṭha": ['bhs'],
    "praśri": ['mw'],
    "praśrita": ['cae', 'mw'],
    "praśritam": ['mw'],
    "praśru": ['mw'],
    "praśubh": ['mw'],
    "praśuc": ['mw'],
    "praśuci": ['ddsa', 'mw'],
    "praśuddhi": ['mw'],
    "praśuddhiḥ": ['ap90'],
    "praśukrīya": ['mw'],
    "praśumbh": ['mw'],
    "praśuśruka": ['mw'],
    "praśuṣ": ['mw'],
    "praśvas": ['mw'],
    "praśvasati": ['bhs'],
    "praśvasitavya": ['ddsa', 'mw'],
    "praśvāsa": ['mw'],
    "praśvāsaḥ": ['ap90'],
    "praśākha": ['ap90', 'mw'],
    "praśākhavat": ['mw'],
    "praśākhikā": ['ap90', 'cae', 'mw'],
    "praśākhā": ['cae', 'ddsa', 'mw'],
    "praśām": ['mw'],
    "praśāma": ['mw'],
    "praśāmaḥ": ['ap90'],
    "praśāmita": ['mw'],
    "praśān": ['mw'],
    "praśānta": ['bhs', 'cae', 'mw'],
    "praśāntabhūmipāla": ['mw'],
    "praśāntabādha": ['mw'],
    "praśāntaceṣṭa": ['mw'],
    "praśāntacitta": ['bhs', 'mw'],
    "praśāntacārin": ['mw'],
    "praśāntacāritramati": ['bhs', 'mw'],
    "praśāntadhī": ['mw'],
    "praśāntaka": ['mw'],
    "praśāntakāma": ['mw'],
    "praśāntamati": ['bhs'],
    "praśāntamatitejas": ['bhs'],
    "praśāntamūrti": ['mw'],
    "praśāntaprabha": ['bhs'],
    "praśāntaroga": ['bhs'],
    "praśāntarutasāgaravatī": ['bhs'],
    "praśāntarāga": ['mw'],
    "praśāntasvara": ['bhs'],
    "praśāntasāgaravatī": ['bhs'],
    "praśāntatā": ['cae', 'mw'],
    "praśāntaujas": ['mw'],
    "praśāntaviniścayapratihāryanirdeśa": ['mw'],
    "praśāntaviniścayaprātihāryanirdeśa": ['bhs'],
    "praśāntavinīteśvara": ['bhs', 'mw'],
    "praśānti": ['cae', 'mw'],
    "praśāntidūtī": ['mw'],
    "praśāntolmuka": ['mw'],
    "praśāntorja": ['mw'],
    "praśāntārāti": ['mw'],
    "praśāntātman": ['mw'],
    "praśās": ['ap90', 'mw'],
    "praśāsaka": ['mw'],
    "praśāsakaḥ": ['ap90'],
    "praśāsana": ['cae', 'gra', 'mw'],
    "praśāsanaṃ": ['ap90'],
    "praśāsita": ['mw'],
    "praśāsitṛ": ['cae', 'mw'],
    "praśāsta": ['mw'],
    "praśāstra": ['gra', 'mw'],
    "praśāstṛ": ['ap90', 'cae', 'gra', 'mw'],
    "praśāsya": ['mw'],
    "praśātikā": ['mw'],
    "praśāṃta": ['ap90'],
    "praśāṃtiḥ": ['ap90'],
    "praśī": ['mw'],
    "praśīrṇa": ['mw'],
    "praśīta": ['mw'],
    "praśūna": ['mw'],
    "praśṝ": ['mw'],
    "praḍīna": ['bhs', 'mw'],
    "praḍīnaṃ": ['ap90'],
    "praṇa": ['ap90', 'mw'],
    "praṇabh": ['mw'],
    "praṇad": ['ap90', 'mw'],
    "praṇada": ['bhs'],
    "praṇadana": ['mw'],
    "praṇadanaṃ": ['ap90'],
    "praṇadita": ['ap90', 'mw'],
    "praṇakha": ['ddsa', 'mw'],
    "praṇakhaḥ": ['ap90'],
    "praṇam": ['ap90', 'mw'],
    "praṇamana": ['cae', 'mw'],
    "praṇamati": ['bhs'],
    "praṇamayya": ['mw'],
    "praṇamita": ['mw'],
    "praṇamra": ['mw'],
    "praṇamrībhū": ['mw'],
    "praṇaptṛ": ['cae'],
    "praṇapāt": ['cae', 'gra', 'mw'],
    "praṇasa": ['ap90', 'mw'],
    "praṇata": ['ap90', 'bhs', 'cae', 'mw'],
    "praṇatabahuphala": ['mw'],
    "praṇatakāya": ['mw'],
    "praṇatavat": ['mw'],
    "praṇataśiras": ['mw'],
    "praṇati": ['cae', 'mw'],
    "praṇatiḥ": ['ap90'],
    "praṇatātmavat": ['mw'],
    "praṇatāśeṣasāmanta": ['mw'],
    "praṇava": ['cae', 'ddsa', 'mw'],
    "praṇavadarpaṇa": ['mw'],
    "praṇavakalpa": ['mw'],
    "praṇavapariśiṣṭa": ['mw'],
    "praṇavatva": ['mw'],
    "praṇavavyākhyā": ['mw'],
    "praṇavaḥ": ['ap90'],
    "praṇavopaniṣad": ['mw'],
    "praṇavārcanacandrikā": ['mw'],
    "praṇavārthanirṇaya": ['mw'],
    "praṇavārthaprakāśikāvyākhyāna": ['mw'],
    "praṇaya": ['cae', 'ddsa', 'mw'],
    "praṇayabhaṅga": ['cae', 'mw'],
    "praṇayakalaha": ['mw'],
    "praṇayakopa": ['mw'],
    "praṇayakupita": ['mw'],
    "praṇayamadhura": ['mw'],
    "praṇayamaya": ['mw'],
    "praṇayamāna": ['mw'],
    "praṇayana": ['cae', 'mw'],
    "praṇayanaṃ": ['ap90'],
    "praṇayanīya": ['mw'],
    "praṇayapeśala": ['mw'],
    "praṇayaprakarṣa": ['mw'],
    "praṇayaspṛś": ['cae', 'mw'],
    "praṇayavacana": ['mw'],
    "praṇayavant": ['cae'],
    "praṇayavat": ['ap90', 'mw'],
    "praṇayavighāta": ['mw'],
    "praṇayavihati": ['mw'],
    "praṇayavimukha": ['mw'],
    "praṇayaḥ": ['ap90'],
    "praṇayena": ['mw'],
    "praṇayibhava": ['mw'],
    "praṇayijana": ['cae', 'mw'],
    "praṇayikriyā": ['mw'],
    "praṇayimādhavacampū": ['mw'],
    "praṇayin": ['ap90', 'cae', 'mw'],
    "praṇayinī": ['mw'],
    "praṇayitā": ['ap90', 'cae', 'mw'],
    "praṇayonmukha": ['mw'],
    "praṇayopeta": ['mw'],
    "praṇayopetam": ['mw'],
    "praṇayāmṛtapañcāśaka": ['mw'],
    "praṇayāpahārin": ['mw'],
    "praṇayāparādha": ['mw'],
    "praṇayāt": ['mw'],
    "praṇayībhū": ['mw'],
    "praṇayīkṛ": ['mw'],
    "praṇaś": ['ap90', 'mw'],
    "praṇejana": ['cae', 'ddsa', 'mw'],
    "praṇejanaṃ": ['ap90'],
    "praṇenī": ['gra', 'mw'],
    "praṇetara": ['bhs'],
    "praṇetavya": ['mw'],
    "praṇetra": ['mw'],
    "praṇetṛ": ['ap90', 'cae', 'gra', 'mw'],
    "praṇetṛmat": ['mw'],
    "praṇeya": ['ap90', 'cae', 'mw'],
    "praṇi": ['mw'],
    "praṇidadhāti": ['bhs'],
    "praṇidheti": ['bhs'],
    "praṇidheya": ['mw'],
    "praṇidheyaṃ": ['ap90'],
    "praṇidhi": ['bhs', 'cae', 'mw'],
    "praṇidhiḥ": ['ap90'],
    "praṇidhyai": ['mw'],
    "praṇidhyeti": ['bhs'],
    "praṇidhā": ['ap90', 'mw'],
    "praṇidhāna": ['bhs', 'cae', 'ddsa', 'mw'],
    "praṇidhānasāgaraprabhāsaśrī": ['bhs'],
    "praṇidhānaṃ": ['ap90'],
    "praṇidhātavya": ['mw'],
    "praṇidhāyin": ['mw'],
    "praṇigad": ['mw'],
    "praṇihan": ['mw'],
    "praṇihata": ['mw'],
    "praṇihita": ['ap90', 'cae', 'mw'],
    "praṇihitadhī": ['mw'],
    "praṇihitekṣaṇa": ['mw'],
    "praṇihitātman": ['mw'],
    "praṇij": ['mw'],
    "praṇijñā": ['mw'],
    "praṇikṣ": ['mw'],
    "praṇikṣaṇa": ['mw'],
    "praṇimat": ['ddsa'],
    "praṇinad": ['mw'],
    "praṇind": ['mw'],
    "praṇindana": ['mw'],
    "praṇināda": ['mw'],
    "praṇinādaḥ": ['ap90'],
    "praṇinīṣeṇya": ['mw'],
    "praṇipat": ['ap90', 'mw'],
    "praṇipatana": ['cae', 'mw'],
    "praṇipatanaṃ": ['ap90'],
    "praṇipatita": ['mw'],
    "praṇipāta": ['cae', 'mw'],
    "praṇipātagata": ['mw'],
    "praṇipātapratīkāra": ['mw'],
    "praṇipātapuraḥsaram": ['mw'],
    "praṇipātarasa": ['mw'],
    "praṇipātin": ['mw'],
    "praṇitar": ['bhs'],
    "praṇiṃsita": ['ap90', 'mw'],
    "praṇiṃsitavya": ['mw'],
    "praṇoda": ['mw'],
    "praṇodaḥ": ['ap90'],
    "praṇodita": ['ap90', 'mw'],
    "praṇodya": ['mw'],
    "praṇottavya": ['mw'],
    "praṇu": ['ap90', 'mw'],
    "praṇud": ['ap90', 'ddsa', 'mw'],
    "praṇuda": ['mw'],
    "praṇudita": ['mw'],
    "praṇunna": ['ap90', 'mw'],
    "praṇuta": ['ap90', 'mw'],
    "praṇutta": ['ap90', 'mw'],
    "praṇyasta": ['mw'],
    "praṇāda": ['bhs', 'cae', 'mw'],
    "praṇādaka": ['mw'],
    "praṇādaḥ": ['ap90'],
    "praṇāla": ['mw'],
    "praṇālaḥ": ['ap90'],
    "praṇālikayā": ['mw'],
    "praṇālikā": ['cae', 'mw'],
    "praṇālin": ['bhs'],
    "praṇālī": ['cae', 'mw'],
    "praṇāma": ['cae', 'mw'],
    "praṇāmakṛti": ['mw'],
    "praṇāmamitra": ['mw'],
    "praṇāmayati": ['bhs'],
    "praṇāmaḥ": ['ap90'],
    "praṇāmin": ['mw'],
    "praṇāmādara": ['mw'],
    "praṇāmāñjali": ['mw'],
    "praṇāyaka": ['mw'],
    "praṇāyakaḥ": ['ap90'],
    "praṇāyya": ['ap90', 'mw'],
    "praṇāśa": ['cae', 'mw'],
    "praṇāśana": ['ap90', 'cae', 'mw'],
    "praṇāśaḥ": ['ap90'],
    "praṇāśin": ['cae', 'mw'],
    "praṇāḍikayā": ['mw'],
    "praṇāḍikā": ['ddsa', 'mw'],
    "praṇāḍyā": ['mw'],
    "praṇāḍī": ['ap90', 'mw'],
    "praṇī": ['ap90', 'cae', 'gra', 'mw'],
    "praṇīta": ['ap90', 'bhs', 'cae', 'mw'],
    "praṇītatva": ['mw'],
    "praṇītavijñāpana": ['mw'],
    "praṇīti": ['cae', 'gra', 'mw'],
    "praṇītiḥ": ['ap90'],
    "praṇītā": ['mw'],
    "praṇītācaru": ['mw'],
    "praṇītākāle": ['mw'],
    "praṇītāpraṇayana": ['mw'],
    "praṇīya": ['mw'],
    "praṣṇavaiṣṇava": ['mw'],
    "praṣṭavya": ['bhs', 'cae', 'ddsa', 'mw'],
    "praṣṭha": ['ap90', 'cae', 'ddsa', 'mw'],
    "praṣṭhatva": ['mw'],
    "praṣṭhauhī": ['ap90', 'mw'],
    "praṣṭhavah": ['mw'],
    "praṣṭhiv": ['mw'],
    "praṣṭhivāhin": ['mw'],
    "praṣṭhī": ['mw'],
    "praṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "praṣṭimat": ['gra', 'mw'],
    "praṣṭivāhana": ['mw'],
    "praṣṭivāhin": ['mw'],
    "praṣṭiḥ": ['ap90'],
    "praṣṭṛ": ['cae', 'mw'],
    "pre": ['ap90', 'mw'],
    "predaṇḍa": ['cae'],
    "predaṇḍaka": ['cae'],
    "preddha": ['mw'],
    "predhā": ['mw'],
    "predi": ['mw'],
    "prehaṇa": ['mw'],
    "prehi": ['ap90', 'ddsa', 'mw'],
    "prehidvitīyā": ['mw'],
    "prehikardamā": ['mw'],
    "prehikaṭā": ['mw'],
    "prehivaṇijā": ['mw'],
    "prekīya": ['mw'],
    "prekṣ": ['ap90', 'mw'],
    "prekṣaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "prekṣakaḥ": ['ap90'],
    "prekṣakerita": ['mw'],
    "prekṣaṇa": ['bhs', 'cae', 'mw'],
    "prekṣaṇaka": ['cae', 'mw'],
    "prekṣaṇakaṃ": ['ap90'],
    "prekṣaṇakūṭa": ['mw'],
    "prekṣaṇaṃ": ['ap90'],
    "prekṣaṇika": ['mw'],
    "prekṣaṇikā": ['ap90', 'mw'],
    "prekṣaṇālambha": ['cae', 'mw'],
    "prekṣaṇīya": ['ap90', 'cae', 'mw'],
    "prekṣaṇīyaka": ['mw'],
    "prekṣaṇīyakaṃ": ['ap90'],
    "prekṣaṇīyatama": ['mw'],
    "prekṣaṇīyatara": ['mw'],
    "prekṣaṇīyatā": ['mw'],
    "prekṣikā": ['bhs'],
    "prekṣin": ['ap90', 'cae', 'mw'],
    "prekṣita": ['ap90', 'cae', 'ddsa', 'mw'],
    "prekṣitavya": ['cae', 'mw'],
    "prekṣitva": ['mw'],
    "prekṣitṛ": ['cae', 'mw'],
    "prekṣya": ['ap90', 'bhs', 'cae', 'mw'],
    "prekṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "prekṣāgāra": ['cae', 'mw'],
    "prekṣāgṛha": ['mw'],
    "prekṣākārin": ['mw'],
    "prekṣāprapañca": ['mw'],
    "prekṣāpūrva": ['mw'],
    "prekṣāpūrvam": ['mw'],
    "prekṣārtham": ['mw'],
    "prekṣāsamāja": ['cae', 'mw'],
    "prekṣāvant": ['cae'],
    "prekṣāvat": ['ap90', 'mw'],
    "prekṣāvidhi": ['mw'],
    "prema": ['cae', 'ddsa', 'mw'],
    "premabandha": ['cae', 'ddsa', 'mw'],
    "premabandhana": ['mw'],
    "premabhakticandrikā": ['mw'],
    "premabhaktistotra": ['mw'],
    "premabhāva": ['mw'],
    "premadhara": ['mw'],
    "premalatikā": ['mw'],
    "preman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "premanidhi": ['mw'],
    "premanārāyaṇa": ['mw'],
    "premapara": ['mw'],
    "premapattanikā": ['mw'],
    "premapātana": ['mw'],
    "premapātra": ['mw'],
    "premapīyūṣalatākartarī": ['mw'],
    "premarasāyana": ['mw'],
    "premarasāyanānurāga": ['mw'],
    "premarddhi": ['mw'],
    "premarāja": ['mw'],
    "premarāśībhū": ['mw'],
    "premasena": ['mw'],
    "premasāgara": ['mw'],
    "premasāhi": ['mw'],
    "prematattvanirūpaṇa": ['mw'],
    "premavat": ['mw'],
    "premavatī": ['ap90', 'mw'],
    "premaviśvāsabhūmi": ['mw'],
    "premaṇī": ['bhs'],
    "premaṇīya": ['bhs', 'mw'],
    "premendusāgara": ['mw'],
    "premin": ['ap90', 'mw'],
    "premna": ['bhs'],
    "premoktyudaya": ['mw'],
    "premā": ['mw'],
    "premābandha": ['cae', 'mw'],
    "premākara": ['ddsa', 'mw'],
    "premāmṛta": ['mw'],
    "premārdra": ['cae', 'mw'],
    "premāvatī": ['mw'],
    "premāśru": ['mw'],
    "premṇā": ['mw'],
    "prenv": ['mw'],
    "prenvana": ['mw'],
    "prenvanīya": ['mw'],
    "prepa": ['mw'],
    "prepsu": ['ap90', 'mw'],
    "prepsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "prer": ['ap90', 'mw'],
    "preraka": ['ap90', 'cae', 'ddsa', 'mw'],
    "prerakatva": ['mw'],
    "prerayitṛ": ['mw'],
    "preraṇa": ['cae', 'mw'],
    "preraṇaṃ": ['ap90'],
    "preraṇīya": ['cae', 'mw'],
    "prerita": ['ap90', 'mw'],
    "preritṛ": ['cae', 'mw'],
    "prertvan": ['ap90', 'mw'],
    "prertvarī": ['mw'],
    "preta": ['ap90', 'cae', 'ddsa', 'mw'],
    "pretabhakṣiṇī": ['mw'],
    "pretabhāva": ['cae', 'mw'],
    "pretabhāvastha": ['mw'],
    "pretabhūmi": ['mw'],
    "pretacārin": ['mw'],
    "pretadhūma": ['cae', 'mw'],
    "pretadāha": ['mw'],
    "pretadāhāgni": ['mw'],
    "pretadīpikā": ['mw'],
    "pretagata": ['cae', 'mw'],
    "pretagati": ['cae', 'mw'],
    "pretagopa": ['mw'],
    "pretagṛha": ['mw'],
    "pretahāra": ['cae', 'mw'],
    "pretaka": ['bhs'],
    "pretakalpa": ['mw'],
    "pretakarman": ['cae', 'mw'],
    "pretakārya": ['cae', 'mw'],
    "pretakāya": ['cae', 'mw'],
    "pretakṛtya": ['cae', 'mw'],
    "pretakṛtyanirṇaya": ['mw'],
    "pretakṛtyādinirṇaya": ['mw'],
    "pretaloka": ['mw'],
    "pretamaharddhika": ['bhs'],
    "pretamañjarī": ['mw'],
    "pretamedha": ['mw'],
    "pretamokṣa": ['mw'],
    "pretamuktidā": ['mw'],
    "pretanadī": ['mw'],
    "pretanara": ['mw'],
    "pretanirhāraka": ['mw'],
    "pretaniryātaka": ['cae', 'mw'],
    "pretanātha": ['cae', 'mw'],
    "pretapakṣa": ['mw'],
    "pretapakṣaka": ['mw'],
    "pretapati": ['cae', 'mw'],
    "pretapatipaṭaha": ['mw'],
    "pretapatnī": ['mw'],
    "pretapatākā": ['mw'],
    "pretapaṭaha": ['mw'],
    "pretapitṛ": ['mw'],
    "pretapiṇḍabhuj": ['mw'],
    "pretapradīpa": ['mw'],
    "pretaprasādhana": ['mw'],
    "pretapura": ['mw'],
    "pretapurī": ['cae', 'mw'],
    "pretapātra": ['mw'],
    "pretarāja": ['cae', 'mw'],
    "pretarājaniveśana": ['mw'],
    "pretarājapura": ['mw'],
    "pretarākṣasī": ['mw'],
    "pretasamkḷpta": ['mw'],
    "pretasaṃsthā": ['mw'],
    "pretasaṃtarpitalokeśvara": ['bhs'],
    "pretasparśin": ['mw'],
    "pretatva": ['mw'],
    "pretavana": ['mw'],
    "pretavat": ['mw'],
    "pretavaśa": ['mw'],
    "pretavāhita": ['mw'],
    "pretaśarīra": ['mw'],
    "pretaśauca": ['mw'],
    "pretaśilā": ['mw'],
    "pretaśrāddha": ['mw'],
    "pretaśuddhi": ['cae', 'mw'],
    "preteśa": ['cae', 'ddsa', 'mw'],
    "preteśvara": ['cae', 'mw'],
    "preti": ['cae', 'ddsa', 'gra', 'mw'],
    "pretika": ['mw'],
    "pretikaḥ": ['ap90'],
    "pretivat": ['mw'],
    "pretiḥ": ['ap90'],
    "pretoddeśa": ['mw'],
    "pretvan": ['ap90', 'cae', 'ddsa', 'mw'],
    "pretya": ['ap90', 'cae', 'ddsa', 'mw'],
    "pretyabhāj": ['mw'],
    "pretyabhāva": ['cae', 'mw'],
    "pretyabhāvika": ['mw'],
    "pretyajāti": ['mw'],
    "pretādhipa": ['cae', 'ddsa', 'mw'],
    "pretādhipanagarī": ['mw'],
    "pretādhipati": ['cae', 'mw'],
    "pretālaya": ['mw'],
    "pretānna": ['cae', 'mw'],
    "pretāsthi": ['mw'],
    "pretāsthidhārin": ['mw'],
    "pretāvāsa": ['mw'],
    "pretāyana": ['mw'],
    "pretī": ['bhs'],
    "pretīṣaṇi": ['gra', 'mw'],
    "pretṛ": ['gra', 'mw'],
    "preyas": ['ap90', 'ddsa', 'gra', 'mw'],
    "preyaskara": ['mw'],
    "preyastva": ['mw'],
    "preyastā": ['mw'],
    "preyasvin": ['mw'],
    "preyasī": ['mw'],
    "preyaṃs": ['cae'],
    "preyopatya": ['mw'],
    "preyopatyaḥ": ['ap90'],
    "preḍ": ['mw'],
    "preḍaka": ['mw'],
    "preḍakatva": ['mw'],
    "preṃkh": ['ap90'],
    "preṃkhaḥ": ['ap90'],
    "preṃkhaṇa": ['ap90'],
    "preṃkhita": ['ap90'],
    "preṃkhol": ['ap90'],
    "preṃkholaḥ": ['ap90'],
    "preṃkhā": ['ap90'],
    "preṅgaṇa": ['mw'],
    "preṅkh": ['mw'],
    "preṅkha": ['cae', 'ddsa', 'gra', 'mw'],
    "preṅkhaphalaka": ['mw'],
    "preṅkhaṇa": ['cae', 'mw'],
    "preṅkhaṇakārikā": ['mw'],
    "preṅkhaṇīya": ['mw'],
    "preṅkheṅkhana": ['mw'],
    "preṅkhita": ['mw'],
    "preṅkhola": ['cae', 'ddsa', 'mw'],
    "preṅkholana": ['cae', 'mw'],
    "preṅkholaya": ['mw'],
    "preṅkholita": ['cae', 'mw'],
    "preṅkhā": ['mw'],
    "preṇi": ['gra', 'mw'],
    "preṇā": ['cae', 'mw'],
    "preṣ": ['ap90', 'cae', 'gra', 'mw'],
    "preṣa": ['cae', 'gra', 'mw'],
    "preṣaka": ['ap90', 'bhs', 'mw'],
    "preṣayati": ['bhs'],
    "preṣayitṛ": ['mw'],
    "preṣaḥ": ['ap90'],
    "preṣaṇa": ['cae', 'ddsa', 'mw'],
    "preṣaṇakṛt": ['mw'],
    "preṣaṇaṃ": ['ap90'],
    "preṣaṇādhyakṣa": ['mw'],
    "preṣaṇīya": ['mw'],
    "preṣita": ['ap90', 'ddsa', 'mw'],
    "preṣitavat": ['mw'],
    "preṣitavya": ['mw'],
    "preṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "preṣyabhāva": ['cae', 'mw'],
    "preṣyajana": ['cae', 'mw'],
    "preṣyakara": ['mw'],
    "preṣyatva": ['mw'],
    "preṣyatā": ['cae', 'mw'],
    "preṣyavadhū": ['mw'],
    "preṣyavarga": ['mw'],
    "preṣyā": ['ddsa'],
    "preṣyāntevāsin": ['mw'],
    "preṣyātva": ['mw'],
    "preṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "preṣṭhatama": ['mw'],
    "preṣṭhā": ['mw'],
    "privisitvā": ['cped'],
    "priya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "priyabandhu": ['cae'],
    "priyabhojana": ['mw'],
    "priyabhāva": ['mw'],
    "priyabhāvuka": ['mw'],
    "priyabhāvukatva": ['mw'],
    "priyabhāvukatā": ['mw'],
    "priyabhāṣaṇa": ['cae', 'mw'],
    "priyabhāṣin": ['mw'],
    "priyabhāṣiṇī": ['mw'],
    "priyacatura": ['mw'],
    "priyacikīrṣu": ['mw'],
    "priyacikīrṣā": ['cae', 'ddsa', 'mw'],
    "priyada": ['mw'],
    "priyadarśa": ['cae', 'mw'],
    "priyadarśana": ['bhs', 'cae', 'mw'],
    "priyadarśanā": ['bhs', 'mw'],
    "priyadarśanī": ['mw'],
    "priyadarśikā": ['cae', 'mw'],
    "priyadarśin": ['mw'],
    "priyadattā": ['mw'],
    "priyadevana": ['mw'],
    "priyadhanva": ['mw'],
    "priyadhā": ['mw'],
    "priyadhāma": ['gra', 'mw'],
    "priyadhāman": ['mw'],
    "priyadhānyakara": ['mw'],
    "priyadā": ['mw'],
    "priyadāsa": ['mw'],
    "priyaguḍa": ['mw'],
    "priyahita": ['cae', 'mw'],
    "priyailikā": ['mw'],
    "priyaiṣin": ['ddsa', 'mw'],
    "priyajana": ['cae', 'mw'],
    "priyajāni": ['mw'],
    "priyajāta": ['cae', 'gra', 'mw'],
    "priyajīva": ['mw'],
    "priyajīvita": ['mw'],
    "priyajīvitatā": ['mw'],
    "priyaka": ['ddsa', 'mw'],
    "priyakalaha": ['mw'],
    "priyakalatra": ['mw'],
    "priyakalpa": ['mw'],
    "priyakara": ['mw'],
    "priyakarman": ['mw'],
    "priyakaḥ": ['ap90'],
    "priyakāma": ['cae', 'mw'],
    "priyakāmya": ['mw'],
    "priyakāmyā": ['cae', 'mw'],
    "priyakāra": ['cae', 'mw'],
    "priyakāraka": ['cae', 'mw'],
    "priyakāraṇa": ['mw'],
    "priyakāraṇāt": ['mw'],
    "priyakārin": ['cae', 'mw'],
    "priyakāritva": ['mw'],
    "priyakī": ['mw'],
    "priyakṛt": ['cae', 'mw'],
    "priyakṛttama": ['mw'],
    "priyakṣatra": ['cae', 'gra', 'mw'],
    "priyam": ['mw'],
    "priyamadhu": ['mw'],
    "priyamaṅgalā": ['mw'],
    "priyamaṇḍana": ['mw'],
    "priyambhaviṣṇu": ['mw'],
    "priyambhaviṣṇutva": ['mw'],
    "priyambhaviṣṇutā": ['mw'],
    "priyamedha": ['gra', 'mw'],
    "priyamedhastuta": ['gra', 'mw'],
    "priyamedhavat": ['mw'],
    "priyamitra": ['mw'],
    "priyamukhyā": ['mw'],
    "priyamukhā": ['bhs', 'mw'],
    "priyamālyānulepana": ['mw'],
    "priyamānasa": ['mw'],
    "priyamāṇa": ['bhs'],
    "priyanivedana": ['cae', 'mw'],
    "priyanivedayitṛ": ['cae', 'mw'],
    "priyanivedikā": ['cae', 'mw'],
    "priyaniveditṛ": ['mw'],
    "priyapati": ['mw'],
    "priyaprada": ['mw'],
    "priyaprasādana": ['mw'],
    "priyaprasādanavrata": ['mw'],
    "priyapraśna": ['mw'],
    "priyaprepsu": ['mw'],
    "priyapriyeṇa": ['mw'],
    "priyaprāya": ['mw'],
    "priyaprāṇa": ['mw'],
    "priyaputra": ['mw'],
    "priyaratha": ['gra', 'mw'],
    "priyaraṇa": ['mw'],
    "priyarūpa": ['cae', 'mw'],
    "priyasa": ['gra', 'mw'],
    "priyasahacarī": ['mw'],
    "priyasakha": ['cae', 'mw'],
    "priyasakhī": ['mw'],
    "priyasamprahāra": ['mw'],
    "priyasamucita": ['mw'],
    "priyasamudra": ['mw'],
    "priyasamāgama": ['mw'],
    "priyasarpiṣka": ['mw'],
    "priyasatya": ['mw'],
    "priyasaṃdeśa": ['mw'],
    "priyasaṃgamana": ['mw'],
    "priyasaṃtati": ['mw'],
    "priyasaṃvāsa": ['cae', 'mw'],
    "priyasena": ['bhs', 'mw'],
    "priyasevaka": ['mw'],
    "priyastotra": ['gra', 'mw'],
    "priyasuhṛd": ['mw'],
    "priyasukha": ['mw'],
    "priyasvapna": ['mw'],
    "priyasvāmin": ['mw'],
    "priyasāhasa": ['mw'],
    "priyasāhasatva": ['mw'],
    "priyasālaka": ['mw'],
    "priyatama": ['ap90', 'mw'],
    "priyatamā": ['mw'],
    "priyatanaya": ['mw'],
    "priyatanu": ['mw'],
    "priyatara": ['ap90', 'mw'],
    "priyataratva": ['mw'],
    "priyatoṣaṇa": ['mw'],
    "priyatva": ['mw'],
    "priyatā": ['ap90', 'cae', 'mw'],
    "priyavacana": ['bhs', 'cae', 'mw'],
    "priyavacas": ['cae', 'mw'],
    "priyavadya": ['mw'],
    "priyavaktṛ": ['mw'],
    "priyavaktṛtva": ['mw'],
    "priyavallī": ['mw'],
    "priyavarṇī": ['mw'],
    "priyavasantaka": ['cae', 'mw'],
    "priyavastu": ['mw'],
    "priyavat": ['mw'],
    "priyavayasya": ['mw'],
    "priyavinākṛta": ['mw'],
    "priyaviprayoga": ['mw'],
    "priyaviśva": ['mw'],
    "priyavrata": ['gra', 'mw'],
    "priyavāc": ['cae', 'mw'],
    "priyavāda": ['cae', 'mw'],
    "priyavādikā": ['mw'],
    "priyavādin": ['mw'],
    "priyavāditā": ['mw'],
    "priyavāksahita": ['mw'],
    "priyayajña": ['mw'],
    "priyaśaṃsā": ['mw'],
    "priyaśiṣyā": ['mw'],
    "priyaśravas": ['mw'],
    "priyaśālaka": ['mw'],
    "priyaṃbhaviṣṇu": ['ap90'],
    "priyaṃdada": ['mw'],
    "priyaṃdadā": ['bhs', 'mw'],
    "priyaṃguḥ": ['ap90'],
    "priyaṃkara": ['ap90', 'bhs', 'cae', 'mw'],
    "priyaṃkaraṇa": ['mw'],
    "priyaṃkarī": ['mw'],
    "priyaṃkāra": ['mw'],
    "priyaṃvada": ['ap90', 'cae', 'ddsa', 'mw'],
    "priyaṃvadaka": ['mw'],
    "priyaṃvadā": ['mw'],
    "priyaṅgu": ['cae', 'ddsa', 'mw'],
    "priyaṅgudvīpa": ['mw'],
    "priyaṅgukā": ['mw'],
    "priyaṅguśyāmā": ['mw'],
    "priyaṅgvākhyā": ['mw'],
    "priyaṅkara": ['ddsa'],
    "priyeṇa": ['mw'],
    "priyodita": ['mw'],
    "priyokti": ['cae', 'mw'],
    "priyopabhoga": ['mw'],
    "priyopabhogavandhya": ['mw'],
    "priyopapatti": ['mw'],
    "priyosriya": ['gra', 'mw'],
    "priyā": ['mw'],
    "priyābhidheya": ['mw'],
    "priyādhāna": ['mw'],
    "priyādāsa": ['mw'],
    "priyājana": ['mw'],
    "priyāka": ['mw'],
    "priyākhya": ['ddsa', 'mw'],
    "priyākhyāna": ['mw'],
    "priyākhyānadāna": ['mw'],
    "priyākhyānapuraḥsara": ['mw'],
    "priyākhyāyin": ['bhs', 'mw'],
    "priyākṛ": ['mw'],
    "priyāla": ['cae', 'ddsa', 'mw'],
    "priyālatālakharjūraharītakīvibhītaka": ['mw'],
    "priyālaḥ": ['ap90'],
    "priyālā": ['mw'],
    "priyālāpa": ['mw'],
    "priyālāpin": ['cae', 'ddsa', 'mw'],
    "priyāmbu": ['mw'],
    "priyāmukhībhū": ['mw'],
    "priyānna": ['bhs', 'mw'],
    "priyānnatva": ['mw'],
    "priyāpatya": ['mw'],
    "priyāpriya": ['cae', 'mw'],
    "priyāpāya": ['mw'],
    "priyārha": ['mw'],
    "priyārtham": ['mw'],
    "priyāsu": ['mw'],
    "priyāsūyamatī": ['mw'],
    "priyātithi": ['cae', 'mw'],
    "priyātmaja": ['mw'],
    "priyātmaka": ['mw'],
    "priyātman": ['mw'],
    "priyāvat": ['mw'],
    "priyāviraha": ['mw'],
    "priyāy": ['gra'],
    "priyāya": ['mw'],
    "priyāyati": ['bhs'],
    "priyīya": ['mw'],
    "pro": ['ddsa'],
    "probh": ['mw'],
    "proccais": ['ap90', 'cae', 'mw'],
    "proccal": ['mw'],
    "proccar": ['mw'],
    "proccaṃḍa": ['ap90'],
    "proccaṇḍa": ['ddsa', 'mw'],
    "procchal": ['mw'],
    "procchrita": ['ap90', 'mw'],
    "procchvas": ['mw'],
    "procchūna": ['ap90', 'mw'],
    "proccārita": ['ap90', 'mw'],
    "proccāṭanā": ['mw'],
    "prodaka": ['cae', 'ddsa', 'mw'],
    "prodakībhāva": ['mw'],
    "prodara": ['mw'],
    "prodbhinna": ['ap90', 'mw'],
    "prodbhūta": ['ap90', 'mw'],
    "prodbodha": ['mw'],
    "prodbodhaḥ": ['ap90'],
    "prodbuddha": ['mw'],
    "proddhā": ['mw'],
    "proddhāra": ['mw'],
    "proddhūṣita": ['mw'],
    "proddhṛ": ['mw'],
    "proddhṛṣita": ['mw'],
    "proddāma": ['mw'],
    "proddāṇḍa": ['mw'],
    "proddīpta": ['ap90', 'mw'],
    "prodgata": ['ap90', 'mw'],
    "prodghoṣaṇaṃ": ['ap90'],
    "prodghoṣaṇā": ['mw'],
    "prodghuṣ": ['ap90', 'mw'],
    "prodghuṣṭa": ['ap90', 'mw'],
    "prodgrīvam": ['mw'],
    "prodgārin": ['mw'],
    "prodgīrṇa": ['mw'],
    "prodgīta": ['mw'],
    "prodi": ['mw'],
    "prodita": ['mw'],
    "prodvah": ['mw'],
    "prodvigna": ['mw'],
    "prodvij": ['mw'],
    "prodvāha": ['mw'],
    "prodvāhaḥ": ['ap90'],
    "prodvīci": ['mw'],
    "prodyam": ['mw'],
    "prodyata": ['ap90', 'cae', 'mw'],
    "prodyatayaṣṭi": ['mw'],
    "prodyāyate": ['bhs'],
    "proghīya": ['mw'],
    "proh": ['mw'],
    "proha": ['ap90', 'mw'],
    "prohaṇa": ['mw'],
    "prohyapadi": ['mw'],
    "prohyapādi": ['mw'],
    "projjh": ['ap90', 'mw'],
    "projjhana": ['mw'],
    "projjhanaṃ": ['ap90'],
    "projjhita": ['ap90', 'mw'],
    "projjhya": ['mw'],
    "projjval": ['mw'],
    "projjāsana": ['mw'],
    "projjāsanaṃ": ['ap90'],
    "prokta": ['cae', 'ddsa', 'mw'],
    "proktakārin": ['mw'],
    "proktavat": ['mw'],
    "prokte": ['mw'],
    "prokṣ": ['ap90', 'mw'],
    "prokṣa": ['cae', 'mw'],
    "prokṣaṇa": ['cae', 'ddsa', 'mw'],
    "prokṣaṇavidhi": ['mw'],
    "prokṣaṇaṃ": ['ap90'],
    "prokṣaṇi": ['mw'],
    "prokṣaṇyāsādana": ['mw'],
    "prokṣaṇī": ['mw'],
    "prokṣaṇīdhānī": ['mw'],
    "prokṣaṇīpātra": ['mw'],
    "prokṣaṇīya": ['mw'],
    "prokṣaṇīyaṃ": ['ap90'],
    "prokṣita": ['ap90', 'mw'],
    "prokṣitavya": ['cae', 'mw'],
    "prollas": ['mw'],
    "prollaṅgh": ['mw'],
    "prollekhana": ['mw'],
    "prollekhanaṃ": ['ap90'],
    "prollikh": ['mw'],
    "prollola": ['mw'],
    "prollāghita": ['ap90', 'mw'],
    "prollāsin": ['mw'],
    "prollāsita": ['mw'],
    "prollīḍha": ['bhs'],
    "prombhaṇa": ['mw'],
    "prombhita": ['mw'],
    "pronmad": ['mw'],
    "pronmath": ['mw'],
    "pronmathyate": ['bhs'],
    "pronmāthin": ['mw'],
    "pronmīl": ['ap90', 'mw'],
    "pronmīlanaṃ": ['ap90'],
    "pronmūlita": ['bhs', 'mw'],
    "pronnad": ['mw'],
    "pronnam": ['mw'],
    "pronnamita": ['mw'],
    "pronnata": ['ap90', 'cae', 'mw'],
    "pronnī": ['mw'],
    "proraka": ['mw'],
    "prorṇu": ['mw'],
    "prorṇunaviṣu": ['mw'],
    "prorṇunāva": ['mw'],
    "prorṇunūṣu": ['mw'],
    "prorṇuvitṛ": ['mw'],
    "prota": ['ap90', 'cae', 'mw'],
    "protaghana": ['mw'],
    "protaya": ['mw'],
    "protayati": ['ap90'],
    "protaśūla": ['mw'],
    "proth": ['ap90', 'ddsa', 'mw'],
    "protha": ['ap90', 'cae', 'ddsa', 'mw'],
    "prothatha": ['cae', 'gra', 'mw'],
    "prothin": ['ap90', 'mw'],
    "proti": ['cae', 'mw'],
    "protkarṣaḥ": ['ap90'],
    "protkaṃṭha": ['ap90'],
    "protkaṇṭha": ['mw'],
    "protkaṇṭhaya": ['mw'],
    "protkaṭa": ['ap90', 'cae', 'mw'],
    "protkaṭabhṛtya": ['mw'],
    "protkhai": ['mw'],
    "protkhan": ['mw'],
    "protkhāta": ['mw'],
    "protkruṣṭa": ['mw'],
    "protkruṣṭaṃ": ['ap90'],
    "protkūj": ['mw'],
    "protkṣipta": ['mw'],
    "prototsādana": ['mw'],
    "protpad": ['mw'],
    "protpanna": ['mw'],
    "protpat": ['mw'],
    "protphala": ['mw'],
    "protphulla": ['ap90', 'cae', 'mw'],
    "protphullanayana": ['mw'],
    "protsad": ['mw'],
    "protsah": ['mw'],
    "protsikta": ['mw'],
    "protsādana": ['mw'],
    "protsāha": ['cae', 'mw'],
    "protsāhaka": ['mw'],
    "protsāhakaḥ": ['ap90'],
    "protsāhana": ['cae', 'mw'],
    "protsāhanaṃ": ['ap90'],
    "protsāhaḥ": ['ap90'],
    "protsāhita": ['mw'],
    "protsāraṇa": ['mw'],
    "protsāraṇaṃ": ['ap90'],
    "protsārita": ['ap90', 'mw'],
    "protsṛ": ['mw'],
    "protsṛj": ['mw'],
    "protsṛjati": ['bhs'],
    "protsṛp": ['mw'],
    "protthita": ['cae', 'mw'],
    "protthā": ['mw'],
    "prottuṃga": ['ap90'],
    "prottuṅga": ['cae', 'mw'],
    "prottāla": ['mw'],
    "prottāna": ['mw'],
    "prottṝ": ['mw'],
    "proñch": ['cae', 'mw'],
    "proñchana": ['cae', 'mw'],
    "proḍha": ['ap90'],
    "proḍham": ['mw'],
    "proḍhiḥ": ['ap90'],
    "proḍḍī": ['mw'],
    "proḍḍīna": ['ap90', 'mw'],
    "proṃchanaṃ": ['ap90'],
    "proṃṭhaḥ": ['ap90'],
    "proṇa": ['bhs'],
    "proṇṭha": ['mw'],
    "proṣa": ['cae', 'mw'],
    "proṣadha": ['mw'],
    "proṣaka": ['mw'],
    "proṣaḥ": ['ap90'],
    "proṣita": ['ap90', 'cae', 'mw'],
    "proṣitabhartṛkā": ['mw'],
    "proṣitamaraṇa": ['mw'],
    "proṣitatrāsa": ['mw'],
    "proṣitavat": ['mw'],
    "proṣuṣa": ['mw'],
    "proṣya": ['cae', 'mw'],
    "proṣyapāpīyas": ['mw'],
    "proṣṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "proṣṭa": ['bhs'],
    "proṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "proṣṭhapada": ['bhs', 'mw'],
    "proṣṭhapāda": ['mw'],
    "proṣṭhaḥ": ['ap90'],
    "proṣṭheśaya": ['gra', 'mw'],
    "proṣṭhika": ['mw'],
    "proṣṭhikā": ['mw'],
    "proṣṭhī": ['mw'],
    "proṣṭila": ['mw'],
    "pru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prukṣi": ['mw'],
    "prut": ['mw'],
    "pruth": ['cae', 'ddsa', 'gra', 'mw'],
    "pruṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pruṣita": ['ap90', 'mw'],
    "pruṣitapsu": ['cae', 'gra', 'mw'],
    "pruṣva": ['mw'],
    "pruṣvaḥ": ['ap90'],
    "pruṣvā": ['cae', 'ddsa', 'mw'],
    "pruṣvāya": ['mw'],
    "pruṣāy": ['gra'],
    "pruṣāya": ['ddsa'],
    "pruṣṭa": ['ap90', 'mw'],
    "pruṣṭā": ['mw'],
    "pruṣṭāyate": ['mw'],
    "prā": ['cae', 'ddsa', 'gra', 'mw'],
    "prābalya": ['cae', 'ddsa', 'mw'],
    "prābalyaṃ": ['ap90'],
    "prābandha": ['mw'],
    "prābandhika": ['bhs'],
    "prābhava": ['mw'],
    "prābhavatya": ['cae', 'ddsa', 'mw'],
    "prābhavatyaṃ": ['ap90'],
    "prābhavaṃ": ['ap90'],
    "prābhañjana": ['mw'],
    "prābhañjani": ['ddsa', 'mw'],
    "prābhaṃjanaṃ": ['ap90'],
    "prābhaṃjaniḥ": ['ap90'],
    "prābhiṇī": ['mw'],
    "prābhākara": ['cae', 'ddsa', 'mw'],
    "prābhākarakhaṇḍana": ['mw'],
    "prābhākaraḥ": ['ap90'],
    "prābhākari": ['mw'],
    "prābhāsika": ['mw'],
    "prābhātika": ['ap90', 'ddsa', 'mw'],
    "prābhāvya": ['bhs'],
    "prābhūtika": ['mw'],
    "prābhṛta": ['bhs', 'cae', 'ddsa', 'mw'],
    "prābhṛtaka": ['cae', 'mw'],
    "prābhṛtaṃ": ['ap90'],
    "prābhṛtīkṛ": ['mw'],
    "prābodhaka": ['mw'],
    "prābodhakaḥ": ['ap90'],
    "prābodhika": ['mw'],
    "prābādhikaḥ": ['ap90'],
    "prābālika": ['mw'],
    "prābālikaḥ": ['ap90'],
    "prāc": ['ap90', 'gra'],
    "prāca": ['gra'],
    "prācais": ['cae', 'mw'],
    "prācas": ['mw'],
    "prācaṃḍyaṃ": ['ap90'],
    "prācaṇḍya": ['cae', 'ddsa', 'mw'],
    "prācetas": ['mw'],
    "prācetasa": ['cae', 'ddsa', 'mw'],
    "prācetasastava": ['mw'],
    "prācetasaḥ": ['ap90'],
    "prāch": ['ap90', 'cae', 'ddsa', 'mw'],
    "prācikya": ['mw'],
    "prācikā": ['ap90', 'mw'],
    "prācinvat": ['mw'],
    "prācurya": ['cae', 'ddsa', 'mw'],
    "prācuryaṃ": ['ap90'],
    "prācuryeṇa": ['mw'],
    "prācya": ['ap90', 'cae', 'ddsa', 'mw'],
    "prācyabhāṣā": ['mw'],
    "prācyaka": ['ap90', 'mw'],
    "prācyakaṭha": ['mw'],
    "prācyapadavṛtti": ['mw'],
    "prācyapāñcālī": ['mw'],
    "prācyaratha": ['mw'],
    "prācyasaptasama": ['mw'],
    "prācyasāman": ['mw'],
    "prācyavāṭa": ['mw'],
    "prācyavṛtti": ['mw'],
    "prācyodañc": ['mw'],
    "prācyā": ['mw'],
    "prācyādhvaryu": ['mw'],
    "prācyāvantya": ['mw'],
    "prācyāyana": ['mw'],
    "prācā": ['ddsa', 'mw'],
    "prācājihva": ['gra', 'mw'],
    "prācāmanyu": ['gra', 'mw'],
    "prācāra": ['ddsa', 'mw'],
    "prācārya": ['ddsa', 'mw'],
    "prācī": ['ap90', 'ddsa', 'mw'],
    "prācīmūla": ['ddsa', 'mw'],
    "prācīna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prācīnabarhis": ['mw'],
    "prācīnagarbha": ['mw'],
    "prācīnagauḍa": ['mw'],
    "prācīnagrīva": ['mw'],
    "prācīnagāthā": ['mw'],
    "prācīnaharaṇa": ['mw'],
    "prācīnakalpa": ['mw'],
    "prācīnakarṇa": ['mw'],
    "prācīnakūla": ['mw'],
    "prācīnam": ['mw'],
    "prācīnamata": ['mw'],
    "prācīnamātrāvāsas": ['mw'],
    "prācīnamūla": ['mw'],
    "prācīnapakṣa": ['mw'],
    "prācīnapanasa": ['mw'],
    "prācīnaprajanana": ['mw'],
    "prācīnaprakriyā": ['mw'],
    "prācīnapravaṇa": ['mw'],
    "prācīnaprāgbhāra": ['mw'],
    "prācīnaraśmi": ['gra', 'mw'],
    "prācīnatilaka": ['mw'],
    "prācīnatva": ['mw'],
    "prācīnatā": ['mw'],
    "prācīnatāna": ['mw'],
    "prācīnavaṃśa": ['mw'],
    "prācīnavṛtti": ['mw'],
    "prācīnayoga": ['mw'],
    "prācīnayogya": ['mw'],
    "prācīnayogīputra": ['mw'],
    "prācīnaāvītin": ['mw'],
    "prācīnaśivastuti": ['mw'],
    "prācīnaśāla": ['mw'],
    "prācīnaśāli": ['mw'],
    "prācīnaṣaḍaśīti": ['mw'],
    "prācīnopavīta": ['mw'],
    "prācīnā": ['mw'],
    "prācīnāgra": ['mw'],
    "prācīnāmalaka": ['mw'],
    "prācīnāpavītin": ['mw'],
    "prācīnātāna": ['mw'],
    "prācīnāvavītin": ['mw'],
    "prācīnāvīta": ['cae', 'mw'],
    "prācīnāvītin": ['mw'],
    "prācīpati": ['mw'],
    "prācīpramāṇa": ['mw'],
    "prācīpratīcitas": ['mw'],
    "prācīra": ['ddsa', 'mw'],
    "prācīraṃ": ['ap90'],
    "prācīsarasvatīmāhātmya": ['mw'],
    "prād": ['mw'],
    "prādakṣiṇa": ['bhs'],
    "prādakṣiṇya": ['cae', 'ddsa', 'mw'],
    "prādakṣiṇyaṃ": ['ap90'],
    "prādeśa": ['ddsa', 'mw'],
    "prādeśamātra": ['mw'],
    "prādeśana": ['mw'],
    "prādeśanaṃ": ['ap90'],
    "prādeśapāda": ['mw'],
    "prādeśasama": ['mw'],
    "prādeśaḥ": ['ap90'],
    "prādeśika": ['ap90', 'bhs', 'ddsa', 'mw'],
    "prādeśin": ['ap90', 'ddsa', 'mw'],
    "prādeśinī": ['ap90', 'mw'],
    "prādeśya": ['bhs'],
    "prādeśāyāma": ['mw'],
    "prādhanika": ['ddsa', 'mw'],
    "prādhanikaṃ": ['ap90'],
    "prādheya": ['mw'],
    "prādhva": ['ap90', 'cae', 'ddsa', 'mw'],
    "prādhvam": ['cae', 'mw'],
    "prādhvana": ['cae', 'gra', 'mw'],
    "prādhvara": ['mw'],
    "prādhvaṃsana": ['mw'],
    "prādhyayana": ['mw'],
    "prādhyayanaṃ": ['ap90'],
    "prādhyeṣaṇa": ['mw'],
    "prādhā": ['mw'],
    "prādhānika": ['ap90', 'cae', 'ddsa', 'mw'],
    "prādhānya": ['cae', 'mw'],
    "prādhānyastuti": ['mw'],
    "prādhānyatas": ['mw'],
    "prādhānyaṃ": ['ap90'],
    "prādhānyena": ['mw'],
    "prādhānyāt": ['mw'],
    "prādhī": ['mw'],
    "prādhīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāditya": ['mw'],
    "prādohani": ['mw'],
    "prādoṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "prādoṣika": ['cae', 'mw'],
    "prādru": ['mw'],
    "prādukarma": ['bhs'],
    "prādur": ['ddsa', 'mw'],
    "prāduras": ['ap90'],
    "prādurbhāmi": ['bhs'],
    "prādurbhāva": ['cae', 'ddsa', 'mw'],
    "prādurbhāvaḥ": ['ap90'],
    "prādurbhū": ['ap90'],
    "prādurbhūta": ['ap90', 'mw'],
    "prādurākṣi": ['mw'],
    "prādus": ['ap90', 'cae'],
    "prāduṣ": ['mw'],
    "prāduṣkaraṇa": ['cae', 'ddsa', 'mw'],
    "prāduṣkaraṇaṃ": ['ap90'],
    "prāduṣkṛta": ['mw'],
    "prāduṣkṛtavapus": ['mw'],
    "prāduṣpīta": ['mw'],
    "prāduṣya": ['mw'],
    "prāduṣyaṃ": ['ap90'],
    "prādyoti": ['mw'],
    "prādyumni": ['mw'],
    "prādā": ['mw'],
    "prādānika": ['mw'],
    "prāg": ['mw'],
    "prāgabhihita": ['mw'],
    "prāgabhihitatva": ['mw'],
    "prāgabhāva": ['mw'],
    "prāgabhāvavicāra": ['mw'],
    "prāgabhāvavicārarahasya": ['mw'],
    "prāgabhāvavijñāna": ['mw'],
    "prāgabhāvavāda": ['mw'],
    "prāgabhāvojjīvana": ['mw'],
    "prāgadya": ['mw'],
    "prāgagra": ['cae', 'ddsa', 'mw'],
    "prāgagratā": ['mw'],
    "prāgahi": ['mw'],
    "prāgahīya": ['mw'],
    "prāgajita": ['bhs'],
    "prāgalbhya": ['mw'],
    "prāgalbhyabuddhi": ['mw'],
    "prāgalbhyavat": ['mw'],
    "prāgalbhyaṃ": ['ap90'],
    "prāgalbhī": ['cae', 'ddsa', 'mw'],
    "prāganurāga": ['cae', 'mw'],
    "prāganūka": ['mw'],
    "prāgapaccheda": ['mw'],
    "prāgapam": ['mw'],
    "prāgaparāyata": ['mw'],
    "prāgapavargam": ['mw'],
    "prāgavasthā": ['cae', 'ddsa', 'mw'],
    "prāgbhakta": ['bhs', 'mw'],
    "prāgbhava": ['mw'],
    "prāgbhāga": ['mw'],
    "prāgbhāra": ['bhs', 'cae', 'mw'],
    "prāgbhāva": ['mw'],
    "prāgbhāvatas": ['mw'],
    "prāgbhāvīya": ['mw'],
    "prāgbodhi": ['mw'],
    "prāgdaihika": ['mw'],
    "prāgdakṣiṇa": ['cae', 'mw'],
    "prāgdakṣiṇā": ['mw'],
    "prāgdakṣiṇāpravaṇa": ['mw'],
    "prāgdakṣiṇāñc": ['mw'],
    "prāgdaśa": ['mw'],
    "prāgdaṇḍa": ['mw'],
    "prāgdaṇḍam": ['mw'],
    "prāgdeśa": ['mw'],
    "prāgdhitīya": ['mw'],
    "prāgdiś": ['mw'],
    "prāgdiśīya": ['mw'],
    "prāgdvār": ['mw'],
    "prāgdvāra": ['mw'],
    "prāgdvārika": ['mw'],
    "prāgdīvyatīya": ['mw'],
    "prāgeva": ['bhs'],
    "prāggamanavant": ['cae'],
    "prāggamanavat": ['mw'],
    "prāggaṅgam": ['mw'],
    "prāgghitīya": ['mw'],
    "prāgghoma": ['mw'],
    "prāgghuta": ['mw'],
    "prāggranthi": ['mw'],
    "prāggrāmam": ['mw'],
    "prāggrīva": ['cae', 'mw'],
    "prāgguṇa": ['mw'],
    "prāggāmin": ['mw'],
    "prāggṅgam": ['ddsa'],
    "prāgharmasad": ['gra', 'mw'],
    "prāghoma": ['mw'],
    "prāghuṇa": ['cae', 'ddsa', 'mw'],
    "prāghuṇaka": ['cae', 'mw'],
    "prāghuṇaḥ": ['ap90'],
    "prāghuṇika": ['cae', 'mw'],
    "prāghāra": ['mw'],
    "prāghāraḥ": ['ap90'],
    "prāghāta": ['mw'],
    "prāghātaḥ": ['ap90'],
    "prāghūrṇa": ['cae', 'ddsa', 'mw'],
    "prāghūrṇaka": ['cae', 'mw'],
    "prāghūrṇika": ['cae', 'mw'],
    "prāghūrṇikā": ['mw'],
    "prāgivīya": ['mw'],
    "prāgjanmaka": ['mw'],
    "prāgjanman": ['cae', 'mw'],
    "prāgjyotiṣa": ['mw'],
    "prāgjyotiṣajyeṣṭha": ['mw'],
    "prāgjāta": ['cae', 'mw'],
    "prāgjāti": ['mw'],
    "prāglagna": ['mw'],
    "prāglajja": ['ddsa', 'mw'],
    "prāgra": ['cae', 'ddsa', 'mw'],
    "prāgrahara": ['mw'],
    "prāgrasara": ['mw'],
    "prāgraṃ": ['ap90'],
    "prāgrya": ['ap90', 'ddsa', 'mw'],
    "prāgrāṭa": ['mw'],
    "prāgrāṭaḥ": ['ap90'],
    "prāgrūpa": ['mw'],
    "prāgudagagra": ['mw'],
    "prāgudak": ['mw'],
    "prāgudakplava": ['mw'],
    "prāgudakplavana": ['mw'],
    "prāgudakpravaṇa": ['mw'],
    "prāgudañc": ['cae', 'mw'],
    "prāgudaṅmukha": ['mw'],
    "prāguddhārasaṃgraha": ['mw'],
    "prāgudīcī": ['mw'],
    "prāgukti": ['mw'],
    "prāgutpatti": ['mw'],
    "prāguttara": ['cae', 'ddsa', 'mw'],
    "prāguttaradigbhāga": ['mw'],
    "prāguttaradigvibhāga": ['mw'],
    "prāguttaratas": ['mw'],
    "prāguttareṇa": ['mw'],
    "prāguttarā": ['mw'],
    "prāguṇya": ['ddsa', 'mw'],
    "prāgvacana": ['mw'],
    "prāgvat": ['cae', 'mw'],
    "prāgvaṃsika": ['mw'],
    "prāgvaṃśa": ['mw'],
    "prāgvaṭa": ['mw'],
    "prāgveṣa": ['mw'],
    "prāgvideha": ['bhs'],
    "prāgvāta": ['mw'],
    "prāgvāṭakula": ['mw'],
    "prāgvṛtta": ['mw'],
    "prāgvṛtti": ['mw'],
    "prāgvṛttānta": ['mw'],
    "prāgāhnika": ['mw'],
    "prāgāhuti": ['mw'],
    "prāgāra": ['mw'],
    "prāgāraḥ": ['ap90'],
    "prāgātha": ['ddsa', 'mw'],
    "prāgāthaka": ['mw'],
    "prāgāthika": ['mw'],
    "prāgāyata": ['ddsa', 'mw'],
    "prāgāṅgam": ['mw'],
    "prāgītya": ['mw'],
    "prāgūḍhā": ['cae', 'mw'],
    "prāh": ['mw'],
    "prāha": ['mw'],
    "prāharika": ['ddsa', 'mw'],
    "prāhavanīya": ['bhs', 'mw'],
    "prāhaḥ": ['ap90'],
    "prāhaṇi": ['mw'],
    "prāhita": ['bhs'],
    "prāhla": ['ddsa'],
    "prāhlādanīya": ['mw'],
    "prāhrādi": ['mw'],
    "prāhuṇa": ['cae', 'ddsa', 'mw'],
    "prāhuṇaka": ['cae', 'mw'],
    "prāhuṇika": ['cae'],
    "prāhuṇikā": ['mw'],
    "prāhuṇī": ['mw'],
    "prāhārika": ['mw'],
    "prāhāṇika": ['bhs'],
    "prāhṇa": ['cae', 'mw'],
    "prāhṇam": ['mw'],
    "prāhṇaḥ": ['ap90'],
    "prāhṇe": ['mw'],
    "prāhṇetamām": ['mw'],
    "prāhṇetana": ['ap90', 'mw'],
    "prāhṇetarām": ['mw'],
    "prāhṇetarāṃ": ['ap90'],
    "prāhṛta": ['bhs'],
    "prāhṛtāyana": ['mw'],
    "prājahita": ['mw'],
    "prājahitaḥ": ['ap90'],
    "prājaka": ['cae', 'ddsa', 'mw'],
    "prājakaḥ": ['ap90'],
    "prājala": ['mw'],
    "prājana": ['mw'],
    "prājanaḥ": ['ap90'],
    "prājanin": ['mw'],
    "prājaruhā": ['mw'],
    "prājaryā": ['mw'],
    "prājeśa": ['mw'],
    "prājeśaṃ": ['ap90'],
    "prājeśvara": ['mw'],
    "prājidhara": ['ddsa', 'mw'],
    "prājika": ['cae', 'ddsa', 'mw'],
    "prājikaḥ": ['ap90'],
    "prājimaṭhikā": ['mw'],
    "prājin": ['mw'],
    "prājina": ['bhs'],
    "prājipakṣin": ['mw'],
    "prājitṛ": ['ap90', 'mw'],
    "prājya": ['ap90', 'cae', 'ddsa', 'mw'],
    "prājyabhaṭṭa": ['mw'],
    "prājyabhojya": ['mw'],
    "prājyabhuja": ['mw'],
    "prājyadakṣiṇa": ['mw'],
    "prājyakāma": ['cae', 'mw'],
    "prājyavikrama": ['mw'],
    "prājyavṛṣṭi": ['cae', 'mw'],
    "prājyendhanatṛṇa": ['mw'],
    "prājña": ['ap90', 'cae', 'ddsa', 'mw'],
    "prājñabhūtanātha": ['mw'],
    "prājñakathā": ['mw'],
    "prājñammānin": ['mw'],
    "prājñamāna": ['mw'],
    "prājñamānin": ['cae', 'mw'],
    "prājñatva": ['mw'],
    "prājñatā": ['mw'],
    "prājñavādika": ['mw'],
    "prājñaṃmānin": ['cae'],
    "prājñā": ['mw'],
    "prājñī": ['mw'],
    "prājāpata": ['ddsa', 'mw'],
    "prājāpatya": ['ap90', 'cae', 'mw'],
    "prājāpatyaka": ['mw'],
    "prājāpatyapradāyin": ['mw'],
    "prājāpatyasthalīpākaprayoga": ['mw'],
    "prājāpatyasthānapradāyin": ['mw'],
    "prājāpatyatva": ['mw'],
    "prājāpatyavrata": ['mw'],
    "prājāpatyeṣṭi": ['mw'],
    "prājāpatyā": ['mw'],
    "prājāpatī": ['mw'],
    "prājāvata": ['mw'],
    "prājīvika": ['bhs'],
    "prāk": ['ap90', 'cae', 'ddsa', 'mw'],
    "prākara": ['mw'],
    "prākaraṇika": ['ap90', 'ddsa', 'mw'],
    "prākarṣa": ['mw'],
    "prākarṣika": ['ap90', 'mw'],
    "prākaṣika": ['mw'],
    "prākaṣikaḥ": ['ap90'],
    "prākaṭa": ['bhs'],
    "prākaṭya": ['ddsa', 'mw'],
    "prākaṭyaṃ": ['ap90'],
    "prākcaraṇa": ['mw'],
    "prākchāya": ['cae', 'mw'],
    "prākciram": ['mw'],
    "prākharati": ['bhs'],
    "prākharya": ['ddsa', 'mw'],
    "prākharyaṃ": ['ap90'],
    "prākkalpa": ['mw'],
    "prākkarman": ['ddsa', 'mw'],
    "prākkevala": ['mw'],
    "prākkosala": ['mw'],
    "prākkośala": ['mw'],
    "prākkāla": ['mw'],
    "prākkālīna": ['mw'],
    "prākkūla": ['mw'],
    "prākkūlatā": ['mw'],
    "prākkṛta": ['mw'],
    "prākoṭaka": ['mw'],
    "prākpada": ['mw'],
    "prākpaścimāyata": ['mw'],
    "prākphala": ['mw'],
    "prākphalgunī": ['mw'],
    "prākphalgunībhava": ['mw'],
    "prākphālguna": ['mw'],
    "prākphālguneya": ['mw'],
    "prākphālgunī": ['mw'],
    "prākprahāna": ['mw'],
    "prākprastuta": ['cae', 'mw'],
    "prākpravaṇa": ['mw'],
    "prākprātarāśika": ['mw'],
    "prākpuṇyaprabhava": ['mw'],
    "prākpuṣpā": ['mw'],
    "prākramika": ['ddsa', 'mw'],
    "prāksamāsa": ['mw'],
    "prāksaumika": ['mw'],
    "prāksaṃdhyā": ['mw'],
    "prāksaṃstha": ['mw'],
    "prāksaṃsthatva": ['mw'],
    "prāksoma": ['mw'],
    "prāksrotas": ['mw'],
    "prāktana": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāktanajanman": ['mw'],
    "prāktanakarman": ['mw'],
    "prāktanaya": ['mw'],
    "prāktarām": ['mw'],
    "prāktas": ['cae', 'mw'],
    "prāktiryakpramāṇa": ['mw'],
    "prāktāt": ['cae', 'gra', 'mw'],
    "prāktūla": ['cae', 'mw'],
    "prāktūlatā": ['mw'],
    "prākāmya": ['ddsa', 'mw'],
    "prākāmyaṃ": ['ap90'],
    "prākāra": ['cae', 'ddsa', 'mw'],
    "prākārabhañjana": ['mw'],
    "prākāradharaṇī": ['mw'],
    "prākārakarṇa": ['mw'],
    "prākārakhaṇḍa": ['cae', 'mw'],
    "prākāramardi": ['mw'],
    "prākāramardin": ['mw'],
    "prākārastha": ['cae', 'mw'],
    "prākāraśeṣa": ['mw'],
    "prākāraḥ": ['ap90'],
    "prākāruka": ['mw'],
    "prākārāgra": ['mw'],
    "prākārīya": ['ap90', 'mw'],
    "prākāśa": ['ddsa', 'mw'],
    "prākāśaḥ": ['ap90'],
    "prākāśya": ['mw'],
    "prākāśyaṃ": ['ap90'],
    "prākśas": ['cae', 'ddsa', 'mw'],
    "prākśiras": ['mw'],
    "prākśirasa": ['mw'],
    "prākśiraska": ['mw'],
    "prākśliṣṭa": ['mw'],
    "prākśrotas": ['mw'],
    "prākśṛṅgavat": ['mw'],
    "prākṛ": ['mw'],
    "prākṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "prākṛtabhāṣin": ['cae', 'mw'],
    "prākṛtabhāṣākāvya": ['mw'],
    "prākṛtabhāṣāntaravidhāna": ['mw'],
    "prākṛtacandrikā": ['mw'],
    "prākṛtacchandaḥkośa": ['mw'],
    "prākṛtacchandaḥsūtra": ['mw'],
    "prākṛtacchandaṣṭīkā": ['mw'],
    "prākṛtadīpikā": ['mw'],
    "prākṛtajvara": ['mw'],
    "prākṛtaka": ['bhs'],
    "prākṛtakalpataru": ['mw'],
    "prākṛtakośa": ['mw'],
    "prākṛtakāmadhenu": ['mw'],
    "prākṛtalakṣaṇa": ['mw'],
    "prākṛtalaṅkeśvara": ['mw'],
    "prākṛtamanoramā": ['mw'],
    "prākṛtamañjarī": ['mw'],
    "prākṛtamaṇidīpikā": ['mw'],
    "prākṛtamitra": ['mw'],
    "prākṛtamānuṣa": ['mw'],
    "prākṛtanāmaliṅgānuśāsana": ['mw'],
    "prākṛtapañcīkaraṇa": ['mw'],
    "prākṛtapiṅgala": ['mw'],
    "prākṛtaprabodha": ['mw'],
    "prākṛtapradīpikā": ['mw'],
    "prākṛtaprakriyāvṛtti": ['mw'],
    "prākṛtaprakāśa": ['mw'],
    "prākṛtaprakāśabhāṣya": ['mw'],
    "prākṛtapralaya": ['mw'],
    "prākṛtapāda": ['mw'],
    "prākṛtarahasya": ['mw'],
    "prākṛtasaptati": ['mw'],
    "prākṛtasarvasva": ['mw'],
    "prākṛtasaṃjīvanī": ['mw'],
    "prākṛtasaṃskāra": ['mw'],
    "prākṛtasetu": ['mw'],
    "prākṛtasubhāṣitāvalī": ['mw'],
    "prākṛtasāhityaratnākara": ['mw'],
    "prākṛtasūtra": ['mw'],
    "prākṛtatva": ['mw'],
    "prākṛtavyākaraṇa": ['mw'],
    "prākṛtavyākaraṇavṛtti": ['mw'],
    "prākṛtaśāsana": ['mw'],
    "prākṛti": ['bhs'],
    "prākṛtika": ['ap90', 'ddsa', 'mw'],
    "prākṛtodāsīna": ['mw'],
    "prākṛtādhyāya": ['mw'],
    "prākṛtānanda": ['mw'],
    "prākṛtāri": ['mw'],
    "prākṛtāyana": ['mw'],
    "prākṛtāṣṭādhyāyī": ['mw'],
    "prākṣālana": ['mw'],
    "prālamba": ['cae', 'ddsa', 'mw'],
    "prālambaka": ['mw'],
    "prālambikā": ['cae', 'mw'],
    "prālaṃba": ['ap90'],
    "prālaṃbakaṃ": ['ap90'],
    "prālaṃbikā": ['ap90'],
    "prālepika": ['mw'],
    "prāleya": ['cae', 'ddsa', 'mw'],
    "prāleyabhūdhara": ['mw'],
    "prāleyaraśmi": ['mw'],
    "prāleyarocis": ['mw'],
    "prāleyavarṣa": ['mw'],
    "prāleyaśaila": ['mw'],
    "prāleyaṃ": ['ap90'],
    "prāleyādri": ['cae', 'mw'],
    "prāleyāṃśu": ['mw'],
    "prālkārīya": ['mw'],
    "prāmati": ['mw'],
    "prāmodaka": ['ap90'],
    "prāmodika": ['ap90', 'ddsa', 'mw'],
    "prāmodya": ['bhs', 'mw'],
    "prāmodyarāja": ['bhs'],
    "prāmudya": ['bhs'],
    "prāmukhya": ['bhs'],
    "prāmādika": ['ap90', 'ddsa', 'mw'],
    "prāmādikatva": ['mw'],
    "prāmādya": ['mw'],
    "prāmādyaṃ": ['ap90'],
    "prāmāṇika": ['ap90', 'bhs', 'ddsa', 'mw'],
    "prāmāṇikatva": ['mw'],
    "prāmāṇikavārttika": ['mw'],
    "prāmāṇya": ['cae', 'ddsa', 'mw'],
    "prāmāṇyavāda": ['mw'],
    "prāmāṇyavādakroḍa": ['mw'],
    "prāmāṇyavādarahasya": ['mw'],
    "prāmāṇyavādasaṃgraha": ['mw'],
    "prāmāṇyavādavicāra": ['mw'],
    "prāmāṇyavādaśiromaṇi": ['mw'],
    "prāmāṇyavādaṭīkā": ['mw'],
    "prāmāṇyavādin": ['mw'],
    "prāmāṇyavādārtha": ['mw'],
    "prāmāṇyaṃ": ['ap90'],
    "prāmītya": ['mw'],
    "prāmītyaṃ": ['ap90'],
    "prān": ['mw'],
    "prānopasparśana": ['mw'],
    "prānta": ['bhs', 'cae', 'ddsa', 'mw'],
    "prāntabhūmau": ['mw'],
    "prāntabhūmi": ['mw'],
    "prāntacara": ['mw'],
    "prāntadurga": ['mw'],
    "prāntaga": ['mw'],
    "prāntakoṭika": ['bhs'],
    "prāntanivāsin": ['mw'],
    "prāntapuṣpā": ['mw'],
    "prāntara": ['cae', 'ddsa', 'mw'],
    "prāntaraśūnya": ['mw'],
    "prāntastha": ['mw'],
    "prāntatas": ['mw'],
    "prāntavirasa": ['mw'],
    "prāntavṛti": ['cae', 'mw'],
    "prāntaśayanāsanabhakta": ['mw'],
    "prāntaśayyāsanika": ['bhs'],
    "prāntāyana": ['mw'],
    "prānāḍī": ['mw'],
    "prānūna": ['mw'],
    "prāp": ['ap90', 'mw'],
    "prāpa": ['ap90', 'mw'],
    "prāpadyate": ['bhs'],
    "prāpaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāpaya": ['mw'],
    "prāpayitṛ": ['mw'],
    "prāpaṇa": ['cae', 'mw'],
    "prāpaṇaṃ": ['ap90'],
    "prāpaṇika": ['ddsa', 'mw'],
    "prāpaṇikaḥ": ['ap90'],
    "prāpaṇikā": ['mw'],
    "prāpaṇīya": ['cae', 'ddsa', 'mw'],
    "prāpin": ['cae', 'mw'],
    "prāpipayiṣu": ['mw'],
    "prāpita": ['ap90', 'mw'],
    "prāpitatva": ['mw'],
    "prāpta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "prāptabhāra": ['mw'],
    "prāptabhāva": ['mw'],
    "prāptabuddhi": ['mw'],
    "prāptabīja": ['mw'],
    "prāptadoṣa": ['mw'],
    "prāptajīvana": ['cae', 'mw'],
    "prāptakarman": ['mw'],
    "prāptakarmatva": ['mw'],
    "prāptakrama": ['mw'],
    "prāptakāla": ['cae', 'mw'],
    "prāptakālam": ['mw'],
    "prāptakālatva": ['mw'],
    "prāptakālā": ['mw'],
    "prāptakārin": ['mw'],
    "prāptamanoratha": ['mw'],
    "prāptapañcatva": ['mw'],
    "prāptaprabhāva": ['cae', 'mw'],
    "prāptaprakāśaka": ['mw'],
    "prāptaprasavā": ['mw'],
    "prāptartu": ['mw'],
    "prāptarūpa": ['cae', 'mw'],
    "prāptasena": ['bhs'],
    "prāptasūrya": ['mw'],
    "prāptatva": ['mw'],
    "prāptavara": ['mw'],
    "prāptavat": ['mw'],
    "prāptavibhāṣā": ['mw'],
    "prāptavikalpa": ['mw'],
    "prāptavikalpatva": ['cae', 'mw'],
    "prāptavya": ['cae', 'ddsa', 'mw'],
    "prāptavyamartha": ['mw'],
    "prāptavyavahāra": ['mw'],
    "prāptayauvana": ['cae', 'mw'],
    "prāptayu": ['bhs'],
    "prāptaśrī": ['ddsa', 'mw'],
    "prāpti": ['cae', 'ddsa', 'mw'],
    "prāptikā": ['bhs'],
    "prāptimat": ['mw'],
    "prāptisama": ['mw'],
    "prāptiśaithilya": ['mw'],
    "prāptiḥ": ['ap90'],
    "prāptodaka": ['cae', 'ddsa', 'mw'],
    "prāptodaya": ['mw'],
    "prāptyāśā": ['ddsa', 'mw'],
    "prāptānujña": ['mw'],
    "prāptāparādha": ['cae', 'ddsa', 'mw'],
    "prāptārtha": ['cae', 'mw'],
    "prāptārthāgrahaṇa": ['mw'],
    "prāptāvasara": ['cae', 'mw'],
    "prāpuṇati": ['bhs'],
    "prāpya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "prāpyakārin": ['mw'],
    "prāpyakāritva": ['mw'],
    "prāpyarūpa": ['mw'],
    "prār": ['mw'],
    "prārabdha": ['ap90', 'cae', 'mw'],
    "prārabdhakarman": ['mw'],
    "prārabdhakārya": ['mw'],
    "prārabdhavat": ['mw'],
    "prārabdhi": ['mw'],
    "prārabdhiḥ": ['ap90'],
    "prārabh": ['ap90', 'mw'],
    "prārambha": ['cae', 'ddsa', 'mw'],
    "prārambhaṇa": ['mw'],
    "prārambhaṇīya": ['mw'],
    "prāraṃbhaḥ": ['ap90'],
    "prāraṃbhaṇaṃ": ['ap90'],
    "prāraṇya": ['bhs'],
    "prārc": ['mw'],
    "prārcchaka": ['mw'],
    "prārch": ['mw'],
    "prārd": ['mw'],
    "prārdaka": ['mw'],
    "prārdh": ['mw'],
    "prārdha": ['mw'],
    "prārdhate": ['bhs'],
    "prārh": ['mw'],
    "prāripsita": ['mw'],
    "prārj": ['mw'],
    "prārjayitṛ": ['mw'],
    "prārjuna": ['mw'],
    "prārkṣīya": ['mw'],
    "prāroha": ['cae', 'ddsa', 'mw'],
    "prārohaḥ": ['ap90'],
    "prārpaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "prārth": ['ap90', 'mw'],
    "prārtha": ['cae', 'ddsa', 'mw'],
    "prārthak": ['bhs'],
    "prārthaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "prārthana": ['cae', 'ddsa', 'mw'],
    "prārthanayā": ['mw'],
    "prārthanaṃ": ['ap90'],
    "prārthanā": ['bhs', 'mw'],
    "prārthanābhaṅga": ['mw'],
    "prārthanābhāva": ['mw'],
    "prārthanāduḥkhabhāj": ['mw'],
    "prārthanāpañcaka": ['mw'],
    "prārthanāsiddhi": ['mw'],
    "prārthanāśataka": ['mw'],
    "prārthanīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "prārthayitavya": ['cae', 'mw'],
    "prārthayitṛ": ['ap90', 'cae', 'mw'],
    "prārthin": ['ap90', 'cae', 'mw'],
    "prārthita": ['ap90', 'cae', 'mw'],
    "prārthitadurlabha": ['mw'],
    "prārthitavat": ['mw'],
    "prārthya": ['cae', 'mw'],
    "prāruh": ['mw'],
    "prārñj": ['mw'],
    "prārṇa": ['mw'],
    "prārṇaṃ": ['ap90'],
    "prārṣ": ['mw'],
    "prārṣabhīya": ['mw'],
    "prās": ['ap90', 'mw'],
    "prāsa": ['bhs', 'cae', 'ddsa', 'mw'],
    "prāsabhārata": ['mw'],
    "prāsaca": ['mw'],
    "prāsah": ['ddsa', 'gra', 'mw'],
    "prāsaha": ['cae', 'mw'],
    "prāsahā": ['mw'],
    "prāsahāt": ['mw'],
    "prāsaka": ['mw'],
    "prāsakaḥ": ['ap90'],
    "prāsana": ['mw'],
    "prāsanaṃ": ['ap90'],
    "prāsarpaka": ['mw'],
    "prāsaḥ": ['ap90'],
    "prāsaṃgaḥ": ['ap90'],
    "prāsaṃgika": ['ap90'],
    "prāsaṃgyaḥ": ['ap90'],
    "prāsaṅga": ['mw'],
    "prāsaṅgavāhīvah": ['mw'],
    "prāsaṅgavāhīvāh": ['mw'],
    "prāsaṅgika": ['cae', 'ddsa', 'mw'],
    "prāsaṅgya": ['mw'],
    "prāsenajitī": ['mw'],
    "prāseva": ['mw'],
    "prāsika": ['ap90', 'bhs', 'mw'],
    "prāskaṇva": ['mw'],
    "prāsravaṇa": ['ap90', 'mw'],
    "prāsta": ['ap90', 'mw'],
    "prāsthika": ['ap90', 'ddsa', 'mw'],
    "prāsthānika": ['ap90', 'mw'],
    "prāstutya": ['mw'],
    "prāstutyaṃ": ['ap90'],
    "prāstārika": ['mw'],
    "prāstāvi": ['mw'],
    "prāstāvika": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāsuka": ['ddsa'],
    "prāsāda": ['cae', 'ddsa', 'mw'],
    "prāsādadīpikā": ['mw'],
    "prāsādagarbha": ['cae', 'mw'],
    "prāsādagata": ['mw'],
    "prāsādaka": ['bhs'],
    "prāsādakalpa": ['mw'],
    "prāsādakukkuṭa": ['mw'],
    "prāsādalakṣaṇa": ['mw'],
    "prāsādamaṇḍanā": ['mw'],
    "prāsādaparāmantra": ['mw'],
    "prāsādaprastara": ['mw'],
    "prāsādapratiṣṭhā": ['mw'],
    "prāsādapratiṣṭhādīdhiti": ['mw'],
    "prāsādapṛṣṭha": ['cae', 'mw'],
    "prāsādastha": ['mw'],
    "prāsādatala": ['mw'],
    "prāsādavāsin": ['mw'],
    "prāsādaśāyin": ['mw'],
    "prāsādaśṛṅga": ['mw'],
    "prāsādaḥ": ['ap90'],
    "prāsādika": ['ap90', 'bhs', 'ddsa', 'mw'],
    "prāsādikā": ['ddsa', 'mw'],
    "prāsādivārika": ['bhs', 'mw'],
    "prāsādya": ['mw'],
    "prāsādāgra": ['cae', 'mw'],
    "prāsādāgrya": ['mw'],
    "prāsādālaṃkāralakṣaṇa": ['mw'],
    "prāsādānukīrtana": ['mw'],
    "prāsādārohaṇa": ['mw'],
    "prāsādārohaṇīya": ['mw'],
    "prāsādāṅgana": ['mw'],
    "prāsādīya": ['ap90', 'mw'],
    "prāsādīyati": ['ap90'],
    "prāsāha": ['mw'],
    "prāsūtika": ['ap90', 'mw'],
    "prāta": ['mw'],
    "prātar": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prātara": ['mw'],
    "prātarabhivāda": ['cae', 'mw'],
    "prātaradhyeya": ['ddsa', 'mw'],
    "prātaragnihotrakālātikramaprāyaścitta": ['mw'],
    "prātarahna": ['mw'],
    "prātarahṇa": ['cae'],
    "prātaranta": ['mw'],
    "prātaranuvāka": ['mw'],
    "prātarapavarga": ['mw'],
    "prātaraupāsanaprayoga": ['mw'],
    "prātaravanega": ['mw'],
    "prātaraśana": ['cae', 'mw'],
    "prātarbhojana": ['mw'],
    "prātarbhoktṛ": ['mw'],
    "prātardana": ['mw'],
    "prātardani": ['gra'],
    "prātardina": ['mw'],
    "prātardoha": ['mw'],
    "prātardugdha": ['mw'],
    "prātargeya": ['mw'],
    "prātarhoma": ['mw'],
    "prātarhomaprayoga": ['mw'],
    "prātarhomavidhi": ['mw'],
    "prātarhuta": ['mw'],
    "prātaritvan": ['ddsa', 'gra', 'mw'],
    "prātarjapa": ['ddsa', 'mw'],
    "prātarjit": ['gra', 'mw'],
    "prātarmantra": ['mw'],
    "prātarmādhyaṃdinasavana": ['mw'],
    "prātarupasthāna": ['mw'],
    "prātarvastṛ": ['mw'],
    "prātarveṣa": ['mw'],
    "prātarvikasvara": ['mw'],
    "prātaryajña": ['cae', 'mw'],
    "prātaryuj": ['gra', 'mw'],
    "prātaryukta": ['cae', 'mw'],
    "prātaryāvan": ['gra', 'mw'],
    "prātarāhuti": ['cae', 'mw'],
    "prātarāśa": ['cae', 'mw'],
    "prātarāśika": ['bhs'],
    "prātarāśita": ['mw'],
    "prātarṇādin": ['mw'],
    "prātas": ['mw'],
    "prātastana": ['ap90', 'cae', 'ddsa', 'mw'],
    "prātastarām": ['mw'],
    "prātastarāṃ": ['ap90'],
    "prātastrivargā": ['mw'],
    "prātastya": ['ap90', 'cae', 'mw'],
    "prātaś": ['mw'],
    "prātaścandra": ['cae', 'mw'],
    "prātaścandradyuti": ['mw'],
    "prātaḥ": ['mw'],
    "prātaḥkalpa": ['ddsa', 'mw'],
    "prātaḥkāla": ['mw'],
    "prātaḥkālavaktavya": ['mw'],
    "prātaḥkārya": ['cae', 'mw'],
    "prātaḥkṛtya": ['cae', 'mw'],
    "prātaḥkṣaṇa": ['mw'],
    "prātaḥpaddhati": ['mw'],
    "prātaḥprahara": ['mw'],
    "prātaḥsandhyā": ['ddsa'],
    "prātaḥsava": ['cae', 'mw'],
    "prātaḥsavana": ['mw'],
    "prātaḥsavanika": ['mw'],
    "prātaḥsavanikadarśapūrṇamāsaprayoga": ['mw'],
    "prātaḥsavanīya": ['mw'],
    "prātaḥsaṃdhyā": ['cae', 'mw'],
    "prātaḥsaṃdhyāprayoga": ['mw'],
    "prātaḥsaṃdhyāvandana": ['mw'],
    "prātaḥsaṃdhyāvandanavidhi": ['mw'],
    "prātaḥsmaraṇa": ['mw'],
    "prātaḥsmaraṇastotra": ['mw'],
    "prātaḥsmaraṇaśloka": ['mw'],
    "prātaḥsmaraṇāṣṭaka": ['mw'],
    "prātaḥsmaraṇīya": ['mw'],
    "prātaḥsnāna": ['mw'],
    "prātaḥsnānavidhi": ['mw'],
    "prātaḥsnāyin": ['mw'],
    "prātaḥsāva": ['gra', 'mw'],
    "prātaṃ": ['bhs'],
    "prāthamakalpika": ['bhs', 'cae', 'ddsa', 'mw'],
    "prāthamakalpikaḥ": ['ap90'],
    "prāthamika": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāthamya": ['cae', 'mw'],
    "prāthamyaṃ": ['ap90'],
    "prāthujjanika": ['bhs'],
    "prāti": ['mw'],
    "prātibha": ['ap90', 'mw'],
    "prātibhavat": ['mw'],
    "prātibhaṭya": ['mw'],
    "prātibhā": ['mw'],
    "prātibhānika": ['bhs'],
    "prātibhāsika": ['ap90', 'mw'],
    "prātibhāvya": ['cae', 'mw'],
    "prātibhāvyaṃ": ['ap90'],
    "prātibodha": ['mw'],
    "prātibodhāyana": ['mw'],
    "prātibodhīputra": ['mw'],
    "prāticāraka": ['bhs'],
    "prātidaivasika": ['ap90', 'mw'],
    "prātihantra": ['mw'],
    "prātihartra": ['mw'],
    "prātihata": ['mw'],
    "prātihaṃtraṃ": ['ap90'],
    "prātihāra": ['mw'],
    "prātihāraka": ['mw'],
    "prātihārakapakṣa": ['bhs'],
    "prātihārapakṣa": ['bhs'],
    "prātihāraḥ": ['ap90'],
    "prātihārika": ['bhs', 'mw'],
    "prātihārya": ['bhs', 'mw'],
    "prātihāryaka": ['bhs'],
    "prātihāryasaṃdarśana": ['mw'],
    "prātihāryasūtra": ['bhs'],
    "prātihāryaṃ": ['ap90'],
    "prātijanīna": ['ap90', 'mw'],
    "prātijña": ['mw'],
    "prātijñaṃ": ['ap90'],
    "prātikaṇṭhika": ['mw'],
    "prātikya": ['mw'],
    "prātikā": ['ap90', 'mw'],
    "prātikāmin": ['ddsa', 'mw'],
    "prātikūlika": ['ap90', 'cae', 'mw'],
    "prātikūlikatā": ['mw'],
    "prātikūlya": ['mw'],
    "prātikūlyaṃ": ['ap90'],
    "prātikṣepika": ['bhs', 'mw'],
    "prātilambhika": ['bhs', 'mw'],
    "prātilomika": ['ap90', 'mw'],
    "prātilomya": ['cae', 'mw'],
    "prātilomyaṃ": ['ap90'],
    "prātimokṣa": ['bhs', 'mw'],
    "prātinidhika": ['mw'],
    "prātipada": ['ap90', 'mw'],
    "prātipadika": ['ap90', 'cae', 'mw'],
    "prātipadikasaṃjñāvāda": ['mw'],
    "prātipadikatva": ['mw'],
    "prātipadikānurodhāt": ['mw'],
    "prātipakṣa": ['ap90', 'mw'],
    "prātipakṣika": ['bhs'],
    "prātipakṣya": ['mw'],
    "prātipakṣyaṃ": ['ap90'],
    "prātipathika": ['bhs', 'mw'],
    "prātipaudgalika": ['bhs'],
    "prātipauruṣika": ['ap90', 'mw'],
    "prātipeya": ['mw'],
    "prātipāna": ['mw'],
    "prātipīya": ['mw'],
    "prātirūpika": ['mw'],
    "prātirūpya": ['mw'],
    "prātisatvanam": ['mw'],
    "prātisvika": ['ap90', 'mw'],
    "prātisīma": ['bhs', 'mw'],
    "prātisīmaka": ['bhs'],
    "prātisīmantika": ['bhs'],
    "prātitheyī": ['mw'],
    "prātiveśaka": ['bhs'],
    "prātiveśika": ['cae', 'mw'],
    "prātiveśikaḥ": ['ap90'],
    "prātiveśmaka": ['mw'],
    "prātiveśmika": ['cae', 'mw'],
    "prātiveśmikī": ['mw'],
    "prātiveśya": ['cae', 'mw'],
    "prātiveśyaka": ['mw'],
    "prātiveśyaḥ": ['ap90'],
    "prātiśravasa": ['mw'],
    "prātiśrutka": ['cae', 'mw'],
    "prātiśākhya": ['cae', 'mw'],
    "prātiśākhyabhāṣya": ['mw'],
    "prātiśākhyakṛt": ['mw'],
    "prātiśākhyaṃ": ['ap90'],
    "prātiḥ": ['ap90'],
    "prātiṣṭhita": ['mw'],
    "prātuda": ['mw'],
    "prāty": ['mw'],
    "prātyagrathi": ['mw'],
    "prātyahika": ['ap90', 'ddsa', 'mw'],
    "prātyakṣa": ['mw'],
    "prātyakṣika": ['cae', 'ddsa', 'mw'],
    "prātyantika": ['ddsa', 'mw'],
    "prātyavekṣā": ['mw'],
    "prātyayika": ['ap90', 'ddsa', 'mw'],
    "prātyaṃtikaḥ": ['ap90'],
    "prātyāya": ['bhs'],
    "prātībodhīputra": ['mw'],
    "prātīpa": ['ddsa', 'mw'],
    "prātīpaḥ": ['ap90'],
    "prātīpika": ['ap90', 'mw'],
    "prātīpya": ['ddsa', 'mw'],
    "prātītheyī": ['mw'],
    "prātītika": ['ap90', 'ddsa', 'mw'],
    "prātṛda": ['mw'],
    "prāv": ['mw'],
    "prāvacana": ['bhs', 'ddsa', 'mw'],
    "prāvacanika": ['mw'],
    "prāvahaṇi": ['mw'],
    "prāvan": ['gra', 'mw'],
    "prāvanij": ['mw'],
    "prāvara": ['mw'],
    "prāvaraka": ['mw'],
    "prāvarakā": ['bhs'],
    "prāvarati": ['bhs'],
    "prāvaraḥ": ['ap90'],
    "prāvaraṇa": ['cae', 'ddsa', 'mw'],
    "prāvaraṇaṃ": ['ap90'],
    "prāvaraṇīya": ['mw'],
    "prāvaraṇīyaṃ": ['ap90'],
    "prāvareya": ['mw'],
    "prāvarga": ['cae', 'gra', 'mw'],
    "prāvartaka": ['mw'],
    "prāvarṣin": ['ddsa', 'mw'],
    "prāvaso": ['mw'],
    "prāvaṇa": ['gra', 'mw'],
    "prāvaṇaṃ": ['ap90'],
    "prāvaṇi": ['mw'],
    "prāvaṇya": ['bhs'],
    "prāvaṭa": ['mw'],
    "prāvaṭaḥ": ['ap90'],
    "prāvepa": ['cae', 'ddsa', 'gra', 'mw'],
    "prāveśana": ['ap90', 'mw'],
    "prāveśika": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāveśya": ['mw'],
    "prāveṇya": ['mw'],
    "prāveṇyaṃ": ['ap90'],
    "prāvitra": ['cae', 'mw'],
    "prāvitṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "prāvivekya": ['bhs'],
    "prāviś": ['mw'],
    "prāviṣkaraṇa": ['bhs'],
    "prāviṣkaroti": ['bhs'],
    "prāviṣkriyamāṇa": ['mw'],
    "prāvrajyaṃ": ['ap90'],
    "prāvrājya": ['mw'],
    "prāvuvūrṣu": ['mw'],
    "prāvāduka": ['ddsa', 'mw'],
    "prāvāhaṇeya": ['mw'],
    "prāvāhaṇeyaka": ['mw'],
    "prāvāhaṇeyi": ['mw'],
    "prāvāhaṇi": ['mw'],
    "prāvālika": ['ddsa', 'mw'],
    "prāvālikaḥ": ['ap90'],
    "prāvāra": ['cae', 'ddsa', 'mw'],
    "prāvāraka": ['bhs', 'cae'],
    "prāvārakarṇa": ['mw'],
    "prāvārakaḥ": ['ap90'],
    "prāvārakīṭa": ['mw'],
    "prāvāraḥ": ['ap90'],
    "prāvārika": ['ddsa', 'mw'],
    "prāvārikaḥ": ['ap90'],
    "prāvārīya": ['mw'],
    "prāvāsa": ['ap90', 'mw'],
    "prāvāsika": ['ap90', 'mw'],
    "prāvī": ['cae', 'gra', 'mw'],
    "prāvīṇya": ['cae', 'mw'],
    "prāvīṇyam": ['ddsa'],
    "prāvīṇyaṃ": ['ap90'],
    "prāvṛ": ['ap90', 'mw'],
    "prāvṛt": ['mw'],
    "prāvṛta": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "prāvṛti": ['bhs', 'mw'],
    "prāvṛtiḥ": ['ap90'],
    "prāvṛttika": ['ap90', 'mw'],
    "prāvṛtā": ['mw'],
    "prāvṛḍ": ['mw'],
    "prāvṛḍatyaya": ['mw'],
    "prāvṛṇ": ['mw'],
    "prāvṛṇmaya": ['ddsa', 'mw'],
    "prāvṛṇmegha": ['cae'],
    "prāvṛṇoti": ['bhs'],
    "prāvṛṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prāvṛṣa": ['cae', 'mw'],
    "prāvṛṣaḥ": ['ap90'],
    "prāvṛṣeya": ['mw'],
    "prāvṛṣeṇya": ['ap90', 'cae', 'mw'],
    "prāvṛṣeṇyā": ['mw'],
    "prāvṛṣija": ['ap90', 'mw'],
    "prāvṛṣika": ['ap90', 'cae', 'mw'],
    "prāvṛṣya": ['mw'],
    "prāvṛṣyaḥ": ['ap90'],
    "prāvṛṣā": ['mw'],
    "prāvṛṣāyaṇī": ['mw'],
    "prāvṛṣīṇa": ['cae', 'gra', 'mw'],
    "prāvṛṭ": ['mw'],
    "prāvṛṭkāla": ['cae', 'ddsa', 'mw'],
    "prāvṛṭkālavaha": ['mw'],
    "prāya": ['cae', 'ddsa', 'gra', 'mw'],
    "prāyabhava": ['mw'],
    "prāyacitta": ['mw'],
    "prāyacitti": ['mw'],
    "prāyadarśana": ['ddsa', 'mw'],
    "prāyagata": ['mw'],
    "prāyam": ['mw'],
    "prāyas": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāyasya": ['mw'],
    "prāyatya": ['cae', 'ddsa', 'mw'],
    "prāyatyaṃ": ['ap90'],
    "prāyatā": ['mw'],
    "prāyavidhāyin": ['mw'],
    "prāyaś": ['mw'],
    "prāyaśas": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāyaścetana": ['mw'],
    "prāyaścitta": ['cae', 'ddsa', 'mw'],
    "prāyaścittabhāṣya": ['mw'],
    "prāyaścittacandrikā": ['mw'],
    "prāyaścittacintāmaṇi": ['mw'],
    "prāyaścittadīpikā": ['mw'],
    "prāyaścittagrantha": ['mw'],
    "prāyaścittahemādri": ['mw'],
    "prāyaścittakadamba": ['mw'],
    "prāyaścittakalpataru": ['mw'],
    "prāyaścittakamalākara": ['mw'],
    "prāyaścittakaumudī": ['mw'],
    "prāyaścittakautūhala": ['mw'],
    "prāyaścittakhaṇḍa": ['mw'],
    "prāyaścittakrama": ['mw'],
    "prāyaścittakārikā": ['mw'],
    "prāyaścittakāṇḍa": ['mw'],
    "prāyaścittamanohara": ['mw'],
    "prāyaścittamayūkha": ['mw'],
    "prāyaścittamañjarī": ['mw'],
    "prāyaścittamuktāvalī": ['mw'],
    "prāyaścittamuktāvalīprakāśa": ['mw'],
    "prāyaścittamādhavīya": ['mw'],
    "prāyaścittamārtaṇḍa": ['mw'],
    "prāyaścittanirūpaṇa": ['mw'],
    "prāyaścittanirṇaya": ['mw'],
    "prāyaścittapaddhati": ['mw'],
    "prāyaścittaparāśara": ['mw'],
    "prāyaścittapradīpa": ['mw'],
    "prāyaścittapradīpikā": ['mw'],
    "prāyaścittaprakaraṇa": ['mw'],
    "prāyaścittaprakāśa": ['mw'],
    "prāyaścittapratyāmnāya": ['mw'],
    "prāyaścittaprayoga": ['mw'],
    "prāyaścittapārijāta": ['mw'],
    "prāyaścittarahasya": ['mw'],
    "prāyaścittaratna": ['mw'],
    "prāyaścittaratnamālā": ['mw'],
    "prāyaścittasamuccaya": ['mw'],
    "prāyaścittasaṃgraha": ['mw'],
    "prāyaścittasaṃkalpa": ['mw'],
    "prāyaścittasetu": ['mw'],
    "prāyaścittasthāna": ['mw'],
    "prāyaścittasubodhinī": ['mw'],
    "prāyaścittasudhānidhi": ['mw'],
    "prāyaścittasāra": ['mw'],
    "prāyaścittasārakaumudī": ['mw'],
    "prāyaścittasārasaṃgraha": ['mw'],
    "prāyaścittasārāvali": ['mw'],
    "prāyaścittasūtra": ['mw'],
    "prāyaścittataraṃga": ['mw'],
    "prāyaścittatattva": ['mw'],
    "prāyaścittaughasāra": ['mw'],
    "prāyaścittavidhi": ['mw'],
    "prāyaścittavidhāna": ['mw'],
    "prāyaścittavinirṇaya": ['mw'],
    "prāyaścittaviveka": ['mw'],
    "prāyaścittavivekoddyota": ['mw'],
    "prāyaścittavyavasthāsaṃkṣepa": ['mw'],
    "prāyaścittavāridhi": ['mw'],
    "prāyaścittaśakti": ['mw'],
    "prāyaścittaśatadvayī": ['mw'],
    "prāyaścittaśatadvayīśatadvayīprāyaścitta": ['mw'],
    "prāyaścittaśekhara": ['mw'],
    "prāyaścittaśrautasūtra": ['mw'],
    "prāyaścittaṃ": ['ap90'],
    "prāyaścittenduśekhara": ['mw'],
    "prāyaścittenduśekharasārasaṃgraha": ['mw'],
    "prāyaścitteṣṭi": ['mw'],
    "prāyaścitteṣṭicandrikā": ['mw'],
    "prāyaścitti": ['mw'],
    "prāyaścittika": ['ap90', 'bhs', 'mw'],
    "prāyaścittimat": ['mw'],
    "prāyaścittin": ['ap90', 'mw'],
    "prāyaścittoddyota": ['mw'],
    "prāyaścittādhikāra": ['mw'],
    "prāyaścittādhyāya": ['mw'],
    "prāyaścittādhyāyabhāṣya": ['mw'],
    "prāyaścittādigodāna": ['mw'],
    "prāyaścittādisaṃgraha": ['mw'],
    "prāyaścittāhuti": ['mw'],
    "prāyaścittāparārka": ['mw'],
    "prāyaścittāṇḍabilā": ['mw'],
    "prāyaścittīy": ['cae'],
    "prāyaścittīya": ['mw'],
    "prāyaścittīyatā": ['cae', 'mw'],
    "prāyaścitīya": ['ap90'],
    "prāyaḥ": ['ap90'],
    "prāyaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "prāyaṇatas": ['mw'],
    "prāyaṇaṃ": ['ap90'],
    "prāyaṇānta": ['mw'],
    "prāyaṇāntam": ['mw'],
    "prāyaṇīya": ['ap90', 'ddsa', 'mw'],
    "prāyaṇīyatva": ['mw'],
    "prāyaṇīyā": ['mw'],
    "prāyaṇīyāvat": ['mw'],
    "prāyeṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāyika": ['ap90', 'ddsa', 'mw'],
    "prāyikatva": ['mw'],
    "prāyo": ['mw'],
    "prāyobhāvin": ['ddsa', 'mw'],
    "prāyodevatā": ['mw'],
    "prāyoga": ['gra', 'mw'],
    "prāyogi": ['mw'],
    "prāyogika": ['ap90', 'ddsa', 'mw'],
    "prāyojya": ['ddsa', 'mw'],
    "prāyoktra": ['ddsa', 'mw'],
    "prāyopagamana": ['cae', 'ddsa', 'mw'],
    "prāyopaveśa": ['mw'],
    "prāyopaveśana": ['cae', 'mw'],
    "prāyopaveśanikā": ['mw'],
    "prāyopaveśin": ['mw'],
    "prāyopaviṣṭa": ['mw'],
    "prāyopayogika": ['mw'],
    "prāyopeta": ['mw'],
    "prāyovāda": ['mw'],
    "prāyu": ['gra', 'mw'],
    "prāyuddheṣin": ['ap90', 'mw'],
    "prāyudh": ['mw'],
    "prāyus": ['cae', 'gra', 'mw'],
    "prāyā": ['mw'],
    "prāyāsa": ['ddsa', 'mw'],
    "prāyātrika": ['mw'],
    "prāyāṇika": ['ap90', 'ddsa', 'mw'],
    "prāñc": ['cae', 'ddsa', 'mw'],
    "prāñjala": ['cae', 'ddsa', 'mw'],
    "prāñjalatā": ['mw'],
    "prāñjali": ['cae', 'mw'],
    "prāñjalika": ['mw'],
    "prāñjalin": ['mw'],
    "prāñjalipragraha": ['mw'],
    "prāñjalisthita": ['mw'],
    "prāñjalībhū": ['mw'],
    "prāñjalīka": ['bhs'],
    "prāñjalīkṛta": ['bhs'],
    "prāñjana": ['mw'],
    "prāñjayati": ['bhs'],
    "prāś": ['ap90', 'cae', 'gra', 'mw'],
    "prāśa": ['cae', 'ddsa', 'mw'],
    "prāśaka": ['mw'],
    "prāśakaḥ": ['ap90'],
    "prāśana": ['cae', 'mw'],
    "prāśanaṃ": ['ap90'],
    "prāśanin": ['mw'],
    "prāśanārthīya": ['mw'],
    "prāśanī": ['mw'],
    "prāśanīya": ['ap90', 'mw'],
    "prāśastya": ['cae', 'ddsa', 'mw'],
    "prāśastyaṃ": ['ap90'],
    "prāśavia": ['gra'],
    "prāśavya": ['gra', 'mw'],
    "prāśaḥ": ['ap90'],
    "prāśaṃsya": ['bhs'],
    "prāśin": ['mw'],
    "prāśita": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāśitavya": ['cae', 'mw'],
    "prāśitra": ['cae', 'ddsa', 'mw'],
    "prāśitraharaṇa": ['mw'],
    "prāśitravat": ['mw'],
    "prāśitraṃ": ['ap90'],
    "prāśitriya": ['mw'],
    "prāśitṛ": ['cae', 'mw'],
    "prāśliṣṭa": ['mw'],
    "prāśnika": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāśnīputra": ['mw'],
    "prāśravaṇa": ['mw'],
    "prāśu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prāśuṣah": ['gra', 'mw'],
    "prāśvamedha": ['ddsa', 'mw'],
    "prāśvas": ['mw'],
    "prāśya": ['mw'],
    "prāśā": ['cae', 'mw'],
    "prāśālika": ['bhs'],
    "prāśāstra": ['mw'],
    "prāśāstraṃ": ['ap90'],
    "prāśātika": ['mw'],
    "prāśū": ['gra', 'mw'],
    "prāśṛṅga": ['mw'],
    "prāḍvivāka": ['cae', 'ddsa', 'mw'],
    "prāḍāhati": ['mw'],
    "prāṃganaṃ": ['ap90'],
    "prāṃgaṃ": ['ap90'],
    "prāṃgaṇaṃ": ['ap90'],
    "prāṃjala": ['ap90'],
    "prāṃjali": ['ap90'],
    "prāṃjalika": ['ap90'],
    "prāṃtaraṃ": ['ap90'],
    "prāṃtataḥ": ['ap90'],
    "prāṃtaḥ": ['ap90'],
    "prāṃśu": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāṃśuka": ['mw'],
    "prāṃśulabhya": ['mw'],
    "prāṃśuprākāra": ['mw'],
    "prāṃśutā": ['mw'],
    "prāṅ": ['cae', 'ddsa', 'mw'],
    "prāṅga": ['mw'],
    "prāṅgana": ['cae'],
    "prāṅgaṇa": ['cae', 'ddsa', 'mw'],
    "prāṅmukha": ['cae', 'mw'],
    "prāṅmukhakaraṇa": ['mw'],
    "prāṅmukham": ['mw'],
    "prāṅmukhatva": ['mw'],
    "prāṅnayana": ['mw'],
    "prāṅnyāya": ['mw'],
    "prāṅnyāyottara": ['mw'],
    "prāṅnāsikā": ['mw'],
    "prāṅnāsikī": ['mw'],
    "prāṅyāya": ['ddsa'],
    "prāṅāyata": ['mw'],
    "prāṅīkṣaṇa": ['mw'],
    "prāṅīṣa": ['mw'],
    "prāṅśāyin": ['mw'],
    "prāṇ": ['ap90', 'mw'],
    "prāṇa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "prāṇabhakṣa": ['mw'],
    "prāṇabhakṣam": ['mw'],
    "prāṇabhaya": ['mw'],
    "prāṇabhāj": ['mw'],
    "prāṇabhāsvat": ['mw'],
    "prāṇabhūta": ['mw'],
    "prāṇabhṛt": ['cae', 'mw'],
    "prāṇabuddhi": ['mw'],
    "prāṇabādha": ['mw'],
    "prāṇacaya": ['mw'],
    "prāṇaccheda": ['mw'],
    "prāṇacchedakara": ['mw'],
    "prāṇacchid": ['mw'],
    "prāṇacit": ['mw'],
    "prāṇaciti": ['mw'],
    "prāṇada": ['cae', 'mw'],
    "prāṇadakṣiṇā": ['mw'],
    "prāṇadavat": ['mw'],
    "prāṇadayita": ['mw'],
    "prāṇadaṇḍa": ['mw'],
    "prāṇadhara": ['mw'],
    "prāṇadharamiśra": ['mw'],
    "prāṇadhāra": ['mw'],
    "prāṇadhāraṇa": ['cae', 'mw'],
    "prāṇadhārin": ['mw'],
    "prāṇadhṛk": ['mw'],
    "prāṇadroha": ['mw'],
    "prāṇadrohin": ['mw'],
    "prāṇadurodara": ['mw'],
    "prāṇadyūta": ['mw'],
    "prāṇadyūtābhidevana": ['mw'],
    "prāṇadā": ['mw'],
    "prāṇadāna": ['mw'],
    "prāṇadātṛ": ['cae', 'mw'],
    "prāṇadāvat": ['mw'],
    "prāṇadṛh": ['mw'],
    "prāṇaghna": ['mw'],
    "prāṇaghātaka": ['mw'],
    "prāṇagraha": ['mw'],
    "prāṇahara": ['cae', 'mw'],
    "prāṇahitā": ['mw'],
    "prāṇahāni": ['mw'],
    "prāṇahāraka": ['cae', 'mw'],
    "prāṇahārin": ['cae', 'mw'],
    "prāṇahāriṇī": ['bhs'],
    "prāṇahīna": ['cae', 'mw'],
    "prāṇaikaśatavidha": ['mw'],
    "prāṇaka": ['bhs', 'mw'],
    "prāṇakara": ['mw'],
    "prāṇakarman": ['cae', 'mw'],
    "prāṇakaḥ": ['ap90'],
    "prāṇakṛcchra": ['cae', 'mw'],
    "prāṇakṛṣṇa": ['mw'],
    "prāṇalipsu": ['cae', 'mw'],
    "prāṇalābha": ['cae', 'mw'],
    "prāṇamant": ['cae'],
    "prāṇamat": ['mw'],
    "prāṇamaya": ['ap90', 'cae', 'mw'],
    "prāṇamayakośa": ['mw'],
    "prāṇamokṣaṇa": ['mw'],
    "prāṇana": ['cae', 'ddsa', 'gra', 'mw'],
    "prāṇanaḥ": ['ap90'],
    "prāṇanigraha": ['cae', 'mw'],
    "prāṇanta": ['mw'],
    "prāṇantī": ['mw'],
    "prāṇanānta": ['cae', 'mw'],
    "prāṇanārāyaṇa": ['mw'],
    "prāṇanātha": ['cae', 'ddsa', 'mw'],
    "prāṇanāśa": ['cae', 'mw'],
    "prāṇaparigraha": ['mw'],
    "prāṇaparikraya": ['mw'],
    "prāṇaparikṣīṇa": ['mw'],
    "prāṇaparityāga": ['cae', 'mw'],
    "prāṇaparīpsā": ['mw'],
    "prāṇapata": ['mw'],
    "prāṇapati": ['mw'],
    "prāṇapatnī": ['mw'],
    "prāṇaprada": ['cae', 'mw'],
    "prāṇapradaphala": ['mw'],
    "prāṇapradā": ['mw'],
    "prāṇapradāyaka": ['mw'],
    "prāṇapradāyin": ['mw'],
    "prāṇaprahāṇa": ['mw'],
    "prāṇapratiṣṭhā": ['mw'],
    "prāṇapratiṣṭhāmantra": ['mw'],
    "prāṇapratiṣṭhāpaddhati": ['mw'],
    "prāṇaprayāṇa": ['mw'],
    "prāṇaprepsu": ['mw'],
    "prāṇapriya": ['cae', 'mw'],
    "prāṇaprāśanin": ['mw'],
    "prāṇapā": ['mw'],
    "prāṇarakṣaṇa": ['mw'],
    "prāṇarakṣaṇārtham": ['mw'],
    "prāṇarakṣā": ['mw'],
    "prāṇarakṣārtham": ['mw'],
    "prāṇarandhra": ['mw'],
    "prāṇarodha": ['mw'],
    "prāṇarājyada": ['mw'],
    "prāṇasadman": ['mw'],
    "prāṇasama": ['cae', 'mw'],
    "prāṇasambhṛta": ['mw'],
    "prāṇasammita": ['mw'],
    "prāṇasamā": ['mw'],
    "prāṇasaṃdeha": ['mw'],
    "prāṇasaṃdhāraṇa": ['mw'],
    "prāṇasaṃhita": ['mw'],
    "prāṇasaṃhitā": ['mw'],
    "prāṇasaṃkaṭa": ['mw'],
    "prāṇasaṃnyāsa": ['mw'],
    "prāṇasaṃrodha": ['mw'],
    "prāṇasaṃtyāga": ['mw'],
    "prāṇasaṃvāda": ['mw'],
    "prāṇasaṃyama": ['mw'],
    "prāṇasaṃśaya": ['mw'],
    "prāṇasaṃśita": ['mw'],
    "prāṇasāra": ['cae', 'mw'],
    "prāṇasūtra": ['mw'],
    "prāṇataja": ['mw'],
    "prāṇatejas": ['mw'],
    "prāṇatha": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāṇatoṣiṇī": ['mw'],
    "prāṇatrāṇa": ['cae', 'mw'],
    "prāṇatrāṇarasa": ['mw'],
    "prāṇatva": ['mw'],
    "prāṇatyāga": ['cae', 'mw'],
    "prāṇavallabhā": ['mw'],
    "prāṇavant": ['cae'],
    "prāṇavat": ['ap90', 'mw'],
    "prāṇavidyā": ['mw'],
    "prāṇavināśa": ['mw'],
    "prāṇaviprayoga": ['mw'],
    "prāṇavyaya": ['cae', 'mw'],
    "prāṇavyāyacchana": ['mw'],
    "prāṇavīrya": ['mw'],
    "prāṇavṛtti": ['cae', 'mw'],
    "prāṇayama": ['mw'],
    "prāṇayita": ['mw'],
    "prāṇayoni": ['mw'],
    "prāṇayuta": ['cae', 'mw'],
    "prāṇayātrika": ['mw'],
    "prāṇayātrikamātra": ['cae', 'mw'],
    "prāṇayātrā": ['cae', 'mw'],
    "prāṇaśakti": ['mw'],
    "prāṇaśarīra": ['mw'],
    "prāṇaḥ": ['ap90'],
    "prāṇaṃdada": ['mw'],
    "prāṇaṃtaḥ": ['ap90'],
    "prāṇaṃtī": ['ap90'],
    "prāṇeśa": ['cae', 'ddsa', 'mw'],
    "prāṇeśvara": ['cae', 'mw'],
    "prāṇeśvarī": ['mw'],
    "prāṇeśā": ['mw'],
    "prāṇi": ['mw'],
    "prāṇibhava": ['mw'],
    "prāṇidyūta": ['mw'],
    "prāṇighātin": ['ddsa', 'mw'],
    "prāṇihita": ['mw'],
    "prāṇihitā": ['mw'],
    "prāṇihiṃsā": ['mw'],
    "prāṇijāta": ['mw'],
    "prāṇika": ['bhs', 'mw'],
    "prāṇimat": ['mw'],
    "prāṇimātṛ": ['mw'],
    "prāṇin": ['ap90', 'cae', 'ddsa', 'mw'],
    "prāṇipīḍā": ['mw'],
    "prāṇisvana": ['mw'],
    "prāṇita": ['ap90'],
    "prāṇitva": ['cae', 'mw'],
    "prāṇivadha": ['cae', 'mw'],
    "prāṇivadhaprāyaścitta": ['mw'],
    "prāṇiyodhana": ['mw'],
    "prāṇiṇiṣu": ['mw'],
    "prāṇopahāra": ['mw'],
    "prāṇopeta": ['mw'],
    "prāṇotkramaṇa": ['mw'],
    "prāṇotkrānti": ['mw'],
    "prāṇotsarga": ['mw'],
    "prāṇyaṅga": ['ddsa', 'mw'],
    "prāṇābharaṇa": ['mw'],
    "prāṇābhisara": ['mw'],
    "prāṇābādha": ['cae', 'mw'],
    "prāṇācārya": ['mw'],
    "prāṇāda": ['mw'],
    "prāṇādhika": ['cae', 'mw'],
    "prāṇādhinātha": ['mw'],
    "prāṇādhipa": ['mw'],
    "prāṇāghāta": ['ddsa', 'mw'],
    "prāṇāgnihotra": ['mw'],
    "prāṇāgnihotravidhi": ['mw'],
    "prāṇāgnihotropaniṣad": ['mw'],
    "prāṇāha": ['mw'],
    "prāṇāhati": ['mw'],
    "prāṇāhuti": ['mw'],
    "prāṇākarṣin": ['mw'],
    "prāṇālābha": ['mw'],
    "prāṇānta": ['cae', 'mw'],
    "prāṇāntika": ['cae', 'mw'],
    "prāṇāntikam": ['mw'],
    "prāṇānuga": ['cae', 'mw'],
    "prāṇāpahārin": ['mw'],
    "prāṇāpriya": ['cae'],
    "prāṇāpāna": ['cae', 'mw'],
    "prāṇārthavat": ['ddsa', 'mw'],
    "prāṇārthin": ['cae', 'mw'],
    "prāṇātilobha": ['mw'],
    "prāṇātipāta": ['mw'],
    "prāṇātipātika": ['bhs'],
    "prāṇātman": ['mw'],
    "prāṇātyaya": ['cae', 'mw'],
    "prāṇāvarodha": ['cae', 'mw'],
    "prāṇāvāya": ['mw'],
    "prāṇāyana": ['mw'],
    "prāṇāyya": ['ap90', 'ddsa', 'mw'],
    "prāṇāyāma": ['cae', 'mw'],
    "prāṇāyāmaśas": ['mw'],
    "prāṇāyāmin": ['mw'],
    "prāṇītya": ['mw'],
    "prāṇītyaṃ": ['ap90'],
    "prāṣṭa": ['mw'],
    "prāṣṭavarṇa": ['mw'],
    "prāṣṭha": ['mw'],
    "prī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "prīta": ['ap90', 'cae', 'mw'],
    "prītacitta": ['mw'],
    "prītamanas": ['mw'],
    "prītamānasa": ['mw'],
    "prītatara": ['ddsa', 'mw'],
    "prīti": ['cae', 'ddsa', 'mw'],
    "prītibhakṣa": ['bhs'],
    "prītibhojya": ['mw'],
    "prītibhāj": ['mw'],
    "prīticandra": ['mw'],
    "prīticcheda": ['cae', 'mw'],
    "prītida": ['mw'],
    "prītidatta": ['mw'],
    "prītidhana": ['mw'],
    "prītidāna": ['cae', 'mw'],
    "prītidāya": ['mw'],
    "prītijuṣā": ['mw'],
    "prītika": ['bhs'],
    "prītikara": ['cae', 'mw'],
    "prītikaraṇa": ['mw'],
    "prītikarman": ['cae', 'mw'],
    "prītikūṭa": ['mw'],
    "prītimanas": ['mw'],
    "prītimant": ['cae'],
    "prītimat": ['ap90', 'mw'],
    "prītimatī": ['mw'],
    "prītimaya": ['mw'],
    "prītipramukha": ['cae', 'mw'],
    "prītipramukhavacana": ['mw'],
    "prītipuroga": ['mw'],
    "prītipātra": ['mw'],
    "prītipūrvakam": ['cae', 'mw'],
    "prītipūrvam": ['mw'],
    "prītirasāyana": ['mw'],
    "prītisambodhyaṅga": ['mw'],
    "prītisaumanasyajāta": ['bhs'],
    "prītisaṃdarbha": ['mw'],
    "prītisaṃgati": ['mw'],
    "prītisaṃyoga": ['mw'],
    "prītisnigdha": ['mw'],
    "prītitṛṣ": ['mw'],
    "prītivacana": ['mw'],
    "prītivacas": ['cae', 'mw'],
    "prītivardhana": ['mw'],
    "prītivivāha": ['mw'],
    "prītiviśrambhabhājana": ['mw'],
    "prītivāda": ['mw'],
    "prītiyuj": ['mw'],
    "prītiśrāddha": ['mw'],
    "prītiḥ": ['ap90'],
    "prītu": ['mw'],
    "prītyā": ['mw'],
    "prītyāhāravyūha": ['bhs'],
    "prītā": ['mw'],
    "prītātman": ['cae', 'mw'],
    "prīyati": ['mw'],
    "prīyaṇā": ['bhs'],
    "prīyāya": ['mw'],
    "prīṇa": ['ap90', 'mw'],
    "prīṇana": ['ap90', 'cae', 'ddsa', 'mw'],
    "prīṇay": ['cae'],
    "prīṇaya": ['ddsa'],
    "prīṇayitvā": ['mw'],
    "prīṇayitṛ": ['mw'],
    "prīṇita": ['ap90', 'mw'],
    "prū": ['mw'],
    "prūṣ": ['mw'],
    "psara": ['cae', 'ddsa', 'gra'],
    "psaras": ['cae', 'ddsa', 'gra', 'mw'],
    "psnya": ['mw'],
    "psu": ['cae', 'ddsa', 'gra', 'mw'],
    "psur": ['gra'],
    "psura": ['ap90'],
    "psuras": ['cae', 'ddsa', 'mw'],
    "psā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "psāna": ['mw'],
    "psānaṃ": ['ap90'],
    "psāta": ['ap90', 'mw'],
    "psātkāra": ['mw'],
    "ptā": ['mw'],
    "pu": ['mw'],
    "pubba": ['bhs', 'cped'],
    "pubbabhāga": ['cped'],
    "pubbacarita": ['cped'],
    "pubbadeva": ['cped'],
    "pubbakamma": ['cped'],
    "pubbakicca": ['cped'],
    "pubbanimitta": ['cped'],
    "pubbanna": ['cped'],
    "pubbanta": ['cped'],
    "pubbapeta": ['cped'],
    "pubbapurisa": ['cped'],
    "pubbavideha": ['cped'],
    "pubbayoga": ['cped'],
    "pubbaṅgama": ['cped'],
    "pubbaṇha": ['cped'],
    "pubbe": ['cped'],
    "pubbekata": ['cped'],
    "pubbenivāsa": ['cped'],
    "pubbenivāsañāṇa": ['cped'],
    "pubbenivāsānussati": ['cped'],
    "pubbesānussati": ['cped'],
    "pubbuṭṭhāyī": ['cped'],
    "pubbā": ['cped'],
    "pubbācariya": ['cped'],
    "pubbāpara": ['cped'],
    "puccaṇḍa": ['cped'],
    "puccha": ['cae', 'cped', 'ddsa', 'mw'],
    "pucchabandha": ['mw'],
    "pucchabrahmavāda": ['mw'],
    "pucchabrahmavādakhaṇḍana": ['mw'],
    "pucchabrahmavādanirākaraṇa": ['mw'],
    "pucchadhi": ['cae', 'mw'],
    "pucchadā": ['mw'],
    "pucchajāha": ['mw'],
    "pucchaka": ['cped', 'mw'],
    "pucchakaṇṭaka": ['mw'],
    "pucchala": ['mw'],
    "pucchalakṣaṇa": ['mw'],
    "pucchalakṣaṇadīdhitiṭīkā": ['mw'],
    "pucchalakṣaṇakroḍa": ['mw'],
    "pucchalakṣaṇaprakāśa": ['mw'],
    "pucchalakṣaṇavivecana": ['mw'],
    "pucchalakṣaṇaṭīkā": ['mw'],
    "pucchalakṣaṇānugama": ['mw'],
    "pucchamūla": ['mw'],
    "pucchana": ['cped'],
    "pucchanta": ['cped'],
    "pucchati": ['bhs', 'cped'],
    "pucchavat": ['mw'],
    "pucchaya": ['mw'],
    "pucchaḥ": ['ap90'],
    "pucchaṭi": ['mw'],
    "pucchaṭiḥ": ['ap90'],
    "puccheśvara": ['mw'],
    "pucchi": ['cped'],
    "pucchin": ['ap90', 'mw'],
    "pucchita": ['cped'],
    "pucchitabba": ['cped'],
    "pucchituṁ": ['cped'],
    "pucchitvā": ['cped'],
    "pucchoṭikā": ['mw'],
    "pucchā": ['cped'],
    "pucchāgra": ['cae', 'mw'],
    "pucchāsyacārin": ['mw'],
    "pucchāṇḍaka": ['mw'],
    "puch": ['mw'],
    "pucimanda": ['cped'],
    "pud": ['cae', 'ddsa', 'mw'],
    "pudaka": ['mw'],
    "puddala": ['mw'],
    "pudgala": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "pudgalapati": ['mw'],
    "puggala": ['cped'],
    "puggalapaññatti": ['cped'],
    "puggalika": ['cped'],
    "puja": ['bhs'],
    "pujja": ['cped'],
    "puka": ['mw'],
    "pukin": ['mw'],
    "pukkasa": ['cae', 'ddsa', 'mw'],
    "pukkasī": ['bhs', 'mw'],
    "pukkaśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "pukkaśaka": ['ap90'],
    "pukkaṣa": ['mw'],
    "pukkusa": ['cped'],
    "puklaka": ['mw'],
    "pul": ['ap90', 'mw'],
    "pula": ['ap90', 'bhs', 'mw'],
    "pulaha": ['cae', 'ddsa', 'mw'],
    "pulahaḥ": ['ap90'],
    "pulahāśrama": ['mw'],
    "pulaka": ['cae', 'cped', 'ddsa', 'mw'],
    "pulakay": ['cae'],
    "pulakaya": ['ddsa', 'mw'],
    "pulakayati": ['ap90'],
    "pulakaḥ": ['ap90'],
    "pulakeśin": ['mw'],
    "pulakeśivallabha": ['mw'],
    "pulakin": ['ap90', 'mw'],
    "pulakita": ['ap90', 'mw'],
    "pulakitasarvāṅga": ['mw'],
    "pulakodbheda": ['mw'],
    "pulakoddhūṣitaśarīra": ['mw'],
    "pulakodgama": ['mw'],
    "pulakotkampa": ['mw'],
    "pulakācita": ['mw'],
    "pulakākulākṛti": ['mw'],
    "pulakālaya": ['mw'],
    "pulakāṅga": ['mw'],
    "pulakāṅkitasarvāṅga": ['mw'],
    "pulakāṅkura": ['mw'],
    "pulakīkṛ": ['ddsa'],
    "pulakīkṛta": ['ap90', 'mw'],
    "pulasa": ['mw'],
    "pulasti": ['ddsa', 'mw'],
    "pulastiḥ": ['ap90'],
    "pulastya": ['cae', 'ddsa', 'mw'],
    "pulastyasiddhānta": ['mw'],
    "pulastyasmṛti": ['mw'],
    "pulastyāṣṭaka": ['mw'],
    "pulava": ['cped'],
    "pulika": ['mw'],
    "pulikeśin": ['mw'],
    "pulikā": ['mw'],
    "pulimat": ['mw'],
    "pulina": ['cae', 'cped', 'ddsa', 'mw'],
    "pulinadvīpaśobhita": ['mw'],
    "pulinajaghanā": ['mw'],
    "pulinamaṇḍita": ['mw'],
    "pulinapradeśa": ['mw'],
    "pulinavatī": ['ap90', 'mw'],
    "pulinaḥ": ['ap90'],
    "pulinda": ['cae', 'ddsa', 'mw'],
    "pulindasena": ['mw'],
    "pulindikā": ['mw'],
    "pulinduka": ['mw'],
    "pulindā": ['bhs', 'mw'],
    "pulindī": ['mw'],
    "pulirika": ['mw'],
    "pulirikaḥ": ['ap90'],
    "puliśa": ['mw'],
    "puliṃdaḥ": ['ap90'],
    "pulkaka": ['mw'],
    "pulkasa": ['cae', 'ddsa', 'mw'],
    "pulla": ['mw'],
    "pullīramalaya": ['bhs'],
    "puloma": ['mw'],
    "pulomabhid": ['mw'],
    "pulomadviṣ": ['mw'],
    "pulomahī": ['mw'],
    "pulomajit": ['mw'],
    "pulomajā": ['ddsa', 'mw'],
    "puloman": ['ap90', 'cae', 'ddsa', 'mw'],
    "pulomaniṣūdana": ['mw'],
    "pulomat": ['mw'],
    "pulomatanayā": ['mw'],
    "pulomā": ['ap90', 'cae', 'mw'],
    "pulomārcis": ['mw'],
    "pulomāri": ['cae', 'ddsa', 'mw'],
    "pulomāvi": ['mw'],
    "pulu": ['cae', 'gra', 'mw'],
    "pulukāma": ['cae', 'gra', 'mw'],
    "puluṣa": ['mw'],
    "pulvagha": ['cae', 'gra', 'mw'],
    "pulya": ['mw'],
    "pulā": ['ap90', 'mw'],
    "pulāka": ['cae', 'ddsa', 'mw'],
    "pulākakārin": ['mw'],
    "pulākaḥ": ['ap90'],
    "pulākin": ['ap90', 'mw'],
    "pulākodaka": ['mw'],
    "pulānikā": ['mw'],
    "pulāyita": ['mw'],
    "pulāyitaṃ": ['ap90'],
    "pulī": ['mw'],
    "pulīkoya": ['mw'],
    "pulīkā": ['mw'],
    "pulītat": ['mw'],
    "pum": ['mw'],
    "puma": ['cped'],
    "pumanujā": ['mw'],
    "pumapatya": ['mw'],
    "pumartha": ['mw'],
    "pumartham": ['mw'],
    "pumarthatā": ['mw'],
    "pumaṃs": ['cae'],
    "pumbhāva": ['ddsa', 'mw'],
    "pumbhūman": ['mw'],
    "pummantra": ['mw'],
    "pummṛga": ['mw'],
    "pumpaśu": ['ddsa', 'mw'],
    "pumprakṛti": ['mw'],
    "pumācāra": ['mw'],
    "pumākhya": ['mw'],
    "pumākhyā": ['mw'],
    "pumāṃs": ['ddsa', 'gra'],
    "puna": ['cped', 'mw'],
    "punabbhava": ['cped'],
    "punadisava": ['cped'],
    "punappunaṁ": ['cped'],
    "punar": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "punarabhidhāna": ['mw'],
    "punarabhiṣeka": ['mw'],
    "punarabhyunnīta": ['mw'],
    "punarabhyāghāram": ['mw'],
    "punarabhyākāram": ['mw'],
    "punarabhyāvartam": ['mw'],
    "punarapagama": ['ddsa', 'mw'],
    "punararthin": ['mw'],
    "punararthitā": ['mw'],
    "punarasu": ['mw'],
    "punarbandhayoga": ['mw'],
    "punarbhakṣya": ['mw'],
    "punarbharyā": ['mw'],
    "punarbhava": ['cae', 'mw'],
    "punarbhavika": ['bhs'],
    "punarbhavin": ['mw'],
    "punarbhoga": ['cae', 'mw'],
    "punarbhāva": ['mw'],
    "punarbhāvin": ['mw'],
    "punarbhū": ['cae', 'gra', 'mw'],
    "punarbāla": ['mw'],
    "punarbālya": ['mw'],
    "punardahana": ['mw'],
    "punardarśana": ['cae', 'mw'],
    "punardarśanāya": ['mw'],
    "punardhenu": ['mw'],
    "punardyūta": ['mw'],
    "punardāha": ['mw'],
    "punardārakriyā": ['cae', 'mw'],
    "punardātṛ": ['mw'],
    "punardāya": ['mw'],
    "punardīyamāna": ['mw'],
    "punargamana": ['ddsa', 'mw'],
    "punargarbhavatī": ['cae', 'mw'],
    "punargava": ['mw'],
    "punargeya": ['mw'],
    "punargrahaṇa": ['mw'],
    "punarhan": ['cae', 'gra', 'mw'],
    "punarhavis": ['cae', 'mw'],
    "punarjanmajaya": ['mw'],
    "punarjanman": ['cae', 'mw'],
    "punarjanmākṣepa": ['mw'],
    "punarjāta": ['cae', 'mw'],
    "punarjīvātu": ['mw'],
    "punarlekhana": ['cae', 'mw'],
    "punarlābha": ['cae', 'mw'],
    "punarmagha": ['mw'],
    "punarmanya": ['gra', 'mw'],
    "punarmāra": ['mw'],
    "punarmṛta": ['mw'],
    "punarmṛtyu": ['mw'],
    "punarnava": ['cae', 'gra', 'mw'],
    "punarnavā": ['mw'],
    "punarnavāmaṇḍūra": ['mw'],
    "punarnigrantham": ['mw'],
    "punarninṛtta": ['mw'],
    "punarnitunna": ['mw'],
    "punarnivartam": ['mw'],
    "punarniṣkṛta": ['mw'],
    "punartta": ['mw'],
    "punarukta": ['cae', 'ddsa', 'mw'],
    "punaruktabhuktaviṣaya": ['mw'],
    "punaruktajanman": ['mw'],
    "punaruktam": ['mw'],
    "punaruktatva": ['mw'],
    "punaruktatā": ['cae', 'mw'],
    "punaruktavadābhāsa": ['mw'],
    "punaruktavādin": ['cae', 'mw'],
    "punarukti": ['cae', 'mw'],
    "punaruktimat": ['mw'],
    "punaruktāya": ['mw'],
    "punaruktīkṛ": ['mw'],
    "punarupagamana": ['mw'],
    "punarupalabdhi": ['cae', 'mw'],
    "punarupanayana": ['mw'],
    "punarupanayanaprayoga": ['mw'],
    "punarupanayanavidhi": ['mw'],
    "punarupanayanavidhāna": ['mw'],
    "punarupasadana": ['mw'],
    "punarupoḍhā": ['mw'],
    "punarupāgama": ['mw'],
    "punarupākaraṇa": ['mw'],
    "punarutpatti": ['mw'],
    "punarutpādana": ['mw'],
    "punarutsyūta": ['mw'],
    "punarutsṛṣṭa": ['mw'],
    "punarutthāna": ['mw'],
    "punarutti": ['cped'],
    "punarvacana": ['cae', 'mw'],
    "punarvaktavya": ['mw'],
    "punarvaktavyatā": ['mw'],
    "punarvaraṇa": ['mw'],
    "punarvasu": ['bhs', 'cae', 'gra', 'mw'],
    "punarvasutva": ['mw'],
    "punarvat": ['mw'],
    "punarvatsa": ['mw'],
    "punarvaṇya": ['mw'],
    "punarviroha": ['mw'],
    "punarvivāha": ['mw'],
    "punarvivāhavidhi": ['mw'],
    "punarvāda": ['cae', 'mw'],
    "punaryajña": ['mw'],
    "punaryuddha": ['ddsa', 'mw'],
    "punaryuvan": ['mw'],
    "punaryuvatva": ['mw'],
    "punaryāman": ['mw'],
    "punaryātrā": ['mw'],
    "punarābhāva": ['mw'],
    "punarādheya": ['mw'],
    "punarādheyaka": ['mw'],
    "punarādheyaprayoga": ['mw'],
    "punarādheyika": ['mw'],
    "punarādhāna": ['cae', 'mw'],
    "punarādhānadhāryāgnihotraprayoga": ['mw'],
    "punarādhānaprayoga": ['mw'],
    "punarādhānaśrautasūtra": ['mw'],
    "punarādhānāgnihotra": ['mw'],
    "punarādi": ['mw'],
    "punarādāyam": ['mw'],
    "punarāgama": ['cae', 'mw'],
    "punarāgamana": ['mw'],
    "punarāgata": ['mw'],
    "punarāgrantham": ['mw'],
    "punarāgāmin": ['cae', 'mw'],
    "punarāhāra": ['mw'],
    "punarāhāram": ['mw'],
    "punarājāti": ['mw'],
    "punarālambha": ['mw'],
    "punarāmnāna": ['mw'],
    "punarānayana": ['cae', 'mw'],
    "punarāsṛta": ['mw'],
    "punarātta": ['mw'],
    "punarāvarta": ['mw'],
    "punarāvartaka": ['mw'],
    "punarāvartana": ['mw'],
    "punarāvartanandā": ['mw'],
    "punarāvartin": ['cae', 'mw'],
    "punarāvṛtta": ['mw'],
    "punarāvṛtti": ['cae', 'mw'],
    "punarāyana": ['mw'],
    "punarḍīna": ['mw'],
    "punarṇava": ['cae', 'mw'],
    "punas": ['mw'],
    "punastarām": ['ddsa', 'mw'],
    "punastati": ['mw'],
    "punavacana": ['cped'],
    "punaś": ['mw'],
    "punaścandrā": ['mw'],
    "punaścara": ['mw'],
    "punaścarvaṇa": ['cae', 'mw'],
    "punaściti": ['cae', 'mw'],
    "punaḥ": ['mw'],
    "punaḥkaraṇa": ['cae', 'mw'],
    "punaḥkarman": ['cae', 'mw'],
    "punaḥkriyā": ['mw'],
    "punaḥkāma": ['mw'],
    "punaḥpada": ['mw'],
    "punaḥparidhāna": ['mw'],
    "punaḥparājaya": ['mw'],
    "punaḥpramāda": ['mw'],
    "punaḥpratinivartana": ['mw'],
    "punaḥpratyupakāra": ['mw'],
    "punaḥpravṛddha": ['mw'],
    "punaḥprayoga": ['mw'],
    "punaḥprayogarūpa": ['mw'],
    "punaḥprepsā": ['mw'],
    "punaḥprādhyeṣaṇa": ['mw'],
    "punaḥprāpya": ['mw'],
    "punaḥprāyaṇīya": ['mw'],
    "punaḥpunā": ['mw'],
    "punaḥpāka": ['cae', 'ddsa', 'mw'],
    "punaḥsambhava": ['mw'],
    "punaḥsara": ['gra', 'mw'],
    "punaḥsaṃbhava": ['cae'],
    "punaḥsaṃdarśana": ['mw'],
    "punaḥsaṃdhāna": ['mw'],
    "punaḥsaṃdhānaprayoga": ['mw'],
    "punaḥsaṃgama": ['mw'],
    "punaḥsaṃskāra": ['ddsa', 'mw'],
    "punaḥsaṃskṛta": ['mw'],
    "punaḥsiddha": ['mw'],
    "punaḥstoma": ['mw'],
    "punaḥstuti": ['mw'],
    "punaḥsukha": ['mw'],
    "punaḥśramaṇa": ['bhs', 'mw'],
    "pundra": ['mw'],
    "puneti": ['cped'],
    "puni": ['bhs'],
    "punnapuṃsaka": ['ddsa'],
    "punnāga": ['cped'],
    "punnāman": ['cae', 'mw'],
    "punth": ['mw'],
    "punā": ['bhs', 'mw'],
    "punāgamana": ['cped'],
    "punāna": ['mw'],
    "punārāja": ['mw'],
    "punārājābhiṣeka": ['mw'],
    "punīta": ['mw'],
    "puppha": ['cped'],
    "pupphachaḍḍaka": ['cped'],
    "pupphacumbaṭaka": ['cped'],
    "pupphadhara": ['cped'],
    "pupphadāma": ['cped'],
    "pupphagaccha": ['cped'],
    "pupphagandha": ['cped'],
    "pupphamuṭṭhi": ['cped'],
    "pupphapaṭa": ['cped'],
    "puppharāsi": ['cped'],
    "pupphati": ['cped'],
    "pupphavatī": ['cped'],
    "pupphi": ['cped'],
    "pupphita": ['cped'],
    "pupphitvā": ['cped'],
    "pupphula": ['mw'],
    "pupphulaḥ": ['ap90'],
    "pupphusa": ['mw'],
    "pupphusaḥ": ['ap90'],
    "pupphuṭaḥ": ['ap90'],
    "puppuṭa": ['mw'],
    "pupūtani": ['gra', 'mw'],
    "pupūṣat": ['mw'],
    "pupūṣā": ['mw'],
    "pur": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pura": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "purabhid": ['cae', 'mw'],
    "puradevatā": ['mw'],
    "puradviṣ": ['mw'],
    "puradvāra": ['cae', 'ddsa', 'mw'],
    "puradāha": ['mw'],
    "puraetṛ": ['cae', 'gra', 'mw'],
    "puraga": ['mw'],
    "puragāvaṇa": ['mw'],
    "purahan": ['mw'],
    "purahita": ['mw'],
    "purajana": ['cae', 'mw'],
    "purajit": ['cae', 'mw'],
    "purajyotis": ['mw'],
    "purajānu": ['mw'],
    "purakkhari": ['cped'],
    "purakkharoti": ['cped'],
    "purakkhata": ['cped'],
    "purakkhatvā": ['cped'],
    "purakoṭṭa": ['ddsa', 'mw'],
    "purakoṭṭapāla": ['mw'],
    "puraloka": ['mw'],
    "puralā": ['ap90', 'mw'],
    "puram": ['bhs'],
    "puramathana": ['cae', 'ddsa', 'mw'],
    "puramathitṛ": ['cae', 'mw'],
    "puramālinī": ['mw'],
    "puramārga": ['mw'],
    "purandara": ['ddsa'],
    "purandhi": ['ddsa'],
    "purandhri": ['ddsa'],
    "puraniveśa": ['mw'],
    "puranārī": ['mw'],
    "purapakṣin": ['mw'],
    "purapāla": ['mw'],
    "purapālaka": ['mw'],
    "purarakṣa": ['cae', 'mw'],
    "purarakṣin": ['cae', 'mw'],
    "purarodha": ['mw'],
    "purarāṣṭra": ['cae', 'mw'],
    "puras": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "puraskaraṇa": ['mw'],
    "puraskaraṇaṃ": ['ap90'],
    "puraskaraṇīya": ['ap90', 'mw'],
    "puraskartavya": ['ddsa', 'mw'],
    "puraskriyā": ['ap90', 'mw'],
    "puraskriyācaryā": ['mw'],
    "puraskāra": ['cae', 'mw'],
    "puraskāraḥ": ['ap90'],
    "puraskārya": ['mw'],
    "puraskṛ": ['ap90', 'mw'],
    "puraskṛta": ['ap90', 'cae', 'mw'],
    "puraskṛtam": ['mw'],
    "puraskṛtamadhyamakrama": ['mw'],
    "puraskṛtya": ['cae', 'mw'],
    "purasta": ['bhs'],
    "purastataḥ": ['bhs'],
    "purastima": ['bhs'],
    "purastād": ['mw'],
    "purastādagniṣṭoma": ['mw'],
    "purastādanūka": ['mw'],
    "purastādapakarṣa": ['ddsa', 'mw'],
    "purastādapavāda": ['mw'],
    "purastādbhāga": ['mw'],
    "purastādbṛhatī": ['mw'],
    "purastāddaṇḍa": ['mw'],
    "purastāddhoma": ['mw'],
    "purastāddhomabhāj": ['mw'],
    "purastāddhomavat": ['mw'],
    "purastādgranthi": ['mw'],
    "purastāducca": ['mw'],
    "purastādudarka": ['mw'],
    "purastāduddhāra": ['mw'],
    "purastādupacāra": ['mw'],
    "purastādupayāma": ['mw'],
    "purastādvadana": ['mw'],
    "purastāj": ['mw'],
    "purastājjapa": ['mw'],
    "purastājjyotis": ['mw'],
    "purastājjyotiṣmatī": ['mw'],
    "purastāl": ['mw'],
    "purastāllakṣaṇa": ['mw'],
    "purastāllakṣman": ['mw'],
    "purastān": ['mw'],
    "purastānmukha": ['cae', 'mw'],
    "purastāt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "purastātkratu": ['mw'],
    "purastātpravaṇa": ['mw'],
    "purastātpuroḍāśa": ['mw'],
    "purastātpṛṣṭhya": ['mw'],
    "purastātstobha": ['mw'],
    "purastātsvāhākāra": ['mw'],
    "purastātsvāhākṛti": ['mw'],
    "purastāttiryakpramāṇa": ['mw'],
    "purastāttna": ['ddsa', 'mw'],
    "puratas": ['ap90', 'cae', 'ddsa', 'mw'],
    "purataḥkṛ": ['mw'],
    "purataṭī": ['mw'],
    "purati": ['bhs'],
    "purato": ['cped'],
    "puratoraṇa": ['mw'],
    "puratthima": ['cped'],
    "puratthā": ['cped'],
    "puratthābhimukha": ['cped'],
    "puraukas": ['mw'],
    "purauṣṇih": ['cae', 'ddsa', 'mw'],
    "puravadhū": ['mw'],
    "puravairin": ['mw'],
    "puravara": ['mw'],
    "puravāsin": ['cae', 'mw'],
    "puravāstu": ['mw'],
    "puravī": ['mw'],
    "puraya": ['cae', 'gra', 'mw'],
    "purañjara": ['mw'],
    "purañjaya": ['ddsa'],
    "puraś": ['mw'],
    "puraścakram": ['mw'],
    "puraścaraṇa": ['cae', 'ddsa', 'mw'],
    "puraścaraṇacandrikā": ['mw'],
    "puraścaraṇadīpikā": ['mw'],
    "puraścaraṇakarman": ['mw'],
    "puraścaraṇakaumudī": ['mw'],
    "puraścaraṇakaustubha": ['mw'],
    "puraścaraṇapaddhati": ['mw'],
    "puraścaraṇapaddhatimālā": ['mw'],
    "puraścaraṇaprapañca": ['mw'],
    "puraścaraṇarasollāsa": ['mw'],
    "puraścaraṇatā": ['mw'],
    "puraścaraṇavidhi": ['mw'],
    "puraścaraṇaviveka": ['mw'],
    "puraścaryā": ['mw'],
    "puraścaryārasāmbudhi": ['mw'],
    "puraśchada": ['mw'],
    "puraśāsana": ['mw'],
    "puraḥ": ['mw'],
    "puraḥphala": ['mw'],
    "puraḥprahartṛ": ['mw'],
    "puraḥprasravaṇa": ['gra', 'mw'],
    "puraḥpāka": ['ddsa', 'mw'],
    "puraḥsad": ['cae', 'gra', 'mw'],
    "puraḥsara": ['cae', 'ddsa', 'mw'],
    "puraḥsaram": ['mw'],
    "puraḥsphurat": ['mw'],
    "puraḥstha": ['cae', 'mw'],
    "puraḥsthita": ['mw'],
    "puraḥsthātṛ": ['mw'],
    "puraḥsthāyin": ['mw'],
    "puraḥstātṛ": ['gra'],
    "puraḥśramaṇa": ['bhs'],
    "puraḥśukram": ['ddsa', 'mw'],
    "puraṃ": ['mw'],
    "puraṃda": ['mw'],
    "puraṃdara": ['bhs', 'cae', 'gra', 'mw'],
    "puraṃdaracāpa": ['mw'],
    "puraṃdaraharit": ['mw'],
    "puraṃdarapura": ['mw'],
    "puraṃdarapurātithi": ['mw'],
    "puraṃdarapurī": ['mw'],
    "puraṃdaraḥ": ['ap90'],
    "puraṃdarā": ['mw'],
    "puraṃdhi": ['cae', 'gra', 'mw'],
    "puraṃdhivat": ['gra', 'mw'],
    "puraṃdhri": ['cae', 'mw'],
    "puraṃdhriḥ": ['ap90'],
    "puraṃdhrī": ['cae', 'mw'],
    "puraṃjana": ['mw'],
    "puraṃjanacarita": ['mw'],
    "puraṃjananāṭaka": ['mw'],
    "puraṃjanaḥ": ['ap90'],
    "puraṃjanī": ['mw'],
    "puraṃjaraḥ": ['ap90'],
    "puraṃjaya": ['bhs', 'cae', 'mw'],
    "puraṇa": ['mw'],
    "puraṇaḥ": ['ap90'],
    "puraṇḍa": ['mw'],
    "puraṭa": ['mw'],
    "puraṭaṃ": ['ap90'],
    "pure": ['bhs', 'cped'],
    "purebhatta": ['cped'],
    "purebhāga": ['bhs'],
    "purecārika": ['cped'],
    "purejava": ['cped'],
    "purejāta": ['cped'],
    "purekkhāra": ['cped'],
    "puretaraṁ": ['cped'],
    "puri": ['bhs', 'mw'],
    "purikā": ['mw'],
    "purikāya": ['mw'],
    "purikāyā": ['mw'],
    "purima": ['bhs', 'cped'],
    "purimajāti": ['cped'],
    "purimaka": ['bhs'],
    "purimakāraka": ['bhs'],
    "purimataraṁ": ['cped'],
    "purimattabhāva": ['cped'],
    "purindada": ['cped'],
    "purisa": ['cped'],
    "purisadamma": ['cped'],
    "purisadammasārathī": ['cped'],
    "purisakāra": ['cped'],
    "purisaliṅga": ['cped'],
    "purisamedha": ['cped'],
    "purisaparakkama": ['cped'],
    "purisasindriya": ['cped'],
    "purisathāma": ['cped'],
    "purisavyañjana": ['cped'],
    "purisindriya": ['cped'],
    "purisuttama": ['cped'],
    "purisādaka": ['cped'],
    "purisādhama": ['cped'],
    "purisājañña": ['cped'],
    "puritat": ['mw'],
    "puriśaya": ['ap90', 'cae', 'mw'],
    "puriḥ": ['ap90'],
    "puro": ['mw'],
    "puroagni": ['mw'],
    "purobalāka": ['mw'],
    "purobhakta": ['bhs'],
    "purobhaktakā": ['bhs', 'mw'],
    "purobhakṣikā": ['bhs'],
    "purobhāga": ['cae', 'ddsa', 'mw'],
    "purobhāgin": ['cae', 'mw'],
    "purobhāvin": ['mw'],
    "purobhū": ['cae', 'gra', 'mw'],
    "purocana": ['mw'],
    "purodbhava": ['mw'],
    "purodha": ['mw'],
    "purodhas": ['ap90', 'cae', 'ddsa', 'mw'],
    "purodhikā": ['ap90', 'mw'],
    "purodhā": ['ap90', 'cae', 'mw'],
    "purodhākāma": ['mw'],
    "purodhāna": ['mw'],
    "purodhānaṃ": ['ap90'],
    "purodhānīya": ['mw'],
    "purodhātṛ": ['mw'],
    "purodyāna": ['mw'],
    "puroga": ['cae', 'ddsa', 'mw'],
    "purogama": ['cae', 'mw'],
    "purogamana": ['mw'],
    "purogantṛ": ['mw'],
    "purogata": ['mw'],
    "purogati": ['mw'],
    "purogava": ['cae', 'gra', 'mw'],
    "purogavī": ['gra'],
    "purogranthi": ['mw'],
    "puroguru": ['mw'],
    "purogā": ['cae', 'gra', 'mw'],
    "purogāmin": ['mw'],
    "purohan": ['cae', 'gra', 'mw'],
    "purohavis": ['mw'],
    "purohita": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "purohitakarman": ['mw'],
    "purohitatva": ['mw'],
    "purohiti": ['cae', 'gra', 'mw'],
    "purohitikā": ['mw'],
    "purohitya": ['bhs'],
    "purojanman": ['mw'],
    "purojanmatā": ['mw'],
    "purojava": ['bhs', 'mw'],
    "purojiti": ['gra', 'mw'],
    "purojyotis": ['mw'],
    "puroka": ['mw'],
    "purokṣam": ['mw'],
    "purol̤āś": ['mw'],
    "puromukha": ['cae', 'mw'],
    "puromāruta": ['mw'],
    "puromūla": ['cae'],
    "puroniḥsaraṇa": ['ddsa', 'mw'],
    "puronuvākyavant": ['cae'],
    "puronuvākyā": ['cae', 'mw'],
    "puronuvākyāvat": ['mw'],
    "puropanīta": ['mw'],
    "puroratha": ['cae', 'ddsa', 'gra', 'mw'],
    "puroruc": ['cae', 'gra', 'mw'],
    "purorugadhyāya": ['mw'],
    "purorukka": ['mw'],
    "puroruṅmat": ['mw'],
    "purotsava": ['mw'],
    "purottama": ['ddsa'],
    "purovartin": ['cae', 'mw'],
    "purovasu": ['mw'],
    "purovat": ['mw'],
    "purovatsa": ['mw'],
    "purovāda": ['mw'],
    "purovāta": ['cae', 'mw'],
    "purovātasani": ['mw'],
    "purovṛtta": ['mw'],
    "purovṛṣendra": ['mw'],
    "puroyodha": ['cae', 'gra', 'mw'],
    "puroyudh": ['cae', 'gra', 'mw'],
    "puroyāvan": ['gra', 'mw'],
    "puroḍās": ['mw'],
    "puroḍāś": ['cae', 'ddsa', 'gra', 'mw'],
    "puroḍāśa": ['ap90', 'cae', 'mw'],
    "puroḍāśabhuj": ['mw'],
    "puroḍāśabṛgala": ['mw'],
    "puroḍāśahara": ['mw'],
    "puroḍāśasviṣṭakṛt": ['mw'],
    "puroḍāśatā": ['mw'],
    "puroḍāśavatsā": ['mw'],
    "puroḍāśeḍā": ['mw'],
    "puroḍāśika": ['mw'],
    "puroḍāśin": ['mw'],
    "puroḍāśya": ['mw'],
    "puroḍāśīya": ['mw'],
    "puroṭi": ['mw'],
    "puroṭiḥ": ['ap90'],
    "puro’nuvākyā": ['ddsa'],
    "puru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "puruanīka": ['gra'],
    "purubhojas": ['gra', 'mw'],
    "purubhuj": ['cae', 'gra', 'mw'],
    "purubhū": ['gra', 'mw'],
    "purubhūta": ['mw'],
    "purucetana": ['gra', 'mw'],
    "puruda": ['mw'],
    "purudama": ['mw'],
    "purudasma": ['gra', 'mw'],
    "purudasyu": ['mw'],
    "purudatra": ['cae', 'gra', 'mw'],
    "purudaya": ['mw'],
    "purudaṃsa": ['cae', 'gra', 'mw'],
    "purudaṃsas": ['cae', 'gra', 'mw'],
    "purudaṃśaka": ['mw'],
    "purudevacampū": ['mw'],
    "purudha": ['cae', 'gra', 'mw'],
    "purudhapratīka": ['gra', 'mw'],
    "purudhā": ['cae', 'gra', 'mw'],
    "purudina": ['gra', 'mw'],
    "purudrapsa": ['cae', 'gra', 'mw'],
    "purudruh": ['gra', 'mw'],
    "purudvat": ['mw'],
    "purugūrta": ['gra', 'mw'],
    "puruha": ['mw'],
    "puruhanman": ['gra', 'mw'],
    "puruhotra": ['mw'],
    "puruhu": ['mw'],
    "puruhuta": ['mw'],
    "puruhāni": ['ddsa', 'mw'],
    "puruhūta": ['cae', 'gra', 'mw'],
    "puruhūtadviṣ": ['mw'],
    "puruhūtakāṣṭhā": ['mw'],
    "puruhūti": ['mw'],
    "puruhūtā": ['mw'],
    "puruja": ['mw'],
    "purujit": ['cae', 'mw'],
    "purujāta": ['gra', 'mw'],
    "purujāti": ['mw'],
    "purukutsa": ['cae', 'gra', 'mw'],
    "purukutsava": ['mw'],
    "purukutsānī": ['cae', 'gra', 'mw'],
    "purukārakavat": ['mw'],
    "purukṛpā": ['mw'],
    "purukṛt": ['cae', 'gra', 'mw'],
    "purukṛtvan": ['cae', 'gra', 'mw'],
    "purukṣu": ['cae', 'ddsa', 'gra', 'mw'],
    "purulampaṭa": ['mw'],
    "purumadga": ['mw'],
    "purumanas": ['mw'],
    "purumandra": ['gra', 'mw'],
    "purumantu": ['gra', 'mw'],
    "purumayia": ['gra'],
    "purumedha": ['gra', 'mw'],
    "purumedhas": ['mw'],
    "purumitra": ['cae', 'gra', 'mw'],
    "purumāya": ['gra', 'mw'],
    "purumāyin": ['mw'],
    "purumāyya": ['gra', 'mw'],
    "purumīl̤ha": ['mw'],
    "purumīḍha": ['gra', 'mw'],
    "puruniḥṣidh": ['mw'],
    "puruniḥṣidhvan": ['mw'],
    "puruniṣṣidh": ['gra'],
    "puruniṣṣidhvan": ['gra'],
    "puruniṣṭha": ['gra', 'mw'],
    "puruniṣṭhā": ['gra', 'mw'],
    "purunṛmṇa": ['gra', 'mw'],
    "purupanthā": ['gra', 'mw'],
    "purupaśu": ['mw'],
    "purupeśa": ['gra', 'mw'],
    "purupeśas": ['gra', 'mw'],
    "purupraiṣa": ['cae', 'gra', 'mw'],
    "puruprajāta": ['gra', 'mw'],
    "puruprauḍha": ['mw'],
    "purupraśasta": ['gra', 'mw'],
    "purupriya": ['cae', 'gra', 'mw'],
    "puruputra": ['gra', 'mw'],
    "pururatha": ['gra', 'mw'],
    "pururavasa": ['mw'],
    "pururuc": ['gra', 'mw'],
    "pururuj": ['mw'],
    "pururājavaṃśakrama": ['mw'],
    "pururāvan": ['mw'],
    "pururūpa": ['cae', 'gra', 'mw'],
    "purusakāra": ['bhs'],
    "purusambhṛta": ['mw'],
    "purusaṃbhṛta": ['gra'],
    "purusena": ['mw'],
    "puruspārha": ['mw'],
    "puruspṛh": ['gra', 'mw'],
    "purutama": ['gra', 'mw'],
    "purutman": ['gra', 'mw'],
    "purutrā": ['cae', 'gra', 'mw'],
    "puruvarpas": ['gra', 'mw'],
    "puruvartman": ['mw'],
    "puruvaśa": ['mw'],
    "puruvepas": ['gra', 'mw'],
    "puruviśruta": ['mw'],
    "puruvrata": ['gra', 'mw'],
    "puruvāja": ['gra', 'mw'],
    "puruvāra": ['gra', 'mw'],
    "puruvārapuṣṭi": ['gra', 'mw'],
    "puruvī": ['mw'],
    "puruvīra": ['cae', 'gra', 'mw'],
    "puruñja": ['mw'],
    "puruśakti": ['mw'],
    "puruścandra": ['cae', 'gra', 'mw'],
    "puruśiṣṭa": ['mw'],
    "puruśāka": ['cae', 'gra', 'mw'],
    "puruṇāman": ['gra', 'mw'],
    "puruṇītha": ['gra', 'mw'],
    "puruṇḍa": ['mw'],
    "puruṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "puruṣabahumāna": ['mw'],
    "puruṣacchandasa": ['mw'],
    "puruṣadaghna": ['mw'],
    "puruṣadamyasārathi": ['bhs', 'mw'],
    "puruṣadantikā": ['mw'],
    "puruṣadatta": ['mw'],
    "puruṣadharma": ['mw'],
    "puruṣadhaureyaka": ['mw'],
    "puruṣadravyasampad": ['mw'],
    "puruṣadvayasa": ['mw'],
    "puruṣadveṣin": ['mw'],
    "puruṣadveṣiṇī": ['mw'],
    "puruṣadviṣ": ['mw'],
    "puruṣagandhi": ['mw'],
    "puruṣagati": ['mw'],
    "puruṣaghnī": ['mw'],
    "puruṣagātra": ['mw'],
    "puruṣahan": ['mw'],
    "puruṣajana": ['mw'],
    "puruṣajñāna": ['cae', 'mw'],
    "puruṣajātaka": ['mw'],
    "puruṣajīvana": ['mw'],
    "puruṣaka": ['bhs', 'ddsa', 'mw'],
    "puruṣakaḥ": ['ap90'],
    "puruṣakesarin": ['cae', 'mw'],
    "puruṣakuṇapa": ['mw'],
    "puruṣakāma": ['mw'],
    "puruṣakāra": ['cae', 'mw'],
    "puruṣakāraka": ['bhs'],
    "puruṣakāramīmāṃsā": ['mw'],
    "puruṣakāraphala": ['mw'],
    "puruṣakṣetra": ['mw'],
    "puruṣakṣīra": ['mw'],
    "puruṣamedha": ['cae', 'mw'],
    "puruṣamukha": ['mw'],
    "puruṣamānin": ['cae', 'mw'],
    "puruṣamāninitva": ['mw'],
    "puruṣamātra": ['mw'],
    "puruṣamṛga": ['cae', 'mw'],
    "puruṣaniyama": ['mw'],
    "puruṣaniṣkrayaṇa": ['mw'],
    "puruṣanti": ['gra', 'mw'],
    "puruṣanāya": ['mw'],
    "puruṣaparīkṣā": ['mw'],
    "puruṣapati": ['mw'],
    "puruṣapaśu": ['cae', 'mw'],
    "puruṣaprabhu": ['mw'],
    "puruṣapura": ['mw'],
    "puruṣapuṃgava": ['mw'],
    "puruṣapuṇḍarīka": ['mw'],
    "puruṣarakṣas": ['mw'],
    "puruṣareṣaṇa": ['mw'],
    "puruṣareṣin": ['mw'],
    "puruṣarāja": ['mw'],
    "puruṣarūpa": ['mw'],
    "puruṣarūpaka": ['mw'],
    "puruṣarṣabha": ['cae', 'mw'],
    "puruṣasamavāya": ['mw'],
    "puruṣasammita": ['mw'],
    "puruṣasaṃskāra": ['mw'],
    "puruṣasiṃha": ['cae', 'mw'],
    "puruṣasāman": ['mw'],
    "puruṣasāmudrikalakṣaṇa": ['mw'],
    "puruṣasūkta": ['mw'],
    "puruṣasūktabhāṣya": ['mw'],
    "puruṣasūktavidhāna": ['mw'],
    "puruṣasūktavyākhyā": ['mw'],
    "puruṣasūktavyākhyāna": ['mw'],
    "puruṣasūktaṣoḍaśopacāravidhi": ['mw'],
    "puruṣasūktopaniṣad": ['mw'],
    "puruṣatantra": ['mw'],
    "puruṣatantratva": ['mw'],
    "puruṣatejas": ['mw'],
    "puruṣatrā": ['cae', 'gra', 'mw'],
    "puruṣatva": ['cae', 'mw'],
    "puruṣatvatvatā": ['mw'],
    "puruṣatvatā": ['gra'],
    "puruṣatā": ['ap90', 'cae', 'gra', 'mw'],
    "puruṣavacas": ['mw'],
    "puruṣavadha": ['mw'],
    "puruṣavara": ['cae', 'mw'],
    "puruṣavarjita": ['mw'],
    "puruṣavat": ['mw'],
    "puruṣavidha": ['cae', 'mw'],
    "puruṣavidhatā": ['mw'],
    "puruṣavrata": ['mw'],
    "puruṣavyāghra": ['cae', 'mw'],
    "puruṣavāc": ['mw'],
    "puruṣavāha": ['mw'],
    "puruṣavāham": ['mw'],
    "puruṣayogin": ['mw'],
    "puruṣayoni": ['mw'],
    "puruṣaśiras": ['mw'],
    "puruṣaśārdūla": ['mw'],
    "puruṣaśīrṣa": ['mw'],
    "puruṣaśīrṣaka": ['mw'],
    "puruṣaḥ": ['ap90'],
    "puruṣendra": ['mw'],
    "puruṣendratā": ['mw'],
    "puruṣeṣita": ['mw'],
    "puruṣia": ['gra'],
    "puruṣokti": ['mw'],
    "puruṣoktika": ['mw'],
    "puruṣopahāra": ['mw'],
    "puruṣottama": ['cae', 'ddsa', 'mw'],
    "puruṣottamacaritra": ['mw'],
    "puruṣottamakhaṇḍa": ['mw'],
    "puruṣottamakṣetra": ['mw'],
    "puruṣottamakṣetramāhātmya": ['mw'],
    "puruṣottamakṣetratattva": ['mw'],
    "puruṣottamamantra": ['mw'],
    "puruṣottamamāhātmya": ['mw'],
    "puruṣottamapattra": ['mw'],
    "puruṣottamaprakāśakṣetravidhi": ['mw'],
    "puruṣottamapurāṇa": ['mw'],
    "puruṣottamapurīmāhātmya": ['mw'],
    "puruṣottamasahasranāman": ['mw'],
    "puruṣottamatīrtha": ['mw'],
    "puruṣottamatīrthaprayogatattva": ['mw'],
    "puruṣottamavāda": ['mw'],
    "puruṣottamaśāstrīya": ['mw'],
    "puruṣya": ['ap90', 'cae', 'gra', 'mw'],
    "puruṣād": ['cae', 'mw'],
    "puruṣāda": ['mw'],
    "puruṣādaka": ['cae', 'mw'],
    "puruṣādatva": ['mw'],
    "puruṣādhama": ['mw'],
    "puruṣādhikāra": ['mw'],
    "puruṣādya": ['mw'],
    "puruṣāhuti": ['mw'],
    "puruṣājāna": ['mw'],
    "puruṣākāra": ['cae', 'ddsa', 'mw'],
    "puruṣākāratā": ['mw'],
    "puruṣākṛti": ['mw'],
    "puruṣānna": ['mw'],
    "puruṣāntara": ['mw'],
    "puruṣāntaram": ['mw'],
    "puruṣāntaravedin": ['mw'],
    "puruṣāntarātman": ['mw'],
    "puruṣānṛta": ['cae', 'mw'],
    "puruṣārtha": ['cae', 'mw'],
    "puruṣārthacintāmaṇi": ['mw'],
    "puruṣārthakaumudī": ['mw'],
    "puruṣārthakāra": ['mw'],
    "puruṣārtham": ['mw'],
    "puruṣārthaprabodha": ['mw'],
    "puruṣārthaprabodhinī": ['mw'],
    "puruṣārtharatnākara": ['mw'],
    "puruṣārthasiddhyupāya": ['mw'],
    "puruṣārthasudhānidhi": ['mw'],
    "puruṣārthasūtravṛtti": ['mw'],
    "puruṣārthatrayīmaya": ['mw'],
    "puruṣārthatva": ['mw'],
    "puruṣārthānuśāsana": ['mw'],
    "puruṣāstha": ['mw'],
    "puruṣāsthimālin": ['mw'],
    "puruṣāvatāra": ['mw'],
    "puruṣāya": ['mw'],
    "puruṣāyata": ['mw'],
    "puruṣāyate": ['ap90'],
    "puruṣāyaṇa": ['mw'],
    "puruṣāyita": ['ap90', 'mw'],
    "puruṣāyitatva": ['mw'],
    "puruṣāyuṣa": ['mw'],
    "puruṣāyuṣaka": ['mw'],
    "puruṣāśin": ['mw'],
    "puruṣāṃsaka": ['mw'],
    "puruṣāṅga": ['mw'],
    "puruṣī": ['cae', 'ddsa', 'gra', 'mw'],
    "puruṣībhū": ['ddsa', 'mw'],
    "puruṣṭuta": ['cae', 'gra', 'mw'],
    "purv": ['ap90', 'mw'],
    "purvanīka": ['gra'],
    "purvaṇīka": ['mw'],
    "purya": ['cae', 'gra', 'mw'],
    "puryaṣṭa": ['ddsa', 'mw'],
    "puryaṣṭaka": ['mw'],
    "purā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "purādhas": ['mw'],
    "purādhipa": ['cae', 'ddsa', 'mw'],
    "purādhyakṣa": ['cae', 'mw'],
    "purāga": ['mw'],
    "purāhita": ['mw'],
    "purājā": ['cae', 'gra', 'mw'],
    "purākalpa": ['cae', 'mw'],
    "purākalpavid": ['mw'],
    "purākathā": ['ddsa', 'mw'],
    "purākṛta": ['bhs', 'cae', 'mw'],
    "purākṛtaphala": ['mw'],
    "purākṛti": ['mw'],
    "purāmathanavallabha": ['mw'],
    "purānokta": ['mw'],
    "purārdhavistara": ['mw'],
    "purāri": ['cae', 'mw'],
    "purāritva": ['mw'],
    "purārāti": ['mw'],
    "purāsah": ['gra'],
    "purāsaṇī": ['mw'],
    "purāsinī": ['mw'],
    "purāsuhṛd": ['mw'],
    "purātala": ['mw'],
    "purātana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "purātanayogasaṃgraha": ['mw'],
    "purātane": ['mw'],
    "purāvasu": ['mw'],
    "purāvatī": ['mw'],
    "purāvid": ['cae', 'ddsa', 'mw'],
    "purāvṛtta": ['cae', 'mw'],
    "purāvṛttakathā": ['mw'],
    "purāvṛttasah": ['mw'],
    "purāvṛttasāh": ['mw'],
    "purāvṛttākhyāna": ['mw'],
    "purāvṛttākhyānakathana": ['mw'],
    "purāyoni": ['mw'],
    "purāṇa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "purāṇadutiyikā": ['cped'],
    "purāṇadvitīyā": ['mw'],
    "purāṇadānamāhātmya": ['mw'],
    "purāṇadṛṣṭa": ['mw'],
    "purāṇadṛṣṭāntaśataka": ['mw'],
    "purāṇaga": ['mw'],
    "purāṇagir": ['mw'],
    "purāṇagīta": ['mw'],
    "purāṇaka": ['mw'],
    "purāṇakalpa": ['mw'],
    "purāṇamahimopavarṇana": ['mw'],
    "purāṇamāhātmya": ['mw'],
    "purāṇapadārthasaṃgraha": ['mw'],
    "purāṇapañcalakṣaṇa": ['mw'],
    "purāṇapañjī": ['mw'],
    "purāṇaprokta": ['mw'],
    "purāṇapuruṣa": ['mw'],
    "purāṇaratna": ['mw'],
    "purāṇasamuccaya": ['mw'],
    "purāṇasarvasva": ['mw'],
    "purāṇasaṃgraha": ['mw'],
    "purāṇasaṃhitā": ['cae', 'mw'],
    "purāṇasiṃha": ['mw'],
    "purāṇasālohita": ['cped'],
    "purāṇasāra": ['mw'],
    "purāṇasārasaṃgraha": ['mw'],
    "purāṇavat": ['cae', 'gra', 'mw'],
    "purāṇaveda": ['mw'],
    "purāṇavid": ['cae', 'mw'],
    "purāṇavidyā": ['cae', 'mw'],
    "purāṇaśravaṇa": ['mw'],
    "purāṇaśravaṇamahiman": ['mw'],
    "purāṇaśravaṇamāhātmya": ['mw'],
    "purāṇaśravaṇavidhi": ['mw'],
    "purāṇya": ['mw'],
    "purāṇānta": ['mw'],
    "purāṇārkaprabhā": ['mw'],
    "purāṇārthaprakāśaka": ['mw'],
    "purāṇārṇava": ['mw'],
    "purāṇāvatāra": ['mw'],
    "purāṇīya": ['mw'],
    "purāṣa": ['bhs'],
    "purāṭaṅka": ['mw'],
    "purāṭṭa": ['mw'],
    "purī": ['ap90', 'ddsa', 'mw'],
    "purīdāsa": ['mw'],
    "purīkaya": ['mw'],
    "purīkaṣeṇa": ['mw'],
    "purīkāya": ['mw'],
    "purīloka": ['mw'],
    "purīmat": ['mw'],
    "purīmoha": ['mw'],
    "purīndrasena": ['mw'],
    "purītat": ['ap90', 'cae', 'ddsa', 'mw'],
    "purīśreṣṭhā": ['mw'],
    "purīṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "purīṣabheda": ['mw'],
    "purīṣabhedin": ['mw'],
    "purīṣabhīru": ['mw'],
    "purīṣama": ['mw'],
    "purīṣamaḥ": ['ap90'],
    "purīṣamūtrapratighāta": ['mw'],
    "purīṣanigrahaṇa": ['mw'],
    "purīṣapada": ['mw'],
    "purīṣasaṃgrahaṇīya": ['mw'],
    "purīṣavat": ['mw'],
    "purīṣavatī": ['mw'],
    "purīṣavirañjanīya": ['mw'],
    "purīṣavāhana": ['mw'],
    "purīṣavāhaṇa": ['mw'],
    "purīṣaya": ['mw'],
    "purīṣayati": ['ap90'],
    "purīṣaṃ": ['ap90'],
    "purīṣaṇa": ['mw'],
    "purīṣaṇaḥ": ['ap90'],
    "purīṣia": ['gra'],
    "purīṣin": ['cae', 'gra', 'mw'],
    "purīṣita": ['ap90', 'mw'],
    "purīṣotsarga": ['mw'],
    "purīṣya": ['cae', 'ddsa', 'gra', 'mw'],
    "purīṣyavāhana": ['mw'],
    "purīṣādhāna": ['mw'],
    "purīṣī": ['mw'],
    "purū": ['cae', 'mw'],
    "purūcī": ['cae', 'ddsa', 'gra', 'mw'],
    "purūdvaha": ['mw'],
    "purūravas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "purūravasa": ['mw'],
    "purūru": ['gra'],
    "purūruc": ['gra', 'mw'],
    "purūruṇā": ['mw'],
    "purūtama": ['cae', 'gra', 'mw'],
    "purūvasu": ['cae', 'gra', 'mw'],
    "purūvṛt": ['mw'],
    "pus": ['ap90', 'mw'],
    "pust": ['ap90', 'mw'],
    "pusta": ['bhs', 'cae', 'ddsa', 'mw'],
    "pustaka": ['cae', 'mw'],
    "pustakakara": ['mw'],
    "pustakarman": ['mw'],
    "pustakaḥ": ['ap90'],
    "pustakāgāra": ['mw'],
    "pustakāstaraṇa": ['mw'],
    "pustamaya": ['ddsa', 'mw'],
    "pustavārtta": ['mw'],
    "pustaṃ": ['ap90'],
    "pustikā": ['ddsa'],
    "put": ['ap90', 'cae', 'ddsa', 'mw'],
    "puta": ['mw'],
    "puth": ['ap90', 'cae', 'ddsa', 'mw'],
    "puthu": ['cped'],
    "puthubhūta": ['cped'],
    "puthujjana": ['cped'],
    "puthuka": ['cped'],
    "puthula": ['cped'],
    "puthuloma": ['cped'],
    "puthuso": ['cped'],
    "puthuvī": ['cped'],
    "putkasa": ['bhs'],
    "putra": ['cae', 'ddsa', 'gra', 'mw'],
    "putrabhadrā": ['mw'],
    "putrabhāga": ['mw'],
    "putrabhāva": ['mw'],
    "putrabhāṇḍa": ['mw'],
    "putrabhūya": ['mw'],
    "putrada": ['mw'],
    "putradharma": ['mw'],
    "putradharmatas": ['mw'],
    "putradā": ['mw'],
    "putradāra": ['cae', 'mw'],
    "putradātrī": ['mw'],
    "putraghnī": ['mw'],
    "putrahan": ['mw'],
    "putrahata": ['mw'],
    "putrahatī": ['mw'],
    "putrahīna": ['mw'],
    "putrahīnatva": ['mw'],
    "putraiśvarya": ['mw'],
    "putraiṣaṇā": ['ddsa', 'mw'],
    "putrajagdhī": ['mw'],
    "putrajananī": ['mw'],
    "putrajāta": ['mw'],
    "putrajīva": ['mw'],
    "putraka": ['cae', 'gra', 'mw'],
    "putrakalatranāśabhīta": ['mw'],
    "putrakandā": ['mw'],
    "putrakarman": ['mw'],
    "putrakaḥ": ['ap90'],
    "putrakramadīpikā": ['mw'],
    "putrakā": ['ap90', 'mw'],
    "putrakāma": ['cae', 'gra', 'mw'],
    "putrakāmakṛṣṇapañcamīvrata": ['mw'],
    "putrakāmeṣṭi": ['mw'],
    "putrakāmika": ['mw'],
    "putrakāmya": ['mw'],
    "putrakāmyeṣṭi": ['mw'],
    "putrakāmyā": ['cae', 'mw'],
    "putrakārya": ['cae', 'mw'],
    "putrakṛt": ['mw'],
    "putrakṛtaka": ['cae', 'mw'],
    "putrakṛtha": ['cae', 'gra', 'mw'],
    "putrakṛtya": ['cae', 'mw'],
    "putralābha": ['mw'],
    "putralālasa": ['mw'],
    "putramartyā": ['mw'],
    "putramaya": ['cae', 'mw'],
    "putramoṭikāputra": ['bhs', 'mw'],
    "putraniveśana": ['mw'],
    "putranāman": ['mw'],
    "putrapautra": ['cae', 'mw'],
    "putrapautraka": ['mw'],
    "putrapautrikā": ['bhs'],
    "putrapautrin": ['mw'],
    "putrapautrīṇa": ['mw'],
    "putrapautrīṇatā": ['mw'],
    "putraphalabhaktṛ": ['mw'],
    "putrapitṛ": ['cae', 'mw'],
    "putrapiṇḍapālana": ['cae', 'mw'],
    "putraprada": ['mw'],
    "putrapradaśivastotra": ['mw'],
    "putrapradā": ['mw'],
    "putrapratigrahavidhi": ['mw'],
    "putrapratinidhi": ['mw'],
    "putrapravara": ['mw'],
    "putrapriya": ['mw'],
    "putrapura": ['mw'],
    "putraputra": ['mw'],
    "putraputrādinī": ['mw'],
    "putrarodam": ['mw'],
    "putrasahasraka": ['mw'],
    "putrasahasrin": ['mw'],
    "putrasakha": ['mw'],
    "putrasaptamī": ['mw'],
    "putrasaptamīvratakathā": ['mw'],
    "putrasaṃgraha": ['mw'],
    "putrasaṃkarin": ['mw'],
    "putrasena": ['mw'],
    "putrasneha": ['cae', 'mw'],
    "putrasnehamaya": ['mw'],
    "putrasvīkāra": ['mw'],
    "putrasvīkāranirūpaṇa": ['mw'],
    "putrasvīkāranirṇaya": ['mw'],
    "putrasvīkāravidhi": ['mw'],
    "putrasāmaprayoga": ['mw'],
    "putrasū": ['mw'],
    "putratva": ['mw'],
    "putratā": ['cae', 'mw'],
    "putratīrtha": ['mw'],
    "putravadhū": ['mw'],
    "putravala": ['mw'],
    "putravant": ['cae'],
    "putravat": ['cae', 'mw'],
    "putravidya": ['mw'],
    "putraśreṇī": ['mw'],
    "putraśṛṅgī": ['mw'],
    "putraḥ": ['ap90'],
    "putraṃjīva": ['mw'],
    "putraṃjīvaka": ['mw'],
    "putrejyā": ['mw'],
    "putrejyāprayoga": ['mw'],
    "putrepsu": ['mw'],
    "putreṣṭi": ['mw'],
    "putreṣṭikā": ['mw'],
    "putreṣṭiprayoga": ['mw'],
    "putrikā": ['ddsa', 'mw'],
    "putrikābhartṛ": ['mw'],
    "putrikāprasū": ['mw'],
    "putrikāputra": ['mw'],
    "putrikāpūrvaputra": ['mw'],
    "putrikāsuta": ['mw'],
    "putrimant": ['bhs'],
    "putrin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "putriy": ['cae'],
    "putriya": ['ap90', 'cae', 'mw'],
    "putriṇyāpta": ['cae', 'mw'],
    "putriṇī": ['mw'],
    "putrotpattipaddhati": ['mw'],
    "putrotsaṅgā": ['mw'],
    "putrya": ['cae', 'mw'],
    "putryapaśavya": ['mw'],
    "putrācārya": ['cae', 'ddsa', 'mw'],
    "putrādinī": ['mw'],
    "putrānnāda": ['mw'],
    "putrārthin": ['cae', 'mw'],
    "putrī": ['ap90', 'cae', 'ddsa', 'mw'],
    "putrībhū": ['mw'],
    "putrīkaraṇa": ['mw'],
    "putrīkaraṇamīmāṃsā": ['mw'],
    "putrīkṛ": ['ap90', 'cae', 'ddsa'],
    "putrīkṛta": ['mw'],
    "putrīvaṭa": ['bhs'],
    "putrīy": ['cae', 'gra'],
    "putrīya": ['cae', 'ddsa', 'mw'],
    "putrīyasthālīpākaprayoga": ['mw'],
    "putrīyati": ['ap90'],
    "putrīyavargaprayoga": ['mw'],
    "putrīyitṛ": ['mw'],
    "putrīyā": ['ap90', 'mw'],
    "putta": ['cped'],
    "puttadāra": ['cped'],
    "puttaka": ['cped'],
    "puttala": ['cae', 'mw'],
    "puttaladahana": ['mw'],
    "puttalaka": ['cae', 'mw'],
    "puttalakaḥ": ['ap90'],
    "puttalavidhi": ['mw'],
    "puttalavidhāna": ['mw'],
    "puttalaḥ": ['ap90'],
    "puttalī": ['mw'],
    "puttalīcālana": ['mw'],
    "puttalīpūjā": ['mw'],
    "puttikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "puttima": ['cped'],
    "puttiya": ['cped'],
    "puvva": ['bhs'],
    "puñchamāna": ['cped'],
    "puñchana": ['cped'],
    "puñchanta": ['cped'],
    "puñchanī": ['cped'],
    "puñchati": ['bhs', 'cped'],
    "puñchi": ['cped'],
    "puñchita": ['cped'],
    "puñchitvā": ['cped'],
    "puñja": ['cae', 'cped', 'ddsa', 'mw'],
    "puñjakata": ['cped'],
    "puñjarāja": ['mw'],
    "puñjay": ['cae'],
    "puñjaya": ['ddsa', 'mw'],
    "puñjaśas": ['cae', 'mw'],
    "puñji": ['mw'],
    "puñjika": ['mw'],
    "puñjikasthalā": ['mw'],
    "puñjikasthalī": ['mw'],
    "puñjikāstanā": ['mw'],
    "puñjikāsthalā": ['mw'],
    "puñjita": ['mw'],
    "puñjiṣṭha": ['cae', 'mw'],
    "puñjātuka": ['mw'],
    "puñjī": ['mw'],
    "puñjībhū": ['mw'],
    "puñjīkartavya": ['mw'],
    "puñjīkṛ": ['cae', 'ddsa'],
    "puñjīkṛta": ['mw'],
    "puñjīkṛtya": ['mw'],
    "puñjīla": ['mw'],
    "puñña": ['cped'],
    "puññabhāga": ['cped'],
    "puññabhāgī": ['cped'],
    "puññakamma": ['cped'],
    "puññakiriyā": ['cped'],
    "puññakkhandha": ['cped'],
    "puññakkhaya": ['cped'],
    "puññakāma": ['cped'],
    "puññapekkha": ['cped'],
    "puññaphala": ['cped'],
    "puññatthika": ['cped'],
    "puññavant": ['cped'],
    "puññābhisanda": ['cped'],
    "puññānubhāva": ['cped'],
    "puḍ": ['ap90', 'mw'],
    "puḍinī": ['bhs'],
    "puṃ": ['mw'],
    "puṃbhāva": ['cae'],
    "puṃdevata": ['mw'],
    "puṃdhvaja": ['mw'],
    "puṃdāna": ['mw'],
    "puṃdāsa": ['mw'],
    "puṃgala": ['bhs'],
    "puṃgalaḥ": ['ap90'],
    "puṃgava": ['cae', 'mw'],
    "puṃgavaketu": ['mw'],
    "puṃgaḥ": ['ap90'],
    "puṃguṇajantujīva": ['mw'],
    "puṃjanmada": ['mw'],
    "puṃjanmakara": ['mw'],
    "puṃjanman": ['mw'],
    "puṃjanmayoga": ['mw'],
    "puṃjayati": ['ap90'],
    "puṃjaḥ": ['ap90'],
    "puṃjikaḥ": ['ap90'],
    "puṃjita": ['ap90'],
    "puṃjiḥ": ['ap90'],
    "puṃkandā": ['mw'],
    "puṃkhaḥ": ['ap90'],
    "puṃkheṭa": ['mw'],
    "puṃkhita": ['ap90'],
    "puṃkhyāna": ['mw'],
    "puṃkṣura": ['mw'],
    "puṃkṣīra": ['mw'],
    "puṃlakṣman": ['mw'],
    "puṃliṅga": ['cae', 'mw'],
    "puṃliṅgatā": ['mw'],
    "puṃnakṣatra": ['mw'],
    "puṃnapuṃsaka": ['cae', 'mw'],
    "puṃnāga": ['cae', 'mw'],
    "puṃnāmadheya": ['mw'],
    "puṃnāman": ['cae', 'mw'],
    "puṃnāḍa": ['mw'],
    "puṃnāṭa": ['mw'],
    "puṃratna": ['ddsa', 'mw'],
    "puṃrāśi": ['mw'],
    "puṃrūpa": ['mw'],
    "puṃs": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "puṃsa": ['mw'],
    "puṃsaka": ['mw'],
    "puṃsavana": ['cae', 'ddsa', 'mw'],
    "puṃsavanaprayoga": ['mw'],
    "puṃsavant": ['cae'],
    "puṃsavanādiprayoga": ['mw'],
    "puṃsavat": ['mw'],
    "puṃska": ['cae', 'mw'],
    "puṃskarmāśaya": ['mw'],
    "puṃskaṭī": ['cae', 'mw'],
    "puṃskokila": ['cae', 'ddsa', 'mw'],
    "puṃskokilatva": ['mw'],
    "puṃskāmā": ['mw'],
    "puṃskṛtyā": ['mw'],
    "puṃsoka": ['mw'],
    "puṃsprajanana": ['mw'],
    "puṃspravāda": ['mw'],
    "puṃsputra": ['mw'],
    "puṃsti": ['mw'],
    "puṃstraya": ['mw'],
    "puṃstrī": ['cae', 'mw'],
    "puṃstva": ['cae', 'mw'],
    "puṃstvadoṣa": ['mw'],
    "puṃstvavigraha": ['mw'],
    "puṃstvaṃ": ['ap90'],
    "puṃsuvana": ['cae', 'mw'],
    "puṃsvat": ['mw'],
    "puṃsānuja": ['mw'],
    "puṃsī": ['mw'],
    "puṃsū": ['mw'],
    "puṃvadvidhāna": ['mw'],
    "puṃvat": ['ap90', 'cae', 'mw'],
    "puṃvatsa": ['mw'],
    "puṃveṣa": ['mw'],
    "puṃviṣaya": ['mw'],
    "puṃvyañjana": ['mw'],
    "puṃvṛṣa": ['mw'],
    "puṃyoga": ['mw'],
    "puṃyuj": ['mw'],
    "puṃyāna": ['mw'],
    "puṃś": ['mw'],
    "puṃśabda": ['mw'],
    "puṃścalī": ['cae', 'ddsa', 'mw'],
    "puṃścalīcala": ['mw'],
    "puṃścalīputra": ['cae', 'mw'],
    "puṃścalīya": ['cae', 'mw'],
    "puṃścalū": ['cae', 'mw'],
    "puṃśchagalā": ['mw'],
    "puṃścihna": ['mw'],
    "puṃścora": ['mw'],
    "puṃḍ": ['ap90'],
    "puṃḍaryaṃ": ['ap90'],
    "puṃḍarīkaṃ": ['ap90'],
    "puṃḍaḥ": ['ap90'],
    "puṃḍrakaḥ": ['ap90'],
    "puṃḍraḥ": ['ap90'],
    "puṃṭ": ['ap90'],
    "puṅga": ['mw'],
    "puṅgala": ['mw'],
    "puṅgava": ['cped', 'ddsa', 'mw'],
    "puṅgī": ['mw'],
    "puṅkha": ['cae', 'cped', 'ddsa', 'mw'],
    "puṅkhilatīrtha": ['mw'],
    "puṅkhita": ['mw'],
    "puṅkhitaśara": ['cae', 'mw'],
    "puṇ": ['ap90', 'mw'],
    "puṇaka": ['mw'],
    "puṇatāmakara": ['mw'],
    "puṇi": ['cped'],
    "puṇika": ['mw'],
    "puṇikā": ['mw'],
    "puṇitvā": ['cped'],
    "puṇya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "puṇyabala": ['mw'],
    "puṇyabharita": ['mw'],
    "puṇyabhāj": ['mw'],
    "puṇyabhājin": ['mw'],
    "puṇyabhū": ['mw'],
    "puṇyabhūmi": ['mw'],
    "puṇyadarśana": ['mw'],
    "puṇyadatta": ['bhs'],
    "puṇyaduh": ['mw'],
    "puṇyagandha": ['cae', 'gra', 'mw'],
    "puṇyagandhi": ['cae', 'mw'],
    "puṇyagandhin": ['cae', 'mw'],
    "puṇyageha": ['mw'],
    "puṇyagṛha": ['mw'],
    "puṇyaikakarman": ['mw'],
    "puṇyajala": ['mw'],
    "puṇyajana": ['cae', 'mw'],
    "puṇyajaneśvara": ['mw'],
    "puṇyajanman": ['mw'],
    "puṇyajita": ['mw'],
    "puṇyaka": ['cae', 'mw'],
    "puṇyakarman": ['cae', 'mw'],
    "puṇyakartṛ": ['cae', 'mw'],
    "puṇyakavrata": ['mw'],
    "puṇyakaṃ": ['ap90'],
    "puṇyaketu": ['bhs'],
    "puṇyakriyā": ['cae', 'mw'],
    "puṇyakriyāvastu": ['bhs'],
    "puṇyakusumaprabha": ['bhs'],
    "puṇyakuṭa": ['mw'],
    "puṇyakāla": ['mw'],
    "puṇyakālatā": ['mw'],
    "puṇyakālavidhi": ['mw'],
    "puṇyakīrti": ['mw'],
    "puṇyakṛt": ['cae', 'mw'],
    "puṇyakṛtyā": ['cae', 'mw'],
    "puṇyakṣetra": ['mw'],
    "puṇyalabdha": ['mw'],
    "puṇyalakṣmīka": ['mw'],
    "puṇyaloka": ['cae', 'mw'],
    "puṇyamahas": ['mw'],
    "puṇyamaheśākhya": ['bhs', 'mw'],
    "puṇyamanya": ['mw'],
    "puṇyamaya": ['mw'],
    "puṇyamitra": ['mw'],
    "puṇyanivaha": ['mw'],
    "puṇyanāman": ['mw'],
    "puṇyanāmaślokāvalī": ['mw'],
    "puṇyanātha": ['mw'],
    "puṇyaparitrātar": ['bhs'],
    "puṇyaparvatatejas": ['bhs'],
    "puṇyaphala": ['cae', 'mw'],
    "puṇyaprabha": ['bhs'],
    "puṇyaprabhāsaśri": ['bhs'],
    "puṇyaprada": ['mw'],
    "puṇyapradīpadhvaja": ['bhs'],
    "puṇyapradīpasaṃpatketuprabhā": ['bhs'],
    "puṇyaprasava": ['bhs', 'mw'],
    "puṇyapratāpa": ['mw'],
    "puṇyapuruṣa": ['mw'],
    "puṇyapuṇyatā": ['mw'],
    "puṇyapālarājakathā": ['mw'],
    "puṇyapāpekṣitṛ": ['cae', 'mw'],
    "puṇyapāvana": ['mw'],
    "puṇyaraśmi": ['bhs'],
    "puṇyarāja": ['mw'],
    "puṇyarātra": ['mw'],
    "puṇyarāśi": ['bhs', 'mw'],
    "puṇyasama": ['bhs', 'mw'],
    "puṇyasamam": ['mw'],
    "puṇyasambhāra": ['mw'],
    "puṇyasaṃcaya": ['mw'],
    "puṇyasena": ['mw'],
    "puṇyaskandha": ['mw'],
    "puṇyastambhakara": ['mw'],
    "puṇyasthāna": ['mw'],
    "puṇyasumeru": ['bhs'],
    "puṇyasumerūdgata": ['bhs'],
    "puṇyasundara": ['mw'],
    "puṇyasundaragaṇī": ['mw'],
    "puṇyasāra": ['mw'],
    "puṇyatara": ['mw'],
    "puṇyatarīkṛ": ['mw'],
    "puṇyatva": ['mw'],
    "puṇyatā": ['cae', 'mw'],
    "puṇyatīrtha": ['cae', 'mw'],
    "puṇyatṛṇa": ['mw'],
    "puṇyavaha": ['mw'],
    "puṇyavallabha": ['mw'],
    "puṇyavant": ['bhs', 'cae'],
    "puṇyavardhana": ['mw'],
    "puṇyavarjita": ['mw'],
    "puṇyavarman": ['mw'],
    "puṇyavat": ['ap90', 'mw'],
    "puṇyavatī": ['mw'],
    "puṇyavijita": ['mw'],
    "puṇyavāgbuddhikarmin": ['mw'],
    "puṇyayoga": ['mw'],
    "puṇyaśakuna": ['mw'],
    "puṇyaśeṣa": ['mw'],
    "puṇyaśloka": ['cae', 'mw'],
    "puṇyaślokeyakarman": ['mw'],
    "puṇyaślokā": ['mw'],
    "puṇyaśrīgarbha": ['bhs', 'mw'],
    "puṇyaśrīka": ['mw'],
    "puṇyaśālā": ['mw'],
    "puṇyaśīla": ['cae', 'mw'],
    "puṇyodaka": ['mw'],
    "puṇyodakā": ['mw'],
    "puṇyodaya": ['mw'],
    "puṇyodyāna": ['mw'],
    "puṇyokta": ['mw'],
    "puṇyā": ['mw'],
    "puṇyābha": ['bhs'],
    "puṇyāgni": ['mw'],
    "puṇyāha": ['cae', 'mw'],
    "puṇyāhamantra": ['mw'],
    "puṇyāhaprayoga": ['mw'],
    "puṇyāhasvana": ['mw'],
    "puṇyāhavācana": ['cae', 'mw'],
    "puṇyāhavācanaprayoga": ['mw'],
    "puṇyāhaśabda": ['mw'],
    "puṇyākara": ['mw'],
    "puṇyālaṃkāra": ['bhs'],
    "puṇyālaṃkṛta": ['mw'],
    "puṇyānagara": ['mw'],
    "puṇyānandanātha": ['mw'],
    "puṇyānubhāva": ['mw'],
    "puṇyātman": ['cae', 'ddsa', 'mw'],
    "puṇyāśaya": ['mw'],
    "puṇyīkṛ": ['mw'],
    "puṇāti": ['cped'],
    "puṇḍ": ['mw'],
    "puṇḍa": ['bhs', 'mw'],
    "puṇḍakakṣa": ['bhs', 'mw'],
    "puṇḍara": ['bhs'],
    "puṇḍarin": ['mw'],
    "puṇḍarisrajā": ['cae', 'mw'],
    "puṇḍarya": ['mw'],
    "puṇḍarīka": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "puṇḍarīkadalopama": ['mw'],
    "puṇḍarīkakavi": ['mw'],
    "puṇḍarīkalocana": ['cae', 'mw'],
    "puṇḍarīkamukha": ['cae', 'mw'],
    "puṇḍarīkamukhī": ['mw'],
    "puṇḍarīkanayana": ['cae', 'mw'],
    "puṇḍarīkanetra": ['bhs'],
    "puṇḍarīkapalāśākṣa": ['mw'],
    "puṇḍarīkaplava": ['mw'],
    "puṇḍarīkapura": ['mw'],
    "puṇḍarīkapuramāhātmya": ['mw'],
    "puṇḍarīkapurāṇa": ['mw'],
    "puṇḍarīkarājan": ['bhs'],
    "puṇḍarīkavanamāhātmya": ['mw'],
    "puṇḍarīkavat": ['mw'],
    "puṇḍarīkaviṭṭhala": ['mw'],
    "puṇḍarīkekṣaṇa": ['mw'],
    "puṇḍarīkiṇī": ['mw'],
    "puṇḍarīkodaraprabha": ['mw'],
    "puṇḍarīkā": ['bhs', 'mw'],
    "puṇḍarīkākṣa": ['bhs', 'cae', 'mw'],
    "puṇḍarīkākṣakopaniṣad": ['mw'],
    "puṇḍarīkākṣastotra": ['mw'],
    "puṇḍarīkānvaya": ['mw'],
    "puṇḍarīkātapatra": ['mw'],
    "puṇḍarīyaka": ['mw'],
    "puṇḍavardhana": ['bhs', 'mw'],
    "puṇḍhra": ['mw'],
    "puṇḍra": ['cae', 'ddsa', 'mw'],
    "puṇḍraka": ['mw'],
    "puṇḍrakakṣa": ['mw'],
    "puṇḍrakeli": ['mw'],
    "puṇḍranagara": ['mw'],
    "puṇḍrastotra": ['mw'],
    "puṇḍravardhana": ['mw'],
    "puṇḍravidhi": ['mw'],
    "puṇḍrekṣu": ['mw'],
    "puṇṇa": ['cped'],
    "puṇṇacanda": ['cped'],
    "puṇṇaghaṭa": ['cped'],
    "puṇṇamāsī": ['cped'],
    "puṇṇamī": ['cped'],
    "puṇṇapatta": ['cped'],
    "puṇṇatta": ['cped'],
    "puṇṇatā": ['cped'],
    "puṇṭ": ['mw'],
    "puṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "puṣa": ['mw'],
    "puṣia": ['gra'],
    "puṣita": ['mw'],
    "puṣka": ['mw'],
    "puṣkala": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "puṣkalaka": ['cae', 'mw'],
    "puṣkalakaḥ": ['ap90'],
    "puṣkalamocana": ['mw'],
    "puṣkalatā": ['bhs'],
    "puṣkalavijaya": ['mw'],
    "puṣkaletra": ['ddsa', 'mw'],
    "puṣkalāvarta": ['mw'],
    "puṣkalāvartaka": ['ddsa', 'mw'],
    "puṣkalāvartamāhātmya": ['mw'],
    "puṣkalāvata": ['bhs', 'ddsa', 'mw'],
    "puṣkalāvatī": ['mw'],
    "puṣkalāṅga": ['bhs'],
    "puṣkalī": ['mw'],
    "puṣkara": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "puṣkarabīja": ['mw'],
    "puṣkaracūḍa": ['mw'],
    "puṣkaradvīpa": ['mw'],
    "puṣkaraja": ['mw'],
    "puṣkarakalpa": ['mw'],
    "puṣkarakarṇikā": ['mw'],
    "puṣkaramukha": ['mw'],
    "puṣkaramāhātmya": ['mw'],
    "puṣkaramālin": ['mw'],
    "puṣkaramūla": ['mw'],
    "puṣkaramūlaka": ['mw'],
    "puṣkaranābha": ['mw'],
    "puṣkaranāḍī": ['mw'],
    "puṣkarapalāśa": ['mw'],
    "puṣkaraparṇa": ['mw'],
    "puṣkaraparṇikā": ['mw'],
    "puṣkaraparṇī": ['mw'],
    "puṣkarapattra": ['mw'],
    "puṣkarapattranetra": ['mw'],
    "puṣkarapriya": ['mw'],
    "puṣkaraprādurbhāva": ['mw'],
    "puṣkarapurāṇa": ['mw'],
    "puṣkarasad": ['mw'],
    "puṣkarasraj": ['gra', 'mw'],
    "puṣkarasthapati": ['mw'],
    "puṣkarasāda": ['mw'],
    "puṣkarasādi": ['mw'],
    "puṣkarasādin": ['mw'],
    "puṣkarasāgara": ['mw'],
    "puṣkarasārin": ['bhs', 'mw'],
    "puṣkarasārī": ['bhs', 'mw'],
    "puṣkaratā": ['bhs'],
    "puṣkaratīrtha": ['mw'],
    "puṣkaravana": ['mw'],
    "puṣkaravanamāhātmya": ['mw'],
    "puṣkaravanaprādurbhāva": ['mw'],
    "puṣkaraviṣṭara": ['mw'],
    "puṣkaravyāghra": ['mw'],
    "puṣkaraśikhā": ['mw'],
    "puṣkaraśikā": ['mw'],
    "puṣkaraśiphā": ['mw'],
    "puṣkaraśāyikā": ['mw'],
    "puṣkaraṃ": ['ap90'],
    "puṣkaraṇī": ['bhs'],
    "puṣkarekṣaṇa": ['ddsa', 'mw'],
    "puṣkarikā": ['ap90', 'ddsa', 'mw'],
    "puṣkarin": ['ap90', 'cae', 'ddsa', 'mw'],
    "puṣkariṇī": ['ap90', 'bhs', 'gra', 'mw'],
    "puṣkaroddhṛta": ['mw'],
    "puṣkarācchādikā": ['mw'],
    "puṣkarāgra": ['mw'],
    "puṣkarāhva": ['mw'],
    "puṣkarāhvaya": ['mw'],
    "puṣkarākhya": ['mw'],
    "puṣkarākṣa": ['cae', 'mw'],
    "puṣkarāraṇya": ['cae', 'mw'],
    "puṣkarāruṇi": ['mw'],
    "puṣkarāstika": ['bhs'],
    "puṣkarāvartaka": ['cae', 'mw'],
    "puṣkarāvatī": ['mw'],
    "puṣkarāya": ['mw'],
    "puṣkarāyate": ['ap90'],
    "puṣkarāṅghrija": ['mw'],
    "puṣkarāṣṭaka": ['mw'],
    "puṣkarī": ['mw'],
    "puṣkasa": ['ddsa', 'mw'],
    "puṣkaśa": ['mw'],
    "puṣkaṃ": ['ap90'],
    "puṣkiriṇī": ['bhs', 'mw'],
    "puṣkiriṇīkā": ['bhs'],
    "puṣkiriṇīya": ['bhs'],
    "puṣp": ['ap90'],
    "puṣpa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "puṣpabali": ['mw'],
    "puṣpabaṭuka": ['mw'],
    "puṣpabhadra": ['cae', 'mw'],
    "puṣpabhadraka": ['mw'],
    "puṣpabhadrā": ['mw'],
    "puṣpabhava": ['mw'],
    "puṣpabhaṅga": ['mw'],
    "puṣpabherotsa": ['bhs', 'mw'],
    "puṣpabhājana": ['cae', 'mw'],
    "puṣpabhūti": ['mw'],
    "puṣpabhūṣaṇa": ['mw'],
    "puṣpabhūṣita": ['mw'],
    "puṣpabāṇa": ['cae', 'mw'],
    "puṣpabāṇavilāsa": ['mw'],
    "puṣpacaya": ['mw'],
    "puṣpacintāmaṇi": ['mw'],
    "puṣpacāmara": ['mw'],
    "puṣpacāpa": ['cae', 'mw'],
    "puṣpacūla": ['mw'],
    "puṣpacūlā": ['mw'],
    "puṣpada": ['mw'],
    "puṣpadanta": ['bhs', 'cae', 'mw'],
    "puṣpadantabhid": ['mw'],
    "puṣpadantatīrtha": ['mw'],
    "puṣpadantavat": ['mw'],
    "puṣpadantānvaya": ['mw'],
    "puṣpadantī": ['bhs', 'mw'],
    "puṣpadatta": ['bhs'],
    "puṣpadaṃṣṭra": ['mw'],
    "puṣpadha": ['cae', 'mw'],
    "puṣpadhanus": ['cae', 'mw'],
    "puṣpadhanvan": ['cae', 'mw'],
    "puṣpadhvaja": ['bhs', 'mw'],
    "puṣpadhāraṇa": ['mw'],
    "puṣpadrava": ['mw'],
    "puṣpadruma": ['mw'],
    "puṣpadrumakusumitamukuṭa": ['bhs', 'mw'],
    "puṣpadāman": ['mw'],
    "puṣpagaṇḍikā": ['mw'],
    "puṣpaghātaka": ['mw'],
    "puṣpagiri": ['mw'],
    "puṣpagranthana": ['mw'],
    "puṣpagṛha": ['mw'],
    "puṣpahārin": ['mw'],
    "puṣpahāsa": ['mw'],
    "puṣpahāsā": ['mw'],
    "puṣpahīna": ['mw'],
    "puṣpahīnā": ['mw'],
    "puṣpaja": ['mw'],
    "puṣpajā": ['mw'],
    "puṣpajāti": ['mw'],
    "puṣpaka": ['cae', 'ddsa', 'mw'],
    "puṣpakaraṇḍa": ['cae', 'mw'],
    "puṣpakaraṇḍaka": ['mw'],
    "puṣpakaraṇḍakodyāna": ['cae'],
    "puṣpakaraṇḍinī": ['mw'],
    "puṣpakaraṇḍodyāna": ['mw'],
    "puṣpakarṇa": ['mw'],
    "puṣpakavimāna": ['mw'],
    "puṣpakaṃ": ['ap90'],
    "puṣpaketana": ['mw'],
    "puṣpaketu": ['bhs', 'cae', 'mw'],
    "puṣpakāla": ['cae', 'mw'],
    "puṣpakāra": ['mw'],
    "puṣpakāsīsa": ['mw'],
    "puṣpakāsīsaka": ['mw'],
    "puṣpakīṭa": ['mw'],
    "puṣpakūṭadhāraṇī": ['bhs'],
    "puṣpakṛta": ['bhs'],
    "puṣpalaka": ['mw'],
    "puṣpalakaḥ": ['ap90'],
    "puṣpalih": ['mw'],
    "puṣpalikṣa": ['mw'],
    "puṣpalipi": ['bhs', 'mw'],
    "puṣpaloha": ['bhs'],
    "puṣpalāva": ['mw'],
    "puṣpalāvī": ['cae', 'mw'],
    "puṣpalīlā": ['mw'],
    "puṣpamaya": ['cae', 'mw'],
    "puṣpamañjarikā": ['mw'],
    "puṣpamañjarimaṇḍita": ['bhs'],
    "puṣpamaṇḍitā": ['bhs'],
    "puṣpamegha": ['cae', 'mw'],
    "puṣpameghīkṛ": ['mw'],
    "puṣpamitra": ['cae', 'mw'],
    "puṣpamitrasabhā": ['mw'],
    "puṣpamālakathā": ['mw'],
    "puṣpamālin": ['mw'],
    "puṣpamālā": ['cae', 'mw'],
    "puṣpamālāmaya": ['mw'],
    "puṣpamās": ['mw'],
    "puṣpamāsa": ['mw'],
    "puṣpamātham": ['mw'],
    "puṣpanetra": ['mw'],
    "puṣpanikara": ['mw'],
    "puṣpanikṣa": ['mw'],
    "puṣpaniryāsa": ['mw'],
    "puṣpaniryāsaka": ['mw'],
    "puṣpanivāsinī": ['bhs'],
    "puṣpanyāsa": ['mw'],
    "puṣpanāṭaka": ['mw'],
    "puṣpapadavī": ['mw'],
    "puṣpapatha": ['mw'],
    "puṣpapattra": ['mw'],
    "puṣpapattrin": ['mw'],
    "puṣpapaṭa": ['mw'],
    "puṣpapeśala": ['cae', 'mw'],
    "puṣpaphala": ['cae', 'mw'],
    "puṣpaphaladruma": ['mw'],
    "puṣpaphalavat": ['mw'],
    "puṣpapracaya": ['mw'],
    "puṣpapracāya": ['mw'],
    "puṣpapracāyikā": ['mw'],
    "puṣpapura": ['mw'],
    "puṣpapurī": ['mw'],
    "puṣpapuṭa": ['bhs', 'mw'],
    "puṣpapāṇḍu": ['mw'],
    "puṣparacana": ['mw'],
    "puṣparajas": ['mw'],
    "puṣparakta": ['mw'],
    "puṣparasa": ['mw'],
    "puṣparasāhvaya": ['mw'],
    "puṣparatha": ['mw'],
    "puṣpareṇu": ['mw'],
    "puṣparocana": ['mw'],
    "puṣparāga": ['cae', 'mw'],
    "puṣparāja": ['mw'],
    "puṣpasa": ['mw'],
    "puṣpasakaṭikānimittajñāna": ['mw'],
    "puṣpasamaya": ['mw'],
    "puṣpasaurabhā": ['mw'],
    "puṣpasitā": ['mw'],
    "puṣpasnāna": ['mw'],
    "puṣpasraj": ['mw'],
    "puṣpasveda": ['mw'],
    "puṣpasādhāraṇa": ['mw'],
    "puṣpasāra": ['cae', 'mw'],
    "puṣpasārasudhānidhi": ['mw'],
    "puṣpasārā": ['mw'],
    "puṣpasāyaka": ['cae', 'mw'],
    "puṣpasūtra": ['cae', 'mw'],
    "puṣpasūtrabhāṣya": ['mw'],
    "puṣpavahā": ['mw'],
    "puṣpavana": ['mw'],
    "puṣpavanamāhātmya": ['mw'],
    "puṣpavant": ['cae'],
    "puṣpavartman": ['mw'],
    "puṣpavarṣa": ['cae', 'mw'],
    "puṣpavat": ['ap90', 'gra', 'mw'],
    "puṣpavatī": ['mw'],
    "puṣpaveṇī": ['mw'],
    "puṣpavicitrā": ['mw'],
    "puṣpaviśikha": ['mw'],
    "puṣpavāhana": ['mw'],
    "puṣpavāhinī": ['mw'],
    "puṣpavāṭikā": ['mw'],
    "puṣpavāṭī": ['mw'],
    "puṣpavṛkṣa": ['mw'],
    "puṣpavṛṣṭi": ['mw'],
    "puṣpayamaka": ['mw'],
    "puṣpaśakalin": ['mw'],
    "puṣpaśakaṭikā": ['mw'],
    "puṣpaśakaṭī": ['mw'],
    "puṣpaśakaṭījñāna": ['mw'],
    "puṣpaśakuna": ['mw'],
    "puṣpaśara": ['mw'],
    "puṣpaśarāsana": ['mw'],
    "puṣpaśayyā": ['cae', 'mw'],
    "puṣpaśekhara": ['cae', 'mw'],
    "puṣpaśilīmukha": ['mw'],
    "puṣpaśrīgarbha": ['bhs', 'mw'],
    "puṣpaśūnya": ['mw'],
    "puṣpaṃ": ['ap90'],
    "puṣpaṃdhaya": ['mw'],
    "puṣpaṃdhayaḥ": ['ap90'],
    "puṣpendra": ['bhs'],
    "puṣpeṣu": ['cae', 'ddsa', 'mw'],
    "puṣpika": ['bhs'],
    "puṣpikā": ['ap90', 'mw'],
    "puṣpin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "puṣpita": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "puṣpitaka": ['bhs', 'mw'],
    "puṣpitapalāśapratima": ['mw'],
    "puṣpitā": ['mw'],
    "puṣpitāgra": ['cae', 'mw'],
    "puṣpitāgrā": ['mw'],
    "puṣpitākṣa": ['mw'],
    "puṣpitākṣitva": ['mw'],
    "puṣpiṇī": ['ap90', 'mw'],
    "puṣpodakā": ['mw'],
    "puṣpodbhava": ['ddsa', 'mw'],
    "puṣpodyāna": ['mw'],
    "puṣpopagama": ['mw'],
    "puṣpopajīvin": ['mw'],
    "puṣpotkaṭā": ['cae', 'mw'],
    "puṣpottara": ['mw'],
    "puṣputtara": ['bhs'],
    "puṣpy": ['cae'],
    "puṣpya": ['ddsa', 'mw'],
    "puṣpā": ['ap90', 'bhs', 'mw'],
    "puṣpābhikīrṇa": ['mw'],
    "puṣpābhiṣeka": ['mw'],
    "puṣpāgama": ['cae', 'mw'],
    "puṣpāgra": ['mw'],
    "puṣpāhara": ['mw'],
    "puṣpāhvā": ['mw'],
    "puṣpājīva": ['mw'],
    "puṣpājīvin": ['mw'],
    "puṣpākara": ['bhs', 'ddsa', 'mw'],
    "puṣpākaradeva": ['mw'],
    "puṣpāmbhas": ['mw'],
    "puṣpāmbu": ['mw'],
    "puṣpāmoda": ['ddsa'],
    "puṣpānana": ['mw'],
    "puṣpānta": ['mw'],
    "puṣpānuga": ['mw'],
    "puṣpāpaṇa": ['mw'],
    "puṣpāpīḍa": ['mw'],
    "puṣpārpaṇa": ['mw'],
    "puṣpārāma": ['cae', 'mw'],
    "puṣpārṇa": ['mw'],
    "puṣpāsava": ['mw'],
    "puṣpāstaraka": ['mw'],
    "puṣpāstaraṇa": ['mw'],
    "puṣpāstra": ['mw'],
    "puṣpāsāra": ['mw'],
    "puṣpāvacaya": ['mw'],
    "puṣpāvacāyikā": ['mw'],
    "puṣpāvacāyin": ['mw'],
    "puṣpāvakīrṇa": ['bhs', 'mw'],
    "puṣpāvalivanarājikusumitābhijña": ['bhs', 'mw'],
    "puṣpāvant": ['cae'],
    "puṣpāvat": ['mw'],
    "puṣpāvatī": ['bhs', 'mw'],
    "puṣpāvatīvanarājasaṃkusumitābhijña": ['bhs'],
    "puṣpāya": ['mw'],
    "puṣpāyudha": ['cae', 'mw'],
    "puṣpāñjali": ['mw'],
    "puṣpāñjalistotra": ['mw'],
    "puṣpāñjalyaṣṭaka": ['mw'],
    "puṣpāñjana": ['mw'],
    "puṣpāśin": ['mw'],
    "puṣpāṇanāda": ['ddsa'],
    "puṣpāṇanāḍa": ['mw'],
    "puṣpāṇḍa": ['mw'],
    "puṣpāṇḍaka": ['mw'],
    "puṣya": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "puṣyadharman": ['bhs', 'mw'],
    "puṣyagupti": ['bhs'],
    "puṣyala": ['bhs'],
    "puṣyalaka": ['mw'],
    "puṣyalakaḥ": ['ap90'],
    "puṣyalipi": ['mw'],
    "puṣyamitra": ['bhs', 'mw'],
    "puṣyanetra": ['mw'],
    "puṣyaratha": ['mw'],
    "puṣyase": ['cae', 'ddsa'],
    "puṣyasnāna": ['mw'],
    "puṣyayaśas": ['mw'],
    "puṣyaḥ": ['ap90'],
    "puṣyā": ['mw'],
    "puṣyābhiṣeka": ['mw'],
    "puṣā": ['mw'],
    "puṣṇāti": ['bhs'],
    "puṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "puṣṭapati": ['mw'],
    "puṣṭatva": ['mw'],
    "puṣṭatā": ['mw'],
    "puṣṭavipuṣṭa": ['mw'],
    "puṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "puṣṭicchu": ['mw'],
    "puṣṭida": ['mw'],
    "puṣṭidā": ['mw'],
    "puṣṭidāvan": ['mw'],
    "puṣṭigu": ['gra', 'mw'],
    "puṣṭika": ['mw'],
    "puṣṭikara": ['ddsa', 'mw'],
    "puṣṭikarman": ['mw'],
    "puṣṭikā": ['ap90', 'mw'],
    "puṣṭikāma": ['mw'],
    "puṣṭikānta": ['mw'],
    "puṣṭilīlāṭīkā": ['mw'],
    "puṣṭimant": ['cae'],
    "puṣṭimat": ['gra', 'mw'],
    "puṣṭimati": ['mw'],
    "puṣṭimbhara": ['gra', 'mw'],
    "puṣṭimārga": ['mw'],
    "puṣṭipati": ['mw'],
    "puṣṭipravāhamaryādābheda": ['mw'],
    "puṣṭipravāhamaryādābhedavivaraṇa": ['mw'],
    "puṣṭivardhana": ['cae', 'gra', 'mw'],
    "puṣṭiśrāddha": ['mw'],
    "puṣṭiḥ": ['ap90'],
    "puṣṭyartha": ['mw'],
    "puṣṭārtha": ['mw'],
    "puṣṭāvat": ['gra', 'mw'],
    "puṣṭāṅga": ['cae', 'ddsa', 'mw'],
    "puṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "puṭa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "puṭabaddha": ['cped'],
    "puṭabhatta": ['cped'],
    "puṭabheda": ['mw'],
    "puṭabhedaka": ['mw'],
    "puṭabhedana": ['cped', 'mw'],
    "puṭabhid": ['mw'],
    "puṭadhenu": ['mw'],
    "puṭagrīva": ['mw'],
    "puṭaka": ['cae', 'cped', 'mw'],
    "puṭakanda": ['mw'],
    "puṭakaṃ": ['ap90'],
    "puṭakinī": ['ap90', 'cae', 'ddsa', 'mw'],
    "puṭakinīpattra": ['mw'],
    "puṭakānuvāsana": ['mw'],
    "puṭana": ['mw'],
    "puṭannaṭa": ['mw'],
    "puṭapāka": ['mw'],
    "puṭapākayukti": ['mw'],
    "puṭaḥ": ['ap90'],
    "puṭaṁsa": ['cped'],
    "puṭikā": ['ap90', 'ddsa', 'mw'],
    "puṭita": ['ap90', 'mw'],
    "puṭodaka": ['mw'],
    "puṭoṭaja": ['mw'],
    "puṭāhvaya": ['mw'],
    "puṭālu": ['mw'],
    "puṭāpuṭikā": ['mw'],
    "puṭāpuṭī": ['bhs'],
    "puṭāñjali": ['mw'],
    "puṭī": ['ap90', 'mw'],
    "puṭīkṛ": ['ddsa'],
    "puṭṭ": ['ap90', 'mw'],
    "puṭṭha": ['cped'],
    "pyai": ['ap90', 'ddsa', 'mw'],
    "pyukṣṇa": ['cae', 'mw'],
    "pyus": ['mw'],
    "pyuṣ": ['mw'],
    "pyā": ['cae', 'gra'],
    "pyāna": ['ap90', 'mw'],
    "pyāta": ['mw'],
    "pyāy": ['ap90', 'mw'],
    "pyāyana": ['ap90', 'mw'],
    "pyāyita": ['ap90', 'mw'],
    "pyāṭ": ['ap90', 'mw'],
    "pā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pābhata": ['cped'],
    "pācaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "pācakastrī": ['mw'],
    "pācakatva": ['mw'],
    "pācala": ['ap90', 'mw'],
    "pācana": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "pācanaka": ['mw'],
    "pācanakaḥ": ['ap90'],
    "pācanikā": ['ap90'],
    "pācanī": ['mw'],
    "pācanīya": ['bhs', 'mw'],
    "pācariya": ['cped'],
    "pācata": ['mw'],
    "pācatti": ['bhs'],
    "pācayitṛ": ['mw'],
    "pāceti": ['cped'],
    "pāci": ['mw'],
    "pācikā": ['cped', 'mw'],
    "pācikābhārya": ['mw'],
    "pācya": ['mw'],
    "pācā": ['ap90', 'mw'],
    "pācāpesi": ['cped'],
    "pācāpeti": ['cped'],
    "pācāpetvā": ['cped'],
    "pācāpita": ['cped'],
    "pācī": ['mw'],
    "pācīkaṭu": ['mw'],
    "pācīna": ['cped'],
    "pācīnadisā": ['cped'],
    "pācīnamukha": ['cped'],
    "pād": ['cae', 'ddsa', 'gra', 'mw'],
    "pāda": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "pādabaddha": ['mw'],
    "pādabandha": ['bhs', 'cae', 'mw'],
    "pādabandhana": ['mw'],
    "pādabhaṭa": ['cae', 'mw'],
    "pādabhāga": ['cae', 'mw'],
    "pādabhāj": ['mw'],
    "pādacatura": ['mw'],
    "pādacatvara": ['mw'],
    "pādacchedana": ['mw'],
    "pādacihna": ['mw'],
    "pādacāpala": ['mw'],
    "pādacāpalya": ['mw'],
    "pādacāra": ['cae', 'mw'],
    "pādacāreṇa": ['mw'],
    "pādacārin": ['cae', 'mw'],
    "pādadhāvana": ['cae', 'ddsa', 'mw'],
    "pādadhāvanikā": ['bhs', 'mw'],
    "pādadāha": ['mw'],
    "pādadārikā": ['mw'],
    "pādadārī": ['mw'],
    "pādagaṇḍira": ['mw'],
    "pādaghṛta": ['mw'],
    "pādagrahaṇa": ['cae', 'mw'],
    "pādagranthi": ['mw'],
    "pādagṛhya": ['cae', 'gra', 'mw'],
    "pādaharṣa": ['mw'],
    "pādahāraka": ['mw'],
    "pādahīnāt": ['mw'],
    "pādaiḥ": ['mw'],
    "pādaja": ['mw'],
    "pādajala": ['cae', 'mw'],
    "pādajāha": ['mw'],
    "pādaka": ['bhs', 'cae', 'cped', 'gra', 'mw'],
    "pādakajjhāna": ['cped'],
    "pādakaṭaka": ['cae', 'mw'],
    "pādakaṭhalikā": ['cped'],
    "pādakramika": ['mw'],
    "pādakramikaḥ": ['ap90'],
    "pādakula": ['mw'],
    "pādakuṭhārikā": ['mw'],
    "pādakīlikā": ['mw'],
    "pādakṛcchra": ['mw'],
    "pādakṣepa": ['mw'],
    "pādalagna": ['cae', 'mw'],
    "pādalepa": ['mw'],
    "pādalepasiddhi": ['mw'],
    "pādalikhitalipi": ['bhs'],
    "pādalipta": ['mw'],
    "pādaliptasūri": ['mw'],
    "pādalola": ['cped'],
    "pādamadhyayamaka": ['mw'],
    "pādamaya": ['bhs'],
    "pādamañjarī": ['mw'],
    "pādamiśra": ['mw'],
    "pādamudrā": ['cae', 'mw'],
    "pādamudrāpaṅkti": ['mw'],
    "pādamātra": ['mw'],
    "pādamūla": ['cae', 'mw'],
    "pādamūle": ['cped'],
    "pādamūlika": ['bhs', 'cped'],
    "pādanakha": ['cae', 'mw'],
    "pādanamra": ['ddsa', 'mw'],
    "pādanicṛt": ['mw'],
    "pādaniketa": ['mw'],
    "pādaniṣka": ['mw'],
    "pādanyāsa": ['cae', 'mw'],
    "pādanālikā": ['mw'],
    "pādapa": ['cae', 'cped', 'mw'],
    "pādapaddhati": ['cae', 'mw'],
    "pādapadma": ['cae', 'mw'],
    "pādapadmopajīvin": ['mw'],
    "pādapaka": ['bhs'],
    "pādapakhaṇḍa": ['mw'],
    "pādaparicāraka": ['mw'],
    "pādaparuhā": ['mw'],
    "pādapatana": ['cae', 'mw'],
    "pādapatita": ['mw'],
    "pādapavivakṣā": ['mw'],
    "pādaphalaka": ['bhs'],
    "pādaphalā": ['mw'],
    "pādapopagamana": ['mw'],
    "pādapopagata": ['mw'],
    "pādapradhāraṇa": ['mw'],
    "pādaprahāra": ['cae', 'mw'],
    "pādaprakaraṇasaṃgati": ['mw'],
    "pādaprakṣālana": ['cae', 'mw'],
    "pādaprasveda": ['mw'],
    "pādaprasvedin": ['mw'],
    "pādaprasāraṇa": ['mw'],
    "pādapratiṣṭhāna": ['mw'],
    "pādapraṇāma": ['mw'],
    "pādapuñchana": ['cped'],
    "pādapuṭī": ['mw'],
    "pādapā": ['mw'],
    "pādapādadhāvana": ['mw'],
    "pādapālikā": ['mw'],
    "pādapāricārikā": ['cped'],
    "pādapāśa": ['mw'],
    "pādapāśī": ['mw'],
    "pādapīṭha": ['cae', 'cped', 'mw'],
    "pādapīṭhikā": ['mw'],
    "pādapūraṇa": ['cae', 'mw'],
    "pādarajas": ['cae', 'mw'],
    "pādarajju": ['mw'],
    "pādarakṣa": ['mw'],
    "pādarakṣaṇa": ['mw'],
    "pādarakṣikā": ['mw'],
    "pādarathī": ['mw'],
    "pādarohaṇa": ['mw'],
    "pādasambāhana": ['cped'],
    "pādasaṃhitā": ['mw'],
    "pādasevana": ['mw'],
    "pādasevā": ['mw'],
    "pādasphoṭa": ['mw'],
    "pādastambha": ['mw'],
    "pādasvedana": ['mw'],
    "pādasvedanika": ['mw'],
    "pādatala": ['cae', 'cped', 'mw'],
    "pādatale": ['mw'],
    "pādatalāhati": ['mw'],
    "pādatas": ['cae', 'mw'],
    "pādatra": ['cae', 'mw'],
    "pādatradhāraṇa": ['mw'],
    "pādatrāṇa": ['cae', 'mw'],
    "pādavalimīka": ['mw'],
    "pādavanda": ['bhs'],
    "pādavandana": ['cae', 'mw'],
    "pādavandanika": ['mw'],
    "pādavant": ['cae'],
    "pādavat": ['mw'],
    "pādaveṣṭanika": ['mw'],
    "pādaveṣṭanikā": ['bhs'],
    "pādavidhāna": ['mw'],
    "pādavigraha": ['mw'],
    "pādavika": ['mw'],
    "pādavikaḥ": ['ap90'],
    "pādavirajas": ['mw'],
    "pādavyākhyāna": ['mw'],
    "pādavī": ['mw'],
    "pādavṛtta": ['mw'],
    "pādaya": ['mw'],
    "pādayamaka": ['mw'],
    "pādayuddha": ['mw'],
    "pādaśabda": ['mw'],
    "pādaśaila": ['mw'],
    "pādaśas": ['cae', 'mw'],
    "pādaśauca": ['cae', 'mw'],
    "pādaśeṣa": ['mw'],
    "pādaśotha": ['mw'],
    "pādaśuśruṣā": ['mw'],
    "pādaśākhā": ['mw'],
    "pādaḥ": ['ap90'],
    "pādaṅguli": ['cped'],
    "pādaṅguṭṭha": ['cped'],
    "pādaṭṭhika": ['cped'],
    "pāddhata": ['mw'],
    "pādegṛhya": ['mw'],
    "pādeṣṭakā": ['mw'],
    "pādika": ['ap90', 'ddsa', 'mw'],
    "pādikā": ['mw'],
    "pādin": ['ap90', 'cae', 'mw'],
    "pādinaḥ": ['ap90'],
    "pādma": ['mw'],
    "pādmamantra": ['mw'],
    "pādmamaṇḍalārcana": ['mw'],
    "pādmanityapūjāvidhi": ['mw'],
    "pādmaprayoga": ['mw'],
    "pādmapurāṇa": ['mw'],
    "pādmasaṃhitā": ['mw'],
    "pādmasaṃhitāprayoga": ['mw'],
    "pādmavacana": ['mw'],
    "pādmavedamantra": ['mw'],
    "pādmottara": ['mw'],
    "pādodaka": ['cae', 'cped', 'mw'],
    "pādodakatīrtha": ['mw'],
    "pādodara": ['mw'],
    "pādoddhūta": ['mw'],
    "pādona": ['cae', 'mw'],
    "pādopadhāna": ['mw'],
    "pādopadhānī": ['mw'],
    "pādopajīvin": ['mw'],
    "pādopasaṅgrahaṇa": ['ddsa'],
    "pādotphāla": ['mw'],
    "pādu": ['cae', 'ddsa', 'gra', 'mw'],
    "pāduka": ['ap90', 'cae', 'mw'],
    "pādukavat": ['mw'],
    "pādukin": ['mw'],
    "pādukā": ['cae', 'cped', 'mw'],
    "pādukākāra": ['mw'],
    "pādukākṛt": ['mw'],
    "pādukāmantra": ['mw'],
    "pādukāsahasra": ['mw'],
    "pādukāsahasraparīkṣā": ['mw'],
    "pādya": ['ap90', 'cae', 'ddsa', 'mw'],
    "pādyaka": ['mw'],
    "pādābhivandana": ['cae', 'mw'],
    "pādābhivādana": ['cae', 'mw'],
    "pādādhiṣṭhāna": ['bhs', 'mw'],
    "pādādhyāsa": ['mw'],
    "pādādi": ['mw'],
    "pādādimadhyayamaka": ['mw'],
    "pādādiyamaka": ['mw'],
    "pādādyantayamaka": ['mw'],
    "pādāghāta": ['cae', 'mw'],
    "pādāgra": ['cae', 'ddsa', 'mw'],
    "pādāgrasthita": ['mw'],
    "pādāhata": ['mw'],
    "pādāhati": ['cae', 'mw'],
    "pādākulaka": ['mw'],
    "pādālika": ['mw'],
    "pādālinda": ['mw'],
    "pādālindī": ['mw'],
    "pādāliṃdaḥ": ['ap90'],
    "pādāmbhas": ['mw'],
    "pādāmbu": ['mw'],
    "pādānata": ['mw'],
    "pādānta": ['cae', 'ddsa', 'mw'],
    "pādāntara": ['cae', 'mw'],
    "pādāntare": ['mw'],
    "pādāntayamaka": ['mw'],
    "pādāntikam": ['mw'],
    "pādānudhyāna": ['mw'],
    "pādānudhyāta": ['mw'],
    "pādānukramaṇī": ['mw'],
    "pādānuprāsa": ['mw'],
    "pādāraka": ['mw'],
    "pādārakaḥ": ['ap90'],
    "pādāravinda": ['mw'],
    "pādāravindaśataka": ['mw'],
    "pādārdha": ['cae', 'mw'],
    "pādārghya": ['mw'],
    "pādārpaṇa": ['cae', 'mw'],
    "pādāsana": ['mw'],
    "pādāsi": ['cped'],
    "pādāsphālana": ['mw'],
    "pādāstaraka": ['bhs'],
    "pādāt": ['ap90', 'mw'],
    "pādāta": ['cae', 'ddsa', 'mw'],
    "pādātaḥ": ['ap90'],
    "pādāti": ['mw'],
    "pādātika": ['mw'],
    "pādātiḥ": ['ap90'],
    "pādāvaneja": ['mw'],
    "pādāvanejana": ['cae', 'mw'],
    "pādāvanejanī": ['mw'],
    "pādāvanejya": ['mw'],
    "pādāvanektṛ": ['mw'],
    "pādāvanāma": ['mw'],
    "pādāvarta": ['mw'],
    "pādāvasecana": ['cae', 'mw'],
    "pādāvika": ['mw'],
    "pādāyana": ['mw'],
    "pādāṃśika": ['mw'],
    "pādāṅgada": ['cae', 'mw'],
    "pādāṅgadī": ['mw'],
    "pādāṅguli": ['cae'],
    "pādāṅgulī": ['cae'],
    "pādāṅgulīyaka": ['mw'],
    "pādāṅguṣṭha": ['cae', 'mw'],
    "pādāṅguṣṭhaśritāvani": ['mw'],
    "pādāṅguṣṭhikā": ['mw'],
    "pādāṣṭhīla": ['mw'],
    "pādū": ['ap90', 'cae', 'mw'],
    "pādūdara": ['cped'],
    "pādūkṛt": ['mw'],
    "pādūlaka": ['mw'],
    "pādūna": ['cae', 'mw'],
    "pāgabbhiya": ['cped'],
    "pāgala": ['ap90', 'mw'],
    "pāguññatā": ['cped'],
    "pāhaṇapura": ['mw'],
    "pāhesi": ['cped'],
    "pāheti": ['cped'],
    "pāhiḍā": ['mw'],
    "pāhuṇa": ['cped'],
    "pāhuṇeyya": ['cped'],
    "pāhāta": ['mw'],
    "pāhāḍikā": ['mw'],
    "pāja": ['ddsa', 'mw'],
    "pājaka": ['cae', 'mw'],
    "pājana": ['cped'],
    "pājas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pājasia": ['gra'],
    "pājasvant": ['cae'],
    "pājasvat": ['mw'],
    "pājasya": ['cae', 'mw'],
    "pājenta": ['cped'],
    "pājesi": ['cped'],
    "pājeta": ['cped'],
    "pājeti": ['cped'],
    "pājetvā": ['cped'],
    "pājika": ['mw'],
    "pājita": ['cped'],
    "pājrya": ['mw'],
    "pājāpeti": ['cped'],
    "pāka": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "pākabali": ['cae', 'mw'],
    "pākabhedaka": ['mw'],
    "pākabhāṇḍa": ['cae', 'mw'],
    "pākadviṣ": ['mw'],
    "pākadūrvā": ['ddsa', 'gra', 'mw'],
    "pākahantṛ": ['mw'],
    "pākahaṃsa": ['mw'],
    "pākaja": ['mw'],
    "pākajaprakriyā": ['mw'],
    "pākajatva": ['mw'],
    "pākajavicāra": ['mw'],
    "pākakarmanibandha": ['mw'],
    "pākakriyā": ['mw'],
    "pākakuṭī": ['mw'],
    "pākakṛṣṇa": ['mw'],
    "pākakṛṣṇaphala": ['mw'],
    "pākala": ['cae', 'ddsa', 'mw'],
    "pākalaḥ": ['ap90'],
    "pākali": ['mw'],
    "pākalā": ['mw'],
    "pākalī": ['mw'],
    "pākamatsya": ['mw'],
    "pākaniṣūdana": ['mw'],
    "pākapaṇḍita": ['mw'],
    "pākaphala": ['mw'],
    "pākapuṭī": ['mw'],
    "pākapātra": ['cae', 'mw'],
    "pākarañjana": ['mw'],
    "pākasaṃsthā": ['mw'],
    "pākasthāman": ['gra', 'mw'],
    "pākasthāna": ['mw'],
    "pākasutvan": ['gra', 'mw'],
    "pākatika": ['cped'],
    "pākatrā": ['cae', 'ddsa', 'gra', 'mw'],
    "pākavat": ['cae', 'gra', 'mw'],
    "pākavatī": ['mw'],
    "pākavaṭṭa": ['cped'],
    "pākayajña": ['cae', 'mw'],
    "pākayajñanirṇaya": ['mw'],
    "pākayajñapaddhati": ['mw'],
    "pākayajñaprakāśa": ['mw'],
    "pākayajñaprayoga": ['mw'],
    "pākayajñavidhi": ['mw'],
    "pākayajñika": ['cae', 'mw'],
    "pākayajñiya": ['cae', 'mw'],
    "pākaśaṃsa": ['cae', 'gra', 'mw'],
    "pākaśuklā": ['mw'],
    "pākaśālā": ['mw'],
    "pākaśāsana": ['cae', 'ddsa', 'mw'],
    "pākaśāsani": ['mw'],
    "pākaśāstra": ['mw'],
    "pākaṭa": ['cped'],
    "pākhaṃḍaḥ": ['ap90'],
    "pākhaṇḍa": ['cae', 'mw'],
    "pākima": ['ap90', 'cae', 'mw'],
    "pākiman": ['mw'],
    "pākin": ['ap90', 'mw'],
    "pākiā": ['gra'],
    "pāku": ['mw'],
    "pākuka": ['mw'],
    "pākuḥ": ['ap90'],
    "pākya": ['ap90', 'cae', 'mw'],
    "pākyā": ['cae', 'ddsa', 'gra', 'mw'],
    "pākādhyāya": ['mw'],
    "pākādisaṃgraha": ['mw'],
    "pākāgāra": ['ddsa', 'mw'],
    "pākāra": ['cped'],
    "pākāraparikkhitta": ['cped'],
    "pākāri": ['mw'],
    "pākāru": ['cae', 'mw'],
    "pākātyaya": ['mw'],
    "pākātīsāra": ['mw'],
    "pākātīta": ['mw'],
    "pākāvalī": ['mw'],
    "pākṣa": ['ap90', 'mw'],
    "pākṣapātika": ['ap90', 'cae', 'ddsa', 'mw'],
    "pākṣika": ['ap90', 'cae', 'ddsa', 'mw'],
    "pākṣikasūtravṛtti": ['mw'],
    "pākṣāyaṇa": ['mw'],
    "pāl": ['mw'],
    "pāla": ['cae', 'cped', 'ddsa', 'mw'],
    "pālada": ['mw'],
    "pālaghna": ['mw'],
    "pālahāri": ['ddsa', 'mw'],
    "pālajagato": ['bhs'],
    "pālaka": ['bhs', 'cae', 'cped', 'mw'],
    "pālakagotra": ['mw'],
    "pālakavirāja": ['mw'],
    "pālakaḥ": ['ap90'],
    "pālakka": ['mw'],
    "pālakyaḥ": ['ap90'],
    "pālakyā": ['mw'],
    "pālakākhyā": ['mw'],
    "pālakāpya": ['mw'],
    "pālakāpyaḥ": ['ap90'],
    "pālakāvya": ['mw'],
    "pālala": ['ap90', 'mw'],
    "pālaloka": ['bhs'],
    "pālana": ['ap90', 'cae', 'cped', 'mw'],
    "pālanakarman": ['cae', 'mw'],
    "pālanavṛtti": ['mw'],
    "pālanā": ['cped'],
    "pālanīya": ['ap90', 'cae', 'mw'],
    "pālavaṇij": ['mw'],
    "pālavī": ['mw'],
    "pālay": ['cae'],
    "pālaya": ['ddsa'],
    "pālayitṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "pālaśaka": ['mw'],
    "pālaḥ": ['ap90'],
    "pālaṃkaḥ": ['ap90'],
    "pālaṅgin": ['mw'],
    "pālaṅka": ['mw'],
    "pālaṅkya": ['mw'],
    "pālaṅkī": ['mw'],
    "pālenta": ['cped'],
    "pālesi": ['cped'],
    "pāletabba": ['cped'],
    "pāletar": ['cped'],
    "pāleti": ['cped'],
    "pāletuṁ": ['cped'],
    "pāletvā": ['cped'],
    "pālevata": ['bhs', 'ddsa'],
    "pāleya": ['mw'],
    "pāli": ['cae', 'cped', 'ddsa', 'mw'],
    "pālibhaṅga": ['ddsa', 'mw'],
    "pālicca": ['cped'],
    "pālijvara": ['mw'],
    "pālika": ['bhs'],
    "pālikā": ['ap90', 'ddsa', 'mw'],
    "pālin": ['cae', 'ddsa', 'mw'],
    "pālinda": ['mw'],
    "pālindhī": ['mw'],
    "pālindī": ['mw'],
    "pālinī": ['mw'],
    "pālita": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "pālitaka": ['bhs'],
    "pālitakoṭa": ['bhs'],
    "pālitya": ['cae', 'mw'],
    "pālityaṃ": ['ap90'],
    "pālitā": ['mw'],
    "pāliśāyana": ['mw'],
    "pāliḥ": ['ap90'],
    "pāliṃdaḥ": ['ap90'],
    "pāliṃhira": ['mw'],
    "pāllaka": ['mw'],
    "pāllavika": ['mw'],
    "pāllavā": ['ap90', 'mw'],
    "pālohaya": ['mw'],
    "pālvala": ['ap90', 'cae', 'mw'],
    "pālvalatīra": ['mw'],
    "pālya": ['cae', 'ddsa', 'mw'],
    "pālyāmaya": ['mw'],
    "pālāgala": ['cae', 'mw'],
    "pālāgalī": ['mw'],
    "pālāśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "pālāśakalpa": ['mw'],
    "pālāśakarman": ['mw'],
    "pālāśakhaṇḍa": ['mw'],
    "pālāśavidhi": ['mw'],
    "pālāśaṣaṇḍa": ['mw'],
    "pālāśi": ['mw'],
    "pālī": ['cae', 'ddsa', 'mw'],
    "pālīvata": ['mw'],
    "pālīvrata": ['mw'],
    "pāma": ['bhs', 'mw'],
    "pāmaghna": ['mw'],
    "pāmaghnī": ['mw'],
    "pāman": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāmana": ['ap90', 'cae', 'mw'],
    "pāmanambhāvuka": ['mw'],
    "pāmara": ['ap90', 'ddsa', 'mw'],
    "pāmaroddhārā": ['mw'],
    "pāmavat": ['mw'],
    "pāmaṅga": ['cped'],
    "pāmeti": ['cped'],
    "pāmojja": ['cped'],
    "pāmokkha": ['cped'],
    "pāmpa": ['mw'],
    "pāmpaka": ['mw'],
    "pāmpālī": ['mw'],
    "pāmpī": ['mw'],
    "pāmujja": ['cped'],
    "pāmā": ['ap90', 'mw'],
    "pāmāra": ['mw'],
    "pāmāri": ['mw'],
    "pāmāvaṭika": ['mw'],
    "pāna": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "pānabhojana": ['cae', 'mw'],
    "pānabhājana": ['mw'],
    "pānabhāṇḍa": ['cae', 'mw'],
    "pānabhū": ['mw'],
    "pānabhūmi": ['mw'],
    "pānabhūmī": ['mw'],
    "pānadoṣa": ['mw'],
    "pānagoṣṭhikā": ['mw'],
    "pānagoṣṭhī": ['mw'],
    "pānaja": ['mw'],
    "pānaka": ['cae', 'cped', 'mw'],
    "pānakarasarāgāsavayojana": ['mw'],
    "pānakarasāsavarāgayojana": ['mw'],
    "pānakaṃ": ['ap90'],
    "pānakumbha": ['mw'],
    "pānamada": ['cae', 'mw'],
    "pānamantra": ['mw'],
    "pānamatta": ['cae', 'mw'],
    "pānamaṅgala": ['mw'],
    "pānamaṇḍala": ['cped'],
    "pānapa": ['cae', 'mw'],
    "pānapara": ['mw'],
    "pānaprasakta": ['mw'],
    "pānaprasaktahṛdaya": ['mw'],
    "pānapātra": ['cae', 'mw'],
    "pānarata": ['mw'],
    "pānasa": ['ddsa', 'mw'],
    "pānasaindhava": ['mw'],
    "pānasindhu": ['mw'],
    "pānavat": ['mw'],
    "pānavaṇij": ['mw'],
    "pānavibhrama": ['mw'],
    "pānaśauṇḍa": ['mw'],
    "pānaṃ": ['ap90'],
    "pānika": ['mw'],
    "pānikaḥ": ['ap90'],
    "pānila": ['mw'],
    "pānilaṃ": ['ap90'],
    "pānnaga": ['mw'],
    "pānnejana": ['mw'],
    "pānnāgāra": ['mw'],
    "pānnāgāri": ['mw'],
    "pānta": ['cae', 'gra', 'mw'],
    "pāntha": ['cae', 'ddsa', 'mw'],
    "pānthadevatā": ['mw'],
    "pānthatva": ['mw'],
    "pānthāyana": ['mw'],
    "pānāghāta": ['mw'],
    "pānāgāra": ['cped', 'mw'],
    "pānājīrṇaka": ['mw'],
    "pānātyaya": ['mw'],
    "pānīya": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "pānīyabhājana": ['cped'],
    "pānīyacāṭi": ['cped'],
    "pānīyacūrṇikā": ['mw'],
    "pānīyadūṣaka": ['mw'],
    "pānīyaghaṭa": ['cped'],
    "pānīyagocara": ['mw'],
    "pānīyakumārarasa": ['mw'],
    "pānīyakākikā": ['mw'],
    "pānīyamālaka": ['cped'],
    "pānīyamūlaka": ['mw'],
    "pānīyanakula": ['mw'],
    "pānīyapala": ['mw'],
    "pānīyaphala": ['mw'],
    "pānīyapṛṣṭhaja": ['mw'],
    "pānīyasālā": ['cped'],
    "pānīyataṇḍulīya": ['mw'],
    "pānīyathālikā": ['cped'],
    "pānīyavarṇikā": ['mw'],
    "pānīyavarṣa": ['cae', 'mw'],
    "pānīyavārika": ['mw'],
    "pānīyaśālikā": ['mw'],
    "pānīyaśālā": ['mw'],
    "pānīyaśīta": ['mw'],
    "pānīysālā": ['cped'],
    "pānīyādhyakṣa": ['mw'],
    "pānīyālu": ['mw'],
    "pānīyāmalaka": ['mw'],
    "pānīyārtham": ['mw'],
    "pānīyāśrā": ['mw'],
    "pāpa": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "pāpabandha": ['cae', 'mw'],
    "pāpabhakṣaṇa": ['mw'],
    "pāpabhañjana": ['mw'],
    "pāpabhāj": ['cae', 'mw'],
    "pāpabhāva": ['mw'],
    "pāpabuddhi": ['cae', 'mw'],
    "pāpacaila": ['mw'],
    "pāpacaka": ['mw'],
    "pāpacara": ['mw'],
    "pāpacelikā": ['mw'],
    "pāpacelī": ['mw'],
    "pāpacetas": ['cae', 'mw'],
    "pāpacetasa": ['cped'],
    "pāpacārin": ['mw'],
    "pāpada": ['mw'],
    "pāpadarśana": ['mw'],
    "pāpadarśin": ['mw'],
    "pāpadeśanā": ['mw'],
    "pāpadhamma": ['cped'],
    "pāpadhī": ['mw'],
    "pāpadṛśvan": ['mw'],
    "pāpadṛṣṭi": ['mw'],
    "pāpagati": ['mw'],
    "pāpaghna": ['mw'],
    "pāpaghnī": ['mw'],
    "pāpaghnīmāhātmya": ['mw'],
    "pāpagocara": ['mw'],
    "pāpagraha": ['mw'],
    "pāpahan": ['cae', 'mw'],
    "pāpahara": ['mw'],
    "pāpaharā": ['mw'],
    "pāpahṛdaya": ['mw'],
    "pāpaja": ['mw'],
    "pāpajīva": ['mw'],
    "pāpaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "pāpakalpa": ['cae', 'mw'],
    "pāpakamma": ['cped'],
    "pāpakammanta": ['cped'],
    "pāpakammī": ['cped'],
    "pāpakara": ['cped', 'mw'],
    "pāpakaraṇa": ['cped'],
    "pāpakarmakṛt": ['mw'],
    "pāpakarman": ['cae', 'mw'],
    "pāpakarmin": ['mw'],
    "pāpakartṛ": ['mw'],
    "pāpakāraka": ['mw'],
    "pāpakārin": ['cae', 'mw'],
    "pāpakārī": ['cped'],
    "pāpakṛt": ['cae', 'mw'],
    "pāpakṛta": ['cae', 'mw'],
    "pāpakṛtvan": ['mw'],
    "pāpakṛtya": ['mw'],
    "pāpakṛtyā": ['mw'],
    "pāpakṣaya": ['mw'],
    "pāpakṣayatīrtha": ['mw'],
    "pāpala": ['ap90', 'mw'],
    "pāpaloka": ['cae', 'mw'],
    "pāpalokya": ['mw'],
    "pāpam": ['mw'],
    "pāpamati": ['cae', 'mw'],
    "pāpamaya": ['mw'],
    "pāpamitra": ['mw'],
    "pāpamitratva": ['mw'],
    "pāpamitta": ['cped'],
    "pāpamittatā": ['cped'],
    "pāpamocana": ['mw'],
    "pāpamocanī": ['mw'],
    "pāpamukta": ['mw'],
    "pāpanakṣatra": ['mw'],
    "pāpanirati": ['mw'],
    "pāpaniścaya": ['cae', 'mw'],
    "pāpaniṣkṛti": ['mw'],
    "pāpanāman": ['mw'],
    "pāpanāpita": ['mw'],
    "pāpanāśana": ['mw'],
    "pāpanāśanamāhātmya": ['mw'],
    "pāpanāśin": ['mw'],
    "pāpaparājita": ['mw'],
    "pāpapati": ['mw'],
    "pāpaphala": ['mw'],
    "pāpapraśamanastava": ['mw'],
    "pāpapriya": ['mw'],
    "pāpapuruṣa": ['mw'],
    "pāpapurī": ['mw'],
    "pāpapuṇya": ['mw'],
    "pāpapūruṣa": ['mw'],
    "pāparahita": ['cae', 'mw'],
    "pāparddhi": ['mw'],
    "pāparddhika": ['mw'],
    "pāparddhiḥ": ['ap90'],
    "pāparipu": ['mw'],
    "pāparoga": ['cae', 'mw'],
    "pāparogin": ['mw'],
    "pāparākṣasī": ['mw'],
    "pāpasama": ['cae', 'mw'],
    "pāpasammita": ['mw'],
    "pāpasamācāra": ['mw'],
    "pāpasaṃkalpa": ['mw'],
    "pāpasaṃśamana": ['mw'],
    "pāpasaṅkappa": ['cped'],
    "pāpaskandha": ['mw'],
    "pāpasupina": ['cped'],
    "pāpasūdanatīrtha": ['mw'],
    "pāpatara": ['mw'],
    "pāpati": ['mw'],
    "pāpatimira": ['mw'],
    "pāpattika": ['bhs'],
    "pāpatva": ['cae', 'gra', 'mw'],
    "pāpatā": ['mw'],
    "pāpavasyasa": ['mw'],
    "pāpavasīyas": ['mw'],
    "pāpavasīyasa": ['mw'],
    "pāpavinigraha": ['mw'],
    "pāpaviniścaya": ['mw'],
    "pāpavināśa": ['mw'],
    "pāpavināśatīrtha": ['mw'],
    "pāpavāda": ['mw'],
    "pāpaya": ['mw'],
    "pāpayakṣma": ['mw'],
    "pāpayakṣmagṛhīta": ['mw'],
    "pāpayallava": ['mw'],
    "pāpayoni": ['cae', 'mw'],
    "pāpayā": ['mw'],
    "pāpayāmuyā": ['mw'],
    "pāpaśamana": ['mw'],
    "pāpaśamanī": ['mw'],
    "pāpaśodhana": ['mw'],
    "pāpaśīla": ['cae', 'mw'],
    "pāpaśīlatva": ['mw'],
    "pāpaṇika": ['cped'],
    "pāpaṭhaka": ['mw'],
    "pāpenta": ['cped'],
    "pāpesi": ['cped'],
    "pāpeti": ['cped'],
    "pāpetvā": ['cped'],
    "pāpeya": ['bhs'],
    "pāpikā": ['cped'],
    "pāpimant": ['cped'],
    "pāpin": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāpita": ['cped'],
    "pāpiya": ['cped'],
    "pāpiṣṭha": ['ap90', 'cae', 'mw'],
    "pāpiṣṭhatama": ['mw'],
    "pāpiṣṭhatara": ['mw'],
    "pāpman": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāpokta": ['mw'],
    "pāpurati": ['cped'],
    "pāpuraṇa": ['cped'],
    "pāpuṇana": ['cped'],
    "pāpuṇanta": ['cped'],
    "pāpuṇi": ['cped'],
    "pāpuṇituṁ": ['cped'],
    "pāpuṇitvā": ['cped'],
    "pāpuṇāti": ['cped'],
    "pāpā": ['bhs', 'mw'],
    "pāpācāra": ['ddsa', 'mw'],
    "pāpādhama": ['mw'],
    "pāpāha": ['cae', 'mw'],
    "pāpāhi": ['mw'],
    "pāpāka": ['mw'],
    "pāpākhyā": ['mw'],
    "pāpānta": ['mw'],
    "pāpāntikā": ['mw'],
    "pāpānubandha": ['cae', 'mw'],
    "pāpānuvasita": ['mw'],
    "pāpāpanutti": ['mw'],
    "pāpāpurī": ['mw'],
    "pāpārambhaka": ['cae', 'mw'],
    "pāpātman": ['cae', 'mw'],
    "pāpāvahīyam": ['mw'],
    "pāpāya": ['mw'],
    "pāpāśya": ['mw'],
    "pāpāṅkuśā": ['mw'],
    "pāpīmant": ['bhs'],
    "pāpīya": ['mw'],
    "pāpīyaka": ['bhs'],
    "pāpīyas": ['ap90', 'mw'],
    "pāpīyastara": ['mw'],
    "pāpīyastva": ['mw'],
    "pāpīyaṃs": ['cae'],
    "pāra": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "pārabava": ['mw'],
    "pārabhṛta": ['mw'],
    "pārabhṛtaṃ": ['ap90'],
    "pārabhṛtīya": ['cae', 'mw'],
    "pāracara": ['mw'],
    "pārada": ['cae', 'cped', 'ddsa', 'mw'],
    "pāradakalpa": ['mw'],
    "pāradarśaka": ['mw'],
    "pāradarśana": ['mw'],
    "pāradatva": ['mw'],
    "pāradaurbalya": ['mw'],
    "pāradaḥ": ['ap90'],
    "pāradaṇḍaka": ['mw'],
    "pāradeśika": ['ap90', 'mw'],
    "pāradeśya": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāradhenu": ['mw'],
    "pāradhenuka": ['mw'],
    "pāradhvaja": ['ddsa', 'mw'],
    "pāradārika": ['cae', 'cped', 'ddsa', 'mw'],
    "pāradārikaḥ": ['ap90'],
    "pāradārin": ['mw'],
    "pāradārya": ['cae', 'mw'],
    "pāradāryaṃ": ['ap90'],
    "pāradṛśvan": ['ddsa', 'mw'],
    "pāraga": ['cae', 'ddsa', 'mw'],
    "pāragamana": ['mw'],
    "pāragata": ['bhs', 'cped', 'mw'],
    "pāragati": ['mw'],
    "pāragavesī": ['cped'],
    "pāragrāmika": ['ap90', 'mw'],
    "pāragā": ['bhs'],
    "pāragāmin": ['mw'],
    "pāragāmī": ['cped'],
    "pāragū": ['cped'],
    "pārahaṃsya": ['ap90', 'mw'],
    "pāraj": ['ap90', 'mw'],
    "pārajanmika": ['bhs', 'mw'],
    "pārajāyika": ['mw'],
    "pārajāyikaḥ": ['ap90'],
    "pārajāyin": ['mw'],
    "pāraka": ['ap90', 'mw'],
    "pārakulīna": ['mw'],
    "pārakya": ['ap90', 'cae', 'ddsa', 'mw'],
    "pārakāma": ['mw'],
    "pārakāṅkṣin": ['mw'],
    "pārakṣudra": ['mw'],
    "pāralaukika": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāraloka": ['bhs'],
    "pāralokika": ['cped'],
    "pāralokya": ['ap90', 'mw'],
    "pārama": ['mw'],
    "pāramagopucchika": ['mw'],
    "pāramahaṃsa": ['mw'],
    "pāramahaṃsya": ['ap90', 'mw'],
    "pāramahaṃsyapari": ['mw'],
    "pāramaiśvarya": ['mw'],
    "pāramaka": ['mw'],
    "pāramarṣa": ['mw'],
    "pāramasthya": ['mw'],
    "pārameśvara": ['cae', 'ddsa', 'mw'],
    "pārameśvaraka": ['mw'],
    "pārameśvarapuṇyāhavarcana": ['mw'],
    "pārameśvarasaṃhitā": ['mw'],
    "pārameśvarya": ['mw'],
    "pārameśvarārādhanavidhi": ['mw'],
    "pārameśvarīya": ['mw'],
    "pārameṣṭha": ['mw'],
    "pārameṣṭhya": ['cae', 'ddsa', 'mw'],
    "pārameṣṭhyaṃ": ['ap90'],
    "pārami": ['bhs', 'mw'],
    "pāramika": ['ap90'],
    "pāramita": ['ap90', 'mw'],
    "pāramitā": ['bhs', 'cped', 'ddsa', 'mw'],
    "pārampara": ['ddsa', 'mw'],
    "pārampariya": ['cped'],
    "pāramparya": ['mw'],
    "pāramparyakramāgata": ['mw'],
    "pāramparyaprakaraṇa": ['mw'],
    "pāramparyeṇa": ['mw'],
    "pāramparyopadeśa": ['mw'],
    "pāramparyāgata": ['mw'],
    "pāramparī": ['mw'],
    "pāramparīya": ['mw'],
    "pāramparīṇa": ['mw'],
    "pāramārthika": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāramārthya": ['mw'],
    "pāramī": ['bhs', 'cped'],
    "pāranetṛ": ['mw'],
    "pārapata": ['cped'],
    "pārappatta": ['cped'],
    "pārapāra": ['mw'],
    "pārasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "pārasika": ['cae', 'mw'],
    "pārasikaḥ": ['ap90'],
    "pāraskanda": ['mw'],
    "pāraskara": ['cae', 'ddsa', 'mw'],
    "pāraskaragṛhyamantra": ['mw'],
    "pāraskaragṛhyapariśiṣṭa": ['mw'],
    "pāraskaragṛhyasūtra": ['mw'],
    "pāraskarapaddhati": ['mw'],
    "pāraskarasamṛti": ['mw'],
    "pāraskaraḥ": ['ap90'],
    "pārastraiṇeya": ['mw'],
    "pārastraiṇeyaḥ": ['ap90'],
    "pārasvata": ['mw'],
    "pārasyakulīna": ['ap90', 'mw'],
    "pārasī": ['ap90', 'mw'],
    "pārasījātaka": ['mw'],
    "pārasīka": ['ap90', 'cae', 'mw'],
    "pārasīkataila": ['mw'],
    "pārasīkayamānī": ['mw'],
    "pārasīkaḥ": ['ap90'],
    "pārasīkeya": ['mw'],
    "pārasīnāmamālā": ['mw'],
    "pārasīprakośa": ['mw'],
    "pārasīprakāśa": ['mw'],
    "pārasīvinoda": ['mw'],
    "pārata": ['cae', 'ddsa', 'mw'],
    "pāratalpika": ['mw'],
    "pāratantra": ['mw'],
    "pāratantrika": ['mw'],
    "pāratantrya": ['cae', 'ddsa', 'mw'],
    "pāratas": ['cae', 'mw'],
    "pārataḥ": ['ap90', 'ddsa'],
    "pārataṃtrika": ['ap90'],
    "pārataṃtryaṃ": ['ap90'],
    "pāratrika": ['ap90', 'ddsa', 'mw'],
    "pāratrya": ['mw'],
    "pāratryaṃ": ['ap90'],
    "pāravargya": ['mw'],
    "pāravata": ['cped', 'mw'],
    "pāravataḥ": ['ap90'],
    "pāravaśya": ['cae', 'mw'],
    "pāravaśyaṃ": ['ap90'],
    "pāravinda": ['mw'],
    "pāraya": ['ap90', 'mw'],
    "pārayati": ['ap90'],
    "pārayitṛ": ['cae', 'ddsa', 'mw'],
    "pārayiṣṇu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pārayiṣṇutama": ['mw'],
    "pārayugīṇa": ['mw'],
    "pāraśava": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāraśavatva": ['mw'],
    "pāraśavya": ['mw'],
    "pāraśavāyana": ['mw'],
    "pāraśvadha": ['mw'],
    "pāraśvadhaḥ": ['ap90'],
    "pāraśvadhika": ['bhs', 'mw'],
    "pāraśīka": ['mw'],
    "pāraḥ": ['ap90'],
    "pāraṁ": ['cped'],
    "pāraṃgata": ['bhs'],
    "pāraṃpariṇa": ['ap90'],
    "pāraṃparya": ['cae'],
    "pāraṃparyakramāgata": ['cae'],
    "pāraṃparyaṃ": ['ap90'],
    "pāraṃparyāgata": ['cae'],
    "pāraṃparīya": ['ap90'],
    "pāraṅgata": ['cped'],
    "pāraṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pāraṇakarman": ['mw'],
    "pāraṇi": ['mw'],
    "pāraṇika": ['mw'],
    "pāraṇīya": ['ap90', 'cae', 'mw'],
    "pāraṣada": ['mw'],
    "pāraṭīṭa": ['mw'],
    "pāraṭīṭaḥ": ['ap90'],
    "pārda": ['mw'],
    "pārdā": ['mw'],
    "pārdākī": ['mw'],
    "pārdāvat": ['mw'],
    "pārdāyanī": ['mw'],
    "pāre": ['ap90', 'mw'],
    "pārebaḍavā": ['mw'],
    "pāredhanva": ['mw'],
    "pāredhanvaka": ['mw'],
    "pāregaṅgam": ['mw'],
    "pārejalam": ['mw'],
    "pāreraka": ['mw'],
    "pārerakaḥ": ['ap90'],
    "pāresindhu": ['mw'],
    "pāretaraṃgiṇi": ['mw'],
    "pārevata": ['cped', 'mw'],
    "pārevataka": ['bhs'],
    "pāreviśokam": ['ddsa', 'mw'],
    "pāreśmaśānam": ['cae', 'mw'],
    "pārghaṭa": ['mw'],
    "pārghaṭaṃ": ['ap90'],
    "pāri": ['bhs', 'mw'],
    "pāria": ['gra'],
    "pāribarha": ['mw'],
    "pāribarhaḥ": ['ap90'],
    "pāribhadra": ['cae', 'mw'],
    "pāribhadraka": ['cae', 'mw'],
    "pāribhadraḥ": ['ap90'],
    "pāribhavya": ['mw'],
    "pāribhogika": ['bhs', 'cped', 'mw'],
    "pāribhogīya": ['bhs'],
    "pāribhāvya": ['mw'],
    "pāribhāvyaṃ": ['ap90'],
    "pāribhāṣika": ['ap90', 'mw'],
    "pāribhāṣikatva": ['mw'],
    "pāricariyā": ['cped'],
    "pāricaryā": ['bhs'],
    "pāricchattaka": ['cped'],
    "pāridheya": ['mw'],
    "pāridhvajika": ['bhs', 'mw'],
    "pāridhvajikaḥ": ['ap90'],
    "pāridṛḍhi": ['mw'],
    "pārigrāmika": ['ap90', 'mw'],
    "pārihanavya": ['mw'],
    "pārihāraka": ['bhs'],
    "pārihārika": ['ap90', 'mw'],
    "pārihārikī": ['mw'],
    "pārihāriṇī": ['mw'],
    "pārihārya": ['cae', 'mw'],
    "pārihāryaḥ": ['ap90'],
    "pārihāsya": ['mw'],
    "pārihāsyaṃ": ['ap90'],
    "pārihāsyena": ['mw'],
    "pārihāṇa": ['bhs'],
    "pārihāṇi": ['bhs'],
    "pārijāta": ['bhs', 'cae', 'ddsa', 'mw'],
    "pārijātaharaṇa": ['mw'],
    "pārijātaharaṇacampū": ['mw'],
    "pārijātaka": ['cae', 'mw'],
    "pārijātakaratnākara": ['mw'],
    "pārijātamaya": ['mw'],
    "pārijātaratnākara": ['mw'],
    "pārijātasarasvatīmantra": ['mw'],
    "pārijātavat": ['mw'],
    "pārijātavyākaraṇa": ['mw'],
    "pārijātavṛttakhaṇḍa": ['mw'],
    "pārijātaḥ": ['ap90'],
    "pārijātācalamāhātmya": ['mw'],
    "pārijūnya": ['bhs'],
    "pārikha": ['mw'],
    "pārikheya": ['ap90', 'mw'],
    "pārikhīya": ['mw'],
    "pārikuṭa": ['ddsa', 'mw'],
    "pārikuṭaḥ": ['ap90'],
    "pārikārmika": ['mw'],
    "pārikāṃkṣin": ['ap90'],
    "pārikāṅkṣaka": ['mw'],
    "pārikāṅkṣin": ['mw'],
    "pārikṣepaka": ['mw'],
    "pārikṣepika": ['mw'],
    "pārikṣi": ['mw'],
    "pārikṣit": ['cae', 'mw'],
    "pārikṣita": ['cae', 'ddsa', 'mw'],
    "pārikṣitaḥ": ['ap90'],
    "pārikṣitī": ['mw'],
    "pārikṣitīya": ['mw'],
    "pārila": ['mw'],
    "pārileya": ['bhs', 'mw'],
    "pārima": ['bhs', 'cped'],
    "pārimaṇḍalya": ['mw'],
    "pārimitya": ['mw'],
    "pārimityaṃ": ['ap90'],
    "pārimukhika": ['ap90', 'mw'],
    "pārimukhya": ['mw'],
    "pārimukhyaṃ": ['ap90'],
    "pārimāṃḍalyaṃ": ['ap90'],
    "pārimāṇya": ['mw'],
    "pārimāṇyaṃ": ['ap90'],
    "pārindra": ['mw'],
    "pārinirvāṇika": ['bhs'],
    "pāripanthika": ['cae', 'cped', 'mw'],
    "pāripaṃthikaḥ": ['ap90'],
    "pāripela": ['mw'],
    "pāriplava": ['ap90', 'cae', 'mw'],
    "pāriplavadṛṣṭi": ['mw'],
    "pāriplavagata": ['mw'],
    "pāriplavamati": ['mw'],
    "pāriplavanetra": ['mw'],
    "pāriplavaprabha": ['mw'],
    "pāriplavatva": ['mw'],
    "pāriplavatā": ['mw'],
    "pāriplavā": ['mw'],
    "pāriplavīya": ['mw'],
    "pāriplāvya": ['mw'],
    "pāriplāvyaḥ": ['ap90'],
    "pāripālya": ['mw'],
    "pāripāna": ['bhs', 'mw'],
    "pāripānthika": ['mw'],
    "pāripārśva": ['mw'],
    "pāripārśvaka": ['cae', 'mw'],
    "pāripārśvakaḥ": ['ap90'],
    "pāripārśvaṃ": ['ap90'],
    "pāripārśvika": ['cae', 'mw'],
    "pāripārśvikā": ['ap90', 'mw'],
    "pāripātra": ['mw'],
    "pāripātraḥ": ['ap90'],
    "pāripātraṃ": ['ap90'],
    "pāripātrikaḥ": ['ap90'],
    "pāripātrikā": ['bhs'],
    "pāripāṭya": ['mw'],
    "pāripāṭyaṃ": ['ap90'],
    "pāripūraka": ['bhs'],
    "pāripūri": ['bhs', 'cped'],
    "pāripūrṇa": ['bhs'],
    "pārirakṣaka": ['mw'],
    "pārirakṣakaḥ": ['ap90'],
    "pārirakṣika": ['mw'],
    "pārisajja": ['cped'],
    "pārisuddhi": ['cped'],
    "pārisuddhisīla": ['cped'],
    "pārisāraka": ['mw'],
    "pārisīrya": ['mw'],
    "pāritathyā": ['ap90', 'cae', 'mw'],
    "pāritavat": ['mw'],
    "pāritoṣika": ['ap90', 'cae', 'mw'],
    "pārivatsa": ['mw'],
    "pārivedya": ['mw'],
    "pārivettrya": ['mw'],
    "pārivittya": ['mw'],
    "pārivittyaṃ": ['ap90'],
    "pārivrajya": ['mw'],
    "pārivrājaka": ['mw'],
    "pārivrājakaṃ": ['ap90'],
    "pārivrājya": ['mw'],
    "pārivyayika": ['bhs'],
    "pārivāsika": ['bhs'],
    "pārivṛḍhi": ['mw'],
    "pārivṛḍhya": ['mw'],
    "pāriyosāpita": ['cped'],
    "pāriyānika": ['mw'],
    "pāriyānikaḥ": ['ap90'],
    "pāriyātra": ['ap90', 'bhs', 'mw'],
    "pāriyātraḥ": ['ap90'],
    "pāriyātrika": ['mw'],
    "pāriyātrikaḥ": ['ap90'],
    "pāriśa": ['mw'],
    "pāriśeṣya": ['mw'],
    "pāriśeṣyaṃ": ['ap90'],
    "pāriśeṣyāt": ['mw'],
    "pāriśikṣā": ['mw'],
    "pāriśuddhi": ['bhs'],
    "pāriśīla": ['mw'],
    "pāriśīlaḥ": ['ap90'],
    "pāriṃdraḥ": ['ap90'],
    "pāriṇa": ['mw'],
    "pāriṇaka": ['mw'],
    "pāriṇāhya": ['mw'],
    "pāriṇāhyaṃ": ['ap90'],
    "pāriṇāmika": ['bhs', 'ddsa', 'mw'],
    "pāriṇāyya": ['ap90', 'cae', 'mw'],
    "pāriṣada": ['ap90', 'cae', 'mw'],
    "pāriṣadaka": ['mw'],
    "pāriṣadya": ['bhs', 'mw'],
    "pāriṣadyaḥ": ['ap90'],
    "pāriṣatka": ['mw'],
    "pāriṣeṇya": ['mw'],
    "pārjanya": ['ap90', 'cae', 'mw'],
    "pāroha": ['cped'],
    "pārokṣa": ['ap90', 'mw'],
    "pārokṣya": ['cae', 'ddsa', 'mw'],
    "pārokṣyaṃ": ['ap90'],
    "pārovarya": ['mw'],
    "pārovaryaṃ": ['ap90'],
    "pārpara": ['mw'],
    "pārparaḥ": ['ap90'],
    "pārtha": ['cae', 'ddsa', 'mw'],
    "pārthagarthya": ['mw'],
    "pārthagjanaka": ['bhs'],
    "pārthaja": ['mw'],
    "pārthakirāta": ['mw'],
    "pārthakya": ['mw'],
    "pārthakyaṃ": ['ap90'],
    "pārthamaya": ['mw'],
    "pārthaparākrama": ['mw'],
    "pārthapura": ['mw'],
    "pārthastuti": ['mw'],
    "pārthastutiṭīkā": ['mw'],
    "pārthasārathi": ['mw'],
    "pārthasārathimiśra": ['mw'],
    "pārthava": ['cae', 'gra', 'mw'],
    "pārthavaṃ": ['ap90'],
    "pārthavi": ['mw'],
    "pārthavijaya": ['mw'],
    "pārthaḥ": ['ap90'],
    "pārthia": ['gra'],
    "pārthika": ['bhs'],
    "pārthiva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pārthivaliṅga": ['mw'],
    "pārthivaliṅgalakṣaṇa": ['mw'],
    "pārthivaliṅgamāhātmya": ['mw'],
    "pārthivaliṅgapūjanavidhi": ['mw'],
    "pārthivaliṅgapūjā": ['mw'],
    "pārthivaliṅgapūjārādhana": ['mw'],
    "pārthivaliṅgavidhāna": ['mw'],
    "pārthivaliṅgodyāpana": ['mw'],
    "pārthivanandinī": ['mw'],
    "pārthivapūjana": ['mw'],
    "pārthivapūjanavidhi": ['mw'],
    "pārthivapūjā": ['mw'],
    "pārthivarṣabha": ['mw'],
    "pārthivasutā": ['mw'],
    "pārthivatva": ['mw'],
    "pārthivatā": ['mw'],
    "pārthivaśreṣṭha": ['mw'],
    "pārthivendra": ['mw'],
    "pārthivesvara": ['mw'],
    "pārthiveśvaracintāmaṇi": ['mw'],
    "pārthiveśvaracintāmaṇipaddhati": ['mw'],
    "pārthiveśvarapūjanavidhi": ['mw'],
    "pārthiveśvarapūjāvidhi": ['mw'],
    "pārthivādhama": ['mw'],
    "pārthivārcanavidhi": ['mw'],
    "pārthivātmajā": ['mw'],
    "pārthivī": ['ap90', 'mw'],
    "pārthona": ['mw'],
    "pārthuraśma": ['mw'],
    "pārthuśravasa": ['mw'],
    "pārthya": ['gra', 'mw'],
    "pāru": ['mw'],
    "pārucchepa": ['mw'],
    "pārucchepi": ['mw'],
    "pārucchepī": ['mw'],
    "pārupana": ['cped'],
    "pārupanta": ['cped'],
    "pārupati": ['cped'],
    "pārupi": ['cped'],
    "pārupitvā": ['cped'],
    "pāruta": ['cped'],
    "pāruḥ": ['ap90'],
    "pāruṣaka": ['bhs', 'mw'],
    "pāruṣeya": ['cae', 'ddsa', 'mw'],
    "pāruṣika": ['bhs', 'mw'],
    "pāruṣya": ['cae', 'ddsa', 'mw'],
    "pāruṣyaka": ['bhs'],
    "pāruṣyalipi": ['bhs'],
    "pāruṣyaṃ": ['ap90'],
    "pāruṣṇa": ['cae', 'mw'],
    "pārvata": ['ap90', 'cae', 'ddsa', 'mw'],
    "pārvateya": ['ap90', 'mw'],
    "pārvateyī": ['mw'],
    "pārvati": ['mw'],
    "pārvatika": ['mw'],
    "pārvatikaṃ": ['ap90'],
    "pārvatāyana": ['cae', 'mw'],
    "pārvatī": ['ap90', 'mw'],
    "pārvatīdharmaputraka": ['mw'],
    "pārvatīkṣetra": ['mw'],
    "pārvatīlocana": ['mw'],
    "pārvatīmokṣaṇa": ['mw'],
    "pārvatīnandana": ['mw'],
    "pārvatīnetra": ['mw'],
    "pārvatīnātha": ['mw'],
    "pārvatīpariṇaya": ['cae', 'mw'],
    "pārvatīpati": ['mw'],
    "pārvatīpaścāttāpavarṇana": ['mw'],
    "pārvatīprasādana": ['mw'],
    "pārvatīpravartana": ['mw'],
    "pārvatīprāṇanātha": ['mw'],
    "pārvatīsahasranāman": ['mw'],
    "pārvatīsakha": ['mw'],
    "pārvatīsampradāna": ['mw'],
    "pārvatīstotra": ['mw'],
    "pārvatīsvayaṃvara": ['mw'],
    "pārvatīya": ['ap90', 'cae', 'mw'],
    "pārvatīśvara": ['mw'],
    "pārvatīśvaraliṅga": ['mw'],
    "pārvaṇa": ['ap90', 'ddsa', 'mw'],
    "pārvaṇacandrikā": ['mw'],
    "pārvaṇacaṭaśrāddhaprayoga": ['mw'],
    "pārvaṇaśrāddha": ['mw'],
    "pārvaṇaśrāddhapaddhati": ['mw'],
    "pārvaṇaśrāddhaprayoga": ['mw'],
    "pārvaṇaśrāddhavidhi": ['mw'],
    "pārvāyanāntīya": ['cae', 'ddsa'],
    "pārvāyānāntīya": ['mw'],
    "pāry": ['mw'],
    "pārya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pāryantika": ['mw'],
    "pāryavasānika": ['mw'],
    "pāryaṃtika": ['ap90'],
    "pāryoṣṭhya": ['mw'],
    "pāryulūkhalya": ['mw'],
    "pāryāptika": ['mw'],
    "pārā": ['ap90', 'mw'],
    "pārājayika": ['bhs'],
    "pārājika": ['bhs', 'cped'],
    "pārājikīya": ['bhs'],
    "pārāpata": ['mw'],
    "pārāpataka": ['mw'],
    "pārāpatapadī": ['mw'],
    "pārāpataḥ": ['ap90'],
    "pārāpāra": ['mw'],
    "pārāpārīṇa": ['ap90'],
    "pārārthya": ['cae', 'ddsa', 'mw'],
    "pārārthyanirṇaya": ['mw'],
    "pārārthyavivecana": ['mw'],
    "pārāruka": ['mw'],
    "pārāvadaghnī": ['mw'],
    "pārāvarya": ['mw'],
    "pārāvaryeṇa": ['mw'],
    "pārāvata": ['cae', 'ddsa', 'gra', 'mw'],
    "pārāvatadeśa": ['mw'],
    "pārāvataghnī": ['mw'],
    "pārāvatahan": ['gra'],
    "pārāvatamālāya": ['mw'],
    "pārāvatapadī": ['mw'],
    "pārāvatasavarṇa": ['mw'],
    "pārāvatasavarṇāśva": ['mw'],
    "pārāvataḥ": ['ap90'],
    "pārāvati": ['mw'],
    "pārāvatābha": ['mw'],
    "pārāvatākṣa": ['mw'],
    "pārāvatāśva": ['mw'],
    "pārāvatāṅghripiccha": ['mw'],
    "pārāvatī": ['mw'],
    "pārāvāra": ['cae', 'ddsa', 'mw'],
    "pārāvārajālāya": ['mw'],
    "pārāvārataraṇārtham": ['mw'],
    "pārāvārīṇa": ['ap90', 'mw'],
    "pārāyana": ['cped'],
    "pārāyaṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "pārāyaṇakrama": ['mw'],
    "pārāyaṇamāhātmya": ['mw'],
    "pārāyaṇavidhi": ['mw'],
    "pārāyaṇika": ['mw'],
    "pārāyaṇikaḥ": ['ap90'],
    "pārāyaṇī": ['mw'],
    "pārāyaṇīya": ['mw'],
    "pārāśara": ['bhs', 'cae', 'ddsa', 'mw'],
    "pārāśarahorā": ['mw'],
    "pārāśarajātaka": ['mw'],
    "pārāśarakalpika": ['mw'],
    "pārāśarasūtra": ['mw'],
    "pārāśaraśikṣā": ['mw'],
    "pārāśaraḥ": ['ap90'],
    "pārāśari": ['mw'],
    "pārāśarin": ['ap90', 'mw'],
    "pārāśariḥ": ['ap90'],
    "pārāśarya": ['cae', 'mw'],
    "pārāśaryavijaya": ['mw'],
    "pārāśaryāyaṇa": ['cae', 'mw'],
    "pārāśarī": ['mw'],
    "pārāśarīhorā": ['mw'],
    "pārāśarīkauṇḍinīputra": ['mw'],
    "pārāśarīmukura": ['mw'],
    "pārāśarīmūla": ['mw'],
    "pārāśarīpaddhati": ['mw'],
    "pārāśarīputra": ['mw'],
    "pārāśarīvyākhyā": ['mw'],
    "pārāśarīya": ['mw'],
    "pārī": ['ap90', 'ddsa', 'mw'],
    "pārīkṣit": ['mw'],
    "pārīkṣita": ['mw'],
    "pārīkṣitaḥ": ['ap90'],
    "pārīndra": ['cae', 'ddsa', 'mw'],
    "pārīraṇa": ['mw'],
    "pārīraṇaḥ": ['ap90'],
    "pārīya": ['ap90', 'mw'],
    "pārīṃdraḥ": ['ap90'],
    "pārīṇa": ['ap90', 'mw'],
    "pārīṇahya": ['ddsa', 'mw'],
    "pārīṇahyaṃ": ['ap90'],
    "pārīṣa": ['mw'],
    "pārśava": ['mw'],
    "pārśavaḥ": ['ap90'],
    "pārśua": ['gra'],
    "pārśukā": ['ap90', 'bhs', 'mw'],
    "pārśva": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "pārśvabhaṅga": ['mw'],
    "pārśvabhāga": ['mw'],
    "pārśvacandra": ['mw'],
    "pārśvacara": ['mw'],
    "pārśvada": ['mw'],
    "pārśvadeva": ['mw'],
    "pārśvadeśa": ['mw'],
    "pārśvadruma": ['mw'],
    "pārśvadāha": ['bhs', 'mw'],
    "pārśvaga": ['cae', 'mw'],
    "pārśvagamana": ['mw'],
    "pārśvagata": ['mw'],
    "pārśvaikādaśī": ['mw'],
    "pārśvaka": ['ddsa', 'mw'],
    "pārśvakaḥ": ['ap90'],
    "pārśvakā": ['bhs'],
    "pārśvala": ['mw'],
    "pārśvamaṇḍalin": ['mw'],
    "pārśvamānī": ['mw'],
    "pārśvanātha": ['mw'],
    "pārśvanāthacaritra": ['mw'],
    "pārśvanāthadaśabhāvavisaha": ['mw'],
    "pārśvanāthagītā": ['mw'],
    "pārśvanāthakāvya": ['mw'],
    "pārśvanāthanamaskāra": ['mw'],
    "pārśvanāthapurāṇa": ['mw'],
    "pārśvanāthastava": ['mw'],
    "pārśvanāthastuti": ['mw'],
    "pārśvaparivartana": ['mw'],
    "pārśvaparivartin": ['cae', 'mw'],
    "pārśvaparivartita": ['cae', 'mw'],
    "pārśvapippala": ['mw'],
    "pārśvaruj": ['mw'],
    "pārśvasaṃdhāna": ['mw'],
    "pārśvasaṃhita": ['mw'],
    "pārśvasaṃstha": ['mw'],
    "pārśvastha": ['cae', 'mw'],
    "pārśvasthita": ['mw'],
    "pārśvasūtraka": ['bhs', 'mw'],
    "pārśvatas": ['ap90', 'cae', 'mw'],
    "pārśvatīya": ['ap90', 'mw'],
    "pārśvavaktra": ['mw'],
    "pārśvavartin": ['cae', 'mw'],
    "pārśvavivartin": ['cae', 'mw'],
    "pārśvaśaya": ['mw'],
    "pārśvaśāyin": ['mw'],
    "pārśvaśūla": ['mw'],
    "pārśvika": ['ap90', 'bhs', 'mw'],
    "pārśvodarapriya": ['mw'],
    "pārśvopapārśva": ['mw'],
    "pārśvopapīḍam": ['mw'],
    "pārśvya": ['mw'],
    "pārśvānucara": ['cae', 'ddsa', 'mw'],
    "pārśvārti": ['mw'],
    "pārśvāsanna": ['mw'],
    "pārśvāsthi": ['mw'],
    "pārśvāsīna": ['mw'],
    "pārśvāvamarda": ['mw'],
    "pārśvāyāta": ['mw'],
    "pārṇa": ['ap90', 'cae', 'mw'],
    "pārṇavalka": ['mw'],
    "pārṇavalki": ['mw'],
    "pārṇavalkya": ['mw'],
    "pārṇavāsin": ['bhs'],
    "pārṣad": ['ap90', 'cae', 'mw'],
    "pārṣada": ['bhs', 'cae', 'ddsa', 'mw'],
    "pārṣadaka": ['mw'],
    "pārṣadapariśiṣṭa": ['mw'],
    "pārṣadatā": ['mw'],
    "pārṣadavyākhyā": ['mw'],
    "pārṣadavṛtti": ['mw'],
    "pārṣadaśva": ['mw'],
    "pārṣadaḥ": ['ap90'],
    "pārṣadaṃśa": ['mw'],
    "pārṣadaṭīkā": ['mw'],
    "pārṣadvāṇa": ['gra', 'mw'],
    "pārṣadya": ['bhs', 'mw'],
    "pārṣadyaḥ": ['ap90'],
    "pārṣadīya": ['mw'],
    "pārṣaki": ['mw'],
    "pārṣata": ['ap90', 'cae', 'ddsa', 'mw'],
    "pārṣatī": ['ap90', 'mw'],
    "pārṣika": ['mw'],
    "pārṣikya": ['mw'],
    "pārṣī": ['mw'],
    "pārṣṇa": ['mw'],
    "pārṣṇi": ['cae', 'ddsa', 'gra', 'mw'],
    "pārṣṇiga": ['mw'],
    "pārṣṇighāta": ['mw'],
    "pārṣṇigraha": ['cae', 'mw'],
    "pārṣṇigrahaṇa": ['mw'],
    "pārṣṇigrāha": ['cae', 'mw'],
    "pārṣṇikṣeman": ['mw'],
    "pārṣṇiprahāra": ['mw'],
    "pārṣṇisārathi": ['mw'],
    "pārṣṇitra": ['mw'],
    "pārṣṇivah": ['mw'],
    "pārṣṇivāh": ['mw'],
    "pārṣṇivāha": ['mw'],
    "pārṣṇiyantṛ": ['mw'],
    "pārṣṇiḥ": ['ap90'],
    "pārṣṇuvi": ['mw'],
    "pārṣṇyabhighāta": ['mw'],
    "pārṣṇī": ['ddsa'],
    "pārṣṇīla": ['mw'],
    "pārṣṭeya": ['cae', 'mw'],
    "pārṣṭhika": ['mw'],
    "pārṣṭika": ['mw'],
    "pāsa": ['bhs', 'cped', 'mw'],
    "pāsaka": ['cped'],
    "pāsaṇḍa": ['cped'],
    "pāsaṇḍaka": ['cped'],
    "pāstia": ['gra'],
    "pāstya": ['ap90', 'cae', 'gra', 'mw'],
    "pāsāda": ['cped'],
    "pāsādatala": ['cped'],
    "pāsādika": ['cped'],
    "pāsālekhā": ['cped'],
    "pāsāphalaka": ['cped'],
    "pāsāpiṭṭhi": ['cped'],
    "pāsāṇa": ['cped'],
    "pāsāṇacetiya": ['cped'],
    "pāsāṇaguḷa": ['cped'],
    "pāsāṇalekhā": ['cped'],
    "pāsāṇaphalaka": ['cped'],
    "pāsāṇapiṭṭhi": ['cped'],
    "pāsī": ['mw'],
    "pāt": ['ap90', 'mw'],
    "pāta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "pātabba": ['cped'],
    "pātabheda": ['mw'],
    "pātaka": ['cae', 'mw'],
    "pātakayoga": ['mw'],
    "pātakaḥ": ['ap90'],
    "pātakin": ['ap90', 'cae', 'mw'],
    "pātakitva": ['mw'],
    "pātalikā": ['bhs'],
    "pātalya": ['gra', 'mw'],
    "pātana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "pātanikā": ['mw'],
    "pātanīya": ['cae', 'mw'],
    "pātarāsa": ['cped'],
    "pātasāha": ['mw'],
    "pātasāriṇī": ['mw'],
    "pātatriṇa": ['mw'],
    "pātavai": ['cae'],
    "pātave": ['cae'],
    "pātavya": ['cae', 'ddsa', 'mw'],
    "pātayantika": ['bhs'],
    "pātayati": ['bhs'],
    "pātayitṛ": ['cae', 'ddsa', 'mw'],
    "pātañjala": ['cae', 'ddsa', 'mw'],
    "pātañjalabhāṣya": ['mw'],
    "pātañjalabhāṣyavārttika": ['mw'],
    "pātañjaladarśana": ['mw'],
    "pātañjalarahasya": ['mw'],
    "pātañjalasūtrabhāṣyavyakhyā": ['mw'],
    "pātañjalasūtravṛttibhāṣyacchāyāvyākhyā": ['mw'],
    "pātañjalatantra": ['mw'],
    "pātañjali": ['mw'],
    "pātañjalīya": ['mw'],
    "pātaḥ": ['ap90'],
    "pātaṃga": ['mw'],
    "pātaṃgi": ['mw'],
    "pātaṃgiḥ": ['ap90'],
    "pātaṃjala": ['ap90'],
    "pātaṅga": ['ddsa'],
    "pātesi": ['cped'],
    "pāteti": ['cped'],
    "pātetvā": ['cped'],
    "pātha": ['mw'],
    "pāthas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pāthaspati": ['mw'],
    "pāthaḥ": ['ap90'],
    "pātheya": ['cae', 'ddsa', 'mw'],
    "pātheyaka": ['mw'],
    "pātheyavat": ['mw'],
    "pātheyaśrāddha": ['mw'],
    "pātheyaṃ": ['ap90'],
    "pātheyya": ['cped'],
    "pāthi": ['mw'],
    "pāthia": ['gra'],
    "pāthika": ['mw'],
    "pāthikya": ['mw'],
    "pāthikārya": ['mw'],
    "pāthikṛtī": ['mw'],
    "pāthis": ['ap90', 'mw'],
    "pāthnya": ['mw'],
    "pātho": ['mw'],
    "pāthobhāj": ['mw'],
    "pāthoda": ['cae', 'mw'],
    "pāthodhara": ['cae', 'mw'],
    "pāthodhi": ['cae', 'mw'],
    "pāthoja": ['cae', 'ddsa', 'mw'],
    "pāthojinī": ['mw'],
    "pāthona": ['mw'],
    "pāthonidhi": ['cae', 'mw'],
    "pāthonātha": ['cae', 'mw'],
    "pāthoruha": ['mw'],
    "pāthya": ['gra', 'mw'],
    "pāti": ['cped', 'mw'],
    "pātika": ['cped', 'mw'],
    "pātikaḥ": ['ap90'],
    "pātilī": ['ap90', 'mw'],
    "pātimokkha": ['cped'],
    "pātin": ['ap90', 'cae', 'ddsa', 'mw'],
    "pātita": ['ap90', 'cped', 'mw'],
    "pātitya": ['ddsa', 'mw'],
    "pātityaṃ": ['ap90'],
    "pātivratya": ['ddsa', 'mw'],
    "pātivratyaṃ": ['ap90'],
    "pātiḥ": ['ap90'],
    "pātnī": ['mw'],
    "pātnīvata": ['mw'],
    "pātnīśāla": ['mw'],
    "pāto": ['cped'],
    "pātotpāta": ['ddsa'],
    "pātova": ['cped'],
    "pātra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "pātrabheda": ['mw'],
    "pātrabhūta": ['mw'],
    "pātrabhṛt": ['mw'],
    "pātracaya": ['mw'],
    "pātracayana": ['mw'],
    "pātradhāraṇa": ['mw'],
    "pātrahasta": ['mw'],
    "pātraka": ['mw'],
    "pātrakara": ['bhs'],
    "pātrakaṃ": ['ap90'],
    "pātrakaṭaka": ['mw'],
    "pātramelana": ['mw'],
    "pātranirṇega": ['mw'],
    "pātraparīṣṭi": ['mw'],
    "pātraprokṣa": ['mw'],
    "pātrapāka": ['mw'],
    "pātrapāla": ['mw'],
    "pātrapāṇi": ['mw'],
    "pātrasaṃcāra": ['mw'],
    "pātrasaṃskāra": ['mw'],
    "pātrastha": ['mw'],
    "pātrasāt": ['ap90'],
    "pātrasātkṛ": ['ddsa', 'mw'],
    "pātratara": ['mw'],
    "pātratva": ['mw'],
    "pātratā": ['cae', 'mw'],
    "pātravandana": ['mw'],
    "pātravarga": ['mw'],
    "pātraya": ['ddsa', 'mw'],
    "pātrayati": ['ap90'],
    "pātrayojana": ['mw'],
    "pātraśeṣa": ['mw'],
    "pātraśuddhi": ['mw'],
    "pātraṃ": ['ap90'],
    "pātraṭa": ['ap90', 'mw'],
    "pātraṭīra": ['mw'],
    "pātraṭīraḥ": ['ap90'],
    "pātre": ['mw'],
    "pātrebahula": ['mw'],
    "pātrebahulaḥ": ['ap90'],
    "pātresamita": ['mw'],
    "pātrika": ['ap90', 'mw'],
    "pātrikā": ['mw'],
    "pātrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "pātriya": ['mw'],
    "pātropakaraṇa": ['mw'],
    "pātrya": ['mw'],
    "pātrārtha": ['mw'],
    "pātrāvaleham": ['mw'],
    "pātrī": ['ddsa', 'mw'],
    "pātrībhū": ['mw'],
    "pātrīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "pātrīnirṇejana": ['mw'],
    "pātrīraḥ": ['ap90'],
    "pātrītas": ['mw'],
    "pātrīva": ['mw'],
    "pātrīya": ['ap90', 'mw'],
    "pātrīyaṃ": ['ap90'],
    "pātrīṇa": ['ap90', 'mw'],
    "pāttigaṇaka": ['mw'],
    "pāttrikya": ['mw'],
    "pātu": ['cped', 'gra', 'mw'],
    "pātubhavati": ['cped'],
    "pātubhavi": ['cped'],
    "pātubhavitvā": ['cped'],
    "pātubhāva": ['cped'],
    "pātubhūta": ['cped'],
    "pātuka": ['ap90', 'cae', 'mw'],
    "pātukamma": ['cped'],
    "pātukamyatā": ['cped'],
    "pātukaraṇa": ['cped'],
    "pātukari": ['cped'],
    "pātukaritvā": ['cped'],
    "pātukaroti": ['cped'],
    "pātukata": ['cped'],
    "pātukatvā": ['cped'],
    "pātukāma": ['cped'],
    "pāturahosi": ['cped'],
    "pātuṁ": ['cped'],
    "pātya": ['ap90', 'cae', 'mw'],
    "pātādhikārodāharana": ['mw'],
    "pātāla": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "pātālabhogivarga": ['mw'],
    "pātālagaruḍāhvaya": ['mw'],
    "pātālagaruḍī": ['mw'],
    "pātālagaṅgā": ['mw'],
    "pātālaketu": ['mw'],
    "pātālakhaṇḍa": ['mw'],
    "pātālanagarī": ['mw'],
    "pātālanilaya": ['mw'],
    "pātālaprastha": ['mw'],
    "pātālaprasthika": ['mw'],
    "pātālatala": ['mw'],
    "pātālatalam": ['mw'],
    "pātālaukas": ['mw'],
    "pātālavarṇana": ['mw'],
    "pātālavijaya": ['mw'],
    "pātālavāsin": ['mw'],
    "pātālayantra": ['mw'],
    "pātālaṃ": ['ap90'],
    "pātānaprastha": ['mw'],
    "pātāṇḍinīya": ['mw'],
    "pātī": ['cped'],
    "pātṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "pāva": ['cae', 'gra', 'mw'],
    "pāvacana": ['cped'],
    "pāvaka": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "pāvakasuta": ['mw'],
    "pāvakavarcas": ['gra', 'mw'],
    "pāvakavarṇa": ['gra', 'mw'],
    "pāvakavat": ['mw'],
    "pāvakaśocis": ['gra', 'mw'],
    "pāvakeśvara": ['mw'],
    "pāvaki": ['cae', 'ddsa', 'mw'],
    "pāvakiḥ": ['ap90'],
    "pāvakāraṇi": ['mw'],
    "pāvakārcis": ['cae', 'mw'],
    "pāvakāstra": ['mw'],
    "pāvakātmaja": ['mw'],
    "pāvakī": ['mw'],
    "pāvakīya": ['mw'],
    "pāvamāna": ['cae', 'ddsa', 'gra', 'mw'],
    "pāvamānī": ['ap90', 'gra', 'mw'],
    "pāvan": ['cae', 'gra', 'mw'],
    "pāvana": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāvanadhvani": ['mw'],
    "pāvanatva": ['mw'],
    "pāvanī": ['ap90', 'mw'],
    "pāvara": ['cae', 'ddsa', 'mw'],
    "pāvaraḥ": ['ap90'],
    "pāvassi": ['cped'],
    "pāvaḷa": ['cped'],
    "pāvaṣṭurikeya": ['mw'],
    "pāvaṭṭaka": ['cped'],
    "pāvikā": ['mw'],
    "pāvindāyana": ['mw'],
    "pāvinī": ['mw'],
    "pāvita": ['mw'],
    "pāvitra": ['mw'],
    "pāvitrya": ['cae', 'mw'],
    "pāvitrāyaṇa": ['mw'],
    "pāvusa": ['cped'],
    "pāvussaka": ['cped'],
    "pāvya": ['mw'],
    "pāvā": ['cae', 'mw'],
    "pāvāpurī": ['mw'],
    "pāvāra": ['cped'],
    "pāvārika": ['cped'],
    "pāvīrava": ['ddsa', 'gra', 'mw'],
    "pāvīravī": ['mw'],
    "pāy": ['cae', 'ddsa', 'mw'],
    "pāya": ['bhs', 'cped', 'mw'],
    "pāyaguṇḍa": ['mw'],
    "pāyaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "pāyalisaṃgha": ['mw'],
    "pāyam": ['cae', 'ddsa', 'mw'],
    "pāyamāna": ['cped'],
    "pāyana": ['cae', 'ddsa', 'gra', 'mw'],
    "pāyanaṃ": ['ap90'],
    "pāyanā": ['mw'],
    "pāyasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāyasadagdha": ['mw'],
    "pāyasapiṇḍāraka": ['cae', 'mw'],
    "pāyasika": ['ap90', 'mw'],
    "pāyasāpūpa": ['cae', 'mw'],
    "pāyattika": ['bhs'],
    "pāyayitavai": ['mw'],
    "pāyaṃ": ['ap90'],
    "pāyena": ['cped'],
    "pāyenta": ['cped'],
    "pāyesi": ['cped'],
    "pāyeti": ['cped'],
    "pāyetvā": ['cped'],
    "pāyia": ['gra'],
    "pāyika": ['mw'],
    "pāyikaḥ": ['ap90'],
    "pāyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāyinmāhātmya": ['mw'],
    "pāyinī": ['mw'],
    "pāyita": ['cped'],
    "pāyu": ['cae', 'ddsa', 'gra', 'mw'],
    "pāyubheda": ['mw'],
    "pāyukṣālana": ['mw'],
    "pāyukṣālanabhūmi": ['mw'],
    "pāyukṣālanabhūmitā": ['mw'],
    "pāyukṣālanaveśman": ['mw'],
    "pāyuḥ": ['ap90'],
    "pāyya": ['ap90', 'cae', 'gra', 'mw'],
    "pāyāsi": ['cped'],
    "pāyāti": ['cped'],
    "pāyī": ['cped'],
    "pāyīka": ['mw'],
    "pāyūpastha": ['mw'],
    "pāñca": ['mw'],
    "pāñcabhautika": ['cae', 'mw'],
    "pāñcadaśa": ['mw'],
    "pāñcadaśika": ['bhs'],
    "pāñcadaśya": ['mw'],
    "pāñcagatika": ['bhs', 'mw'],
    "pāñcajanya": ['cae', 'ddsa', 'gra', 'mw'],
    "pāñcajanyadhama": ['mw'],
    "pāñcajanyadhara": ['mw'],
    "pāñcajanyanādin": ['mw'],
    "pāñcajanyavana": ['mw'],
    "pāñcajanyā": ['mw'],
    "pāñcajanyāyani": ['mw'],
    "pāñcajanī": ['mw'],
    "pāñcajanīna": ['mw'],
    "pāñcakalāpika": ['mw'],
    "pāñcakapāla": ['mw'],
    "pāñcakapālika": ['mw'],
    "pāñcakarmika": ['mw'],
    "pāñcalauhitika": ['mw'],
    "pāñcalohitika": ['mw'],
    "pāñcamika": ['bhs', 'mw'],
    "pāñcamāhnika": ['mw'],
    "pāñcamūlika": ['mw'],
    "pāñcanada": ['mw'],
    "pāñcanakha": ['mw'],
    "pāñcanāpiti": ['mw'],
    "pāñcaprasṛtikī": ['mw'],
    "pāñcarātra": ['mw'],
    "pāñcarātramahopaniṣad": ['mw'],
    "pāñcarātramantra": ['mw'],
    "pāñcarātraprāyaścittavidhāna": ['mw'],
    "pāñcarātrarahasya": ['mw'],
    "pāñcarātrarakṣā": ['mw'],
    "pāñcarātrasaṃgraha": ['mw'],
    "pāñcarātrasthāpana": ['mw'],
    "pāñcarātravacana": ['mw'],
    "pāñcarātraśrīcūrṇaparipālana": ['mw'],
    "pāñcarātrika": ['mw'],
    "pāñcarātrāgama": ['mw'],
    "pāñcarātrārādhana": ['mw'],
    "pāñcaudanika": ['mw'],
    "pāñcavalkika": ['mw'],
    "pāñcavarṇa": ['mw'],
    "pāñcavarṣika": ['mw'],
    "pāñcavidhya": ['mw'],
    "pāñcavāja": ['mw'],
    "pāñcavārṣika": ['cae', 'mw'],
    "pāñcayajñika": ['cae', 'mw'],
    "pāñcaśabdika": ['mw'],
    "pāñcaśara": ['mw'],
    "pāñci": ['mw'],
    "pāñcigrāma": ['ddsa', 'mw'],
    "pāñcika": ['bhs', 'mw'],
    "pāñcāla": ['bhs', 'cae', 'ddsa', 'mw'],
    "pāñcāladeśa": ['mw'],
    "pāñcālajātiviveka": ['mw'],
    "pāñcālaka": ['cae', 'mw'],
    "pāñcālanātha": ['mw'],
    "pāñcālapati": ['mw'],
    "pāñcālaputrikā": ['mw'],
    "pāñcālarāja": ['mw'],
    "pāñcāleya": ['mw'],
    "pāñcāli": ['mw'],
    "pāñcālika": ['mw'],
    "pāñcālikā": ['ddsa', 'mw'],
    "pāñcālya": ['cae', 'mw'],
    "pāñcālānuyāna": ['mw'],
    "pāñcālāyana": ['mw'],
    "pāñcālī": ['bhs', 'mw'],
    "pāñcālīsvayaṃvaravarṇana": ['mw'],
    "pāñcālīvivāhakathana": ['mw'],
    "pāñcārthika": ['mw'],
    "pāñjara": ['mw'],
    "pāñjarya": ['mw'],
    "pāśa": ['cae', 'ddsa', 'gra', 'mw'],
    "pāśabaddha": ['mw'],
    "pāśabandha": ['mw'],
    "pāśabandhaka": ['mw'],
    "pāśabandhana": ['mw'],
    "pāśabhṛt": ['mw'],
    "pāśadhara": ['mw'],
    "pāśadyumna": ['gra', 'mw'],
    "pāśagraha": ['bhs'],
    "pāśahasta": ['cae', 'ddsa', 'mw'],
    "pāśajāla": ['mw'],
    "pāśaka": ['mw'],
    "pāśakakevalī": ['mw'],
    "pāśakapālin": ['mw'],
    "pāśakapīṭha": ['cae', 'mw'],
    "pāśakaḥ": ['ap90'],
    "pāśakaṇṭha": ['cae', 'mw'],
    "pāśakrīḍā": ['mw'],
    "pāśanaṃ": ['ap90'],
    "pāśapāṇi": ['mw'],
    "pāśarajju": ['mw'],
    "pāśatva": ['mw'],
    "pāśava": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāśavamata": ['mw'],
    "pāśavapālana": ['mw'],
    "pāśavat": ['mw'],
    "pāśay": ['cae'],
    "pāśaya": ['mw'],
    "pāśayati": ['ap90'],
    "pāśaḥ": ['ap90'],
    "pāścāttya": ['cae', 'ddsa', 'mw'],
    "pāścāttyabhāga": ['mw'],
    "pāścāttyanirṇayāmṛta": ['mw'],
    "pāścāttyarātrau": ['mw'],
    "pāścāttyarātri": ['mw'],
    "pāścātya": ['ap90', 'cae', 'mw'],
    "pāścātyākarasambhava": ['mw'],
    "pāśika": ['ddsa', 'mw'],
    "pāśikaḥ": ['ap90'],
    "pāśikā": ['mw'],
    "pāśila": ['mw'],
    "pāśin": ['ap90', 'cae', 'gra', 'mw'],
    "pāśita": ['ap90', 'mw'],
    "pāśivāṭa": ['mw'],
    "pāśubandhaka": ['mw'],
    "pāśubandhika": ['mw'],
    "pāśubaṃdhakaḥ": ['ap90'],
    "pāśuka": ['ap90', 'cae', 'mw'],
    "pāśukacāturmāsya": ['mw'],
    "pāśukādiprayoga": ['mw'],
    "pāśupalya": ['mw'],
    "pāśupata": ['ap90', 'ddsa', 'mw'],
    "pāśupatabrahmopaniṣad": ['mw'],
    "pāśupatajñāna": ['mw'],
    "pāśupatavrata": ['mw'],
    "pāśupatavratavivaraṇa": ['mw'],
    "pāśupatavratin": ['mw'],
    "pāśupatavrativiśa": ['mw'],
    "pāśupatayoga": ['mw'],
    "pāśupatayogaprakaraṇa": ['mw'],
    "pāśupatayogavidhi": ['mw'],
    "pāśupataśāstra": ['mw'],
    "pāśupatopaniṣad": ['mw'],
    "pāśupatāstra": ['mw'],
    "pāśupālya": ['ddsa'],
    "pāśupālyaṃ": ['ap90'],
    "pāśyā": ['ap90', 'mw'],
    "pāśā": ['bhs'],
    "pāśābhidhānā": ['mw'],
    "pāśālepa": ['bhs'],
    "pāśānta": ['mw'],
    "pāśāya": ['mw'],
    "pāśī": ['mw'],
    "pāśīkṛta": ['ap90'],
    "pāḍalīpura": ['mw'],
    "pāḍinī": ['ap90', 'mw'],
    "pāṃcabhautika": ['ap90'],
    "pāṃcadaśa": ['ap90'],
    "pāṃcadaśyaṃ": ['ap90'],
    "pāṃcajanyaḥ": ['ap90'],
    "pāṃcakapāla": ['ap90'],
    "pāṃcanada": ['ap90'],
    "pāṃcavarṣika": ['ap90'],
    "pāṃcayajñika": ['ap90'],
    "pāṃcaśabdikaṃ": ['ap90'],
    "pāṃcāla": ['ap90'],
    "pāṃcālaka": ['ap90'],
    "pāṃcālikā": ['ap90'],
    "pāṃcālī": ['ap90'],
    "pāṃcārthikaḥ": ['ap90'],
    "pāṃgulyaṃ": ['ap90'],
    "pāṃkta": ['ap90'],
    "pāṃkteya": ['ap90'],
    "pāṃsaka": ['mw'],
    "pāṃsana": ['ap90', 'cae', 'mw'],
    "pāṃsava": ['ap90', 'cae', 'mw'],
    "pāṃsavya": ['cae', 'mw'],
    "pāṃsin": ['mw'],
    "pāṃsu": ['cae', 'ddsa', 'gra', 'mw'],
    "pāṃsubhava": ['mw'],
    "pāṃsucandana": ['mw'],
    "pāṃsucatvara": ['mw'],
    "pāṃsucāmara": ['mw'],
    "pāṃsudhvastaśiroruha": ['mw'],
    "pāṃsudhāna": ['mw'],
    "pāṃsudhūmra": ['mw'],
    "pāṃsuguṇṭhita": ['mw'],
    "pāṃsuhara": ['mw'],
    "pāṃsuja": ['mw'],
    "pāṃsujālika": ['mw'],
    "pāṃsuka": ['cae', 'ddsa', 'mw'],
    "pāṃsukasīsa": ['mw'],
    "pāṃsukhala": ['mw'],
    "pāṃsukrīḍana": ['cae', 'ddsa', 'mw'],
    "pāṃsukrīḍā": ['mw'],
    "pāṃsukulī": ['mw'],
    "pāṃsukā": ['ap90', 'mw'],
    "pāṃsukūla": ['mw'],
    "pāṃsukūlasīvana": ['mw'],
    "pāṃsukūlika": ['mw'],
    "pāṃsukṛta": ['mw'],
    "pāṃsukṣāra": ['mw'],
    "pāṃsula": ['ap90', 'cae', 'mw'],
    "pāṃsulavaṇa": ['mw'],
    "pāṃsulekhana": ['mw'],
    "pāṃsulā": ['mw'],
    "pāṃsulāvṛttiprakāśa": ['mw'],
    "pāṃsumardana": ['mw'],
    "pāṃsunipāta": ['mw'],
    "pāṃsuparṇī": ['mw'],
    "pāṃsupattra": ['mw'],
    "pāṃsupaṭala": ['mw'],
    "pāṃsupiśāca": ['mw'],
    "pāṃsura": ['cae', 'gra', 'mw'],
    "pāṃsuraḥ": ['ap90'],
    "pāṃsurāgiṇī": ['mw'],
    "pāṃsurāṣṭra": ['mw'],
    "pāṃsusamūhana": ['cae', 'mw'],
    "pāṃsusaṃcaya": ['cae', 'mw'],
    "pāṃsusikatā": ['mw'],
    "pāṃsusnāna": ['cae'],
    "pāṃsuva": ['mw'],
    "pāṃsuvarṣa": ['cae', 'mw'],
    "pāṃsuvikarṣaṇa": ['mw'],
    "pāṃsuḥ": ['ap90'],
    "pāṃsūpta": ['cae'],
    "pāṃsūtkara": ['mw'],
    "pāṃthaḥ": ['ap90'],
    "pāṃśana": ['ap90', 'ddsa'],
    "pāṃśava": ['ap90', 'bhs'],
    "pāṃśu": ['mw'],
    "pāṃśukrīḍana": ['bhs'],
    "pāṃśukrīḍanaka": ['bhs'],
    "pāṃśukūla": ['bhs'],
    "pāṃśukūlika": ['bhs'],
    "pāṃśukṛta": ['bhs'],
    "pāṃśula": ['ap90'],
    "pāṃśulika": ['bhs'],
    "pāṃśupisāca": ['bhs'],
    "pāṃśuraḥ": ['ap90'],
    "pāṃśuḥ": ['ap90'],
    "pāṃḍara": ['ap90'],
    "pāṃḍavaḥ": ['ap90'],
    "pāṃḍaveyaḥ": ['ap90'],
    "pāṃḍavāyanaḥ": ['ap90'],
    "pāṃḍavīya": ['ap90'],
    "pāṃḍityaṃ": ['ap90'],
    "pāṃḍu": ['ap90'],
    "pāṃḍukaḥ": ['ap90'],
    "pāṃḍukin": ['ap90'],
    "pāṃḍura": ['ap90'],
    "pāṃḍuriman": ['ap90'],
    "pāṃḍvaṃ": ['ap90'],
    "pāṃḍya": ['ap90'],
    "pāṃḍyāḥ": ['ap90'],
    "pāṅgulya": ['mw'],
    "pāṅgulyahāriṇī": ['mw'],
    "pāṅkta": ['cae', 'ddsa', 'mw'],
    "pāṅktakākubha": ['mw'],
    "pāṅktatva": ['mw'],
    "pāṅktatā": ['cae', 'mw'],
    "pāṅkteya": ['cae', 'ddsa', 'mw'],
    "pāṅktra": ['cae', 'mw'],
    "pāṅktya": ['cae', 'ddsa', 'mw'],
    "pāṅktīhari": ['ddsa', 'mw'],
    "pāṇa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "pāṇabhūta": ['cped'],
    "pāṇada": ['cped'],
    "pāṇaghāta": ['cped'],
    "pāṇaghātī": ['cped'],
    "pāṇahara": ['cped'],
    "pāṇaka": ['cped'],
    "pāṇana": ['cped'],
    "pāṇasama": ['cped'],
    "pāṇau": ['mw'],
    "pāṇaukaraṇa": ['mw'],
    "pāṇavadha": ['cped'],
    "pāṇavika": ['ddsa', 'mw'],
    "pāṇaḥ": ['ap90'],
    "pāṇi": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "pāṇibandha": ['cae', 'mw'],
    "pāṇibhuj": ['mw'],
    "pāṇicandra": ['mw'],
    "pāṇicāpala": ['mw'],
    "pāṇicāpalya": ['mw'],
    "pāṇidharma": ['cae', 'mw'],
    "pāṇigata": ['ddsa', 'mw'],
    "pāṇiggaha": ['cped'],
    "pāṇigha": ['mw'],
    "pāṇighna": ['mw'],
    "pāṇighāta": ['mw'],
    "pāṇighātam": ['mw'],
    "pāṇigraha": ['cae', 'mw'],
    "pāṇigrahaṇa": ['mw'],
    "pāṇigrahaṇamantra": ['mw'],
    "pāṇigrahaṇasaṃskāra": ['mw'],
    "pāṇigrahaṇika": ['cae', 'mw'],
    "pāṇigrahaṇīya": ['cae', 'mw'],
    "pāṇigrahaṇīyā": ['mw'],
    "pāṇigrahādikṛtyaviveka": ['mw'],
    "pāṇigrahītṛ": ['cae', 'mw'],
    "pāṇigrāha": ['cae', 'mw'],
    "pāṇigrāhaka": ['cae', 'mw'],
    "pāṇigrāham": ['mw'],
    "pāṇigrāhavat": ['mw'],
    "pāṇigṛhīta": ['mw'],
    "pāṇihatā": ['bhs', 'mw'],
    "pāṇija": ['mw'],
    "pāṇika": ['ap90', 'mw'],
    "pāṇikacchapikā": ['mw'],
    "pāṇikarṇa": ['mw'],
    "pāṇikhāta": ['mw'],
    "pāṇikhātā": ['bhs'],
    "pāṇikā": ['cped', 'mw'],
    "pāṇikūrcan": ['mw'],
    "pāṇikūrcas": ['mw'],
    "pāṇimant": ['cae'],
    "pāṇimarda": ['mw'],
    "pāṇimardam": ['mw'],
    "pāṇimat": ['mw'],
    "pāṇimita": ['cae', 'mw'],
    "pāṇimukha": ['mw'],
    "pāṇimukta": ['mw'],
    "pāṇimānikā": ['mw'],
    "pāṇimūla": ['mw'],
    "pāṇin": ['cae', 'ddsa', 'mw'],
    "pāṇina": ['mw'],
    "pāṇini": ['cae', 'ddsa', 'mw'],
    "pāṇinidarśana": ['mw'],
    "pāṇinikṛti": ['mw'],
    "pāṇinisūtravṛtti": ['mw'],
    "pāṇinisūtravṛttyarthasaṃgraha": ['mw'],
    "pāṇinivyākaraṇadīpikā": ['mw'],
    "pāṇiniḥ": ['ap90'],
    "pāṇinīya": ['ap90', 'cae', 'mw'],
    "pāṇinīyaliṅgānuśāsana": ['mw'],
    "pāṇinīyamatadarpaṇa": ['mw'],
    "pāṇinīyasūtra": ['mw'],
    "pāṇinīyasūtrasārakośa": ['mw'],
    "pāṇinīyaśīkṣā": ['mw'],
    "pāṇipadma": ['cae'],
    "pāṇipallava": ['mw'],
    "pāṇipradāna": ['mw'],
    "pāṇipraṇayin": ['mw'],
    "pāṇipraṇayinī": ['mw'],
    "pāṇipuṭa": ['mw'],
    "pāṇipuṭaka": ['mw'],
    "pāṇipāda": ['cae', 'mw'],
    "pāṇipādacapala": ['mw'],
    "pāṇipātra": ['ddsa', 'mw'],
    "pāṇipīḍana": ['cae', 'mw'],
    "pāṇipūra": ['mw'],
    "pāṇipūrānna": ['mw'],
    "pāṇirekhā": ['mw'],
    "pāṇiruh": ['mw'],
    "pāṇiruha": ['mw'],
    "pāṇisargya": ['mw'],
    "pāṇisaṃghaṭṭana": ['mw'],
    "pāṇisaṃgraha": ['mw'],
    "pāṇisaṃgrahaṇa": ['mw'],
    "pāṇistha": ['cae', 'mw'],
    "pāṇisvanika": ['mw'],
    "pāṇisvara": ['bhs'],
    "pāṇisvaraka": ['bhs'],
    "pāṇisvarya": ['bhs'],
    "pāṇitala": ['cae', 'cped', 'mw'],
    "pāṇitāla": ['mw'],
    "pāṇivāda": ['mw'],
    "pāṇiḥ": ['ap90'],
    "pāṇiṃdhama": ['ap90', 'mw'],
    "pāṇiṃdhaya": ['mw'],
    "pāṇy": ['mw'],
    "pāṇya": ['ap90', 'cae', 'mw'],
    "pāṇyupaghātam": ['mw'],
    "pāṇyupakarṣam": ['mw'],
    "pāṇyāsya": ['cae', 'ddsa', 'mw'],
    "pāṇī": ['bhs', 'cped', 'mw'],
    "pāṇītaka": ['mw'],
    "pāṇītala": ['mw'],
    "pāṇḍa": ['mw'],
    "pāṇḍaka": ['bhs', 'mw'],
    "pāṇḍala": ['bhs', 'mw'],
    "pāṇḍalameghā": ['bhs', 'mw'],
    "pāṇḍara": ['bhs', 'cae', 'ddsa', 'mw'],
    "pāṇḍarabhikṣu": ['bhs', 'mw'],
    "pāṇḍaradanta": ['mw'],
    "pāṇḍaradvaragopura": ['mw'],
    "pāṇḍarapuṣpikā": ['mw'],
    "pāṇḍaravāsas": ['cae', 'mw'],
    "pāṇḍaravāsin": ['mw'],
    "pāṇḍaravāsinī": ['bhs', 'mw'],
    "pāṇḍaravāyasa": ['mw'],
    "pāṇḍaretara": ['mw'],
    "pāṇḍaretaravāsas": ['mw'],
    "pāṇḍarin": ['ddsa'],
    "pāṇḍarā": ['bhs', 'mw'],
    "pāṇḍarājayaśobhūṣaṇa": ['mw'],
    "pāṇḍava": ['bhs', 'cae', 'ddsa', 'mw'],
    "pāṇḍavacarita": ['mw'],
    "pāṇḍavagītā": ['mw'],
    "pāṇḍavakulaprasūta": ['mw'],
    "pāṇḍavanakula": ['mw'],
    "pāṇḍavapratāpa": ['mw'],
    "pāṇḍavapurāṇa": ['mw'],
    "pāṇḍavavahni": ['mw'],
    "pāṇḍavaśreṣṭha": ['mw'],
    "pāṇḍaveya": ['cae', 'mw'],
    "pāṇḍavika": ['mw'],
    "pāṇḍavābhyudaya": ['mw'],
    "pāṇḍavābhīla": ['mw'],
    "pāṇḍavānanda": ['mw'],
    "pāṇḍavānīka": ['mw'],
    "pāṇḍavāraṇi": ['mw'],
    "pāṇḍavāyana": ['mw'],
    "pāṇḍavīya": ['cae', 'mw'],
    "pāṇḍiman": ['cae', 'ddsa'],
    "pāṇḍitya": ['cae', 'ddsa', 'mw'],
    "pāṇḍityadarpaṇa": ['mw'],
    "pāṇḍu": ['bhs', 'cae', 'ddsa', 'mw'],
    "pāṇḍubhāva": ['mw'],
    "pāṇḍubhūma": ['cae', 'mw'],
    "pāṇḍucchattra": ['mw'],
    "pāṇḍucchāya": ['mw'],
    "pāṇḍudukūla": ['mw'],
    "pāṇḍudukūlasīvana": ['mw'],
    "pāṇḍudāsa": ['mw'],
    "pāṇḍugātra": ['mw'],
    "pāṇḍugātratā": ['mw'],
    "pāṇḍuka": ['bhs', 'mw'],
    "pāṇḍukambala": ['mw'],
    "pāṇḍukambalasaṃvṛta": ['mw'],
    "pāṇḍukambalaśilā": ['bhs', 'mw'],
    "pāṇḍukambalin": ['mw'],
    "pāṇḍukaraṇa": ['mw'],
    "pāṇḍukarman": ['mw'],
    "pāṇḍukaṇṭaka": ['mw'],
    "pāṇḍukin": ['mw'],
    "pāṇḍula": ['bhs'],
    "pāṇḍulaka": ['bhs'],
    "pāṇḍulekha": ['cae', 'ddsa', 'mw'],
    "pāṇḍulekhya": ['mw'],
    "pāṇḍuloha": ['mw'],
    "pāṇḍulohita": ['bhs'],
    "pāṇḍulomaparṇī": ['mw'],
    "pāṇḍulomaśā": ['mw'],
    "pāṇḍulomā": ['mw'],
    "pāṇḍumukha": ['mw'],
    "pāṇḍumṛd": ['mw'],
    "pāṇḍumṛttika": ['mw'],
    "pāṇḍumṛttikā": ['mw'],
    "pāṇḍunandana": ['cae'],
    "pāṇḍunāga": ['mw'],
    "pāṇḍupatnī": ['mw'],
    "pāṇḍupattra": ['cae', 'mw'],
    "pāṇḍupattratā": ['mw'],
    "pāṇḍupattrodara": ['mw'],
    "pāṇḍupattrī": ['mw'],
    "pāṇḍuphala": ['mw'],
    "pāṇḍuphalā": ['mw'],
    "pāṇḍuphalī": ['mw'],
    "pāṇḍuputra": ['mw'],
    "pāṇḍuputrī": ['mw'],
    "pāṇḍupṛṣṭha": ['mw'],
    "pāṇḍura": ['cae', 'ddsa', 'mw'],
    "pāṇḍuradruma": ['mw'],
    "pāṇḍuraka": ['bhs', 'mw'],
    "pāṇḍuraphalī": ['mw'],
    "pāṇḍurapṛṣṭha": ['mw'],
    "pāṇḍuratā": ['cae', 'mw'],
    "pāṇḍuravāsin": ['mw'],
    "pāṇḍuraya": ['mw'],
    "pāṇḍuraṅga": ['mw'],
    "pāṇḍuraṅgamāhātmya": ['mw'],
    "pāṇḍuraṅgaviṭṭhalastotra": ['mw'],
    "pāṇḍuraṅgā": ['mw'],
    "pāṇḍuraṅgāṣṭaka": ['mw'],
    "pāṇḍurekṣu": ['mw'],
    "pāṇḍuriman": ['mw'],
    "pāṇḍurita": ['mw'],
    "pāṇḍuroga": ['cae', 'mw'],
    "pāṇḍurogaghna": ['mw'],
    "pāṇḍuroganāśana": ['mw'],
    "pāṇḍurogin": ['mw'],
    "pāṇḍurā": ['bhs', 'mw'],
    "pāṇḍurāga": ['mw'],
    "pāṇḍurāṣṭra": ['mw'],
    "pāṇḍurīkaraṇa": ['mw'],
    "pāṇḍurīkaraṇakṛ": ['mw'],
    "pāṇḍusaupāka": ['cae', 'mw'],
    "pāṇḍusikata": ['mw'],
    "pāṇḍusopāka": ['cae', 'mw'],
    "pāṇḍusūdanarasa": ['mw'],
    "pāṇḍutaru": ['mw'],
    "pāṇḍutva": ['mw'],
    "pāṇḍutā": ['mw'],
    "pāṇḍutīrtha": ['mw'],
    "pāṇḍuvarmadeva": ['mw'],
    "pāṇḍuvarṇa": ['mw'],
    "pāṇḍuśarkarā": ['mw'],
    "pāṇḍuśarmilā": ['mw'],
    "pāṇḍv": ['mw'],
    "pāṇḍva": ['cae', 'mw'],
    "pāṇḍvarirasa": ['mw'],
    "pāṇḍvavabhāsa": ['mw'],
    "pāṇḍvāmaya": ['mw'],
    "pāṇḍvāmayin": ['mw'],
    "pāṇḍvārti": ['mw'],
    "pāṇḍya": ['cae', 'ddsa', 'mw'],
    "pāṇḍyadeśa": ['mw'],
    "pāṇḍyamāthura": ['bhs'],
    "pāṇḍyanareśvara": ['mw'],
    "pāṇḍyanātha": ['mw'],
    "pāṇḍyarāja": ['mw'],
    "pāṇḍyarāṣṭrādhipa": ['mw'],
    "pāṇḍyavāṭa": ['mw'],
    "pāṇḍyavāṭaka": ['mw'],
    "pāṇḍūka": ['mw'],
    "pāṇṭa": ['mw'],
    "pāṣaka": ['mw'],
    "pāṣaṃḍa": ['ap90'],
    "pāṣaṃḍakaḥ": ['ap90'],
    "pāṣaṇḍa": ['cae', 'ddsa', 'mw'],
    "pāṣaṇḍacapeṭikā": ['mw'],
    "pāṣaṇḍadalana": ['mw'],
    "pāṣaṇḍaka": ['mw'],
    "pāṣaṇḍakhaṇḍana": ['mw'],
    "pāṣaṇḍamukhacapeṭikā": ['mw'],
    "pāṣaṇḍamukhamardana": ['mw'],
    "pāṣaṇḍastha": ['cae', 'mw'],
    "pāṣaṇḍatā": ['cae', 'mw'],
    "pāṣaṇḍaviḍambana": ['mw'],
    "pāṣaṇḍika": ['bhs', 'mw'],
    "pāṣaṇḍin": ['cae', 'mw'],
    "pāṣaṇḍāsyacapeṭikā": ['mw'],
    "pāṣia": ['gra'],
    "pāṣya": ['cae', 'gra', 'mw'],
    "pāṣāṇa": ['cae', 'ddsa', 'mw'],
    "pāṣāṇabheda": ['mw'],
    "pāṣāṇabhedaka": ['mw'],
    "pāṣāṇabhedana": ['mw'],
    "pāṣāṇabhedarasa": ['mw'],
    "pāṣāṇabhedin": ['mw'],
    "pāṣāṇacaturdaśī": ['mw'],
    "pāṣāṇacayanibaddha": ['mw'],
    "pāṣāṇadāraka": ['mw'],
    "pāṣāṇadāraṇa": ['mw'],
    "pāṣāṇagardabha": ['mw'],
    "pāṣāṇaghātadāyin": ['mw'],
    "pāṣāṇahṛdaya": ['mw'],
    "pāṣāṇamaya": ['mw'],
    "pāṣāṇasaṃdhi": ['mw'],
    "pāṣāṇasetubandha": ['mw'],
    "pāṣāṇavajrakarasa": ['mw'],
    "pāṣāṇaśilā": ['mw'],
    "pāṣāṇaḥ": ['ap90'],
    "pāṣāṇī": ['mw'],
    "pāṣāṇḍa": ['mw'],
    "pāṣāṇḍin": ['mw'],
    "pāṣāṇḍya": ['mw'],
    "pāṣī": ['bhs', 'mw'],
    "pāṣṭhauha": ['mw'],
    "pāṭ": ['ap90', 'mw'],
    "pāṭa": ['cae', 'ddsa', 'mw'],
    "pāṭaccara": ['cae', 'ddsa', 'mw'],
    "pāṭaccaraḥ": ['ap90'],
    "pāṭahika": ['bhs'],
    "pāṭahikā": ['mw'],
    "pāṭaka": ['cae', 'mw'],
    "pāṭakaḥ": ['ap90'],
    "pāṭala": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "pāṭalacakṣus": ['mw'],
    "pāṭaladruma": ['mw'],
    "pāṭalagaṇḍalekha": ['mw'],
    "pāṭalaka": ['ap90', 'bhs', 'mw'],
    "pāṭalakusama": ['mw'],
    "pāṭalakīṭa": ['mw'],
    "pāṭalapuṣpa": ['mw'],
    "pāṭalaromaka": ['mw'],
    "pāṭalaya": ['ddsa', 'mw'],
    "pāṭali": ['cae', 'ddsa', 'mw'],
    "pāṭaligrāmaka": ['bhs'],
    "pāṭaligrāmīyaka": ['bhs'],
    "pāṭalika": ['ap90', 'mw'],
    "pāṭalikā": ['bhs'],
    "pāṭaliman": ['ap90', 'ddsa', 'mw'],
    "pāṭalin": ['ddsa', 'mw'],
    "pāṭaliputra": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāṭaliputraka": ['mw'],
    "pāṭaliputranāmadheya": ['mw'],
    "pāṭaliputta": ['cped'],
    "pāṭalita": ['mw'],
    "pāṭaliḥ": ['ap90'],
    "pāṭalopala": ['ddsa', 'mw'],
    "pāṭalya": ['mw'],
    "pāṭalyā": ['ap90', 'mw'],
    "pāṭalā": ['ap90', 'mw'],
    "pāṭalācalamāhātmya": ['mw'],
    "pāṭalādrimāhātmya": ['mw'],
    "pāṭalāpuṣpasaṃnibha": ['mw'],
    "pāṭalāvatī": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāṭalī": ['cped', 'mw'],
    "pāṭalīkṛ": ['ddsa', 'mw'],
    "pāṭalīputra": ['mw'],
    "pāṭana": ['cae', 'ddsa', 'mw'],
    "pāṭanakriyā": ['mw'],
    "pāṭanaṃ": ['ap90'],
    "pāṭanā": ['mw'],
    "pāṭanīya": ['mw'],
    "pāṭapāṭika": ['bhs'],
    "pāṭava": ['cae', 'cped', 'ddsa', 'mw'],
    "pāṭavaṃ": ['ap90'],
    "pāṭavika": ['ap90', 'mw'],
    "pāṭaḥ": ['ap90'],
    "pāṭekka": ['cped'],
    "pāṭha": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "pāṭhaccheda": ['mw'],
    "pāṭhadoṣa": ['cae', 'mw'],
    "pāṭhaka": ['cae', 'cped', 'mw'],
    "pāṭhakaḥ": ['ap90'],
    "pāṭhamañjarī": ['mw'],
    "pāṭhana": ['cae', 'mw'],
    "pāṭhanaṃ": ['ap90'],
    "pāṭhaniścaya": ['mw'],
    "pāṭhaniściti": ['mw'],
    "pāṭhanārambhapīṭhikā": ['mw'],
    "pāṭhapraṇālī": ['mw'],
    "pāṭhavant": ['cae'],
    "pāṭhavat": ['mw'],
    "pāṭhaviccheda": ['mw'],
    "pāṭhaḥ": ['ap90'],
    "pāṭheya": ['mw'],
    "pāṭhika": ['ap90', 'mw'],
    "pāṭhikā": ['mw'],
    "pāṭhikāyana": ['mw'],
    "pāṭhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "pāṭhita": ['ap90', 'mw'],
    "pāṭhya": ['cae', 'mw'],
    "pāṭhyaratnakośa": ['mw'],
    "pāṭhā": ['mw'],
    "pāṭhāntara": ['mw'],
    "pāṭhāntaraya": ['mw'],
    "pāṭhīna": ['cae', 'cped', 'ddsa', 'mw'],
    "pāṭhīnaḥ": ['ap90'],
    "pāṭibhoga": ['cped'],
    "pāṭihera": ['cped'],
    "pāṭihāra": ['cped'],
    "pāṭihāriya": ['cped'],
    "pāṭihāriyapakkha": ['cped'],
    "pāṭihīra": ['cped'],
    "pāṭikaṅkha": ['cped'],
    "pāṭikaṅkhī": ['cped'],
    "pāṭikā": ['cped', 'mw'],
    "pāṭikāvāḍi": ['mw'],
    "pāṭikūlya": ['cped'],
    "pāṭin": ['cae', 'mw'],
    "pāṭipada": ['cped'],
    "pāṭirāja": ['bhs'],
    "pāṭita": ['ap90', 'mw'],
    "pāṭiyaka": ['bhs'],
    "pāṭiyekka": ['cped'],
    "pāṭiyekkaṁ": ['cped'],
    "pāṭya": ['mw'],
    "pāṭā": ['mw'],
    "pāṭāvalī": ['mw'],
    "pāṭī": ['ap90', 'mw'],
    "pāṭīgaṇita": ['mw'],
    "pāṭīkaumudī": ['mw'],
    "pāṭīlilāvatī": ['mw'],
    "pāṭīra": ['cae', 'mw'],
    "pāṭīraḥ": ['ap90'],
    "pāṭīsāra": ['mw'],
    "pāṭūpaṭa": ['mw'],
    "pāṭūra": ['cae', 'mw'],
    "pāṭṭāraka": ['mw'],
    "pī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pības": ['mw'],
    "pīcaṃ": ['ap90'],
    "pīdārī": ['mw'],
    "pīl": ['ap90', 'mw'],
    "pīlaka": ['mw'],
    "pīlakaḥ": ['ap90'],
    "pīlu": ['bhs', 'cae', 'ddsa', 'mw'],
    "pīluka": ['mw'],
    "pīlukaḥ": ['ap90'],
    "pīlukuṇa": ['mw'],
    "pīlumatī": ['cae', 'mw'],
    "pīlunī": ['mw'],
    "pīluparṇī": ['mw'],
    "pīlupati": ['mw'],
    "pīlupattra": ['mw'],
    "pīlupāka": ['mw'],
    "pīlusāra": ['mw'],
    "pīlusārastūpa": ['mw'],
    "pīluvaha": ['mw'],
    "pīluvana": ['mw'],
    "pīluvādin": ['mw'],
    "pīluḥ": ['ap90'],
    "pīlā": ['cae', 'mw'],
    "pīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "pīnakakudmat": ['mw'],
    "pīnanitambā": ['mw'],
    "pīnara": ['mw'],
    "pīnasa": ['cae', 'ddsa', 'mw'],
    "pīnasanāśana": ['mw'],
    "pīnasanāśanā": ['mw'],
    "pīnasaḥ": ['ap90'],
    "pīnasin": ['mw'],
    "pīnasita": ['mw'],
    "pīnastana": ['mw'],
    "pīnatarala": ['mw'],
    "pīnatva": ['mw'],
    "pīnatā": ['mw'],
    "pīnavakṣas": ['mw'],
    "pīnaśroṇipayodhara": ['mw'],
    "pīnodhas": ['mw'],
    "pīnodhnī": ['mw'],
    "pīnottuṅgastanī": ['mw'],
    "pīnāha": ['mw'],
    "pīnāyatakakudmat": ['ddsa', 'mw'],
    "pīnāṃsa": ['mw'],
    "pīpari": ['mw'],
    "pīpivas": ['gra', 'mw'],
    "pīpivaṃs": ['cae'],
    "pīta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "pītabhasman": ['mw'],
    "pītabhṛṅgarāja": ['mw'],
    "pītabījā": ['mw'],
    "pītacampaka": ['mw'],
    "pītacandana": ['mw'],
    "pītacañcu": ['mw'],
    "pītadru": ['mw'],
    "pītadugdhā": ['mw'],
    "pītadāru": ['mw'],
    "pītadīptā": ['mw'],
    "pītagandha": ['mw'],
    "pītaghoṣā": ['mw'],
    "pītaharita": ['mw'],
    "pītaharitacchāya": ['mw'],
    "pītaka": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "pītakadalī": ['mw'],
    "pītakadruma": ['mw'],
    "pītakamākṣika": ['mw'],
    "pītakanda": ['mw'],
    "pītakaravīraka": ['mw'],
    "pītakauśeyavāsas": ['mw'],
    "pītakedāra": ['mw'],
    "pītakośa": ['ddsa', 'mw'],
    "pītakuṣṭha": ['mw'],
    "pītakāvera": ['mw'],
    "pītakāṣṭha": ['mw'],
    "pītakīlā": ['mw'],
    "pītala": ['ap90', 'mw'],
    "pītalaka": ['mw'],
    "pītalakaṃ": ['ap90'],
    "pītaloha": ['mw'],
    "pītamadya": ['mw'],
    "pītamastaka": ['mw'],
    "pītamaṇi": ['mw'],
    "pītamaṇḍūka": ['mw'],
    "pītamudga": ['mw'],
    "pītamustā": ['mw'],
    "pītamuṇḍa": ['mw'],
    "pītamākṣika": ['mw'],
    "pītamāruta": ['mw'],
    "pītamāñjiṣṭha": ['mw'],
    "pītamūlaka": ['mw'],
    "pītana": ['cae', 'cped', 'mw'],
    "pītanaka": ['mw'],
    "pītanaḥ": ['ap90'],
    "pītanidra": ['mw'],
    "pītanīla": ['mw'],
    "pītaparṇī": ['mw'],
    "pītaphala": ['mw'],
    "pītaprasava": ['mw'],
    "pītapratibaddhavatsā": ['mw'],
    "pītapura": ['mw'],
    "pītapuṣpa": ['mw'],
    "pītapuṣpā": ['mw'],
    "pītapuṣpī": ['mw'],
    "pītapādaka": ['mw'],
    "pītapādā": ['mw'],
    "pītarakta": ['mw'],
    "pītaraktacchāya": ['mw'],
    "pītarambhā": ['mw'],
    "pītarasa": ['mw'],
    "pītaratna": ['mw'],
    "pītaratnaka": ['mw'],
    "pītarohiṇī": ['mw'],
    "pītarāga": ['mw'],
    "pītaskandha": ['mw'],
    "pītasomapūrva": ['cae', 'mw'],
    "pītasphaṭika": ['mw'],
    "pītasphoṭa": ['mw'],
    "pītasāra": ['mw'],
    "pītasāraka": ['mw'],
    "pītasāri": ['mw'],
    "pītataila": ['mw'],
    "pītatailā": ['mw'],
    "pītataṇḍula": ['mw'],
    "pītataṇḍulā": ['mw'],
    "pītatuṇḍa": ['mw'],
    "pītatva": ['mw'],
    "pītatā": ['mw'],
    "pītavant": ['cae'],
    "pītavarṇa": ['mw'],
    "pītavarṇaka": ['mw'],
    "pītavat": ['mw'],
    "pītavipīta": ['mw'],
    "pītavālukā": ['mw'],
    "pītavāsas": ['cae', 'mw'],
    "pītavṛkṣa": ['mw'],
    "pītayūthī": ['mw'],
    "pītaśeṣa": ['mw'],
    "pītaśoṇita": ['mw'],
    "pītaśāla": ['mw'],
    "pītaśālaka": ['mw'],
    "pītaṅgalya": ['bhs'],
    "pītha": ['cae', 'ddsa', 'gra', 'mw'],
    "pīthaḥ": ['ap90'],
    "pīthe": ['mw'],
    "pīthi": ['mw'],
    "pīthin": ['cae', 'ddsa', 'mw'],
    "pīthita": ['bhs'],
    "pīthiḥ": ['ap90'],
    "pīthya": ['gra', 'mw'],
    "pīthī": ['bhs', 'mw'],
    "pīti": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "pītibhakkha": ['cped'],
    "pītikā": ['ap90', 'mw'],
    "pītiman": ['cae', 'mw'],
    "pītimana": ['cped'],
    "pītin": ['ap90', 'mw'],
    "pītipāmojja": ['cped'],
    "pītirasa": ['cped'],
    "pītisahagata": ['cped'],
    "pītisambojjhaṅga": ['cped'],
    "pītiḥ": ['ap90'],
    "pītodaka": ['cae', 'mw'],
    "pītu": ['mw'],
    "pītudāru": ['ddsa', 'mw'],
    "pītuḥ": ['ap90'],
    "pītvā": ['mw'],
    "pītvāsthiraka": ['mw'],
    "pītvī": ['mw'],
    "pītvīnam": ['mw'],
    "pītā": ['mw'],
    "pītābdhi": ['mw'],
    "pītāmbara": ['cae', 'mw'],
    "pītāmbarāpaddhati": ['mw'],
    "pītāmlāna": ['mw'],
    "pītāruṇa": ['mw'],
    "pītāvabhāsa": ['mw'],
    "pītāvabhāsatā": ['mw'],
    "pītāvaśeṣa": ['mw'],
    "pītāśman": ['mw'],
    "pītāṅga": ['mw'],
    "pīv": ['ap90'],
    "pīva": ['ap90', 'cae', 'ddsa', 'mw'],
    "pīvan": ['ap90', 'cae', 'gra', 'mw'],
    "pīvara": ['ap90', 'cae', 'mw'],
    "pīvarastanī": ['mw'],
    "pīvaratva": ['mw'],
    "pīvarā": ['mw'],
    "pīvarī": ['mw'],
    "pīvarīkṛta": ['mw'],
    "pīvas": ['cae', 'gra', 'mw'],
    "pīvasa": ['cae', 'gra', 'mw'],
    "pīvasvant": ['cae'],
    "pīvasvat": ['gra', 'mw'],
    "pīvaḥsphāka": ['mw'],
    "pīvaṃs": ['cae'],
    "pīviṣṭha": ['cae', 'mw'],
    "pīvo": ['mw'],
    "pīvoanna": ['gra', 'mw'],
    "pīvoaśva": ['gra', 'mw'],
    "pīvopavasana": ['mw'],
    "pīvorūpa": ['ddsa', 'mw'],
    "pīvā": ['ap90', 'mw'],
    "pīy": ['cae', 'gra', 'mw'],
    "pīya": ['ddsa'],
    "pīyaka": ['cae', 'mw'],
    "pīyatnu": ['cae', 'gra', 'mw'],
    "pīyu": ['cae', 'gra', 'mw'],
    "pīyuḥ": ['ap90'],
    "pīyūkṣila": ['mw'],
    "pīyūkṣā": ['mw'],
    "pīyūṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "pīyūṣabhuj": ['mw'],
    "pīyūṣabhānu": ['mw'],
    "pīyūṣadhāman": ['mw'],
    "pīyūṣadhārā": ['mw'],
    "pīyūṣadhārākir": ['mw'],
    "pīyūṣadyuti": ['mw'],
    "pīyūṣagarala": ['cae', 'mw'],
    "pīyūṣakaṇikā": ['mw'],
    "pīyūṣalaharī": ['mw'],
    "pīyūṣamahas": ['mw'],
    "pīyūṣamayūkha": ['mw'],
    "pīyūṣapūrṇa": ['mw'],
    "pīyūṣaruci": ['mw'],
    "pīyūṣasāgara": ['mw'],
    "pīyūṣatā": ['mw'],
    "pīyūṣavarṇa": ['mw'],
    "pīyūṣavarṣa": ['mw'],
    "pīyūṣavarṣāya": ['mw'],
    "pīyūṣaḥ": ['ap90'],
    "pīḍ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pīḍa": ['mw'],
    "pīḍaka": ['mw'],
    "pīḍakaḥ": ['ap90'],
    "pīḍana": ['cae', 'ddsa', 'mw'],
    "pīḍanaṃ": ['ap90'],
    "pīḍanīya": ['mw'],
    "pīḍayitavya": ['mw'],
    "pīḍayā": ['mw'],
    "pīḍin": ['mw'],
    "pīḍita": ['ap90', 'cae', 'ddsa', 'mw'],
    "pīḍitam": ['mw'],
    "pīḍitatva": ['mw'],
    "pīḍitatā": ['mw'],
    "pīḍā": ['ap90', 'cae', 'ddsa', 'mw'],
    "pīḍābhāj": ['mw'],
    "pīḍāgṛha": ['mw'],
    "pīḍākara": ['cae', 'mw'],
    "pīḍākaraṇa": ['mw'],
    "pīḍākṛt": ['cae', 'mw'],
    "pīḍākṛta": ['mw'],
    "pīḍāsthāna": ['mw'],
    "pīḍāya": ['mw'],
    "pīḍāyantragṛha": ['mw'],
    "pīḷaka": ['cped'],
    "pīḷana": ['cped'],
    "pīḷesi": ['cped'],
    "pīḷeti": ['cped'],
    "pīḷetvā": ['cped'],
    "pīḷita": ['cped'],
    "pīḷā": ['cped'],
    "pīṇa": ['cped'],
    "pīṇana": ['cped'],
    "pīṇenta": ['cped'],
    "pīṇesi": ['cped'],
    "pīṇeti": ['cped'],
    "pīṇetvā": ['cped'],
    "pīṇita": ['cped'],
    "pīṣ": ['mw'],
    "pīṣaka": ['bhs'],
    "pīṣati": ['bhs'],
    "pīṭha": ['cae', 'cped', 'ddsa', 'mw'],
    "pīṭhabhū": ['mw'],
    "pīṭhacakra": ['mw'],
    "pīṭhacintāmaṇi": ['mw'],
    "pīṭhaga": ['mw'],
    "pīṭhagarbha": ['mw'],
    "pīṭhaka": ['bhs', 'cae', 'cped', 'mw'],
    "pīṭhakaḥ": ['ap90'],
    "pīṭhakeli": ['mw'],
    "pīṭhalakṣaṇa": ['mw'],
    "pīṭhamarda": ['cae', 'mw'],
    "pīṭhamardikā": ['mw'],
    "pīṭhanirūpaṇa": ['mw'],
    "pīṭhanirṇaya": ['mw'],
    "pīṭhanyāsa": ['mw'],
    "pīṭhanāyikā": ['mw'],
    "pīṭhasappī": ['cped'],
    "pīṭhasarpa": ['cae', 'mw'],
    "pīṭhasarpin": ['cae', 'mw'],
    "pīṭhasthāna": ['mw'],
    "pīṭhasūtra": ['mw'],
    "pīṭhavivara": ['mw'],
    "pīṭhaśaktinirṇaya": ['mw'],
    "pīṭhaṃ": ['ap90'],
    "pīṭhikā": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "pīṭhopapāli": ['mw'],
    "pīṭhādhikāra": ['mw'],
    "pīṭhāya": ['mw'],
    "pū": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pūga": ['cae', 'cped', 'ddsa', 'mw'],
    "pūgakhaṇḍa": ['mw'],
    "pūgakṛta": ['mw'],
    "pūgaphala": ['mw'],
    "pūgapota": ['mw'],
    "pūgapuṣpikā": ['mw'],
    "pūgapātra": ['mw'],
    "pūgapīṭha": ['mw'],
    "pūgaroṭa": ['mw'],
    "pūgarukkha": ['cped'],
    "pūgatitha": ['mw'],
    "pūgavaira": ['mw'],
    "pūgavoṭa": ['mw'],
    "pūgayajña": ['cae', 'mw'],
    "pūgayajñiya": ['mw'],
    "pūgaḥ": ['ap90'],
    "pūgya": ['mw'],
    "pūgī": ['mw'],
    "pūgīlatā": ['mw'],
    "pūgīphala": ['ddsa', 'mw'],
    "pūj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pūjaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "pūjana": ['cae', 'gra', 'mw'],
    "pūjanamālikā": ['mw'],
    "pūjanaṃ": ['ap90'],
    "pūjaneyya": ['cped'],
    "pūjanā": ['bhs', 'cped'],
    "pūjanī": ['mw'],
    "pūjanīya": ['cae', 'cped', 'mw'],
    "pūjanīyā": ['mw'],
    "pūjayamāna": ['cped'],
    "pūjayati": ['bhs'],
    "pūjayitavya": ['cae', 'mw'],
    "pūjayitṛ": ['cae', 'mw'],
    "pūjayāna": ['ap90', 'mw'],
    "pūjenta": ['cped'],
    "pūjesi": ['cped'],
    "pūjeti": ['cped'],
    "pūjetuṁ": ['cped'],
    "pūjetvā": ['cped'],
    "pūjikā": ['cae'],
    "pūjila": ['ap90', 'mw'],
    "pūjita": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "pūjitapattraphalā": ['mw'],
    "pūjitapūjaka": ['mw'],
    "pūjiya": ['cped'],
    "pūjiyamāna": ['cped'],
    "pūjopakaraṇa": ['cae', 'ddsa', 'mw'],
    "pūjopayogisāman": ['mw'],
    "pūjya": ['ap90', 'cae', 'ddsa', 'mw'],
    "pūjyapāda": ['mw'],
    "pūjyapādacaritra": ['mw'],
    "pūjyapūjā": ['mw'],
    "pūjyapūjāvyatikrama": ['mw'],
    "pūjyatva": ['mw'],
    "pūjyatā": ['cae', 'mw'],
    "pūjā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "pūjāgṛha": ['cae', 'mw'],
    "pūjākara": ['mw'],
    "pūjākarman": ['mw'],
    "pūjākhaṇḍa": ['mw'],
    "pūjākrama": ['mw'],
    "pūjākāṇḍa": ['mw'],
    "pūjānyāsavidhi": ['mw'],
    "pūjāpaddhati": ['mw'],
    "pūjāpathyamālā": ['mw'],
    "pūjāpaṭṭaka": ['mw'],
    "pūjāpradīpa": ['mw'],
    "pūjāprakāśa": ['mw'],
    "pūjāraha": ['cped'],
    "pūjāratna": ['mw'],
    "pūjāratnākara": ['mw'],
    "pūjārha": ['cae', 'mw'],
    "pūjāsambhāra": ['mw'],
    "pūjāsatkāra": ['cae', 'mw'],
    "pūjāsaṃbhāra": ['cae'],
    "pūjāvaikalyaprāyaścitta": ['mw'],
    "pūjāvat": ['mw'],
    "pūjāvidhi": ['mw'],
    "pūl": ['ap90', 'mw'],
    "pūla": ['bhs', 'cae', 'ddsa', 'mw'],
    "pūlaka": ['cae'],
    "pūlaḥ": ['ap90'],
    "pūlikā": ['ap90'],
    "pūlya": ['cae', 'mw'],
    "pūlyaṃ": ['ap90'],
    "pūlāka": ['mw'],
    "pūlākaḥ": ['ap90'],
    "pūlāsa": ['mw'],
    "pūlāsaka": ['mw'],
    "pūlāsakakuraṇḍa": ['mw'],
    "pūlāsakuraṇḍa": ['mw'],
    "pūna": ['ap90', 'mw'],
    "pūni": ['mw'],
    "pūniḥ": ['ap90'],
    "pūnādevī": ['mw'],
    "pūpa": ['cae', 'cped', 'ddsa', 'mw'],
    "pūpalikā": ['mw'],
    "pūpalā": ['ap90', 'mw'],
    "pūpalī": ['ap90', 'mw'],
    "pūpaśālā": ['cae', 'mw'],
    "pūpaḥ": ['ap90'],
    "pūpika": ['bhs'],
    "pūpikā": ['ap90', 'mw'],
    "pūpiya": ['cped'],
    "pūpya": ['mw'],
    "pūpālika": ['mw'],
    "pūpālikā": ['ap90', 'mw'],
    "pūpālī": ['ap90', 'mw'],
    "pūpāṣṭakā": ['mw'],
    "pūpīya": ['mw'],
    "pūr": ['ap90', 'mw'],
    "pūra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "pūraka": ['ap90', 'cae', 'cped', 'mw'],
    "pūrakakumbhakarecaka": ['mw'],
    "pūrakapiṇḍa": ['mw'],
    "pūram": ['mw'],
    "pūray": ['cae'],
    "pūraya": ['ddsa'],
    "pūrayitavya": ['mw'],
    "pūrayitvā": ['mw'],
    "pūrayitṛ": ['ap90', 'cae', 'mw'],
    "pūraśāyin": ['bhs'],
    "pūraḥ": ['ap90'],
    "pūraṇa": ['ap90', 'cae', 'mw'],
    "pūraṇakarṇa": ['bhs'],
    "pūraṇakāśyapa": ['bhs', 'mw'],
    "pūraṇapariśiṣṭa": ['mw'],
    "pūraṇapratyaya": ['mw'],
    "pūraṇavyākhyā": ['mw'],
    "pūraṇī": ['mw'],
    "pūraṇīya": ['cae', 'mw'],
    "pūrbhid": ['cae', 'ddsa', 'gra', 'mw'],
    "pūrbhidya": ['gra', 'mw'],
    "pūrdevī": ['mw'],
    "pūrdvār": ['mw'],
    "pūrdvāra": ['mw'],
    "pūrenta": ['cped'],
    "pūresi": ['cped'],
    "pūreti": ['cped'],
    "pūretuṁ": ['cped'],
    "pūretvā": ['cped'],
    "pūri": ['bhs'],
    "pūrikaḥ": ['ap90'],
    "pūrikā": ['ddsa', 'mw'],
    "pūrin": ['mw'],
    "pūrita": ['ap90', 'cped', 'mw'],
    "pūrjayana": ['mw'],
    "pūrmārga": ['mw'],
    "pūrotpīḍa": ['ddsa', 'mw'],
    "pūrpati": ['cae', 'gra', 'mw'],
    "pūrta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pūrtadharma": ['mw'],
    "pūrtamālā": ['mw'],
    "pūrtaprakāśa": ['mw'],
    "pūrtaya": ['ddsa', 'mw'],
    "pūrti": ['cae', 'ddsa', 'gra', 'mw'],
    "pūrtikāma": ['mw'],
    "pūrtin": ['cae', 'mw'],
    "pūrtiḥ": ['ap90'],
    "pūrtoddyota": ['mw'],
    "pūrtvan": ['cae', 'mw'],
    "pūru": ['cae', 'ddsa', 'gra', 'mw'],
    "pūruāyus": ['gra'],
    "pūruṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "pūruṣaghna": ['gra', 'mw'],
    "pūruṣatvatā": ['mw'],
    "pūruṣaḥ": ['ap90'],
    "pūruṣād": ['cae', 'gra', 'mw'],
    "pūruṣāda": ['mw'],
    "pūrva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pūrvabandhu": ['cae', 'mw'],
    "pūrvabhadrapada": ['mw'],
    "pūrvabhaj": ['gra'],
    "pūrvabhakṣikā": ['bhs', 'mw'],
    "pūrvabhava": ['mw'],
    "pūrvabhikṣikā": ['mw'],
    "pūrvabhukti": ['cae', 'mw'],
    "pūrvabhādrapada": ['mw'],
    "pūrvabhāga": ['cae', 'ddsa', 'mw'],
    "pūrvabhāj": ['cae', 'mw'],
    "pūrvabhāva": ['mw'],
    "pūrvabhāvin": ['mw'],
    "pūrvabhāvitva": ['mw'],
    "pūrvabhāṣin": ['mw'],
    "pūrvabhūbhṛt": ['cae', 'mw'],
    "pūrvabhūta": ['mw'],
    "pūrvabrāhmaṇa": ['mw'],
    "pūrvabuddhānusmṛtyasaṅgājñānā": ['bhs'],
    "pūrvabādha": ['mw'],
    "pūrvacarama": ['bhs'],
    "pūrvacintana": ['mw'],
    "pūrvacit": ['mw'],
    "pūrvacitta": ['mw'],
    "pūrvacitti": ['cae', 'ddsa', 'gra', 'mw'],
    "pūrvacittikā": ['mw'],
    "pūrvacittī": ['mw'],
    "pūrvacitī": ['mw'],
    "pūrvacodita": ['cae', 'mw'],
    "pūrvacoditatva": ['mw'],
    "pūrvadaihika": ['mw'],
    "pūrvadakṣiṇa": ['cae', 'ddsa', 'mw'],
    "pūrvadarśana": ['mw'],
    "pūrvadatta": ['cae', 'mw'],
    "pūrvadeha": ['mw'],
    "pūrvadehe": ['mw'],
    "pūrvadehika": ['mw'],
    "pūrvadeva": ['cae', 'mw'],
    "pūrvadevikā": ['mw'],
    "pūrvadeśa": ['cae', 'mw'],
    "pūrvadhyāna": ['mw'],
    "pūrvadigīśa": ['mw'],
    "pūrvadikpati": ['mw'],
    "pūrvadina": ['mw'],
    "pūrvadiś": ['cae', 'mw'],
    "pūrvadiśya": ['mw'],
    "pūrvadiṣṭa": ['mw'],
    "pūrvadugdha": ['mw'],
    "pūrvaduṣkṛtabhoga": ['mw'],
    "pūrvadvāra": ['mw'],
    "pūrvadvārika": ['mw'],
    "pūrvadāvika": ['mw'],
    "pūrvadīkṣin": ['mw'],
    "pūrvadīkṣā": ['mw'],
    "pūrvadṛṣṭa": ['cae', 'mw'],
    "pūrvadṛṣṭi": ['mw'],
    "pūrvaga": ['cae', 'ddsa', 'mw'],
    "pūrvagama": ['mw'],
    "pūrvagata": ['cae', 'mw'],
    "pūrvagatvan": ['cae', 'gra', 'mw'],
    "pūrvagaṅgā": ['mw'],
    "pūrvaghaṭakarpara": ['mw'],
    "pūrvagrāmin": ['mw'],
    "pūrvahoma": ['mw'],
    "pūrvahūti": ['cae', 'gra', 'mw'],
    "pūrvaiṣukāmaśama": ['mw'],
    "pūrvaja": ['cae', 'ddsa', 'gra', 'mw'],
    "pūrvajadeva": ['mw'],
    "pūrvajana": ['cae', 'mw'],
    "pūrvajanmakṛta": ['mw'],
    "pūrvajanman": ['cae', 'mw'],
    "pūrvajanmika": ['bhs'],
    "pūrvajanmārjita": ['mw'],
    "pūrvajanmāvadāna": ['bhs'],
    "pūrvajina": ['mw'],
    "pūrvajñāna": ['mw'],
    "pūrvajā": ['cae', 'gra', 'mw'],
    "pūrvajāti": ['mw'],
    "pūrvajāvan": ['cae', 'gra', 'mw'],
    "pūrvaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "pūrvakalpa": ['mw'],
    "pūrvakalpe": ['mw'],
    "pūrvakalpeṣu": ['mw'],
    "pūrvakam": ['mw'],
    "pūrvakarmakṛtavādin": ['mw'],
    "pūrvakarman": ['cae', 'mw'],
    "pūrvakoṭi": ['bhs', 'mw'],
    "pūrvakramāgata": ['mw'],
    "pūrvakriyā": ['mw'],
    "pūrvakāla": ['cae', 'mw'],
    "pūrvakālatā": ['mw'],
    "pūrvakālika": ['cae', 'mw'],
    "pūrvakālīna": ['mw'],
    "pūrvakālīnatva": ['mw'],
    "pūrvakāmakṛtvan": ['mw'],
    "pūrvakārin": ['bhs', 'mw'],
    "pūrvakārya": ['mw'],
    "pūrvakāya": ['cae', 'mw'],
    "pūrvakāṣṭhā": ['mw'],
    "pūrvakṛt": ['mw'],
    "pūrvakṛta": ['cae', 'mw'],
    "pūrvakṛtvarī": ['mw'],
    "pūrvakṛṣṇīya": ['mw'],
    "pūrvalakṣaṇa": ['mw'],
    "pūrvam": ['mw'],
    "pūrvamadhyāhna": ['mw'],
    "pūrvamadhyānha": ['ddsa'],
    "pūrvamadra": ['mw'],
    "pūrvamagadha": ['mw'],
    "pūrvamukha": ['mw'],
    "pūrvamāgadhaka": ['mw'],
    "pūrvamārin": ['cae', 'mw'],
    "pūrvamīmāṃsā": ['cae', 'mw'],
    "pūrvamīmāṃsākārikā": ['mw'],
    "pūrvamīmāṃsārthasaṃgraha": ['mw'],
    "pūrvanagarī": ['mw'],
    "pūrvanaḍaka": ['mw'],
    "pūrvanimitta": ['bhs', 'mw'],
    "pūrvanipāta": ['cae', 'ddsa', 'mw'],
    "pūrvaniviṣṭa": ['cae', 'mw'],
    "pūrvanivāsa": ['bhs', 'mw'],
    "pūrvanivāsajñāna": ['mw'],
    "pūrvanivāsānusmṛti": ['mw'],
    "pūrvanyāsa": ['mw'],
    "pūrvanyāya": ['mw'],
    "pūrvapada": ['cae', 'mw'],
    "pūrvapadaprakṛtisvara": ['mw'],
    "pūrvapadatva": ['mw'],
    "pūrvapadika": ['mw'],
    "pūrvapadya": ['mw'],
    "pūrvapakṣa": ['cae', 'ddsa', 'mw'],
    "pūrvapakṣagrantha": ['mw'],
    "pūrvapakṣagranthaprakāśa": ['mw'],
    "pūrvapakṣagrantharahasya": ['mw'],
    "pūrvapakṣagranthaṭīkā": ['mw'],
    "pūrvapakṣagranthānugama": ['mw'],
    "pūrvapakṣalakṣaṇa": ['mw'],
    "pūrvapakṣanirukti": ['mw'],
    "pūrvapakṣapāda": ['mw'],
    "pūrvapakṣarahasya": ['mw'],
    "pūrvapakṣavyutpattilakṣaṇa": ['mw'],
    "pūrvapakṣavyutpattivāda": ['mw'],
    "pūrvapakṣavyāpti": ['mw'],
    "pūrvapakṣavyāptikroḍa": ['mw'],
    "pūrvapakṣavyāptilakṣaṇa": ['mw'],
    "pūrvapakṣaya": ['mw'],
    "pūrvapakṣin": ['mw'],
    "pūrvapakṣāvalī": ['mw'],
    "pūrvapakṣīkṛ": ['mw'],
    "pūrvapakṣīya": ['mw'],
    "pūrvaparibhedya": ['mw'],
    "pūrvapariccheda": ['mw'],
    "pūrvaparigraha": ['mw'],
    "pūrvaparvata": ['mw'],
    "pūrvapatha": ['cae', 'mw'],
    "pūrvapañcāla": ['mw'],
    "pūrvapaścima": ['mw'],
    "pūrvapaścimatas": ['mw'],
    "pūrvapaścānmukha": ['mw'],
    "pūrvapaścāt": ['mw'],
    "pūrvapaścāyata": ['mw'],
    "pūrvapeya": ['cae', 'gra', 'mw'],
    "pūrvaphalgunī": ['mw'],
    "pūrvaphalgunībhava": ['mw'],
    "pūrvapitāmaha": ['cae', 'mw'],
    "pūrvaprajñā": ['mw'],
    "pūrvaprasthita": ['mw'],
    "pūrvapratipanna": ['mw'],
    "pūrvapravṛtta": ['mw'],
    "pūrvaprayoga": ['mw'],
    "pūrvapraṇidhinirmāṇacandra": ['bhs'],
    "pūrvapraṇidhānasaṃcodanasvara": ['bhs'],
    "pūrvapreta": ['bhs', 'mw'],
    "pūrvapretapūjaka": ['mw'],
    "pūrvaprāyaścitta": ['mw'],
    "pūrvapuruṣa": ['cae', 'mw'],
    "pūrvapā": ['cae', 'gra', 'mw'],
    "pūrvapāda": ['cae', 'mw'],
    "pūrvapālin": ['mw'],
    "pūrvapāna": ['mw'],
    "pūrvapāyia": ['gra'],
    "pūrvapāyya": ['cae', 'gra', 'mw'],
    "pūrvapāñcālaka": ['mw'],
    "pūrvapāṇinīya": ['mw'],
    "pūrvapāṭaliputra": ['mw'],
    "pūrvapāṭaliputraka": ['mw'],
    "pūrvapīti": ['cae', 'gra', 'mw'],
    "pūrvapīṭhikā": ['mw'],
    "pūrvapūjita": ['mw'],
    "pūrvapūrva": ['cae', 'mw'],
    "pūrvapūrvokta": ['cae', 'mw'],
    "pūrvapūrvānugaṇḍikā": ['mw'],
    "pūrvapūrṇamāsī": ['mw'],
    "pūrvaraṅga": ['ddsa', 'mw'],
    "pūrvarāga": ['mw'],
    "pūrvarāja": ['mw'],
    "pūrvarātra": ['cae', 'mw'],
    "pūrvarātrakṛta": ['mw'],
    "pūrvarūpa": ['cae', 'mw'],
    "pūrvarūpatā": ['mw'],
    "pūrvasabhika": ['cae', 'mw'],
    "pūrvasad": ['cae', 'mw'],
    "pūrvasaktha": ['mw'],
    "pūrvasamudra": ['cae', 'mw'],
    "pūrvasara": ['mw'],
    "pūrvasasya": ['mw'],
    "pūrvasañcita": ['ddsa'],
    "pūrvasaṃcita": ['mw'],
    "pūrvasaṃdhyā": ['mw'],
    "pūrvasaṃhitā": ['mw'],
    "pūrvasaṃjalpa": ['mw'],
    "pūrvasevā": ['mw'],
    "pūrvasiddha": ['mw'],
    "pūrvasiddhānta": ['mw'],
    "pūrvasiddhāntapakṣatā": ['mw'],
    "pūrvastha": ['mw'],
    "pūrvasthiti": ['mw'],
    "pūrvasupta": ['mw'],
    "pūrvasvara": ['mw'],
    "pūrvasāgara": ['cae', 'mw'],
    "pūrvasāhasa": ['cae', 'mw'],
    "pūrvasāra": ['mw'],
    "pūrvasārasārāsvādinī": ['mw'],
    "pūrvasārin": ['mw'],
    "pūrvasū": ['cae', 'gra', 'mw'],
    "pūrvasūri": ['mw'],
    "pūrvatana": ['ap90', 'mw'],
    "pūrvatantra": ['mw'],
    "pūrvatara": ['ddsa', 'mw'],
    "pūrvataram": ['mw'],
    "pūrvatas": ['ap90', 'cae', 'mw'],
    "pūrvataskara": ['cae', 'mw'],
    "pūrvathā": ['cae', 'ddsa', 'gra', 'mw'],
    "pūrvatra": ['ap90', 'cae', 'mw'],
    "pūrvatraigartaka": ['mw'],
    "pūrvatraiyalinda": ['mw'],
    "pūrvatryalinda": ['mw'],
    "pūrvatva": ['cae', 'mw'],
    "pūrvatā": ['mw'],
    "pūrvatāpanīya": ['mw'],
    "pūrvatāpanīyopaniṣad": ['mw'],
    "pūrvatāpinī": ['mw'],
    "pūrvatāpinīdīpikā": ['mw'],
    "pūrvavah": ['cae', 'mw'],
    "pūrvavairin": ['cae', 'mw'],
    "pūrvavant": ['cae'],
    "pūrvavartin": ['mw'],
    "pūrvavartitva": ['mw'],
    "pūrvavartitā": ['mw'],
    "pūrvavat": ['ap90', 'cae', 'gra', 'mw'],
    "pūrvavattara": ['mw'],
    "pūrvavayas": ['mw'],
    "pūrvavayasa": ['mw'],
    "pūrvavayasin": ['mw'],
    "pūrvavayaska": ['mw'],
    "pūrvavid": ['cae', 'mw'],
    "pūrvavideha": ['bhs', 'mw'],
    "pūrvavidehalipi": ['mw'],
    "pūrvavidhi": ['cae', 'mw'],
    "pūrvavihita": ['cae', 'mw'],
    "pūrvavipratiṣedha": ['mw'],
    "pūrvavāda": ['cae', 'mw'],
    "pūrvavādin": ['mw'],
    "pūrvavāh": ['cae'],
    "pūrvavākya": ['mw'],
    "pūrvavārṣika": ['mw'],
    "pūrvavāyu": ['mw'],
    "pūrvavṛta": ['mw'],
    "pūrvavṛtta": ['cae', 'mw'],
    "pūrvaya": ['mw'],
    "pūrvayakṣa": ['mw'],
    "pūrvayoga": ['bhs', 'mw'],
    "pūrvayāmya": ['mw'],
    "pūrvayāmye": ['mw'],
    "pūrvayāvan": ['gra', 'mw'],
    "pūrvayāyin": ['mw'],
    "pūrvayāyāta": ['mw'],
    "pūrvaśaila": ['bhs', 'ddsa', 'mw'],
    "pūrvaśailasaṃghārāma": ['mw'],
    "pūrvaśaivadīkṣāvidhi": ['mw'],
    "pūrvaśas": ['bhs'],
    "pūrvaśiṣya": ['cae', 'mw'],
    "pūrvaśānti": ['mw'],
    "pūrvaśārada": ['mw'],
    "pūrvaśāstra": ['mw'],
    "pūrvaśāṃśapa": ['mw'],
    "pūrvaśīrṣa": ['mw'],
    "pūrvaṃgama": ['ap90', 'bhs', 'mw'],
    "pūrvaṃgamana": ['bhs'],
    "pūrvaṃgata": ['mw'],
    "pūrvaṣaṭka": ['mw'],
    "pūrve": ['bhs'],
    "pūrvedyurdugdha": ['mw'],
    "pūrvedyurāhṛta": ['mw'],
    "pūrvedyus": ['ap90', 'cae', 'ddsa', 'mw'],
    "pūrvejāti": ['bhs'],
    "pūrvendra": ['mw'],
    "pūrvenivāsa": ['bhs'],
    "pūrvetara": ['mw'],
    "pūrvevāsa": ['bhs'],
    "pūrveṇa": ['cae', 'ddsa', 'mw'],
    "pūrveṣukāmaśamī": ['mw'],
    "pūrvi": ['bhs'],
    "pūrvia": ['gra'],
    "pūrviastuti": ['gra'],
    "pūrvika": ['bhs', 'mw'],
    "pūrvikāyām": ['bhs'],
    "pūrvin": ['ap90', 'mw'],
    "pūrvineṣṭha": ['mw'],
    "pūrviṇa": ['mw'],
    "pūrvocita": ['mw'],
    "pūrvodakplava": ['mw'],
    "pūrvodita": ['mw'],
    "pūrvokta": ['cae', 'ddsa', 'mw'],
    "pūrvoktaparāmarśaka": ['mw'],
    "pūrvopakrama": ['mw'],
    "pūrvopakārin": ['cae', 'mw'],
    "pūrvopanihita": ['cae', 'mw'],
    "pūrvopapanna": ['mw'],
    "pūrvopasṛta": ['mw'],
    "pūrvopārjita": ['mw'],
    "pūrvotpanna": ['mw'],
    "pūrvotpannatva": ['mw'],
    "pūrvotpatti": ['mw'],
    "pūrvottara": ['mw'],
    "pūrvottaraśānti": ['mw'],
    "pūrvottare": ['mw'],
    "pūrvotthita": ['mw'],
    "pūrvotthāyin": ['mw'],
    "pūrvya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pūrvyam": ['mw'],
    "pūrvyastuti": ['mw'],
    "pūrvā": ['ddsa', 'mw'],
    "pūrvābhibhāṣin": ['mw'],
    "pūrvābhilāpin": ['bhs'],
    "pūrvābhimukha": ['ddsa', 'mw'],
    "pūrvābhirāmā": ['mw'],
    "pūrvābhiṣeka": ['mw'],
    "pūrvābhyāsa": ['mw'],
    "pūrvābhyāsena": ['mw'],
    "pūrvābhādrapadā": ['mw'],
    "pūrvābhūtvā": ['bhs'],
    "pūrvācala": ['cae', 'mw'],
    "pūrvācarita": ['mw'],
    "pūrvācārya": ['cae'],
    "pūrvācāryavṛttāntadīpikā": ['mw'],
    "pūrvādhika": ['cae', 'mw'],
    "pūrvādhikadyuti": ['mw'],
    "pūrvādhikārin": ['mw'],
    "pūrvādhirāma": ['mw'],
    "pūrvādhyuṣita": ['mw'],
    "pūrvādi": ['mw'],
    "pūrvāditas": ['mw'],
    "pūrvādri": ['cae', 'mw'],
    "pūrvādya": ['cae', 'mw'],
    "pūrvāgni": ['mw'],
    "pūrvāgnivahana": ['mw'],
    "pūrvāgnivāh": ['mw'],
    "pūrvāhla": ['ddsa'],
    "pūrvāhṇa": ['cae', 'gra', 'mw'],
    "pūrvāhṇaka": ['mw'],
    "pūrvāhṇakāle": ['mw'],
    "pūrvāhṇakṛta": ['mw'],
    "pūrvāhṇatana": ['mw'],
    "pūrvāhṇegeya": ['mw'],
    "pūrvāhṇetana": ['mw'],
    "pūrvāhṇika": ['cae', 'mw'],
    "pūrvāhṇikā": ['bhs'],
    "pūrvāhṇāparāhṇayoḥ": ['mw'],
    "pūrvākṣara": ['ddsa'],
    "pūrvālāpin": ['bhs'],
    "pūrvāmbudhi": ['mw'],
    "pūrvānta": ['bhs', 'mw'],
    "pūrvāntatas": ['mw'],
    "pūrvāntika": ['bhs'],
    "pūrvānubhūta": ['mw'],
    "pūrvānuyoga": ['mw'],
    "pūrvānuṣṭhita": ['mw'],
    "pūrvānuṣṭhitatva": ['mw'],
    "pūrvāpaharaṇā": ['mw'],
    "pūrvāpakārin": ['mw'],
    "pūrvāpara": ['cae', 'gra', 'mw'],
    "pūrvāparadakṣiṇa": ['mw'],
    "pūrvāparadina": ['mw'],
    "pūrvāparagrantha": ['mw'],
    "pūrvāparam": ['mw'],
    "pūrvāparaprayoga": ['mw'],
    "pūrvāpararātri": ['mw'],
    "pūrvāparasmārtaprayoga": ['mw'],
    "pūrvāparatva": ['mw'],
    "pūrvāparavirodha": ['mw'],
    "pūrvāparya": ['mw'],
    "pūrvāparyeṇa": ['mw'],
    "pūrvāparāntakasūtra": ['bhs'],
    "pūrvāparāyata": ['mw'],
    "pūrvāparībhāva": ['ddsa', 'mw'],
    "pūrvāparībhū": ['mw'],
    "pūrvāpuṣ": ['mw'],
    "pūrvārcika": ['mw'],
    "pūrvārdha": ['cae', 'mw'],
    "pūrvārdhabhāga": ['mw'],
    "pūrvārdhakāya": ['cae', 'mw'],
    "pūrvārdhalambin": ['mw'],
    "pūrvārdhya": ['mw'],
    "pūrvārjita": ['ddsa', 'mw'],
    "pūrvārāma": ['bhs', 'mw'],
    "pūrvāsin": ['mw'],
    "pūrvātitha": ['mw'],
    "pūrvātithi": ['mw'],
    "pūrvāvadhīrita": ['cae', 'mw'],
    "pūrvāvadāna": ['bhs'],
    "pūrvāvedaka": ['cae', 'mw'],
    "pūrvāyus": ['gra', 'mw'],
    "pūrvāśin": ['mw'],
    "pūrvāśā": ['ddsa', 'mw'],
    "pūrvāṅga": ['mw'],
    "pūrvāṣāḍhajananaśānti": ['mw'],
    "pūrvāṣāḍhā": ['mw'],
    "pūrvī": ['cae', 'ddsa', 'mw'],
    "pūrvīkaroti": ['bhs'],
    "pūrvīṇa": ['mw'],
    "pūrya": ['mw'],
    "pūryasyām": ['bhs'],
    "pūryya": ['ap90'],
    "pūryāṇa": ['mw'],
    "pūrāmla": ['mw'],
    "pūrāpesi": ['cped'],
    "pūrāpeti": ['cped'],
    "pūrāpetvā": ['cped'],
    "pūrāpita": ['cped'],
    "pūrī": ['mw'],
    "pūrṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "pūrṇabandhura": ['mw'],
    "pūrṇabhadra": ['bhs', 'mw'],
    "pūrṇabhadrikā": ['bhs'],
    "pūrṇabhedinī": ['mw'],
    "pūrṇabīja": ['mw'],
    "pūrṇacandra": ['bhs', 'cae', 'mw'],
    "pūrṇacandranibhānana": ['mw'],
    "pūrṇacandraprabhā": ['mw'],
    "pūrṇacandraprāyaścittaprakaraṇa": ['mw'],
    "pūrṇacāttra": ['mw'],
    "pūrṇadarva": ['mw'],
    "pūrṇadeva": ['mw'],
    "pūrṇadharma": ['mw'],
    "pūrṇagabhasti": ['gra', 'mw'],
    "pūrṇagarbha": ['mw'],
    "pūrṇagarbhā": ['mw'],
    "pūrṇagiri": ['mw'],
    "pūrṇagātra": ['bhs'],
    "pūrṇahoma": ['mw'],
    "pūrṇaka": ['bhs', 'cae', 'mw'],
    "pūrṇakakud": ['mw'],
    "pūrṇakaḥ": ['ap90'],
    "pūrṇakaṃsa": ['mw'],
    "pūrṇakha": ['mw'],
    "pūrṇakośā": ['mw'],
    "pūrṇakoṣṭhā": ['mw'],
    "pūrṇakumbha": ['cae', 'mw'],
    "pūrṇakuṭa": ['mw'],
    "pūrṇakākud": ['mw'],
    "pūrṇakākuda": ['mw'],
    "pūrṇakāma": ['mw'],
    "pūrṇakāmatā": ['mw'],
    "pūrṇakāraṇa": ['mw'],
    "pūrṇakūṭa": ['mw'],
    "pūrṇalakṣmīka": ['mw'],
    "pūrṇamaitrāyaṇīputra": ['bhs', 'mw'],
    "pūrṇamaṇḍala": ['mw'],
    "pūrṇamukha": ['bhs', 'mw'],
    "pūrṇamukta": ['mw'],
    "pūrṇamuṣṭi": ['mw'],
    "pūrṇamā": ['bhs', 'mw'],
    "pūrṇamānasa": ['mw'],
    "pūrṇamās": ['cae', 'mw'],
    "pūrṇamāsa": ['cae', 'mw'],
    "pūrṇamāsī": ['mw'],
    "pūrṇaparvendu": ['mw'],
    "pūrṇaprajña": ['mw'],
    "pūrṇaprajñadarśana": ['mw'],
    "pūrṇaprakāśa": ['mw'],
    "pūrṇapuruṣārthacandra": ['mw'],
    "pūrṇapurī": ['mw'],
    "pūrṇapātra": ['cae', 'mw'],
    "pūrṇapātramaya": ['mw'],
    "pūrṇapātrapratibhaṭa": ['mw'],
    "pūrṇapātravṛttyā": ['mw'],
    "pūrṇaratha": ['mw'],
    "pūrṇasamaya": ['mw'],
    "pūrṇasaugandha": ['mw'],
    "pūrṇasena": ['mw'],
    "pūrṇasruva": ['mw'],
    "pūrṇatva": ['mw'],
    "pūrṇatā": ['cae', 'mw'],
    "pūrṇatūṇa": ['mw'],
    "pūrṇavaināśika": ['mw'],
    "pūrṇavandhura": ['gra', 'mw'],
    "pūrṇavapus": ['mw'],
    "pūrṇavarman": ['mw'],
    "pūrṇavighana": ['mw'],
    "pūrṇaviṃśativarṣa": ['cae', 'mw'],
    "pūrṇayauvana": ['mw'],
    "pūrṇayoga": ['mw'],
    "pūrṇaśakti": ['mw'],
    "pūrṇaśaktimat": ['mw'],
    "pūrṇaśruti": ['mw'],
    "pūrṇaśrī": ['cae', 'mw'],
    "pūrṇeccha": ['cae', 'ddsa', 'mw'],
    "pūrṇendu": ['cae', 'mw'],
    "pūrṇendubimbānana": ['mw'],
    "pūrṇendurasa": ['mw'],
    "pūrṇenduvadana": ['mw'],
    "pūrṇeśa": ['mw'],
    "pūrṇi": ['mw'],
    "pūrṇika": ['bhs'],
    "pūrṇikā": ['mw'],
    "pūrṇiman": ['mw'],
    "pūrṇimā": ['ap90', 'cae', 'ddsa', 'mw'],
    "pūrṇimādina": ['mw'],
    "pūrṇimāmanorathavrata": ['mw'],
    "pūrṇimānta": ['mw'],
    "pūrṇimārātri": ['mw'],
    "pūrṇimārātriśarvarī": ['mw'],
    "pūrṇimāsī": ['mw'],
    "pūrṇoda": ['mw'],
    "pūrṇodarā": ['mw'],
    "pūrṇopamā": ['ddsa', 'mw'],
    "pūrṇotkaṭa": ['mw'],
    "pūrṇotsaṅga": ['mw'],
    "pūrṇā": ['mw'],
    "pūrṇābhilāṣa": ['mw'],
    "pūrṇābhiṣeka": ['mw'],
    "pūrṇābhiṣekapaddhati": ['mw'],
    "pūrṇābhiṣikta": ['mw'],
    "pūrṇābhrarasa": ['mw'],
    "pūrṇāhuti": ['mw'],
    "pūrṇāhutika": ['mw'],
    "pūrṇāhutimantra": ['mw'],
    "pūrṇāhutiprayoga": ['mw'],
    "pūrṇākṣa": ['mw'],
    "pūrṇākṣya": ['mw'],
    "pūrṇālaka": ['mw'],
    "pūrṇāmṛta": ['mw'],
    "pūrṇāmṛtā": ['mw'],
    "pūrṇāmṛtāṃśuvadana": ['mw'],
    "pūrṇāmṛtāṃśuvadanā": ['cae'],
    "pūrṇānadī": ['mw'],
    "pūrṇānaka": ['mw'],
    "pūrṇānanda": ['mw'],
    "pūrṇānandaprabandha": ['mw'],
    "pūrṇāpūrṇa": ['mw'],
    "pūrṇārtha": ['cae', 'mw'],
    "pūrṇāvatāra": ['mw'],
    "pūrṇāyata": ['mw'],
    "pūrṇāyus": ['mw'],
    "pūrṇāñjali": ['ddsa', 'mw'],
    "pūrṇāśrama": ['mw'],
    "pūrṇāśramīya": ['mw'],
    "pūrṇāśā": ['mw'],
    "pūrṇāṅgada": ['mw'],
    "pūrṇāṅka": ['mw'],
    "pūrṇāṅkagaṇita": ['mw'],
    "pūrṇīkṛ": ['ddsa', 'mw'],
    "pūt": ['ap90', 'ddsa', 'mw'],
    "pūta": ['ap90', 'bhs', 'mw'],
    "pūtabandhana": ['gra', 'mw'],
    "pūtabandhu": ['gra', 'mw'],
    "pūtabhṛt": ['ddsa', 'mw'],
    "pūtadakṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "pūtadakṣas": ['cae', 'gra'],
    "pūtadhānya": ['mw'],
    "pūtadru": ['mw'],
    "pūtagandha": ['mw'],
    "pūtakratu": ['gra', 'mw'],
    "pūtakratā": ['gra', 'mw'],
    "pūtakratāyī": ['mw'],
    "pūtamati": ['mw'],
    "pūtamūrti": ['cae', 'mw'],
    "pūtana": ['cae', 'ddsa', 'mw'],
    "pūtanaḥ": ['ap90'],
    "pūtanikā": ['mw'],
    "pūtanā": ['mw'],
    "pūtanādūṣaṇa": ['mw'],
    "pūtanāhan": ['mw'],
    "pūtanākeśa": ['mw'],
    "pūtanākeśī": ['mw'],
    "pūtanāmokṣaṇaprastāva": ['mw'],
    "pūtanāri": ['mw'],
    "pūtanāsūdana": ['mw'],
    "pūtanātva": ['mw'],
    "pūtanāvidhāna": ['mw'],
    "pūtanāya": ['mw'],
    "pūtapattrī": ['mw'],
    "pūtaphala": ['mw'],
    "pūtapāpa": ['cae', 'mw'],
    "pūtapāpman": ['mw'],
    "pūtara": ['mw'],
    "pūtatṛṇa": ['mw'],
    "pūtayavam": ['mw'],
    "pūthikā": ['mw'],
    "pūti": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "pūtibhāva": ['cae', 'mw'],
    "pūtidhānya": ['mw'],
    "pūtigandha": ['cae', 'cped', 'mw'],
    "pūtigandhi": ['cae', 'mw'],
    "pūtigandhika": ['mw'],
    "pūtigandhikā": ['mw'],
    "pūtigandhā": ['mw'],
    "pūtighāsa": ['mw'],
    "pūtika": ['ap90', 'cae', 'cped', 'mw'],
    "pūtikaraja": ['mw'],
    "pūtikarañja": ['mw'],
    "pūtikarṇa": ['mw'],
    "pūtikarṇaka": ['mw'],
    "pūtikarṇatā": ['mw'],
    "pūtikeśvaratīrtha": ['mw'],
    "pūtikhaṣa": ['mw'],
    "pūtikuṣmāṇḍāya": ['mw'],
    "pūtikuṣmāṇḍāyamānatva": ['mw'],
    "pūtikā": ['ap90', 'mw'],
    "pūtikāmukha": ['mw'],
    "pūtikāya": ['cped'],
    "pūtikāṣṭha": ['mw'],
    "pūtikāṣṭhaka": ['mw'],
    "pūtikīṭa": ['mw'],
    "pūtilatā": ['cped'],
    "pūtimaccha": ['cped'],
    "pūtimayūrikā": ['mw'],
    "pūtimeda": ['mw'],
    "pūtimukha": ['cped'],
    "pūtimukta": ['bhs', 'mw'],
    "pūtimutta": ['cped'],
    "pūtimāṃsa": ['mw'],
    "pūtimāṣa": ['mw'],
    "pūtimṛttika": ['cae', 'mw'],
    "pūtinasya": ['mw'],
    "pūtināsika": ['mw'],
    "pūtināsāgada": ['mw'],
    "pūtiparṇa": ['mw'],
    "pūtipattra": ['mw'],
    "pūtiphalā": ['mw'],
    "pūtiphalī": ['mw'],
    "pūtipuṣpikā": ['mw'],
    "pūtirajju": ['mw'],
    "pūtitailā": ['mw'],
    "pūtitailātva": ['mw'],
    "pūtitva": ['cae'],
    "pūtivaktra": ['cae', 'mw'],
    "pūtivaktratā": ['mw'],
    "pūtivaya": ['mw'],
    "pūtivraṇa": ['mw'],
    "pūtivāta": ['mw'],
    "pūtivṛkṣa": ['mw'],
    "pūtiśapharī": ['mw'],
    "pūtiśārijā": ['mw'],
    "pūtiśṛñjaya": ['mw'],
    "pūtkārī": ['ap90', 'mw'],
    "pūtkṛ": ['ap90'],
    "pūtrima": ['ap90', 'cae', 'mw'],
    "pūtudru": ['mw'],
    "pūtudāru": ['mw'],
    "pūtyaṇḍa": ['ddsa', 'mw'],
    "pūtā": ['mw'],
    "pūtātman": ['mw'],
    "pūtātmatā": ['mw'],
    "pūtīka": ['cae', 'mw'],
    "pūtīkarañja": ['mw'],
    "pūva": ['cped'],
    "pūvika": ['cped'],
    "pūy": ['ap90', 'cae', 'mw'],
    "pūya": ['cae', 'cped', 'ddsa', 'mw'],
    "pūyabhuj": ['cae', 'mw'],
    "pūyamāna": ['ddsa', 'mw'],
    "pūyamānayavam": ['mw'],
    "pūyana": ['mw'],
    "pūyanaṃ": ['ap90'],
    "pūyarakta": ['mw'],
    "pūyavaha": ['mw'],
    "pūyaśonita": ['cae'],
    "pūyaśoṇita": ['mw'],
    "pūyaḥ": ['ap90'],
    "pūyoda": ['mw'],
    "pūyābha": ['mw'],
    "pūyālasa": ['mw'],
    "pūyāri": ['mw'],
    "pūḥkāmya": ['mw'],
    "pūṇ": ['ap90', 'mw'],
    "pūṣ": ['ap90', 'mw'],
    "pūṣa": ['mw'],
    "pūṣabhāsā": ['mw'],
    "pūṣadantahara": ['mw'],
    "pūṣadhra": ['mw'],
    "pūṣamitra": ['mw'],
    "pūṣan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pūṣaria": ['gra'],
    "pūṣarya": ['gra'],
    "pūṣarāti": ['gra', 'mw'],
    "pūṣaḥ": ['ap90'],
    "pūṣaṇ": ['mw'],
    "pūṣaṇa": ['ddsa', 'gra', 'mw'],
    "pūṣaṇvant": ['cae'],
    "pūṣaṇvat": ['ddsa', 'gra', 'mw'],
    "pūṣaṇā": ['mw'],
    "pūṣkara": ['mw'],
    "pūṣā": ['mw'],
    "pūṣānuja": ['mw'],
    "pūṣāsuhṛd": ['mw'],
    "pūṣātmaja": ['mw'],
    "pūṣāṣṭottara": ['mw'],
    "pūṭa": ['bhs'],
    "pṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "pṛc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pṛccha": ['bhs', 'ddsa'],
    "pṛcchaka": ['cae', 'ddsa', 'mw'],
    "pṛcchakaḥ": ['ap90'],
    "pṛcchana": ['mw'],
    "pṛcchanaṃ": ['ap90'],
    "pṛcchaparipṛcchikā": ['bhs'],
    "pṛcchati": ['bhs'],
    "pṛcchika": ['bhs'],
    "pṛcchya": ['cae', 'mw'],
    "pṛcchā": ['ap90', 'cae', 'mw'],
    "pṛch": ['gra'],
    "pṛdāku": ['cae', 'ddsa', 'gra', 'mw'],
    "pṛdākusānu": ['gra', 'mw'],
    "pṛdākuḥ": ['ap90'],
    "pṛhā": ['bhs'],
    "pṛj": ['mw'],
    "pṛkkā": ['mw'],
    "pṛkta": ['ap90', 'cae', 'ddsa', 'mw'],
    "pṛktha": ['mw'],
    "pṛkthaṃ": ['ap90'],
    "pṛkti": ['mw'],
    "pṛktiḥ": ['ap90'],
    "pṛkṣ": ['cae', 'ddsa', 'gra', 'mw'],
    "pṛkṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "pṛkṣaprayaj": ['gra', 'mw'],
    "pṛkṣas": ['ap90'],
    "pṛkṣayāma": ['gra', 'mw'],
    "pṛkṣu": ['mw'],
    "pṛkṣudh": ['gra', 'mw'],
    "pṛt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pṛtana": ['cae', 'ddsa', 'mw'],
    "pṛtanaṃ": ['ap90'],
    "pṛtany": ['cae', 'gra'],
    "pṛtanya": ['ddsa', 'mw'],
    "pṛtanyati": ['ap90'],
    "pṛtanyu": ['cae', 'ddsa', 'gra', 'mw'],
    "pṛtanyā": ['ap90', 'mw'],
    "pṛtanā": ['ap90', 'gra', 'mw'],
    "pṛtanāhava": ['gra', 'mw'],
    "pṛtanāj": ['cae', 'gra', 'mw'],
    "pṛtanāja": ['mw'],
    "pṛtanājaya": ['mw'],
    "pṛtanājia": ['gra'],
    "pṛtanājit": ['cae', 'mw'],
    "pṛtanājya": ['cae', 'gra', 'mw'],
    "pṛtanānī": ['mw'],
    "pṛtanāpati": ['mw'],
    "pṛtanāsāhya": ['cae', 'mw'],
    "pṛtanāy": ['cae', 'gra'],
    "pṛtanāya": ['ddsa', 'mw'],
    "pṛtanāyu": ['ap90', 'cae', 'gra', 'mw'],
    "pṛtanāṣah": ['cae', 'ddsa', 'gra', 'mw'],
    "pṛtanāṣāh": ['gra', 'mw'],
    "pṛtanāṣāhia": ['gra'],
    "pṛtanāṣāhya": ['cae', 'gra', 'mw'],
    "pṛth": ['ap90', 'gra', 'mw'],
    "pṛtha": ['cae', 'ddsa', 'mw'],
    "pṛthag": ['mw'],
    "pṛthagabhimati": ['mw'],
    "pṛthagartha": ['cae', 'ddsa', 'mw'],
    "pṛthagarthatā": ['mw'],
    "pṛthagbhavati": ['bhs'],
    "pṛthagbhāva": ['cae', 'mw'],
    "pṛthagbhū": ['mw'],
    "pṛthagbhūta": ['mw'],
    "pṛthagbīja": ['mw'],
    "pṛthagdevata": ['mw'],
    "pṛthagdharmavid": ['mw'],
    "pṛthagdvāra": ['mw'],
    "pṛthagdṛś": ['mw'],
    "pṛthaggaṇa": ['cae', 'ddsa', 'mw'],
    "pṛthaggotra": ['mw'],
    "pṛthagguṇa": ['mw'],
    "pṛthagjana": ['cae', 'mw'],
    "pṛthagjanakalyāṇaka": ['bhs', 'mw'],
    "pṛthagjanapada": ['mw'],
    "pṛthagjanatā": ['bhs'],
    "pṛthagjanavat": ['mw'],
    "pṛthagjaya": ['mw'],
    "pṛthaglakṣaṇa": ['mw'],
    "pṛthagrasamaya": ['mw'],
    "pṛthagrūpa": ['mw'],
    "pṛthagudāhāra": ['bhs'],
    "pṛthagupādāna": ['cae', 'mw'],
    "pṛthagvartman": ['mw'],
    "pṛthagvarṣa": ['cae', 'mw'],
    "pṛthagvidha": ['cae', 'mw'],
    "pṛthagvādin": ['mw'],
    "pṛthagyoga": ['mw'],
    "pṛthagyogakaraṇa": ['mw'],
    "pṛthagālaya": ['mw'],
    "pṛthagātman": ['mw'],
    "pṛthagātmatā": ['mw'],
    "pṛthagātmikā": ['mw'],
    "pṛthagīśamānin": ['mw'],
    "pṛthahara": ['mw'],
    "pṛthak": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pṛthakat": ['mw'],
    "pṛthakcara": ['mw'],
    "pṛthakceṣṭā": ['mw'],
    "pṛthakkaraṇa": ['cae', 'mw'],
    "pṛthakkriyā": ['mw'],
    "pṛthakkula": ['mw'],
    "pṛthakkāma": ['mw'],
    "pṛthakkārakam": ['bhs'],
    "pṛthakkārya": ['ddsa', 'mw'],
    "pṛthakkṛ": ['mw'],
    "pṛthakkṛta": ['mw'],
    "pṛthakkṛti": ['mw'],
    "pṛthakkṣetra": ['mw'],
    "pṛthakpada": ['mw'],
    "pṛthakpadatva": ['mw'],
    "pṛthakparṇikā": ['mw'],
    "pṛthakparṇī": ['mw'],
    "pṛthakpiṇḍa": ['cae', 'mw'],
    "pṛthaksalila": ['mw'],
    "pṛthaksthita": ['mw'],
    "pṛthaksthiti": ['cae', 'mw'],
    "pṛthaksukha": ['cae', 'mw'],
    "pṛthaktva": ['mw'],
    "pṛthaktvacā": ['mw'],
    "pṛthaktvatas": ['mw'],
    "pṛthaktvaśas": ['mw'],
    "pṛthaktvaṃ": ['ap90'],
    "pṛthaktvena": ['mw'],
    "pṛthaktā": ['cae', 'mw'],
    "pṛthakśabda": ['mw'],
    "pṛthakśayyā": ['mw'],
    "pṛthakśruti": ['mw'],
    "pṛthakśāyin": ['mw'],
    "pṛthamātra": ['mw'],
    "pṛthavāna": ['gra', 'mw'],
    "pṛthavī": ['ap90', 'mw'],
    "pṛthaḥ": ['ap90'],
    "pṛthaṅ": ['mw'],
    "pṛthaṅniṣṭha": ['mw'],
    "pṛthi": ['cae', 'gra', 'mw'],
    "pṛthikā": ['ap90', 'mw'],
    "pṛthisava": ['mw'],
    "pṛthitapṛthita": ['bhs'],
    "pṛthivi": ['mw'],
    "pṛthivibhāga": ['mw'],
    "pṛthividā": ['mw'],
    "pṛthiviloka": ['mw'],
    "pṛthivimūla": ['mw'],
    "pṛthivisad": ['mw'],
    "pṛthivitva": ['mw'],
    "pṛthiviṣad": ['mw'],
    "pṛthiviṣṭha": ['mw'],
    "pṛthiviṣṭhā": ['gra', 'mw'],
    "pṛthivy": ['mw'],
    "pṛthivyupara": ['mw'],
    "pṛthivyupasaṃkramaṇā": ['bhs', 'mw'],
    "pṛthivyāpīḍa": ['mw'],
    "pṛthivyāsaṃsarpa": ['mw'],
    "pṛthivyāvrata": ['mw'],
    "pṛthivī": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "pṛthivībhuj": ['cae', 'mw'],
    "pṛthivībhujaṃga": ['mw'],
    "pṛthivībhṛt": ['cae', 'mw'],
    "pṛthivīcandra": ['mw'],
    "pṛthivīcāla": ['bhs'],
    "pṛthivīdaṇḍapāla": ['mw'],
    "pṛthivīdaṇḍapālatā": ['mw'],
    "pṛthivīdevī": ['mw'],
    "pṛthivīdhara": ['mw'],
    "pṛthivīdharaṇa": ['mw'],
    "pṛthivīdyāvā": ['cae', 'gra', 'mw'],
    "pṛthivīgrantha": ['mw'],
    "pṛthivījaya": ['mw'],
    "pṛthivīkampa": ['cae', 'ddsa', 'mw'],
    "pṛthivīkṛtsna": ['mw'],
    "pṛthivīkṣit": ['cae', 'mw'],
    "pṛthivīloka": ['mw'],
    "pṛthivīmaya": ['mw'],
    "pṛthivīmaṇḍa": ['mw'],
    "pṛthivīmaṇḍala": ['mw'],
    "pṛthivīndra": ['mw'],
    "pṛthivīnātha": ['cae'],
    "pṛthivīparipālaka": ['mw'],
    "pṛthivīparpaṭaka": ['bhs'],
    "pṛthivīpati": ['cae', 'mw'],
    "pṛthivīpaśyin": ['bhs'],
    "pṛthivīplava": ['mw'],
    "pṛthivīpra": ['mw'],
    "pṛthivīpratiṣṭha": ['mw'],
    "pṛthivīpāla": ['cae', 'mw'],
    "pṛthivīpālaka": ['mw'],
    "pṛthivīpārvataka": ['mw'],
    "pṛthivīrasa": ['mw'],
    "pṛthivīruha": ['mw'],
    "pṛthivīrājya": ['mw'],
    "pṛthivīsava": ['mw'],
    "pṛthivīsaṃśita": ['mw'],
    "pṛthivītala": ['cae', 'mw'],
    "pṛthivītva": ['mw'],
    "pṛthivītīrtha": ['mw'],
    "pṛthivīvaralocana": ['bhs', 'mw'],
    "pṛthivīvijaya": ['bhs'],
    "pṛthivīśa": ['mw'],
    "pṛthivīśakra": ['mw'],
    "pṛthivīśvara": ['mw'],
    "pṛthivīṃdadā": ['bhs', 'mw'],
    "pṛthivīṃjaya": ['mw'],
    "pṛthivīṣad": ['mw'],
    "pṛthu": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "pṛthubhuvana": ['mw'],
    "pṛthubudhna": ['cae', 'gra', 'mw'],
    "pṛthubāhu": ['mw'],
    "pṛthubījaka": ['mw'],
    "pṛthucchada": ['mw'],
    "pṛthucārvañcitekṣaṇa": ['mw'],
    "pṛthudarśin": ['mw'],
    "pṛthudatta": ['mw'],
    "pṛthudaṃṣṭra": ['mw'],
    "pṛthudharaṇidhara": ['mw'],
    "pṛthudharma": ['mw'],
    "pṛthudhāra": ['cae', 'mw'],
    "pṛthudāna": ['mw'],
    "pṛthudātṛ": ['mw'],
    "pṛthudīrghabāhu": ['mw'],
    "pṛthuga": ['mw'],
    "pṛthugman": ['gra', 'mw'],
    "pṛthugrīva": ['mw'],
    "pṛthuhara": ['mw'],
    "pṛthujaghana": ['mw'],
    "pṛthujaya": ['mw'],
    "pṛthujman": ['mw'],
    "pṛthujraya": ['cae', 'gra', 'mw'],
    "pṛthujrayas": ['gra', 'mw'],
    "pṛthujāghana": ['gra'],
    "pṛthuka": ['bhs', 'cae', 'ddsa', 'mw'],
    "pṛthukalpiṇī": ['mw'],
    "pṛthukarman": ['mw'],
    "pṛthukaḥ": ['ap90'],
    "pṛthukola": ['mw'],
    "pṛthukucotpīḍam": ['mw'],
    "pṛthukya": ['mw'],
    "pṛthukā": ['mw'],
    "pṛthukīrti": ['mw'],
    "pṛthukīya": ['mw'],
    "pṛthukṛṣṇā": ['mw'],
    "pṛthula": ['ap90', 'cae', 'ddsa', 'mw'],
    "pṛthulalocana": ['mw'],
    "pṛthulalāṭatā": ['mw'],
    "pṛthulaujas": ['mw'],
    "pṛthulavakṣas": ['cae', 'mw'],
    "pṛthulavikrama": ['mw'],
    "pṛthulekṣaṇa": ['cae'],
    "pṛthulocana": ['cae', 'ddsa', 'mw'],
    "pṛthulocanapṛthulaujas": ['ddsa'],
    "pṛthulā": ['mw'],
    "pṛthulākṣa": ['mw'],
    "pṛthumat": ['mw'],
    "pṛthumukha": ['mw'],
    "pṛthumṛdvīkā": ['mw'],
    "pṛthunitamba": ['cae', 'mw'],
    "pṛthupakṣas": ['gra', 'mw'],
    "pṛthupalāśikā": ['mw'],
    "pṛthuparśu": ['cae', 'gra', 'mw'],
    "pṛthupattra": ['mw'],
    "pṛthupragāman": ['gra', 'mw'],
    "pṛthupragāṇa": ['gra', 'mw'],
    "pṛthuprajña": ['mw'],
    "pṛthupratha": ['mw'],
    "pṛthuprotha": ['mw'],
    "pṛthupājas": ['cae', 'gra', 'mw'],
    "pṛthupājavat": ['mw'],
    "pṛthupāṇi": ['cae', 'gra', 'mw'],
    "pṛthupīnavakṣas": ['mw'],
    "pṛthuraśmi": ['mw'],
    "pṛthuroman": ['mw'],
    "pṛthuromayugma": ['mw'],
    "pṛthurukma": ['mw'],
    "pṛthurukman": ['mw'],
    "pṛthurāṣṭra": ['bhs'],
    "pṛthusampad": ['mw'],
    "pṛthusattama": ['mw'],
    "pṛthusattvavat": ['mw'],
    "pṛthusena": ['mw'],
    "pṛthuskandha": ['mw'],
    "pṛthutama": ['mw'],
    "pṛthutara": ['mw'],
    "pṛthutarīkṛ": ['cae', 'mw'],
    "pṛthutva": ['mw'],
    "pṛthutā": ['cae', 'mw'],
    "pṛthuvaktrā": ['mw'],
    "pṛthuvakṣas": ['ddsa', 'mw'],
    "pṛthuvega": ['mw'],
    "pṛthuvyaṃsa": ['mw'],
    "pṛthuyaśas": ['mw'],
    "pṛthuyāman": ['cae', 'gra', 'mw'],
    "pṛthuśekhara": ['mw'],
    "pṛthuśimba": ['mw'],
    "pṛthuśiras": ['cae', 'mw'],
    "pṛthuśrava": ['mw'],
    "pṛthuśravas": ['cae', 'gra', 'mw'],
    "pṛthuśroṇi": ['mw'],
    "pṛthuśroṇī": ['mw'],
    "pṛthuśrī": ['mw'],
    "pṛthuśṛṅga": ['mw'],
    "pṛthuṃjaya": ['mw'],
    "pṛthuṣeṇa": ['mw'],
    "pṛthuṣṭu": ['gra', 'mw'],
    "pṛthuṣṭuka": ['gra', 'mw'],
    "pṛthvikā": ['mw'],
    "pṛthvī": ['ap90', 'bhs', 'ddsa', 'mw'],
    "pṛthvībhara": ['mw'],
    "pṛthvībhuj": ['mw'],
    "pṛthvībhṛt": ['mw'],
    "pṛthvīcandrodaya": ['mw'],
    "pṛthvīdaṇḍapālatā": ['mw'],
    "pṛthvīdhara": ['mw'],
    "pṛthvīdānavidhi": ['mw'],
    "pṛthvīgarbha": ['mw'],
    "pṛthvīgṛha": ['mw'],
    "pṛthvīhara": ['mw'],
    "pṛthvīja": ['mw'],
    "pṛthvīkhāta": ['mw'],
    "pṛthvīkurabaka": ['mw'],
    "pṛthvīkā": ['ap90', 'mw'],
    "pṛthvīmalla": ['mw'],
    "pṛthvīmallarāja": ['mw'],
    "pṛthvīpati": ['mw'],
    "pṛthvīpatitva": ['mw'],
    "pṛthvīpremodaya": ['mw'],
    "pṛthvīpura": ['mw'],
    "pṛthvīpāla": ['mw'],
    "pṛthvīrāja": ['mw'],
    "pṛthvīrājavijaya": ['mw'],
    "pṛthvīrājya": ['mw'],
    "pṛthvīrūpa": ['mw'],
    "pṛthvīsārataila": ['mw'],
    "pṛthvītala": ['mw'],
    "pṛthvīvarāhasaṃvāda": ['mw'],
    "pṛthvīśa": ['mw'],
    "pṛthvīśatā": ['mw'],
    "pṛthā": ['ap90', 'ddsa', 'mw'],
    "pṛthābhū": ['cae', 'mw'],
    "pṛthāja": ['mw'],
    "pṛthājanman": ['cae', 'mw'],
    "pṛthāpati": ['mw'],
    "pṛthāraṇi": ['mw'],
    "pṛthāsuta": ['mw'],
    "pṛthāsūnu": ['cae', 'mw'],
    "pṛthātmaja": ['cae', 'mw'],
    "pṛthāśva": ['mw'],
    "pṛthī": ['gra', 'mw'],
    "pṛthūdaka": ['mw'],
    "pṛthūdakasvāmin": ['mw'],
    "pṛthūdara": ['ddsa', 'mw'],
    "pṛthūkṛ": ['mw'],
    "pṛthūpākhyāna": ['mw'],
    "pṛtsu": ['mw'],
    "pṛtsudha": ['mw'],
    "pṛtsuti": ['cae', 'gra', 'mw'],
    "pṛtsutur": ['gra', 'mw'],
    "pṛtsuṣu": ['mw'],
    "pṛtsuṣutur": ['cae'],
    "pṛñj": ['mw'],
    "pṛśana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pṛśanāyu": ['cae', 'gra', 'mw'],
    "pṛśanī": ['cae', 'ddsa', 'mw'],
    "pṛśati": ['bhs'],
    "pṛśni": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pṛśnibhadra": ['mw'],
    "pṛśnibāhu": ['mw'],
    "pṛśnidhara": ['mw'],
    "pṛśnigarbha": ['gra', 'mw'],
    "pṛśnigo": ['gra', 'mw'],
    "pṛśnigu": ['gra', 'mw'],
    "pṛśnihan": ['mw'],
    "pṛśnikā": ['ap90', 'mw'],
    "pṛśnimantha": ['mw'],
    "pṛśnimat": ['ddsa', 'mw'],
    "pṛśnimātṛ": ['cae', 'gra', 'mw'],
    "pṛśninipreṣita": ['gra', 'mw'],
    "pṛśniparṇikā": ['mw'],
    "pṛśniparṇī": ['mw'],
    "pṛśnisaktha": ['mw'],
    "pṛśnitva": ['mw'],
    "pṛśnivat": ['mw'],
    "pṛśnivāla": ['mw'],
    "pṛśniśapha": ['mw'],
    "pṛśniśṛṅga": ['mw'],
    "pṛśnyāhvayā": ['mw'],
    "pṛśnī": ['mw'],
    "pṛḍ": ['ap90', 'mw'],
    "pṛṃj": ['ap90'],
    "pṛṅga": ['bhs'],
    "pṛṇ": ['gra', 'mw'],
    "pṛṇa": ['gra'],
    "pṛṇant": ['cae'],
    "pṛṇākā": ['mw'],
    "pṛṣ": ['ap90', 'gra', 'mw'],
    "pṛṣa": ['mw'],
    "pṛṣabhāṣā": ['ap90', 'mw'],
    "pṛṣad": ['mw'],
    "pṛṣadaśva": ['cae', 'ddsa', 'gra', 'mw'],
    "pṛṣadaṃśa": ['mw'],
    "pṛṣaddhra": ['mw'],
    "pṛṣadhra": ['gra', 'mw'],
    "pṛṣadvala": ['mw'],
    "pṛṣadvant": ['cae'],
    "pṛṣadvarā": ['mw'],
    "pṛṣadvat": ['gra', 'mw'],
    "pṛṣadvatsa": ['mw'],
    "pṛṣadvāṇa": ['gra', 'mw'],
    "pṛṣadyoni": ['gra', 'mw'],
    "pṛṣadājia": ['gra'],
    "pṛṣadājya": ['gra', 'mw'],
    "pṛṣadājyadhānī": ['mw'],
    "pṛṣadājyapraṇutta": ['mw'],
    "pṛṣant": ['cae'],
    "pṛṣanti": ['mw'],
    "pṛṣat": ['ap90', 'ddsa', 'gra', 'mw'],
    "pṛṣata": ['ap90', 'cae', 'ddsa', 'mw'],
    "pṛṣatka": ['cae', 'ddsa', 'mw'],
    "pṛṣatkaḥ": ['ap90'],
    "pṛṣattva": ['mw'],
    "pṛṣattā": ['mw'],
    "pṛṣatāśva": ['mw'],
    "pṛṣatī": ['mw'],
    "pṛṣaṃtiḥ": ['ap90'],
    "pṛṣita": ['cae', 'mw'],
    "pṛṣodara": ['ddsa', 'mw'],
    "pṛṣodaraḥ": ['ap90'],
    "pṛṣodvāni": ['mw'],
    "pṛṣodyāna": ['mw'],
    "pṛṣokta": ['mw'],
    "pṛṣotthāna": ['mw'],
    "pṛṣva": ['cae', 'mw'],
    "pṛṣākarā": ['ap90', 'mw'],
    "pṛṣāta": ['mw'],
    "pṛṣātaka": ['ddsa', 'mw'],
    "pṛṣātakaṃ": ['ap90'],
    "pṛṣātakī": ['mw'],
    "pṛṣṇi": ['ap90', 'mw'],
    "pṛṣṇiparṇī": ['mw'],
    "pṛṣṇiḥ": ['ap90'],
    "pṛṣṭa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pṛṣṭabandhu": ['gra', 'mw'],
    "pṛṣṭahāyana": ['mw'],
    "pṛṣṭahāyanaḥ": ['ap90'],
    "pṛṣṭaparṇī": ['mw'],
    "pṛṣṭaprativacana": ['mw'],
    "pṛṣṭavācikā": ['bhs'],
    "pṛṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "pṛṣṭhabhaṅga": ['mw'],
    "pṛṣṭhabhāga": ['cae', 'mw'],
    "pṛṣṭhabhūmi": ['mw'],
    "pṛṣṭhacakṣus": ['mw'],
    "pṛṣṭhadeśa": ['ddsa', 'mw'],
    "pṛṣṭhadeśe": ['mw'],
    "pṛṣṭhadhāraka": ['mw'],
    "pṛṣṭhadṛṣṭi": ['mw'],
    "pṛṣṭhaga": ['cae', 'mw'],
    "pṛṣṭhaghna": ['mw'],
    "pṛṣṭhagopa": ['mw'],
    "pṛṣṭhagranthi": ['mw'],
    "pṛṣṭhagālana": ['mw'],
    "pṛṣṭhagāmin": ['mw'],
    "pṛṣṭhahoma": ['mw'],
    "pṛṣṭhaja": ['mw'],
    "pṛṣṭhajāha": ['mw'],
    "pṛṣṭhaka": ['ddsa', 'mw'],
    "pṛṣṭhakaṃ": ['ap90'],
    "pṛṣṭhakaṇṭaka": ['bhs'],
    "pṛṣṭhakekṛ": ['mw'],
    "pṛṣṭhalagna": ['mw'],
    "pṛṣṭhamadhya": ['mw'],
    "pṛṣṭhamāṃsa": ['cae', 'mw'],
    "pṛṣṭhamāṃsāda": ['mw'],
    "pṛṣṭhamāṃsādana": ['mw'],
    "pṛṣṭhaphala": ['mw'],
    "pṛṣṭhapātin": ['mw'],
    "pṛṣṭhapīṭhī": ['mw'],
    "pṛṣṭharakṣa": ['mw'],
    "pṛṣṭharakṣaṇa": ['mw'],
    "pṛṣṭhastotra": ['mw'],
    "pṛṣṭhatalpana": ['mw'],
    "pṛṣṭhatap": ['mw'],
    "pṛṣṭhatas": ['ap90', 'cae', 'ddsa', 'mw'],
    "pṛṣṭhatobhāvam": ['mw'],
    "pṛṣṭhatomukha": ['bhs', 'mw'],
    "pṛṣṭhatāpa": ['mw'],
    "pṛṣṭhavah": ['mw'],
    "pṛṣṭhavaṃśa": ['mw'],
    "pṛṣṭhavāh": ['mw'],
    "pṛṣṭhavāha": ['mw'],
    "pṛṣṭhavāhya": ['mw'],
    "pṛṣṭhavāstu": ['cae', 'mw'],
    "pṛṣṭhayajvan": ['cae', 'gra', 'mw'],
    "pṛṣṭhayāna": ['mw'],
    "pṛṣṭhayāyin": ['mw'],
    "pṛṣṭhaśamanīya": ['mw'],
    "pṛṣṭhaśaya": ['mw'],
    "pṛṣṭhaśikhara": ['mw'],
    "pṛṣṭhaśveta": ['mw'],
    "pṛṣṭhaśṛṅga": ['mw'],
    "pṛṣṭhaśṛṅgin": ['mw'],
    "pṛṣṭhaṃ": ['ap90'],
    "pṛṣṭhe": ['mw'],
    "pṛṣṭhemukha": ['mw'],
    "pṛṣṭhi": ['bhs'],
    "pṛṣṭhia": ['gra'],
    "pṛṣṭhima": ['bhs'],
    "pṛṣṭhodaya": ['mw'],
    "pṛṣṭhopatāpa": ['mw'],
    "pṛṣṭhya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "pṛṣṭhyastoma": ['mw'],
    "pṛṣṭhyā": ['mw'],
    "pṛṣṭhyāvalamba": ['mw'],
    "pṛṣṭhākṣepa": ['mw'],
    "pṛṣṭhānuga": ['cae', 'ddsa', 'mw'],
    "pṛṣṭhānugāmin": ['cae', 'mw'],
    "pṛṣṭhānupṛṣṭhaka": ['mw'],
    "pṛṣṭhānupṛṣṭhikā": ['cae'],
    "pṛṣṭhāsthi": ['mw'],
    "pṛṣṭhāvaguṇṭhanapaṭa": ['mw'],
    "pṛṣṭhāṣṭhīla": ['mw'],
    "pṛṣṭhībhavati": ['bhs'],
    "pṛṣṭhībhū": ['mw'],
    "pṛṣṭhīkaṇṭaka": ['bhs'],
    "pṛṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "pṛṣṭisācaya": ['mw'],
    "pṛṣṭitas": ['mw'],
    "pṛṣṭivah": ['mw'],
    "pṛṣṭivāh": ['mw'],
    "pṛṣṭiāmaya": ['gra'],
    "pṛṣṭiāmayin": ['gra'],
    "pṛṣṭiḥ": ['ap90'],
    "pṛṣṭvā": ['mw'],
    "pṛṣṭyā": ['cae', 'mw'],
    "pṛṣṭyāmaya": ['mw'],
    "pṛṣṭyāmayin": ['gra', 'mw'],
    "pṛṣṭābhidhāyin": ['mw'],
    "pṛṣṭī": ['cae'],
    "pṝ": ['ap90', 'mw'],
    "ra": ['cae', 'ddsa', 'mw'],
    "rabdha": ['mw'],
    "rabdhā": ['cae', 'mw'],
    "rabdhṛ": ['mw'],
    "rabh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rabha": ['cae', 'mw'],
    "rabhas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rabhasa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rabhasakośa": ['mw'],
    "rabhasanandin": ['mw'],
    "rabhasapāla": ['mw'],
    "rabhasena": ['mw'],
    "rabhasvant": ['cae'],
    "rabhasvat": ['ddsa', 'gra', 'mw'],
    "rabhasā": ['mw'],
    "rabhasāna": ['gra', 'mw'],
    "rabhasāt": ['mw'],
    "rabhi": ['cae', 'gra', 'mw'],
    "rabhin": ['gra'],
    "rabhis": ['gra'],
    "rabhiṣṭha": ['cae', 'gra', 'mw'],
    "rabhodā": ['cae', 'gra', 'mw'],
    "rabhyas": ['cae', 'gra', 'mw'],
    "rabhīyas": ['mw'],
    "rabhīyaṃs": ['cae'],
    "rabhū": ['mw'],
    "rac": ['ap90', 'cae', 'ddsa', 'mw'],
    "racana": ['cae', 'ddsa', 'mw'],
    "racanaṃ": ['ap90'],
    "racanā": ['cped', 'mw'],
    "racanārciparvatapradīpa": ['bhs'],
    "racayati": ['cped'],
    "racayi": ['cped'],
    "racayitṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "raccha": ['bhs'],
    "racchā": ['cped'],
    "racita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "racitadhī": ['mw'],
    "racitamaṅgala": ['mw'],
    "racitamāla": ['bhs'],
    "racitapaṅkti": ['mw'],
    "racitapūrva": ['mw'],
    "racitasvāgata": ['mw'],
    "racitatva": ['mw'],
    "racitaśikhara": ['mw'],
    "racitotsava": ['mw'],
    "racitvā": ['cped'],
    "racitānati": ['mw'],
    "racitārtha": ['cae', 'mw'],
    "racitātithya": ['mw'],
    "rad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rada": ['cae', 'cped', 'ddsa', 'mw'],
    "radacchada": ['cae', 'mw'],
    "radakhaṇḍana": ['mw'],
    "radana": ['cae', 'mw'],
    "radanacchada": ['cae', 'mw'],
    "radanikā": ['cae', 'mw'],
    "radanin": ['ap90', 'mw'],
    "radaḥ": ['ap90'],
    "radda": ['mw'],
    "raddha": ['ap90', 'mw'],
    "raddhṛ": ['ap90', 'mw'],
    "radh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "radhita": ['mw'],
    "radhitṛ": ['mw'],
    "radhra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "radhracoda": ['cae', 'gra', 'mw'],
    "radhracodana": ['cae', 'gra', 'mw'],
    "radhratur": ['cae', 'gra', 'mw'],
    "radin": ['mw'],
    "radāvali": ['mw'],
    "radāvalidvandva": ['mw'],
    "radāvasu": ['cae', 'gra', 'mw'],
    "radāyudha": ['mw'],
    "radāṅkura": ['ddsa', 'mw'],
    "rag": ['ap90', 'mw'],
    "ragh": ['mw'],
    "raghu": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "raghudeva": ['mw'],
    "raghudevī": ['mw'],
    "raghudru": ['gra', 'mw'],
    "raghuja": ['gra', 'mw'],
    "raghukulottaṃsa": ['mw'],
    "raghukāra": ['mw'],
    "raghulāladāsa": ['mw'],
    "raghumanyu": ['cae', 'gra', 'mw'],
    "raghumaṇi": ['mw'],
    "raghumukha": ['mw'],
    "raghumāhātmya": ['mw'],
    "raghunandana": ['cae', 'mw'],
    "raghunandanakośa": ['mw'],
    "raghunātha": ['cae', 'mw'],
    "raghunāthabhaṭṭagosvāmiguṇaleśāṣṭaka": ['mw'],
    "raghunāthabhūpālīya": ['mw'],
    "raghunāthacarita": ['mw'],
    "raghunāthanāthābhyudaya": ['mw'],
    "raghunāthanāthīya": ['mw'],
    "raghunāthapañcaratna": ['mw'],
    "raghunāthavilāsa": ['mw'],
    "raghunāthavratakathā": ['mw'],
    "raghunāyaka": ['mw'],
    "raghupati": ['mw'],
    "raghupatirahasyadīpikā": ['mw'],
    "raghupatmajaṃhas": ['gra', 'mw'],
    "raghupatman": ['gra'],
    "raghupatvan": ['cae', 'gra', 'mw'],
    "raghupratinidhi": ['mw'],
    "raghupravara": ['mw'],
    "raghurājasiṃha": ['mw'],
    "raghurāma": ['mw'],
    "raghusuta": ['mw'],
    "raghusvāmin": ['mw'],
    "raghusyada": ['mw'],
    "raghutanaya": ['mw'],
    "raghutilaka": ['mw'],
    "raghuvara": ['cae', 'mw'],
    "raghuvarasaṃhitā": ['mw'],
    "raghuvaraśaraṇa": ['mw'],
    "raghuvartani": ['cae', 'gra', 'mw'],
    "raghuvarya": ['mw'],
    "raghuvaryatīrtha": ['mw'],
    "raghuvaṃśa": ['cae', 'mw'],
    "raghuvaṃśasaṃjīvanī": ['mw'],
    "raghuvaṃśasaṃkṣepa": ['mw'],
    "raghuvaṃśasubodhinī": ['mw'],
    "raghuvaṃśatilaka": ['mw'],
    "raghuvilāpanāṭaka": ['mw'],
    "raghuvīra": ['cae', 'mw'],
    "raghuvīracarita": ['mw'],
    "raghuvīragadya": ['mw'],
    "raghuvīraviṃśati": ['mw'],
    "raghuy": ['gra'],
    "raghuyant": ['cae'],
    "raghuyat": ['mw'],
    "raghuyā": ['cae', 'gra', 'mw'],
    "raghuyāman": ['cae', 'gra', 'mw'],
    "raghuṣyad": ['cae', 'gra', 'mw'],
    "raghuṭippaṇī": ['mw'],
    "raghīyas": ['ddsa', 'mw'],
    "raghīyaṃs": ['cae'],
    "raghūdvaha": ['mw'],
    "raghūttama": ['mw'],
    "raghūyat": ['mw'],
    "rah": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "raha": ['cae', 'mw'],
    "rahada": ['cped'],
    "raharūḍhabhāva": ['mw'],
    "rahas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rahasa": ['mw'],
    "rahasanandin": ['mw'],
    "rahasi": ['mw'],
    "rahaskara": ['mw'],
    "rahaskāma": ['mw'],
    "rahaskāmatā": ['mw'],
    "rahassa": ['cped'],
    "rahassu": ['mw'],
    "rahastas": ['mw'],
    "rahastha": ['mw'],
    "rahasya": ['ap90', 'cae', 'ddsa', 'mw'],
    "rahasyabheda": ['cae', 'mw'],
    "rahasyabhedana": ['mw'],
    "rahasyabrāhmaṇa": ['mw'],
    "rahasyachalākṣara": ['mw'],
    "rahasyadhārin": ['cae', 'mw'],
    "rahasyadhāriṇī": ['mw'],
    "rahasyagāna": ['mw'],
    "rahasyam": ['mw'],
    "rahasyamañjarī": ['mw'],
    "rahasyamātṛkā": ['mw'],
    "rahasyanavanīta": ['mw'],
    "rahasyanikṣepa": ['mw'],
    "rahasyanuśāsikā": ['bhs'],
    "rahasyapadavī": ['mw'],
    "rahasyapuraścaraṇavidhi": ['mw'],
    "rahasyarakṣā": ['mw'],
    "rahasyasaṃdeśavivaraṇa": ['mw'],
    "rahasyasaṃrakṣaṇa": ['mw'],
    "rahasyasaṃrakṣaṇā": ['cae'],
    "rahasyasāra": ['mw'],
    "rahasyatraya": ['mw'],
    "rahasyatrayacudāmaṇi": ['mw'],
    "rahasyatrayaculuka": ['mw'],
    "rahasyatrayakārikāvyākhyā": ['mw'],
    "rahasyatrayamīmāṃsā": ['mw'],
    "rahasyatrayasaṃgraha": ['mw'],
    "rahasyatrayasāra": ['mw'],
    "rahasyatrayasārasaṃgraha": ['mw'],
    "rahasyatrayavidhi": ['mw'],
    "rahasyatrayavyākhyārtha": ['mw'],
    "rahasyatrayārtha": ['mw'],
    "rahasyavibheda": ['mw'],
    "rahasyavid": ['mw'],
    "rahasyavrata": ['mw'],
    "rahasyaṣoḍaśīṭīkā": ['mw'],
    "rahasyeṣṭi": ['mw'],
    "rahasyeṣṭipaddhati": ['mw'],
    "rahasyocchiṣṭasumukhīkalpa": ['mw'],
    "rahasyopaniṣad": ['mw'],
    "rahasyu": ['mw'],
    "rahasyā": ['mw'],
    "rahasyākhyāyin": ['cae', 'mw'],
    "rahasyālocana": ['mw'],
    "rahasyālocanā": ['mw'],
    "rahasyālocanāpara": ['mw'],
    "rahasyātirahasyapuraścaraṇa": ['mw'],
    "rahasānandin": ['mw'],
    "rahasū": ['cae', 'gra', 'mw'],
    "rahaḥ": ['mw'],
    "rahaḥsakhī": ['mw'],
    "rahaḥstha": ['cae', 'ddsa', 'mw'],
    "rahaḥśuci": ['mw'],
    "rahaḥśīla": ['ddsa', 'mw'],
    "rahaṇa": ['cae', 'ddsa', 'mw'],
    "rahaṇaṃ": ['ap90'],
    "rahita": ['ap90', 'cae', 'cped', 'mw'],
    "rahitaratna": ['mw'],
    "rahitaratnacaya": ['mw'],
    "rahitatva": ['ddsa', 'mw'],
    "rahite": ['mw'],
    "rahiteṣu": ['mw'],
    "rahitāsura": ['mw'],
    "raho": ['cped', 'mw'],
    "rahogata": ['cae', 'cped', 'ddsa', 'mw'],
    "rahomānin": ['mw'],
    "rahonuśāsaka": ['bhs'],
    "rahurāja": ['mw'],
    "rahābhāva": ['cped'],
    "rahāya": ['mw'],
    "rahāyati": ['bhs'],
    "rahāṭa": ['mw'],
    "rahāṭaḥ": ['ap90'],
    "rahī": ['mw'],
    "rahībhū": ['mw'],
    "rahībhūta": ['mw'],
    "rahīkṛ": ['mw'],
    "rahūgaṇa": ['cae', 'gra', 'mw'],
    "rai": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "raibha": ['gra', 'mw'],
    "raibhya": ['cae', 'mw'],
    "raibhī": ['ddsa', 'mw'],
    "raicīkya": ['mw'],
    "raikha": ['mw'],
    "raikva": ['cae', 'mw'],
    "raikvaparṇa": ['mw'],
    "raikṛ": ['mw'],
    "rairupyaka": ['mw'],
    "raitasa": ['cae', 'mw'],
    "raitika": ['ap90', 'cae', 'ddsa', 'mw'],
    "raitya": ['cae', 'ddsa', 'mw'],
    "raiva": ['mw'],
    "raivata": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "raivatagarbha": ['mw'],
    "raivatagiri": ['mw'],
    "raivataka": ['cae', 'mw'],
    "raivatakaḥ": ['ap90'],
    "raivatamadanikā": ['mw'],
    "raivatapṛṣṭha": ['mw'],
    "raivatastotra": ['mw'],
    "raivatika": ['mw'],
    "raivatikīya": ['mw'],
    "raivatya": ['cae', 'gra', 'mw'],
    "raivatācala": ['mw'],
    "raivatādri": ['mw'],
    "raivatī": ['mw'],
    "raiya": ['mw'],
    "raiṇava": ['mw'],
    "raiṇukeya": ['mw'],
    "raiṣṇāyana": ['mw'],
    "raj": ['cae', 'ddsa', 'gra', 'mw'],
    "raja": ['bhs', 'cae', 'ddsa', 'mw'],
    "rajabha": ['bhs'],
    "rajaka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "rajakaratha": ['bhs'],
    "rajakasarasvatī": ['mw'],
    "rajakaḥ": ['ap90'],
    "rajakkha": ['cped'],
    "rajakkhandha": ['cped'],
    "rajakā": ['ap90'],
    "rajakī": ['mw'],
    "rajana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "rajanakamma": ['cped'],
    "rajanaḥ": ['ap90'],
    "rajani": ['cae', 'ddsa', 'mw'],
    "rajanicara": ['cae', 'mw'],
    "rajanikara": ['cae', 'mw'],
    "rajanikṛt": ['mw'],
    "rajanimmanya": ['mw'],
    "rajanipuraṃdhrī": ['mw'],
    "rajanirākṣasī": ['cae', 'mw'],
    "rajaniḥ": ['ap90'],
    "rajaniṃmanya": ['ap90'],
    "rajanī": ['cped', 'ddsa', 'gra', 'mw'],
    "rajanībhujaṃga": ['mw'],
    "rajanīcara": ['cae', 'mw'],
    "rajanīcaranātha": ['mw'],
    "rajanīdvaya": ['mw'],
    "rajanīdvaṃdva": ['mw'],
    "rajanīgandha": ['mw'],
    "rajanīhāsā": ['mw'],
    "rajanījala": ['mw'],
    "rajanīkara": ['mw'],
    "rajanīkaranātha": ['mw'],
    "rajanīmukha": ['cae', 'mw'],
    "rajanīpati": ['cae', 'mw'],
    "rajanīramaṇa": ['cae', 'mw'],
    "rajanīya": ['bhs', 'cped', 'mw'],
    "rajanīśa": ['cae', 'mw'],
    "rajas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rajasa": ['cae', 'mw'],
    "rajasaya": ['mw'],
    "rajaska": ['cae', 'mw'],
    "rajastamaska": ['mw'],
    "rajastamomaya": ['mw'],
    "rajastas": ['mw'],
    "rajastoka": ['mw'],
    "rajastur": ['gra', 'mw'],
    "rajasvala": ['ap90', 'cae', 'ddsa', 'mw'],
    "rajasvalā": ['mw'],
    "rajasvara": ['bhs'],
    "rajasvin": ['mw'],
    "rajasya": ['cae', 'mw'],
    "rajasyati": ['ap90'],
    "rajasānu": ['mw'],
    "rajasānuḥ": ['ap90'],
    "rajata": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rajatabhājana": ['cae', 'mw'],
    "rajatadaṃṣṭra": ['mw'],
    "rajatadyuti": ['mw'],
    "rajatadānaprayoga": ['mw'],
    "rajatakumbha": ['mw'],
    "rajatakūṭa": ['mw'],
    "rajatamaya": ['cae', 'mw'],
    "rajatanābha": ['mw'],
    "rajatanābhi": ['mw'],
    "rajatapadmadāna": ['mw'],
    "rajataparvata": ['mw'],
    "rajatapaṭṭa": ['cped'],
    "rajataprastha": ['mw'],
    "rajatapātra": ['cae', 'mw'],
    "rajatavāha": ['mw'],
    "rajati": ['cped'],
    "rajatācala": ['mw'],
    "rajatādri": ['mw'],
    "rajatākara": ['mw'],
    "rajatānvita": ['cae', 'mw'],
    "rajaudvāsā": ['mw'],
    "rajayitrī": ['cae', 'mw'],
    "rajaḥ": ['ap90', 'mw'],
    "rajaḥkaṇa": ['cae', 'ddsa', 'mw'],
    "rajaḥpaṭala": ['mw'],
    "rajaḥpluta": ['mw'],
    "rajaḥputra": ['mw'],
    "rajaḥsnāta": ['mw'],
    "rajaḥspṛś": ['ddsa', 'mw'],
    "rajaḥsuvāsinī": ['mw'],
    "rajaḥśaya": ['cae', 'mw'],
    "rajaḥśuddhi": ['mw'],
    "rajeṣita": ['gra', 'mw'],
    "raji": ['cae', 'cped', 'gra', 'mw'],
    "rajikā": ['ddsa', 'mw'],
    "rajita": ['mw'],
    "rajitabba": ['cped'],
    "rajitvā": ['cped'],
    "rajiṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "rajja": ['cped'],
    "rajjana": ['cped'],
    "rajjanta": ['cped'],
    "rajjappadesa": ['cped'],
    "rajjasiri": ['cped'],
    "rajjasīmā": ['cped'],
    "rajjati": ['cped'],
    "rajjavya": ['cae', 'mw'],
    "rajji": ['cped'],
    "rajjitvā": ['cped'],
    "rajju": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rajjubandha": ['cae', 'mw'],
    "rajjubhāra": ['mw'],
    "rajjudhāna": ['mw'],
    "rajjudāla": ['cae', 'ddsa', 'mw'],
    "rajjudālaka": ['cae', 'mw'],
    "rajjugāhaka": ['cped'],
    "rajjuka": ['cae', 'mw'],
    "rajjukaṇṭha": ['mw'],
    "rajjukriyā": ['mw'],
    "rajjulamba": ['cae', 'mw'],
    "rajjumaya": ['cae', 'mw'],
    "rajjumātratva": ['mw'],
    "rajjupeḍā": ['cae', 'mw'],
    "rajjupīṭhikā": ['cae', 'mw'],
    "rajjusarja": ['cae', 'mw'],
    "rajjusaṃdāna": ['mw'],
    "rajjuvartana": ['mw'],
    "rajjuvāla": ['cae', 'mw'],
    "rajjuyantra": ['mw'],
    "rajjuśārada": ['mw'],
    "rajjuḥ": ['ap90'],
    "rajjvambara": ['mw'],
    "rajjvavalambin": ['mw'],
    "rajjūddhṛta": ['mw'],
    "rajjūkṛ": ['ap90', 'mw'],
    "rajjūta": ['mw'],
    "rajo": ['cped', 'mw'],
    "rajobala": ['mw'],
    "rajobandha": ['mw'],
    "rajodarśana": ['mw'],
    "rajodarśanaśānti": ['mw'],
    "rajodhika": ['mw'],
    "rajograhi": ['mw'],
    "rajoguṇamaya": ['mw'],
    "rajogātra": ['mw'],
    "rajohara": ['mw'],
    "rajoharaṇa": ['bhs', 'cped', 'mw'],
    "rajoharaṇadhārin": ['mw'],
    "rajojala": ['bhs'],
    "rajojalla": ['cped'],
    "rajojuṣ": ['ddsa', 'mw'],
    "rajomala": ['bhs'],
    "rajomegha": ['cae', 'mw'],
    "rajonimīlita": ['mw'],
    "rajonmiśra": ['mw'],
    "rajopaharaṇa": ['bhs'],
    "rajopama": ['mw'],
    "rajorasa": ['mw'],
    "rajosūka": ['cped'],
    "rajotsavamāhātmya": ['mw'],
    "rajovala": ['mw'],
    "rajovimalatejaḥśrī": ['bhs'],
    "rajoviriktamanas": ['mw'],
    "rajoviśāla": ['mw'],
    "rajyanā": ['bhs'],
    "rajāśaya": ['mw'],
    "rajīkṛ": ['mw'],
    "rajīyas": ['mw'],
    "rak": ['ap90', 'mw'],
    "raka": ['mw'],
    "rakasā": ['mw'],
    "rakaḥ": ['ap90'],
    "rakh": ['ap90', 'mw'],
    "rakka": ['ddsa', 'mw'],
    "rakkajayā": ['mw'],
    "rakkhaka": ['cped'],
    "rakkhana": ['cped'],
    "rakkhanaka": ['cped'],
    "rakkhanta": ['cped'],
    "rakkhasa": ['cped'],
    "rakkhati": ['cped'],
    "rakkhi": ['cped'],
    "rakkhita": ['cped'],
    "rakkhitabba": ['cped'],
    "rakkhitvā": ['cped'],
    "rakkhiya": ['cped'],
    "rakkhā": ['cped'],
    "rakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "raktabhava": ['mw'],
    "raktabhāva": ['cae', 'mw'],
    "raktabindu": ['mw'],
    "raktabīja": ['mw'],
    "raktabījakā": ['mw'],
    "raktacandana": ['cae', 'mw'],
    "raktacandanagandha": ['bhs'],
    "raktacchada": ['cae', 'mw'],
    "raktacchadatva": ['mw'],
    "raktacchardi": ['mw'],
    "raktacillikā": ['mw'],
    "raktacitraka": ['mw'],
    "raktacūrṇa": ['mw'],
    "raktacūrṇaka": ['mw'],
    "raktadalā": ['mw'],
    "raktadant": ['cae', 'mw'],
    "raktadantikā": ['mw'],
    "raktadantī": ['mw'],
    "raktadat": ['mw'],
    "raktadhātu": ['mw'],
    "raktadruma": ['mw'],
    "raktadūṣaṇa": ['mw'],
    "raktadṛś": ['mw'],
    "raktadṛṣṭi": ['mw'],
    "raktagairika": ['mw'],
    "raktagandhaka": ['mw'],
    "raktagarbhā": ['mw'],
    "raktagaura": ['mw'],
    "raktaghna": ['mw'],
    "raktaghnī": ['mw'],
    "raktagraha": ['mw'],
    "raktagranthi": ['mw'],
    "raktagrīva": ['mw'],
    "raktagulma": ['mw'],
    "raktagulminī": ['mw'],
    "raktahaṃsa": ['mw'],
    "raktahaṃsā": ['mw'],
    "raktahīna": ['mw'],
    "raktairaṇḍa": ['mw'],
    "raktairvāru": ['mw'],
    "raktaja": ['mw'],
    "raktajantuka": ['mw'],
    "raktajihva": ['mw'],
    "raktaka": ['ap90', 'cae', 'mw'],
    "raktakadalī": ['mw'],
    "raktakadamba": ['cae', 'mw'],
    "raktakairava": ['mw'],
    "raktakallola": ['mw'],
    "raktakamala": ['mw'],
    "raktakamalinī": ['mw'],
    "raktakambala": ['mw'],
    "raktakanda": ['mw'],
    "raktakandala": ['mw'],
    "raktakaravīra": ['mw'],
    "raktakaravīraka": ['mw'],
    "raktakaṅgu": ['mw'],
    "raktakaṇṭa": ['mw'],
    "raktakaṇṭha": ['cae', 'mw'],
    "raktakaṇṭhin": ['cae', 'mw'],
    "raktakesara": ['mw'],
    "raktakhadira": ['mw'],
    "raktakhāḍava": ['mw'],
    "raktakokanada": ['mw'],
    "raktakośātakī": ['mw'],
    "raktakumuda": ['mw'],
    "raktakuṇḍala": ['mw'],
    "raktakāla": ['mw'],
    "raktakāñcana": ['mw'],
    "raktakāṇḍā": ['mw'],
    "raktakāṣṭha": ['mw'],
    "raktakṛmijā": ['mw'],
    "raktakṛṣṇa": ['mw'],
    "raktalaśuna": ['mw'],
    "raktalocana": ['mw'],
    "raktalā": ['mw'],
    "raktamastaka": ['mw'],
    "raktamatsya": ['mw'],
    "raktamatta": ['mw'],
    "raktamaya": ['mw'],
    "raktamañjara": ['mw'],
    "raktamaṇḍala": ['mw'],
    "raktamaṇḍalatā": ['mw'],
    "raktamaṇḍalā": ['mw'],
    "raktameha": ['mw'],
    "raktamehin": ['mw'],
    "raktamokṣa": ['cae', 'mw'],
    "raktamokṣaṇa": ['mw'],
    "raktamukha": ['cae', 'mw'],
    "raktamādrī": ['mw'],
    "raktamāli": ['bhs'],
    "raktamūlaka": ['cae', 'mw'],
    "raktamūlā": ['mw'],
    "raktamūtratā": ['mw'],
    "raktanayana": ['mw'],
    "raktanetra": ['cae', 'mw'],
    "raktanetratva": ['mw'],
    "raktanetratā": ['mw'],
    "raktaniryāsaka": ['mw'],
    "raktanāla": ['mw'],
    "raktanāsika": ['mw'],
    "raktanāḍī": ['mw'],
    "raktanīla": ['mw'],
    "raktapa": ['mw'],
    "raktapadma": ['mw'],
    "raktapadī": ['mw'],
    "raktapaitta": ['mw'],
    "raktapaittika": ['mw'],
    "raktapakṣa": ['mw'],
    "raktapallava": ['mw'],
    "raktaparṇa": ['mw'],
    "raktapatana": ['mw'],
    "raktapattra": ['mw'],
    "raktapattrikā": ['mw'],
    "raktapattrā": ['mw'],
    "raktapattrāṅga": ['mw'],
    "raktapaṭa": ['mw'],
    "raktapaṭamaya": ['mw'],
    "raktapaṭavratavāhinī": ['mw'],
    "raktapaṭīkṛta": ['mw'],
    "raktaphala": ['mw'],
    "raktaphalā": ['mw'],
    "raktaphenaja": ['mw'],
    "raktapitta": ['mw'],
    "raktapittahā": ['mw'],
    "raktapittakara": ['mw'],
    "raktapittakāsa": ['mw'],
    "raktapittika": ['mw'],
    "raktapittin": ['mw'],
    "raktapiṇḍa": ['mw'],
    "raktapiṇḍaka": ['mw'],
    "raktapiṇḍālu": ['mw'],
    "raktapiṭikā": ['mw'],
    "raktapradara": ['mw'],
    "raktaprameha": ['mw'],
    "raktaprasava": ['mw'],
    "raktapravāha": ['mw'],
    "raktapucchaka": ['mw'],
    "raktapucchikā": ['mw'],
    "raktapunarnavā": ['mw'],
    "raktapuṣpa": ['cae', 'mw'],
    "raktapuṣpaka": ['mw'],
    "raktapuṣpikā": ['mw'],
    "raktapuṣpā": ['mw'],
    "raktapuṣpī": ['mw'],
    "raktapā": ['mw'],
    "raktapāda": ['cae', 'mw'],
    "raktapādī": ['mw'],
    "raktapākī": ['mw'],
    "raktapārada": ['mw'],
    "raktapāta": ['mw'],
    "raktapātā": ['mw'],
    "raktapāyin": ['mw'],
    "raktapāyinī": ['mw'],
    "raktapītāsitaśyeta": ['mw'],
    "raktapūraka": ['mw'],
    "raktapūrṇa": ['mw'],
    "raktapūrṇatva": ['mw'],
    "raktapūya": ['mw'],
    "raktaraivataka": ['mw'],
    "raktareṇu": ['mw'],
    "raktarāji": ['mw'],
    "raktarājī": ['mw'],
    "raktasahā": ['mw'],
    "raktasaroruha": ['mw'],
    "raktasarṣapa": ['mw'],
    "raktasaugandhika": ['mw'],
    "raktasaṃdaṃśikā": ['mw'],
    "raktasaṃdhyaka": ['mw'],
    "raktasaṃjña": ['mw'],
    "raktasaṃkoca": ['cae', 'mw'],
    "raktasaṃkocaka": ['mw'],
    "raktasraganulepin": ['mw'],
    "raktasrāva": ['mw'],
    "raktasāra": ['mw'],
    "raktasūryamaṇi": ['mw'],
    "raktasūryāya": ['mw'],
    "raktatara": ['mw'],
    "raktatejas": ['mw'],
    "raktatrivṛt": ['mw'],
    "raktatuṇḍa": ['mw'],
    "raktatuṇḍaka": ['mw'],
    "raktatva": ['mw'],
    "raktatvatā": ['mw'],
    "raktatā": ['cae', 'mw'],
    "raktatṛṇā": ['mw'],
    "raktavaraṭi": ['mw'],
    "raktavardhana": ['mw'],
    "raktavarga": ['mw'],
    "raktavartmaka": ['mw'],
    "raktavarṇa": ['cae', 'mw'],
    "raktavarṇaka": ['mw'],
    "raktavarṣābhū": ['mw'],
    "raktavasana": ['mw'],
    "raktavastrin": ['mw'],
    "raktavaṭī": ['mw'],
    "raktavidradhi": ['mw'],
    "raktavikāra": ['mw'],
    "raktavindu": ['mw'],
    "raktavirakta": ['mw'],
    "raktavāluka": ['mw'],
    "raktavārija": ['mw'],
    "raktavāsas": ['cae', 'mw'],
    "raktavāsin": ['cae', 'mw'],
    "raktavāta": ['mw'],
    "raktavīja": ['mw'],
    "raktavījakā": ['mw'],
    "raktavṛkṣa": ['mw'],
    "raktavṛntā": ['mw'],
    "raktayaṣṭi": ['mw'],
    "raktayaṣṭikā": ['mw'],
    "raktayāvanāla": ['mw'],
    "raktaśigru": ['mw'],
    "raktaśmaśru": ['mw'],
    "raktaśmaśruśiroruha": ['mw'],
    "raktaśukratā": ['mw'],
    "raktaśyāma": ['mw'],
    "raktaśāli": ['mw'],
    "raktaśāsana": ['mw'],
    "raktaśīrṣaka": ['mw'],
    "raktaśūla": ['mw'],
    "raktaśṛṅgaka": ['mw'],
    "raktaśṛṅgī": ['mw'],
    "raktaṣṭhīvanatā": ['mw'],
    "raktaṣṭhīvī": ['mw'],
    "raktekṣu": ['mw'],
    "rakti": ['ddsa', 'mw'],
    "raktikā": ['ap90', 'mw'],
    "raktiman": ['ap90', 'cae', 'ddsa', 'mw'],
    "raktimant": ['cae'],
    "raktimat": ['mw'],
    "raktiḥ": ['ap90'],
    "raktodara": ['mw'],
    "raktopala": ['mw'],
    "raktotkliṣṭa": ['mw'],
    "raktotpala": ['ddsa', 'mw'],
    "raktotpalābha": ['mw'],
    "raktā": ['mw'],
    "raktābha": ['cae', 'mw'],
    "raktābhiṣyanda": ['mw'],
    "raktādharā": ['mw'],
    "raktādhimantha": ['mw'],
    "raktādhāra": ['mw'],
    "raktākta": ['mw'],
    "raktākāra": ['mw'],
    "raktākṣa": ['bhs', 'cae', 'mw'],
    "raktākṣatā": ['mw'],
    "raktākṣi": ['mw'],
    "raktākṣin": ['mw'],
    "raktākṣī": ['mw'],
    "raktālu": ['mw'],
    "raktāluka": ['mw'],
    "raktāmbara": ['cae', 'mw'],
    "raktāmbaradhara": ['mw'],
    "raktāmbaratva": ['mw'],
    "raktāmbhoja": ['mw'],
    "raktāmbupūra": ['mw'],
    "raktāmburuha": ['mw'],
    "raktāmiṣāda": ['mw'],
    "raktāmra": ['mw'],
    "raktānta": ['mw'],
    "raktāpaha": ['mw'],
    "raktāpāmārga": ['mw'],
    "raktārbuda": ['mw'],
    "raktārman": ['mw'],
    "raktārti": ['mw'],
    "raktāruṇa": ['mw'],
    "raktārśas": ['mw'],
    "raktātisāra": ['mw'],
    "raktātīsāra": ['mw'],
    "raktāśaya": ['mw'],
    "raktāśoka": ['cae', 'mw'],
    "raktāṃśuka": ['ddsa', 'mw'],
    "raktāṅga": ['mw'],
    "raktāṅgā": ['mw'],
    "raktāṅgī": ['bhs', 'mw'],
    "raktāṅka": ['mw'],
    "raktīkṛ": ['ddsa'],
    "raktṛ": ['ap90', 'mw'],
    "rakāra": ['cae', 'ddsa', 'mw'],
    "rakārādirāmasahasranāman": ['mw'],
    "rakṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rakṣa": ['cae', 'ddsa', 'mw'],
    "rakṣabhagavatī": ['mw'],
    "rakṣaka": ['ap90', 'cae', 'mw'],
    "rakṣakāmbā": ['mw'],
    "rakṣapuruṣa": ['mw'],
    "rakṣapāla": ['cae', 'ddsa', 'mw'],
    "rakṣapālaka": ['cae', 'mw'],
    "rakṣas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rakṣaspāśa": ['mw'],
    "rakṣastua": ['gra'],
    "rakṣastva": ['cae', 'gra', 'mw'],
    "rakṣastvaṃ": ['ap90'],
    "rakṣasvin": ['cae', 'gra', 'mw'],
    "rakṣasya": ['cae', 'mw'],
    "rakṣaīśa": ['mw'],
    "rakṣaḥ": ['ap90', 'mw'],
    "rakṣaḥpati": ['mw'],
    "rakṣaḥpāla": ['mw'],
    "rakṣaḥsabha": ['mw'],
    "rakṣaṇa": ['cae', 'gra', 'mw'],
    "rakṣaṇaṃ": ['ap90'],
    "rakṣaṇopāya": ['mw'],
    "rakṣaṇā": ['mw'],
    "rakṣaṇāraka": ['mw'],
    "rakṣaṇārakaḥ": ['ap90'],
    "rakṣaṇārtham": ['mw'],
    "rakṣaṇī": ['mw'],
    "rakṣaṇīraka": ['mw'],
    "rakṣaṇīrakaḥ": ['ap90'],
    "rakṣaṇīya": ['cae', 'mw'],
    "rakṣi": ['cae', 'gra', 'mw'],
    "rakṣijana": ['mw'],
    "rakṣika": ['bhs', 'ddsa', 'mw'],
    "rakṣikapuruṣa": ['mw'],
    "rakṣikaḥ": ['ap90'],
    "rakṣikā": ['ap90', 'mw'],
    "rakṣin": ['cae', 'mw'],
    "rakṣita": ['bhs', 'mw'],
    "rakṣitaka": ['mw'],
    "rakṣitavat": ['mw'],
    "rakṣitavya": ['cae', 'mw'],
    "rakṣitikā": ['bhs', 'mw'],
    "rakṣitva": ['mw'],
    "rakṣitā": ['mw'],
    "rakṣitṛ": ['ap90', 'cae', 'gra', 'mw'],
    "rakṣivarga": ['mw'],
    "rakṣo": ['mw'],
    "rakṣobhāṣ": ['mw'],
    "rakṣodaivata": ['cae', 'mw'],
    "rakṣodevatya": ['cae', 'mw'],
    "rakṣodevatā": ['cae', 'mw'],
    "rakṣodhidevatā": ['mw'],
    "rakṣogaṇa": ['mw'],
    "rakṣogaṇabhojana": ['mw'],
    "rakṣoghna": ['cae', 'ddsa', 'mw'],
    "rakṣoghnamantra": ['mw'],
    "rakṣoghnasūkta": ['mw'],
    "rakṣoghnī": ['mw'],
    "rakṣohan": ['cae', 'gra', 'mw'],
    "rakṣohatya": ['cae', 'gra', 'mw'],
    "rakṣohaṇa": ['mw'],
    "rakṣohaṇaka": ['mw'],
    "rakṣojana": ['cae', 'mw'],
    "rakṣojananī": ['mw'],
    "rakṣomukha": ['mw'],
    "rakṣonātha": ['mw'],
    "rakṣorāja": ['mw'],
    "rakṣovidyā": ['mw'],
    "rakṣovikṣobhiṇī": ['mw'],
    "rakṣovāha": ['mw'],
    "rakṣoyuj": ['cae', 'gra', 'mw'],
    "rakṣya": ['cae', 'ddsa', 'mw'],
    "rakṣyatama": ['mw'],
    "rakṣā": ['ap90', 'bhs', 'ddsa', 'mw'],
    "rakṣābandhanavidhi": ['mw'],
    "rakṣābhyadhikṛta": ['mw'],
    "rakṣābhūṣaṇa": ['mw'],
    "rakṣādhikṛta": ['cae', 'mw'],
    "rakṣādhipati": ['cae', 'mw'],
    "rakṣāgaṇḍaka": ['cae', 'mw'],
    "rakṣāgṛha": ['mw'],
    "rakṣākaraṇḍaka": ['cae', 'mw'],
    "rakṣāmahauṣadhi": ['mw'],
    "rakṣāmalla": ['mw'],
    "rakṣāmantra": ['mw'],
    "rakṣāmaṅgala": ['cae', 'mw'],
    "rakṣāmaṇi": ['cae', 'mw'],
    "rakṣāparigha": ['mw'],
    "rakṣāpati": ['cae', 'mw'],
    "rakṣāpattra": ['mw'],
    "rakṣāpaṭṭolikā": ['mw'],
    "rakṣāpekṣaka": ['mw'],
    "rakṣāpradīpa": ['mw'],
    "rakṣāpratisara": ['cae'],
    "rakṣāpratiśara": ['mw'],
    "rakṣāpuruṣa": ['mw'],
    "rakṣāratna": ['mw'],
    "rakṣāratnapradīpa": ['mw'],
    "rakṣārtham": ['mw'],
    "rakṣāsarṣapa": ['mw'],
    "rakṣāsūtra": ['mw'],
    "rakṣāvant": ['cae'],
    "rakṣāvaraṇagupti": ['bhs'],
    "rakṣāvat": ['mw'],
    "rakṣī": ['mw'],
    "rakṣṇa": ['cae', 'mw'],
    "rakṣṇaḥ": ['ap90'],
    "ralamānātha": ['mw'],
    "ralarola": ['mw'],
    "rallaka": ['cae', 'ddsa', 'mw'],
    "rallakaḥ": ['ap90'],
    "ralā": ['cae', 'mw'],
    "ram": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rama": ['ap90', 'cae', 'ddsa', 'mw'],
    "ramaka": ['ap90', 'mw'],
    "ramakatva": ['mw'],
    "ramala": ['mw'],
    "ramalabhūṣaṇa": ['mw'],
    "ramalacintāmaṇi": ['mw'],
    "ramalagrantha": ['mw'],
    "ramalanavaratna": ['mw'],
    "ramalapaddhati": ['mw'],
    "ramalapraśna": ['mw'],
    "ramalapraśnatantra": ['mw'],
    "ramalarahasya": ['mw'],
    "ramalarahasyasārasaṃgraha": ['mw'],
    "ramalasiktā": ['mw'],
    "ramalasāra": ['mw'],
    "ramalatantra": ['mw'],
    "ramalatattvasāra": ['mw'],
    "ramalayantrikā": ['mw'],
    "ramalaśāstra": ['mw'],
    "ramalenduprakāśa": ['mw'],
    "ramalotkarṣa": ['mw'],
    "ramalābhidheya": ['mw'],
    "ramalāmṛta": ['mw'],
    "ramamāna": ['cped'],
    "ramana": ['cped'],
    "ramanta": ['cped'],
    "ramanī": ['cped'],
    "ramatha": ['mw'],
    "ramati": ['cae', 'cped', 'mw'],
    "ramatiḥ": ['ap90'],
    "ramayantikā": ['ddsa', 'mw'],
    "ramaṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "ramaṇaka": ['bhs', 'mw'],
    "ramaṇapati": ['mw'],
    "ramaṇavasati": ['mw'],
    "ramaṇya": ['mw'],
    "ramaṇā": ['ap90', 'mw'],
    "ramaṇāsakta": ['mw'],
    "ramaṇī": ['ap90', 'cped', 'mw'],
    "ramaṇīsakta": ['mw'],
    "ramaṇīya": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "ramaṇīyacaraṇa": ['mw'],
    "ramaṇīyajanman": ['cae', 'mw'],
    "ramaṇīyaka": ['bhs', 'mw'],
    "ramaṇīyarāghava": ['mw'],
    "ramaṇīyatama": ['mw'],
    "ramaṇīyatara": ['mw'],
    "ramaṇīyataratva": ['mw'],
    "ramaṇīyatva": ['mw'],
    "ramaṇīyatā": ['cae', 'mw'],
    "ramaṇīyatāraka": ['mw'],
    "ramaṇīyaḍāmara": ['mw'],
    "ramaṇīyaḍāmaratva": ['cae', 'mw'],
    "ramaṇīyā": ['mw'],
    "ramaṭa": ['cae'],
    "ramaṭaka": ['cae'],
    "ramaṭha": ['bhs', 'mw'],
    "ramaṭhadhvani": ['mw'],
    "ramaṭhaṃ": ['ap90'],
    "ramb": ['cae', 'ddsa', 'gra', 'mw'],
    "rambh": ['cae', 'ddsa', 'gra', 'mw'],
    "rambha": ['cae', 'ddsa', 'gra', 'mw'],
    "rambhaka": ['bhs'],
    "rambhaṇa": ['mw'],
    "rambhin": ['cae', 'gra', 'mw'],
    "rambhita": ['mw'],
    "rambhiṇī": ['mw'],
    "rambhoru": ['cae', 'mw'],
    "rambhā": ['cped', 'mw'],
    "rambhābhisāra": ['mw'],
    "rambhāmañjarī": ['mw'],
    "rambhāstambha": ['mw'],
    "rambhāstambhana": ['mw'],
    "rambhātṛtīyā": ['mw'],
    "rambhāvrata": ['mw'],
    "rameti": ['cped'],
    "rameśa": ['cae', 'mw'],
    "rameśvara": ['cae', 'mw'],
    "rami": ['cped'],
    "ramin": ['bhs'],
    "ramita": ['bhs', 'mw'],
    "ramitaṃgama": ['mw'],
    "ramituṁ": ['cped'],
    "ramitvā": ['cped'],
    "ramma": ['cped'],
    "rammaka": ['cped'],
    "ramph": ['mw'],
    "rampā": ['mw'],
    "ramra": ['mw'],
    "ramya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ramyadeva": ['mw'],
    "ramyadāruṇa": ['cae', 'mw'],
    "ramyagrāma": ['mw'],
    "ramyaka": ['mw'],
    "ramyapatha": ['mw'],
    "ramyaphala": ['mw'],
    "ramyapuṣpa": ['mw'],
    "ramyarūpa": ['mw'],
    "ramyasānu": ['mw'],
    "ramyatva": ['mw'],
    "ramyatā": ['cae', 'mw'],
    "ramyaśrī": ['mw'],
    "ramyā": ['mw'],
    "ramyākṣi": ['mw'],
    "ramyāntara": ['cae', 'mw'],
    "ramā": ['ap90', 'mw'],
    "ramādhava": ['mw'],
    "ramādhipa": ['mw'],
    "ramākānta": ['ddsa', 'mw'],
    "ramāna": ['cped'],
    "ramānātha": ['cae', 'mw'],
    "ramāpati": ['cae', 'mw'],
    "ramāpriya": ['mw'],
    "ramāveṣṭa": ['mw'],
    "ramāśaṃkara": ['mw'],
    "ramāśraya": ['mw'],
    "ran": ['cae', 'ddsa', 'gra', 'mw'],
    "randalā": ['mw'],
    "randh": ['ddsa', 'gra', 'mw'],
    "randha": ['cped', 'mw'],
    "randhagavesī": ['cped'],
    "randhaka": ['cped', 'mw'],
    "randhana": ['cae', 'cped', 'ddsa', 'mw'],
    "randhanāy": ['cae', 'gra'],
    "randhanāya": ['mw'],
    "randhas": ['mw'],
    "randhasa": ['mw'],
    "randhesi": ['cped'],
    "randheti": ['cped'],
    "randhetvā": ['cped'],
    "randhi": ['cae', 'gra', 'mw'],
    "randhin": ['mw'],
    "randhita": ['cped', 'mw'],
    "randhiṣa": ['mw'],
    "randhra": ['cae', 'ddsa', 'gra', 'mw'],
    "randhrababhru": ['mw'],
    "randhragupti": ['mw'],
    "randhraka": ['mw'],
    "randhrakaṇṭa": ['mw'],
    "randhraprahārin": ['mw'],
    "randhravaṃśa": ['mw'],
    "randhropanipātin": ['cae', 'mw'],
    "randhrāgata": ['mw'],
    "randhrānusārin": ['cae', 'mw'],
    "randhrānveṣaṇa": ['mw'],
    "randhrānveṣin": ['mw'],
    "randhrāpekṣin": ['mw'],
    "rantavya": ['mw'],
    "rantavyā": ['ddsa'],
    "ranti": ['cae', 'ddsa', 'gra', 'mw'],
    "rantia": ['gra'],
    "rantibhāra": ['mw'],
    "rantideva": ['cae', 'mw'],
    "rantināra": ['mw'],
    "rantos": ['mw'],
    "rantu": ['mw'],
    "rantumanas": ['mw'],
    "rantya": ['cae', 'mw'],
    "rantṛ": ['cae', 'mw'],
    "rap": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rapas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "raph": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "raphita": ['mw'],
    "rapratyāhāra": ['mw'],
    "rapratyāhārakhaṇḍana": ['mw'],
    "rapratyāhāramaṇḍana": ['mw'],
    "rapratyāhāravarṇana": ['mw'],
    "rapsu": ['mw'],
    "rapsud": ['gra'],
    "rapsudā": ['mw'],
    "rapś": ['cae', 'ddsa', 'gra', 'mw'],
    "rapśadūdhan": ['cae', 'ddsa', 'gra', 'mw'],
    "rarph": ['mw'],
    "rarāvan": ['gra', 'mw'],
    "rarāṇa": ['ddsa', 'mw'],
    "rarāṭa": ['cae', 'ddsa', 'mw'],
    "rarāṭaṃ": ['ap90'],
    "rarāṭya": ['ddsa', 'mw'],
    "rarāṭyā": ['mw'],
    "rarāṭī": ['mw'],
    "ras": ['ap90', 'cae', 'ddsa', 'mw'],
    "rasa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rasabandhana": ['mw'],
    "rasabhasman": ['mw'],
    "rasabhasmavidhi": ['mw'],
    "rasabhava": ['mw'],
    "rasabhaṅga": ['mw'],
    "rasabheda": ['mw'],
    "rasabhedin": ['mw'],
    "rasabhedīya": ['mw'],
    "rasabheṣajakalpa": ['mw'],
    "rasabhogamuktāvalī": ['mw'],
    "rasabhojana": ['mw'],
    "rasabhāvavid": ['mw'],
    "rasabodha": ['mw'],
    "rasacandra": ['mw'],
    "rasacandrikā": ['mw'],
    "rasacintāmaṇi": ['mw'],
    "rasacūḍāmaṇi": ['mw'],
    "rasada": ['mw'],
    "rasadarpaṇa": ['mw'],
    "rasadaṇḍa": ['mw'],
    "rasadhenu": ['mw'],
    "rasadhātu": ['mw'],
    "rasadrāvin": ['mw'],
    "rasadālikā": ['mw'],
    "rasadīpikā": ['mw'],
    "rasadīrghikā": ['mw'],
    "rasagandha": ['mw'],
    "rasagandhaka": ['mw'],
    "rasagarbha": ['mw'],
    "rasagaṅgādhara": ['mw'],
    "rasagaṅgādharīya": ['mw'],
    "rasagga": ['cped'],
    "rasaghana": ['mw'],
    "rasaghna": ['mw'],
    "rasagovinda": ['mw'],
    "rasagraha": ['mw'],
    "rasagrāhaka": ['mw'],
    "rasaguṇa": ['cae', 'mw'],
    "rasagāndhāra": ['mw'],
    "rasaharaṇa": ['mw'],
    "rasaharaṇī": ['bhs', 'cped'],
    "rasaheman": ['mw'],
    "rasahārin": ['mw'],
    "rasahṛdaya": ['mw'],
    "rasaja": ['cae', 'mw'],
    "rasajvara": ['mw'],
    "rasajyeṣṭha": ['mw'],
    "rasajña": ['cae', 'mw'],
    "rasajñatva": ['mw'],
    "rasajñatā": ['mw'],
    "rasajñāna": ['mw'],
    "rasajāta": ['mw'],
    "rasaka": ['bhs', 'cped', 'ddsa', 'mw'],
    "rasakadambakallolinī": ['mw'],
    "rasakalikā": ['mw'],
    "rasakalpalatā": ['mw'],
    "rasakalpanā": ['mw'],
    "rasakalpasārastava": ['mw'],
    "rasakalyāṇīvrata": ['mw'],
    "rasakarman": ['mw'],
    "rasakarpūra": ['mw'],
    "rasakaumudī": ['mw'],
    "rasakautuka": ['mw'],
    "rasakaṅkāli": ['mw'],
    "rasakaṣāya": ['mw'],
    "rasakesara": ['mw'],
    "rasaketu": ['mw'],
    "rasakomala": ['mw'],
    "rasakriyā": ['mw'],
    "rasakulyā": ['mw'],
    "rasaleha": ['mw'],
    "rasaloha": ['mw'],
    "rasamahārṇava": ['mw'],
    "rasamala": ['mw'],
    "rasamaya": ['ap90', 'cae', 'mw'],
    "rasamañjarī": ['mw'],
    "rasamañjarīguṇaleśasūcakāṣṭaka": ['mw'],
    "rasamañjarīparimala": ['mw'],
    "rasamañjarīprakāśa": ['mw'],
    "rasamañjarīsthūlatātparyārtha": ['mw'],
    "rasamaṇi": ['mw'],
    "rasamiśra": ['mw'],
    "rasamuktāvali": ['mw'],
    "rasamātra": ['mw'],
    "rasamātṛ": ['mw'],
    "rasamātṛkā": ['mw'],
    "rasamīmāṃsā": ['mw'],
    "rasamūlā": ['mw'],
    "rasana": ['cae', 'ddsa', 'mw'],
    "rasanaṃ": ['ap90'],
    "rasanendriya": ['ddsa', 'mw'],
    "rasanetrikā": ['mw'],
    "rasanetrī": ['mw'],
    "rasanibandha": ['mw'],
    "rasanirūpaṇa": ['mw'],
    "rasanivṛtti": ['mw'],
    "rasantama": ['mw'],
    "rasanā": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "rasanābha": ['mw'],
    "rasanālih": ['mw'],
    "rasanāmala": ['mw'],
    "rasanāmūla": ['mw'],
    "rasanānigraha": ['mw'],
    "rasanārada": ['mw'],
    "rasanātha": ['mw'],
    "rasanāyaka": ['ddsa', 'mw'],
    "rasanīya": ['cae', 'ddsa', 'mw'],
    "rasapaddhati": ['mw'],
    "rasapadmacandrikā": ['mw'],
    "rasapadmākara": ['mw'],
    "rasapadmākaracampū": ['mw'],
    "rasaparimala": ['mw'],
    "rasaparpaṭī": ['mw'],
    "rasapati": ['mw'],
    "rasapaṭhavī": ['cped'],
    "rasaphala": ['mw'],
    "rasaprabandha": ['cae', 'mw'],
    "rasapradīpa": ['mw'],
    "rasaprakāśa": ['mw'],
    "rasaprakāśasudhākara": ['mw'],
    "rasaprāśanī": ['mw'],
    "rasapuṣpa": ['mw'],
    "rasapācaka": ['ddsa', 'mw'],
    "rasapākaja": ['mw'],
    "rasapārijāta": ['mw'],
    "rasarahasya": ['mw'],
    "rasarasāgra": ['bhs'],
    "rasarasārṇava": ['mw'],
    "rasaratna": ['mw'],
    "rasaratnadīpikā": ['mw'],
    "rasaratnahāra": ['mw'],
    "rasaratnakośa": ['mw'],
    "rasaratnamaya": ['mw'],
    "rasaratnamālā": ['mw'],
    "rasaratnapradīpa": ['mw'],
    "rasaratnapradīpikā": ['mw'],
    "rasaratnasamuccaya": ['mw'],
    "rasaratnākara": ['mw'],
    "rasaratnāvalī": ['mw'],
    "rasarāja": ['mw'],
    "rasarājahaṃsa": ['mw'],
    "rasarājalakṣmī": ['mw'],
    "rasarājaśaṃkara": ['mw'],
    "rasarājaśiromaṇi": ['mw'],
    "rasasadana": ['mw'],
    "rasasamuccaya": ['mw'],
    "rasasarvasva": ['mw'],
    "rasasaṃbhava": ['bhs'],
    "rasasaṃgraha": ['mw'],
    "rasasaṃgrahasiddhānta": ['mw'],
    "rasasaṃgrāhī": ['mw'],
    "rasasaṃketa": ['mw'],
    "rasasaṃketakalikā": ['mw'],
    "rasasaṃskāra": ['mw'],
    "rasasetu": ['mw'],
    "rasasiddha": ['mw'],
    "rasasiddhi": ['mw'],
    "rasasiddhiprakāśa": ['mw'],
    "rasasiddhāntasaṃgraha": ['mw'],
    "rasasiddhāntasāgara": ['mw'],
    "rasasindhu": ['mw'],
    "rasasindūra": ['mw'],
    "rasasthāna": ['mw'],
    "rasasudhākara": ['mw'],
    "rasasudhāmbhodhi": ['mw'],
    "rasasudhānidhi": ['mw'],
    "rasasāgara": ['mw'],
    "rasasāra": ['mw'],
    "rasasārasamuccaya": ['mw'],
    "rasasārasaṃgraha": ['mw'],
    "rasasārāmṛta": ['mw'],
    "rasasūtrasthāna": ['mw'],
    "rasatama": ['mw'],
    "rasatanmātra": ['mw'],
    "rasataraṃgiṇī": ['mw'],
    "rasatas": ['mw'],
    "rasatattvasāra": ['mw'],
    "rasataṇhā": ['cped'],
    "rasatejas": ['mw'],
    "rasatva": ['mw'],
    "rasatvajātipramāṇa": ['mw'],
    "rasatā": ['mw'],
    "rasaudana": ['mw'],
    "rasavaha": ['mw'],
    "rasavaiśeṣika": ['mw'],
    "rasavant": ['cae'],
    "rasavara": ['mw'],
    "rasavarja": ['mw'],
    "rasavarjam": ['cae', 'mw'],
    "rasavat": ['ap90', 'gra', 'mw'],
    "rasavattara": ['mw'],
    "rasavattā": ['ap90', 'cae', 'mw'],
    "rasavatī": ['cped', 'mw'],
    "rasavatīśataka": ['mw'],
    "rasavid": ['cae', 'mw'],
    "rasaviddha": ['mw'],
    "rasavikraya": ['mw'],
    "rasavikrayin": ['cae', 'mw'],
    "rasavikretṛ": ['mw'],
    "rasavilāsa": ['mw'],
    "rasaviveka": ['mw'],
    "rasaviśeṣa": ['mw'],
    "rasavāda": ['mw'],
    "rasayati": ['cae', 'mw'],
    "rasayitavya": ['cae', 'mw'],
    "rasayitṛ": ['cae', 'mw'],
    "rasayoga": ['mw'],
    "rasayogamuktāvalī": ['mw'],
    "rasayoni": ['mw'],
    "rasayāmala": ['mw'],
    "rasañjana": ['cped'],
    "rasaśabdasāraṇinighaṇṭu": ['mw'],
    "rasaśodhana": ['mw'],
    "rasaśukta": ['mw'],
    "rasaśārdūla": ['mw'],
    "rasaśāstra": ['mw'],
    "rasaḥ": ['ap90'],
    "rasekṣu": ['mw'],
    "rasendra": ['ddsa', 'mw'],
    "rasendracintāmaṇi": ['mw'],
    "rasendracūḍāmaṇi": ['mw'],
    "rasendrakalpadruma": ['mw'],
    "rasendramaṅgala": ['mw'],
    "rasendrasaṃhitā": ['mw'],
    "rasendrasārasaṃgraha": ['mw'],
    "raseśvara": ['mw'],
    "raseśvaradarśana": ['mw'],
    "raseśvarasiddhānta": ['mw'],
    "rasika": ['ap90', 'cae', 'ddsa', 'mw'],
    "rasikabhūṣaṇa": ['mw'],
    "rasikacandrikā": ['mw'],
    "rasikajana": ['cae'],
    "rasikajīvana": ['mw'],
    "rasikajīvanī": ['mw'],
    "rasikaprakāśa": ['mw'],
    "rasikapriyā": ['mw'],
    "rasikaramaṇa": ['mw'],
    "rasikarañjana": ['mw'],
    "rasikarañjinī": ['mw'],
    "rasikasarvasva": ['mw'],
    "rasikasaṃjīvinī": ['mw'],
    "rasikatva": ['mw'],
    "rasikatā": ['ap90', 'mw'],
    "rasikeśvara": ['mw'],
    "rasikā": ['mw'],
    "rasikābhārya": ['mw'],
    "rasin": ['ap90', 'cae', 'gra', 'mw'],
    "rasita": ['ap90', 'cae', 'ddsa', 'mw'],
    "rasitavat": ['mw'],
    "rasitāśin": ['mw'],
    "rasitṛ": ['cae', 'mw'],
    "rasmi": ['cped'],
    "rasna": ['mw'],
    "rasnaṃ": ['ap90'],
    "rasnā": ['mw'],
    "rasodadhi": ['mw'],
    "rasodbhava": ['mw'],
    "rasollāsa": ['mw'],
    "rasollāsabhāṇa": ['mw'],
    "rasollāsin": ['mw'],
    "rasollāsā": ['mw'],
    "rasona": ['cae', 'mw'],
    "rasonaka": ['mw'],
    "rasonaḥ": ['ap90'],
    "rasopala": ['mw'],
    "rasoparasa": ['mw'],
    "rasoparasaśodhana": ['mw'],
    "rasotpatti": ['mw'],
    "rasottama": ['mw'],
    "rassa": ['cped'],
    "rassatta": ['cped'],
    "rasuna": ['mw'],
    "rasya": ['ap90', 'cae', 'ddsa', 'mw'],
    "rasyamāna": ['mw'],
    "rasyamānatā": ['mw'],
    "rasyā": ['mw'],
    "rasā": ['ap90', 'ddsa', 'gra', 'mw'],
    "rasābdhi": ['mw'],
    "rasābhiniveśa": ['mw'],
    "rasābhivyañjanā": ['mw'],
    "rasābhivyañjikā": ['mw'],
    "rasābhyantara": ['mw'],
    "rasābhāsa": ['mw'],
    "rasādhika": ['cae', 'mw'],
    "rasādhikā": ['mw'],
    "rasādhikāra": ['mw'],
    "rasādhipatya": ['mw'],
    "rasādhyakṣa": ['mw'],
    "rasādhyāya": ['mw'],
    "rasādhāra": ['mw'],
    "rasādhāraṇa": ['mw'],
    "rasādiśuddhi": ['mw'],
    "rasādvaita": ['mw'],
    "rasādāna": ['mw'],
    "rasāgra": ['bhs'],
    "rasāgraja": ['mw'],
    "rasāhva": ['mw'],
    "rasāhvā": ['mw'],
    "rasākara": ['mw'],
    "rasākhana": ['mw'],
    "rasāla": ['cae', 'ddsa', 'mw'],
    "rasālasā": ['ap90', 'mw'],
    "rasālaya": ['mw'],
    "rasālaḥ": ['ap90'],
    "rasālaṃkāra": ['mw'],
    "rasālihā": ['mw'],
    "rasālā": ['mw'],
    "rasālī": ['mw'],
    "rasāmbhodhi": ['mw'],
    "rasāmbhonidhi": ['mw'],
    "rasāmla": ['mw'],
    "rasāmlā": ['mw'],
    "rasāmṛta": ['mw'],
    "rasāmṛtasindhu": ['mw'],
    "rasāntara": ['cae', 'mw'],
    "rasāntaravid": ['cae', 'mw'],
    "rasānupradāna": ['mw'],
    "rasāpuṣ": ['mw'],
    "rasāpāyin": ['mw'],
    "rasārasā": ['mw'],
    "rasārṇava": ['mw'],
    "rasārṇavakalā": ['mw'],
    "rasārṇavasudhākara": ['mw'],
    "rasāsvāda": ['cae', 'ddsa', 'mw'],
    "rasāsvādin": ['mw'],
    "rasātala": ['cae', 'mw'],
    "rasātmaka": ['cae', 'ddsa', 'mw'],
    "rasāvaha": ['mw'],
    "rasāvatāra": ['mw'],
    "rasāveṣṭa": ['mw'],
    "rasāyaka": ['mw'],
    "rasāyana": ['cae', 'mw'],
    "rasāyanakara": ['mw'],
    "rasāyananidhāna": ['mw'],
    "rasāyanaphalā": ['mw'],
    "rasāyanatantra": ['mw'],
    "rasāyanataraṃgiṇī": ['mw'],
    "rasāyanavidhi": ['mw'],
    "rasāyanaśreṣṭha": ['mw'],
    "rasāyanin": ['mw'],
    "rasāyanāmṛtalauha": ['mw'],
    "rasāyanī": ['mw'],
    "rasāyia": ['gra'],
    "rasāyya": ['cae', 'gra', 'mw'],
    "rasāñjana": ['mw'],
    "rasāśin": ['mw'],
    "rasāśir": ['cae', 'gra', 'mw'],
    "rasāśvāsā": ['mw'],
    "rasāśā": ['mw'],
    "rasāḍhya": ['mw'],
    "rasāḍhyā": ['mw'],
    "rasāṅgaka": ['mw'],
    "rata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "ratabandha": ['mw'],
    "rataguru": ['mw'],
    "ratagṛha": ['mw'],
    "ratahiṇḍaka": ['mw'],
    "ratajvara": ['mw'],
    "ratakīla": ['mw'],
    "ratakūjita": ['mw'],
    "ratamānasa": ['mw'],
    "ratana": ['bhs', 'cped'],
    "ratanattaya": ['cped'],
    "ratanavara": ['cped'],
    "ratanendra": ['bhs'],
    "ratanidhi": ['mw'],
    "ratanika": ['cped'],
    "ratanākara": ['cped'],
    "ratanāmaka": ['bhs'],
    "ratanārāca": ['mw'],
    "ratanārīca": ['mw'],
    "ratarddhika": ['mw'],
    "ratatālin": ['mw'],
    "ratatālī": ['mw'],
    "ratavat": ['mw'],
    "rataviśeṣa": ['mw'],
    "ratavraṇa": ['mw'],
    "rataśāyin": ['mw'],
    "ratemadā": ['mw'],
    "ratha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rathabandha": ['mw'],
    "rathabhaṅga": ['cae', 'mw'],
    "rathabhṛt": ['mw'],
    "rathacakka": ['cped'],
    "rathacakra": ['cae', 'mw'],
    "rathacakracit": ['mw'],
    "rathacakrākṛti": ['mw'],
    "rathacaraṇa": ['cae', 'mw'],
    "rathacaryā": ['cae', 'mw'],
    "rathacarṣaṇa": ['gra', 'mw'],
    "rathacarṣaṇi": ['mw'],
    "rathacitra": ['mw'],
    "rathacitrā": ['mw'],
    "rathadhur": ['cae', 'mw'],
    "rathadhurya": ['mw'],
    "rathadhuryatā": ['mw'],
    "rathadhūrgata": ['mw'],
    "rathadru": ['mw'],
    "rathadruma": ['mw'],
    "rathadurga": ['mw'],
    "rathadānavidhi": ['mw'],
    "rathadāru": ['mw'],
    "rathagarbhaka": ['mw'],
    "rathagaruta": ['mw'],
    "rathagaṇaka": ['mw'],
    "rathaghoṣa": ['cae', 'mw'],
    "rathagopana": ['mw'],
    "rathagranthi": ['mw'],
    "rathagupti": ['mw'],
    "rathagutti": ['cped'],
    "rathagṛtsa": ['mw'],
    "rathajaṅghā": ['cae', 'mw'],
    "rathajit": ['cae', 'gra', 'mw'],
    "rathajvara": ['mw'],
    "rathajñāna": ['cae', 'mw'],
    "rathajñānin": ['mw'],
    "rathajūti": ['mw'],
    "rathaka": ['bhs', 'mw'],
    "rathakalpaka": ['mw'],
    "rathakara": ['mw'],
    "rathakaḍyā": ['mw'],
    "rathakaṭyā": ['mw'],
    "rathaketu": ['cae', 'mw'],
    "rathakrānta": ['mw'],
    "rathakrīta": ['mw'],
    "rathakuṭumba": ['mw'],
    "rathakuṭumbika": ['mw'],
    "rathakuṭumbin": ['mw'],
    "rathakāmya": ['mw'],
    "rathakāra": ['cae', 'cped', 'ddsa', 'mw'],
    "rathakāraka": ['mw'],
    "rathakārakula": ['mw'],
    "rathakāratva": ['mw'],
    "rathakāya": ['mw'],
    "rathakūbara": ['mw'],
    "rathakṛcchra": ['mw'],
    "rathakṛt": ['cae', 'mw'],
    "rathakṛtsna": ['mw'],
    "rathakṣaya": ['gra', 'mw'],
    "rathakṣobha": ['mw'],
    "rathalakṣaṇa": ['mw'],
    "rathamadhya": ['mw'],
    "rathamadhyastha": ['mw'],
    "rathamahotsava": ['mw'],
    "rathamaṇḍala": ['mw'],
    "rathamitra": ['mw'],
    "rathamukha": ['cae', 'mw'],
    "rathamārga": ['cae', 'mw'],
    "rathanemi": ['cae', 'mw'],
    "rathanirghoṣa": ['mw'],
    "rathanirhrāda": ['mw'],
    "rathanisvana": ['mw'],
    "rathanābhi": ['cae', 'mw'],
    "rathanīḍa": ['mw'],
    "rathapada": ['mw'],
    "rathapaddhati": ['mw'],
    "rathaparyāya": ['mw'],
    "rathapatha": ['cae', 'mw'],
    "rathapañjara": ['cped'],
    "rathapratiṣṭhāvidhi": ['mw'],
    "rathapraṇetṛ": ['mw'],
    "rathapraṣṭha": ['mw'],
    "rathaprota": ['mw'],
    "rathaproṣṭha": ['gra', 'mw'],
    "rathaprā": ['cae', 'gra', 'mw'],
    "rathapsā": ['mw'],
    "rathapuṃgava": ['mw'],
    "rathapāda": ['mw'],
    "ratharaśmi": ['cae', 'mw'],
    "rathareṇu": ['cped', 'mw'],
    "rathareṣa": ['mw'],
    "ratharvī": ['mw'],
    "rathary": ['cae', 'gra'],
    "ratharya": ['mw'],
    "ratharāja": ['mw'],
    "rathasaptamī": ['mw'],
    "rathasaptamīkālanirṇaya": ['mw'],
    "rathasaptamīpūjā": ['mw'],
    "rathasaptamīsnānavidhi": ['mw'],
    "rathasaptamīvrata": ['mw'],
    "rathasattama": ['mw'],
    "rathasaṃga": ['gra'],
    "rathasaṅga": ['cae', 'mw'],
    "rathaspati": ['cae', 'gra', 'mw'],
    "rathaspaṣṭa": ['mw'],
    "rathaspṛś": ['gra', 'mw'],
    "rathastha": ['cae', 'mw'],
    "rathasthā": ['mw'],
    "rathasvana": ['mw'],
    "rathasyā": ['bhs'],
    "rathasāhvayā": ['mw'],
    "rathasārathi": ['mw'],
    "rathasūtra": ['mw'],
    "rathatur": ['cae', 'gra', 'mw'],
    "rathaugha": ['mw'],
    "rathaujas": ['mw'],
    "rathavant": ['cae'],
    "rathavara": ['mw'],
    "rathavartman": ['cae', 'mw'],
    "rathavat": ['gra', 'mw'],
    "rathavaṃśa": ['mw'],
    "rathavega": ['cae', 'mw'],
    "rathavidyā": ['mw'],
    "rathavijñāna": ['cae', 'mw'],
    "rathavimocana": ['cae', 'mw'],
    "rathavimocanīya": ['mw'],
    "rathavraja": ['mw'],
    "rathavrāta": ['mw'],
    "rathavāha": ['cae', 'mw'],
    "rathavāhaka": ['cae', 'mw'],
    "rathavāhana": ['cae', 'gra', 'mw'],
    "rathavāhanavāha": ['mw'],
    "rathavāhaṇa": ['mw'],
    "rathavāraka": ['mw'],
    "rathavīthī": ['cae', 'mw'],
    "rathavīti": ['gra', 'mw'],
    "rathavṛt": ['mw'],
    "rathayodha": ['cae', 'mw'],
    "rathayoga": ['cae', 'mw'],
    "rathayojaka": ['mw'],
    "rathayu": ['cae', 'gra', 'mw'],
    "rathayuddha": ['cae', 'mw'],
    "rathayuga": ['cped', 'mw'],
    "rathayuj": ['cae', 'gra', 'mw'],
    "rathayā": ['gra', 'mw'],
    "rathayāna": ['cae', 'mw'],
    "rathayātaka": ['mw'],
    "rathayātrā": ['mw'],
    "rathayātrāmahotsava": ['mw'],
    "rathayātrāprayoga": ['mw'],
    "rathayāvan": ['cae', 'gra', 'mw'],
    "rathayūtha": ['mw'],
    "rathayūthapa": ['mw'],
    "rathaśakti": ['mw'],
    "rathaśikṣā": ['cae', 'mw'],
    "rathaśiras": ['cae', 'mw'],
    "rathaśreṇi": ['mw'],
    "rathaśālā": ['mw'],
    "rathaśīrṣa": ['cae', 'mw'],
    "rathaūḍha": ['gra'],
    "rathaḥ": ['ap90'],
    "rathaṃtara": ['gra', 'mw'],
    "rathaṃtaracaraṇabhāṣya": ['mw'],
    "rathaṃtarapāda": ['mw'],
    "rathaṃtarapṛṣṭha": ['mw'],
    "rathaṃtarasāman": ['mw'],
    "rathaṃtaravarṇa": ['mw'],
    "rathaṃtarī": ['mw'],
    "rathaṅga": ['cped'],
    "rathecitra": ['mw'],
    "ratheśa": ['cae', 'ddsa', 'mw'],
    "ratheśubh": ['cae', 'gra', 'mw'],
    "ratheṣu": ['cae', 'mw'],
    "ratheṣā": ['cae', 'mw'],
    "ratheṣṭha": ['cae', 'gra', 'mw'],
    "ratheṣṭhā": ['cae', 'gra', 'mw'],
    "rathia": ['gra'],
    "rathika": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "rathikā": ['cped'],
    "rathin": ['ap90', 'cae', 'gra', 'mw'],
    "rathina": ['ap90', 'mw'],
    "rathinī": ['mw'],
    "rathira": ['ap90', 'cae', 'gra', 'mw'],
    "rathirāy": ['gra'],
    "rathirāya": ['mw'],
    "rathita": ['mw'],
    "rathoddhata": ['cae', 'mw'],
    "rathoddhatā": ['mw'],
    "rathodvaha": ['mw'],
    "rathol̤ha": ['cae', 'mw'],
    "rathopastha": ['cae', 'mw'],
    "rathoraga": ['mw'],
    "rathotsava": ['mw'],
    "rathottama": ['mw'],
    "rathoḍha": ['gra', 'mw'],
    "rathoḍupa": ['mw'],
    "rathoṣmā": ['mw'],
    "rathya": ['cae', 'ddsa', 'gra', 'mw'],
    "rathyacarya": ['mw'],
    "rathyacaya": ['mw'],
    "rathyavirathya": ['mw'],
    "rathyaḥ": ['ap90'],
    "rathyopasarpaṇa": ['cae', 'mw'],
    "rathyā": ['ap90', 'mw'],
    "rathyāli": ['mw'],
    "rathyāmukha": ['cae', 'mw'],
    "rathyāmṛga": ['mw'],
    "rathyāntar": ['mw'],
    "rathyāpaṅkti": ['mw'],
    "rathyāvasarpaṇa": ['mw'],
    "rathābhirūḍhā": ['bhs', 'mw'],
    "rathābhra": ['mw'],
    "rathācariya": ['cped'],
    "rathāgra": ['mw'],
    "rathāgratas": ['mw'],
    "rathāgrya": ['mw'],
    "rathāhas": ['cae', 'mw'],
    "rathāhna": ['mw'],
    "rathāhnya": ['mw'],
    "rathāhvā": ['mw'],
    "rathākṣa": ['cae', 'ddsa', 'mw'],
    "rathākṣamātra": ['mw'],
    "rathāntara": ['mw'],
    "rathānīka": ['cae', 'ddsa', 'mw'],
    "rathārathi": ['ap90', 'cae', 'mw'],
    "rathārbhaka": ['mw'],
    "rathāroha": ['cae', 'cped', 'mw'],
    "rathārohin": ['mw'],
    "rathārūḍha": ['mw'],
    "rathāsah": ['gra', 'mw'],
    "rathāvarta": ['mw'],
    "rathāvayava": ['mw'],
    "rathāvayavāyudha": ['mw'],
    "rathāvaṭṭa": ['mw'],
    "rathāyudhaka": ['mw'],
    "rathāśman": ['mw'],
    "rathāśva": ['cae', 'mw'],
    "rathāṅga": ['cae', 'ddsa', 'mw'],
    "rathāṅgabhartṛ": ['mw'],
    "rathāṅgadhvani": ['mw'],
    "rathāṅganemi": ['mw'],
    "rathāṅganāmaka": ['mw'],
    "rathāṅganāman": ['cae', 'mw'],
    "rathāṅgapāṇi": ['cae', 'mw'],
    "rathāṅgasaṃjña": ['cae', 'mw'],
    "rathāṅgasāhva": ['cae', 'mw'],
    "rathāṅgatulyāhvayana": ['mw'],
    "rathāṅgaśroṇibimbā": ['mw'],
    "rathāṅgin": ['cae', 'mw'],
    "rathāṅgā": ['mw'],
    "rathāṅgāhva": ['mw'],
    "rathāṅgāhvaya": ['mw'],
    "rathāṅgāhvayana": ['mw'],
    "rathāṅgī": ['mw'],
    "rathāṅkā": ['mw'],
    "rathāṇīka": ['cped'],
    "rathāṣṭamī": ['mw'],
    "rathī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rathīkara": ['mw'],
    "rathīnara": ['mw'],
    "rathītama": ['mw'],
    "rathītara": ['mw'],
    "rathīy": ['cae', 'gra'],
    "rathīya": ['mw'],
    "rati": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ratibandhu": ['cae', 'mw'],
    "ratibhavana": ['mw'],
    "ratibhoga": ['mw'],
    "raticaraṇasamantasvara": ['bhs', 'mw'],
    "ratida": ['mw'],
    "ratideva": ['mw'],
    "ratiguṇa": ['mw'],
    "ratigṛha": ['mw'],
    "ratijaha": ['bhs', 'mw'],
    "ratijanaka": ['mw'],
    "ratijña": ['cae', 'mw'],
    "ratika": ['bhs'],
    "ratikara": ['bhs', 'cae', 'ddsa', 'mw'],
    "ratikarman": ['mw'],
    "ratikarā": ['bhs', 'mw'],
    "ratikheda": ['mw'],
    "ratikhedakhinna": ['mw'],
    "ratikhedasupta": ['mw'],
    "ratikriyā": ['cae', 'mw'],
    "ratikuhara": ['mw'],
    "ratikā": ['mw'],
    "ratikāmapūjā": ['mw'],
    "ratikāntatarkavāgīśa": ['mw'],
    "ratikīḷā": ['cped'],
    "ratilakṣa": ['mw'],
    "ratilambhā": ['bhs'],
    "ratilampaṭa": ['mw'],
    "ratilola": ['bhs', 'mw'],
    "ratilīla": ['mw'],
    "ratilīlā": ['mw'],
    "ratimadā": ['mw'],
    "ratimandira": ['mw'],
    "ratimanmatha": ['mw'],
    "ratimanmathapūjā": ['mw'],
    "ratimant": ['cae'],
    "ratimat": ['mw'],
    "ratimañjarī": ['mw'],
    "ratimañjarīguṇaleśasūcakāṣṭaka": ['mw'],
    "ratimitra": ['mw'],
    "ratināga": ['mw'],
    "ratiparicaya": ['mw'],
    "ratipati": ['cae', 'mw'],
    "ratiphala": ['mw'],
    "ratiprabhā": ['bhs'],
    "ratipradhāna": ['bhs'],
    "ratiprapūrṇa": ['bhs', 'mw'],
    "ratipriya": ['mw'],
    "ratipriyā": ['mw'],
    "ratiprīti": ['cae', 'mw'],
    "ratipāśa": ['mw'],
    "ratirahasya": ['mw'],
    "ratirahasyadīpikā": ['mw'],
    "ratiramaṇa": ['cae', 'mw'],
    "ratirasa": ['cae', 'mw'],
    "ratirasaglāni": ['mw'],
    "ratiratnapradīpikā": ['mw'],
    "ratiraṇadhīra": ['mw'],
    "ratirāgā": ['bhs'],
    "ratisahacara": ['cae', 'mw'],
    "ratisarvasva": ['cae', 'mw'],
    "ratisatvarā": ['mw'],
    "ratisaṃgrahavyākhyā": ['mw'],
    "ratisaṃhita": ['mw'],
    "ratisaṃyoga": ['cae', 'mw'],
    "ratisena": ['mw'],
    "ratisundara": ['mw'],
    "ratisāra": ['mw'],
    "ratitaskara": ['mw'],
    "ratitāla": ['mw'],
    "rativallī": ['mw'],
    "rativara": ['mw'],
    "rativardhana": ['mw'],
    "rativyūhā": ['bhs'],
    "ratiśakti": ['mw'],
    "ratiśūra": ['mw'],
    "ratiḥ": ['ap90'],
    "ratiṃkara": ['bhs'],
    "ratna": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ratnabandhaka": ['mw'],
    "ratnabhāj": ['cae', 'gra', 'mw'],
    "ratnabhājana": ['cae'],
    "ratnabhāṇḍa": ['cae'],
    "ratnabhūta": ['cae', 'mw'],
    "ratnabhūti": ['mw'],
    "ratnabuddhi": ['bhs'],
    "ratnabāhu": ['mw'],
    "ratnacandra": ['bhs', 'mw'],
    "ratnacandradhvaja": ['bhs'],
    "ratnacandraprabha": ['bhs'],
    "ratnacandrapradīpaprabhā": ['bhs'],
    "ratnacandrāmati": ['mw'],
    "ratnacaura": ['mw'],
    "ratnacaṅkrama": ['bhs'],
    "ratnacchattra": ['mw'],
    "ratnacchattrakūṭasaṃdarśana": ['mw'],
    "ratnacchattrābhyudgatāvabhāsa": ['mw'],
    "ratnacchāyā": ['cae', 'mw'],
    "ratnachattrakūṭasaṃdarśana": ['bhs'],
    "ratnachattrābhyudgatāvabhāsa": ['bhs'],
    "ratnacūramuni": ['mw'],
    "ratnacūropākhyāna": ['mw'],
    "ratnacūḍa": ['bhs', 'mw'],
    "ratnacūḍamuni": ['mw'],
    "ratnacūḍaparipṛcchā": ['bhs'],
    "ratnacūḍasūtra": ['bhs'],
    "ratnacūḍopākhyāna": ['mw'],
    "ratnacūḍāparipṛcchā": ['mw'],
    "ratnadarpaṇa": ['mw'],
    "ratnadatta": ['bhs', 'mw'],
    "ratnadaṇḍa": ['bhs'],
    "ratnadaṇḍātapatrin": ['mw'],
    "ratnadeva": ['mw'],
    "ratnadha": ['cae', 'gra', 'mw'],
    "ratnadhara": ['mw'],
    "ratnadhenu": ['mw'],
    "ratnadheya": ['cae', 'gra', 'mw'],
    "ratnadhvaja": ['bhs', 'mw'],
    "ratnadhvajāgramati": ['bhs'],
    "ratnadhā": ['cae', 'gra', 'mw'],
    "ratnadhātama": ['mw'],
    "ratnadruma": ['mw'],
    "ratnadrumamaya": ['mw'],
    "ratnadvīpa": ['mw'],
    "ratnadyota": ['mw'],
    "ratnadāma": ['bhs'],
    "ratnadānaśri": ['bhs'],
    "ratnadīpa": ['cae', 'mw'],
    "ratnadīpaka": ['mw'],
    "ratnadīpaviśvaprakāśa": ['mw'],
    "ratnadīpikā": ['mw'],
    "ratnagarbha": ['bhs', 'cae', 'mw'],
    "ratnagarbhā": ['mw'],
    "ratnagiri": ['mw'],
    "ratnagirirasa": ['mw'],
    "ratnagrīvatīrtha": ['mw'],
    "ratnagātraśrī": ['bhs'],
    "ratnahasta": ['bhs', 'mw'],
    "ratnahavis": ['cae', 'mw'],
    "ratnajinaṃ": ['bhs'],
    "ratnajātaka": ['mw'],
    "ratnaka": ['bhs', 'mw'],
    "ratnakalaśa": ['mw'],
    "ratnakalā": ['mw'],
    "ratnakalācaritra": ['mw'],
    "ratnakandala": ['mw'],
    "ratnakara": ['bhs', 'mw'],
    "ratnakaraṇḍaka": ['bhs', 'mw'],
    "ratnakaraṇḍaketu": ['bhs'],
    "ratnakaraṇḍasūtra": ['bhs'],
    "ratnakarṇikā": ['mw'],
    "ratnakaṇṭha": ['mw'],
    "ratnaketu": ['bhs', 'mw'],
    "ratnaketurāja": ['bhs'],
    "ratnaketūdaya": ['mw'],
    "ratnakeśa": ['bhs'],
    "ratnakhacita": ['mw'],
    "ratnakheṭa": ['mw'],
    "ratnakholaka": ['bhs'],
    "ratnakhāni": ['mw'],
    "ratnakirīṭin": ['bhs', 'mw'],
    "ratnakośa": ['mw'],
    "ratnakośakāramatavāda": ['mw'],
    "ratnakośakāravādārtha": ['mw'],
    "ratnakośakārikāvicāra": ['mw'],
    "ratnakośamatarahasya": ['mw'],
    "ratnakośapariṣkāra": ['mw'],
    "ratnakośavicāra": ['mw'],
    "ratnakośavāda": ['mw'],
    "ratnakośavādarahasya": ['mw'],
    "ratnakośavādārtha": ['mw'],
    "ratnakoṭi": ['bhs', 'mw'],
    "ratnakumbha": ['cae', 'mw'],
    "ratnakumāra": ['bhs'],
    "ratnakusumaguṇasāgaravaiḍūryakanakagirisuvarṇakāñcanaprabhāsaśrī": ['bhs'],
    "ratnakusumaprabha": ['bhs'],
    "ratnakusumapradīpā": ['bhs'],
    "ratnakusumasaṃpuṣpitagātra": ['bhs'],
    "ratnakuśa": ['bhs'],
    "ratnakīrti": ['bhs', 'mw'],
    "ratnakūṭa": ['bhs', 'mw'],
    "ratnakūṭasūtra": ['mw'],
    "ratnakṣetrakūṭasaṃdarśana": ['mw'],
    "ratnalakṣaṇa": ['mw'],
    "ratnalakṣaṇavibhūṣitameru": ['bhs'],
    "ratnaliṅgasthāpanavidhi": ['mw'],
    "ratnaliṅgeśvara": ['mw'],
    "ratnamakuṭa": ['bhs'],
    "ratnamati": ['bhs', 'mw'],
    "ratnamaya": ['cae', 'mw'],
    "ratnamañjarī": ['mw'],
    "ratnamañjarīguṇaleśamātrasūcakāṣṭaka": ['mw'],
    "ratnamañjarīguṇaleśasūcakadaśaka": ['mw'],
    "ratnamegha": ['bhs'],
    "ratnameghasūtra": ['mw'],
    "ratnameru": ['bhs'],
    "ratnamitra": ['mw'],
    "ratnamudra": ['bhs'],
    "ratnamudrā": ['bhs', 'mw'],
    "ratnamudrāhasta": ['bhs', 'mw'],
    "ratnamukhya": ['mw'],
    "ratnamukuṭa": ['bhs', 'mw'],
    "ratnamālikā": ['mw'],
    "ratnamālin": ['mw'],
    "ratnamālā": ['bhs', 'cae', 'mw'],
    "ratnamālāvatī": ['mw'],
    "ratnamālīyapuṇḍroka": ['mw'],
    "ratnanadī": ['mw'],
    "ratnanetra": ['bhs'],
    "ratnanetrā": ['bhs'],
    "ratnanicaya": ['mw'],
    "ratnanidhi": ['cae', 'mw'],
    "ratnanābha": ['mw'],
    "ratnanātha": ['mw'],
    "ratnanāyaka": ['mw'],
    "ratnapadmapraphullitagātra": ['bhs'],
    "ratnapadmasupratiṣṭhitaśailendrarāja": ['bhs'],
    "ratnapadmavikrāmin": ['bhs'],
    "ratnapadmābha": ['bhs'],
    "ratnapadmāvabhāsagarbha": ['bhs'],
    "ratnapariṇāma": ['mw'],
    "ratnaparvata": ['bhs', 'cae', 'mw'],
    "ratnaparīkṣā": ['mw'],
    "ratnapati": ['mw'],
    "ratnapañcaka": ['mw'],
    "ratnaprabha": ['bhs', 'mw'],
    "ratnaprabhā": ['bhs', 'mw'],
    "ratnaprabhāsa": ['bhs'],
    "ratnapradīpa": ['cae', 'mw'],
    "ratnapradīpanighaṇṭu": ['mw'],
    "ratnaprakāśa": ['mw'],
    "ratnaprāsāda": ['cae', 'mw'],
    "ratnapura": ['cae', 'mw'],
    "ratnapurībhaṭṭāraka": ['mw'],
    "ratnapuṣpa": ['bhs'],
    "ratnapāla": ['mw'],
    "ratnapāṇi": ['bhs', 'mw'],
    "ratnapīṭhā": ['bhs', 'mw'],
    "ratnarakṣita": ['mw'],
    "ratnaratna": ['cae', 'mw'],
    "ratnaraśmipradīpadhvajarāja": ['bhs'],
    "ratnarekhā": ['mw'],
    "ratnaruciraśrīrāja": ['bhs'],
    "ratnarudhiraketu": ['bhs'],
    "ratnarāj": ['mw'],
    "ratnarājaśri": ['bhs'],
    "ratnarāji": ['mw'],
    "ratnarāśi": ['bhs', 'cae', 'mw'],
    "ratnarāśisūtra": ['bhs'],
    "ratnasambhava": ['mw'],
    "ratnasamuccaya": ['mw'],
    "ratnasamudgala": ['mw'],
    "ratnasamudgata": ['bhs'],
    "ratnasaṃbhava": ['bhs'],
    "ratnasaṃbhavā": ['bhs'],
    "ratnasaṃghāta": ['mw'],
    "ratnasaṃghātamaya": ['mw'],
    "ratnasaṃgraha": ['mw'],
    "ratnasaṃmata": ['bhs'],
    "ratnasena": ['mw'],
    "ratnasiṃha": ['mw'],
    "ratnasiṃhāvabhāsajvalā": ['bhs'],
    "ratnasthalanagara": ['mw'],
    "ratnasvāmin": ['mw'],
    "ratnasāgara": ['mw'],
    "ratnasālavyūhameghapradīpa": ['bhs'],
    "ratnasānu": ['mw'],
    "ratnasāra": ['mw'],
    "ratnasāracintāmaṇi": ['mw'],
    "ratnasārajātakejyotiṣasārasaṃgraha": ['mw'],
    "ratnasāraparvata": ['mw'],
    "ratnasārasamuccaya": ['mw'],
    "ratnasāraśataka": ['mw'],
    "ratnasū": ['cae', 'mw'],
    "ratnasūti": ['mw'],
    "ratnasūtrabhāṣya": ['mw'],
    "ratnatalpa": ['cae', 'mw'],
    "ratnatejas": ['bhs'],
    "ratnatejobhyudgatarāja": ['bhs', 'mw'],
    "ratnatraya": ['bhs', 'mw'],
    "ratnatrayajayamālā": ['mw'],
    "ratnatrayaparīkṣā": ['mw'],
    "ratnatrayavidhānakathā": ['mw'],
    "ratnatrayoddyota": ['mw'],
    "ratnatrayodyāpana": ['mw'],
    "ratnatūlikā": ['mw'],
    "ratnavajrī": ['bhs'],
    "ratnavant": ['bhs', 'cae'],
    "ratnavara": ['bhs', 'mw'],
    "ratnavardhana": ['cae', 'mw'],
    "ratnavardhaneśa": ['mw'],
    "ratnavarman": ['cae', 'mw'],
    "ratnavarṣa": ['mw'],
    "ratnavarṣuka": ['mw'],
    "ratnavastrāvabhāsadhvajā": ['bhs'],
    "ratnavat": ['ap90', 'gra', 'mw'],
    "ratnavatī": ['mw'],
    "ratnaviśuddha": ['mw'],
    "ratnaviśuddhā": ['bhs'],
    "ratnavyomaka": ['bhs'],
    "ratnavyūha": ['bhs'],
    "ratnavyūhā": ['bhs'],
    "ratnavṛkṣa": ['bhs', 'mw'],
    "ratnayaṣṭi": ['bhs', 'mw'],
    "ratnayugmatīrtha": ['mw'],
    "ratnayūpa": ['bhs'],
    "ratnaśaila": ['bhs'],
    "ratnaśalākā": ['mw'],
    "ratnaśayana": ['bhs'],
    "ratnaśekhara": ['mw'],
    "ratnaśeṇā": ['mw'],
    "ratnaśikhara": ['bhs', 'mw'],
    "ratnaśikharārciḥparvatapradīpa": ['bhs'],
    "ratnaśikhaṇḍa": ['mw'],
    "ratnaśikhin": ['bhs', 'mw'],
    "ratnaśilā": ['bhs', 'mw'],
    "ratnaśrī": ['bhs', 'mw'],
    "ratnaśrīhaṃsacintā": ['bhs'],
    "ratnaśrīpradīpaguṇaketu": ['bhs'],
    "ratnaśrīsaṃbhava": ['bhs'],
    "ratnaśrīśikharameghapradīpa": ['bhs'],
    "ratnaśāstra": ['mw'],
    "ratnaśāṇa": ['mw'],
    "ratnaśṛṅga": ['bhs'],
    "ratnaḍākinī": ['bhs'],
    "ratnaṃ": ['ap90'],
    "ratnaṣaṣṭhī": ['cae', 'mw'],
    "ratnedra": ['ddsa'],
    "ratnendra": ['bhs', 'mw'],
    "ratneśa": ['bhs'],
    "ratneśaka": ['mw'],
    "ratneśvara": ['mw'],
    "ratni": ['mw'],
    "ratnika": ['bhs'],
    "ratnin": ['cae', 'ddsa', 'gra', 'mw'],
    "ratnipṛṣṭhaka": ['mw'],
    "ratnitva": ['mw'],
    "ratniḥ": ['ap90'],
    "ratnoccaya": ['bhs'],
    "ratnodbhava": ['mw'],
    "ratnojjvala": ['mw'],
    "ratnolkā": ['bhs', 'mw'],
    "ratnotpalaśrī": ['bhs'],
    "ratnottama": ['bhs', 'mw'],
    "ratnottamā": ['bhs', 'mw'],
    "ratnābha": ['bhs'],
    "ratnābharaṇa": ['mw'],
    "ratnābhibhāsa": ['bhs', 'mw'],
    "ratnābhiṣekamantra": ['mw'],
    "ratnādevī": ['mw'],
    "ratnādhipati": ['mw'],
    "ratnādinandin": ['mw'],
    "ratnādiparīkṣā": ['mw'],
    "ratnādri": ['mw'],
    "ratnāgni": ['bhs'],
    "ratnāgraprabhateja": ['bhs'],
    "ratnākara": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ratnākaragupta": ['bhs'],
    "ratnākaramekhalā": ['mw'],
    "ratnākaranighaṇṭa": ['mw'],
    "ratnākarapaddhati": ['mw'],
    "ratnākarasapādaśataka": ['mw'],
    "ratnākaratva": ['mw'],
    "ratnākaraśānti": ['bhs'],
    "ratnākarāyita": ['mw'],
    "ratnāloka": ['mw'],
    "ratnāmaya": ['bhs'],
    "ratnānuviddha": ['mw'],
    "ratnāpaṇa": ['mw'],
    "ratnāpura": ['mw'],
    "ratnārcinetraprabha": ['bhs'],
    "ratnārciparvataśrī": ['bhs'],
    "ratnārcis": ['bhs', 'mw'],
    "ratnārciḥparvata": ['bhs'],
    "ratnārciḥparvataśrīteja": ['bhs'],
    "ratnārpaṇa": ['mw'],
    "ratnārṇava": ['mw'],
    "ratnāsana": ['mw'],
    "ratnāvabhāsa": ['bhs', 'mw'],
    "ratnāvalī": ['cae', 'ddsa', 'mw'],
    "ratnāvalīnibandha": ['mw'],
    "ratnāvalīpaddhati": ['mw'],
    "ratnāvatī": ['bhs', 'ddsa', 'mw'],
    "ratnāyita": ['ddsa'],
    "ratnāḍhya": ['mw'],
    "ratnāṅga": ['mw'],
    "ratnāṅgulīyaka": ['cae', 'mw'],
    "ratnāṅgurīyaka": ['cae', 'mw'],
    "ratnāṅka": ['mw'],
    "ratnāṅkarā": ['bhs'],
    "ratnāṅkura": ['cae', 'mw'],
    "ratnāṣṭaka": ['mw'],
    "ratodvaha": ['mw'],
    "ratoparatasaṃsupta": ['mw'],
    "ratotsava": ['cae', 'ddsa', 'mw'],
    "ratta": ['cped'],
    "rattacandana": ['cped'],
    "rattakkha": ['cped'],
    "rattamaṇi": ['cped'],
    "rattandhakāra": ['cped'],
    "rattapaduma": ['cped'],
    "rattaphalā": ['cped'],
    "rattapā": ['cped'],
    "rattaññū": ['cped'],
    "ratti": ['cped'],
    "rattibhojana": ['cped'],
    "rattibhāga": ['cped'],
    "rattikhitta": ['cped'],
    "rattikkhaya": ['cped'],
    "rattātisāra": ['cped'],
    "rattūparata": ['cped'],
    "ratyaṅga": ['mw'],
    "ratyudgata": ['bhs'],
    "ratā": ['mw'],
    "ratāmarda": ['mw'],
    "ratāmbuka": ['mw'],
    "ratāndhrī": ['mw'],
    "ratānduka": ['mw'],
    "ratānta": ['mw'],
    "ratārambhāvasānika": ['mw'],
    "ratārthin": ['mw'],
    "ratārthinī": ['mw'],
    "ratāyanī": ['mw'],
    "ratī": ['mw'],
    "ratīśa": ['cae', 'mw'],
    "ratū": ['mw'],
    "raucanika": ['ap90', 'ddsa', 'mw'],
    "raucya": ['mw'],
    "raucyaḥ": ['ap90'],
    "raudara": ['gra'],
    "raudha": ['mw'],
    "raudhira": ['ap90', 'cae', 'ddsa', 'mw'],
    "raudhādika": ['ddsa', 'mw'],
    "raudra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "raudradarśana": ['mw'],
    "raudradaṃṣṭra": ['mw'],
    "raudraka": ['mw'],
    "raudrakarman": ['mw'],
    "raudram": ['mw'],
    "raudramanas": ['mw'],
    "raudranetrā": ['mw'],
    "raudrapāda": ['mw'],
    "raudrarkṣa": ['mw'],
    "raudratā": ['mw'],
    "raudri": ['mw'],
    "raudrā": ['bhs', 'cae'],
    "raudrāgna": ['mw'],
    "raudrākṣa": ['bhs', 'mw'],
    "raudrāyaṇa": ['mw'],
    "raudrāśva": ['mw'],
    "raudrāṇī": ['mw'],
    "raudrī": ['mw'],
    "raudrībhāva": ['mw'],
    "raudrīkaraṇa": ['mw'],
    "rauhakṣiti": ['mw'],
    "rauheya": ['mw'],
    "rauhidaśva": ['mw'],
    "rauhika": ['mw'],
    "rauhita": ['mw'],
    "rauhitaka": ['mw'],
    "rauhityāyani": ['mw'],
    "rauhiṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rauhiṇahavanī": ['mw'],
    "rauhiṇaka": ['mw'],
    "rauhiṇakapāla": ['mw'],
    "rauhiṇeya": ['cae', 'mw'],
    "rauhiṇeyaḥ": ['ap90'],
    "rauhiṇeśvaratīrtha": ['mw'],
    "rauhiṇi": ['mw'],
    "rauhiṇika": ['mw'],
    "rauhiṇya": ['mw'],
    "rauhiṇāyana": ['cae', 'mw'],
    "rauhiṇī": ['bhs'],
    "rauhiṣ": ['ap90', 'mw'],
    "rauhiṣa": ['mw'],
    "rauhiṣaḥ": ['ap90'],
    "rauhiṣī": ['mw'],
    "rauhī": ['cae', 'mw'],
    "rauhītaka": ['ddsa', 'mw'],
    "raukma": ['ap90', 'cae', 'ddsa', 'mw'],
    "raukmiṇeya": ['mw'],
    "raukmiṇeyaḥ": ['ap90'],
    "raukṣa": ['bhs'],
    "raukṣacitta": ['mw'],
    "raukṣaka": ['mw'],
    "raukṣya": ['cae', 'ddsa', 'mw'],
    "raukṣyaṃ": ['ap90'],
    "raukṣāyaṇa": ['mw'],
    "rauma": ['ddsa', 'mw'],
    "raumaharṣaṇaka": ['mw'],
    "raumaharṣaṇi": ['mw'],
    "raumaka": ['ap90', 'mw'],
    "raumakalavaṇa": ['mw'],
    "raumakīya": ['mw'],
    "raumalavaṇa": ['mw'],
    "raumaśīya": ['mw'],
    "raumaṃ": ['ap90'],
    "raumaṇya": ['mw'],
    "raumya": ['cae', 'mw'],
    "raumāyaṇa": ['mw'],
    "raupya": ['ap90', 'cae', 'ddsa', 'mw'],
    "raupyaka": ['mw'],
    "raupyamaya": ['cae', 'mw'],
    "raupyamāṣaka": ['cae', 'mw'],
    "raupyanābha": ['mw'],
    "raupyarukmamaya": ['mw'],
    "raupyā": ['mw'],
    "raupyāyasahiraṇmaya": ['mw'],
    "raupyāyaṇa": ['mw'],
    "raupyāyaṇi": ['mw'],
    "raura": ['mw'],
    "raurava": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "rauravaka": ['mw'],
    "rauravatantra": ['mw'],
    "rauruka": ['bhs'],
    "raurukin": ['mw'],
    "raurukīya": ['mw'],
    "rauśadaśva": ['ddsa', 'mw'],
    "rauśarman": ['mw'],
    "rauḍ": ['ap90', 'mw'],
    "rauḍhīya": ['mw'],
    "rauḍi": ['mw'],
    "rauṭ": ['ap90', 'mw'],
    "rava": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ravaka": ['mw'],
    "ravamāna": ['cped'],
    "ravamāṇa": ['mw'],
    "ravana": ['cped'],
    "ravanta": ['cped'],
    "ravas": ['gra', 'mw'],
    "ravasa": ['mw'],
    "ravat": ['mw'],
    "ravata": ['cae', 'mw'],
    "ravatha": ['cae', 'gra', 'mw'],
    "ravati": ['cped'],
    "ravaḥ": ['ap90'],
    "ravaṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "ravaṇaka": ['bhs', 'mw'],
    "ravaṇakaḥ": ['ap90'],
    "ravi": ['cae', 'cped', 'ddsa', 'mw'],
    "ravibimba": ['cae', 'mw'],
    "ravicakra": ['mw'],
    "ravicakrakṣepakadhruvāṅkāḥ": ['mw'],
    "ravicandra": ['mw'],
    "ravidatta": ['mw'],
    "ravideva": ['mw'],
    "ravidharman": ['mw'],
    "ravidhvaja": ['mw'],
    "ravidina": ['ddsa', 'mw'],
    "ravidugdha": ['mw'],
    "ravidāsa": ['mw'],
    "ravidīpta": ['mw'],
    "ravigraha": ['mw'],
    "ravigrahaṇa": ['mw'],
    "ravigrāvan": ['mw'],
    "ravigupta": ['bhs', 'mw'],
    "ravihaṁsa": ['cped'],
    "ravija": ['mw'],
    "ravijaputradina": ['mw'],
    "ravikara": ['mw'],
    "ravikiraṇa": ['cae', 'mw'],
    "ravikiraṇakūrcikā": ['mw'],
    "ravikuladīpaprakāśa": ['mw'],
    "ravikānta": ['mw'],
    "ravikāntamaya": ['mw'],
    "ravikīrti": ['mw'],
    "ravilocana": ['mw'],
    "raviloha": ['mw'],
    "ravimaṇi": ['mw'],
    "ravimaṇḍala": ['cae', 'mw'],
    "ravimuhūrta": ['mw'],
    "ravimāsaka": ['mw'],
    "ravinandana": ['mw'],
    "ravinda": ['mw'],
    "ravinetra": ['mw'],
    "ravināga": ['mw'],
    "ravipatigurumūrti": ['mw'],
    "ravipattra": ['mw'],
    "raviprabhu": ['mw'],
    "ravipraśna": ['mw'],
    "ravipriya": ['mw'],
    "ravipriyā": ['mw'],
    "ravipulā": ['mw'],
    "raviputra": ['mw'],
    "raviratha": ['mw'],
    "raviratna": ['mw'],
    "raviratnaka": ['mw'],
    "ravisamaprabha": ['mw'],
    "ravisaṃjñaka": ['mw'],
    "ravisaṃkrānti": ['mw'],
    "ravisaṃkrāntinirṇaya": ['mw'],
    "ravisena": ['mw'],
    "ravisundararasa": ['mw'],
    "ravisuta": ['cae', 'mw'],
    "ravisārathi": ['mw'],
    "ravisūnu": ['mw'],
    "ravita": ['bhs', 'cped', 'mw'],
    "ravitanaya": ['cae', 'mw'],
    "ravitejas": ['mw'],
    "ravitvā": ['cped'],
    "ravitīrtha": ['mw'],
    "ravitṛ": ['cae', 'ddsa', 'mw'],
    "ravivardhanagaṇi": ['mw'],
    "ravivarman": ['mw'],
    "ravivaṃśa": ['mw'],
    "ravivāra": ['mw'],
    "ravivāravratavidhi": ['mw'],
    "ravivāsara": ['mw'],
    "raviśa": ['bhs'],
    "raviḥ": ['ap90'],
    "raviṣeṇa": ['mw'],
    "ravā": ['mw'],
    "ravāṇa": ['mw'],
    "ravīndra": ['mw'],
    "ravīṣu": ['mw'],
    "ravīṣuḥ": ['ap90'],
    "ravīṣṭa": ['mw'],
    "ravīṣṭā": ['mw'],
    "ray": ['ap90', 'mw'],
    "raya": ['cae', 'ddsa', 'mw'],
    "rayaka": ['mw'],
    "rayamaṇi": ['mw'],
    "rayapraśnasūtrasiddhānta": ['mw'],
    "rayas": ['mw'],
    "rayavat": ['mw'],
    "rayaḥ": ['ap90'],
    "rayaṇasāra": ['mw'],
    "rayeṇa": ['mw'],
    "rayi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rayida": ['cae', 'gra', 'mw'],
    "rayidhāraṇapiṇḍa": ['mw'],
    "rayidā": ['cae', 'gra', 'mw'],
    "rayikva": ['mw'],
    "rayimant": ['cae'],
    "rayimat": ['ddsa', 'gra', 'mw'],
    "rayintama": ['cae', 'ddsa', 'gra', 'mw'],
    "rayipati": ['cae', 'gra', 'mw'],
    "rayisthāna": ['cae', 'gra', 'mw'],
    "rayivant": ['cae'],
    "rayivat": ['gra', 'mw'],
    "rayivid": ['cae', 'gra', 'mw'],
    "rayivṛdh": ['cae', 'gra', 'mw'],
    "rayiṣac": ['cae', 'mw'],
    "rayiṣah": ['cae', 'mw'],
    "rayiṣāc": ['cae', 'gra'],
    "rayiṣāh": ['cae', 'gra'],
    "rayiṣṭha": ['mw'],
    "rayiṣṭhaḥ": ['ap90'],
    "rayiṣṭhā": ['cae', 'mw'],
    "rayiṣṭhāna": ['cae', 'mw'],
    "rayyā": ['ddsa'],
    "rayyāvaṭṭa": ['ddsa', 'mw'],
    "rayāt": ['mw'],
    "rayīy": ['gra'],
    "rayīyant": ['cae'],
    "rayīyat": ['mw'],
    "rayīṣin": ['mw'],
    "rañch": ['mw'],
    "rañj": ['ddsa', 'mw'],
    "rañja": ['mw'],
    "rañjaka": ['cae', 'ddsa', 'mw'],
    "rañjakī": ['mw'],
    "rañjamāna": ['cped'],
    "rañjana": ['cae', 'mw'],
    "rañjanadravya": ['mw'],
    "rañjanadru": ['mw'],
    "rañjanadruma": ['mw'],
    "rañjanaka": ['mw'],
    "rañjanatva": ['mw'],
    "rañjanavallī": ['mw'],
    "rañjanta": ['cped'],
    "rañjanī": ['mw'],
    "rañjanīya": ['cae', 'mw'],
    "rañjati": ['cped'],
    "rañjenta": ['cped'],
    "rañjesi": ['cped'],
    "rañjeti": ['cped'],
    "rañjetvā": ['cped'],
    "rañji": ['cped'],
    "rañjinī": ['mw'],
    "rañjita": ['cped', 'mw'],
    "rañjitvā": ['cped'],
    "rañjā": ['mw'],
    "rañjāpanika": ['bhs'],
    "raś": ['gra'],
    "raśami": ['bhs'],
    "raśana": ['mw'],
    "raśanasammita": ['mw'],
    "raśanopamā": ['mw'],
    "raśanā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "raśanāguṇa": ['mw'],
    "raśanāguṇāspada": ['mw'],
    "raśanākalāpa": ['cae', 'mw'],
    "raśanākalāpaka": ['mw'],
    "raśanākṛta": ['mw'],
    "raśanāpada": ['mw'],
    "raśanāya": ['mw'],
    "raśman": ['cae', 'gra', 'mw'],
    "raśmi": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "raśmicandrapratimaṇḍitavidyuttejaghoṣeśvararāja": ['bhs'],
    "raśmicandrorṇamegha": ['bhs'],
    "raśmidhvaja": ['bhs'],
    "raśmidhāra": ['mw'],
    "raśmiguṇamakuṭajñānaprajñābha": ['bhs'],
    "raśmijvalanacūḍa": ['bhs'],
    "raśmijāla": ['cae', 'mw'],
    "raśmikalāpa": ['mw'],
    "raśmiketu": ['mw'],
    "raśmikrīḍa": ['mw'],
    "raśmimant": ['cae'],
    "raśmimat": ['ap90', 'mw'],
    "raśmimaya": ['cae', 'mw'],
    "raśmimaṇḍala": ['mw'],
    "raśmimaṇḍalaśikhararāja": ['bhs'],
    "raśmimuca": ['mw'],
    "raśmimukha": ['bhs'],
    "raśmimālin": ['cae', 'mw'],
    "raśmin": ['mw'],
    "raśminetrapratibhāprabhacandra": ['bhs'],
    "raśmipa": ['mw'],
    "raśmiparvatamegha": ['bhs'],
    "raśmipati": ['mw'],
    "raśmipavitra": ['mw'],
    "raśmiprabhāsa": ['bhs', 'mw'],
    "raśmipramukta": ['bhs'],
    "raśmipuñja": ['cae', 'mw'],
    "raśmirasaprayoga": ['mw'],
    "raśmirāja": ['mw'],
    "raśmisa": ['mw'],
    "raśmisaṃkusumitapradīpa": ['bhs'],
    "raśmivant": ['cae'],
    "raśmivat": ['ap90', 'mw'],
    "raśmivatī": ['mw'],
    "raśmivimalaprabha": ['bhs'],
    "raśmiśatasahasraparipūrṇadhvaja": ['bhs', 'mw'],
    "raśmiḥ": ['ap90'],
    "raśmīvat": ['mw'],
    "raḍi": ['mw'],
    "raḍḍa": ['ddsa', 'mw'],
    "raḍḍā": ['mw'],
    "raḥ": ['ap90'],
    "raṁsi": ['cped'],
    "raṁsimant": ['cped'],
    "raṃbh": ['ap90'],
    "raṃbhaḥ": ['ap90'],
    "raṃbhā": ['ap90'],
    "raṃdhanaṃ": ['ap90'],
    "raṃdhita": ['ap90'],
    "raṃdhraṃ": ['ap90'],
    "raṃg": ['ap90'],
    "raṃgaḥ": ['ap90'],
    "raṃgaṇaṃ": ['ap90'],
    "raṃgh": ['ap90'],
    "raṃghas": ['ap90'],
    "raṃgin": ['ap90'],
    "raṃh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "raṃha": ['mw'],
    "raṃhas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "raṃhasa": ['mw'],
    "raṃhati": ['mw'],
    "raṃhatiḥ": ['ap90'],
    "raṃhaṇa": ['mw'],
    "raṃhaṇaṃ": ['ap90'],
    "raṃhi": ['cae', 'ddsa', 'gra', 'mw'],
    "raṃhita": ['mw'],
    "raṃhiḥ": ['ap90'],
    "raṃj": ['ap90'],
    "raṃjaka": ['ap90'],
    "raṃjana": ['ap90'],
    "raṃjanī": ['ap90'],
    "raṃjita": ['ap90'],
    "raṃka": ['ap90'],
    "raṃkuḥ": ['ap90'],
    "raṃsu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "raṃsujihva": ['cae', 'gra', 'mw'],
    "raṃtidevaḥ": ['ap90'],
    "raṃtuḥ": ['ap90'],
    "raṃḍa": ['ap90'],
    "raṃḍakaḥ": ['ap90'],
    "raṅg": ['cae', 'mw'],
    "raṅga": ['cae', 'cped', 'ddsa', 'mw'],
    "raṅgabhūmi": ['cae', 'mw'],
    "raṅgabhūti": ['mw'],
    "raṅgabhṛṅgavallī": ['mw'],
    "raṅgacara": ['mw'],
    "raṅgada": ['mw'],
    "raṅgadatta": ['mw'],
    "raṅgadevatā": ['mw'],
    "raṅgadhātu": ['mw'],
    "raṅgadvār": ['mw'],
    "raṅgadvāra": ['cae', 'mw'],
    "raṅgadā": ['mw'],
    "raṅgadāyaka": ['mw'],
    "raṅgadṛḍhā": ['mw'],
    "raṅgaja": ['mw'],
    "raṅgajāta": ['cped'],
    "raṅgajīvaka": ['mw'],
    "raṅgakāra": ['cped', 'mw'],
    "raṅgakāraka": ['mw'],
    "raṅgakāṣṭha": ['mw'],
    "raṅgakṣetra": ['mw'],
    "raṅgakṣāra": ['mw'],
    "raṅgalatā": ['mw'],
    "raṅgalāsinī": ['mw'],
    "raṅgalīla": ['mw'],
    "raṅgamadhya": ['mw'],
    "raṅgamalla": ['mw'],
    "raṅgamallī": ['mw'],
    "raṅgamaṅgala": ['cae', 'mw'],
    "raṅgamaṇḍapa": ['cae', 'mw'],
    "raṅgamāhātmya": ['mw'],
    "raṅgamātṛ": ['mw'],
    "raṅgamāṇikya": ['mw'],
    "raṅganāmaka": ['mw'],
    "raṅganātha": ['cae', 'mw'],
    "raṅganāthadeśikāhnika": ['mw'],
    "raṅganāthamaṅgalastotra": ['mw'],
    "raṅganāthamāhātmya": ['mw'],
    "raṅganāthanāmaratna": ['mw'],
    "raṅganāthanāṭaka": ['mw'],
    "raṅganāthapādukāsahasra": ['mw'],
    "raṅganāthastotra": ['mw'],
    "raṅganāthānuśāsana": ['mw'],
    "raṅganāthāṣṭaka": ['mw'],
    "raṅganāthāṣṭottaraśata": ['mw'],
    "raṅganāthīya": ['mw'],
    "raṅganāyaka": ['mw'],
    "raṅgapattrī": ['mw'],
    "raṅgapatākā": ['mw'],
    "raṅgaplutalakṣaṇa": ['mw'],
    "raṅgapradīpaka": ['mw'],
    "raṅgaprasādana": ['mw'],
    "raṅgapraveśa": ['mw'],
    "raṅgapuṣpī": ['mw'],
    "raṅgapīṭha": ['mw'],
    "raṅgaratta": ['cped'],
    "raṅgarāja": ['mw'],
    "raṅgarājastava": ['mw'],
    "raṅgarāmānuja": ['mw'],
    "raṅgarāmānujīya": ['mw'],
    "raṅgarāṭchandas": ['mw'],
    "raṅgasaṃgara": ['mw'],
    "raṅgastambhana": ['bhs'],
    "raṅgastotra": ['mw'],
    "raṅgataraṃga": ['mw'],
    "raṅgataraṃgiṇī": ['mw'],
    "raṅgatāla": ['mw'],
    "raṅgavallikā": ['mw'],
    "raṅgavallī": ['mw'],
    "raṅgavastu": ['mw'],
    "raṅgavatī": ['mw'],
    "raṅgavidyādhara": ['mw'],
    "raṅgavārāṅganā": ['mw'],
    "raṅgavāṭa": ['cae', 'mw'],
    "raṅgaśālā": ['mw'],
    "raṅgaṇa": ['mw'],
    "raṅgeśa": ['mw'],
    "raṅgeśapura": ['mw'],
    "raṅgeśvarī": ['mw'],
    "raṅgeṣṭālu": ['mw'],
    "raṅgeṣṭāluka": ['mw'],
    "raṅgh": ['cae', 'ddsa', 'mw'],
    "raṅghas": ['cae', 'ddsa', 'mw'],
    "raṅghyā": ['mw'],
    "raṅgika": ['bhs'],
    "raṅgin": ['cae', 'ddsa', 'mw'],
    "raṅgita": ['ddsa', 'mw'],
    "raṅgiṇī": ['mw'],
    "raṅgoddyota": ['mw'],
    "raṅgopajīvin": ['mw'],
    "raṅgopajīvina": ['ddsa'],
    "raṅgopajīvya": ['mw'],
    "raṅgopamardin": ['mw'],
    "raṅgā": ['bhs', 'mw'],
    "raṅgābharaṇa": ['mw'],
    "raṅgācārya": ['mw'],
    "raṅgājīva": ['cped', 'mw'],
    "raṅgāri": ['mw'],
    "raṅgārohaṇa": ['mw'],
    "raṅgāvali": ['mw'],
    "raṅgāvataraṇa": ['cae', 'mw'],
    "raṅgāvatāraka": ['cae', 'mw'],
    "raṅgāvatārin": ['cae', 'mw'],
    "raṅgāṅgana": ['mw'],
    "raṅgāṅgaṇa": ['cae'],
    "raṅgāṅgā": ['mw'],
    "raṅka": ['cae', 'ddsa', 'mw'],
    "raṅkaka": ['mw'],
    "raṅkh": ['mw'],
    "raṅktṛ": ['mw'],
    "raṅku": ['cae', 'ddsa', 'mw'],
    "raṅkuka": ['mw'],
    "raṅkumālin": ['mw'],
    "raṅkuṭi": ['mw'],
    "raṅkṣu": ['mw'],
    "raṇ": ['ap90', 'gra', 'mw'],
    "raṇa": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "raṇabahāduraśāhavirudrāvalī": ['mw'],
    "raṇabhaṭa": ['mw'],
    "raṇabhū": ['cae', 'mw'],
    "raṇabhūmi": ['cae', 'mw'],
    "raṇadara": ['mw'],
    "raṇadhara": ['bhs'],
    "raṇadhur": ['mw'],
    "raṇadhurā": ['mw'],
    "raṇadhṛṣṭa": ['mw'],
    "raṇadundubhi": ['cae', 'ddsa', 'mw'],
    "raṇadurgā": ['mw'],
    "raṇadurgādhāraṇayantra": ['mw'],
    "raṇagocara": ['mw'],
    "raṇahastin": ['mw'],
    "raṇaiṣin": ['mw'],
    "raṇajambuka": ['mw'],
    "raṇajaya": ['mw'],
    "raṇaka": ['mw'],
    "raṇakarman": ['cae', 'mw'],
    "raṇakhala": ['mw'],
    "raṇakāmin": ['mw'],
    "raṇakāmya": ['mw'],
    "raṇakārin": ['mw'],
    "raṇakṛt": ['cae', 'gra', 'mw'],
    "raṇakṣauṇi": ['mw'],
    "raṇakṣetra": ['mw'],
    "raṇakṣiti": ['cae', 'mw'],
    "raṇakṣmā": ['mw'],
    "raṇakṣoṇi": ['mw'],
    "raṇalakṣmī": ['cae', 'mw'],
    "raṇamatta": ['mw'],
    "raṇamukha": ['cae', 'mw'],
    "raṇamuṣṭikā": ['mw'],
    "raṇamārgakovida": ['mw'],
    "raṇamūrdhan": ['mw'],
    "raṇapakṣin": ['mw'],
    "raṇapaṇḍita": ['mw'],
    "raṇapriya": ['cae', 'mw'],
    "raṇapurasvāmin": ['mw'],
    "raṇarasika": ['cae', 'mw'],
    "raṇaraṅga": ['mw'],
    "raṇaraṅgamalla": ['mw'],
    "raṇaraṅka": ['mw'],
    "raṇaraṇa": ['mw'],
    "raṇaraṇaka": ['cae', 'mw'],
    "raṇaraṇāyita": ['mw'],
    "raṇasahāya": ['mw'],
    "raṇasajjā": ['mw'],
    "raṇasattra": ['mw'],
    "raṇasaṃkula": ['mw'],
    "raṇasaṃrambha": ['mw'],
    "raṇastambabhramara": ['mw'],
    "raṇastambha": ['mw'],
    "raṇastha": ['mw'],
    "raṇasthāna": ['cae', 'mw'],
    "raṇasvāmin": ['mw'],
    "raṇat": ['mw'],
    "raṇati": ['bhs'],
    "raṇatkāra": ['cae', 'ddsa', 'mw'],
    "raṇatkāraḥ": ['ap90'],
    "raṇatūrya": ['mw'],
    "raṇavanya": ['mw'],
    "raṇavaṅgamalla": ['mw'],
    "raṇavigraha": ['mw'],
    "raṇavikrama": ['mw'],
    "raṇaviśārada": ['mw'],
    "raṇavādya": ['mw'],
    "raṇavṛtti": ['mw'],
    "raṇayajña": ['mw'],
    "raṇañjaha": ['cped'],
    "raṇaśauṇḍa": ['cae', 'mw'],
    "raṇaśikṣā": ['cae', 'mw'],
    "raṇaśiras": ['mw'],
    "raṇaśīrṣa": ['mw'],
    "raṇaśūra": ['cae', 'mw'],
    "raṇaḥ": ['ap90'],
    "raṇaṃgaha": ['mw'],
    "raṇaṃjaha": ['bhs'],
    "raṇaṃjaya": ['mw'],
    "raṇecara": ['mw'],
    "raṇesvaccha": ['mw'],
    "raṇesvacchaḥ": ['ap90'],
    "raṇeśa": ['ddsa', 'mw'],
    "raṇeśvara": ['mw'],
    "raṇia": ['gra'],
    "raṇita": ['cae', 'ddsa', 'mw'],
    "raṇitaṃ": ['ap90'],
    "raṇitṛ": ['cae', 'mw'],
    "raṇoddeśa": ['mw'],
    "raṇoddāma": ['mw'],
    "raṇoddīpasiṃha": ['mw'],
    "raṇotkaṭa": ['ddsa', 'mw'],
    "raṇotsāha": ['mw'],
    "raṇv": ['cae', 'mw'],
    "raṇva": ['cae', 'ddsa', 'gra', 'mw'],
    "raṇvan": ['gra', 'mw'],
    "raṇvasaṃdṛś": ['cae', 'gra', 'mw'],
    "raṇvita": ['cae', 'gra', 'mw'],
    "raṇya": ['cae', 'gra', 'mw'],
    "raṇyajit": ['gra', 'mw'],
    "raṇyavāc": ['gra', 'mw'],
    "raṇābhiyoga": ['mw'],
    "raṇāditya": ['mw'],
    "raṇāgni": ['ddsa', 'mw'],
    "raṇāgra": ['mw'],
    "raṇāji": ['mw'],
    "raṇājira": ['cae', 'mw'],
    "raṇālaṃkaraṇa": ['mw'],
    "raṇāntakṛt": ['mw'],
    "raṇāpeta": ['mw'],
    "raṇārambhā": ['mw'],
    "raṇārambhāsvāmideva": ['mw'],
    "raṇātodya": ['cae', 'mw'],
    "raṇāvani": ['cae', 'mw'],
    "raṇāyudha": ['mw'],
    "raṇāśva": ['mw'],
    "raṇāṅga": ['mw'],
    "raṇāṅgana": ['cae', 'mw'],
    "raṇāṅgaṇa": ['cae'],
    "raṇḍa": ['ddsa', 'mw'],
    "raṇḍaka": ['mw'],
    "raṇḍā": ['bhs', 'cae', 'mw'],
    "raṇḍānanda": ['mw'],
    "raṇḍāśramin": ['mw'],
    "raṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "raṭana": ['cae', 'ddsa', 'mw'],
    "raṭanaṃ": ['ap90'],
    "raṭantī": ['mw'],
    "raṭaraṭāy": ['cae'],
    "raṭaraṭāya": ['ddsa', 'mw'],
    "raṭaṃtī": ['ap90'],
    "raṭh": ['ap90', 'mw'],
    "raṭita": ['cae', 'ddsa', 'mw'],
    "raṭitaṃ": ['ap90'],
    "raṭṭha": ['cped'],
    "raṭṭhapiṇḍa": ['cped'],
    "raṭṭhavāsika": ['cped'],
    "raṭṭhavāsī": ['cped'],
    "raṭṭhika": ['cped'],
    "raṭṭā": ['ddsa', 'mw'],
    "re": ['ap90', 'cae', 'ddsa', 'mw'],
    "reb": ['ap90', 'mw'],
    "rebh": ['ap90', 'gra', 'mw'],
    "rebha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rebhasūnu": ['mw'],
    "rebhaṇa": ['mw'],
    "rebhaṇaṃ": ['ap90'],
    "rebhaṭi": ['mw'],
    "rebhila": ['cae', 'mw'],
    "rebhilaka": ['cae', 'mw'],
    "rebhin": ['cae', 'ddsa', 'mw'],
    "rebhā": ['mw'],
    "rebhāya": ['ddsa', 'mw'],
    "reca": ['ap90', 'cae', 'mw'],
    "recaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "recakita": ['mw'],
    "recana": ['cped', 'mw'],
    "recanaka": ['mw'],
    "recanaṃ": ['ap90'],
    "recanī": ['mw'],
    "recin": ['mw'],
    "recita": ['ap90', 'mw'],
    "recitā": ['mw'],
    "recya": ['mw'],
    "redhaka": ['ddsa', 'mw'],
    "rehat": ['mw'],
    "rehāya": ['mw'],
    "rej": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "reja": ['mw'],
    "rek": ['ap90', 'mw'],
    "reka": ['ddsa', 'mw'],
    "rekaḥ": ['ap90'],
    "rekaṇas": ['ap90'],
    "rekha": ['mw'],
    "rekhaka": ['mw'],
    "rekhin": ['mw'],
    "rekhā": ['ap90', 'cae', 'ddsa', 'mw'],
    "rekhāgaṇita": ['mw'],
    "rekhāgaṇitakṣetravyavahāra": ['mw'],
    "rekhājātakasudhākara": ['mw'],
    "rekhākāra": ['mw'],
    "rekhāmātram": ['mw'],
    "rekhāntara": ['mw'],
    "rekhānyāsa": ['cae', 'mw'],
    "rekhāpradīpa": ['mw'],
    "rekhāpratīti": ['mw'],
    "rekhāya": ['mw'],
    "rekhāyani": ['mw'],
    "rekhāyate": ['ap90'],
    "rekhāṃśa": ['mw'],
    "rekhīkṛ": ['ddsa'],
    "reku": ['cae', 'ddsa', 'gra', 'mw'],
    "rekṇas": ['ap90', 'cae', 'gra', 'mw'],
    "rekṇasvant": ['cae'],
    "rekṇasvat": ['gra', 'mw'],
    "rel̤": ['mw'],
    "remi": ['mw'],
    "rep": ['ap90', 'mw'],
    "repa": ['ap90', 'mw'],
    "repas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "repha": ['ap90', 'cae', 'ddsa', 'mw'],
    "rephalakāropānta": ['mw'],
    "rephas": ['ap90', 'mw'],
    "rephasaṃdhi": ['mw'],
    "rephavat": ['mw'],
    "rephavipulā": ['mw'],
    "rephin": ['mw'],
    "rephāya": ['mw'],
    "reriha": ['cae', 'mw'],
    "rerihat": ['mw'],
    "rerihya": ['ddsa'],
    "rerihāṇa": ['mw'],
    "rerihāṇaḥ": ['ap90'],
    "rerivan": ['mw'],
    "reta": ['cae', 'mw'],
    "retaja": ['cae', 'mw'],
    "retana": ['mw'],
    "retanaṃ": ['ap90'],
    "retas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "retasa": ['mw'],
    "retasvant": ['cae'],
    "retasvat": ['mw'],
    "retasvin": ['cae', 'mw'],
    "retasya": ['cae', 'ddsa', 'mw'],
    "retasyā": ['mw'],
    "retaḥ": ['mw'],
    "retaḥkulyā": ['mw'],
    "retaḥpāta": ['ddsa', 'mw'],
    "retaḥpātin": ['mw'],
    "retaḥpīta": ['mw'],
    "retaḥseka": ['mw'],
    "retaḥsektṛ": ['mw'],
    "retaḥsic": ['mw'],
    "retaḥsicya": ['cae', 'ddsa', 'mw'],
    "retaḥskandana": ['cae', 'mw'],
    "retaḥskhalana": ['cae', 'mw'],
    "retaṃ": ['ap90'],
    "retin": ['cae', 'gra', 'mw'],
    "reto": ['mw'],
    "retodhas": ['cae', 'ddsa', 'mw'],
    "retodheya": ['mw'],
    "retodhā": ['cae', 'gra', 'mw'],
    "retoka": ['mw'],
    "retomārga": ['mw'],
    "retovaha": ['mw'],
    "retovasikta": ['mw'],
    "retra": ['mw'],
    "retraṃ": ['ap90'],
    "retya": ['mw'],
    "retyaṃ": ['ap90'],
    "reui": ['mw'],
    "rev": ['ap90', 'mw'],
    "reva": ['cae', 'mw'],
    "revant": ['cae'],
    "revanta": ['ddsa', 'mw'],
    "revantamanusū": ['mw'],
    "revantottara": ['mw'],
    "revat": ['ddsa', 'gra', 'mw'],
    "revata": ['bhs', 'mw'],
    "revataka": ['bhs', 'mw'],
    "revataḥ": ['ap90'],
    "revati": ['mw'],
    "revatiputra": ['mw'],
    "revatottara": ['mw'],
    "revatya": ['mw'],
    "revatī": ['ap90', 'bhs', 'mw'],
    "revatībhava": ['mw'],
    "revatīdvīpa": ['mw'],
    "revatīgraha": ['bhs', 'mw'],
    "revatīhālānta": ['mw'],
    "revatīkānta": ['mw'],
    "revatīpṛṣṭha": ['mw'],
    "revatīramaṇa": ['mw'],
    "revatīsuta": ['mw'],
    "revatītantra": ['mw'],
    "revatīśa": ['mw'],
    "revaṇa": ['mw'],
    "revaṭa": ['mw'],
    "revaṭaḥ": ['ap90'],
    "revottaras": ['mw'],
    "revā": ['ap90', 'ddsa', 'mw'],
    "revākhaṇḍa": ['mw'],
    "revāmāhātmya": ['mw'],
    "reśaya": ['mw'],
    "reśayadārin": ['mw'],
    "reśī": ['cae', 'mw'],
    "reḍ": ['mw'],
    "reṇu": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "reṇudīkṣita": ['mw'],
    "reṇugarbha": ['mw'],
    "reṇuguṇṭhita": ['cae', 'mw'],
    "reṇujāla": ['mw'],
    "reṇuka": ['mw'],
    "reṇukadambaka": ['mw'],
    "reṇukakāṭa": ['gra', 'mw'],
    "reṇukā": ['ap90', 'mw'],
    "reṇukācārya": ['mw'],
    "reṇukākavaca": ['mw'],
    "reṇukāmāhātmya": ['mw'],
    "reṇukāmālāmantra": ['mw'],
    "reṇukārikā": ['mw'],
    "reṇukāsahasranāman": ['mw'],
    "reṇukāstotra": ['mw'],
    "reṇukāsuta": ['mw'],
    "reṇukātanaya": ['mw'],
    "reṇukātanayatā": ['mw'],
    "reṇukātīrtha": ['mw'],
    "reṇukāṣṭaka": ['mw'],
    "reṇulakṣman": ['mw'],
    "reṇumat": ['mw'],
    "reṇupa": ['mw'],
    "reṇupadavī": ['mw'],
    "reṇupālaka": ['mw'],
    "reṇurūṣita": ['mw'],
    "reṇusahasra": ['mw'],
    "reṇusāra": ['mw'],
    "reṇusāraka": ['mw'],
    "reṇutva": ['ddsa', 'mw'],
    "reṇuvāsa": ['mw'],
    "reṇuśas": ['mw'],
    "reṇuḥ": ['ap90'],
    "reṇā": ['mw'],
    "reṇūtpāta": ['mw'],
    "reṣ": ['ap90', 'mw'],
    "reṣa": ['cae', 'mw'],
    "reṣaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "reṣaṇaṃ": ['ap90'],
    "reṣin": ['cae', 'mw'],
    "reṣita": ['mw'],
    "reṣma": ['mw'],
    "reṣmachinna": ['mw'],
    "reṣmamathita": ['mw'],
    "reṣman": ['cae', 'mw'],
    "reṣmaṇya": ['mw'],
    "reṣmya": ['mw'],
    "reṣā": ['mw'],
    "reṣṭṛ": ['mw'],
    "reṭ": ['ap90', 'mw'],
    "reṭi": ['mw'],
    "reṭṭamata": ['mw'],
    "ri": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ribh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ribhvan": ['ap90', 'mw'],
    "ric": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ricchaṭā": ['bhs'],
    "riddha": ['mw'],
    "riddhi": ['bhs'],
    "ridhama": ['mw'],
    "ridhamaḥ": ['ap90'],
    "ridhyate": ['bhs'],
    "rigiti": ['bhs'],
    "rih": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "riham": ['mw'],
    "rihāyas": ['ap90', 'mw'],
    "rij": ['ap90', 'mw'],
    "rikh": ['cae', 'ddsa', 'gra', 'mw'],
    "rikta": ['ap90', 'cae', 'ddsa', 'mw'],
    "riktabhaṇḍa": ['mw'],
    "riktaguru": ['mw'],
    "riktahasta": ['cae', 'mw'],
    "riktahāra": ['mw'],
    "riktaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "riktakumbha": ['mw'],
    "riktakṛt": ['mw'],
    "riktamati": ['mw'],
    "riktamuṣṭi": ['bhs'],
    "riktapāṇi": ['cae', 'mw'],
    "riktatā": ['mw'],
    "riktha": ['cae', 'ddsa', 'gra', 'mw'],
    "rikthabhaj": ['cae'],
    "rikthabhāgin": ['cae', 'mw'],
    "rikthabhāj": ['mw'],
    "rikthagrāha": ['cae', 'mw'],
    "rikthahara": ['cae', 'mw'],
    "rikthahāra": ['mw'],
    "rikthahārin": ['mw'],
    "rikthajāta": ['mw'],
    "rikthavibhāga": ['mw'],
    "rikthaṃ": ['ap90'],
    "rikthin": ['ap90', 'cae', 'ddsa', 'mw'],
    "rikthāda": ['cae', 'mw'],
    "rikthīya": ['mw'],
    "riktā": ['ap90', 'mw'],
    "riktārka": ['mw'],
    "riktī": ['mw'],
    "riktīkṛ": ['ddsa', 'mw'],
    "riktīkṛtahṛdaya": ['mw'],
    "rikvan": ['ap90', 'mw'],
    "rikṇas": ['mw'],
    "rikṣa": ['bhs'],
    "rikṣā": ['ap90', 'mw'],
    "rilhaṇa": ['mw'],
    "rimb": ['mw'],
    "rimeda": ['mw'],
    "rimph": ['mw'],
    "rimpha": ['mw'],
    "rip": ['cae', 'ddsa', 'gra', 'mw'],
    "riph": ['ap90', 'cae', 'ddsa', 'mw'],
    "riphita": ['mw'],
    "ripra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ripravāha": ['cae', 'gra', 'mw'],
    "ripsu": ['mw'],
    "ripta": ['mw'],
    "riptalepa": ['mw'],
    "ripu": ['cae', 'ddsa', 'gra', 'mw'],
    "ripubala": ['mw'],
    "ripubhavana": ['mw'],
    "ripubhaya": ['mw'],
    "ripubhāva": ['mw'],
    "ripughna": ['mw'],
    "ripughātin": ['mw'],
    "ripughātinī": ['mw'],
    "ripuhaṇa": ['mw'],
    "ripukāla": ['mw'],
    "ripumalla": ['mw'],
    "ripumardin": ['mw'],
    "ripunipātin": ['mw'],
    "ripupakṣa": ['mw'],
    "ripurakta": ['mw'],
    "ripurakṣin": ['mw'],
    "ripurākṣasa": ['mw'],
    "ripurāśi": ['mw'],
    "ripusthāna": ['mw'],
    "ripusūdana": ['mw'],
    "riputā": ['mw'],
    "ripuvarjita": ['mw'],
    "ripuvaśa": ['mw'],
    "ripuvaśatva": ['mw'],
    "ripuḥ": ['ap90'],
    "ripuṃjaya": ['cae', 'mw'],
    "rirakṣiṣu": ['cae', 'mw'],
    "rirakṣiṣā": ['cae', 'ddsa', 'mw'],
    "rirakṣā": ['cae'],
    "riramayiṣu": ['mw'],
    "riraṃsu": ['mw'],
    "riraṃsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "riricyām": ['ddsa'],
    "riricāna": ['mw'],
    "ririkvas": ['mw'],
    "ririkṣat": ['ap90'],
    "ririkṣu": ['cae', 'gra', 'mw'],
    "rirī": ['ap90', 'mw'],
    "rissu": ['mw'],
    "rit": ['cae', 'gra', 'mw'],
    "ritakvan": ['mw'],
    "ritta": ['cped'],
    "rittahattha": ['cped'],
    "rittamuṭṭhi": ['cped'],
    "ritu": ['bhs'],
    "ritīyate": ['bhs'],
    "rivaka": ['mw'],
    "riya": ['mw'],
    "riñcamāna": ['cped'],
    "riñcana": ['bhs'],
    "riñcati": ['bhs', 'cped'],
    "riñci": ['cped'],
    "riñcitvā": ['cped'],
    "riś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "riśa": ['gra', 'mw'],
    "riśaḥ": ['ap90'],
    "riśya": ['cae', 'mw'],
    "riśyapad": ['mw'],
    "riśyaḥ": ['ap90'],
    "riśā": ['cae', 'mw'],
    "riśādas": ['cae', 'ddsa', 'gra', 'mw'],
    "riḥpha": ['mw'],
    "riṃgitaṃ": ['ap90'],
    "riṃgiḥ": ['ap90'],
    "riṃkh": ['ap90'],
    "riṃkhaṇaṃ": ['ap90'],
    "riṃkhā": ['ap90'],
    "riṃph": ['ap90'],
    "riṃpha": ['ap90'],
    "riṅg": ['ddsa', 'mw'],
    "riṅgaṇa": ['cae', 'mw'],
    "riṅgaṇī": ['mw'],
    "riṅgi": ['cae', 'ddsa', 'mw'],
    "riṅgin": ['cae', 'mw'],
    "riṅgita": ['mw'],
    "riṅkh": ['cae', 'ddsa', 'mw'],
    "riṅkha": ['mw'],
    "riṅkhaṇa": ['cae', 'ddsa', 'mw'],
    "riṅkhola": ['mw'],
    "riṅkholana": ['mw'],
    "riṅkhā": ['ddsa', 'mw'],
    "riṇv": ['mw'],
    "riṇīnagara": ['mw'],
    "riṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "riṣa": ['ap90', 'mw'],
    "riṣaṇaya": ['mw'],
    "riṣaṇy": ['cae', 'gra'],
    "riṣaṇya": ['ddsa', 'gra', 'mw'],
    "riṣaṇyati": ['ap90'],
    "riṣaṇyu": ['cae', 'gra', 'mw'],
    "riṣi": ['bhs', 'mw'],
    "riṣidatta": ['bhs'],
    "riṣpha": ['mw'],
    "riṣva": ['ap90', 'mw'],
    "riṣya": ['mw'],
    "riṣyamūka": ['mw'],
    "riṣyaḥ": ['ap90'],
    "riṣīka": ['mw'],
    "riṣīkara": ['mw'],
    "riṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "riṣṭadeha": ['mw'],
    "riṣṭaka": ['mw'],
    "riṣṭanavanīta": ['mw'],
    "riṣṭasamuccayaśāstra": ['mw'],
    "riṣṭatāti": ['mw'],
    "riṣṭi": ['cae', 'ddsa', 'mw'],
    "riṣṭiḥ": ['ap90'],
    "riṣṭā": ['mw'],
    "riṣṭīya": ['mw'],
    "riṭi": ['mw'],
    "riṭiḥ": ['ap90'],
    "roc": ['mw'],
    "roca": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "rocaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "rocakin": ['cae', 'mw'],
    "rocama": ['bhs'],
    "rocamāna": ['ap90', 'bhs', 'ddsa', 'mw'],
    "rocamānā": ['bhs', 'mw'],
    "rocana": ['ap90', 'cae', 'cped', 'gra', 'mw'],
    "rocanaka": ['mw'],
    "rocanakaḥ": ['ap90'],
    "rocanaphala": ['mw'],
    "rocanaphalā": ['mw'],
    "rocanapiśācakā": ['bhs'],
    "rocanastha": ['gra'],
    "rocanasthā": ['mw'],
    "rocaneya": ['bhs'],
    "rocanikā": ['mw'],
    "rocanā": ['ap90', 'mw'],
    "rocanāmukha": ['mw'],
    "rocanāvant": ['cae'],
    "rocanāvat": ['mw'],
    "rocanī": ['ap90', 'bhs', 'mw'],
    "rocas": ['cae', 'mw'],
    "rocati": ['cped'],
    "rocayati": ['bhs'],
    "rocesi": ['cped'],
    "roceti": ['cped'],
    "rocetvā": ['cped'],
    "roci": ['cped', 'mw'],
    "rocin": ['mw'],
    "rocis": ['ap90', 'cae', 'gra', 'mw'],
    "rocita": ['cped'],
    "rociṣa": ['mw'],
    "rociṣmant": ['cae'],
    "rociṣmat": ['mw'],
    "rociṣṇu": ['ap90', 'cae', 'ddsa', 'mw'],
    "rociṣṇumukha": ['mw'],
    "rocuka": ['cae', 'mw'],
    "rocya": ['mw'],
    "rocī": ['mw'],
    "roda": ['cae', 'mw'],
    "rodamāna": ['cped'],
    "rodana": ['cae', 'cped', 'ddsa', 'mw'],
    "rodanaṃ": ['ap90'],
    "rodanikā": ['mw'],
    "rodanta": ['cped'],
    "rodantaka": ['bhs'],
    "rodanī": ['mw'],
    "rodara": ['ddsa', 'mw'],
    "rodas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rodasiprā": ['gra', 'mw'],
    "rodastva": ['mw'],
    "rodasī": ['cae', 'ddsa', 'gra', 'mw'],
    "rodati": ['cped'],
    "rodaḥ": ['mw'],
    "rodaḥkandarakuhara": ['mw'],
    "rodaḥkuhara": ['mw'],
    "roddhavya": ['cae', 'ddsa', 'mw'],
    "roddhos": ['mw'],
    "roddhṛ": ['cae', 'mw'],
    "rodha": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rodhacakra": ['ddsa', 'gra', 'mw'],
    "rodhaka": ['ap90', 'cae', 'mw'],
    "rodhakṛt": ['mw'],
    "rodhana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rodhanaḥ": ['ap90'],
    "rodhanā": ['mw'],
    "rodhas": ['ap90', 'cae', 'gra', 'mw'],
    "rodhastha": ['mw'],
    "rodhasvant": ['cae'],
    "rodhasvat": ['gra', 'mw'],
    "rodhasvatī": ['mw'],
    "rodhavakrā": ['mw'],
    "rodhavedī": ['mw'],
    "rodhaḥ": ['ap90', 'mw'],
    "rodhaḥpatanakaluṣa": ['mw'],
    "rodhaḥstha": ['mw'],
    "rodhin": ['ap90', 'cae', 'mw'],
    "rodho": ['mw'],
    "rodhobhū": ['ddsa', 'mw'],
    "rodhovakrā": ['mw'],
    "rodhovapra": ['mw'],
    "rodhovatī": ['mw'],
    "rodhra": ['cae', 'ddsa', 'mw'],
    "rodhrapuṣpa": ['mw'],
    "rodhrapuṣpaka": ['mw'],
    "rodhrapuṣpiṇī": ['mw'],
    "rodhraśūka": ['mw'],
    "rodhraḥ": ['ap90'],
    "rodhya": ['mw'],
    "rodhāvarodha": ['mw'],
    "rodi": ['cped'],
    "rodita": ['bhs', 'cped'],
    "roditavya": ['cae', 'ddsa', 'mw'],
    "roditavyaka": ['bhs'],
    "rodituṁ": ['cped'],
    "roditvā": ['cped'],
    "rodo": ['mw'],
    "rodogṛha": ['mw'],
    "rodorandhra": ['mw'],
    "rodākā": ['mw'],
    "roga": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rogabhaya": ['mw'],
    "rogabhāj": ['mw'],
    "rogabhū": ['mw'],
    "rogada": ['mw'],
    "rogaghna": ['cae', 'mw'],
    "rogagrasta": ['mw'],
    "rogaha": ['mw'],
    "rogahan": ['cae', 'mw'],
    "rogahara": ['mw'],
    "rogahārin": ['mw'],
    "rogahārī": ['cped'],
    "rogahṛt": ['mw'],
    "rogajña": ['mw'],
    "rogajñāna": ['mw'],
    "rogalakṣaṇa": ['mw'],
    "rogamukta": ['mw'],
    "rogamurāri": ['mw'],
    "rogamūrtidānaprakaraṇa": ['mw'],
    "roganigrahaṇa": ['mw'],
    "roganirṇaya": ['mw'],
    "roganiḍḍa": ['cped'],
    "roganāśana": ['cae', 'mw'],
    "roganīḷa": ['cped'],
    "rogaprada": ['mw'],
    "rogapradīpa": ['mw'],
    "rogapreṣṭha": ['mw'],
    "rogapuṣṭa": ['mw'],
    "rogapālaka": ['mw'],
    "rogarāj": ['mw'],
    "rogarāja": ['mw'],
    "rogasambaddha": ['mw'],
    "rogasambandha": ['mw'],
    "rogasaṃghāta": ['mw'],
    "rogavairūpya": ['mw'],
    "rogaviniścaya": ['mw'],
    "rogaśama": ['mw'],
    "rogaśilpin": ['mw'],
    "rogaśilā": ['mw'],
    "rogaśreṣṭha": ['mw'],
    "rogaśāntaka": ['mw'],
    "rogaśānti": ['mw'],
    "rogaḥ": ['ap90'],
    "rogi": ['mw'],
    "rogin": ['ap90', 'cae', 'ddsa', 'mw'],
    "rogita": ['ap90', 'mw'],
    "rogitaru": ['mw'],
    "rogitā": ['mw'],
    "rogivallabha": ['mw'],
    "rogiṣṭha": ['mw'],
    "rogolbaṇatā": ['mw'],
    "rogonmādita": ['mw'],
    "rogopaśama": ['mw'],
    "rogya": ['ap90', 'mw'],
    "rogābhyāgama": ['mw'],
    "rogādhīśa": ['mw'],
    "rogāhvaya": ['mw'],
    "rogākhya": ['mw'],
    "rogāntaka": ['mw'],
    "rogāntakasāra": ['mw'],
    "rogānvita": ['mw'],
    "rogānīka": ['mw'],
    "rogānīkarāj": ['mw'],
    "rogārambha": ['mw'],
    "rogārdita": ['cae', 'mw'],
    "rogārta": ['cae', 'mw'],
    "rogātura": ['cped'],
    "rogāviṣṭa": ['cae', 'mw'],
    "rogāyatana": ['mw'],
    "rogī": ['cped'],
    "roha": ['ap90', 'cae', 'ddsa', 'mw'],
    "rohaga": ['mw'],
    "rohaka": ['bhs', 'cae', 'mw'],
    "rohakṣiti": ['mw'],
    "rohana": ['cped'],
    "rohanta": ['mw'],
    "rohantī": ['mw'],
    "rohapūrva": ['mw'],
    "rohas": ['cae', 'gra', 'mw'],
    "rohasena": ['cae', 'ddsa', 'mw'],
    "rohat": ['mw'],
    "rohati": ['bhs', 'cped'],
    "rohatparvā": ['mw'],
    "rohaśikhin": ['mw'],
    "rohaṃtaḥ": ['ap90'],
    "rohaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "rohaṇadruma": ['mw'],
    "rohaṇaparvata": ['mw'],
    "rohaṇaḥ": ['ap90'],
    "rohaṇācala": ['mw'],
    "rohaṇī": ['mw'],
    "rohaṇīya": ['bhs'],
    "rohi": ['cae', 'mw'],
    "rohidaśva": ['cae', 'ddsa', 'gra', 'mw'],
    "rohimāṃsa": ['mw'],
    "rohin": ['ap90', 'cae', 'ddsa', 'mw'],
    "rohit": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rohita": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rohitagiri": ['mw'],
    "rohitagirīya": ['mw'],
    "rohitaita": ['mw'],
    "rohitaka": ['bhs', 'mw'],
    "rohitakāraṇya": ['mw'],
    "rohitakūla": ['mw'],
    "rohitakūlīya": ['mw'],
    "rohitakūlīyottara": ['mw'],
    "rohitakūlīyādya": ['mw'],
    "rohitamaccha": ['cped'],
    "rohitamatsya": ['mw'],
    "rohitapura": ['mw'],
    "rohitarūpa": ['mw'],
    "rohitavastu": ['bhs', 'mw'],
    "rohitavat": ['mw'],
    "rohitavṛkṣa": ['mw'],
    "rohitendradhanus": ['mw'],
    "rohiteya": ['mw'],
    "rohitparvā": ['mw'],
    "rohitākṣa": ['cae', 'mw'],
    "rohitāsya": ['mw'],
    "rohitāvarta": ['bhs'],
    "rohitāyana": ['mw'],
    "rohitāñji": ['mw'],
    "rohitāśva": ['bhs', 'cae', 'mw'],
    "rohiḥ": ['ap90'],
    "rohiṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "rohiṇi": ['mw'],
    "rohiṇikā": ['ap90', 'mw'],
    "rohiṇinandana": ['mw'],
    "rohiṇiputra": ['mw'],
    "rohiṇisena": ['mw'],
    "rohiṇitva": ['mw'],
    "rohiṇiḥ": ['ap90'],
    "rohiṇiṣeṇa": ['mw'],
    "rohiṇyaṣṭamī": ['mw'],
    "rohiṇī": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "rohiṇībhava": ['mw'],
    "rohiṇīcandravrata": ['mw'],
    "rohiṇīcandraśayana": ['mw'],
    "rohiṇīkānta": ['mw'],
    "rohiṇīpati": ['mw'],
    "rohiṇīpriya": ['mw'],
    "rohiṇīramaṇa": ['mw'],
    "rohiṇīsuta": ['mw'],
    "rohiṇītanaya": ['mw'],
    "rohiṇītapas": ['mw'],
    "rohiṇītaru": ['mw'],
    "rohiṇītva": ['mw'],
    "rohiṇītīrtha": ['mw'],
    "rohiṇīvallabha": ['mw'],
    "rohiṇīvrata": ['mw'],
    "rohiṇīvratodyāpana": ['mw'],
    "rohiṇīyoga": ['mw'],
    "rohiṇīśa": ['mw'],
    "rohiṇīśakaṭa": ['mw'],
    "rohiṇīśānti": ['mw'],
    "rohiṇīṣeṇa": ['mw'],
    "rohiṣ": ['mw'],
    "rohiṣa": ['mw'],
    "rohiṣaḥ": ['ap90'],
    "rohiṣyai": ['mw'],
    "rohāya": ['mw'],
    "rohī": ['cae', 'mw'],
    "rohītaka": ['bhs', 'mw'],
    "roka": ['cae', 'ddsa', 'gra', 'mw'],
    "rokas": ['mw'],
    "rokaṃ": ['ap90'],
    "rokya": ['mw'],
    "rola": ['mw'],
    "roladeva": ['ddsa', 'mw'],
    "rolamba": ['cae', 'ddsa', 'mw'],
    "rolambakadamba": ['mw'],
    "rolambarāja": ['mw'],
    "rolambarājīya": ['mw'],
    "rolaṃbaḥ": ['ap90'],
    "rolicandrū": ['mw'],
    "rolā": ['bhs', 'mw'],
    "roma": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "romabaddha": ['mw'],
    "romabandha": ['mw'],
    "romabhū": ['mw'],
    "romabhūmi": ['mw'],
    "romagarta": ['mw'],
    "romaguccha": ['mw'],
    "romagutsa": ['mw'],
    "romaharṣa": ['cae', 'ddsa', 'mw'],
    "romaharṣaṇa": ['mw'],
    "romaharṣaṇaka": ['mw'],
    "romaharṣaṇi": ['mw'],
    "romaharṣaṇīyasūtra": ['bhs'],
    "romaharṣin": ['mw'],
    "romaharṣita": ['mw'],
    "romaharṣiṇi": ['mw'],
    "romahṛt": ['mw'],
    "romaja": ['mw'],
    "romaka": ['cae', 'cped', 'ddsa', 'mw'],
    "romakanda": ['mw'],
    "romakapattana": ['mw'],
    "romakapura": ['mw'],
    "romakarṇaka": ['mw'],
    "romakasiddhānta": ['mw'],
    "romakaviṣaya": ['mw'],
    "romakaḥ": ['ap90'],
    "romakesara": ['mw'],
    "romakācārya": ['mw'],
    "romakāyaṇa": ['mw'],
    "romakūpa": ['ddsa', 'mw'],
    "romalatikā": ['mw'],
    "romalatā": ['mw'],
    "romamūrdhan": ['mw'],
    "roman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "romantha": ['cae', 'ddsa', 'mw'],
    "romanthana": ['cped', 'mw'],
    "romanthati": ['cped'],
    "romanthayitvā": ['cped'],
    "romanthi": ['cped'],
    "romanthāya": ['ddsa', 'mw'],
    "romaphalā": ['mw'],
    "romapulaka": ['ddsa', 'mw'],
    "romapāda": ['mw'],
    "romapāta": ['bhs'],
    "romarandhra": ['mw'],
    "romarasāsāra": ['mw'],
    "romaratādhāra": ['mw'],
    "romarāji": ['cae', 'mw'],
    "romarājipatha": ['mw'],
    "romarājī": ['cae', 'mw'],
    "romasaṃvejana": ['mw'],
    "romasūcī": ['mw'],
    "romatyaj": ['mw'],
    "romavallī": ['mw'],
    "romavant": ['cae'],
    "romavat": ['mw'],
    "romavedha": ['mw'],
    "romavibheda": ['mw'],
    "romavidhvaṃsa": ['mw'],
    "romavikriyā": ['mw'],
    "romavikāra": ['mw'],
    "romavivara": ['bhs', 'mw'],
    "romavāhin": ['mw'],
    "romañca": ['cped'],
    "romaśa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "romaśaphala": ['mw'],
    "romaśapucchaka": ['mw'],
    "romaśasiddhānta": ['mw'],
    "romaśuka": ['mw'],
    "romaśā": ['mw'],
    "romaśātana": ['mw'],
    "romaśī": ['mw'],
    "romaḥ": ['ap90'],
    "romaṃthaḥ": ['ap90'],
    "romaṇvant": ['cae'],
    "romaṇvat": ['ddsa', 'gra', 'mw'],
    "rombillaveṅkaṭabudha": ['mw'],
    "romodbheda": ['cae', 'mw'],
    "romodgama": ['mw'],
    "romodgati": ['cae', 'ddsa', 'mw'],
    "romotpāta": ['mw'],
    "romā": ['bhs'],
    "romālaviṭapin": ['mw'],
    "romālu": ['mw'],
    "romāluviṭapin": ['mw'],
    "romālī": ['cae', 'mw'],
    "romānta": ['mw'],
    "romāvalī": ['cae', 'mw'],
    "romāvalīśataka": ['mw'],
    "romāñca": ['cae', 'ddsa', 'mw'],
    "romāñcakañcuka": ['mw'],
    "romāñcakin": ['mw'],
    "romāñcikā": ['mw'],
    "romāñcin": ['mw'],
    "romāñcita": ['mw'],
    "romāñcodgatarājimat": ['mw'],
    "romāśrayaphalā": ['mw'],
    "romāṅka": ['mw'],
    "romāṅkura": ['ddsa', 'mw'],
    "ropa": ['cae', 'cped', 'ddsa', 'mw'],
    "ropaka": ['cae', 'cped', 'mw'],
    "ropakaḥ": ['ap90'],
    "ropaya": ['ddsa'],
    "ropayamāna": ['cped'],
    "ropayitṛ": ['cae', 'mw'],
    "ropayiṣṇu": ['mw'],
    "ropaḥ": ['ap90'],
    "ropaṇa": ['cae', 'mw'],
    "ropaṇaṃ": ['ap90'],
    "ropaṇākā": ['ddsa', 'gra', 'mw'],
    "ropaṇīya": ['cae', 'mw'],
    "ropenta": ['cped'],
    "ropesi": ['cped'],
    "ropeti": ['cped'],
    "ropetvā": ['cped'],
    "ropi": ['cae', 'mw'],
    "ropin": ['cae', 'mw'],
    "ropita": ['ap90', 'cped', 'mw'],
    "ropiya": ['cped'],
    "ropuṣī": ['gra', 'mw'],
    "ropya": ['cae', 'mw'],
    "rora": ['cae', 'mw'],
    "roravaṇa": ['mw'],
    "roravīti": ['ddsa'],
    "rorudat": ['mw'],
    "rorudyamāna": ['mw'],
    "rorudā": ['ap90', 'mw'],
    "rorudāvat": ['mw'],
    "roruka": ['bhs', 'mw'],
    "roruva": ['cped'],
    "rorūya": ['mw'],
    "rosa": ['cped'],
    "rosaka": ['cped'],
    "rosanā": ['cped'],
    "rosaṃsā": ['mw'],
    "rosesi": ['cped'],
    "roseti": ['cped'],
    "rosetvā": ['cped'],
    "rosita": ['cped'],
    "rośaṃsā": ['mw'],
    "roḍ": ['ap90', 'mw'],
    "roḍa": ['ap90', 'mw'],
    "roḍhṛ": ['mw'],
    "roṇī": ['mw'],
    "roṇīka": ['mw'],
    "roṇīkīya": ['mw'],
    "roṣ": ['mw'],
    "roṣa": ['cae', 'ddsa', 'mw'],
    "roṣabhāj": ['mw'],
    "roṣabhāṣaṇa": ['mw'],
    "roṣadṛṣṭi": ['mw'],
    "roṣaka": ['bhs', 'mw'],
    "roṣamaya": ['mw'],
    "roṣaparīta": ['mw'],
    "roṣarūkṣa": ['mw'],
    "roṣatāmrākṣa": ['mw'],
    "roṣavāhaṇa": ['mw'],
    "roṣaḥ": ['ap90'],
    "roṣaṇa": ['ap90', 'cae', 'mw'],
    "roṣaṇatā": ['mw'],
    "roṣin": ['bhs', 'cae', 'ddsa', 'mw'],
    "roṣita": ['ap90', 'mw'],
    "roṣitar": ['bhs'],
    "roṣokti": ['mw'],
    "roṣāgni": ['cae', 'mw'],
    "roṣākulita": ['mw'],
    "roṣākṣepa": ['mw'],
    "roṣāvaroha": ['mw'],
    "roṣāṇa": ['mw'],
    "roṣṭṛ": ['cae', 'mw'],
    "roṭa": ['mw'],
    "roṭakavrata": ['mw'],
    "roṭikā": ['mw'],
    "roṭī": ['mw'],
    "ru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rubheṭi": ['mw'],
    "ruc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ruca": ['cae', 'mw'],
    "rucaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "rucay": ['cae', 'gra'],
    "ruccana": ['cped'],
    "ruccanaka": ['cped'],
    "ruccati": ['bhs', 'cped'],
    "ruccha": ['bhs'],
    "rucci": ['cped'],
    "ruccita": ['cped'],
    "ruccitvā": ['cped'],
    "ruce": ['mw'],
    "ruci": ['cae', 'cped', 'ddsa', 'mw'],
    "rucibhartṛ": ['mw'],
    "rucidatta": ['mw'],
    "rucidattabhāṣya": ['mw'],
    "rucidattīya": ['mw'],
    "rucideva": ['mw'],
    "rucidhāman": ['mw'],
    "rucika": ['bhs', 'cped', 'mw'],
    "rucikara": ['cae', 'ddsa', 'mw'],
    "rucikṛt": ['mw'],
    "rucinātha": ['mw'],
    "ruciparvan": ['mw'],
    "rucipati": ['mw'],
    "ruciphala": ['mw'],
    "ruciprabha": ['mw'],
    "ruciprada": ['mw'],
    "rucira": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "rucirabhadrayaśaṣ": ['bhs'],
    "rucirabhāṣaṇa": ['mw'],
    "ruciradeva": ['mw'],
    "ruciradhvaja": ['bhs'],
    "ruciradhī": ['mw'],
    "ruciraketu": ['bhs', 'mw'],
    "ruciramud": ['mw'],
    "ruciramūrti": ['mw'],
    "ruciraprabhāsasaṃbhava": ['bhs'],
    "ruciraprabhāvasambhava": ['mw'],
    "ruciravadana": ['mw'],
    "rucirañjana": ['mw'],
    "ruciraśrīgarbha": ['bhs', 'mw'],
    "ruciruci": ['mw'],
    "rucirā": ['bhs', 'mw'],
    "rucirānana": ['mw'],
    "rucirāpāṅgī": ['mw'],
    "rucirāsuta": ['mw'],
    "rucirātanaya": ['mw'],
    "rucirāśva": ['mw'],
    "rucisamprakḷpta": ['mw'],
    "rucistava": ['mw'],
    "rucistha": ['mw'],
    "rucita": ['ap90', 'cae', 'mw'],
    "rucitabhānu": ['bhs'],
    "rucitavat": ['ddsa', 'mw'],
    "rucitva": ['mw'],
    "rucitā": ['ddsa', 'mw'],
    "rucivadhūgalaratnamālā": ['mw'],
    "rucivaha": ['mw'],
    "ruciḥ": ['ap90'],
    "ruciṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ruciṭa": ['mw'],
    "rucu": ['mw'],
    "rucya": ['ap90', 'cae', 'mw'],
    "rucyakanda": ['mw'],
    "rucyati": ['bhs'],
    "rucyavāhana": ['mw'],
    "rucyā": ['mw'],
    "rucā": ['ap90', 'ddsa', 'mw'],
    "rucī": ['ap90', 'mw'],
    "rud": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rudammukha": ['cped'],
    "rudamāna": ['cped'],
    "rudana": ['mw'],
    "rudanaṃ": ['ap90'],
    "rudanmukha": ['bhs'],
    "rudanta": ['cped'],
    "rudantikā": ['mw'],
    "rudantī": ['mw'],
    "rudanī": ['bhs'],
    "rudara": ['gra'],
    "rudatha": ['mw'],
    "rudathaḥ": ['ap90'],
    "rudati": ['cped'],
    "ruddha": ['ap90', 'cped', 'ddsa', 'mw'],
    "ruddhadṛś": ['mw'],
    "ruddhagir": ['mw'],
    "ruddhaka": ['mw'],
    "ruddhamukha": ['mw'],
    "ruddhamūtra": ['mw'],
    "ruddhapravāha": ['mw'],
    "ruddhataṭābhimukhya": ['mw'],
    "ruddhavadana": ['mw'],
    "ruddhavaktra": ['mw'],
    "ruddhavasudha": ['mw'],
    "ruddhavīrya": ['mw'],
    "ruddhā": ['mw'],
    "ruddhāloka": ['mw'],
    "ruddhāpāṅgaprasara": ['mw'],
    "rudh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rudha": ['gra', 'mw'],
    "rudhikrā": ['gra', 'mw'],
    "rudhira": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rudhirabindu": ['mw'],
    "rudhiracarcitasarvāṅga": ['mw'],
    "rudhiralepa": ['cae', 'mw'],
    "rudhiralālasa": ['mw'],
    "rudhiramaya": ['mw'],
    "rudhiraplāvita": ['mw'],
    "rudhirapradigdha": ['mw'],
    "rudhirapāta": ['cae', 'mw'],
    "rudhirapāyin": ['mw'],
    "rudhirarūṣita": ['mw'],
    "rudhirasāra": ['mw'],
    "rudhiratāmrākṣa": ['mw'],
    "rudhiravarṣa": ['cae', 'mw'],
    "rudhirodgārin": ['mw'],
    "rudhirādhyāya": ['mw'],
    "rudhirādāna": ['mw'],
    "rudhirāhāriṇī": ['bhs'],
    "rudhirākhya": ['mw'],
    "rudhirākṣa": ['mw'],
    "rudhirāmaya": ['mw'],
    "rudhirānana": ['mw'],
    "rudhirāndha": ['mw'],
    "rudhirāvila": ['mw'],
    "rudhirāśana": ['cae', 'mw'],
    "rudi": ['cped'],
    "rudita": ['cae', 'cped', 'ddsa', 'mw'],
    "ruditvā": ['cped'],
    "rudra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rudrabali": ['mw'],
    "rudrabhairavī": ['mw'],
    "rudrabhaṭṭa": ['mw'],
    "rudrabhāṣya": ['mw'],
    "rudrabhū": ['mw'],
    "rudrabhūmi": ['mw'],
    "rudrabhūti": ['mw'],
    "rudracandra": ['mw'],
    "rudracandradeva": ['mw'],
    "rudracaṇḍika": ['mw'],
    "rudracaṇḍī": ['mw'],
    "rudracchattra": ['mw'],
    "rudradarśana": ['mw'],
    "rudradatta": ['mw'],
    "rudradattavṛtti": ['mw'],
    "rudradattīya": ['mw'],
    "rudradeva": ['bhs', 'cae', 'mw'],
    "rudradhara": ['mw'],
    "rudradhyānavarṇana": ['mw'],
    "rudradāman": ['mw'],
    "rudradānavidhi": ['mw'],
    "rudradīpikā": ['mw'],
    "rudragarbha": ['cae', 'mw'],
    "rudragaṇa": ['mw'],
    "rudragāyatri": ['mw'],
    "rudragāyatrī": ['mw'],
    "rudragīta": ['mw'],
    "rudrahavana": ['mw'],
    "rudrahimālaya": ['mw'],
    "rudrahotṛ": ['mw'],
    "rudrahāsa": ['mw'],
    "rudrahūti": ['mw'],
    "rudrahṛdaya": ['mw'],
    "rudrahṛdayopaniṣad": ['mw'],
    "rudraikādaśakamantra": ['mw'],
    "rudraikādaśavastradānavidhi": ['mw'],
    "rudraikādaśikā": ['mw'],
    "rudraikādaśinī": ['ddsa', 'mw'],
    "rudraja": ['mw'],
    "rudrajapa": ['cae', 'mw'],
    "rudrajapakalpa": ['mw'],
    "rudrajapana": ['mw'],
    "rudrajapapañcādhyāya": ['mw'],
    "rudrajapavidhi": ['mw'],
    "rudrajaṭā": ['mw'],
    "rudrajābālopaniṣad": ['mw'],
    "rudrajāpaka": ['cae', 'mw'],
    "rudrajāpaviniyoga": ['mw'],
    "rudrajāpin": ['cae', 'mw'],
    "rudrajāpya": ['mw'],
    "rudraka": ['mw'],
    "rudrakalaśa": ['mw'],
    "rudrakalaśasnānavidhi": ['mw'],
    "rudrakalpa": ['mw'],
    "rudrakalpadruma": ['mw'],
    "rudrakalpataru": ['mw'],
    "rudrakarāmaputra": ['bhs'],
    "rudrakavaca": ['mw'],
    "rudrakavacastotra": ['mw'],
    "rudrakavīndra": ['mw'],
    "rudrakośa": ['mw'],
    "rudrakoṭi": ['mw'],
    "rudrakoṭimāhātmya": ['mw'],
    "rudrakumāra": ['mw'],
    "rudrakālī": ['mw'],
    "rudrakāṭi": ['mw'],
    "rudralatā": ['mw'],
    "rudraloka": ['mw'],
    "rudramahādevī": ['mw'],
    "rudramahānyāsa": ['mw'],
    "rudramantra": ['mw'],
    "rudramantravibhāga": ['mw'],
    "rudramaya": ['mw'],
    "rudramaṇi": ['mw'],
    "rudranandin": ['mw'],
    "rudranirmālya": ['mw'],
    "rudranyāsa": ['mw'],
    "rudranyāyavācaspatibhaṭṭācārya": ['mw'],
    "rudranārāyaṇa": ['mw'],
    "rudranātha": ['mw'],
    "rudrapaddhati": ['mw'],
    "rudrapatnī": ['mw'],
    "rudrapañcāṅganyāsa": ['mw'],
    "rudrapaṇḍita": ['mw'],
    "rudrapradīpa": ['mw'],
    "rudrapratiṣṭhā": ['mw'],
    "rudrapratāpa": ['mw'],
    "rudraprayāga": ['mw'],
    "rudrapraśna": ['mw'],
    "rudrapriyā": ['mw'],
    "rudrapura": ['mw'],
    "rudrapurāṇa": ['mw'],
    "rudraputra": ['mw'],
    "rudrapuṣpa": ['mw'],
    "rudrapādamahiman": ['mw'],
    "rudrapāla": ['mw'],
    "rudrapāṭha": ['mw'],
    "rudrapūjana": ['mw'],
    "rudrapūjā": ['mw'],
    "rudrarodana": ['mw'],
    "rudraroman": ['mw'],
    "rudrarāya": ['mw'],
    "rudrarāśi": ['mw'],
    "rudrasahasranāman": ['mw'],
    "rudrasakha": ['mw'],
    "rudrasammita": ['mw'],
    "rudrasampradāyin": ['mw'],
    "rudrasaras": ['mw'],
    "rudrasarga": ['mw'],
    "rudrasaṃhitā": ['mw'],
    "rudrasena": ['mw'],
    "rudrasenā": ['mw'],
    "rudrasiṃha": ['mw'],
    "rudraskanda": ['mw'],
    "rudraskandasvāmin": ['mw'],
    "rudrasnānavidhi": ['mw'],
    "rudrasoma": ['cae', 'mw'],
    "rudrasomā": ['mw'],
    "rudrasundarī": ['mw'],
    "rudrasuta": ['mw'],
    "rudrasvarga": ['mw'],
    "rudrasvāmin": ['mw'],
    "rudrasāman": ['mw'],
    "rudrasāvarṇi": ['mw'],
    "rudrasāvarṇika": ['mw'],
    "rudrasāvitrī": ['mw'],
    "rudrasīha": ['mw'],
    "rudrasū": ['mw'],
    "rudrasūkta": ['mw'],
    "rudrasūktajapa": ['mw'],
    "rudrasūri": ['mw'],
    "rudrasūtra": ['mw'],
    "rudrasṛṣṭi": ['mw'],
    "rudratanaya": ['mw'],
    "rudratripāṭhin": ['mw'],
    "rudratriśatī": ['mw'],
    "rudratva": ['mw'],
    "rudravadgaṇa": ['mw'],
    "rudravant": ['cae'],
    "rudravartani": ['cae', 'gra', 'mw'],
    "rudravat": ['mw'],
    "rudravaṭa": ['mw'],
    "rudravidhi": ['mw'],
    "rudravidhāna": ['mw'],
    "rudravidhānapaddhati": ['mw'],
    "rudraviṃśati": ['mw'],
    "rudravrata": ['mw'],
    "rudravratin": ['mw'],
    "rudravīṇā": ['mw'],
    "rudrayajña": ['cae', 'mw'],
    "rudrayāmala": ['mw'],
    "rudrayāmalatantra": ['mw'],
    "rudrayāmalādisaṃgraha": ['mw'],
    "rudrayāmalīyacikitsā": ['mw'],
    "rudrayāmila": ['mw'],
    "rudraśarman": ['cae', 'mw'],
    "rudraḍamarūdbhavasūtravivaraṇa": ['mw'],
    "rudraṛṅmantradhyāna": ['mw'],
    "rudraṭa": ['mw'],
    "rudriya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rudropaniṣad": ['mw'],
    "rudropastha": ['mw'],
    "rudrā": ['mw'],
    "rudrābhiṣeka": ['mw'],
    "rudrābhiṣekavidhi": ['mw'],
    "rudrācārya": ['mw'],
    "rudrādhyāya": ['mw'],
    "rudrādhyāyaṭīkā": ['mw'],
    "rudrādhyāyin": ['mw'],
    "rudrāgni": ['mw'],
    "rudrāhva": ['mw'],
    "rudrākrīḍa": ['ddsa', 'mw'],
    "rudrākṣa": ['mw'],
    "rudrākṣadhāraṇa": ['mw'],
    "rudrākṣakalpa": ['mw'],
    "rudrākṣamāhātmya": ['mw'],
    "rudrākṣamāhātmyavarṇana": ['mw'],
    "rudrākṣamālikā": ['mw'],
    "rudrākṣamālā": ['mw'],
    "rudrākṣaparīkṣā": ['mw'],
    "rudrākṣavalaya": ['mw'],
    "rudrākṣopaniṣad": ['mw'],
    "rudrāmbā": ['mw'],
    "rudrānuja": ['mw'],
    "rudrānuṣṭhānapaddhati": ['mw'],
    "rudrārcanacandrikā": ['mw'],
    "rudrāri": ['mw'],
    "rudrātharvaṇaśīrṣopaniṣad": ['mw'],
    "rudrāvarta": ['mw'],
    "rudrāvasṛṣṭa": ['mw'],
    "rudrāvāsa": ['mw'],
    "rudrāyatana": ['mw'],
    "rudrāyaṇa": ['bhs', 'mw'],
    "rudrāśva": ['mw'],
    "rudrāṅkuśa": ['mw'],
    "rudrāṇī": ['ap90', 'cae', 'ddsa', 'mw'],
    "rudrī": ['mw'],
    "rudrīya": ['mw'],
    "rug": ['mw'],
    "ruganvita": ['cae', 'ddsa', 'mw'],
    "rugbhaya": ['mw'],
    "rugbheṣaja": ['mw'],
    "rugdāha": ['mw'],
    "rugma": ['bhs'],
    "rugviniścaya": ['mw'],
    "rugārta": ['cae', 'mw'],
    "rugṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "rugṇaraya": ['mw'],
    "rugṇatva": ['mw'],
    "rugṇatā": ['mw'],
    "ruh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ruha": ['cae', 'cped', 'ddsa', 'mw'],
    "ruhaka": ['mw'],
    "ruhakaṃ": ['ap90'],
    "ruhana": ['cped'],
    "ruharuhikā": ['mw'],
    "ruhira": ['cped'],
    "ruhiruhikā": ['mw'],
    "ruhvan": ['ap90', 'mw'],
    "ruhā": ['ap90', 'mw'],
    "ruj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ruja": ['cae', 'mw'],
    "rujana": ['cped'],
    "rujanaka": ['cped'],
    "rujaskara": ['cae', 'mw'],
    "rujati": ['cped'],
    "ruji": ['cped'],
    "rujitvā": ['cped'],
    "rujjhati": ['cped'],
    "rujjhi": ['cped'],
    "rujā": ['cped', 'ddsa', 'mw'],
    "rujākara": ['cae', 'mw'],
    "rujānā": ['gra', 'mw'],
    "rujāpaha": ['mw'],
    "rujāsaha": ['mw'],
    "rujāvat": ['mw'],
    "rujāvin": ['mw'],
    "rujāy": ['cae'],
    "rujāya": ['mw'],
    "rujāyate": ['ap90'],
    "ruk": ['mw'],
    "ruka": ['ap90', 'mw'],
    "rukkeśa": ['mw'],
    "rukkha": ['cped'],
    "rukkhadevatā": ['cped'],
    "rukkhagahaṇa": ['cped'],
    "rukkhamūla": ['cped'],
    "rukkhamūlika": ['cped'],
    "rukkhasusira": ['cped'],
    "rukkāma": ['mw'],
    "rukma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rukmabāhu": ['mw'],
    "rukmadhara": ['mw'],
    "rukmakavaca": ['mw'],
    "rukmakeśa": ['mw'],
    "rukmakāraka": ['mw'],
    "rukmala": ['mw'],
    "rukmalalāṭa": ['mw'],
    "rukmalauha": ['mw'],
    "rukmaloha": ['mw'],
    "rukmamaya": ['cae', 'mw'],
    "rukmamālin": ['mw'],
    "rukmant": ['cae'],
    "rukmapattra": ['mw'],
    "rukmaprastaraṇa": ['mw'],
    "rukmapura": ['mw'],
    "rukmapuruṣa": ['mw'],
    "rukmapuṅkha": ['cae', 'mw'],
    "rukmapāśa": ['cae', 'mw'],
    "rukmapṛṣṭha": ['cae', 'mw'],
    "rukmaratha": ['cae', 'mw'],
    "rukmasteya": ['cae', 'mw'],
    "rukmat": ['gra', 'mw'],
    "rukmavakṣas": ['cae', 'gra', 'mw'],
    "rukmavat": ['mw'],
    "rukmavatī": ['mw'],
    "rukmavāhana": ['mw'],
    "rukmeṣu": ['mw'],
    "rukmi": ['mw'],
    "rukmibhid": ['mw'],
    "rukmidarpa": ['mw'],
    "rukmidāraṇa": ['mw'],
    "rukmidārin": ['mw'],
    "rukmin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rukmiśāsana": ['mw'],
    "rukmiṇinandana": ['mw'],
    "rukmiṇī": ['ap90', 'ddsa', 'mw'],
    "rukmiṇīcampū": ['mw'],
    "rukmiṇīharaṇa": ['mw'],
    "rukmiṇīhrada": ['mw'],
    "rukmiṇīkalyāṇa": ['mw'],
    "rukmiṇīkṛṣṇavallī": ['mw'],
    "rukmiṇīnāṭaka": ['mw'],
    "rukmiṇīpariṇaya": ['mw'],
    "rukmiṇīsvayaṃvara": ['mw'],
    "rukmiṇītīrtha": ['mw'],
    "rukmiṇīvrata": ['mw'],
    "rukmiṇīśa": ['cae', 'mw'],
    "rukmiṇīśavijaya": ['mw'],
    "rukmābha": ['cae', 'mw'],
    "rukmāṅgada": ['mw'],
    "rukmāṅgadacarita": ['mw'],
    "rukmāṅgadacaritra": ['mw'],
    "rukmāṅgadīya": ['mw'],
    "rukpratikriyā": ['mw'],
    "ruksadman": ['mw'],
    "rukṣa": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "rukṣma": ['ddsa'],
    "ruma": ['cae', 'gra', 'mw'],
    "rumaṇa": ['mw'],
    "rumaṇvant": ['cae'],
    "rumaṇvat": ['ddsa', 'mw'],
    "rumhaniya": ['cped'],
    "rumra": ['ap90', 'mw'],
    "rumā": ['ap90', 'mw'],
    "rumābhava": ['mw'],
    "rundh": ['ddsa', 'mw'],
    "rundhana": ['bhs', 'cped'],
    "rundhati": ['cped'],
    "rundhi": ['cped'],
    "rundhita": ['cped'],
    "rundhitvā": ['cped'],
    "rundhīyati": ['cped'],
    "rundra": ['mw'],
    "rup": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rupa": ['bhs', 'mw'],
    "rupita": ['mw'],
    "ruppamāna": ['cped'],
    "ruppana": ['cped'],
    "ruppati": ['cped'],
    "ruppi": ['cped'],
    "rupyaka": ['mw'],
    "ruru": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rurubha": ['bhs'],
    "rurubhairava": ['mw'],
    "rurudiṣu": ['cae', 'mw'],
    "rurudiṣā": ['cae', 'ddsa', 'mw'],
    "ruruka": ['cae', 'mw'],
    "rurukvas": ['mw'],
    "rurukṣaṇi": ['cae', 'gra', 'mw'],
    "rurumuṇḍa": ['bhs', 'mw'],
    "rurunakhadhārin": ['mw'],
    "rurupṛṣata": ['mw'],
    "rurutsu": ['cae', 'ddsa', 'mw'],
    "rurutsā": ['mw'],
    "ruruvidāriṇī": ['ddsa', 'mw'],
    "ruruśīrṣan": ['gra', 'mw'],
    "ruruḥ": ['ap90'],
    "ruta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "rutajña": ['cae', 'mw'],
    "rutavettṛ": ['cae', 'mw'],
    "rutavyāja": ['mw'],
    "rutha": ['mw'],
    "rutā": ['bhs'],
    "rutābhijña": ['mw'],
    "rutāvatī": ['bhs'],
    "rutāvin": ['bhs'],
    "rutāyata": ['mw'],
    "ruvatha": ['cae', 'mw'],
    "ruvaṇy": ['cae', 'gra'],
    "ruvaṇya": ['ddsa', 'mw'],
    "ruvaṇyu": ['cae', 'gra', 'mw'],
    "ruvu": ['mw'],
    "ruvuka": ['mw'],
    "ruvuḥ": ['ap90'],
    "ruvūka": ['mw'],
    "ruyyaka": ['mw'],
    "ruś": ['ap90', 'ddsa', 'gra', 'mw'],
    "ruśad": ['mw'],
    "ruśadgo": ['gra'],
    "ruśadgu": ['cae', 'mw'],
    "ruśadratha": ['mw'],
    "ruśadvatsa": ['cae', 'gra', 'mw'],
    "ruśadūrmi": ['cae', 'gra', 'mw'],
    "ruśama": ['gra', 'mw'],
    "ruśamā": ['mw'],
    "ruśant": ['cae'],
    "ruśanā": ['mw'],
    "ruśat": ['ap90', 'ddsa', 'gra', 'mw'],
    "ruśatpaśu": ['cae', 'gra', 'mw'],
    "ruśaṅgu": ['mw'],
    "ruśeku": ['mw'],
    "ruḥ": ['ap90'],
    "ruṃś": ['mw'],
    "ruṃḍa": ['ap90'],
    "ruṃḍikā": ['ap90'],
    "ruṃṣ": ['cae', 'ddsa', 'mw'],
    "ruṃṣita": ['mw'],
    "ruṃṭ": ['ap90'],
    "ruṃṭh": ['ap90'],
    "ruṅ": ['mw'],
    "ruṅmat": ['mw'],
    "ruṅmatī": ['mw'],
    "ruṅnivartana": ['mw'],
    "ruṇaskarā": ['ap90', 'mw'],
    "ruṇā": ['mw'],
    "ruṇḍ": ['mw'],
    "ruṇḍa": ['bhs', 'cae', 'ddsa', 'mw'],
    "ruṇḍaka": ['mw'],
    "ruṇḍikā": ['mw'],
    "ruṇṇa": ['bhs', 'cped'],
    "ruṇṭ": ['mw'],
    "ruṇṭh": ['mw'],
    "ruṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ruṣad": ['mw'],
    "ruṣadgu": ['mw'],
    "ruṣadratha": ['mw'],
    "ruṣat": ['mw'],
    "ruṣaṅgu": ['mw'],
    "ruṣita": ['ap90', 'cae', 'mw'],
    "ruṣya": ['bhs', 'mw'],
    "ruṣyamat": ['mw'],
    "ruṣā": ['cae', 'mw'],
    "ruṣānvita": ['mw'],
    "ruṣṭa": ['cae', 'mw'],
    "ruṣṭi": ['mw'],
    "ruṣṭimat": ['mw'],
    "ruṣṭiḥ": ['ap90'],
    "ruṭ": ['ap90', 'mw'],
    "ruṭh": ['ap90', 'mw'],
    "ruṭṭha": ['cped'],
    "rā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rābhasika": ['mw'],
    "rābhasikatā": ['mw'],
    "rābhasya": ['mw'],
    "rābhasyaṃ": ['ap90'],
    "rācita": ['mw'],
    "rācitāyana": ['mw'],
    "rāddha": ['ap90', 'cae', 'ddsa', 'mw'],
    "rāddhi": ['cae', 'ddsa', 'mw'],
    "rāddhiḥ": ['ap90'],
    "rāddhānna": ['mw'],
    "rāddhānta": ['mw'],
    "rāddhāntamuktāhāra": ['mw'],
    "rāddhāntita": ['mw'],
    "rādh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rādha": ['cae', 'ddsa', 'gra', 'mw'],
    "rādhagupta": ['bhs', 'mw'],
    "rādhaka": ['mw'],
    "rādhana": ['mw'],
    "rādhanadravya": ['mw'],
    "rādhanaṃ": ['ap90'],
    "rādhanā": ['mw'],
    "rādhanī": ['mw'],
    "rādharaṅka": ['mw'],
    "rādharaṅku": ['mw'],
    "rādhas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rādhaspati": ['cae', 'gra', 'mw'],
    "rādhaḥ": ['ap90'],
    "rādheya": ['cae', 'ddsa', 'mw'],
    "rādheyaḥ": ['ap90'],
    "rādheśa": ['ddsa', 'mw'],
    "rādheśvara": ['mw'],
    "rādhi": ['mw'],
    "rādhika": ['mw'],
    "rādhikā": ['ap90', 'ddsa', 'mw'],
    "rādhikāvinoda": ['mw'],
    "rādho": ['mw'],
    "rādhodbhavasaṃvāda": ['mw'],
    "rādhodeya": ['cae', 'ddsa', 'gra', 'mw'],
    "rādhogūrta": ['mw'],
    "rādhopāsaka": ['mw'],
    "rādhottaratāpanīyopaniṣad": ['mw'],
    "rādhrevaki": ['mw'],
    "rādhya": ['cae', 'ddsa', 'mw'],
    "rādhyate": ['bhs'],
    "rādhā": ['ap90', 'ddsa', 'mw'],
    "rādhābhartṛ": ['mw'],
    "rādhābhedin": ['mw'],
    "rādhācaraṇa": ['mw'],
    "rādhādāmodara": ['mw'],
    "rādhājanmāṣṭamī": ['mw'],
    "rādhākavaca": ['mw'],
    "rādhākānta": ['cae', 'mw'],
    "rādhākāntadeva": ['mw'],
    "rādhākṛṣṇa": ['mw'],
    "rādhākṛṣṇakośa": ['mw'],
    "rādhākṛṣṇalīlā": ['mw'],
    "rādhākṛṣṇapadacihna": ['mw'],
    "rādhākṛṣṇarūpacintāmaṇi": ['mw'],
    "rādhākṛṣṇārcanadīpikā": ['mw'],
    "rādhāmantra": ['mw'],
    "rādhāmohana": ['mw'],
    "rādhāmādhava": ['mw'],
    "rādhāmādhavarūpacintāmaṇi": ['mw'],
    "rādhāmādhavavilāsa": ['mw'],
    "rādhāmānataraṃgiṇī": ['mw'],
    "rādhānagarī": ['mw'],
    "rādhānurādhīya": ['mw'],
    "rādhānātha": ['mw'],
    "rādhāpaddhati": ['mw'],
    "rādhārahasyakāvya": ['mw'],
    "rādhāramaṇa": ['mw'],
    "rādhāramaṇadāsa": ['mw'],
    "rādhārasamañjarī": ['mw'],
    "rādhārasasudhānidhi": ['mw'],
    "rādhāsahasranāman": ['mw'],
    "rādhāsaundaryamañjarī": ['mw'],
    "rādhāsudhānidhi": ['mw'],
    "rādhāsuta": ['mw'],
    "rādhātanaya": ['mw'],
    "rādhātantra": ['mw'],
    "rādhāvallabha": ['mw'],
    "rādhāvallabhopaniṣad": ['mw'],
    "rādhāvat": ['mw'],
    "rādhāvedhin": ['mw'],
    "rādhāvilāsa": ['mw'],
    "rādhāvinodakāvya": ['mw'],
    "rādhāṣṭaka": ['mw'],
    "rādhī": ['mw'],
    "rāga": ['cae', 'cped', 'ddsa', 'mw'],
    "rāgabandha": ['cae', 'mw'],
    "rāgabandhin": ['mw'],
    "rāgabhañjana": ['mw'],
    "rāgacandrodaya": ['mw'],
    "rāgacarita": ['cped'],
    "rāgacchanna": ['mw'],
    "rāgacūrṇa": ['mw'],
    "rāgada": ['mw'],
    "rāgadhyānādikathanādhyāya": ['mw'],
    "rāgadoṣa": ['mw'],
    "rāgadravya": ['mw'],
    "rāgadveṣa": ['cae', 'mw'],
    "rāgadveṣamohaparimokṣaṇa": ['mw'],
    "rāgadveṣaprakaraṇa": ['mw'],
    "rāgadā": ['mw'],
    "rāgadāli": ['mw'],
    "rāgadṛś": ['mw'],
    "rāgaggi": ['cped'],
    "rāgagrahavat": ['ddsa', 'mw'],
    "rāgakhāḍava": ['mw'],
    "rāgakhāṇḍava": ['mw'],
    "rāgakhāṇḍavika": ['mw'],
    "rāgakkhaya": ['cped'],
    "rāgakāṣṭha": ['mw'],
    "rāgalakṣaṇa": ['mw'],
    "rāgalatā": ['mw'],
    "rāgalekhā": ['cae', 'mw'],
    "rāgamaya": ['ap90', 'cae', 'mw'],
    "rāgamañjarikā": ['mw'],
    "rāgamañjarī": ['mw'],
    "rāgamālā": ['mw'],
    "rāgaparimuktā": ['bhs'],
    "rāgapaṭṭa": ['mw'],
    "rāgaprasava": ['mw'],
    "rāgaprastāra": ['mw'],
    "rāgaprāpta": ['mw'],
    "rāgapuṣpa": ['mw'],
    "rāgapuṣpī": ['mw'],
    "rāgarajju": ['mw'],
    "rāgaratnākara": ['mw'],
    "rāgaratta": ['cped'],
    "rāgarāgiṇīsvarūpavelāvarṇana": ['mw'],
    "rāgasūtra": ['mw'],
    "rāgatattvavibodha": ['mw'],
    "rāgavant": ['cae'],
    "rāgavardhana": ['mw'],
    "rāgavat": ['mw'],
    "rāgavibodha": ['mw'],
    "rāgavibodhaviveka": ['mw'],
    "rāgavihiṃsanavratanirṇaya": ['mw'],
    "rāgaviveka": ['mw'],
    "rāgavṛnta": ['mw'],
    "rāgayuj": ['mw'],
    "rāgaḥ": ['ap90'],
    "rāgaṣāḍava": ['mw'],
    "rāgaṣāḍhava": ['mw'],
    "rāgh": ['ap90', 'mw'],
    "rāghava": ['bhs', 'cae', 'ddsa', 'mw'],
    "rāghavacaitanya": ['mw'],
    "rāghavacaritra": ['mw'],
    "rāghavadeva": ['mw'],
    "rāghavanandana": ['mw'],
    "rāghavapaṇḍita": ['mw'],
    "rāghavapaṇḍitīya": ['mw'],
    "rāghavaprabandha": ['mw'],
    "rāghavapāṇḍava": ['mw'],
    "rāghavapāṇḍavaprakāśa": ['mw'],
    "rāghavapāṇḍavayādavīya": ['mw'],
    "rāghavapāṇḍavīya": ['cae', 'mw'],
    "rāghavarahasya": ['mw'],
    "rāghavasiṃha": ['mw'],
    "rāghavavilāsa": ['mw'],
    "rāghavayādavapāṇḍavīya": ['mw'],
    "rāghavayādavīya": ['mw'],
    "rāghavayādāvīyacarita": ['mw'],
    "rāghavaḥ": ['ap90'],
    "rāghavendra": ['mw'],
    "rāghavendrastotravyākhyā": ['mw'],
    "rāghavendrīya": ['mw'],
    "rāghaveśvara": ['mw'],
    "rāghavollāsa": ['mw'],
    "rāghavābhyudaya": ['mw'],
    "rāghavānanda": ['mw'],
    "rāghavānuja": ['mw'],
    "rāghavāyaṇa": ['mw'],
    "rāghavāṣṭaka": ['mw'],
    "rāghavīya": ['mw'],
    "rāgi": ['mw'],
    "rāgin": ['ap90', 'cae', 'ddsa', 'mw'],
    "rāgitaru": ['mw'],
    "rāgitā": ['cae', 'ddsa', 'mw'],
    "rāgiṇī": ['mw'],
    "rāgodreka": ['mw'],
    "rāgotpatti": ['mw'],
    "rāgā": ['mw'],
    "rāgāndha": ['mw'],
    "rāgānugā": ['mw'],
    "rāgānvita": ['mw'],
    "rāgārha": ['mw'],
    "rāgāru": ['ap90', 'mw'],
    "rāgārṇava": ['mw'],
    "rāgātmaka": ['cae', 'mw'],
    "rāgāyāta": ['mw'],
    "rāgāśani": ['mw'],
    "rāgāḍhyā": ['mw'],
    "rāgāṅgī": ['mw'],
    "rāgī": ['cped', 'mw'],
    "rāhakṣati": ['mw'],
    "rāhaseyyaka": ['cped'],
    "rāhavi": ['mw'],
    "rāhavīya": ['cae', 'ddsa', 'mw'],
    "rāhaḍī": ['mw'],
    "rāhila": ['ddsa', 'mw'],
    "rāhitya": ['cae', 'ddsa', 'mw'],
    "rāhityaṃ": ['ap90'],
    "rāhu": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "rāhubhedin": ['mw'],
    "rāhucchattra": ['mw'],
    "rāhucāra": ['mw'],
    "rāhudarśana": ['mw'],
    "rāhugamya": ['mw'],
    "rāhugata": ['mw'],
    "rāhugraha": ['cae', 'mw'],
    "rāhugrahaṇa": ['cae', 'mw'],
    "rāhugrasana": ['cae', 'mw'],
    "rāhugrasta": ['mw'],
    "rāhugrastaniśākara": ['mw'],
    "rāhugrāha": ['mw'],
    "rāhugrāsa": ['mw'],
    "rāhuka": ['bhs'],
    "rāhukanya": ['mw'],
    "rāhuketu": ['mw'],
    "rāhukālāvalī": ['mw'],
    "rāhula": ['bhs', 'ddsa', 'mw'],
    "rāhulabhadra": ['mw'],
    "rāhulaka": ['mw'],
    "rāhulamātar": ['bhs'],
    "rāhulasū": ['mw'],
    "rāhulata": ['mw'],
    "rāhumukha": ['cped', 'mw'],
    "rāhumūrdhabhid": ['mw'],
    "rāhumūrdhahara": ['mw'],
    "rāhuparvan": ['mw'],
    "rāhupīḍā": ['mw'],
    "rāhupūjā": ['mw'],
    "rāhuratna": ['mw'],
    "rāhusapatnavaktra": ['mw'],
    "rāhusaṃsparśa": ['mw'],
    "rāhusuta": ['mw'],
    "rāhusūkta": ['mw'],
    "rāhusūtaka": ['ddsa', 'mw'],
    "rāhuvamin": ['bhs'],
    "rāhuśatru": ['mw'],
    "rāhuḥ": ['ap90'],
    "rāhūcchiṣṭa": ['mw'],
    "rāhūgaṇa": ['cae', 'ddsa', 'mw'],
    "rāhūgaṇya": ['mw'],
    "rāhūpasarga": ['mw'],
    "rāhūtsṛṣṭa": ['mw'],
    "rāj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rāja": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rājabadara": ['mw'],
    "rājabalendraketu": ['mw'],
    "rājabali": ['cped'],
    "rājabalā": ['mw'],
    "rājabandha": ['mw'],
    "rājabandin": ['mw'],
    "rājabhadraka": ['mw'],
    "rājabhakṣa": ['mw'],
    "rājabhauta": ['mw'],
    "rājabhavana": ['cae', 'cped', 'mw'],
    "rājabhaya": ['cped', 'mw'],
    "rājabhaṭa": ['cae', 'cped', 'mw'],
    "rājabhaṭṭikā": ['mw'],
    "rājabhoga": ['mw'],
    "rājabhogga": ['cped'],
    "rājabhogya": ['mw'],
    "rājabhogīna": ['mw'],
    "rājabhojana": ['mw'],
    "rājabhrātṛ": ['cae', 'mw'],
    "rājabhāj": ['mw'],
    "rājabhāryā": ['mw'],
    "rājabhāva": ['cae'],
    "rājabhūya": ['mw'],
    "rājabhūṣaṇī": ['mw'],
    "rājabhṛt": ['mw'],
    "rājabhṛta": ['mw'],
    "rājabhṛtya": ['cae', 'mw'],
    "rājabhṛṅga": ['mw'],
    "rājabrāhmaṇa": ['mw'],
    "rājabāndhava": ['cae', 'mw'],
    "rājabījin": ['mw'],
    "rājacakra": ['mw'],
    "rājacampaka": ['mw'],
    "rājacandra": ['mw'],
    "rājacihna": ['mw'],
    "rājacihnaka": ['mw'],
    "rājacūḍāmaṇi": ['mw'],
    "rājadaivika": ['mw'],
    "rājadanta": ['cae', 'mw'],
    "rājadanti": ['mw'],
    "rājadarśana": ['cae', 'mw'],
    "rājadattā": ['mw'],
    "rājadaṇḍa": ['cae', 'cped', 'mw'],
    "rājadaṇḍabhayākula": ['mw'],
    "rājadeva": ['mw'],
    "rājadevī": ['cped'],
    "rājadhamma": ['cped'],
    "rājadharma": ['cae', 'mw'],
    "rājadharmabhṛt": ['cae', 'mw'],
    "rājadharmakaustubha": ['mw'],
    "rājadharmakāṇḍa": ['mw'],
    "rājadharmalakṣaṇa": ['mw'],
    "rājadharman": ['mw'],
    "rājadharmaprakaraṇa": ['mw'],
    "rājadharmasārasaṃgraha": ['mw'],
    "rājadharmavid": ['cae', 'mw'],
    "rājadharmānuśāsana": ['mw'],
    "rājadhattūra": ['mw'],
    "rājadhattūraka": ['mw'],
    "rājadhura": ['mw'],
    "rājadhustūraka": ['mw'],
    "rājadhāman": ['mw'],
    "rājadhāna": ['mw'],
    "rājadhānaka": ['mw'],
    "rājadhāni": ['cped'],
    "rājadhānikā": ['mw'],
    "rājadhānya": ['mw'],
    "rājadhānī": ['cae', 'mw'],
    "rājadhānītas": ['mw'],
    "rājadhīra": ['mw'],
    "rājadhītu": ['cped'],
    "rājadhūrta": ['mw'],
    "rājadroha": ['mw'],
    "rājadrohin": ['mw'],
    "rājadruma": ['mw'],
    "rājaduhitṛ": ['cae', 'mw'],
    "rājaduhitṛmaya": ['mw'],
    "rājadvār": ['cae', 'mw'],
    "rājadvāra": ['mw'],
    "rājadvārika": ['mw'],
    "rājadāra": ['cae', 'mw'],
    "rājadārikā": ['cae', 'mw'],
    "rājadāya": ['cped'],
    "rājadūrvā": ['mw'],
    "rājadūta": ['cped'],
    "rājadṛṣad": ['mw'],
    "rājagahaka": ['cped'],
    "rājagavī": ['cae', 'mw'],
    "rājagaṇa": ['mw'],
    "rājageha": ['cped', 'mw'],
    "rājagha": ['mw'],
    "rājaghātaka": ['cae', 'mw'],
    "rājagiri": ['mw'],
    "rājagirīya": ['mw'],
    "rājagrīva": ['mw'],
    "rājaguhya": ['cae', 'mw'],
    "rājaguru": ['cae', 'mw'],
    "rājagāmin": ['cae', 'mw'],
    "rājagṛha": ['cae', 'mw'],
    "rājagṛhaka": ['bhs', 'mw'],
    "rājagṛhamāhātmya": ['mw'],
    "rājagṛhanirmāṇa": ['mw'],
    "rājagṛheyaka": ['bhs'],
    "rājaharmya": ['cae', 'mw'],
    "rājaharṣaṇa": ['mw'],
    "rājahastin": ['mw'],
    "rājahatyā": ['mw'],
    "rājahaṁsa": ['cped'],
    "rājahaṃsa": ['cae', 'mw'],
    "rājahaṃsagāmin": ['bhs'],
    "rājahaṃsasudhābhāṣya": ['mw'],
    "rājahaṃsāya": ['mw'],
    "rājahaṃsīya": ['mw'],
    "rājahāra": ['cae', 'mw'],
    "rājahāsaka": ['mw'],
    "rājajakṣman": ['mw'],
    "rājajambū": ['cae', 'mw'],
    "rājajhaṃkāra": ['mw'],
    "rājaka": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "rājakadamba": ['mw'],
    "rājakakudhabhaṇḍa": ['cped'],
    "rājakalaśa": ['mw'],
    "rājakali": ['mw'],
    "rājakalā": ['mw'],
    "rājakammika": ['cped'],
    "rājakandarpa": ['mw'],
    "rājakanyakā": ['cae', 'mw'],
    "rājakanyā": ['cae', 'mw'],
    "rājakara": ['mw'],
    "rājakaraṇa": ['mw'],
    "rājakarkaṭī": ['mw'],
    "rājakarman": ['cae', 'mw'],
    "rājakarmin": ['mw'],
    "rājakartṛ": ['cae', 'mw'],
    "rājakarṇa": ['mw'],
    "rājakaseru": ['mw'],
    "rājakathā": ['cped', 'mw'],
    "rājakaustubha": ['mw'],
    "rājakaññā": ['cped'],
    "rājakaḥ": ['ap90'],
    "rājakharjūrī": ['mw'],
    "rājakilbiṣin": ['cae', 'mw'],
    "rājakineya": ['mw'],
    "rājakola": ['mw'],
    "rājakolāhala": ['mw'],
    "rājakośanighaṇṭu": ['mw'],
    "rājakośātaka": ['mw'],
    "rājakośātakī": ['mw'],
    "rājakraya": ['mw'],
    "rājakrayaṇī": ['mw'],
    "rājakriyā": ['cae', 'mw'],
    "rājakula": ['cae', 'cped', 'mw'],
    "rājakulabhaṭṭa": ['mw'],
    "rājakulaprajāta": ['mw'],
    "rājakulavivāda": ['mw'],
    "rājakulya": ['mw'],
    "rājakulānumantavya": ['mw'],
    "rājakumāra": ['cae', 'cped', 'ddsa', 'mw'],
    "rājakumārikā": ['mw'],
    "rājakumārī": ['cped'],
    "rājakuñjara": ['mw'],
    "rājakuṇḍa": ['mw'],
    "rājakuṣmāṇḍa": ['mw'],
    "rājakya": ['bhs'],
    "rājakārya": ['cae', 'mw'],
    "rājakīra": ['mw'],
    "rājakīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "rājakīyanāman": ['mw'],
    "rājakīyasaras": ['mw'],
    "rājakṛt": ['cae', 'mw'],
    "rājakṛta": ['mw'],
    "rājakṛtapratijña": ['mw'],
    "rājakṛtvan": ['mw'],
    "rājakṛtya": ['cae', 'mw'],
    "rājakṛṣṇa": ['mw'],
    "rājakṣavaka": ['mw'],
    "rājakṣetragupta": ['bhs'],
    "rājalakṣaṇa": ['cae', 'mw'],
    "rājalakṣman": ['mw'],
    "rājalakṣmī": ['cae', 'mw'],
    "rājalekha": ['mw'],
    "rājaliṅga": ['mw'],
    "rājaloka": ['cae', 'mw'],
    "rājalīlānāman": ['mw'],
    "rājamahendratīrtha": ['mw'],
    "rājamahesī": ['cped'],
    "rājamahila": ['mw'],
    "rājamahiṣī": ['mw'],
    "rājamahāmatta": ['cped'],
    "rājamalla": ['mw'],
    "rājamandira": ['cae', 'cped', 'mw'],
    "rājamantradhara": ['mw'],
    "rājamantrin": ['mw'],
    "rājamaṇi": ['mw'],
    "rājamaṇḍūka": ['mw'],
    "rājambhavya": ['mw'],
    "rājamuddā": ['cped'],
    "rājamudga": ['mw'],
    "rājamudgaka": ['mw'],
    "rājamudrā": ['mw'],
    "rājamukha": ['cae', 'mw'],
    "rājamukuṭa": ['mw'],
    "rājamuni": ['mw'],
    "rājamāna": ['cped', 'mw'],
    "rājamānasollāsa": ['mw'],
    "rājamānatva": ['cae', 'ddsa', 'mw'],
    "rājamānuṣa": ['cae', 'ddsa', 'mw'],
    "rājamārga": ['cae', 'mw'],
    "rājamārgaviśārada": ['mw'],
    "rājamārgīkṛ": ['mw'],
    "rājamārtaṇḍa": ['mw'],
    "rājamāsa": ['mw'],
    "rājamātaṃgīpaddhati": ['mw'],
    "rājamātaṃgīstotra": ['mw'],
    "rājamātra": ['bhs', 'mw'],
    "rājamātṛ": ['cae', 'mw'],
    "rājamāṣa": ['mw'],
    "rājamāṣya": ['mw'],
    "rājamṛgāṅka": ['mw'],
    "rājan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rājana": ['mw'],
    "rājanagarī": ['mw'],
    "rājanandana": ['mw'],
    "rājanaya": ['cae', 'ddsa', 'mw'],
    "rājani": ['mw'],
    "rājania": ['gra'],
    "rājanighaṇṭu": ['mw'],
    "rājanindaka": ['mw'],
    "rājanirdhūtadaṇḍa": ['mw'],
    "rājanivesana": ['cped'],
    "rājaniveśana": ['mw'],
    "rājanvant": ['cae'],
    "rājanvat": ['ap90', 'ddsa', 'mw'],
    "rājanya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "rājanyabandhu": ['cae', 'mw'],
    "rājanyaka": ['cae', 'mw'],
    "rājanyakaṃ": ['ap90'],
    "rājanyakumāra": ['cae', 'mw'],
    "rājanyarṣi": ['mw'],
    "rājanyatva": ['mw'],
    "rājanyavat": ['mw'],
    "rājanyā": ['mw'],
    "rājanyāvartaka": ['mw'],
    "rājanāman": ['mw'],
    "rājanāpita": ['mw'],
    "rājanārāyaṇa": ['mw'],
    "rājanātha": ['mw'],
    "rājanī": ['mw'],
    "rājanīla": ['mw'],
    "rājanīlikā": ['mw'],
    "rājanīti": ['mw'],
    "rājanītimayūkha": ['mw'],
    "rājanītiprakāśa": ['mw'],
    "rājanītiśāstra": ['mw'],
    "rājanīya": ['bhs'],
    "rājanīyaprabha": ['mw'],
    "rājapada": ['mw'],
    "rājapaddhati": ['mw'],
    "rājapalāṇḍu": ['mw'],
    "rājaparisā": ['cped'],
    "rājaparivarta": ['cae', 'mw'],
    "rājaparṇī": ['mw'],
    "rājapatha": ['cae', 'mw'],
    "rājapathāya": ['mw'],
    "rājapati": ['cae', 'mw'],
    "rājapatnī": ['cae', 'mw'],
    "rājapauruṣika": ['mw'],
    "rājapauruṣya": ['mw'],
    "rājapaṭola": ['mw'],
    "rājapaṭolī": ['mw'],
    "rājapaṭṭa": ['bhs', 'cae', 'ddsa', 'mw'],
    "rājapaṭṭikā": ['mw'],
    "rājaphala": ['mw'],
    "rājaphalā": ['mw'],
    "rājaphaṇijjhaka": ['mw'],
    "rājapitṛ": ['mw'],
    "rājapiṇḍā": ['mw'],
    "rājaporisa": ['cped'],
    "rājaprakṛti": ['cae', 'mw'],
    "rājaprasāda": ['mw'],
    "rājaprasādapaṭṭaka": ['mw'],
    "rājaprathamābhiṣeka": ['mw'],
    "rājapratyenas": ['mw'],
    "rājapraśastimahākāvya": ['mw'],
    "rājapreṣya": ['cae', 'mw'],
    "rājapriya": ['mw'],
    "rājapriyā": ['cae', 'mw'],
    "rājapumaṃs": ['cae'],
    "rājapura": ['cae', 'mw'],
    "rājapurisa": ['cped'],
    "rājapuruṣa": ['cae', 'mw'],
    "rājapuruṣavāda": ['mw'],
    "rājapurī": ['mw'],
    "rājaputra": ['cae', 'gra', 'mw'],
    "rājaputraka": ['cae', 'mw'],
    "rājaputraloka": ['mw'],
    "rājaputraparpaṭi": ['mw'],
    "rājaputratā": ['mw'],
    "rājaputrikā": ['mw'],
    "rājaputrā": ['mw'],
    "rājaputrārgaṭa": ['mw'],
    "rājaputrī": ['mw'],
    "rājaputrīya": ['mw'],
    "rājaputta": ['cped'],
    "rājaputtī": ['cped'],
    "rājapuṃs": ['mw'],
    "rājapuṣpa": ['mw'],
    "rājapuṣpī": ['mw'],
    "rājapāla": ['mw'],
    "rājapāṭikā": ['mw'],
    "rājapīlu": ['mw'],
    "rājapūga": ['mw'],
    "rājapūruṣa": ['cae', 'mw'],
    "rājaratha": ['cped', 'mw'],
    "rājaraṅga": ['mw'],
    "rājarddhi": ['mw'],
    "rājarāj": ['cae', 'mw'],
    "rājarāja": ['cae', 'mw'],
    "rājarājagiri": ['mw'],
    "rājarājatva": ['mw'],
    "rājarājatā": ['mw'],
    "rājarājeśvara": ['mw'],
    "rājarājeśvarayogakathā": ['mw'],
    "rājarājeśvarī": ['mw'],
    "rājarājeśvarīdaṇḍaka": ['mw'],
    "rājarājeśvarīkavaca": ['mw'],
    "rājarājeśvarīmantra": ['mw'],
    "rājarājeśvarīstotra": ['mw'],
    "rājarājeśvarītantra": ['mw'],
    "rājarājya": ['cae', 'mw'],
    "rājarākṣasa": ['mw'],
    "rājarāma": ['mw'],
    "rājarāmanagara": ['mw'],
    "rājarāṇaka": ['mw'],
    "rājarīti": ['mw'],
    "rājarṣabha": ['mw'],
    "rājarṣi": ['cae', 'mw'],
    "rājarṣibhaṭṭa": ['mw'],
    "rājarṣiloka": ['mw'],
    "rājarṣin": ['mw'],
    "rājasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "rājasabhā": ['cae', 'mw'],
    "rājasabhāstha": ['mw'],
    "rājasadana": ['mw'],
    "rājasadman": ['cae', 'mw'],
    "rājasampatti": ['cped'],
    "rājasarpa": ['mw'],
    "rājasarṣapa": ['cae', 'mw'],
    "rājasattra": ['cae', 'mw'],
    "rājasatva": ['mw'],
    "rājasaudha": ['mw'],
    "rājasaṃnidhāna": ['mw'],
    "rājasaṃsad": ['cae', 'mw'],
    "rājasaṃyuktakanipāta": ['bhs'],
    "rājasaṃśraya": ['ddsa', 'mw'],
    "rājase": ['mw'],
    "rājasena": ['mw'],
    "rājasevaka": ['cae', 'mw'],
    "rājasevin": ['cae', 'mw'],
    "rājasevopajīvin": ['mw'],
    "rājasevā": ['cae', 'mw'],
    "rājasika": ['mw'],
    "rājasiṃha": ['cae', 'mw'],
    "rājasiṃhapāṇḍya": ['mw'],
    "rājasiṃhasudhāsaṃgraha": ['mw'],
    "rājaskandha": ['mw'],
    "rājasravas": ['mw'],
    "rājastamba": ['mw'],
    "rājastambi": ['mw'],
    "rājastambāyana": ['mw'],
    "rājasthalaka": ['mw'],
    "rājasthalī": ['mw'],
    "rājasthānādhikāra": ['mw'],
    "rājasthānīya": ['mw'],
    "rājastrī": ['mw'],
    "rājasukha": ['mw'],
    "rājasundaragaṇi": ['mw'],
    "rājasuta": ['cae', 'mw'],
    "rājasutā": ['mw'],
    "rājasva": ['cae', 'mw'],
    "rājasvarṇa": ['mw'],
    "rājasvāmin": ['mw'],
    "rājasyālaka": ['cae'],
    "rājasāi": ['mw'],
    "rājasākṣika": ['mw'],
    "rājasāman": ['mw'],
    "rājasārasa": ['mw'],
    "rājasāt": ['ap90', 'mw'],
    "rājasātbhū": ['mw'],
    "rājasātkṛ": ['mw'],
    "rājasātsampad": ['mw'],
    "rājasāyujya": ['mw'],
    "rājasī": ['mw'],
    "rājasū": ['mw'],
    "rājasūnu": ['cae', 'mw'],
    "rājasūya": ['cae', 'mw'],
    "rājasūyasūtra": ['mw'],
    "rājasūyayājin": ['mw'],
    "rājasūyeṣṭi": ['mw'],
    "rājasūyika": ['mw'],
    "rājasūyārambhaparvan": ['mw'],
    "rājata": ['ap90', 'cae', 'ddsa', 'mw'],
    "rājatanaya": ['cae', 'ddsa', 'mw'],
    "rājatanayā": ['mw'],
    "rājataraṃgiṇī": ['cae', 'mw'],
    "rājataraṃgiṇīsaṃgraha": ['mw'],
    "rājataraṇī": ['mw'],
    "rājataru": ['mw'],
    "rājatas": ['cae', 'mw'],
    "rājatemiṣa": ['mw'],
    "rājati": ['cped'],
    "rājatimiṣa": ['mw'],
    "rājatta": ['cped'],
    "rājatuṅga": ['mw'],
    "rājatva": ['mw'],
    "rājatā": ['ap90', 'cae', 'mw'],
    "rājatādri": ['ddsa', 'mw'],
    "rājatāla": ['mw'],
    "rājatālī": ['ddsa'],
    "rājatānvita": ['mw'],
    "rājatīrtha": ['mw'],
    "rājavadana": ['mw'],
    "rājavadha": ['cae', 'mw'],
    "rājavahana": ['mw'],
    "rājavahikā": ['mw'],
    "rājavallabha": ['cae', 'cped', 'mw'],
    "rājavallabhamaṇḍana": ['mw'],
    "rājavallabhaturaṃgama": ['mw'],
    "rājavallabhatā": ['mw'],
    "rājavallī": ['mw'],
    "rājavandin": ['mw'],
    "rājavant": ['cae'],
    "rājavara": ['cped'],
    "rājavarcasa": ['mw'],
    "rājavarcasin": ['mw'],
    "rājavardhana": ['mw'],
    "rājavarman": ['mw'],
    "rājavarta": ['mw'],
    "rājavartman": ['mw'],
    "rājavarṇaka": ['mw'],
    "rājavasati": ['mw'],
    "rājavat": ['cae', 'mw'],
    "rājavati": ['mw'],
    "rājavatsa": ['mw'],
    "rājavatī": ['mw'],
    "rājavaśībhūta": ['mw'],
    "rājavaśībhūtatā": ['mw'],
    "rājavaṃśa": ['cae', 'mw'],
    "rājavaṃśakāvya": ['mw'],
    "rājavaṃśya": ['cae', 'mw'],
    "rājavaṃśāvalī": ['mw'],
    "rājavaṃśīya": ['mw'],
    "rājavetrin": ['mw'],
    "rājaveśman": ['cae', 'mw'],
    "rājaveṣa": ['cae', 'mw'],
    "rājavi": ['mw'],
    "rājavidyā": ['cae', 'mw'],
    "rājavidyādhara": ['mw'],
    "rājavihaṃgama": ['mw'],
    "rājavihāra": ['mw'],
    "rājavijaya": ['mw'],
    "rājavinoda": ['mw'],
    "rājavinodatāla": ['mw'],
    "rājavyavahārakośa": ['mw'],
    "rājavādhavya": ['mw'],
    "rājavāha": ['mw'],
    "rājavāhana": ['mw'],
    "rājavāhikā": ['mw'],
    "rājavāhya": ['mw'],
    "rājavārttika": ['mw'],
    "rājavījin": ['mw'],
    "rājavīrya": ['mw'],
    "rājavīthī": ['cae', 'mw'],
    "rājavṛkṣa": ['mw'],
    "rājavṛtta": ['mw'],
    "rājayajña": ['cae', 'mw'],
    "rājayakṣma": ['cae', 'ddsa', 'gra', 'mw'],
    "rājayakṣman": ['cae', 'mw'],
    "rājayakṣmannāman": ['mw'],
    "rājayakṣmanāman": ['mw'],
    "rājayakṣmin": ['mw'],
    "rājayoga": ['mw'],
    "rājayogavidhi": ['mw'],
    "rājayogya": ['mw'],
    "rājayogādhyāya": ['mw'],
    "rājayoṣit": ['cae', 'mw'],
    "rājayudhvan": ['mw'],
    "rājayājaka": ['mw'],
    "rājayāna": ['mw'],
    "rājañña": ['cped'],
    "rājaśaila": ['mw'],
    "rājaśaphara": ['mw'],
    "rājaśayana": ['mw'],
    "rājaśaṇa": ['mw'],
    "rājaśekhara": ['ap90', 'cae', 'mw'],
    "rājaśravas": ['mw'],
    "rājaśrī": ['bhs', 'cae', 'mw'],
    "rājaśuka": ['mw'],
    "rājaśyāmalopāsaka": ['mw'],
    "rājaśyāmāka": ['mw'],
    "rājaśāka": ['mw'],
    "rājaśākaṇikā": ['mw'],
    "rājaśākiṇī": ['mw'],
    "rājaśārdūla": ['mw'],
    "rājaśāsana": ['cae', 'mw'],
    "rājaśāstra": ['cae', 'mw'],
    "rājaśāyyā": ['mw'],
    "rājaśīrṣaka": ['mw'],
    "rājaśṛṅga": ['mw'],
    "rājaṛṣi": ['mw'],
    "rājendra": ['cae', 'ddsa', 'mw'],
    "rājendradaśāvadhāna": ['mw'],
    "rājendragir": ['mw'],
    "rājendrakarṇapūra": ['mw'],
    "rājeya": ['mw'],
    "rājeyu": ['mw'],
    "rājeśvara": ['mw'],
    "rājeśvaramahodaya": ['mw'],
    "rājeṣṭa": ['mw'],
    "rājeṣṭā": ['mw'],
    "rāji": ['cae', 'cped', 'ddsa', 'mw'],
    "rājia": ['gra'],
    "rājicitra": ['ddsa', 'mw'],
    "rājiddhi": ['cped'],
    "rājika": ['ddsa', 'mw'],
    "rājikā": ['ap90', 'mw'],
    "rājikāphala": ['mw'],
    "rājila": ['cae', 'mw'],
    "rājilaḥ": ['ap90'],
    "rājimant": ['cae'],
    "rājimat": ['ddsa', 'mw'],
    "rājin": ['cae', 'ddsa', 'gra', 'mw'],
    "rājinī": ['cped'],
    "rājiphalā": ['mw'],
    "rājiphalī": ['mw'],
    "rājisi": ['cped'],
    "rājita": ['cped', 'mw'],
    "rājitas": ['mw'],
    "rājiḥ": ['ap90'],
    "rājju": ['mw'],
    "rājjubhārin": ['mw'],
    "rājjudāla": ['mw'],
    "rājjukaṇṭhin": ['mw'],
    "rājodvejanasaṃjñaka": ['mw'],
    "rājoka": ['mw'],
    "rājopacāra": ['cae', 'mw'],
    "rājopajīvin": ['mw'],
    "rājopakaraṇa": ['cae', 'mw'],
    "rājopakīrṇakasūtra": ['bhs'],
    "rājopasevin": ['cae', 'mw'],
    "rājopasevā": ['cae', 'mw'],
    "rājorodha": ['cped'],
    "rājupaṭṭhāna": ['cped'],
    "rājuyyāna": ['cped'],
    "rājya": ['cae', 'ddsa', 'gra', 'mw'],
    "rājyabhaṅga": ['cae', 'mw'],
    "rājyabhedamara": ['mw'],
    "rājyabhoga": ['mw'],
    "rājyabhraṃśa": ['mw'],
    "rājyabhraṣṭa": ['mw'],
    "rājyabhāj": ['cae', 'mw'],
    "rājyabhāra": ['mw'],
    "rājyacyuta": ['mw'],
    "rājyacyuti": ['cae', 'mw'],
    "rājyadevī": ['mw'],
    "rājyadhara": ['mw'],
    "rājyadhurā": ['mw'],
    "rājyadravya": ['mw'],
    "rājyadravyamaya": ['mw'],
    "rājyahara": ['mw'],
    "rājyaikaśeṣeṇa": ['mw'],
    "rājyakara": ['ddsa', 'mw'],
    "rājyakartṛ": ['mw'],
    "rājyakhaṇḍa": ['mw'],
    "rājyakṛt": ['mw'],
    "rājyalakṣmī": ['cae', 'mw'],
    "rājyalaulya": ['mw'],
    "rājyalobha": ['mw'],
    "rājyaloka": ['mw'],
    "rājyalābha": ['mw'],
    "rājyalābhastotra": ['mw'],
    "rājyalīlā": ['mw'],
    "rājyapada": ['mw'],
    "rājyaparibhraṣṭa": ['mw'],
    "rājyaparikriyā": ['mw'],
    "rājyaprada": ['mw'],
    "rājyapāla": ['mw'],
    "rājyarakṣā": ['mw'],
    "rājyasena": ['mw'],
    "rājyastha": ['cae', 'mw'],
    "rājyasthiti": ['cae', 'mw'],
    "rājyasthāyin": ['cae', 'mw'],
    "rājyasukha": ['cae', 'mw'],
    "rājyatantra": ['mw'],
    "rājyatyāga": ['mw'],
    "rājyavardhana": ['mw'],
    "rājyavatī": ['mw'],
    "rājyavibhava": ['mw'],
    "rājyavibhūti": ['mw'],
    "rājyavyavahāra": ['mw'],
    "rājyaśrī": ['cae', 'mw'],
    "rājyaṃ": ['ap90'],
    "rājyopakaraṇa": ['cae', 'mw'],
    "rājyābhiṣeka": ['cae', 'mw'],
    "rājyābhiṣekadīdhiti": ['mw'],
    "rājyābhiṣekamantra": ['mw'],
    "rājyābhiṣekapaddhati": ['mw'],
    "rājyābhiṣekaprakaraṇaṭīkā": ['mw'],
    "rājyābhiṣekavidhi": ['mw'],
    "rājyābhiṣikta": ['mw'],
    "rājyādhideva": ['mw'],
    "rājyādhidevatā": ['mw'],
    "rājyādhikāra": ['mw'],
    "rājyāpaharaṇa": ['mw'],
    "rājyāpahāraka": ['mw'],
    "rājyāśramamuni": ['mw'],
    "rājyāṅga": ['ddsa', 'mw'],
    "rājñī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rājñīdevīmāhātmya": ['mw'],
    "rājñīdevīpañcāṅga": ['mw'],
    "rājñīpada": ['mw'],
    "rājñīstava": ['mw'],
    "rājābharaṇa": ['mw'],
    "rājābhiṣeka": ['cae', 'mw'],
    "rājābhiṣekapaddhati": ['mw'],
    "rājābhiṣekaprayoga": ['mw'],
    "rājādana": ['cae', 'ddsa', 'mw'],
    "rājādhara": ['mw'],
    "rājādhideva": ['mw'],
    "rājādhidevī": ['mw'],
    "rājādhikārin": ['mw'],
    "rājādhikṛta": ['mw'],
    "rājādhirāja": ['cae', 'mw'],
    "rājādhiṣṭhāna": ['cae', 'mw'],
    "rājādhvan": ['mw'],
    "rājādhīna": ['cae', 'mw'],
    "rājāditya": ['mw'],
    "rājādri": ['mw'],
    "rājāhi": ['mw'],
    "rājājñā": ['mw'],
    "rājāluka": ['mw'],
    "rājālābū": ['mw'],
    "rājāmacca": ['cped'],
    "rājāmla": ['mw'],
    "rājāmra": ['mw'],
    "rājāna": ['mw'],
    "rājānaka": ['ddsa', 'mw'],
    "rājānakamahimācārya": ['mw'],
    "rājānna": ['cae', 'mw'],
    "rājāntakaraṇa": ['mw'],
    "rājāntepura": ['cped'],
    "rājānubhāva": ['cped'],
    "rājānuja": ['cae'],
    "rājānujīvin": ['cae', 'ddsa', 'mw'],
    "rājānyatva": ['mw'],
    "rājāpasada": ['mw'],
    "rājāpatyā": ['mw'],
    "rājārha": ['cae', 'ddsa', 'mw'],
    "rājārhaṇa": ['mw'],
    "rājārhā": ['mw'],
    "rājārka": ['mw'],
    "rājārtha": ['cae'],
    "rājārāma": ['mw'],
    "rājāsalakhaṇa": ['mw'],
    "rājāsana": ['cae', 'mw'],
    "rājāsandī": ['cae', 'mw'],
    "rājātmakastava": ['mw'],
    "rājātyāvartaka": ['mw'],
    "rājāvali": ['mw'],
    "rājāvalipatākā": ['mw'],
    "rājāvalī": ['mw'],
    "rājāvalīphalagrantha": ['mw'],
    "rājāvarta": ['mw'],
    "rājāvartopala": ['mw'],
    "rājāvavāda": ['mw'],
    "rājāvavādaka": ['bhs', 'mw'],
    "rājāya": ['ddsa', 'mw'],
    "rājāyatana": ['cped'],
    "rājāyate": ['ap90'],
    "rājāśva": ['cae', 'mw'],
    "rājāṅgaṇa": ['cped', 'mw'],
    "rājāṇā": ['cped'],
    "rājī": ['cae', 'ddsa', 'mw'],
    "rājīkṛta": ['cae', 'ddsa', 'mw'],
    "rājīmanmatīparityāga": ['mw'],
    "rājīmant": ['cae'],
    "rājīmat": ['mw'],
    "rājīphala": ['mw'],
    "rājīva": ['cae', 'ddsa', 'mw'],
    "rājīvaka": ['mw'],
    "rājīvalocana": ['cae', 'mw'],
    "rājīvalocanā": ['mw'],
    "rājīvamukha": ['mw'],
    "rājīvamukhī": ['mw'],
    "rājīvanetra": ['cae', 'mw'],
    "rājīvaphala": ['mw'],
    "rājīvapṛśni": ['mw'],
    "rājīvavilocana": ['mw'],
    "rājīvaśubhalocana": ['mw'],
    "rājīvaḥ": ['ap90'],
    "rājīvinī": ['ddsa', 'mw'],
    "rājīvinījīvitavallabha": ['mw'],
    "rājīya": ['mw'],
    "rāka": ['mw'],
    "rākendra": ['mw'],
    "rākendīvarabandhu": ['mw'],
    "rākeśa": ['mw'],
    "rākh": ['ap90', 'mw'],
    "rākhaḍī": ['mw'],
    "rākiṇī": ['mw'],
    "rākya": ['mw'],
    "rākā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rākācandra": ['cae', 'mw'],
    "rākāgama": ['mw'],
    "rākāniśā": ['cae', 'mw'],
    "rākāpati": ['cae', 'mw'],
    "rākāramaṇa": ['cae', 'mw'],
    "rākāsudhākara": ['mw'],
    "rākāvibhāvarī": ['mw'],
    "rākāvibhāvarījāni": ['mw'],
    "rākāyajña": ['mw'],
    "rākāśaśin": ['cae', 'mw'],
    "rākāśaśāṅka": ['cae', 'mw'],
    "rākṣa": ['bhs'],
    "rākṣasa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "rākṣasaghna": ['mw'],
    "rākṣasagraha": ['mw'],
    "rākṣasakāvya": ['mw'],
    "rākṣasatva": ['mw'],
    "rākṣasatā": ['cae', 'mw'],
    "rākṣasendra": ['cae', 'ddsa', 'mw'],
    "rākṣaseśa": ['mw'],
    "rākṣaseśvara": ['mw'],
    "rākṣasotpatti": ['mw'],
    "rākṣasālaya": ['mw'],
    "rākṣasī": ['ddsa', 'mw'],
    "rākṣasībhūta": ['mw'],
    "rākṣasīdvīpa": ['bhs'],
    "rākṣasīkaraṇa": ['mw'],
    "rākṣasīkṛ": ['ddsa'],
    "rākṣoghna": ['ddsa', 'mw'],
    "rākṣosura": ['mw'],
    "rākṣā": ['ap90', 'cae', 'mw'],
    "rāla": ['mw'],
    "rālaka": ['mw'],
    "rālakārya": ['mw'],
    "rālaḥ": ['ap90'],
    "rāli": ['mw'],
    "rāma": ['ap90', 'bhs', 'ddsa', 'gra', 'mw'],
    "rāmabhadra": ['mw'],
    "rāmabhadrāmbā": ['mw'],
    "rāmabhadrāśrama": ['mw'],
    "rāmabhaginī": ['mw'],
    "rāmabhakta": ['mw'],
    "rāmabhujaṃga": ['mw'],
    "rāmabrahmānandasvāmin": ['mw'],
    "rāmabāhuśataka": ['mw'],
    "rāmabālacaritra": ['mw'],
    "rāmabāṇa": ['mw'],
    "rāmacakra": ['mw'],
    "rāmacandra": ['cae', 'mw'],
    "rāmacandracampū": ['mw'],
    "rāmacandracandrikā": ['mw'],
    "rāmacandracarita": ['mw'],
    "rāmacandracaritrasāra": ['mw'],
    "rāmacandracatuḥsūtrī": ['mw'],
    "rāmacandradāsa": ['mw'],
    "rāmacandragaṇeśa": ['mw'],
    "rāmacandrajyotsnā": ['mw'],
    "rāmacandrakaruṇāsāgaracandrikā": ['mw'],
    "rāmacandrakavaca": ['mw'],
    "rāmacandrakāvya": ['mw'],
    "rāmacandramahodaya": ['mw'],
    "rāmacandranāmāṣṭottaraśata": ['mw'],
    "rāmacandranāṭaka": ['mw'],
    "rāmacandrapañcadaśī": ['mw'],
    "rāmacandrapūjāvidhi": ['mw'],
    "rāmacandrastavarāja": ['mw'],
    "rāmacandrastotra": ['mw'],
    "rāmacandratīrtha": ['mw'],
    "rāmacandrayaśaḥprabandha": ['mw'],
    "rāmacandrendra": ['mw'],
    "rāmacandrikā": ['mw'],
    "rāmacandrodaya": ['mw'],
    "rāmacandrāhnika": ['mw'],
    "rāmacandrāryamaṅgalāśāsana": ['mw'],
    "rāmacandrāśrama": ['mw'],
    "rāmacandrāśritapārijāta": ['mw'],
    "rāmacandrāṣṭaka": ['mw'],
    "rāmacara": ['mw'],
    "rāmacaraṇa": ['mw'],
    "rāmacarita": ['mw'],
    "rāmacchardanaka": ['mw'],
    "rāmadarśanāditas": ['mw'],
    "rāmadatta": ['mw'],
    "rāmadayā": ['mw'],
    "rāmadayālu": ['mw'],
    "rāmadaṇḍaka": ['mw'],
    "rāmadeva": ['cae', 'ddsa', 'mw'],
    "rāmadhara": ['mw'],
    "rāmadhyāna": ['mw'],
    "rāmadhyānastotra": ['mw'],
    "rāmadurga": ['mw'],
    "rāmadvādaśanāmastotra": ['mw'],
    "rāmadvādaśī": ['mw'],
    "rāmadāsa": ['mw'],
    "rāmadūta": ['mw'],
    "rāmadūtī": ['mw'],
    "rāmagaṅgā": ['mw'],
    "rāmagiri": ['cae', 'mw'],
    "rāmagopāla": ['mw'],
    "rāmagovinda": ['mw'],
    "rāmagovindakīrtana": ['mw'],
    "rāmagovindatīrtha": ['mw'],
    "rāmagrāma": ['bhs', 'mw'],
    "rāmaguṇākara": ['mw'],
    "rāmagāyatrī": ['mw'],
    "rāmagītagovinda": ['mw'],
    "rāmagītā": ['mw'],
    "rāmahari": ['mw'],
    "rāmahrada": ['cae', 'mw'],
    "rāmahṛdaya": ['mw'],
    "rāmahṛdayāspada": ['mw'],
    "rāmaja": ['mw'],
    "rāmajananī": ['mw'],
    "rāmajanman": ['mw'],
    "rāmajayantīpūjā": ['mw'],
    "rāmajit": ['mw'],
    "rāmajātaka": ['mw'],
    "rāmajātakamahāyantra": ['mw'],
    "rāmajīvana": ['mw'],
    "rāmaka": ['ap90', 'mw'],
    "rāmakakṣā": ['bhs'],
    "rāmakalpa": ['mw'],
    "rāmakalpadruma": ['mw'],
    "rāmakarpūra": ['mw'],
    "rāmakarpūraka": ['mw'],
    "rāmakarī": ['mw'],
    "rāmakarṇāmṛta": ['mw'],
    "rāmakathā": ['mw'],
    "rāmakathāmṛta": ['mw'],
    "rāmakathāsaṃgraha": ['mw'],
    "rāmakautuka": ['mw'],
    "rāmakautūhala": ['mw'],
    "rāmakavaca": ['mw'],
    "rāmakaṇṭha": ['mw'],
    "rāmakelī": ['mw'],
    "rāmakeśavatīrtha": ['mw'],
    "rāmakilbiṣa": ['mw'],
    "rāmakirī": ['mw'],
    "rāmakiśora": ['mw'],
    "rāmakiṃkara": ['mw'],
    "rāmakrī": ['mw'],
    "rāmakumāra": ['mw'],
    "rāmakutūhala": ['mw'],
    "rāmakānta": ['mw'],
    "rāmakāntatanaya": ['mw'],
    "rāmakāvya": ['mw'],
    "rāmakāyaṇa": ['mw'],
    "rāmakāṇḍa": ['mw'],
    "rāmakīrtimukundamālā": ['mw'],
    "rāmakīrī": ['mw'],
    "rāmakṛt": ['mw'],
    "rāmakṛṣṇa": ['cae', 'ddsa', 'mw'],
    "rāmakṛṣṇadeva": ['mw'],
    "rāmakṛṣṇadīkṣitīya": ['mw'],
    "rāmakṛṣṇakāvya": ['mw'],
    "rāmakṛṣṇapaddhati": ['mw'],
    "rāmakṛṣṇasaṃvāda": ['mw'],
    "rāmakṛṣṇastotra": ['mw'],
    "rāmakṛṣṇavilomakāvya": ['mw'],
    "rāmakṛṣṇānanda": ['mw'],
    "rāmakṛṣṇānandatīrtha": ['mw'],
    "rāmakṛṣṇīya": ['mw'],
    "rāmakṣetra": ['mw'],
    "rāmala": ['ddsa', 'mw'],
    "rāmalavaṇa": ['mw'],
    "rāmalekhā": ['mw'],
    "rāmaliṅga": ['mw'],
    "rāmaliṅgavarṇana": ['mw'],
    "rāmaliṅgāmṛta": ['mw'],
    "rāmalīlodaya": ['mw'],
    "rāmalīlā": ['mw'],
    "rāmalīlāmṛta": ['mw'],
    "rāmalīlāsūcī": ['mw'],
    "rāmamahiman": ['mw'],
    "rāmamantra": ['mw'],
    "rāmamantrapaddhati": ['mw'],
    "rāmamantrapaṭala": ['mw'],
    "rāmamantrapaṭhanavidhi": ['mw'],
    "rāmamantrārtha": ['mw'],
    "rāmamantrārthanirṇaya": ['mw'],
    "rāmamaya": ['mw'],
    "rāmamaṅgala": ['mw'],
    "rāmamaṇidāsa": ['mw'],
    "rāmamohana": ['mw'],
    "rāmamānasikapūjā": ['mw'],
    "rāmanagara": ['mw'],
    "rāmanavamī": ['mw'],
    "rāmanavamīnirṇaya": ['mw'],
    "rāmanavamīpūjā": ['mw'],
    "rāmanavamīvratakathā": ['mw'],
    "rāmanavamīvratamāhātmya": ['mw'],
    "rāmanavaratnasāra": ['mw'],
    "rāmanibandha": ['mw'],
    "rāmanidhi": ['mw'],
    "rāmanyāyālaṃkāra": ['mw'],
    "rāmanāma": ['mw'],
    "rāmanāmalekhanavidhi": ['mw'],
    "rāmanāmalekhanodyāpanavidhi": ['mw'],
    "rāmanāmamāhātmya": ['mw'],
    "rāmanāmapaddhati": ['mw'],
    "rāmanāmavrata": ['mw'],
    "rāmanāmodyāpana": ['mw'],
    "rāmanāmāṣṭottaraśata": ['mw'],
    "rāmanārāyaṇa": ['mw'],
    "rāmanārāyaṇajīva": ['mw'],
    "rāmanātha": ['cae', 'mw'],
    "rāmanāthastotra": ['mw'],
    "rāmanāṭaka": ['mw'],
    "rāmanṛpati": ['mw'],
    "rāmapaddhati": ['mw'],
    "rāmapara": ['mw'],
    "rāmapati": ['mw'],
    "rāmapañcadaśīkalpalatikā": ['mw'],
    "rāmapañcāṅga": ['mw'],
    "rāmapaṭala": ['mw'],
    "rāmapaṭṭābhiṣeka": ['mw'],
    "rāmaprakāśa": ['mw'],
    "rāmaprasāda": ['mw'],
    "rāmapura": ['mw'],
    "rāmaputra": ['bhs', 'mw'],
    "rāmapādastava": ['mw'],
    "rāmapāla": ['mw'],
    "rāmapūga": ['mw'],
    "rāmapūjā": ['mw'],
    "rāmapūjāpaddhati": ['mw'],
    "rāmapūjāsaraṇi": ['mw'],
    "rāmapūjāstotra": ['mw'],
    "rāmapūjāvidhi": ['mw'],
    "rāmapūjāvidhānapaddhati": ['mw'],
    "rāmapūrvatāpanīya": ['mw'],
    "rāmarahasya": ['mw'],
    "rāmarahasyopaniṣad": ['mw'],
    "rāmarakṣā": ['mw'],
    "rāmarakṣākavaca": ['mw'],
    "rāmarakṣāstotra": ['mw'],
    "rāmarakṣāstotramālā": ['mw'],
    "rāmarasāmṛta": ['mw'],
    "rāmaratnākara": ['mw'],
    "rāmarudra": ['mw'],
    "rāmarāja": ['mw'],
    "rāmarāma": ['mw'],
    "rāmarāsa": ['mw'],
    "rāmarṣi": ['mw'],
    "rāmasahasranāman": ['mw'],
    "rāmasahasranāmastotra": ['mw'],
    "rāmasahasranāmavivaraṇa": ['mw'],
    "rāmasakha": ['mw'],
    "rāmasamuddhāra": ['mw'],
    "rāmasaparyāsopāna": ['mw'],
    "rāmasaptaratna": ['mw'],
    "rāmasaras": ['mw'],
    "rāmasena": ['mw'],
    "rāmasenaka": ['mw'],
    "rāmasetu": ['mw'],
    "rāmasetupradīpa": ['mw'],
    "rāmasevaka": ['mw'],
    "rāmasiddhāntasaṃgraha": ['mw'],
    "rāmasiṃha": ['mw'],
    "rāmasiṃhadeva": ['mw'],
    "rāmasiṃhavarman": ['mw'],
    "rāmastavarāja": ['mw'],
    "rāmastotra": ['mw'],
    "rāmastuti": ['mw'],
    "rāmasubrahmaṇya": ['mw'],
    "rāmasvasṛ": ['mw'],
    "rāmasvāmin": ['mw'],
    "rāmasāhi": ['mw'],
    "rāmasūkta": ['mw'],
    "rāmatantra": ['mw'],
    "rāmatapana": ['mw'],
    "rāmataraṇī": ['mw'],
    "rāmataruṇī": ['mw'],
    "rāmatattvabhāskara": ['mw'],
    "rāmatattvaprakāśa": ['mw'],
    "rāmatoṣaṇa": ['mw'],
    "rāmatrailokyamohanakavaca": ['mw'],
    "rāmatrayodaśākṣarī": ['mw'],
    "rāmatriṃśannāmastotra": ['mw'],
    "rāmatva": ['mw'],
    "rāmatāpanopaniṣad": ['mw'],
    "rāmatāpanī": ['cae', 'mw'],
    "rāmatāpanīya": ['mw'],
    "rāmatāpinī": ['mw'],
    "rāmatārakabrahmopaniṣad": ['mw'],
    "rāmatārakamantraṭīkā": ['mw'],
    "rāmatīrtha": ['cae', 'mw'],
    "rāmatīrthamāhātmya": ['mw'],
    "rāmavacana": ['mw'],
    "rāmavajrapañjarakavaca": ['mw'],
    "rāmavallabha": ['mw'],
    "rāmavardhana": ['mw'],
    "rāmavarman": ['mw'],
    "rāmavarṇanastotra": ['mw'],
    "rāmavijñāpanastotra": ['mw'],
    "rāmavilāsakāvya": ['mw'],
    "rāmavinoda": ['mw'],
    "rāmavinodakaraṇa": ['mw'],
    "rāmaviśvarūpastotra": ['mw'],
    "rāmavratin": ['bhs', 'mw'],
    "rāmavyākaraṇa": ['mw'],
    "rāmavāṇa": ['mw'],
    "rāmavīṇā": ['mw'],
    "rāmayantra": ['mw'],
    "rāmayantrapūjāpaddhati": ['mw'],
    "rāmayaśas": ['mw'],
    "rāmaśara": ['mw'],
    "rāmaśarman": ['mw'],
    "rāmaśataka": ['mw'],
    "rāmaśaṃkara": ['mw'],
    "rāmaśeṣa": ['mw'],
    "rāmaśilāmāhātmya": ['mw'],
    "rāmaśiṣya": ['mw'],
    "rāmaśrīkramacandrikā": ['mw'],
    "rāmaśrīpāda": ['mw'],
    "rāmaśāstrin": ['mw'],
    "rāmaśītalā": ['mw'],
    "rāmaṇa": ['mw'],
    "rāmaṇeyyaka": ['cped'],
    "rāmaṇi": ['mw'],
    "rāmaṇyaka": ['mw'],
    "rāmaṇā": ['mw'],
    "rāmaṇīyaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "rāmaṛṣi": ['mw'],
    "rāmaṣaḍakṣaramantrarāja": ['mw'],
    "rāmaṣaḍakṣaravidhāna": ['mw'],
    "rāmaṣoḍaśanāman": ['mw'],
    "rāmaṭha": ['cae', 'mw'],
    "rāmaṭhaḥ": ['ap90'],
    "rāmaṭhī": ['mw'],
    "rāmbha": ['mw'],
    "rāmendra": ['mw'],
    "rāmendravana": ['mw'],
    "rāmeśa": ['mw'],
    "rāmeśvara": ['cae', 'ddsa', 'mw'],
    "rāmeśvaradatta": ['mw'],
    "rāmeśvarapūjā": ['mw'],
    "rāmeśvarastava": ['mw'],
    "rāmeṣu": ['mw'],
    "rāmi": ['mw'],
    "rāmila": ['mw'],
    "rāmilaḥ": ['ap90'],
    "rāmin": ['mw'],
    "rāmiā": ['gra'],
    "rāmoda": ['mw'],
    "rāmodanta": ['mw'],
    "rāmodaya": ['mw'],
    "rāmodāyana": ['mw'],
    "rāmopaniṣad": ['mw'],
    "rāmopaniṣatpañcaka": ['mw'],
    "rāmopādhyāya": ['mw'],
    "rāmopākhyāna": ['mw'],
    "rāmopāsaka": ['mw'],
    "rāmopāsanakrama": ['mw'],
    "rāmottaratāpanīya": ['mw'],
    "rāmuṣa": ['ddsa', 'mw'],
    "rāmyā": ['cae', 'ddsa', 'gra', 'mw'],
    "rāmā": ['ap90', 'ddsa', 'mw'],
    "rāmābhinanda": ['mw'],
    "rāmābhiṣeka": ['mw'],
    "rāmābhyudaya": ['mw'],
    "rāmābhyudayatilaka": ['mw'],
    "rāmābhyudayavyākhyāna": ['mw'],
    "rāmācakra": ['mw'],
    "rāmādevī": ['mw'],
    "rāmādhikaraṇa": ['mw'],
    "rāmādhipati": ['mw'],
    "rāmādhāra": ['mw'],
    "rāmādvaya": ['mw'],
    "rāmāgnicit": ['mw'],
    "rāmāgnija": ['mw'],
    "rāmākheṭaka": ['mw'],
    "rāmāliṅganakāma": ['mw'],
    "rāmāmātya": ['mw'],
    "rāmānanda": ['ddsa', 'mw'],
    "rāmānandarāya": ['mw'],
    "rāmānandasvāmin": ['mw'],
    "rāmānandatīrtha": ['mw'],
    "rāmānandīya": ['mw'],
    "rāmānuja": ['mw'],
    "rāmānujabhāṣyagāmbhīrya": ['mw'],
    "rāmānujacampū": ['mw'],
    "rāmānujacarita": ['mw'],
    "rāmānujacaritra": ['mw'],
    "rāmānujadarśana": ['mw'],
    "rāmānujadaṇḍaka": ['mw'],
    "rāmānujadivyacaritra": ['mw'],
    "rāmānujagrantha": ['mw'],
    "rāmānujaguruparamparā": ['mw'],
    "rāmānujamatadhvaṃsana": ['mw'],
    "rāmānujamatakhaṇḍana": ['mw'],
    "rāmānujamauktika": ['mw'],
    "rāmānujasiddhāntapadavī": ['mw'],
    "rāmānujasiddhāntasaṃgraha": ['mw'],
    "rāmānujasiddhāntavijaya": ['mw'],
    "rāmānujastotra": ['mw'],
    "rāmānujasuprabhāta": ['mw'],
    "rāmānujasvāmin": ['mw'],
    "rāmānujavaṃśāvali": ['mw'],
    "rāmānujavijaya": ['mw'],
    "rāmānujaśatakaṭīkā": ['mw'],
    "rāmānujārādhanavidhi": ['mw'],
    "rāmānujāṣṭottara": ['mw'],
    "rāmānujīya": ['mw'],
    "rāmānujīyasiddhānta": ['mw'],
    "rāmānusmṛti": ['mw'],
    "rāmānuṣṭubh": ['mw'],
    "rāmārcana": ['mw'],
    "rāmārcanacandrikā": ['mw'],
    "rāmārcanadīpikā": ['mw'],
    "rāmārcanapaddhati": ['mw'],
    "rāmārcanaratnākara": ['mw'],
    "rāmārcanasopāna": ['mw'],
    "rāmārcanavidhi": ['mw'],
    "rāmārcā": ['mw'],
    "rāmārcāpaddhati": ['mw'],
    "rāmārya": ['mw'],
    "rāmāryavijñapti": ['mw'],
    "rāmāryaśataka": ['mw'],
    "rāmāryā": ['mw'],
    "rāmātmaikyaprakāśikā": ['mw'],
    "rāmāvakṣojopama": ['mw'],
    "rāmāvarānta": ['bhs'],
    "rāmāyaṇa": ['cae', 'mw'],
    "rāmāyaṇabhāratasārasaṃgraha": ['mw'],
    "rāmāyaṇacampū": ['mw'],
    "rāmāyaṇakathā": ['mw'],
    "rāmāyaṇakathāpraśna": ['mw'],
    "rāmāyaṇakathāsāra": ['mw'],
    "rāmāyaṇakathāsāramañjarī": ['mw'],
    "rāmāyaṇakālanirṇayacandrikā": ['mw'],
    "rāmāyaṇakūṭaṭīkā": ['mw'],
    "rāmāyaṇamahimādarśa": ['mw'],
    "rāmāyaṇamāhātmya": ['mw'],
    "rāmāyaṇanirvacana": ['mw'],
    "rāmāyaṇanāṭaka": ['mw'],
    "rāmāyaṇapaṭhanaphala": ['mw'],
    "rāmāyaṇaprabandha": ['mw'],
    "rāmāyaṇarahasya": ['mw'],
    "rāmāyaṇarañjanī": ['mw'],
    "rāmāyaṇasaṃgraha": ['mw'],
    "rāmāyaṇasaṃkṣepa": ['mw'],
    "rāmāyaṇastotra": ['mw'],
    "rāmāyaṇasāra": ['mw'],
    "rāmāyaṇasārasaṃgraha": ['mw'],
    "rāmāyaṇasūtradīpikā": ['mw'],
    "rāmāyaṇatattvadarpaṇa": ['mw'],
    "rāmāyaṇatātparyadīpikā": ['mw'],
    "rāmāyaṇatātparyanirṇaya": ['mw'],
    "rāmāyaṇatātparyasaṃgraha": ['mw'],
    "rāmāyaṇavidhi": ['mw'],
    "rāmāyaṇaviveka": ['mw'],
    "rāmāyaṇika": ['mw'],
    "rāmāyaṇopanyāsaśloka": ['mw'],
    "rāmāyaṇāyodhyākāṇḍa": ['mw'],
    "rāmāyaṇī": ['mw'],
    "rāmāyaṇīya": ['mw'],
    "rāmāśrama": ['mw'],
    "rāmāśramoddhārakośa": ['mw'],
    "rāmāśvamedha": ['mw'],
    "rāmāśvamedhika": ['mw'],
    "rāmāṅkanāṭikā": ['mw'],
    "rāmāṇḍāra": ['mw'],
    "rāmāṣṭaka": ['mw'],
    "rāmāṣṭakavyākhyā": ['mw'],
    "rāmāṣṭaviṃśatināmastotra": ['mw'],
    "rāmāṣṭottaraśatanāman": ['mw'],
    "rāmī": ['ddsa', 'gra', 'mw'],
    "rāndhasa": ['mw'],
    "rāndrya": ['gra', 'mw'],
    "rāpya": ['mw'],
    "rārahāṇa": ['mw'],
    "rārakṣāṇa": ['mw'],
    "rārā": ['mw'],
    "rās": ['ap90', 'cae', 'ddsa', 'mw'],
    "rāsa": ['cae', 'ddsa', 'mw'],
    "rāsabha": ['cae', 'ddsa', 'gra', 'mw'],
    "rāsabhadhūsara": ['mw'],
    "rāsabhasena": ['mw'],
    "rāsabhavandinī": ['mw'],
    "rāsabhayukta": ['mw'],
    "rāsabhaḥ": ['ap90'],
    "rāsabhāruṇa": ['mw'],
    "rāsabhārāva": ['mw'],
    "rāsabhī": ['mw'],
    "rāsagoṣṭhī": ['mw'],
    "rāsagītikā": ['mw'],
    "rāsaka": ['mw'],
    "rāsakaṃ": ['ap90'],
    "rāsakrīḍā": ['mw'],
    "rāsakrīḍāmāhātmya": ['mw'],
    "rāsamahotsava": ['mw'],
    "rāsamañjarī": ['mw'],
    "rāsamaṇḍala": ['mw'],
    "rāsana": ['ap90', 'mw'],
    "rāsapañcādhyāyī": ['mw'],
    "rāsapraṇetṛ": ['mw'],
    "rāsasundaramahākāvya": ['mw'],
    "rāsavilāsa": ['mw'],
    "rāsayātrā": ['mw'],
    "rāsayātrāpaddhati": ['mw'],
    "rāsayātrāviveka": ['mw'],
    "rāsaḥ": ['ap90'],
    "rāserasa": ['mw'],
    "rāserasaḥ": ['ap90'],
    "rāsi": ['cped'],
    "rāsin": ['mw'],
    "rāsivaḍḍhaka": ['cped'],
    "rāsnā": ['ap90', 'cae', 'mw'],
    "rāsnākā": ['mw'],
    "rāsnāva": ['mw'],
    "rāsollāsatantra": ['mw'],
    "rāspa": ['mw'],
    "rāspina": ['cae', 'gra', 'mw'],
    "rāspira": ['cae', 'gra', 'mw'],
    "rāsya": ['mw'],
    "rāsāyana": ['mw'],
    "rāta": ['cae', 'ddsa', 'mw'],
    "rātahavis": ['cae', 'gra', 'mw'],
    "rātahavya": ['cae', 'gra', 'mw'],
    "rātamanas": ['mw'],
    "rātantī": ['mw'],
    "rātaṃtī": ['ap90'],
    "rātha": ['mw'],
    "rāthagaṇaka": ['mw'],
    "rāthajiteyī": ['mw'],
    "rāthakārika": ['mw'],
    "rāthakārya": ['mw'],
    "rāthantara": ['ddsa'],
    "rāthaproṣṭha": ['mw'],
    "rāthaṃtara": ['mw'],
    "rāthaṃtari": ['mw'],
    "rāthaṃtarāyaṇa": ['mw'],
    "rāthaṃtarī": ['mw'],
    "rāthia": ['gra'],
    "rāthya": ['cae', 'gra', 'mw'],
    "rāthītara": ['mw'],
    "rāthītarāyaṇa": ['mw'],
    "rāthītarīputra": ['mw'],
    "rāti": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rātikula": ['mw'],
    "rātin": ['cae', 'gra', 'mw'],
    "rātiṣāc": ['cae', 'gra', 'mw'],
    "rātna": ['mw'],
    "rātra": ['cae', 'ddsa', 'gra', 'mw'],
    "rātraka": ['ap90', 'cae', 'mw'],
    "rātrau": ['mw'],
    "rātraubhava": ['mw'],
    "rātri": ['cae', 'ddsa', 'mw'],
    "rātribala": ['mw'],
    "rātribhojana": ['mw'],
    "rātribhojananiṣedha": ['mw'],
    "rātribhujaṃga": ['mw'],
    "rātribhṛt": ['mw'],
    "rātricara": ['mw'],
    "rātricaryā": ['cae', 'mw'],
    "rātricchandas": ['mw'],
    "rātricāra": ['mw'],
    "rātridevata": ['mw'],
    "rātridivam": ['mw'],
    "rātridviṣ": ['mw'],
    "rātrihiṇḍaka": ['mw'],
    "rātrihuta": ['mw'],
    "rātrihāsa": ['mw'],
    "rātrija": ['mw'],
    "rātrijala": ['mw'],
    "rātrijāgara": ['cae', 'mw'],
    "rātrijāgarada": ['mw'],
    "rātrijāgaraṇa": ['mw'],
    "rātrika": ['ap90', 'cae', 'mw'],
    "rātrikara": ['mw'],
    "rātrikā": ['mw'],
    "rātrikāla": ['mw'],
    "rātrilagnanirūpaṇa": ['mw'],
    "rātriloka": ['mw'],
    "rātrimaya": ['cae', 'mw'],
    "rātrimaṇi": ['mw'],
    "rātrimaṭa": ['mw'],
    "rātrimmanya": ['mw'],
    "rātrimāraṇa": ['mw'],
    "rātrinātha": ['mw'],
    "rātrināśana": ['mw'],
    "rātripadavicāra": ['mw'],
    "rātripariśiṣṭa": ['mw'],
    "rātriparyuṣita": ['mw'],
    "rātriparyāya": ['mw'],
    "rātripuṣpa": ['mw'],
    "rātripūjā": ['mw'],
    "rātrirakṣaka": ['cae', 'mw'],
    "rātrirāga": ['mw'],
    "rātrisahasra": ['mw'],
    "rātrisattra": ['cae', 'mw'],
    "rātrisācaya": ['mw'],
    "rātrisāman": ['mw'],
    "rātrisūkta": ['mw'],
    "rātrisūktavidhāna": ['mw'],
    "rātritarā": ['mw'],
    "rātritithi": ['mw'],
    "rātriveda": ['mw'],
    "rātrivedin": ['mw'],
    "rātrivigama": ['mw'],
    "rātrivihārin": ['cae', 'mw'],
    "rātriviśleṣagāmin": ['mw'],
    "rātrivāsas": ['mw'],
    "rātriyoga": ['mw'],
    "rātriśeṣa": ['cae', 'mw'],
    "rātriśṛta": ['mw'],
    "rātriḥ": ['ap90'],
    "rātriṃcara": ['mw'],
    "rātriṃdiva": ['cae', 'mw'],
    "rātriṃdivam": ['mw'],
    "rātriṃdivasa": ['bhs', 'mw'],
    "rātriṃdivaṃ": ['ap90'],
    "rātriṃdivā": ['mw'],
    "rātriṃmanya": ['ap90'],
    "rātriṃvāsa": ['bhs'],
    "rātriṣāman": ['mw'],
    "rātry": ['mw'],
    "rātryahan": ['cae'],
    "rātryahanī": ['mw'],
    "rātryandha": ['ddsa', 'mw'],
    "rātryandhatā": ['mw'],
    "rātryaṭa": ['mw'],
    "rātryupāya": ['cae', 'mw'],
    "rātryāgama": ['cae', 'mw'],
    "rātryākhyā": ['mw'],
    "rātryām": ['mw'],
    "rātryāndhya": ['mw'],
    "rātrī": ['cae', 'ddsa', 'gra', 'mw'],
    "rātrīdaivodāsa": ['mw'],
    "rātrīkaraṇa": ['mw'],
    "rātrīsūkta": ['mw'],
    "rātrīṇa": ['ap90', 'mw'],
    "rātula": ['mw'],
    "rāula": ['mw'],
    "rāva": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "rāvan": ['cae', 'gra', 'mw'],
    "rāvauṭa": ['mw'],
    "rāvaḥ": ['ap90'],
    "rāvaṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "rāvaṇabhaiṭ": ['mw'],
    "rāvaṇacaritra": ['mw'],
    "rāvaṇagaṅgā": ['mw'],
    "rāvaṇahasra": ['mw'],
    "rāvaṇahrada": ['mw'],
    "rāvaṇasūdana": ['mw'],
    "rāvaṇavadha": ['mw'],
    "rāvaṇavaha": ['mw'],
    "rāvaṇi": ['cae', 'mw'],
    "rāvaṇiḥ": ['ap90'],
    "rāvaṇāri": ['mw'],
    "rāvaṇārjunīya": ['mw'],
    "rāvaṇī": ['bhs', 'mw'],
    "rāvaṭ": ['mw'],
    "rāvin": ['cae', 'mw'],
    "rāvita": ['cae', 'ddsa', 'mw'],
    "rāya": ['ddsa', 'gra', 'mw'],
    "rāyabhāṭī": ['ap90', 'mw'],
    "rāyamadanapāla": ['mw'],
    "rāyambhaṭṭa": ['mw'],
    "rāyamukuṭa": ['mw'],
    "rāyanarasiṃhapaṇḍita": ['mw'],
    "rāyaraṅgāla": ['mw'],
    "rāyarāghava": ['mw'],
    "rāyas": ['mw'],
    "rāyasiṃhotsava": ['mw'],
    "rāyaskāma": ['cae', 'gra', 'mw'],
    "rāyaspoṣa": ['cae', 'ddsa', 'mw'],
    "rāyaspoṣadā": ['cae', 'mw'],
    "rāyaspoṣadāvan": ['cae', 'mw'],
    "rāyaspoṣaka": ['mw'],
    "rāyaspoṣavani": ['cae', 'mw'],
    "rāyavaṅgāla": ['mw'],
    "rāyavaṅkola": ['mw'],
    "rāyaḥ": ['ap90'],
    "rāyaṇa": ['mw'],
    "rāyaṇaṃ": ['ap90'],
    "rāyaṇendrasarasvatī": ['mw'],
    "rāyo": ['mw'],
    "rāyovāja": ['mw'],
    "rāyovājīya": ['mw'],
    "rāyāna": ['mw'],
    "rāyāṇanīya": ['mw'],
    "rāś": ['mw'],
    "rāśabha": ['mw'],
    "rāśi": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "rāśibheda": ['mw'],
    "rāśibhoga": ['mw'],
    "rāśibhāga": ['mw'],
    "rāśibhāgānubandha": ['mw'],
    "rāśibhāgāpavāha": ['mw'],
    "rāśicakra": ['mw'],
    "rāśidāśāphala": ['mw'],
    "rāśigata": ['mw'],
    "rāśika": ['mw'],
    "rāśimarāya": ['mw'],
    "rāśināman": ['mw'],
    "rāśipa": ['mw'],
    "rāśipravibhāga": ['mw'],
    "rāśiprāyaścitta": ['mw'],
    "rāśistha": ['cae', 'mw'],
    "rāśitraya": ['mw'],
    "rāśivyavahāra": ['mw'],
    "rāśiśas": ['cae', 'mw'],
    "rāśiḥ": ['ap90'],
    "rāśy": ['mw'],
    "rāśya": ['bhs'],
    "rāśyabhidhāna": ['mw'],
    "rāśyadhipa": ['mw'],
    "rāśyaṃśa": ['mw'],
    "rāśī": ['mw'],
    "rāśībhū": ['mw'],
    "rāśībhūta": ['mw'],
    "rāśībhūtadhana": ['mw'],
    "rāśīkaraṇa": ['mw'],
    "rāśīkaraṇabhāṣya": ['mw'],
    "rāśīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "rāśīkṛta": ['ap90', 'mw'],
    "rāśīna": ['bhs'],
    "rāḍha": ['mw'],
    "rāḍhā": ['ap90', 'ddsa', 'mw'],
    "rāḍhāpura": ['mw'],
    "rāḍhīya": ['mw'],
    "rāṃbhaḥ": ['ap90'],
    "rāṃkalaḥ": ['ap90'],
    "rāṃkava": ['ap90'],
    "rāṅga": ['cae', 'mw'],
    "rāṅgaṇa": ['mw'],
    "rāṅkala": ['mw'],
    "rāṅkava": ['cae', 'ddsa', 'mw'],
    "rāṅkavaka": ['mw'],
    "rāṅkavakūṭaśāyin": ['mw'],
    "rāṅkavājina": ['mw'],
    "rāṅkavājinasaṃsparśa": ['mw'],
    "rāṅkavājinaśāyin": ['mw'],
    "rāṅkavāstaraṇa": ['mw'],
    "rāṅkavāstṛta": ['mw'],
    "rāṅkavāyaṇa": ['mw'],
    "rāṇa": ['mw'],
    "rāṇaka": ['mw'],
    "rāṇakojjīvinī": ['mw'],
    "rāṇaḍya": ['mw'],
    "rāṇaṃ": ['ap90'],
    "rāṇi": ['mw'],
    "rāṇiga": ['mw'],
    "rāṇikā": ['ap90', 'mw'],
    "rāṇā": ['mw'],
    "rāṇādevīmāhātmya": ['mw'],
    "rāṇāka": ['mw'],
    "rāṇāyana": ['mw'],
    "rāṇāyanī": ['mw'],
    "rāṇāyanīputra": ['mw'],
    "rāṇāyanīya": ['ddsa', 'mw'],
    "rāṇāyanīyasūtra": ['mw'],
    "rāṇāyanīyi": ['mw'],
    "rāṇī": ['mw'],
    "rāṇḍya": ['gra', 'mw'],
    "rāṣṭa": ['bhs'],
    "rāṣṭra": ['cae', 'ddsa', 'gra', 'mw'],
    "rāṣṭrabhaya": ['mw'],
    "rāṣṭrabhaṅga": ['cae', 'mw'],
    "rāṣṭrabheda": ['mw'],
    "rāṣṭrabhedin": ['cae', 'mw'],
    "rāṣṭrabhṛt": ['cae', 'mw'],
    "rāṣṭrabhṛti": ['cae', 'mw'],
    "rāṣṭrabhṛttva": ['mw'],
    "rāṣṭrabhṛtya": ['mw'],
    "rāṣṭradeva": ['bhs'],
    "rāṣṭradevī": ['mw'],
    "rāṣṭradipsu": ['mw'],
    "rāṣṭradā": ['mw'],
    "rāṣṭragopa": ['cae', 'mw'],
    "rāṣṭragupti": ['mw'],
    "rāṣṭraka": ['cae', 'ddsa', 'mw'],
    "rāṣṭrakarṣaṇa": ['cae', 'mw'],
    "rāṣṭrakāma": ['mw'],
    "rāṣṭrakūṭa": ['mw'],
    "rāṣṭramukhya": ['mw'],
    "rāṣṭrapata": ['mw'],
    "rāṣṭrapati": ['cae', 'mw'],
    "rāṣṭrapāla": ['bhs', 'cae', 'mw'],
    "rāṣṭrapālaparipṛcchā": ['bhs', 'mw'],
    "rāṣṭrapālikā": ['mw'],
    "rāṣṭrapālī": ['mw'],
    "rāṣṭrasaṃvarga": ['mw'],
    "rāṣṭratantra": ['mw'],
    "rāṣṭravardhana": ['cae', 'mw'],
    "rāṣṭraviplava": ['mw'],
    "rāṣṭravivṛddhi": ['mw'],
    "rāṣṭravāsin": ['mw'],
    "rāṣṭraṃ": ['ap90'],
    "rāṣṭri": ['cae', 'ddsa', 'mw'],
    "rāṣṭrika": ['cae', 'mw'],
    "rāṣṭrikaḥ": ['ap90'],
    "rāṣṭrikā": ['mw'],
    "rāṣṭrin": ['cae', 'mw'],
    "rāṣṭriya": ['ap90', 'cae', 'mw'],
    "rāṣṭriyasyāla": ['cae'],
    "rāṣṭriḥ": ['ap90'],
    "rāṣṭroḍa": ['mw'],
    "rāṣṭrābhivṛddhi": ['mw'],
    "rāṣṭrāntapāla": ['mw'],
    "rāṣṭrī": ['cae', 'ddsa', 'gra', 'mw'],
    "rāṣṭrīya": ['cae', 'mw'],
    "rāṭha": ['mw'],
    "rāṭi": ['mw'],
    "rāṭikā": ['mw'],
    "rāṭiḥ": ['ap90'],
    "rāṭu": ['mw'],
    "rī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "rīdhā": ['mw'],
    "rījyā": ['ap90', 'mw'],
    "rīra": ['mw'],
    "rīrama": ['ddsa'],
    "rīriṣaḥ": ['ddsa'],
    "rīrī": ['mw'],
    "rīti": ['cae', 'ddsa', 'gra', 'mw'],
    "rītiap": ['gra'],
    "rītibaddha": ['mw'],
    "rītija": ['mw'],
    "rītijña": ['mw'],
    "rītika": ['mw'],
    "rītikaṃ": ['ap90'],
    "rītikusuma": ['mw'],
    "rītikā": ['mw'],
    "rītiprastha": ['mw'],
    "rītipuṣpa": ['mw'],
    "rītivṛttilakṣaṇa": ['mw'],
    "rītiāp": ['gra'],
    "rītiḥ": ['ap90'],
    "rītyap": ['cae', 'gra', 'mw'],
    "rītībhū": ['ddsa'],
    "rītībhūta": ['mw'],
    "rīv": ['ap90', 'mw'],
    "rīḍha": ['mw'],
    "rīḍhaka": ['mw'],
    "rīḍhakaḥ": ['ap90'],
    "rīḍhā": ['ap90', 'ddsa'],
    "rīṇa": ['ap90', 'mw'],
    "rīṭhā": ['mw'],
    "rīṭhākarañja": ['mw'],
    "rīṭi": ['mw'],
    "rūcaka": ['mw'],
    "rūhana": ['cped'],
    "rūhati": ['cped'],
    "rūhi": ['cped'],
    "rūkhara": ['mw'],
    "rūkṣ": ['ap90', 'mw'],
    "rūkṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "rūkṣabhāva": ['mw'],
    "rūkṣadarbha": ['mw'],
    "rūkṣadurbala": ['mw'],
    "rūkṣagandha": ['mw'],
    "rūkṣagandhaka": ['mw'],
    "rūkṣaka": ['bhs'],
    "rūkṣamlānāṅga": ['mw'],
    "rūkṣaniṣṭhuravāda": ['mw'],
    "rūkṣapattra": ['mw'],
    "rūkṣapeṣam": ['mw'],
    "rūkṣapriya": ['mw'],
    "rūkṣasvana": ['cae'],
    "rūkṣasvara": ['mw'],
    "rūkṣasvaram": ['mw'],
    "rūkṣasvāduphala": ['mw'],
    "rūkṣatva": ['mw'],
    "rūkṣatā": ['mw'],
    "rūkṣavarṇa": ['mw'],
    "rūkṣavāc": ['cae', 'mw'],
    "rūkṣavādin": ['mw'],
    "rūkṣavāluka": ['mw'],
    "rūkṣavāśin": ['mw'],
    "rūkṣay": ['cae'],
    "rūkṣaya": ['ddsa'],
    "rūkṣaṇa": ['cae', 'mw'],
    "rūkṣaṇaṃ": ['ap90'],
    "rūkṣaṇīya": ['mw'],
    "rūkṣaṇīyā": ['mw'],
    "rūkṣita": ['ap90', 'gra', 'mw'],
    "rūkṣitatva": ['mw'],
    "rūkṣā": ['mw'],
    "rūkṣābhibhāṣin": ['mw'],
    "rūkṣīkṛ": ['cae', 'ddsa'],
    "rūkṣīkṛta": ['mw'],
    "rūma": ['mw'],
    "rūp": ['ap90', 'mw'],
    "rūpa": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "rūpabhava": ['cped'],
    "rūpabheda": ['mw'],
    "rūpabhedaprakāśa": ['mw'],
    "rūpabhāgānubandha": ['mw'],
    "rūpabhāgāpavāha": ['mw'],
    "rūpabhāj": ['mw'],
    "rūpabhṛt": ['cae', 'mw'],
    "rūpacandra": ['mw'],
    "rūpacintāmaṇi": ['mw'],
    "rūpadassana": ['cped'],
    "rūpadeva": ['mw'],
    "rūpadhara": ['cae', 'ddsa', 'mw'],
    "rūpadheya": ['mw'],
    "rūpadhārin": ['cae', 'mw'],
    "rūpadhāritva": ['mw'],
    "rūpadhātu": ['bhs', 'mw'],
    "rūpadhātuka": ['bhs'],
    "rūpadhṛk": ['mw'],
    "rūpadhṛt": ['cae', 'mw'],
    "rūpadīpakapiṅgala": ['mw'],
    "rūpagata": ['bhs'],
    "rūpagosvāmiguṇaleśasūcakanāmadaśaka": ['mw'],
    "rūpagosvāmin": ['mw'],
    "rūpagraha": ['mw'],
    "rūpaguṇa": ['cae', 'mw'],
    "rūpaguṇopeta": ['cae', 'mw'],
    "rūpahāni": ['mw'],
    "rūpajña": ['mw'],
    "rūpajīva": ['mw'],
    "rūpajīvanā": ['mw'],
    "rūpaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "rūpakanṛtya": ['mw'],
    "rūpakaparibhāṣā": ['mw'],
    "rūpakartṛ": ['mw'],
    "rūpakarūpaka": ['cae', 'mw'],
    "rūpakatāla": ['mw'],
    "rūpakavirājagosvāmiguṇaleśasūcakāṣṭaka": ['mw'],
    "rūpakavākya": ['mw'],
    "rūpakaśabda": ['mw'],
    "rūpakā": ['mw'],
    "rūpakākhyaṣaḍaṅga": ['mw'],
    "rūpakāntā": ['mw'],
    "rūpakāra": ['cae', 'ddsa', 'mw'],
    "rūpakāya": ['bhs'],
    "rūpakṛt": ['cae', 'mw'],
    "rūpalatā": ['mw'],
    "rūpalāvaṇya": ['mw'],
    "rūpamatī": ['mw'],
    "rūpamañjarī": ['mw'],
    "rūpamañjarīguṇaleśasūcakāṣṭaka": ['mw'],
    "rūpamañjarīpādāmbujasevāprārthanā": ['mw'],
    "rūpamaṇḍana": ['mw'],
    "rūpamālā": ['mw'],
    "rūpamālī": ['mw'],
    "rūpamātra": ['mw'],
    "rūpanayana": ['mw'],
    "rūpanārāyaṇa": ['mw'],
    "rūpanārāyaṇacakravartin": ['mw'],
    "rūpanārāyaṇasena": ['mw'],
    "rūpanāśana": ['mw'],
    "rūpanāśin": ['cae', 'mw'],
    "rūpapa": ['mw'],
    "rūpaparikalpanā": ['mw'],
    "rūpapati": ['mw'],
    "rūpapraśna": ['mw'],
    "rūpapura": ['mw'],
    "rūparasagandhasparśavat": ['mw'],
    "rūparasasparśavat": ['mw'],
    "rūparatnākara": ['mw'],
    "rūparāga": ['cped', 'mw'],
    "rūpasampad": ['mw'],
    "rūpasampanna": ['mw'],
    "rūpasampatti": ['cped', 'mw'],
    "rūpasamṛddha": ['mw'],
    "rūpasamṛddhi": ['mw'],
    "rūpasanātana": ['mw'],
    "rūpasaubhāgyavat": ['mw'],
    "rūpasaṃpad": ['cae'],
    "rūpasaṃpanna": ['cae'],
    "rūpasena": ['mw'],
    "rūpasiddhi": ['mw'],
    "rūpasiri": ['cped'],
    "rūpaskandha": ['mw'],
    "rūpasparśavat": ['mw'],
    "rūpastha": ['mw'],
    "rūpasvin": ['mw'],
    "rūpasvinī": ['mw'],
    "rūpatama": ['mw'],
    "rūpataraṃgiṇī": ['mw'],
    "rūpatarka": ['mw'],
    "rūpatas": ['cae', 'ddsa', 'mw'],
    "rūpatattva": ['mw'],
    "rūpataṇhā": ['cped'],
    "rūpatva": ['mw'],
    "rūpatvajātipramāṇa": ['mw'],
    "rūpatā": ['mw'],
    "rūpavajrā": ['mw'],
    "rūpavant": ['bhs', 'cae', 'cped'],
    "rūpavat": ['ap90', 'mw'],
    "rūpavatī": ['bhs', 'mw'],
    "rūpavibhāga": ['mw'],
    "rūpavicāra": ['mw'],
    "rūpaviparyaya": ['cae', 'mw'],
    "rūpavāhika": ['mw'],
    "rūpavāsika": ['mw'],
    "rūpay": ['cae'],
    "rūpaya": ['ddsa'],
    "rūpayauvanavant": ['cae'],
    "rūpayauvanavat": ['ddsa', 'mw'],
    "rūpayauvanotsāhin": ['mw'],
    "rūpaśas": ['cae', 'gra', 'mw'],
    "rūpaśikhā": ['mw'],
    "rūpaśālin": ['cae', 'mw'],
    "rūpaṃ": ['ap90'],
    "rūpaṇa": ['cae', 'ddsa', 'mw'],
    "rūpaṇaṃ": ['ap90'],
    "rūpaṇya": ['bhs'],
    "rūpendriya": ['ddsa', 'mw'],
    "rūpeśvara": ['mw'],
    "rūpeśvarī": ['mw'],
    "rūpidāraka": ['cae', 'mw'],
    "rūpika": ['mw'],
    "rūpikā": ['mw'],
    "rūpin": ['ap90', 'cae', 'ddsa', 'mw'],
    "rūpinī": ['cped'],
    "rūpita": ['mw'],
    "rūpiya": ['cped'],
    "rūpiyamaya": ['cped'],
    "rūpiṇa": ['mw'],
    "rūpiṇikā": ['bhs', 'ddsa', 'mw'],
    "rūpiṇī": ['bhs'],
    "rūpoccaya": ['mw'],
    "rūpopajīvana": ['mw'],
    "rūpopajīvin": ['mw'],
    "rūpya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "rūpyada": ['cae', 'mw'],
    "rūpyadhauta": ['mw'],
    "rūpyaka": ['mw'],
    "rūpyaketu": ['bhs'],
    "rūpyamaya": ['mw'],
    "rūpyamayī": ['bhs'],
    "rūpyamākṣika": ['mw'],
    "rūpyamāṣa": ['mw'],
    "rūpyarajju": ['cae', 'mw'],
    "rūpyaratnaparīkṣā": ['mw'],
    "rūpyarukmamaya": ['mw'],
    "rūpyasvarṇamaṇimaya": ['mw'],
    "rūpyavatī": ['bhs'],
    "rūpyaśatamāna": ['mw'],
    "rūpyā": ['mw'],
    "rūpyācala": ['mw'],
    "rūpyādhyakṣa": ['mw'],
    "rūpā": ['mw'],
    "rūpābhigrāhita": ['mw'],
    "rūpādhibodha": ['mw'],
    "rūpājīva": ['cae', 'ddsa', 'mw'],
    "rūpājīvā": ['mw'],
    "rūpārammaṇa": ['cped'],
    "rūpāstra": ['mw'],
    "rūpāvacara": ['bhs', 'cped', 'mw'],
    "rūpāvalī": ['mw'],
    "rūpāvata": ['bhs', 'mw'],
    "rūpāvatyalaṃkaraṇa": ['mw'],
    "rūpāvatāra": ['mw'],
    "rūpāvatī": ['bhs', 'mw'],
    "rūpāyatana": ['mw'],
    "rūpāyudhabhṛt": ['mw'],
    "rūpāśraya": ['mw'],
    "rūpī": ['cped'],
    "rūpīkṛ": ['mw'],
    "rūpūpajīvinī": ['cped'],
    "rūra": ['cae', 'ddsa', 'mw'],
    "rūvuka": ['mw'],
    "rūvukaḥ": ['ap90'],
    "rūḍha": ['ap90', 'cae', 'ddsa', 'mw'],
    "rūḍhacīvara": ['bhs'],
    "rūḍhagranthi": ['mw'],
    "rūḍhamanyu": ['mw'],
    "rūḍhamūla": ['mw'],
    "rūḍhamūlatva": ['mw'],
    "rūḍhaparicchada": ['mw'],
    "rūḍhaparyāya": ['mw'],
    "rūḍhapraṇaya": ['mw'],
    "rūḍharāgapravāla": ['mw'],
    "rūḍhasauhṛda": ['mw'],
    "rūḍhaskandha": ['mw'],
    "rūḍhatṛṇāṅkura": ['mw'],
    "rūḍhavacana": ['mw'],
    "rūḍhavaṃśa": ['mw'],
    "rūḍhavraṇa": ['mw'],
    "rūḍhayauvana": ['mw'],
    "rūḍhayoga": ['mw'],
    "rūḍhaśmaśru": ['mw'],
    "rūḍhaśādvala": ['mw'],
    "rūḍhi": ['cae', 'ddsa', 'mw'],
    "rūḍhiśabda": ['mw'],
    "rūḍhiśabdatā": ['mw'],
    "rūḍhiḥ": ['ap90'],
    "rūḷha": ['cped'],
    "rūṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "rūṣa": ['mw'],
    "rūṣaka": ['mw'],
    "rūṣaṇa": ['cae', 'mw'],
    "rūṣaṇaṃ": ['ap90'],
    "rūṣita": ['ap90', 'mw'],
    "r̥": ['ddsa'],
    "r̥bhu": ['ddsa'],
    "r̥bhvan": ['ddsa'],
    "r̥bīsa": ['ddsa'],
    "r̥c": ['ddsa'],
    "r̥ca": ['ddsa'],
    "r̥ch": ['ddsa'],
    "r̥cīka": ['ddsa'],
    "r̥cīṣama": ['ddsa'],
    "r̥d": ['ddsa'],
    "r̥ddhi": ['ddsa'],
    "r̥dh": ['ddsa'],
    "r̥dhak": ['ddsa'],
    "r̥ggāthā": ['ddsa'],
    "r̥ghāvat": ['ddsa'],
    "r̥ghāya": ['ddsa'],
    "r̥gmin": ['ddsa'],
    "r̥j": ['ddsa'],
    "r̥jipya": ['ddsa'],
    "r̥jra": ['ddsa'],
    "r̥ju": ['ddsa'],
    "r̥jīka": ['ddsa'],
    "r̥jīti": ['ddsa'],
    "r̥jīyas": ['ddsa'],
    "r̥jīṣa": ['ddsa'],
    "r̥jūkṛ": ['ddsa'],
    "r̥ksaṃhitā": ['ddsa'],
    "r̥ktas": ['ddsa'],
    "r̥kvat": ['ddsa'],
    "r̥kāra": ['ddsa'],
    "r̥kṣa": ['ddsa'],
    "r̥kṣeṣṭi": ['ddsa'],
    "r̥ta": ['ddsa'],
    "r̥taya": ['ddsa'],
    "r̥tayā": ['ddsa'],
    "r̥te": ['ddsa'],
    "r̥tejā": ['ddsa'],
    "r̥terakṣas": ['ddsa'],
    "r̥tokti": ['ddsa'],
    "r̥tu": ['ddsa'],
    "r̥tukāla": ['ddsa'],
    "r̥tvanta": ['ddsa'],
    "r̥tvij": ['ddsa'],
    "r̥tviya": ['ddsa'],
    "r̥tāvan": ['ddsa'],
    "r̥tāya": ['ddsa'],
    "r̥ñjate": ['ddsa'],
    "r̥śya": ['ddsa'],
    "r̥ṅmaya": ['ddsa'],
    "r̥ṇa": ['ddsa'],
    "r̥ṇakartṛ": ['ddsa'],
    "r̥ṇika": ['ddsa'],
    "r̥ṇoddhāra": ['ddsa'],
    "r̥ṇādāna": ['ddsa'],
    "r̥ṣ": ['ddsa'],
    "r̥ṣabha": ['ddsa'],
    "r̥ṣi": ['ddsa'],
    "r̥ṣu": ['ddsa'],
    "r̥ṣva": ['ddsa'],
    "r̥ṣyamūka": ['ddsa'],
    "r̥ṣṭi": ['ddsa'],
    "sa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sabahumānam": ['cae', 'mw'],
    "sabala": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sabalasiṃha": ['mw'],
    "sabalatva": ['mw'],
    "sabalatā": ['mw'],
    "sabalavāhana": ['cae', 'mw'],
    "sabali": ['mw'],
    "sabaliḥ": ['ap90'],
    "sabalānuga": ['mw'],
    "sabalātkāram": ['cae', 'mw'],
    "sabandha": ['mw'],
    "sabandhaka": ['ddsa', 'mw'],
    "sabandhu": ['cae', 'gra', 'mw'],
    "sabar": ['gra', 'mw'],
    "sabardhu": ['gra', 'mw'],
    "sabardugha": ['cae', 'ddsa', 'gra', 'mw'],
    "sabarduh": ['cae', 'gra', 'mw'],
    "sabarhis": ['mw'],
    "sabaṃdhu": ['ap90'],
    "sabba": ['cped'],
    "sabbadhi": ['cped'],
    "sabbadā": ['cped'],
    "sabbakammika": ['cped'],
    "sabbakaṇiṭṭha": ['cped'],
    "sabbalokādhipacca": ['cped'],
    "sabbapacchato": ['cped'],
    "sabbapaṭhama": ['cped'],
    "sabbapaṭhamaṁ": ['cped'],
    "sabbasata": ['cped'],
    "sabbaso": ['cped'],
    "sabbasovaṇṇa": ['cped'],
    "sabbassa": ['cped'],
    "sabbassaharaṇa": ['cped'],
    "sabbathā": ['cped'],
    "sabbato": ['cped'],
    "sabbatra": ['cped'],
    "sabbattha": ['cped'],
    "sabbatthaka": ['cped'],
    "sabbavidū": ['cped'],
    "sabbaññutā": ['cped'],
    "sabbaññū": ['cped'],
    "sabbaṭṭhaka": ['cped'],
    "sabbhi": ['cped'],
    "sabda": ['mw'],
    "sabh": ['ddsa', 'mw'],
    "sabha": ['mw'],
    "sabhadramusta": ['mw'],
    "sabhaggata": ['cped'],
    "sabhaktikam": ['cae', 'ddsa', 'mw'],
    "sabhakṣa": ['cae', 'mw'],
    "sabharas": ['cae', 'gra', 'mw'],
    "sabhartṛkā": ['ap90', 'mw'],
    "sabhasmadvija": ['mw'],
    "sabhasmaka": ['mw'],
    "sabhasman": ['cae', 'mw'],
    "sabhava": ['mw'],
    "sabhaya": ['cae', 'mw'],
    "sabhayam": ['mw'],
    "sabhaṅga": ['mw'],
    "sabhaṅgaśleṣa": ['mw'],
    "sabheya": ['cae', 'gra', 'mw'],
    "sabheśvarastotra": ['mw'],
    "sabhika": ['bhs', 'cae', 'ddsa', 'mw'],
    "sabhikaḥ": ['ap90'],
    "sabhikā": ['bhs'],
    "sabhikṣuka": ['bhs'],
    "sabhocita": ['mw'],
    "sabhoddeśa": ['ddsa', 'mw'],
    "sabhojana": ['bhs', 'cped'],
    "sabhopaviṣṭa": ['mw'],
    "sabhrātṛ": ['mw'],
    "sabhrātṛka": ['mw'],
    "sabhrūbhaṅga": ['cae', 'mw'],
    "sabhrūbhaṅgam": ['mw'],
    "sabhrūbhedam": ['cae', 'mw'],
    "sabhrūkṣepam": ['cae', 'ddsa', 'mw'],
    "sabhrūvilāsam": ['cae', 'mw'],
    "sabhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "sabhyakaṇṭhābharaṇa": ['mw'],
    "sabhyatama": ['mw'],
    "sabhyatva": ['mw'],
    "sabhyatā": ['ap90', 'mw'],
    "sabhyetara": ['cae', 'mw'],
    "sabhyābharaṇa": ['mw'],
    "sabhyābhinavayati": ['mw'],
    "sabhā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sabhābharaṇa": ['mw'],
    "sabhācara": ['mw'],
    "sabhācāra": ['mw'],
    "sabhācāturya": ['mw'],
    "sabhādhairya": ['mw'],
    "sabhāga": ['bhs', 'cped', 'mw'],
    "sabhāgata": ['cae', 'mw'],
    "sabhāgatā": ['bhs', 'mw'],
    "sabhāgaya": ['mw'],
    "sabhāgaṭṭhāna": ['cped'],
    "sabhāgya": ['ddsa', 'mw'],
    "sabhāgṛha": ['mw'],
    "sabhāj": ['ap90', 'mw'],
    "sabhājana": ['cae', 'mw'],
    "sabhājanaṃ": ['ap90'],
    "sabhājay": ['cae'],
    "sabhājaya": ['ddsa'],
    "sabhājita": ['mw'],
    "sabhājya": ['mw'],
    "sabhākaumudī": ['mw'],
    "sabhākāra": ['mw'],
    "sabhākṣa": ['mw'],
    "sabhāmadhye": ['mw'],
    "sabhāmaṇḍana": ['mw'],
    "sabhāmaṇḍapa": ['cae', 'mw'],
    "sabhānara": ['mw'],
    "sabhāntare": ['mw'],
    "sabhānāyaka": ['mw'],
    "sabhānāṭaka": ['mw'],
    "sabhāpariṣad": ['mw'],
    "sabhāparvan": ['mw'],
    "sabhāpati": ['bhs', 'cae', 'ddsa', 'mw'],
    "sabhāpativilāsa": ['mw'],
    "sabhāprapādin": ['mw'],
    "sabhāpraveśana": ['mw'],
    "sabhāpāla": ['cae', 'mw'],
    "sabhāpūjā": ['mw'],
    "sabhāratā": ['mw'],
    "sabhārañjana": ['mw'],
    "sabhāraṇyavitaṅkavat": ['mw'],
    "sabhārya": ['cae', 'ddsa', 'mw'],
    "sabhāryaka": ['mw'],
    "sabhāsad": ['cae', 'ddsa', 'mw'],
    "sabhāsada": ['mw'],
    "sabhāsaṃnayana": ['mw'],
    "sabhāsiṃha": ['mw'],
    "sabhāstha": ['mw'],
    "sabhāsthānastha": ['mw'],
    "sabhāsthāṇu": ['mw'],
    "sabhāstāra": ['mw'],
    "sabhāsāha": ['cae', 'gra', 'mw'],
    "sabhāsīna": ['mw'],
    "sabhātaraṃga": ['mw'],
    "sabhāva": ['cped'],
    "sabhāvadhamma": ['cped'],
    "sabhāvana": ['mw'],
    "sabhāvanaḥ": ['ap90'],
    "sabhāvant": ['cae'],
    "sabhāvasara": ['mw'],
    "sabhāvat": ['gra', 'mw'],
    "sabhāvaśakara": ['mw'],
    "sabhāvin": ['mw'],
    "sabhāvinoda": ['mw'],
    "sabhāvuttī": ['cped'],
    "sabhāyogya": ['mw'],
    "sabhāṇḍa": ['mw'],
    "sabhīka": ['mw'],
    "sabhīkaḥ": ['ap90'],
    "sabhīma": ['mw'],
    "sabhīti": ['mw'],
    "sabhūmi": ['mw'],
    "sabhūta": ['mw'],
    "sabhṛkuṭīmukha": ['mw'],
    "sabhṛti": ['gra', 'mw'],
    "sabhṛtya": ['cae', 'mw'],
    "sabindu": ['mw'],
    "sabrahmacaryaṃ": ['ap90'],
    "sabrahmacārika": ['mw'],
    "sabrahmacārin": ['ap90', 'cae', 'mw'],
    "sabrahmacārī": ['cped'],
    "sabrahmaka": ['cped', 'mw'],
    "sabrāhmaṇa": ['mw'],
    "sabrāhmaṇaspatya": ['mw'],
    "sabuva": ['mw'],
    "sabva": ['mw'],
    "sabādh": ['cae', 'mw'],
    "sabādha": ['ap90', 'cae', 'mw'],
    "sabādhas": ['cae', 'gra', 'mw'],
    "sabāhyāntaḥkaraṇa": ['cae', 'mw'],
    "sabālavṛddha": ['mw'],
    "sabāndhava": ['mw'],
    "sabāṣpa": ['cae', 'mw'],
    "sabāṣpagadgadam": ['mw'],
    "sabāṣpaka": ['mw'],
    "sabāṣpam": ['mw'],
    "sabībhatsam": ['mw'],
    "sabīja": ['mw'],
    "sabījatva": ['mw'],
    "sac": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "saca": ['bhs', 'gra', 'mw'],
    "sacadhyai": ['cae', 'mw'],
    "sacaila": ['cae', 'mw'],
    "sacailam": ['mw'],
    "sacaitanya": ['mw'],
    "sacakita": ['ap90', 'mw'],
    "sacakitam": ['cae', 'ddsa', 'mw'],
    "sacakra": ['cae', 'mw'],
    "sacakram": ['mw'],
    "sacakrin": ['cae', 'mw'],
    "sacakropaskara": ['mw'],
    "sacakṣus": ['cae', 'mw'],
    "sacakṣuṣa": ['cae', 'mw'],
    "sacala": ['mw'],
    "sacamatkāram": ['ddsa', 'mw'],
    "sacana": ['cae', 'gra', 'mw'],
    "sacanas": ['cae', 'gra', 'mw'],
    "sacanastama": ['mw'],
    "sacanasy": ['cae', 'gra'],
    "sacanasya": ['ddsa', 'mw'],
    "sacanaṃ": ['ap90'],
    "sacandraka": ['mw'],
    "sacandrikāprakāśa": ['mw'],
    "sacanāvat": ['gra'],
    "sacanīya": ['mw'],
    "sacaraṇalākṣārāga": ['mw'],
    "sacarma": ['mw'],
    "sacarācara": ['cae', 'mw'],
    "sacasy": ['cae', 'gra'],
    "sacasya": ['ddsa', 'mw'],
    "sacatha": ['cae', 'gra', 'mw'],
    "sacathia": ['gra'],
    "sacathya": ['cae', 'gra', 'mw'],
    "sacaukṣa": ['bhs'],
    "sacca": ['cped'],
    "saccakiriya": ['cped'],
    "saccakāla": ['cped'],
    "saccakāra": ['cped'],
    "saccandrikā": ['cae', 'ddsa', 'mw'],
    "saccapaṭivedha": ['cped'],
    "saccarita": ['cae', 'mw'],
    "saccaritamīmāṃsā": ['mw'],
    "saccaritra": ['cae', 'mw'],
    "saccaritraparitrāṇa": ['mw'],
    "saccaritrarakṣā": ['mw'],
    "saccaritrasudhānidhi": ['mw'],
    "saccaryā": ['mw'],
    "saccasandha": ['cped'],
    "saccavāca": ['cped'],
    "sacchadis": ['cae', 'mw'],
    "sacchala": ['cae', 'mw'],
    "sacchalajātinigrahamaya": ['mw'],
    "sacchambita": ['bhs'],
    "sacchanda": ['cae', 'mw'],
    "sacchandas": ['cae', 'ddsa', 'mw'],
    "sacchandasya": ['cae', 'mw'],
    "sacchandoma": ['mw'],
    "sacchandomatva": ['mw'],
    "saccheda": ['cae', 'mw'],
    "sacchidra": ['ap90', 'mw'],
    "sacchikaraṇa": ['cped'],
    "sacchikaraṇīya": ['cped'],
    "sacchikari": ['cped'],
    "sacchikarituṁ": ['cped'],
    "sacchikaritvā": ['cped'],
    "sacchikaronta": ['cped'],
    "sacchikaroti": ['cped'],
    "sacchikata": ['cped'],
    "sacchikatvā": ['cped'],
    "sacchikiriyā": ['cped'],
    "sacchikiriyāhetu": ['cped'],
    "sacchikātabba": ['cped'],
    "sacchikātuṁ": ['cped'],
    "sacchloka": ['mw'],
    "sacchāka": ['mw'],
    "sacchāstra": ['cae', 'ddsa', 'mw'],
    "sacchāstravat": ['mw'],
    "sacchāya": ['cae', 'mw'],
    "sacchīla": ['cae', 'mw'],
    "sacchūdra": ['mw'],
    "sacchūdrācāra": ['mw'],
    "sacchūdrāhnika": ['mw'],
    "saccid": ['mw'],
    "saccidaṃśa": ['mw'],
    "saccidānanda": ['cae', 'mw'],
    "saccidānandabhujaṃga": ['mw'],
    "saccidānandabhāratī": ['mw'],
    "saccidānandacāṭu": ['mw'],
    "saccidānandamaya": ['cae', 'mw'],
    "saccidānandanātha": ['mw'],
    "saccidānandasarasvatī": ['mw'],
    "saccidānandastotra": ['mw'],
    "saccidānandasvāmin": ['mw'],
    "saccidānandatīrtha": ['mw'],
    "saccidānandayogīndra": ['mw'],
    "saccidānandaśāstrin": ['mw'],
    "saccidānandānubhavadīpikā": ['mw'],
    "saccidānandānubhavapradīpikā": ['mw'],
    "saccidānandāśrama": ['mw'],
    "saccidātman": ['mw'],
    "saccin": ['mw'],
    "saccinmaya": ['cae', 'mw'],
    "saccit": ['mw'],
    "saccittiśaṃsin": ['cae'],
    "saccābhisamaya": ['cped'],
    "saccāpesi": ['cped'],
    "saccāpeti": ['cped'],
    "saccāpita": ['cped'],
    "saccāra": ['mw'],
    "sace": ['cped'],
    "sacela": ['ap90', 'cae', 'mw'],
    "sacet": ['bhs'],
    "sacetana": ['ap90', 'cae', 'cped', 'mw'],
    "sacetas": ['ap90', 'cae', 'gra', 'mw'],
    "saceṣṭa": ['mw'],
    "saceṣṭaḥ": ['ap90'],
    "saci": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sacihna": ['mw'],
    "sacihnam": ['mw'],
    "sacillaka": ['ap90', 'mw'],
    "sacinha": ['ddsa'],
    "sacinta": ['cae', 'mw'],
    "sacintam": ['mw'],
    "sacintākulam": ['cae', 'mw'],
    "sacit": ['cae', 'gra', 'mw'],
    "sacitka": ['mw'],
    "sacitra": ['ap90', 'cae', 'ddsa', 'mw'],
    "sacitta": ['cae', 'cped', 'mw'],
    "sacittaka": ['cped'],
    "saciva": ['cae', 'ddsa', 'mw'],
    "sacivatva": ['mw'],
    "sacivatā": ['cae', 'mw'],
    "sacivaḥ": ['ap90'],
    "sacivid": ['cae', 'ddsa', 'gra', 'mw'],
    "sacivāmaya": ['mw'],
    "saciḥ": ['ap90'],
    "sacyuti": ['mw'],
    "sacā": ['cae', 'ddsa', 'gra', 'mw'],
    "sacābhū": ['cae', 'ddsa', 'gra', 'mw'],
    "sacāmara": ['mw'],
    "sacāru": ['mw'],
    "sacāṅkācapuṣpī": ['mw'],
    "sacī": ['ap90', 'mw'],
    "sacīnaka": ['mw'],
    "sad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sada": ['cae', 'ddsa', 'mw'],
    "sadadhan": ['cae', 'mw'],
    "sadadi": ['cae', 'ddsa', 'mw'],
    "sadaikarasa": ['mw'],
    "sadaikarūparūpa": ['mw'],
    "sadaivata": ['mw'],
    "sadaka": ['mw'],
    "sadakṣa": ['cae', 'mw'],
    "sadakṣiṇa": ['cae', 'ddsa', 'mw'],
    "sadalaṃkāracandrikā": ['mw'],
    "sadalaṃkṛti": ['mw'],
    "sadalaṃkṛtitā": ['mw'],
    "sadalaṅkṛti": ['ddsa'],
    "sadam": ['cae', 'ddsa', 'gra', 'mw'],
    "sadama": ['bhs', 'mw'],
    "sadambha": ['ddsa', 'mw'],
    "sadana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sadanaṃ": ['ap90'],
    "sadandi": ['ddsa'],
    "sadani": ['mw'],
    "sadanugraha": ['mw'],
    "sadanya": ['mw'],
    "sadanāsad": ['cae', 'gra', 'mw'],
    "sadapadeśa": ['mw'],
    "sadara": ['cped', 'mw'],
    "sadarpa": ['cae', 'ddsa', 'mw'],
    "sadarpam": ['mw'],
    "sadartha": ['ddsa', 'mw'],
    "sadarthasāramañjarī": ['mw'],
    "sadas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sadasa": ['cped', 'mw'],
    "sadasad": ['mw'],
    "sadasadbhāva": ['cae', 'mw'],
    "sadasadrūpa": ['mw'],
    "sadasadviveka": ['mw'],
    "sadasadvyaktihetu": ['mw'],
    "sadasadātmaka": ['cae', 'mw'],
    "sadasadātmatā": ['mw'],
    "sadasan": ['mw'],
    "sadasanmaya": ['mw'],
    "sadasant": ['cae'],
    "sadasaspati": ['cae', 'ddsa', 'mw'],
    "sadasat": ['ddsa', 'mw'],
    "sadasatkhyātivicāra": ['mw'],
    "sadasatpati": ['mw'],
    "sadasatphala": ['cae', 'mw'],
    "sadasatphalamaya": ['mw'],
    "sadasattva": ['mw'],
    "sadaspati": ['cae', 'ddsa', 'gra', 'mw'],
    "sadassa": ['cped'],
    "sadasthimālā": ['mw'],
    "sadasya": ['cae', 'ddsa', 'mw'],
    "sadasyapaddhati": ['mw'],
    "sadasyaḥ": ['ap90'],
    "sadasyormi": ['mw'],
    "sadat": ['mw'],
    "sadattha": ['cped'],
    "sadattva": ['mw'],
    "sadaya": ['ap90', 'cae', 'mw'],
    "sadayahṛdaya": ['mw'],
    "sadayam": ['mw'],
    "sadayatva": ['mw'],
    "sadañjana": ['mw'],
    "sadaśa": ['mw'],
    "sadaśabandhaka": ['mw'],
    "sadaśajyotsna": ['ddsa'],
    "sadaśanajyotsna": ['mw'],
    "sadaśanārcis": ['mw'],
    "sadaśaratha": ['mw'],
    "sadaśva": ['cae', 'ddsa', 'gra', 'mw'],
    "sadaśvasena": ['mw'],
    "sadaśvavat": ['mw'],
    "sadaśvormi": ['mw'],
    "sadaśāpavitra": ['mw'],
    "sadaḥ": ['ap90', 'mw'],
    "sadaḥsada": ['mw'],
    "sadaḥstha": ['mw'],
    "sadaḥsuvāc": ['mw'],
    "sadaṃdi": ['cae', 'mw'],
    "sadaṃśa": ['mw'],
    "sadaṃśaka": ['mw'],
    "sadaṃśavadana": ['mw'],
    "sadaṃśavadanaḥ": ['ap90'],
    "sadaṃśaḥ": ['ap90'],
    "sadaṇḍa": ['mw'],
    "sadbhāgya": ['mw'],
    "sadbhāva": ['cae', 'mw'],
    "sadbhāvaśrī": ['mw'],
    "sadbhāṣya": ['mw'],
    "sadbhūta": ['cae', 'mw'],
    "sadbhūtadakṣiṇīya": ['mw'],
    "sadbhūtotpādaka": ['mw'],
    "sadbhṛtya": ['cae', 'mw'],
    "sadbrahman": ['mw'],
    "sadda": ['cped'],
    "saddahana": ['cped'],
    "saddahanta": ['cped'],
    "saddahanā": ['cped'],
    "saddahati": ['cped'],
    "saddahi": ['cped'],
    "saddahita": ['cped'],
    "saddahitabba": ['cped'],
    "saddahitvā": ['cped'],
    "saddala": ['cped'],
    "saddasattha": ['cped'],
    "saddattha": ['cped'],
    "saddavedhī": ['cped'],
    "saddavidū": ['cped'],
    "saddha": ['cped'],
    "saddhamma": ['cped'],
    "saddhan": ['mw'],
    "saddhana": ['mw'],
    "saddharma": ['cae', 'mw'],
    "saddharmacandrodaya": ['mw'],
    "saddharmacintāmaṇi": ['mw'],
    "saddharmaghoṣāmbaradīparāja": ['bhs'],
    "saddharmalaṅkāvatāra": ['mw'],
    "saddharmapuṇḍarīka": ['bhs', 'cae', 'mw'],
    "saddharmasamparigraha": ['mw'],
    "saddharmasmṛtyupasthāna": ['bhs'],
    "saddharmatattvākhyāhnika": ['mw'],
    "saddhetu": ['mw'],
    "saddhivihārika": ['cped'],
    "saddhivihārī": ['cped'],
    "saddhiṁ": ['cped'],
    "saddhiṁcara": ['cped'],
    "saddhyāyin": ['mw'],
    "saddhā": ['cped'],
    "saddhādeyya": ['cped'],
    "saddhādhana": ['cped'],
    "saddhālū": ['cped'],
    "saddhātabba": ['cped'],
    "saddhāyika": ['cped'],
    "saddhī": ['mw'],
    "saddāyamāna": ['cped'],
    "saddāyati": ['cped'],
    "saddāyi": ['cped'],
    "saddāyitvā": ['cped'],
    "saddūla": ['cped'],
    "sadeva": ['cae', 'mw'],
    "sadevaka": ['bhs', 'cped', 'mw'],
    "sadevamanuṣya": ['cae', 'mw'],
    "sadevamaṇi": ['mw'],
    "sadevatva": ['mw'],
    "sadevāsurarākṣasa": ['mw'],
    "sadevīka": ['mw'],
    "sadeśa": ['ap90', 'mw'],
    "sadeśatva": ['mw'],
    "sadgati": ['cae', 'ddsa', 'mw'],
    "sadgava": ['mw'],
    "sadghana": ['mw'],
    "sadgorakṣa": ['mw'],
    "sadgraha": ['mw'],
    "sadguru": ['cae', 'mw'],
    "sadgurustotra": ['mw'],
    "sadguṇa": ['cae', 'mw'],
    "sadguṇanirguṇavāda": ['mw'],
    "sadguṇācārya": ['mw'],
    "sadha": ['cae', 'ddsa', 'gra', 'mw'],
    "sadhairyam": ['mw'],
    "sadhamad": ['cae', 'ddsa', 'mw'],
    "sadhamitra": ['mw'],
    "sadhamād": ['gra', 'mw'],
    "sadhamāda": ['cae', 'gra', 'mw'],
    "sadhamādia": ['gra'],
    "sadhamādin": ['cae', 'mw'],
    "sadhamādya": ['cae', 'gra', 'mw'],
    "sadhana": ['cae', 'cped', 'ddsa', 'mw'],
    "sadhanatā": ['mw'],
    "sadhania": ['gra'],
    "sadhanitva": ['gra', 'mw'],
    "sadhanus": ['mw'],
    "sadhanuṣka": ['mw'],
    "sadhanuṣpāṇi": ['mw'],
    "sadhanya": ['gra'],
    "sadhanī": ['gra', 'mw'],
    "sadharma": ['cae', 'ddsa', 'mw'],
    "sadharmacāriṇī": ['cae', 'mw'],
    "sadharmaka": ['mw'],
    "sadharman": ['ap90', 'cae', 'ddsa', 'mw'],
    "sadharmatva": ['cae', 'mw'],
    "sadharmin": ['ap90', 'cae', 'mw'],
    "sadharmiṇī": ['ap90', 'mw'],
    "sadhastha": ['cae', 'gra', 'mw'],
    "sadhastuti": ['cae', 'ddsa', 'gra', 'mw'],
    "sadhastutya": ['cae', 'gra', 'mw'],
    "sadhavastrī": ['mw'],
    "sadhavā": ['mw'],
    "sadhavīra": ['cae', 'gra', 'mw'],
    "sadhi": ['gra', 'mw'],
    "sadhis": ['ap90', 'cae', 'ddsa', 'mw'],
    "sadhiḥ": ['ap90'],
    "sadhri": ['gra', 'mw'],
    "sadhriac": ['gra'],
    "sadhryac": ['gra'],
    "sadhryak": ['mw'],
    "sadhryañc": ['cae', 'ddsa', 'mw'],
    "sadhryaṃc": ['ap90'],
    "sadhrī": ['cae', 'gra', 'mw'],
    "sadhrīcī": ['ap90', 'mw'],
    "sadhrīcīna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sadhura": ['ddsa', 'mw'],
    "sadhvaja": ['mw'],
    "sadhvaṃsa": ['mw'],
    "sadhātu": ['mw'],
    "sadhī": ['cae', 'mw'],
    "sadhūma": ['cae', 'mw'],
    "sadhūmaka": ['mw'],
    "sadhūmakam": ['mw'],
    "sadhūmavarṇā": ['mw'],
    "sadhūmra": ['mw'],
    "sadhūmravarṇā": ['mw'],
    "sadhūpāyitvā": ['cped'],
    "sadi": ['mw'],
    "sadisa": ['cped'],
    "sadisatta": ['cped'],
    "sadivas": ['cae', 'ddsa', 'gra', 'mw'],
    "sadiś": ['mw'],
    "sadma": ['mw'],
    "sadmabarhis": ['gra', 'mw'],
    "sadmaciti": ['mw'],
    "sadmamakhas": ['gra', 'mw'],
    "sadman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sadmaniveśita": ['mw'],
    "sadmanivāsin": ['mw'],
    "sado": ['mw'],
    "sadobila": ['mw'],
    "sadodyama": ['cae', 'ddsa', 'mw'],
    "sadogata": ['cae', 'ddsa', 'mw'],
    "sadogṛha": ['cae', 'mw'],
    "sadohavirdhāna": ['mw'],
    "sadohavirdhānin": ['mw'],
    "sadojira": ['mw'],
    "sadopacāramuktāvalī": ['mw'],
    "sadopavāsin": ['mw'],
    "sadopayoga": ['mw'],
    "sadotsava": ['mw'],
    "sadoviśīya": ['mw'],
    "sadoṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "sadoṣaka": ['mw'],
    "sadoṣavat": ['mw'],
    "sadoṣavikāśa": ['mw'],
    "sadrasa": ['mw'],
    "sadratna": ['cae', 'ddsa', 'mw'],
    "sadratnamālā": ['mw'],
    "sadravya": ['cae', 'ddsa', 'mw'],
    "sadri": ['mw'],
    "sadroṇa": ['mw'],
    "sadru": ['ap90', 'mw'],
    "sadruci": ['mw'],
    "sadrūpatva": ['mw'],
    "sadugdha": ['mw'],
    "sadukti": ['ddsa', 'mw'],
    "saduktikarṇāmṛta": ['mw'],
    "sadupahāraratnākara": ['mw'],
    "saduparāgacandrodaya": ['mw'],
    "sadurdina": ['mw'],
    "saduttara": ['cped', 'mw'],
    "saduḥkha": ['cae', 'mw'],
    "sadvacas": ['cae', 'ddsa', 'mw'],
    "sadvaha": ['mw'],
    "sadvaidya": ['cae', 'mw'],
    "sadvaidyanātha": ['mw'],
    "sadvaidyaratnākara": ['mw'],
    "sadvan": ['cae', 'gra'],
    "sadvandva": ['ddsa'],
    "sadvartaka": ['mw'],
    "sadvasatha": ['mw'],
    "sadvasathaḥ": ['ap90'],
    "sadvastu": ['mw'],
    "sadvat": ['mw'],
    "sadvatsala": ['cae', 'mw'],
    "sadvatī": ['mw'],
    "sadvaṃdva": ['ap90', 'mw'],
    "sadvaṃśa": ['cae', 'ddsa', 'mw'],
    "sadvaṃśajāta": ['mw'],
    "sadvaṃśatva": ['mw'],
    "sadvelā": ['mw'],
    "sadveṣadhārin": ['mw'],
    "sadviccheda": ['mw'],
    "sadvidhāna": ['mw'],
    "sadvidhānapariśiṣṭa": ['mw'],
    "sadvidya": ['cae', 'mw'],
    "sadvidyā": ['cae', 'mw'],
    "sadvidyāvijaya": ['mw'],
    "sadvigarhita": ['cae', 'mw'],
    "sadviyoga": ['mw'],
    "sadvrata": ['mw'],
    "sadvādin": ['mw'],
    "sadvādita": ['mw'],
    "sadvājin": ['ddsa', 'mw'],
    "sadvārttā": ['cae', 'mw'],
    "sadvṛkṣa": ['cae', 'mw'],
    "sadvṛkṣaja": ['mw'],
    "sadvṛtta": ['cae', 'mw'],
    "sadvṛttaratnamālā": ['mw'],
    "sadvṛttaratnāvalī": ['mw'],
    "sadvṛttastha": ['mw'],
    "sadvṛttaśālin": ['mw'],
    "sadvṛtti": ['cae', 'mw'],
    "sadvṛttibhāj": ['mw'],
    "sadvṛttiviśiṣṭa": ['mw'],
    "sadvṛttānta": ['mw'],
    "sadya": ['mw'],
    "sadyas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sadyaska": ['ap90', 'mw'],
    "sadyaskrī": ['mw'],
    "sadyaskāla": ['mw'],
    "sadyaskālatva": ['mw'],
    "sadyaskālīna": ['mw'],
    "sadyaskāra": ['mw'],
    "sadyastana": ['mw'],
    "sadyastapta": ['mw'],
    "sadyastva": ['mw'],
    "sadyastā": ['mw'],
    "sadyasūti": ['gra'],
    "sadyathāpināma": ['bhs'],
    "sadyaś": ['mw'],
    "sadyaśchinna": ['mw'],
    "sadyaūti": ['cae', 'gra', 'mw'],
    "sadyaḥ": ['mw'],
    "sadyaḥkrī": ['cae', 'mw'],
    "sadyaḥkāla": ['mw'],
    "sadyaḥkṛta": ['mw'],
    "sadyaḥkṛtta": ['cae', 'ddsa', 'mw'],
    "sadyaḥkṛttota": ['mw'],
    "sadyaḥkṣata": ['mw'],
    "sadyaḥparyuṣita": ['mw'],
    "sadyaḥphala": ['cae', 'mw'],
    "sadyaḥphalatva": ['mw'],
    "sadyaḥprajñāhara": ['mw'],
    "sadyaḥprajñākara": ['mw'],
    "sadyaḥprakṣālaka": ['mw'],
    "sadyaḥprakṣālitānnaka": ['mw'],
    "sadyaḥprasūtā": ['cae', 'mw'],
    "sadyaḥprāṇahara": ['mw'],
    "sadyaḥprāṇakara": ['mw'],
    "sadyaḥpāka": ['mw'],
    "sadyaḥpātin": ['cae', 'mw'],
    "sadyaḥsnehana": ['mw'],
    "sadyaḥsutyā": ['cae', 'ddsa', 'mw'],
    "sadyaḥśaktihara": ['mw'],
    "sadyaḥśaktikara": ['mw'],
    "sadyaḥśauca": ['cae', 'mw'],
    "sadyaḥśotha": ['mw'],
    "sadyaḥśothā": ['mw'],
    "sadyaḥśrāddhin": ['mw'],
    "sadyaḥśuddhi": ['mw'],
    "sadyaṃ": ['bhs'],
    "sadyo": ['mw'],
    "sadyoartha": ['cae', 'gra', 'mw'],
    "sadyobala": ['ddsa', 'mw'],
    "sadyobalahara": ['mw'],
    "sadyobalakara": ['mw'],
    "sadyobhava": ['cae', 'mw'],
    "sadyobhivarṣa": ['mw'],
    "sadyobhāvin": ['mw'],
    "sadyobhṛt": ['mw'],
    "sadyobodhinīprakriyā": ['mw'],
    "sadyodugdha": ['mw'],
    "sadyogamuktāvalī": ['mw'],
    "sadyogaratnāvalī": ['mw'],
    "sadyohata": ['mw'],
    "sadyoja": ['mw'],
    "sadyojvara": ['mw'],
    "sadyojāta": ['cae', 'mw'],
    "sadyojātapāda": ['mw'],
    "sadyojātā": ['mw'],
    "sadyojū": ['cae', 'gra', 'mw'],
    "sadyomanyu": ['mw'],
    "sadyomaraṇa": ['mw'],
    "sadyomāṃsa": ['cae', 'mw'],
    "sadyomṛta": ['cae', 'mw'],
    "sadyonugata": ['mw'],
    "sadyotpanna": ['mw'],
    "sadyovarṣa": ['mw'],
    "sadyovarṣaṇa": ['mw'],
    "sadyovraṇa": ['mw'],
    "sadyovṛdh": ['gra', 'mw'],
    "sadyovṛṣṭi": ['mw'],
    "sadyovṛṣṭilakṣaṇa": ['mw'],
    "sadyoyajña": ['mw'],
    "sadyoyajñasaṃsthā": ['mw'],
    "sadyukti": ['ddsa', 'mw'],
    "sadyuktimuktāvalī": ['mw'],
    "sadyuvati": ['mw'],
    "sadyājin": ['mw'],
    "sadā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sadābhadrā": ['mw'],
    "sadābhava": ['mw'],
    "sadābhavya": ['mw'],
    "sadābhrama": ['mw'],
    "sadābhāsa": ['mw'],
    "sadācandra": ['mw'],
    "sadācaraṇa": ['mw'],
    "sadācāra": ['cae', 'mw'],
    "sadācāracandrodaya": ['mw'],
    "sadācāracintana": ['mw'],
    "sadācāradharma": ['mw'],
    "sadācārakrama": ['mw'],
    "sadācāranirṇaya": ['mw'],
    "sadācārapaddhati": ['mw'],
    "sadācāraprakaraṇa": ['mw'],
    "sadācārasamṛddhi": ['mw'],
    "sadācārasaṃgraha": ['mw'],
    "sadācārasmṛti": ['mw'],
    "sadācārasmṛtivivaraṇa": ['mw'],
    "sadācārasmṛtivyākhyā": ['mw'],
    "sadācārastutistotra": ['mw'],
    "sadācārasārasaṃgraha": ['mw'],
    "sadācāravant": ['cae'],
    "sadācāravarṇana": ['mw'],
    "sadācāravat": ['mw'],
    "sadācāravidhi": ['mw'],
    "sadācāravivaraṇa": ['mw'],
    "sadācārin": ['cae', 'mw'],
    "sadācārya": ['mw'],
    "sadācārāhnikavidhi": ['mw'],
    "sadādāna": ['mw'],
    "sadāgama": ['ddsa', 'mw'],
    "sadāgati": ['cae', 'ddsa', 'mw'],
    "sadāham": ['mw'],
    "sadāhuta": ['mw'],
    "sadākālavaha": ['mw'],
    "sadākāntā": ['mw'],
    "sadākārin": ['ddsa', 'mw'],
    "sadāma": ['cae', 'mw'],
    "sadāmada": ['cae', 'mw'],
    "sadāmarṣa": ['mw'],
    "sadāmatta": ['bhs', 'cae', 'mw'],
    "sadāmattaka": ['bhs', 'mw'],
    "sadāmudita": ['mw'],
    "sadāmāda": ['bhs'],
    "sadāna": ['cae', 'ddsa', 'gra', 'mw'],
    "sadānana": ['cae', 'ddsa', 'mw'],
    "sadānanda": ['cae', 'ddsa', 'mw'],
    "sadānandacidātmaka": ['mw'],
    "sadānandagaṇi": ['mw'],
    "sadānandagiri": ['mw'],
    "sadānandagirīya": ['mw'],
    "sadānandakāśmīra": ['mw'],
    "sadānandamaya": ['mw'],
    "sadānandanātha": ['mw'],
    "sadānandaratnamālā": ['mw'],
    "sadānandasarasvatī": ['mw'],
    "sadānandavyāsa": ['mw'],
    "sadānandayogīndra": ['mw'],
    "sadānandaśukla": ['mw'],
    "sadānandopaniṣad": ['mw'],
    "sadānandākhyadharmārṇava": ['mw'],
    "sadānarta": ['mw'],
    "sadānirāmayā": ['mw'],
    "sadānonuva": ['mw'],
    "sadānukāladarśinī": ['bhs', 'mw'],
    "sadānuvṛtti": ['bhs', 'mw'],
    "sadānuā": ['gra'],
    "sadānva": ['mw'],
    "sadānvacātana": ['mw'],
    "sadānvakṣayaṇa": ['mw'],
    "sadānvā": ['cae', 'gra', 'mw'],
    "sadānīravahā": ['mw'],
    "sadānīrā": ['cae', 'mw'],
    "sadāpa": ['mw'],
    "sadāparibhūta": ['bhs', 'mw'],
    "sadāparṇa": ['mw'],
    "sadāphala": ['cae', 'ddsa', 'mw'],
    "sadāpramudita": ['mw'],
    "sadāprarudita": ['bhs'],
    "sadāprasravaṇī": ['mw'],
    "sadāprasūna": ['mw'],
    "sadāpuṣpa": ['ddsa', 'mw'],
    "sadāpuṣpaphaladruma": ['mw'],
    "sadāpuṣpī": ['mw'],
    "sadāpṛṇa": ['cae', 'gra', 'mw'],
    "sadāra": ['cae', 'cped', 'ddsa', 'mw'],
    "sadāramin": ['bhs'],
    "sadāraputra": ['mw'],
    "sadārjava": ['mw'],
    "sadārāma": ['mw'],
    "sadāsah": ['cae', 'gra', 'mw'],
    "sadāsukha": ['cae', 'mw'],
    "sadāsā": ['cae', 'gra', 'mw'],
    "sadātana": ['ap90', 'cped', 'ddsa', 'mw'],
    "sadātanatva": ['mw'],
    "sadātman": ['mw'],
    "sadātoyā": ['mw'],
    "sadāvaradāyaka": ['mw'],
    "sadāvṛdha": ['cae', 'gra', 'mw'],
    "sadāvṛtti": ['mw'],
    "sadāyogin": ['mw'],
    "sadāśaya": ['mw'],
    "sadāśaṃkara": ['mw'],
    "sadāśis": ['mw'],
    "sadāśiva": ['cae', 'ddsa', 'mw'],
    "sadāśivabhaṭṭīya": ['mw'],
    "sadāśivabrahman": ['mw'],
    "sadāśivabrahmavṛtti": ['mw'],
    "sadāśivabrahmāryā": ['mw'],
    "sadāśivagītā": ['mw'],
    "sadāśivakavaca": ['mw'],
    "sadāśivamālā": ['mw'],
    "sadāśivanāmamantra": ['mw'],
    "sadāśivapada": ['mw'],
    "sadāśivasahasranāman": ['mw'],
    "sadāśivasaṃhitā": ['mw'],
    "sadāśivastotra": ['mw'],
    "sadāśivatā": ['mw'],
    "sadāśivaṣaṇmukhasaṃvāda": ['mw'],
    "sadāśivā": ['mw'],
    "sadāśivāryā": ['mw'],
    "sadāśivāṣṭaka": ['mw'],
    "sadāśrita": ['mw'],
    "sadāśva": ['mw'],
    "sadīkṣopasatka": ['mw'],
    "sadīnam": ['cae', 'mw'],
    "sadīpaka": ['mw'],
    "sadīśvara": ['mw'],
    "sadūrva": ['cae', 'mw'],
    "sadṛg": ['mw'],
    "sadṛgbhavam": ['mw'],
    "sadṛka": ['mw'],
    "sadṛkṣa": ['ap90', 'ddsa', 'mw'],
    "sadṛś": ['cae', 'gra', 'mw'],
    "sadṛśa": ['cae', 'mw'],
    "sadṛśaka": ['bhs'],
    "sadṛśakṣama": ['cae', 'mw'],
    "sadṛśam": ['mw'],
    "sadṛśaspandana": ['mw'],
    "sadṛśastrī": ['mw'],
    "sadṛśatama": ['mw'],
    "sadṛśatva": ['mw'],
    "sadṛśatā": ['mw'],
    "sadṛśavinimaya": ['cae', 'mw'],
    "sadṛśavṛtti": ['mw'],
    "sadṛśavṛttitā": ['mw'],
    "sadṛśaśveta": ['mw'],
    "sadṛśāsadṛśayogyāyogyatva": ['mw'],
    "sadṛṣṭikṣepam": ['cae', 'ddsa', 'mw'],
    "sadṛṣṭivikṣepam": ['cae'],
    "sag": ['ap90', 'mw'],
    "sagabbha": ['cped'],
    "sagadgada": ['cae', 'mw'],
    "sagadgadagir": ['cae', 'mw'],
    "sagadgadam": ['mw'],
    "sagadgadasvaram": ['mw'],
    "sagajāroha": ['mw'],
    "sagandha": ['cae', 'mw'],
    "sagandharva": ['mw'],
    "sagandharvāpsaraska": ['mw'],
    "sagandhin": ['cae'],
    "sagara": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "sagaras": ['mw'],
    "sagarbha": ['cae', 'mw'],
    "sagarbhaḥ": ['ap90'],
    "sagarbhya": ['mw'],
    "sagarbhā": ['mw'],
    "sagaropākhyāna": ['mw'],
    "sagarva": ['cae', 'mw'],
    "sagarvam": ['mw'],
    "sagarī": ['mw'],
    "sagatika": ['mw'],
    "sagauravam": ['cae', 'mw'],
    "sagaṃdha": ['ap90'],
    "sagaṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sagdhi": ['cae', 'ddsa', 'mw'],
    "sagdhiti": ['mw'],
    "sagdhiḥ": ['ap90'],
    "sagga": ['cped'],
    "saggakāya": ['cped'],
    "saggaloka": ['cped'],
    "saggamagga": ['cped'],
    "saggaparāyaṇa": ['cped'],
    "saggasaṁvattanika": ['cped'],
    "sagguṇa": ['cped'],
    "sagh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sagha": ['mw'],
    "saghan": ['cae', 'mw'],
    "saghana": ['cae', 'ddsa', 'mw'],
    "saghoṣa": ['cae', 'mw'],
    "saghṛta": ['cae', 'mw'],
    "saghṛṇa": ['cae', 'mw'],
    "sagma": ['mw'],
    "sagman": ['mw'],
    "sagomaya": ['mw'],
    "sagotra": ['ap90', 'cae', 'mw'],
    "sagotta": ['cped'],
    "sagoṣṭhī": ['mw'],
    "sagraha": ['cae', 'ddsa', 'mw'],
    "sagu": ['cae', 'mw'],
    "sagulika": ['mw'],
    "saguḍa": ['mw'],
    "saguḍaśṛṅgaka": ['mw'],
    "saguḍā": ['cae'],
    "saguṇa": ['ap90', 'cae', 'mw'],
    "saguṇanirguṇavāda": ['mw'],
    "saguṇatva": ['mw'],
    "saguṇavatī": ['mw'],
    "saguṇin": ['mw'],
    "sagāha": ['cped'],
    "sagāmeyya": ['cped'],
    "sagārava": ['cped'],
    "sagāravatā": ['cped'],
    "sagāravaṁ": ['cped'],
    "sagūḍham": ['mw'],
    "sagṛha": ['cae', 'mw'],
    "sagṛhapatika": ['mw'],
    "sah": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "saha": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sahabhakṣa": ['cae', 'mw'],
    "sahabhasman": ['cae', 'mw'],
    "sahabhojana": ['cae', 'mw'],
    "sahabhojin": ['cae', 'mw'],
    "sahabhrātṛ": ['mw'],
    "sahabhuj": ['cae', 'mw'],
    "sahabhārya": ['mw'],
    "sahabhāva": ['cae', 'mw'],
    "sahabhāvanika": ['mw'],
    "sahabhāvin": ['mw'],
    "sahabhū": ['cae', 'cped', 'mw'],
    "sahabhūta": ['mw'],
    "sahabhūti": ['mw'],
    "sahabāndhava": ['mw'],
    "sahacaityavat": ['mw'],
    "sahacandralalāma": ['mw'],
    "sahacara": ['cae', 'mw'],
    "sahacarabhinna": ['mw'],
    "sahacarabhinnatva": ['mw'],
    "sahacarabhinnatā": ['mw'],
    "sahacarat": ['mw'],
    "sahacaraṇa": ['mw'],
    "sahacarita": ['mw'],
    "sahacaritatva": ['mw'],
    "sahacarī": ['mw'],
    "sahacarīdharma": ['mw'],
    "sahacchandas": ['mw'],
    "sahachandas": ['gra'],
    "sahacittotpādadharmacakrapravartin": ['bhs'],
    "sahacāra": ['cae', 'mw'],
    "sahacāragranthaprakāśa": ['mw'],
    "sahacārarahasya": ['mw'],
    "sahacāratva": ['mw'],
    "sahacāravidhi": ['mw'],
    "sahacāravāda": ['mw'],
    "sahacārigrantharahasya": ['mw'],
    "sahacārin": ['cae', 'mw'],
    "sahacāritva": ['cae', 'mw'],
    "sahacāriṇī": ['mw'],
    "sahadaṇḍa": ['cae', 'mw'],
    "sahadeva": ['cae', 'gra', 'mw'],
    "sahadevaja": ['mw'],
    "sahadevata": ['cae', 'mw'],
    "sahadevaśāstra": ['mw'],
    "sahadevi": ['mw'],
    "sahadevā": ['mw'],
    "sahadevī": ['mw'],
    "sahadevīgaṇa": ['mw'],
    "sahadhammena": ['cped'],
    "sahadhammika": ['cped'],
    "sahadharma": ['bhs', 'cae', 'mw'],
    "sahadharmacara": ['cae', 'mw'],
    "sahadharmacaraṇa": ['cae', 'mw'],
    "sahadharmacarī": ['mw'],
    "sahadharmacārin": ['cae', 'mw'],
    "sahadharmacāriṇī": ['mw'],
    "sahadharman": ['mw'],
    "sahadharmin": ['mw'],
    "sahadharmiṇī": ['mw'],
    "sahadhyai": ['ddsa', 'mw'],
    "sahadhānya": ['mw'],
    "sahadhārmika": ['bhs'],
    "sahadroṇa": ['mw'],
    "sahadāna": ['mw'],
    "sahadānu": ['cae', 'gra', 'mw'],
    "sahadāra": ['cae', 'mw'],
    "sahadīkṣitin": ['mw'],
    "sahagamana": ['mw'],
    "sahagata": ['cped', 'mw'],
    "sahagopa": ['cae', 'gra', 'mw'],
    "sahagu": ['cae', 'mw'],
    "sahaguḍa": ['mw'],
    "sahagāmin": ['mw'],
    "sahagāminī": ['mw'],
    "sahahuta": ['mw'],
    "sahaikasthana": ['mw'],
    "sahaikasthāna": ['ddsa'],
    "sahaja": ['cae', 'cped', 'mw'],
    "sahajadhārmika": ['mw'],
    "sahajagdhi": ['mw'],
    "sahajakīrti": ['mw'],
    "sahajalalita": ['mw'],
    "sahajamalina": ['mw'],
    "sahajamitra": ['mw'],
    "sahajanmaka": ['bhs'],
    "sahajanman": ['mw'],
    "sahajanya": ['cae', 'mw'],
    "sahajanyī": ['mw'],
    "sahajapāla": ['mw'],
    "sahajasiddhi": ['mw'],
    "sahajasuhṛd": ['mw'],
    "sahajavatsala": ['mw'],
    "sahajavilāsa": ['bhs', 'mw'],
    "sahajaśatru": ['mw'],
    "sahajendra": ['cae', 'mw'],
    "sahajetara": ['mw'],
    "sahajit": ['mw'],
    "sahajodāsīna": ['mw'],
    "sahajoṣaṇa": ['mw'],
    "sahajā": ['cae', 'gra', 'mw'],
    "sahajādhinātha": ['mw'],
    "sahajānanda": ['mw'],
    "sahajāndhadṛś": ['mw'],
    "sahajāni": ['cae', 'mw'],
    "sahajānuṣa": ['gra', 'mw'],
    "sahajāri": ['mw'],
    "sahajāta": ['cae', 'cped', 'mw'],
    "sahajāṣṭaka": ['mw'],
    "sahajīvin": ['cae', 'mw'],
    "sahajīvī": ['cped'],
    "sahaka": ['ddsa', 'mw'],
    "sahakaraṇa": ['mw'],
    "sahakartṛ": ['cae', 'ddsa', 'mw'],
    "sahakaṇṭhaka": ['mw'],
    "sahakhaṭvāsana": ['cae', 'mw'],
    "sahakramya": ['mw'],
    "sahakāra": ['cae', 'cped', 'mw'],
    "sahakārabhañjikā": ['mw'],
    "sahakāramañjarī": ['mw'],
    "sahakārataila": ['mw'],
    "sahakāratā": ['mw'],
    "sahakāribhāva": ['mw'],
    "sahakārin": ['cae', 'mw'],
    "sahakāritva": ['mw'],
    "sahakāritā": ['cae', 'mw'],
    "sahakāropadeśa": ['mw'],
    "sahakṛt": ['mw'],
    "sahakṛta": ['mw'],
    "sahakṛtvan": ['mw'],
    "sahalakṣmaṇa": ['mw'],
    "sahalanīya": ['mw'],
    "sahalin": ['bhs'],
    "sahalokadhātu": ['ddsa', 'mw'],
    "sahama": ['mw'],
    "sahamacandrikā": ['mw'],
    "sahamakalpalatā": ['mw'],
    "sahamanas": ['mw'],
    "sahamaraṇa": ['mw'],
    "sahamarmāsthisaṃghāta": ['mw'],
    "sahamitra": ['mw'],
    "sahamukha": ['mw'],
    "sahamāda": ['mw'],
    "sahamāna": ['cped', 'mw'],
    "sahamānā": ['mw'],
    "sahamārīca": ['mw'],
    "sahamātṛka": ['mw'],
    "sahamūla": ['cae', 'gra', 'mw'],
    "sahamūra": ['cae', 'gra', 'mw'],
    "sahamṛtā": ['mw'],
    "sahan": ['gra'],
    "sahana": ['ap90', 'cae', 'cped', 'mw'],
    "sahanana": ['mw'],
    "sahanandī": ['cped'],
    "sahanartana": ['mw'],
    "sahanau": ['mw'],
    "sahanaśīla": ['mw'],
    "sahanirvāpa": ['cae', 'mw'],
    "sahanivāsin": ['mw'],
    "sahanivāsitā": ['cae', 'mw'],
    "sahanta": ['cped'],
    "sahantama": ['cae', 'mw'],
    "sahantia": ['gra'],
    "sahantya": ['cae', 'gra', 'mw'],
    "sahanīya": ['cae', 'mw'],
    "sahanṛtya": ['mw'],
    "sahapathin": ['mw'],
    "sahapati": ['mw'],
    "sahapatni": ['cae', 'mw'],
    "sahapatnī": ['cae', 'mw'],
    "sahapatnīka": ['cae', 'mw'],
    "sahapiṇḍakriyā": ['cae', 'mw'],
    "sahaprakḷpti": ['mw'],
    "sahaprakṛti": ['mw'],
    "sahaprama": ['mw'],
    "sahapramā": ['gra'],
    "sahaprasthāyin": ['cae'],
    "sahaprathāyin": ['mw'],
    "sahapravāda": ['mw'],
    "sahaprayoga": ['mw'],
    "sahaprayāyin": ['cae', 'mw'],
    "sahapuruṣa": ['cae', 'mw'],
    "sahaputra": ['cae', 'mw'],
    "sahapāna": ['cae', 'mw'],
    "sahapānaka": ['mw'],
    "sahapāṃsukila": ['mw'],
    "sahapāṃsukrīḍana": ['cae', 'ddsa', 'mw'],
    "sahapāṃsukrīḍita": ['mw'],
    "sahapāṃśukrīḍanaka": ['bhs'],
    "sahapāṭha": ['mw'],
    "sahapīti": ['mw'],
    "sahapūruṣa": ['cae', 'mw'],
    "sahapūrvāhṇam": ['mw'],
    "sahara": ['mw'],
    "saharakṣa": ['mw'],
    "saharakṣas": ['mw'],
    "saharasā": ['mw'],
    "sahari": ['mw'],
    "sahariḥ": ['ap90'],
    "saharājaka": ['mw'],
    "saharṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "saharṣabha": ['cae', 'mw'],
    "saharṣam": ['mw'],
    "saharṣamṛgayugrāmaninādamaya": ['mw'],
    "saharṣasādhvasam": ['cae', 'mw'],
    "saharṣavairāgyam": ['mw'],
    "saharṣita": ['mw'],
    "saharṣya": ['bhs'],
    "saharṣākūtam": ['cae', 'mw'],
    "sahas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sahasa": ['ddsa', 'mw'],
    "sahasambhalā": ['mw'],
    "sahasambhava": ['mw'],
    "sahasaumitri": ['mw'],
    "sahasaṃjātavṛddha": ['mw'],
    "sahasaṃsarga": ['mw'],
    "sahasaṃvega": ['mw'],
    "sahasaṃvāda": ['mw'],
    "sahasaṃvāsa": ['ddsa', 'mw'],
    "sahasevin": ['mw'],
    "sahaseyyā": ['cped'],
    "sahasia": ['gra'],
    "sahasiddha": ['mw'],
    "sahasiddhatva": ['mw'],
    "sahasin": ['gra', 'mw'],
    "sahaskṛt": ['cae', 'mw'],
    "sahaskṛta": ['cae', 'ddsa', 'gra', 'mw'],
    "sahasodgata": ['bhs', 'mw'],
    "sahasokī": ['cped'],
    "sahasoma": ['mw'],
    "sahasopinī": ['bhs'],
    "sahasphya": ['mw'],
    "sahasra": ['cae', 'ddsa', 'gra', 'mw'],
    "sahasraargha": ['gra'],
    "sahasrabala": ['mw'],
    "sahasrabhakta": ['mw'],
    "sahasrabhara": ['cae', 'gra', 'mw'],
    "sahasrabharṇas": ['cae', 'gra', 'mw'],
    "sahasrabhedaśas": ['mw'],
    "sahasrabhid": ['mw'],
    "sahasrabhuja": ['bhs', 'mw'],
    "sahasrabhujajihvākṣa": ['mw'],
    "sahasrabhujarāmadhyāna": ['mw'],
    "sahasrabhujā": ['mw'],
    "sahasrabhāgavatī": ['mw'],
    "sahasrabhānu": ['mw'],
    "sahasrabhāva": ['mw'],
    "sahasrabhṛṣṭi": ['cae', 'gra', 'mw'],
    "sahasrabuddhi": ['mw'],
    "sahasrabāhavīya": ['mw'],
    "sahasrabāhu": ['cae', 'gra', 'mw'],
    "sahasracakṣas": ['cae', 'gra', 'mw'],
    "sahasracakṣu": ['cae', 'mw'],
    "sahasracakṣus": ['mw'],
    "sahasracaraṇa": ['cae', 'mw'],
    "sahasracaṇḍyādiprayogapaddhati": ['mw'],
    "sahasracaṇḍyādividhi": ['mw'],
    "sahasracaṇḍīvidhi": ['mw'],
    "sahasracaṇḍīvidhāna": ['mw'],
    "sahasracaṇḍīśatacaṇḍīvidhāna": ['mw'],
    "sahasracetas": ['gra', 'mw'],
    "sahasracitya": ['mw'],
    "sahasrada": ['cae', 'mw'],
    "sahasradakṣiṇa": ['cae', 'gra', 'mw'],
    "sahasradala": ['mw'],
    "sahasradaṃṣṭra": ['mw'],
    "sahasradaṃṣṭrin": ['mw'],
    "sahasradharma": ['bhs'],
    "sahasradhauta": ['mw'],
    "sahasradhā": ['ap90', 'cae', 'gra', 'mw'],
    "sahasradhāman": ['cae', 'mw'],
    "sahasradhāra": ['cae', 'gra', 'mw'],
    "sahasradhārā": ['mw'],
    "sahasradhāyas": ['cae', 'mw'],
    "sahasradhī": ['mw'],
    "sahasrados": ['mw'],
    "sahasradvār": ['cae', 'gra', 'mw'],
    "sahasradvāra": ['cae', 'mw'],
    "sahasradā": ['cae', 'gra', 'mw'],
    "sahasradāna": ['cae', 'gra', 'mw'],
    "sahasradātama": ['mw'],
    "sahasradātar": ['bhs'],
    "sahasradātu": ['gra', 'mw'],
    "sahasradāvan": ['cae', 'gra', 'mw'],
    "sahasradīdhiti": ['cae', 'mw'],
    "sahasradṛś": ['cae', 'mw'],
    "sahasragarbha": ['bhs'],
    "sahasragaṇanāman": ['mw'],
    "sahasraghni": ['mw'],
    "sahasraghātin": ['mw'],
    "sahasragodānapaddhati": ['mw'],
    "sahasragu": ['cae', 'mw'],
    "sahasraguṇa": ['cae', 'mw'],
    "sahasraguṇatā": ['mw'],
    "sahasraguṇita": ['cae', 'mw'],
    "sahasragīti": ['mw'],
    "sahasraha": ['cae', 'mw'],
    "sahasraharyaśva": ['mw'],
    "sahasraharyāśva": ['mw'],
    "sahasrahasta": ['cae', 'mw'],
    "sahasrajaladhāra": ['mw'],
    "sahasrajihva": ['mw'],
    "sahasrajit": ['cae', 'gra', 'mw'],
    "sahasrajyotis": ['mw'],
    "sahasraka": ['cae', 'mw'],
    "sahasrakalaśasnapanādi": ['mw'],
    "sahasrakalaśābhiṣekaprayoga": ['mw'],
    "sahasrakalā": ['mw'],
    "sahasrakara": ['cae', 'mw'],
    "sahasrakarapannetra": ['mw'],
    "sahasrakavaca": ['mw'],
    "sahasrakaṃdhararāmāyaṇa": ['mw'],
    "sahasraketu": ['gra', 'mw'],
    "sahasrakiraṇa": ['cae', 'mw'],
    "sahasrakiraṇāvali": ['mw'],
    "sahasrakiraṇī": ['mw'],
    "sahasrakuṇapa": ['mw'],
    "sahasrakāṇḍa": ['mw'],
    "sahasrakāṇḍā": ['mw'],
    "sahasrakṛtvas": ['cae', 'mw'],
    "sahasraliṅgī": ['mw'],
    "sahasralocana": ['cae', 'mw'],
    "sahasram": ['mw'],
    "sahasramanyu": ['mw'],
    "sahasramarīci": ['mw'],
    "sahasramauli": ['mw'],
    "sahasramaṅgala": ['mw'],
    "sahasrambhara": ['gra', 'mw'],
    "sahasrambhari": ['mw'],
    "sahasramukha": ['mw'],
    "sahasramukharāvaṇacaritra": ['mw'],
    "sahasramuṣka": ['cae', 'gra', 'mw'],
    "sahasramīl̤ha": ['mw'],
    "sahasramīḍha": ['gra', 'mw'],
    "sahasramūla": ['mw'],
    "sahasramūlī": ['mw'],
    "sahasramūrdha": ['mw'],
    "sahasramūrdhan": ['cae', 'mw'],
    "sahasramūrdhaśravaṇākṣināsika": ['mw'],
    "sahasramūrti": ['mw'],
    "sahasramūti": ['cae', 'gra', 'mw'],
    "sahasranayana": ['cae', 'mw'],
    "sahasranetra": ['cae', 'mw'],
    "sahasranetrānanapādabāhu": ['mw'],
    "sahasranirṇij": ['cae', 'gra', 'mw'],
    "sahasranāmabhāṣya": ['mw'],
    "sahasranāmakārikā": ['mw'],
    "sahasranāman": ['cae', 'mw'],
    "sahasranāmasarayu": ['mw'],
    "sahasranāmastotra": ['mw'],
    "sahasranāmastuti": ['mw'],
    "sahasranāmavivaraṇa": ['mw'],
    "sahasranāmārthaślokasahasrāvali": ['mw'],
    "sahasranītha": ['mw'],
    "sahasrapad": ['cae', 'gra', 'mw'],
    "sahasraparama": ['mw'],
    "sahasraparvā": ['mw'],
    "sahasraparṇa": ['cae', 'gra', 'mw'],
    "sahasraparṇī": ['mw'],
    "sahasrapati": ['cae', 'mw'],
    "sahasrapattra": ['mw'],
    "sahasrapattrābharaṇa": ['mw'],
    "sahasrapoṣa": ['cae', 'gra', 'mw'],
    "sahasrapoṣakāma": ['mw'],
    "sahasrapoṣapuṣi": ['mw'],
    "sahasrapoṣia": ['gra'],
    "sahasrapoṣin": ['gra', 'mw'],
    "sahasrapoṣya": ['gra', 'mw'],
    "sahasrapoṣā": ['mw'],
    "sahasrapradhana": ['gra', 'mw'],
    "sahasraprakāra": ['mw'],
    "sahasraprāṇa": ['mw'],
    "sahasraputra": ['mw'],
    "sahasrapād": ['cae', 'gra', 'mw'],
    "sahasrapāda": ['mw'],
    "sahasrapādākṣiśirorubāhu": ['mw'],
    "sahasrapājas": ['gra', 'mw'],
    "sahasrapākya": ['mw'],
    "sahasrapāthas": ['gra', 'mw'],
    "sahasrapāśa": ['mw'],
    "sahasrapūraṇa": ['mw'],
    "sahasrapṛṣṭha": ['cae', 'mw'],
    "sahasraraśmi": ['cae', 'mw'],
    "sahasraraśmitanaya": ['mw'],
    "sahasraretas": ['cae', 'gra', 'mw'],
    "sahasraroman": ['mw'],
    "sahasraruc": ['mw'],
    "sahasrasama": ['mw'],
    "sahasrasammita": ['mw'],
    "sahasrasani": ['cae', 'mw'],
    "sahasrasava": ['mw'],
    "sahasrasaṃkhya": ['cae', 'mw'],
    "sahasrasaṃkhyā": ['mw'],
    "sahasrasaṃkhyāka": ['mw'],
    "sahasrasaṃvatsara": ['mw'],
    "sahasrasrota": ['mw'],
    "sahasrasrotas": ['mw'],
    "sahasrastari": ['mw'],
    "sahasrastarī": ['gra'],
    "sahasrasthūṇa": ['gra', 'mw'],
    "sahasrastotriya": ['mw'],
    "sahasrastuka": ['mw'],
    "sahasrastuti": ['mw'],
    "sahasrasā": ['cae', 'gra', 'mw'],
    "sahasrasātama": ['mw'],
    "sahasrasāva": ['cae', 'gra', 'mw'],
    "sahasrasāvya": ['mw'],
    "sahasrasīta": ['mw'],
    "sahasratama": ['cae', 'mw'],
    "sahasrataya": ['ap90', 'mw'],
    "sahasravadana": ['mw'],
    "sahasravaktra": ['cae', 'mw'],
    "sahasravaliśa": ['cae', 'mw'],
    "sahasravalśa": ['cae', 'gra', 'mw'],
    "sahasravant": ['cae'],
    "sahasravarcas": ['cae', 'gra', 'mw'],
    "sahasravarga": ['bhs'],
    "sahasravartani": ['mw'],
    "sahasravartanin": ['mw'],
    "sahasravartman": ['mw'],
    "sahasravat": ['gra', 'mw'],
    "sahasravedha": ['mw'],
    "sahasravedhin": ['mw'],
    "sahasravāc": ['mw'],
    "sahasravāja": ['cae', 'gra', 'mw'],
    "sahasravāka": ['mw'],
    "sahasravīra": ['cae', 'gra', 'mw'],
    "sahasravīrya": ['cae', 'mw'],
    "sahasravīryā": ['mw'],
    "sahasravṛt": ['mw'],
    "sahasrayajña": ['bhs', 'cae', 'mw'],
    "sahasrayajñatīrtha": ['mw'],
    "sahasrayodhin": ['bhs'],
    "sahasrayoga": ['mw'],
    "sahasrayogacikitsā": ['mw'],
    "sahasrayojana": ['mw'],
    "sahasrayuga": ['mw'],
    "sahasrayāj": ['mw'],
    "sahasrayājin": ['mw'],
    "sahasrayāman": ['gra', 'mw'],
    "sahasraśakti": ['mw'],
    "sahasraśala": ['mw'],
    "sahasraśas": ['ap90', 'cae', 'gra', 'mw'],
    "sahasraśatadakṣiṇa": ['cae', 'mw'],
    "sahasraśikhara": ['mw'],
    "sahasraśiras": ['cae', 'mw'],
    "sahasraśirasa": ['cae', 'mw'],
    "sahasraśirasodara": ['mw'],
    "sahasraśiri": ['bhs'],
    "sahasraśokas": ['cae', 'gra', 'mw'],
    "sahasraśravaṇa": ['mw'],
    "sahasraśruti": ['mw'],
    "sahasraśākha": ['mw'],
    "sahasraśīrṣa": ['cae', 'mw'],
    "sahasraśīrṣan": ['cae', 'gra', 'mw'],
    "sahasraśīrṣā": ['mw'],
    "sahasraśṛṅga": ['cae', 'gra', 'mw'],
    "sahasraṃ": ['ap90'],
    "sahasraṃbhara": ['cae'],
    "sahasraṇī": ['cae', 'mw'],
    "sahasraṇītha": ['cae', 'gra', 'mw'],
    "sahasraṇīti": ['cae', 'gra', 'mw'],
    "sahasredhma": ['mw'],
    "sahasrekṣaṇa": ['mw'],
    "sahasrika": ['mw'],
    "sahasrima": ['bhs'],
    "sahasrin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sahasriya": ['cae', 'gra', 'mw'],
    "sahasropaniṣad": ['mw'],
    "sahasrorvaṅghribāhvakṣa": ['mw'],
    "sahasroti": ['cae', 'gra', 'mw'],
    "sahasrācāra": ['mw'],
    "sahasrādhipati": ['cae', 'mw'],
    "sahasrāha": ['cae', 'mw'],
    "sahasrāhnya": ['cae', 'mw'],
    "sahasrājit": ['mw'],
    "sahasrākhya": ['mw'],
    "sahasrākṣa": ['cae', 'gra', 'mw'],
    "sahasrākṣadhanuṣmat": ['mw'],
    "sahasrākṣajit": ['mw'],
    "sahasrākṣara": ['gra', 'mw'],
    "sahasrākṣeśvara": ['mw'],
    "sahasrākṣī": ['mw'],
    "sahasrāmagha": ['cae', 'gra', 'mw'],
    "sahasrānana": ['mw'],
    "sahasrānanaśīrṣavat": ['mw'],
    "sahasrānīka": ['mw'],
    "sahasrāpoṣa": ['mw'],
    "sahasrāpsas": ['gra', 'mw'],
    "sahasrāra": ['mw'],
    "sahasrāraja": ['mw'],
    "sahasrārcis": ['cae', 'mw'],
    "sahasrārgha": ['cae', 'gra', 'mw'],
    "sahasrārha": ['cae', 'mw'],
    "sahasrāsya": ['mw'],
    "sahasrātman": ['mw'],
    "sahasrātṛṇṇa": ['mw'],
    "sahasrāvara": ['mw'],
    "sahasrāvartakatīrtha": ['mw'],
    "sahasrāvartā": ['bhs', 'mw'],
    "sahasrāyu": ['cae', 'mw'],
    "sahasrāyudha": ['mw'],
    "sahasrāyudhīya": ['mw'],
    "sahasrāyus": ['cae', 'mw'],
    "sahasrāyutīya": ['mw'],
    "sahasrāyuṣṭva": ['mw'],
    "sahasrāśva": ['mw'],
    "sahasrāśvīna": ['mw'],
    "sahasrāṃśu": ['cae', 'ddsa', 'mw'],
    "sahasrāṃśuja": ['mw'],
    "sahasrāṃśusama": ['mw'],
    "sahasrāṅka": ['mw'],
    "sahasrāṇīka": ['mw'],
    "sahasrī": ['bhs'],
    "sahasrīya": ['cae', 'mw'],
    "sahassa": ['cped'],
    "sahassa-maṇḍala": ['cped'],
    "sahassabhaṇḍikā": ['cped'],
    "sahassadhā": ['cped'],
    "sahassagghanaka": ['cped'],
    "sahassakkha": ['cped'],
    "sahassakkhattuṁ": ['cped'],
    "sahassanetta": ['cped'],
    "sahassaraṁsī": ['cped'],
    "sahassatthavikā": ['cped'],
    "sahassika": ['cped'],
    "sahassāra": ['cped'],
    "sahassīlokadhātu": ['cped'],
    "sahasta": ['cae', 'ddsa', 'mw'],
    "sahastatalam": ['mw'],
    "sahastha": ['cae', 'ddsa', 'mw'],
    "sahasthita": ['cae', 'mw'],
    "sahasthiti": ['mw'],
    "sahasthāna": ['mw'],
    "sahastoma": ['gra', 'mw'],
    "sahasuralalanālalāmayūthapati": ['mw'],
    "sahasvant": ['cae'],
    "sahasvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "sahasvatī": ['mw'],
    "sahasya": ['cae', 'ddsa', 'gra', 'mw'],
    "sahasyacandra": ['mw'],
    "sahasyaḥ": ['ap90'],
    "sahasā": ['ap90', 'cped', 'mw'],
    "sahasādṛṣṭa": ['mw'],
    "sahasāman": ['gra', 'mw'],
    "sahasāna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sahasānu": ['mw'],
    "sahasāvan": ['cae', 'ddsa', 'gra'],
    "sahasāvat": ['mw'],
    "sahasūktavāka": ['mw'],
    "sahat": ['mw'],
    "sahati": ['cped'],
    "sahattha": ['cped'],
    "sahatva": ['cae', 'mw'],
    "sahatvakarman": ['mw'],
    "sahatā": ['ap90', 'cae', 'mw'],
    "sahaujas": ['cae', 'mw'],
    "sahautra": ['mw'],
    "sahautranakṣatrasattvaprayoga": ['mw'],
    "sahavah": ['cae', 'gra', 'mw'],
    "sahavaiśikya": ['mw'],
    "sahavartin": ['mw'],
    "sahavasati": ['cae', 'mw'],
    "sahavasu": ['gra', 'mw'],
    "sahavatsa": ['cae', 'gra', 'mw'],
    "sahavivakṣā": ['mw'],
    "sahavrata": ['cae', 'mw'],
    "sahavratā": ['bhs', 'mw'],
    "sahavya": ['cped'],
    "sahavyatā": ['cped'],
    "sahavācya": ['mw'],
    "sahavāda": ['mw'],
    "sahavāh": ['gra'],
    "sahavāhana": ['cae', 'mw'],
    "sahavārṣṇeyabāhuka": ['mw'],
    "sahavārṣṇeyajīvala": ['mw'],
    "sahavārṣṇeyasārathi": ['mw'],
    "sahavāsa": ['cae', 'cped', 'mw'],
    "sahavāsika": ['mw'],
    "sahavāsin": ['mw'],
    "sahavīra": ['cae', 'gra', 'mw'],
    "sahavīrya": ['mw'],
    "sahavṛddhikṣayabhāva": ['mw'],
    "sahaya": ['cae', 'mw'],
    "sahayajña": ['cae', 'mw'],
    "sahayaugaṃdharāyaṇa": ['mw'],
    "sahayaśas": ['cae', 'mw'],
    "sahayoga": ['cped'],
    "sahayoṣit": ['mw'],
    "sahayudhvan": ['mw'],
    "sahayuj": ['cae', 'mw'],
    "sahayāta": ['mw'],
    "sahayāyin": ['cae', 'mw'],
    "sahaśaya": ['mw'],
    "sahaśayyā": ['cae', 'mw'],
    "sahaśayyāsanāśana": ['mw'],
    "sahaśeyia": ['gra'],
    "sahaśeyya": ['gra', 'mw'],
    "sahaśiṣṭa": ['mw'],
    "sahaśiṣṭatva": ['mw'],
    "sahaśāyinī": ['bhs'],
    "sahaṃpati": ['bhs'],
    "sahaṃsapāta": ['mw'],
    "sahaṃsavālavyajana": ['ddsa', 'mw'],
    "sahaṇḍuka": ['mw'],
    "sahaṛṣabha": ['mw'],
    "sahela": ['ap90', 'cae', 'mw'],
    "sahelam": ['mw'],
    "sahemaka": ['mw'],
    "sahemakakṣya": ['mw'],
    "sahendra": ['cae', 'mw'],
    "saheti": ['mw'],
    "sahetikaraṇa": ['mw'],
    "sahetikāra": ['mw'],
    "sahetu": ['cae', 'mw'],
    "sahetuka": ['cae', 'cped', 'mw'],
    "sahi": ['cped'],
    "sahima": ['ddsa', 'mw'],
    "sahira": ['mw'],
    "sahiraṇya": ['cae', 'mw'],
    "sahiraṇyapātra": ['mw'],
    "sahita": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sahitabba": ['cped'],
    "sahitaka": ['bhs'],
    "sahitakumbhaka": ['mw'],
    "sahitam": ['mw'],
    "sahitar": ['cped'],
    "sahitasthita": ['mw'],
    "sahitatva": ['mw'],
    "sahitavya": ['cae', 'mw'],
    "sahitoru": ['mw'],
    "sahitottara": ['mw'],
    "sahitra": ['mw'],
    "sahitraṃ": ['ap90'],
    "sahitvā": ['cped'],
    "sahitā": ['mw'],
    "sahitāṅguli": ['mw'],
    "sahitṛ": ['ap90', 'mw'],
    "sahiṣṇu": ['ap90', 'cae', 'mw'],
    "sahiṣṇutva": ['mw'],
    "sahiṣṇutā": ['ap90', 'mw'],
    "sahiṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "sahla": ['mw'],
    "sahlādam": ['mw'],
    "sahma": ['ap90'],
    "saho": ['mw'],
    "sahobala": ['mw'],
    "sahobhari": ['cae', 'gra', 'mw'],
    "sahobhiḥ": ['mw'],
    "sahodairghatamasa": ['mw'],
    "sahodaka": ['mw'],
    "sahodakumbha": ['mw'],
    "sahodana": ['mw'],
    "sahodara": ['cae', 'mw'],
    "sahodaya": ['mw'],
    "sahodita": ['mw'],
    "sahodā": ['cae', 'gra', 'mw'],
    "sahohā": ['mw'],
    "sahojit": ['cae', 'mw'],
    "sahojā": ['cae', 'gra', 'mw'],
    "sahokti": ['cae', 'mw'],
    "sahopadha": ['mw'],
    "sahopalambha": ['mw'],
    "sahopamā": ['mw'],
    "sahopapativeśman": ['mw'],
    "sahora": ['ap90', 'mw'],
    "sahorayiṣṭhīya": ['mw'],
    "sahoru": ['mw'],
    "sahotpatti": ['mw'],
    "sahottha": ['mw'],
    "sahotthāyin": ['cae', 'mw'],
    "sahovan": ['cae', 'mw'],
    "sahovṛdh": ['cae', 'gra', 'mw'],
    "sahoḍha": ['cae', 'cped', 'ddsa', 'mw'],
    "sahoḍhaja": ['mw'],
    "sahoḍhajā": ['mw'],
    "sahoḍhaḥ": ['ap90'],
    "sahoṣita": ['cae', 'mw'],
    "sahoṭaja": ['mw'],
    "sahra": ['mw'],
    "sahuri": ['cae', 'ddsa', 'gra', 'mw'],
    "sahuriḥ": ['ap90'],
    "sahuḍa": ['mw'],
    "sahvan": ['cae', 'mw'],
    "sahya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "sahyakarman": ['cae', 'mw'],
    "sahyamahībhṛt": ['mw'],
    "sahyaparvata": ['mw'],
    "sahyas": ['gra', 'mw'],
    "sahyatā": ['mw'],
    "sahyavarṇana": ['mw'],
    "sahyavāsin": ['cae'],
    "sahyavāsinī": ['mw'],
    "sahyaṃs": ['cae'],
    "sahyu": ['cae', 'gra', 'mw'],
    "sahyādri": ['mw'],
    "sahyādrikhaṇḍa": ['mw'],
    "sahyātmajā": ['mw'],
    "sahā": ['ap90', 'bhs', 'mw'],
    "sahācara": ['mw'],
    "sahādaram": ['mw'],
    "sahādhyayana": ['cae', 'mw'],
    "sahādhyāyin": ['cae', 'ddsa', 'mw'],
    "sahājya": ['mw'],
    "sahālin": ['mw'],
    "sahālāpa": ['mw'],
    "sahāmpati": ['mw'],
    "sahāmātya": ['mw'],
    "sahānugamana": ['mw'],
    "sahānuja": ['mw'],
    "sahānumaraṇa": ['mw'],
    "sahānumaraṇaviveka": ['mw'],
    "sahānya": ['mw'],
    "sahāpati": ['bhs'],
    "sahāpatya": ['mw'],
    "sahāpavāda": ['mw'],
    "sahāra": ['mw'],
    "sahārambha": ['mw'],
    "sahāraḥ": ['ap90'],
    "sahārda": ['ddsa', 'mw'],
    "sahārdha": ['ddsa', 'mw'],
    "sahārjuna": ['mw'],
    "sahārogya": ['mw'],
    "sahārtha": ['mw'],
    "sahārthanāśa": ['mw'],
    "sahārthatva": ['mw'],
    "sahārthībhāva": ['mw'],
    "sahārthībhū": ['mw'],
    "sahāsa": ['cae', 'ddsa', 'mw'],
    "sahāsahākāram": ['mw'],
    "sahāsam": ['mw'],
    "sahāsana": ['cae', 'ddsa', 'mw'],
    "sahāsarabhasa": ['mw'],
    "sahāsyā": ['mw'],
    "sahāva": ['mw'],
    "sahāvam": ['mw'],
    "sahāvan": ['cae', 'ddsa', 'gra', 'mw'],
    "sahāvant": ['cae'],
    "sahāvasthita": ['mw'],
    "sahāvasthitatā": ['mw'],
    "sahāvat": ['gra', 'mw'],
    "sahāya": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sahāyaka": ['bhs', 'cped', 'mw'],
    "sahāyakaraṇa": ['mw'],
    "sahāyakṛt": ['mw'],
    "sahāyakṛtya": ['mw'],
    "sahāyana": ['cae', 'mw'],
    "sahāyatana": ['ddsa', 'mw'],
    "sahāyatva": ['mw'],
    "sahāyatā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sahāyavant": ['cae'],
    "sahāyavat": ['ap90', 'mw'],
    "sahāyaḥ": ['ap90'],
    "sahāyika": ['bhs'],
    "sahāyin": ['cae', 'mw'],
    "sahāyārtham": ['cae', 'mw'],
    "sahāyārthin": ['mw'],
    "sahāyī": ['mw'],
    "sahāyībhāva": ['mw'],
    "sahāyībhū": ['mw'],
    "sahāśrāya": ['mw'],
    "sahāṃpati": ['bhs'],
    "sahāṃpatīka": ['bhs'],
    "sahī": ['bhs'],
    "sahīla": ['ddsa', 'mw'],
    "sahīya": ['bhs'],
    "sahīyas": ['ddsa', 'gra', 'mw'],
    "sahīyaṃs": ['cae'],
    "sahūti": ['cae', 'ddsa', 'gra', 'mw'],
    "sahṛd": ['mw'],
    "sahṛdaya": ['ap90', 'cae', 'mw'],
    "sahṛdayalīlā": ['mw'],
    "sahṛdayāloka": ['mw'],
    "sahṛllekha": ['ap90', 'mw'],
    "sahṛṣṭakam": ['mw'],
    "sai": ['ap90', 'mw'],
    "saicālina": ['mw'],
    "saiddhāntika": ['mw'],
    "saiddhāṃtika": ['ap90'],
    "saidhraka": ['mw'],
    "saidhrakāvata": ['mw'],
    "saidhrika": ['mw'],
    "saidhrikamaya": ['mw'],
    "saihareya": ['mw'],
    "saika": ['ddsa', 'mw'],
    "saikadvisaptaka": ['mw'],
    "saikata": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "saikatavat": ['mw'],
    "saikateṣṭa": ['mw'],
    "saikatika": ['ap90', 'mw'],
    "saikatin": ['mw'],
    "saikayata": ['mw'],
    "saikayatavidha": ['mw'],
    "saikayatyā": ['mw'],
    "saikya": ['mw'],
    "saikāvali": ['cae', 'ddsa', 'mw'],
    "saikṣava": ['mw'],
    "saila": ['bhs'],
    "sailaga": ['mw'],
    "saili": ['mw'],
    "saimantika": ['mw'],
    "saimaṃtikaṃ": ['ap90'],
    "sainaka": ['mw'],
    "saindhava": ['bhs', 'cae', 'ddsa', 'mw'],
    "saindhavacūrṇa": ['mw'],
    "saindhavaghana": ['cae', 'mw'],
    "saindhavaka": ['mw'],
    "saindhavakhilya": ['cae', 'mw'],
    "saindhavasarpis": ['mw'],
    "saindhavaśilāśakala": ['mw'],
    "saindhavāraṇya": ['mw'],
    "saindhavāyana": ['mw'],
    "saindhavāyani": ['mw'],
    "saindhavī": ['mw'],
    "saindhukṣita": ['mw'],
    "saindhumitrika": ['mw'],
    "saindhuvaktraka": ['mw'],
    "saindhī": ['mw'],
    "saindūra": ['ddsa', 'mw'],
    "saindūrīkṛ": ['cae'],
    "sainika": ['ap90', 'cae', 'ddsa', 'mw'],
    "sainya": ['cae', 'ddsa', 'mw'],
    "sainyaghātakara": ['mw'],
    "sainyahantṛ": ['mw'],
    "sainyaka": ['bhs'],
    "sainyakakṣa": ['mw'],
    "sainyakṣobha": ['mw'],
    "sainyamaya": ['mw'],
    "sainyanigrāhikā": ['mw'],
    "sainyaniveśabhūmi": ['mw'],
    "sainyanāyaka": ['mw'],
    "sainyapati": ['mw'],
    "sainyapāla": ['mw'],
    "sainyapṛṣṭha": ['mw'],
    "sainyapṛṣṭhabhāga": ['mw'],
    "sainyavyapadeśa": ['mw'],
    "sainyavāsa": ['mw'],
    "sainyaśiras": ['mw'],
    "sainyaḥ": ['ap90'],
    "sainyopaveśana": ['mw'],
    "sainyādhipati": ['mw'],
    "sainyādhyakṣa": ['mw'],
    "sainānya": ['cae', 'ddsa', 'mw'],
    "sainānīka": ['mw'],
    "saināpatya": ['cae', 'ddsa', 'mw'],
    "saināpatyaṃ": ['ap90'],
    "saira": ['ddsa', 'mw'],
    "sairakāyaṇa": ['mw'],
    "sairandhra": ['cae', 'ddsa'],
    "sairaṃdhra": ['mw'],
    "sairaṃdhraḥ": ['ap90'],
    "sairaṃdhrikā": ['mw'],
    "sairaṃdhrī": ['ap90', 'mw'],
    "saireya": ['mw'],
    "saireyaka": ['mw'],
    "sairi": ['mw'],
    "sairia": ['gra'],
    "sairibha": ['cae', 'ddsa', 'mw'],
    "sairibhaḥ": ['ap90'],
    "sairibhī": ['mw'],
    "sairidhraka": ['mw'],
    "sairika": ['ap90', 'mw'],
    "sairindhra": ['ddsa'],
    "sairiṃdha": ['mw'],
    "sairiṃdhra": ['mw'],
    "sairiṃdhraka": ['mw'],
    "sairiṣṭha": ['mw'],
    "sairya": ['cae', 'gra', 'mw'],
    "sairāvant": ['cae'],
    "sairāvat": ['ddsa', 'mw'],
    "sairīya": ['ddsa', 'mw'],
    "sairīyaka": ['mw'],
    "saisa": ['cae', 'mw'],
    "saisaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "saisikata": ['mw'],
    "saisiridhra": ['mw'],
    "saita": ['mw'],
    "saitakeya": ['mw'],
    "saitava": ['ddsa', 'mw'],
    "saitavāhinī": ['mw'],
    "saivāla": ['ap90', 'mw'],
    "saivālina": ['mw'],
    "saiṃdhava": ['ap90'],
    "saiṃdhavaka": ['ap90'],
    "saiṃdhī": ['ap90'],
    "saiṃha": ['ap90', 'cae', 'ddsa', 'mw'],
    "saiṃhakaroṇa": ['mw'],
    "saiṃhakarṇa": ['mw'],
    "saiṃhakāyana": ['mw'],
    "saiṃhala": ['ap90', 'ddsa', 'mw'],
    "saiṃhalī": ['mw'],
    "saiṃhika": ['mw'],
    "saiṃhikaḥ": ['ap90'],
    "saiṃhikeya": ['ddsa', 'mw'],
    "saiṃhādrika": ['mw'],
    "saj": ['cae', 'ddsa', 'gra', 'mw'],
    "sajala": ['ap90', 'cae', 'ddsa', 'mw'],
    "sajalanayana": ['mw'],
    "sajalapṛṣata": ['cae', 'mw'],
    "sajalatva": ['mw'],
    "sajambāla": ['mw'],
    "sajamāna": ['cped'],
    "sajana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sajanapada": ['mw'],
    "sajane": ['mw'],
    "sajanu": ['mw'],
    "sajanya": ['cae', 'gra', 'mw'],
    "sajanāmātya": ['mw'],
    "sajanīya": ['ddsa', 'mw'],
    "sajapa": ['mw'],
    "sajati": ['bhs', 'cped'],
    "sajaṃbāla": ['ap90'],
    "saji": ['cped'],
    "sajitvan": ['cae', 'gra', 'mw'],
    "sajitvā": ['cped'],
    "sajiṣṇu": ['mw'],
    "sajj": ['mw'],
    "sajja": ['ap90', 'cae', 'ddsa', 'mw'],
    "sajjakarman": ['cae', 'mw'],
    "sajjala": ['ddsa', 'mw'],
    "sajjamāna": ['cped'],
    "sajjana": ['cae', 'ddsa', 'mw'],
    "sajjanacittavallabha": ['mw'],
    "sajjanagarhita": ['mw'],
    "sajjanaikavasati": ['mw'],
    "sajjanamanoratha": ['mw'],
    "sajjanamaṇḍana": ['mw'],
    "sajjanarañjinī": ['mw'],
    "sajjanavallabha": ['mw'],
    "sajjanavallabhā": ['mw'],
    "sajjanaṃ": ['ap90'],
    "sajjaneṣṭa": ['mw'],
    "sajjati": ['cped'],
    "sajjatā": ['mw'],
    "sajjay": ['cae'],
    "sajjaya": ['ddsa', 'mw'],
    "sajjaṭā": ['mw'],
    "sajjenta": ['cped'],
    "sajjesi": ['cped'],
    "sajjeti": ['cped'],
    "sajjetvā": ['cped'],
    "sajjhu": ['cped'],
    "sajjhumaya": ['cped'],
    "sajjhāya": ['cped'],
    "sajjhāyamāna": ['cped'],
    "sajjhāyanā": ['cped'],
    "sajjhāyati": ['cped'],
    "sajjhāyi": ['cped'],
    "sajjhāyita": ['cped'],
    "sajjhāyitvā": ['cped'],
    "sajji": ['cped'],
    "sajjira": ['bhs'],
    "sajjita": ['ap90', 'cped', 'mw'],
    "sajjitvā": ['cped'],
    "sajjiya": ['cped'],
    "sajju": ['cped'],
    "sajjukaṁ": ['cped'],
    "sajjulasa": ['cped'],
    "sajjuṣṭa": ['mw'],
    "sajjā": ['ap90', 'mw'],
    "sajjī": ['mw'],
    "sajjībhū": ['ap90', 'mw'],
    "sajjībhūta": ['mw'],
    "sajjīkaraṇa": ['mw'],
    "sajjīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "sajjīkṛta": ['mw'],
    "sajjīkṣāra": ['mw'],
    "sajjīva": ['bhs'],
    "sajjīya": ['mw'],
    "sajotibhūta": ['cped'],
    "sajoṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "sajoṣas": ['cae', 'gra', 'mw'],
    "sajoṣaṇa": ['cae', 'mw'],
    "sajus": ['ap90'],
    "sajuṣ": ['ap90', 'cae', 'mw'],
    "sajvara": ['cae', 'ddsa', 'mw'],
    "sajya": ['ap90', 'cae', 'ddsa', 'mw'],
    "sajyakarman": ['cae', 'mw'],
    "sajyasāyaka": ['mw'],
    "sajyotibhūta": ['bhs'],
    "sajyotis": ['cae', 'mw'],
    "sajyotsnā": ['ap90', 'mw'],
    "sajyīkṛ": ['mw'],
    "sajāgara": ['cae', 'mw'],
    "sajāla": ['cae', 'mw'],
    "sajāmi": ['mw'],
    "sajāni": ['mw'],
    "sajāra": ['cae', 'mw'],
    "sajāta": ['ap90', 'cae', 'gra', 'mw'],
    "sajātakāma": ['mw'],
    "sajātavanasyā": ['mw'],
    "sajātavani": ['mw'],
    "sajātavat": ['mw'],
    "sajātaśaṃsa": ['mw'],
    "sajāti": ['ap90', 'cae', 'mw'],
    "sajātia": ['gra'],
    "sajātika": ['cped'],
    "sajātya": ['cae', 'gra', 'mw'],
    "sajātyaṃ": ['ap90'],
    "sajātīya": ['cae', 'mw'],
    "sajātīyavisiṣṭāntarāghaṭitatva": ['mw'],
    "sajāya": ['cae', 'mw'],
    "sajīva": ['cae', 'cped', 'mw'],
    "sajīvatā": ['mw'],
    "sajūr": ['mw'],
    "sajūrabdīya": ['mw'],
    "sajūs": ['ddsa', 'gra', 'mw'],
    "sajṛmbhikam": ['ddsa', 'mw'],
    "saka": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sakabala": ['cped'],
    "sakacchapa": ['ddsa', 'mw'],
    "sakaddama": ['cped'],
    "sakadāgāmī": ['cped'],
    "sakageha": ['cped'],
    "sakaitava": ['ap90', 'mw'],
    "sakaitavam": ['mw'],
    "sakala": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sakalabhuvanamaya": ['mw'],
    "sakaladeha": ['mw'],
    "sakaladevatāpratiṣṭhā": ['mw'],
    "sakaladoṣamaya": ['mw'],
    "sakalagranthadīpikā": ['mw'],
    "sakalaha": ['mw'],
    "sakalahaṃsagaṇa": ['mw'],
    "sakalajana": ['cae', 'mw'],
    "sakalajananī": ['mw'],
    "sakalajananīstava": ['mw'],
    "sakalakala": ['mw'],
    "sakalakaluṣa": ['cae', 'mw'],
    "sakalakarmacintāmaṇi": ['mw'],
    "sakalakāmadugha": ['mw'],
    "sakalaloka": ['cae', 'mw'],
    "sakalaprabandhavarṇasārasaṃgraha": ['mw'],
    "sakalapramāṇasaṃgraha": ['mw'],
    "sakalapurāṇasamuccaya": ['mw'],
    "sakalapurāṇatātparyasāra": ['mw'],
    "sakalapāṭha": ['mw'],
    "sakalarūpaka": ['cae', 'mw'],
    "sakalasiddhi": ['mw'],
    "sakalasiddhida": ['mw'],
    "sakalatra": ['mw'],
    "sakalavarṇa": ['mw'],
    "sakalavedin": ['mw'],
    "sakalavedopaniṣatsāropadeśasāhasrī": ['mw'],
    "sakalavedādhyāyin": ['mw'],
    "sakalavidyāmaya": ['cae', 'mw'],
    "sakalaya": ['mw'],
    "sakalayajñamaya": ['mw'],
    "sakalayūthaparivṛta": ['mw'],
    "sakalaśāntisaṃgraha": ['mw'],
    "sakalaṅka": ['mw'],
    "sakalendu": ['cae', 'mw'],
    "sakalendumukha": ['mw'],
    "sakalevara": ['mw'],
    "sakaleśvara": ['mw'],
    "sakalika": ['cae', 'ddsa', 'mw'],
    "sakalikā": ['cped'],
    "sakalpa": ['ap90', 'cae', 'mw'],
    "sakaluṣa": ['cae', 'mw'],
    "sakalādhikāra": ['mw'],
    "sakalādhāra": ['mw'],
    "sakalāgamasaṃgraha": ['mw'],
    "sakalāgamācārya": ['mw'],
    "sakalārthaśāstrasāra": ['mw'],
    "sakalārthisārthakalpadruma": ['mw'],
    "sakalārṇamaya": ['mw'],
    "sakalī": ['mw'],
    "sakalīkṛ": ['mw'],
    "sakalīvidhā": ['mw'],
    "sakamala": ['mw'],
    "sakamana": ['cped'],
    "sakamma": ['cped'],
    "sakammaka": ['cped'],
    "sakampa": ['cae', 'mw'],
    "sakampam": ['mw'],
    "sakampana": ['mw'],
    "sakapaṭam": ['mw'],
    "sakara": ['bhs', 'mw'],
    "sakaravipulā": ['mw'],
    "sakaraṇaka": ['mw'],
    "sakaraṇīya": ['bhs', 'cped'],
    "sakarmaka": ['ap90', 'cae', 'mw'],
    "sakarman": ['mw'],
    "sakarmatā": ['mw'],
    "sakartṛka": ['ap90', 'mw'],
    "sakartṛkatva": ['mw'],
    "sakartṛkatā": ['mw'],
    "sakaruṇa": ['ap90', 'cae', 'mw'],
    "sakaruṇam": ['mw'],
    "sakarṇa": ['ap90', 'cae', 'mw'],
    "sakarṇaka": ['cae', 'mw'],
    "sakarṇaprāvṛta": ['mw'],
    "sakarṇapuccha": ['mw'],
    "sakasāva": ['cped'],
    "sakata-mukha": ['cped'],
    "sakaurava": ['mw'],
    "sakautuka": ['cae', 'mw'],
    "sakautukam": ['mw'],
    "sakautūhalam": ['cae', 'mw'],
    "sakavaca": ['mw'],
    "sakañcuka": ['mw'],
    "sakaśmīra": ['mw'],
    "sakaṃpa": ['ap90'],
    "sakaṃṭaka": ['ap90'],
    "sakaṅkaṭa": ['mw'],
    "sakaṅkha": ['cped'],
    "sakaṇika": ['cped'],
    "sakaṇḍu": ['mw'],
    "sakaṇḍūka": ['mw'],
    "sakaṇṭaka": ['cae', 'cped', 'ddsa', 'mw'],
    "sakaṇṭharodham": ['mw'],
    "sakaṣāya": ['cae', 'mw'],
    "sakaṣāyatva": ['mw'],
    "sakaṣṭam": ['cae', 'mw'],
    "sakaṭa": ['ap90', 'cped', 'mw'],
    "sakaṭa-parivatta": ['cped'],
    "sakaṭabhāra": ['cped'],
    "sakaṭavyūha": ['cped'],
    "sakaṭavāha": ['cped'],
    "sakaṭuka": ['mw'],
    "sakaṭākṣa": ['mw'],
    "sakaṭākṣam": ['mw'],
    "sakaṭānna": ['ddsa', 'mw'],
    "saketa": ['cae', 'ddsa', 'gra', 'mw'],
    "saketu": ['mw'],
    "sakeśa": ['ap90', 'cae', 'mw'],
    "sakeśanakha": ['mw'],
    "sakh": ['mw'],
    "sakha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sakhaḍga": ['cae', 'mw'],
    "sakhaṇḍa": ['mw'],
    "sakheda": ['mw'],
    "sakhedam": ['cae', 'ddsa', 'mw'],
    "sakhelam": ['mw'],
    "sakhi": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sakhia": ['gra'],
    "sakhibhāva": ['mw'],
    "sakhidatta": ['mw'],
    "sakhikā": ['bhs'],
    "sakhila": ['bhs', 'cped', 'mw'],
    "sakhipūrva": ['cae', 'mw'],
    "sakhitva": ['gra', 'mw'],
    "sakhitvana": ['gra', 'mw'],
    "sakhitā": ['cae', 'cped', 'ddsa', 'mw'],
    "sakhivant": ['cae'],
    "sakhivat": ['gra', 'mw'],
    "sakhivid": ['cae', 'mw'],
    "sakhivigraha": ['mw'],
    "sakhola": ['ddsa', 'mw'],
    "sakhura": ['mw'],
    "sakhurapravāra": ['bhs'],
    "sakhya": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sakhyavisarjana": ['mw'],
    "sakhyaṃ": ['ap90'],
    "sakhāya": ['bhs'],
    "sakhī": ['ap90', 'cae', 'ddsa', 'mw'],
    "sakhīgaṇa": ['cae', 'mw'],
    "sakhīgaṇasamāvṛta": ['mw'],
    "sakhīhṛdayābharaṇa": ['mw'],
    "sakhījana": ['cae', 'mw'],
    "sakhīkadambaka": ['mw'],
    "sakhīsahita": ['mw'],
    "sakhīsneha": ['cae', 'mw'],
    "sakhīy": ['cae', 'gra'],
    "sakhīya": ['ddsa', 'mw'],
    "sakhīyati": ['ap90'],
    "sakicca": ['cped'],
    "sakid eva": ['cped'],
    "sakirīṭakaustubha": ['mw'],
    "sakiñcana": ['cped'],
    "sakiṁ": ['cped'],
    "sakiṃcana": ['bhs'],
    "sakiṃkara": ['cae', 'mw'],
    "sakka": ['cped'],
    "sakkacca": ['cped'],
    "sakkaccakārī": ['cped'],
    "sakkaccaṁ": ['cped'],
    "sakkari": ['cped'],
    "sakkaritabba": ['cped'],
    "sakkarituṁ": ['cped'],
    "sakkaritvā": ['cped'],
    "sakkaronta": ['cped'],
    "sakkaroti": ['cped'],
    "sakkarīyati": ['cped'],
    "sakkarīyatimāna": ['cped'],
    "sakkata": ['cped'],
    "sakkati": ['bhs'],
    "sakkatta": ['cped'],
    "sakkatvā": ['cped'],
    "sakkhali": ['cped'],
    "sakkhalikā": ['cped'],
    "sakkharā": ['cped'],
    "sakkhi": ['cped'],
    "sakkhidiṭṭha": ['cped'],
    "sakkhika": ['cped'],
    "sakkhipuṭṭha": ['cped'],
    "sakkhī": ['cped'],
    "sakkin": ['bhs'],
    "sakkonta": ['cped'],
    "sakkoti": ['cped'],
    "sakkuṇanta": ['cped'],
    "sakkuṇeyyatta": ['cped'],
    "sakkuṇi": ['cped'],
    "sakkuṇimāna": ['cped'],
    "sakkuṇitvā": ['cped'],
    "sakkuṇāti": ['cped'],
    "sakkā": ['cped'],
    "sakkāra": ['cped'],
    "sakkātabba": ['cped'],
    "sakkātuṁ": ['cped'],
    "sakkāya": ['cped'],
    "sakkāyadiṭṭhi": ['cped'],
    "sakman": ['cae', 'ddsa', 'gra', 'mw'],
    "sakmia": ['gra'],
    "sakmya": ['cae', 'gra', 'mw'],
    "sakopa": ['ap90', 'cae', 'mw'],
    "sakopam": ['mw'],
    "sakopavikṛti": ['mw'],
    "sakośa": ['mw'],
    "sakratu": ['cae', 'ddsa', 'gra', 'mw'],
    "sakriya": ['ap90', 'mw'],
    "sakriyatva": ['mw'],
    "sakrodha": ['cae', 'mw'],
    "sakrodhahāsam": ['mw'],
    "sakrodham": ['mw'],
    "sakrodhana": ['mw'],
    "sakroḍa": ['mw'],
    "sakrudh": ['cae', 'mw'],
    "sakrīḍa": ['mw'],
    "sakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "saktadviṣ": ['mw'],
    "saktamūtra": ['mw'],
    "saktatva": ['mw'],
    "saktatā": ['mw'],
    "saktavaira": ['mw'],
    "saktavat": ['mw'],
    "saktavya": ['mw'],
    "saktha": ['cae', 'ddsa', 'mw'],
    "sakthan": ['ap90', 'cae', 'ddsa', 'gra'],
    "sakthi": ['ap90', 'cae', 'gra', 'mw'],
    "sakthī": ['gra', 'mw'],
    "sakti": ['cae', 'ddsa', 'mw'],
    "saktimat": ['mw'],
    "saktiḥ": ['ap90'],
    "saktu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "saktudhānī": ['mw'],
    "saktughaṭākhyāyikā": ['mw'],
    "saktuhoma": ['cae', 'mw'],
    "saktuka": ['bhs', 'mw'],
    "saktukaḥ": ['ap90'],
    "saktukāra": ['mw'],
    "saktukāraka": ['mw'],
    "saktula": ['ap90', 'mw'],
    "saktumiśra": ['mw'],
    "saktuphalā": ['mw'],
    "saktuphalī": ['mw'],
    "saktuprasthīya": ['mw'],
    "saktusindhu": ['mw'],
    "saktuśrī": ['cae', 'mw'],
    "sakukṣi": ['ap90', 'mw'],
    "sakula": ['ap90', 'mw'],
    "sakulaja": ['cae', 'mw'],
    "sakulya": ['cae', 'mw'],
    "sakulyaḥ": ['ap90'],
    "sakunta": ['cped'],
    "sakuruṇḍa": ['mw'],
    "sakusumāstaraṇa": ['mw'],
    "sakutūhala": ['mw'],
    "sakutūhalam": ['mw'],
    "sakuñjara": ['mw'],
    "sakuśa": ['mw'],
    "sakuṇa": ['cped'],
    "sakuṇagghī": ['cped'],
    "sakuṇī": ['cped'],
    "sakuṇḍa": ['mw'],
    "sakuṇḍala": ['mw'],
    "sakuṣṭhika": ['mw'],
    "sakuṭumba": ['mw'],
    "sakvaṇa": ['mw'],
    "sakya": ['cped'],
    "sakyamuni": ['cped'],
    "sakākola": ['cae', 'mw'],
    "sakākolaḥ": ['ap90'],
    "sakāla": ['ap90', 'mw'],
    "sakālam": ['mw'],
    "sakālī": ['mw'],
    "sakālīsamudra": ['mw'],
    "sakāma": ['ap90', 'cae', 'mw'],
    "sakāmam": ['mw'],
    "sakāmāri": ['mw'],
    "sakāra": ['cae', 'mw'],
    "sakārabheda": ['mw'],
    "sakāraṇa": ['mw'],
    "sakāraṇaka": ['mw'],
    "sakārilipi": ['bhs'],
    "sakārmuka": ['mw'],
    "sakāsa": ['cped'],
    "sakātara": ['cae', 'mw'],
    "sakātaram": ['mw'],
    "sakāyikā": ['bhs', 'mw'],
    "sakāśa": ['ap90', 'cae', 'mw'],
    "sakāśāt": ['bhs'],
    "sakāṣāya": ['mw'],
    "sakīla": ['mw'],
    "sakīya": ['cped'],
    "sakīṭa": ['mw'],
    "sakūti": ['cae', 'mw'],
    "sakṛcchra": ['mw'],
    "sakṛcchrutadhara": ['mw'],
    "sakṛd": ['mw'],
    "sakṛdabhiṣuta": ['mw'],
    "sakṛdgarbha": ['mw'],
    "sakṛdgarbhā": ['mw'],
    "sakṛdgati": ['mw'],
    "sakṛdgraha": ['mw'],
    "sakṛdgrāha": ['mw'],
    "sakṛdguha": ['mw'],
    "sakṛduktagṛhītārtha": ['mw'],
    "sakṛdupamathita": ['mw'],
    "sakṛdvaha": ['mw'],
    "sakṛdvibhāta": ['cae', 'mw'],
    "sakṛdvidyutta": ['mw'],
    "sakṛdvīra": ['mw'],
    "sakṛdācchinna": ['mw'],
    "sakṛdādīpana": ['mw'],
    "sakṛdāgāmin": ['bhs', 'mw'],
    "sakṛdāgāmiphala": ['mw'],
    "sakṛdāgāmiphalapratipannaka": ['mw'],
    "sakṛdāgāmitva": ['mw'],
    "sakṛdāhṛta": ['mw'],
    "sakṛl": ['mw'],
    "sakṛllekha": ['mw'],
    "sakṛllū": ['mw'],
    "sakṛllūna": ['mw'],
    "sakṛn": ['mw'],
    "sakṛnmadvat": ['cae', 'mw'],
    "sakṛnnandā": ['mw'],
    "sakṛnnārāśaṃsa": ['mw'],
    "sakṛpa": ['mw'],
    "sakṛpam": ['cae', 'mw'],
    "sakṛpaṇa": ['ap90'],
    "sakṛpaṇam": ['cae', 'ddsa', 'mw'],
    "sakṛt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sakṛta": ['mw'],
    "sakṛtphalā": ['mw'],
    "sakṛtpraja": ['mw'],
    "sakṛtprasūtikā": ['mw'],
    "sakṛtprayogin": ['mw'],
    "sakṛtsnāyin": ['cae', 'mw'],
    "sakṛtsū": ['cae', 'gra', 'mw'],
    "sakṣ": ['ddsa', 'mw'],
    "sakṣa": ['cae', 'mw'],
    "sakṣama": ['mw'],
    "sakṣata": ['mw'],
    "sakṣatram": ['mw'],
    "sakṣaṇa": ['ap90', 'ddsa', 'gra', 'mw'],
    "sakṣaṇi": ['cae', 'ddsa', 'gra', 'mw'],
    "sakṣit": ['cae', 'ddsa', 'gra', 'mw'],
    "sakṣāra": ['mw'],
    "sakṣīra": ['cae', 'mw'],
    "sakṣīradṛti": ['mw'],
    "sal": ['ap90', 'mw'],
    "sala": ['mw'],
    "salabha": ['cped'],
    "salada": ['mw'],
    "salagnaka": ['mw'],
    "salais": ['mw'],
    "salajja": ['ap90', 'cae', 'mw'],
    "salajjam": ['mw'],
    "salajjatva": ['mw'],
    "salajjita": ['cae', 'mw'],
    "salajjitasnehakaruṇam": ['mw'],
    "salakhaka": ['mw'],
    "salakkhaṇa": ['cped'],
    "salakṣa": ['mw'],
    "salakṣaṇa": ['cae', 'ddsa', 'mw'],
    "salakṣman": ['cae', 'gra', 'mw'],
    "salalitam": ['cae', 'mw'],
    "salalūka": ['ddsa', 'gra', 'mw'],
    "salarin": ['mw'],
    "salasala": ['mw'],
    "salavaka": ['mw'],
    "salavaṇa": ['mw'],
    "salavi": ['cae', 'mw'],
    "salaṃ": ['ap90'],
    "saleka": ['mw'],
    "salepa": ['mw'],
    "saleśa": ['mw'],
    "saleśam": ['mw'],
    "salha": ['ddsa', 'mw'],
    "salhaṇa": ['mw'],
    "salhādam": ['ddsa'],
    "saliga": ['mw'],
    "salila": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "salilabhara": ['mw'],
    "salilabhaya": ['mw'],
    "salilabhayadāyin": ['mw'],
    "salilacara": ['mw'],
    "salilacaraketana": ['mw'],
    "salilada": ['cae', 'mw'],
    "saliladhara": ['cae', 'mw'],
    "saliladhārā": ['cped'],
    "saliladāyin": ['mw'],
    "salilagargarī": ['cae', 'mw'],
    "salilagupta": ['bhs'],
    "salilaguru": ['mw'],
    "salilaja": ['cae', 'mw'],
    "salilajanman": ['mw'],
    "salilakarman": ['cae', 'mw'],
    "salilakriyā": ['mw'],
    "salilakukkuṭa": ['mw'],
    "salilakuntala": ['mw'],
    "salilamaya": ['mw'],
    "salilamuc": ['mw'],
    "salilanidhi": ['cae', 'mw'],
    "salilanipāta": ['mw'],
    "salilaniṣeka": ['mw'],
    "salilapati": ['cae', 'mw'],
    "salilapavanāśin": ['mw'],
    "salilapriya": ['mw'],
    "salilapūra": ['mw'],
    "salilapūravat": ['mw'],
    "salilaraya": ['mw'],
    "salilarāja": ['mw'],
    "salilarāśi": ['mw'],
    "salilasaraka": ['cae', 'mw'],
    "salilastambhin": ['mw'],
    "salilasthalacara": ['mw'],
    "salilatva": ['mw'],
    "salilaudana": ['mw'],
    "salilaukas": ['mw'],
    "salilavat": ['mw'],
    "salilavāta": ['mw'],
    "salilayoni": ['mw'],
    "salilaṃ": ['ap90'],
    "salilecara": ['mw'],
    "salilendhana": ['mw'],
    "salilendra": ['mw'],
    "salilendrapura": ['mw'],
    "salileśa": ['mw'],
    "salileśaya": ['mw'],
    "salileśvara": ['mw'],
    "saliloccaya": ['mw'],
    "salilodbhava": ['mw'],
    "salilopajīvin": ['mw'],
    "salilopaplava": ['mw'],
    "salilottha": ['mw'],
    "salilotthita": ['cae'],
    "salilā": ['mw'],
    "salilādhipa": ['mw'],
    "salilāhāra": ['mw'],
    "salilākara": ['mw'],
    "salilālaya": ['mw'],
    "salilārthin": ['mw'],
    "salilārṇava": ['cae', 'mw'],
    "salilārṇavasāyaka": ['mw'],
    "salilāvagāha": ['mw'],
    "salilāvatī": ['mw'],
    "salilāñjali": ['mw'],
    "salilāśana": ['mw'],
    "salilāśaya": ['cae', 'mw'],
    "saliṅga": ['mw'],
    "saliṅgin": ['mw'],
    "salla": ['cped'],
    "salladra": ['mw'],
    "sallahuka": ['cped'],
    "sallaka": ['cped'],
    "sallakatta": ['cped'],
    "sallakattiya": ['cped'],
    "sallakkhaṇa": ['cped'],
    "sallakkhaṇā": ['cped'],
    "sallakkhenta": ['cped'],
    "sallakkhesi": ['cped'],
    "sallakkheti": ['cped'],
    "sallakkhetvā": ['cped'],
    "sallakkhita": ['cped'],
    "sallakā": ['ap90'],
    "sallakī": ['cae', 'mw'],
    "sallakīya": ['mw'],
    "sallakṣaṇatīrtha": ['mw'],
    "sallakṣya": ['mw'],
    "sallapana": ['cped'],
    "sallapanta": ['cped'],
    "sallapati": ['cped'],
    "sallapi": ['cped'],
    "sallapitvā": ['cped'],
    "sallaviddha": ['cped'],
    "sallaya": ['mw'],
    "sallekha": ['cped'],
    "sallikhati": ['cped'],
    "sallikhi": ['cped'],
    "sallikhita": ['cped'],
    "sallikhitvā": ['cped'],
    "salloka": ['cae', 'ddsa', 'mw'],
    "sallāpa": ['cped', 'mw'],
    "sallīna": ['cped'],
    "sallīyanā": ['cped'],
    "sallīyati": ['cped'],
    "sallīyi": ['cped'],
    "sallīyitvā": ['cped'],
    "salobha": ['cae', 'mw'],
    "salohita": ['mw'],
    "saloka": ['cae', 'ddsa', 'mw'],
    "salokatā": ['ap90', 'cae', 'mw'],
    "salokya": ['cae', 'mw'],
    "salokānāṃ": ['bhs'],
    "salomadhi": ['mw'],
    "saloman": ['cae', 'mw'],
    "salomatva": ['mw'],
    "saloptra": ['cae'],
    "salva": ['mw'],
    "salvadeśa": ['mw'],
    "salya": ['mw'],
    "salābha": ['cped'],
    "salājakusuma": ['mw'],
    "salākā": ['cped'],
    "salākābhatta": ['cped'],
    "salākāgāha": ['cped'],
    "salākāgāhāpaka": ['cped'],
    "salākākagga": ['cped'],
    "salākāvutta": ['cped'],
    "salāvṛkī": ['cae', 'mw'],
    "salāṭu": ['cped'],
    "salāṭuka": ['cped'],
    "salīla": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "salīlagajagāmin": ['bhs', 'mw'],
    "salīlahaṃsagamanā": ['mw'],
    "salīlam": ['mw'],
    "salīlaparihāsa": ['mw'],
    "salūna": ['mw'],
    "sam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sama": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "samabhibhāṣ": ['mw'],
    "samabhibhāṣaṇa": ['cae', 'mw'],
    "samabhibhūta": ['bhs'],
    "samabhicchanna": ['mw'],
    "samabhidhyai": ['mw'],
    "samabhidhā": ['cae', 'ddsa', 'mw'],
    "samabhidhāv": ['mw'],
    "samabhidru": ['mw'],
    "samabhidruta": ['mw'],
    "samabhidrutam": ['mw'],
    "samabhigam": ['mw'],
    "samabhigarj": ['mw'],
    "samabhiguh": ['mw'],
    "samabhiharaṇa": ['mw'],
    "samabhihita": ['mw'],
    "samabhihāra": ['cae', 'mw'],
    "samabhihāraḥ": ['ap90'],
    "samabhihṛ": ['mw'],
    "samabhihṛṣ": ['mw'],
    "samabhijan": ['mw'],
    "samabhijñā": ['mw'],
    "samabhikram": ['mw'],
    "samabhikruddha": ['mw'],
    "samabhikīrt": ['mw'],
    "samabhilaṣ": ['mw'],
    "samabhinand": ['mw'],
    "samabhinandita": ['mw'],
    "samabhinayati": ['bhs'],
    "samabhiniḥsṛta": ['mw'],
    "samabhipad": ['mw'],
    "samabhipat": ['mw'],
    "samabhiplu": ['mw'],
    "samabhipluta": ['ap90', 'mw'],
    "samabhiprasādayati": ['bhs'],
    "samabhipraṇamati": ['bhs'],
    "samabhiprekṣ": ['mw'],
    "samabhipāl": ['mw'],
    "samabhipīḍ": ['mw'],
    "samabhipūj": ['mw'],
    "samabhipṝ": ['mw'],
    "samabhirañj": ['mw'],
    "samabhirocate": ['bhs'],
    "samabhiruh": ['mw'],
    "samabhisarati": ['bhs'],
    "samabhisaraṇa": ['mw'],
    "samabhisaraṇaṃ": ['ap90'],
    "samabhisaṃdhā": ['mw'],
    "samabhisaṃvṛta": ['mw'],
    "samabhisṛ": ['mw'],
    "samabhitarj": ['mw'],
    "samabhitas": ['cae', 'mw'],
    "samabhityaj": ['mw'],
    "samabhityakta": ['mw'],
    "samabhityaktajīvita": ['mw'],
    "samabhivad": ['mw'],
    "samabhivadh": ['mw'],
    "samabhivandati": ['bhs'],
    "samabhivyāhāra": ['cae', 'mw'],
    "samabhivyāhāraḥ": ['ap90'],
    "samabhivyāhārin": ['mw'],
    "samabhivyāhṛ": ['mw'],
    "samabhivyāhṛta": ['mw'],
    "samabhivāñch": ['mw'],
    "samabhivīkṣ": ['mw'],
    "samabhivṛdh": ['mw'],
    "samabhivṛt": ['mw'],
    "samabhivṛṣ": ['mw'],
    "samabhiyā": ['mw'],
    "samabhiyāc": ['mw'],
    "samabhiśubh": ['mw'],
    "samabhiśyāna": ['mw'],
    "samabhiṣic": ['mw'],
    "samabhiṣyand": ['mw'],
    "samabhiṣyandin": ['mw'],
    "samabhiṣṭhā": ['mw'],
    "samabhiṣṭu": ['mw'],
    "samabhiṣṭuta": ['mw'],
    "samabhyarc": ['mw'],
    "samabhyarcana": ['mw'],
    "samabhyarcanaṃ": ['ap90'],
    "samabhyarcita": ['mw'],
    "samabhyarth": ['mw'],
    "samabhyarthayitṛ": ['cae', 'mw'],
    "samabhyas": ['mw'],
    "samabhyatikram": ['mw'],
    "samabhyavagā": ['mw'],
    "samabhyave": ['mw'],
    "samabhye": ['mw'],
    "samabhyuccaya": ['mw'],
    "samabhyuccayavat": ['mw'],
    "samabhyuddharaṇa": ['mw'],
    "samabhyuddhṛ": ['mw'],
    "samabhyudgacchati": ['bhs'],
    "samabhyudgam": ['mw'],
    "samabhyudyata": ['mw'],
    "samabhyunnata": ['cae', 'mw'],
    "samabhyupagamana": ['mw'],
    "samabhyupaiti": ['bhs'],
    "samabhyupe": ['mw'],
    "samabhyupeya": ['mw'],
    "samabhyutthā": ['mw'],
    "samabhyādā": ['mw'],
    "samabhyāgam": ['mw'],
    "samabhyāgata": ['mw'],
    "samabhyāgā": ['mw'],
    "samabhyāhata": ['bhs'],
    "samabhyāhāra": ['mw'],
    "samabhyāhāraḥ": ['ap90'],
    "samabhyānī": ['mw'],
    "samabhyāsa": ['mw'],
    "samabhyāśa": ['cae', 'mw'],
    "samabhyāśīkaraṇa": ['mw'],
    "samabhāga": ['mw'],
    "samabhāva": ['mw'],
    "samabhī": ['mw'],
    "samabhūmi": ['cae', 'mw'],
    "samabuddhi": ['bhs', 'cae', 'mw'],
    "samacakravāla": ['mw'],
    "samacariyā": ['cped'],
    "samacaturaśra": ['ddsa', 'mw'],
    "samacaturaśrī": ['mw'],
    "samacaturbhuja": ['mw'],
    "samacatuṣkoṇa": ['mw'],
    "samacatvāriṃśadantatā": ['mw'],
    "samaccheda": ['mw'],
    "samacchedana": ['mw'],
    "samacchedīkṛ": ['mw'],
    "samacetas": ['cae', 'mw'],
    "samacitta": ['cae', 'cped', 'mw'],
    "samacittatva": ['mw'],
    "samacittatā": ['mw'],
    "samacittā": ['cped'],
    "samacodita": ['mw'],
    "samad": ['cae', 'ddsa', 'gra', 'mw'],
    "samada": ['ap90', 'cae', 'mw'],
    "samadana": ['cae', 'gra', 'mw'],
    "samadanta": ['mw'],
    "samadantatā": ['mw'],
    "samadarśana": ['cae', 'ddsa', 'mw'],
    "samadarśin": ['cae', 'mw'],
    "samadaṃṣṭratā": ['mw'],
    "samadeśa": ['cae', 'mw'],
    "samadharma": ['mw'],
    "samadhibhāṣati": ['bhs'],
    "samadhigacchati": ['cped'],
    "samadhigacchi": ['cped'],
    "samadhigam": ['ap90', 'mw'],
    "samadhigama": ['ddsa', 'mw'],
    "samadhigamana": ['mw'],
    "samadhigamanaṃ": ['ap90'],
    "samadhigamya": ['mw'],
    "samadhigantvā": ['cped'],
    "samadhigata": ['cped', 'mw'],
    "samadhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "samadhikalajjāvatī": ['mw'],
    "samadhikalāvaṇya": ['mw'],
    "samadhikam": ['mw'],
    "samadhikatara": ['mw'],
    "samadhikatararūpa": ['mw'],
    "samadhikatarocchvāsin": ['mw'],
    "samadhikārambha": ['mw'],
    "samadhikṛt": ['mw'],
    "samadhikṛta": ['bhs'],
    "samadhirohaṇa": ['mw'],
    "samadhiruh": ['mw'],
    "samadhirūḍha": ['mw'],
    "samadhisṛp": ['mw'],
    "samadhiśri": ['mw'],
    "samadhiśī": ['mw'],
    "samadhiṣṭha": ['bhs'],
    "samadhiṣṭhita": ['mw'],
    "samadhiṣṭhā": ['mw'],
    "samadhiṣṭhāna": ['mw'],
    "samadhura": ['cae', 'ddsa', 'mw'],
    "samadhurā": ['mw'],
    "samadhva": ['ap90', 'mw'],
    "samadhyama": ['mw'],
    "samadhyayana": ['mw'],
    "samadhyās": ['mw'],
    "samadhyāsita": ['mw'],
    "samadhā": ['cae', 'mw'],
    "samadhī": ['mw'],
    "samadhīta": ['mw'],
    "samadhṛta": ['cae', 'mw'],
    "samadu": ['mw'],
    "samaduḥkha": ['cae', 'mw'],
    "samaduḥkhasukha": ['cae', 'mw'],
    "samadvan": ['cae', 'gra', 'mw'],
    "samadvibhuja": ['mw'],
    "samadvidvibhuja": ['mw'],
    "samadvādaśāśra": ['mw'],
    "samadyuti": ['cae', 'mw'],
    "samadṛś": ['mw'],
    "samadṛṣṭi": ['bhs', 'cae', 'mw'],
    "samadṛṣṭipāta": ['mw'],
    "samadṛṣṭitva": ['mw'],
    "samagandha": ['mw'],
    "samagandhaka": ['mw'],
    "samagandhika": ['mw'],
    "samagga": ['cped'],
    "samaggakaraṇa": ['cped'],
    "samaggarata": ['cped'],
    "samaggatta": ['cped'],
    "samaggārāma": ['cped'],
    "samagra": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "samagrabhakṣaṇaśīla": ['mw'],
    "samagradhana": ['cae', 'mw'],
    "samagramalahāraka": ['mw'],
    "samagrasampad": ['mw'],
    "samagrasauvarṇa": ['mw'],
    "samagravartin": ['cae', 'mw'],
    "samagraya": ['mw'],
    "samagraśakti": ['mw'],
    "samagraṇī": ['mw'],
    "samagrendu": ['cae', 'mw'],
    "samagrendunibhānana": ['mw'],
    "samagrya": ['bhs'],
    "samagrāṅga": ['mw'],
    "samagrībhūta": ['bhs'],
    "samaha": ['cae', 'ddsa', 'gra', 'mw'],
    "samahas": ['mw'],
    "samahyā": ['mw'],
    "samahāvrata": ['mw'],
    "samahīdhara": ['ddsa', 'mw'],
    "samairaya": ['mw'],
    "samaj": ['ap90', 'mw'],
    "samaja": ['cae', 'mw'],
    "samajaḥ": ['ap90'],
    "samajja": ['cped'],
    "samajjabhicaraṇa": ['cped'],
    "samajjaṭṭhāna": ['cped'],
    "samajjitaka": ['bhs'],
    "samajya": ['bhs'],
    "samajyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "samajñā": ['bhs', 'mw'],
    "samajāti": ['mw'],
    "samajātika": ['cped'],
    "samajātīya": ['mw'],
    "samajīvakā": ['bhs'],
    "samaka": ['cae', 'cped', 'ddsa', 'mw'],
    "samakakṣa": ['cae', 'mw'],
    "samakakṣatva": ['mw'],
    "samakakṣatā": ['mw'],
    "samakakṣā": ['mw'],
    "samakanyā": ['mw'],
    "samakara": ['mw'],
    "samakarman": ['mw'],
    "samakarṇa": ['mw'],
    "samakarṇatā": ['mw'],
    "samakhāta": ['mw'],
    "samakkhana": ['cped'],
    "samakna": ['mw'],
    "samakola": ['mw'],
    "samakoṣṭhamiti": ['mw'],
    "samakrama": ['ddsa', 'mw'],
    "samakramatā": ['mw'],
    "samakriya": ['mw'],
    "samakriyatva": ['mw'],
    "samakta": ['ddsa', 'mw'],
    "samakāla": ['cae', 'mw'],
    "samakālabhava": ['mw'],
    "samakālam": ['mw'],
    "samakālīna": ['mw'],
    "samakṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "samakṣadarśana": ['cae', 'mw'],
    "samakṣam": ['mw'],
    "samakṣatas": ['mw'],
    "samakṣatā": ['mw'],
    "samakṣe": ['mw'],
    "samakṣetra": ['mw'],
    "samakṣāt": ['mw'],
    "samala": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "samalamba": ['mw'],
    "samalaṃkṛ": ['mw'],
    "samalaṃkṛta": ['mw'],
    "samalaṅkari": ['cped'],
    "samalaṅkaritvā": ['cped'],
    "samalaṅkaroti": ['cped'],
    "samalaṅkata": ['cped'],
    "samalaṅkṛta": ['ddsa'],
    "samalepanī": ['mw'],
    "samallikākṣa": ['ddsa', 'mw'],
    "samaloṣṭakāñcana": ['cae', 'ddsa', 'mw'],
    "samaloṣṭrakāñcana": ['mw'],
    "samaloṣṭāśmakāñcana": ['cae', 'mw'],
    "samalīkṛ": ['mw'],
    "samam": ['mw'],
    "samamathita": ['bhs'],
    "samamati": ['cae', 'mw'],
    "samamaya": ['mw'],
    "samamaṇḍala": ['mw'],
    "samamaṇḍalaśaṅku": ['mw'],
    "samambhūmi": ['mw'],
    "samambila": ['mw'],
    "samamiti": ['mw'],
    "samamātra": ['mw'],
    "saman": ['mw'],
    "samana": ['cae', 'ddsa', 'gra', 'mw'],
    "samanaga": ['mw'],
    "samanagatika": ['cped'],
    "samanagā": ['cae', 'gra'],
    "samanana": ['mw'],
    "samanantara": ['cae', 'cped', 'ddsa', 'mw'],
    "samanantaram": ['mw'],
    "samanantarapratyaya": ['bhs'],
    "samanantarā": ['cped'],
    "samanara": ['mw'],
    "samanas": ['cae', 'ddsa', 'gra', 'mw'],
    "samanaska": ['cae', 'mw'],
    "samanatta": ['cped'],
    "samandhakāra": ['mw'],
    "samandhakārīkṛta": ['mw'],
    "samania": ['gra'],
    "samanindānavana": ['ddsa', 'mw'],
    "samanmatha": ['cae', 'mw'],
    "samannāgata": ['cped'],
    "samannāharati": ['cped'],
    "samannāhari": ['cped'],
    "samannāharitvā": ['cped'],
    "samannāhaṭa": ['cped'],
    "samanojñārutasiṃhadhvaja": ['bhs'],
    "samanta": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "samantabhaddaka": ['cped'],
    "samantabhadra": ['bhs', 'mw'],
    "samantabhadrā": ['bhs'],
    "samantabhuj": ['mw'],
    "samantacakkhu": ['cped'],
    "samantacakṣus": ['bhs'],
    "samantacandra": ['bhs'],
    "samantacāritramati": ['bhs', 'mw'],
    "samantadarśananetra": ['bhs'],
    "samantadarśin": ['bhs', 'mw'],
    "samantadharmadhātugaganapratibhāsamakuṭa": ['bhs'],
    "samantadharmadvāravahanaśikharābha": ['bhs'],
    "samantadigabhimukha": ['bhs'],
    "samantadiśatejas": ['bhs'],
    "samantadugdhā": ['mw'],
    "samantadugdhī": ['mw'],
    "samantagambhīraśrīvimalaprabhā": ['bhs'],
    "samantagandha": ['bhs', 'mw'],
    "samantagandhavitāna": ['bhs'],
    "samantagandhāvabhāsaśriya": ['bhs'],
    "samantagupta": ['bhs'],
    "samantaguṇamegha": ['bhs'],
    "samantajyotigandhāvabhāsaśriya": ['bhs'],
    "samantajñānabhadramaṇḍala": ['bhs'],
    "samantajñānacaryāvilamba": ['bhs'],
    "samantajñānadhvajaśūra": ['bhs'],
    "samantajñānamaṇḍalapratibhāsanirghoṣa": ['bhs'],
    "samantajñānaprabharāja": ['bhs'],
    "samantajñānaprabhāsa": ['bhs'],
    "samantajñānaratnārciśrīguṇaketurāja": ['bhs'],
    "samantajñānaratnārciḥpadmabhadrābhirāmanetraśrīcandrā": ['bhs'],
    "samantajñānābhapravara": ['bhs'],
    "samantajñānālokavikramasiṃha": ['bhs'],
    "samantajñānārcipadma": ['bhs'],
    "samantajñānārciśrīguṇaketudhvaja": ['bhs'],
    "samantakarṇa": ['bhs'],
    "samantakusuma": ['bhs', 'mw'],
    "samantakusumārciḥpralambacūḍa": ['bhs'],
    "samantam": ['mw'],
    "samantamukha": ['bhs'],
    "samantamukhadhāriṇī": ['mw'],
    "samantamukhajñānabhadrameru": ['bhs'],
    "samantamukhajñānavirocanaghoṣa": ['bhs'],
    "samantamukhaviśuddhivyūha": ['bhs'],
    "samantamukhā": ['bhs'],
    "samantanetra": ['bhs', 'mw'],
    "samantaparyāyin": ['ddsa', 'mw'],
    "samantapañcaka": ['mw'],
    "samantaprabha": ['bhs', 'mw'],
    "samantaprabhatejas": ['bhs'],
    "samantaprabhaśrītejas": ['bhs'],
    "samantaprabhā": ['bhs'],
    "samantaprabhāsa": ['bhs', 'mw'],
    "samantaprajñaptinirghoṣamegha": ['bhs'],
    "samantaprajñābhadharmanagarapradīpa": ['bhs'],
    "samantaprasādika": ['mw'],
    "samantapratibhāsacūḍa": ['bhs'],
    "samantaprāsādika": ['bhs', 'mw'],
    "samantaprāsādikatā": ['mw'],
    "samantapāsādika": ['cped'],
    "samantara": ['cped', 'mw'],
    "samantarahita": ['bhs'],
    "samantaratnakiraṇamuktaprabha": ['bhs'],
    "samantaratnakusumaprabhā": ['bhs'],
    "samantaratnā": ['bhs'],
    "samantaratnārciśrīguṇaketurāja": ['bhs'],
    "samantaraśmi": ['bhs', 'mw'],
    "samantasattvatrāṇojaḥśrī": ['bhs'],
    "samantasaṃbhavapradīpa": ['bhs'],
    "samantasaṃpūrṇaśrīgarbhā": ['bhs'],
    "samantasphāraṇamukhadarśana": ['mw'],
    "samantasthūlāvalokana": ['mw'],
    "samantasthūlāvalokananayanābhirāma": ['bhs'],
    "samantasūcisuviśuddhajñānakusuma": ['bhs'],
    "samantasūryāvabhāsaprabharāja": ['bhs'],
    "samantatabhadra": ['bhs'],
    "samantatas": ['mw'],
    "samantato": ['cped'],
    "samantavairocanacandra": ['bhs'],
    "samantavairocanamakuṭa": ['bhs'],
    "samantavairocanaśrīmerurāja": ['bhs'],
    "samantaveda": ['bhs'],
    "samantavighuṣṭakīrtidhvaja": ['bhs'],
    "samantavilokitajñāna": ['bhs'],
    "samantavilokitā": ['bhs', 'mw'],
    "samantavyūha": ['bhs'],
    "samantavyūhasāgaracaryavyavalokana": ['mw'],
    "samantavīryolkāvabhāsamegha": ['bhs'],
    "samantaābhaśiri": ['bhs'],
    "samantaśitibāhu": ['mw'],
    "samantaśitirandhra": ['mw'],
    "samantaśrīkusumatejābha": ['bhs'],
    "samantaśrīsamudrarāja": ['bhs'],
    "samantaśrīsaṃbhava": ['bhs'],
    "samantaśrītejas": ['bhs'],
    "samantaśrīvairocanaketu": ['bhs'],
    "samantena": ['mw'],
    "samanteryāpatha": ['bhs'],
    "samantikam": ['cae', 'mw'],
    "samantra": ['cae', 'mw'],
    "samantraka": ['cae', 'ddsa', 'mw'],
    "samantrika": ['mw'],
    "samantrin": ['mw'],
    "samantritva": ['mw'],
    "samantā": ['cped', 'mw'],
    "samantābhaśrī": ['bhs'],
    "samantāloka": ['bhs', 'mw'],
    "samantānuracitaśāntanirghoṣa": ['bhs'],
    "samantāt": ['mw'],
    "samantāvabhāsa": ['bhs'],
    "samantāvabhāsadharmaśrīghoṣa": ['bhs'],
    "samantāvabhāsadhvaja": ['bhs'],
    "samantāvabhāsaketu": ['bhs'],
    "samantāvabhāsavyūhaśrī": ['bhs'],
    "samantāvabhāsaśrī": ['bhs'],
    "samantāvabhāsaśrīgarbharāja": ['bhs'],
    "samantāvabhāsodgata": ['bhs'],
    "samantāvaloka": ['bhs'],
    "samantāvalokabuddhi": ['bhs'],
    "samantāvalokita": ['bhs', 'mw'],
    "samanubadhnāti": ['bhs'],
    "samanubandha": ['bhs', 'mw'],
    "samanubhāsanā": ['cped'],
    "samanubhāsati": ['cped'],
    "samanubhāsi": ['cped'],
    "samanubhū": ['mw'],
    "samanubudhyate": ['bhs'],
    "samanucint": ['mw'],
    "samanuddeśakatva": ['bhs'],
    "samanudhyai": ['mw'],
    "samanudhāv": ['mw'],
    "samanudiś": ['mw'],
    "samanudru": ['mw'],
    "samanudṛś": ['mw'],
    "samanugai": ['mw'],
    "samanugam": ['mw'],
    "samanugata": ['mw'],
    "samanugrah": ['mw'],
    "samanugrāhaka": ['bhs'],
    "samanugrāhya": ['mw'],
    "samanugā": ['mw'],
    "samanugāhati": ['cped'],
    "samanugāhi": ['cped'],
    "samanugāhitvā": ['cped'],
    "samanugāhyate": ['bhs'],
    "samanuja": ['mw'],
    "samanujan": ['mw'],
    "samanujñaka": ['bhs'],
    "samanujñā": ['ap90', 'bhs', 'mw'],
    "samanujñāna": ['mw'],
    "samanujñānaṃ": ['ap90'],
    "samanujñāta": ['ddsa', 'mw'],
    "samanukamp": ['mw'],
    "samanukram": ['mw'],
    "samanukīrtana": ['mw'],
    "samanukḷp": ['mw'],
    "samanuman": ['mw'],
    "samanumata": ['mw'],
    "samanumodana": ['bhs'],
    "samanunayati": ['bhs'],
    "samanuniśam": ['mw'],
    "samanupad": ['mw'],
    "samanupassamāna": ['cped'],
    "samanupassati": ['cped'],
    "samanupassi": ['cped'],
    "samanupassitvā": ['cped'],
    "samanupaś": ['mw'],
    "samanupaśyanatā": ['bhs'],
    "samanuprach": ['mw'],
    "samanupraveśana": ['bhs'],
    "samanuprāp": ['mw'],
    "samanuprāpaṇa": ['bhs'],
    "samanuprāpta": ['mw'],
    "samanupāl": ['mw'],
    "samanurakṣati": ['bhs'],
    "samanusarati": ['bhs'],
    "samanusmarati": ['bhs'],
    "samanusmṛ": ['mw'],
    "samanussaranta": ['cped'],
    "samanussarati": ['cped'],
    "samanussari": ['cped'],
    "samanussaritvā": ['cped'],
    "samanusvṛ": ['mw'],
    "samanusṛp": ['mw'],
    "samanutap": ['mw'],
    "samanuvartin": ['mw'],
    "samanuvarṇita": ['mw'],
    "samanuvas": ['mw'],
    "samanuvicarati": ['bhs'],
    "samanuvid": ['mw'],
    "samanuviṣṭavān": ['bhs'],
    "samanuvraj": ['mw'],
    "samanuvrata": ['cae', 'mw'],
    "samanuvīkṣ": ['mw'],
    "samanuvṛt": ['mw'],
    "samanuyojya": ['mw'],
    "samanuyuj": ['mw'],
    "samanuyujyate": ['bhs'],
    "samanuyuñjati": ['cped'],
    "samanuyuñji": ['cped'],
    "samanuyuñjitvā": ['cped'],
    "samanuyā": ['mw'],
    "samanuyāta": ['mw'],
    "samanuñña": ['cped'],
    "samanuññā": ['cped'],
    "samanuññāta": ['cped'],
    "samanuśiṣṭa": ['mw'],
    "samanuśuc": ['mw'],
    "samanuśās": ['mw'],
    "samanuśāsana": ['bhs'],
    "samanuṣya": ['ddsa', 'mw'],
    "samanuṣyarājanya": ['mw'],
    "samanuṣṭheya": ['mw'],
    "samanuṣṭhita": ['mw'],
    "samanvagībhūta": ['bhs'],
    "samanvaya": ['cae', 'ddsa', 'mw'],
    "samanvayapradīpa": ['mw'],
    "samanvayapradīpasaṃketa": ['mw'],
    "samanvayasūtravivṛti": ['mw'],
    "samanvayaḥ": ['ap90'],
    "samanvayāt": ['mw'],
    "samanvaṅgībhūta": ['mw'],
    "samanveṣaṇa": ['mw'],
    "samanveṣaṇā": ['bhs'],
    "samanvi": ['ap90', 'mw'],
    "samanvita": ['ap90', 'cae', 'mw'],
    "samanviṣ": ['mw'],
    "samanvāgama": ['bhs'],
    "samanvāgata": ['bhs', 'mw'],
    "samanvāhara": ['bhs'],
    "samanvāharati": ['bhs'],
    "samanvāharaṇa": ['bhs'],
    "samanvāhāra": ['bhs'],
    "samanvārabdha": ['mw'],
    "samanvārabh": ['mw'],
    "samanvārambha": ['mw'],
    "samanvārambhaṇa": ['mw'],
    "samanvāruh": ['mw'],
    "samanvāsayati": ['bhs'],
    "samanvī": ['bhs'],
    "samanvīkṣ": ['mw'],
    "samanya": ['cae', 'gra', 'mw'],
    "samanyu": ['ap90', 'cae', 'gra', 'mw'],
    "samanyā": ['bhs'],
    "samanā": ['cae', 'ddsa', 'gra', 'mw'],
    "samanīka": ['cae', 'ddsa', 'gra', 'mw'],
    "samanīkamūrdhan": ['mw'],
    "samanīkatas": ['mw'],
    "samapacchid": ['mw'],
    "samapada": ['mw'],
    "samapadhyai": ['mw'],
    "samapadāti": ['mw'],
    "samapaiti": ['bhs'],
    "samapakṣa": ['bhs'],
    "samapakṣapāta": ['ddsa', 'mw'],
    "samapavṛj": ['mw'],
    "samapavṛt": ['mw'],
    "samapaṭavāsa": ['mw'],
    "samapekkhati": ['cped'],
    "samapekkhi": ['cped'],
    "samapidhā": ['mw'],
    "samapiruh": ['mw'],
    "samapoh": ['mw'],
    "samappesi": ['cped'],
    "samappeti": ['cped'],
    "samappetvā": ['cped'],
    "samappita": ['cped'],
    "samappiya": ['cped'],
    "samaprabha": ['mw'],
    "samaprepsu": ['mw'],
    "samaprādhānyasaṃkara": ['mw'],
    "samapāda": ['mw'],
    "samapāvṛ": ['mw'],
    "samara": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "samarabala": ['mw'],
    "samarabha": ['mw'],
    "samarabhaṭa": ['mw'],
    "samarabhū": ['mw'],
    "samarabhūmi": ['mw'],
    "samarajambuka": ['mw'],
    "samarajit": ['mw'],
    "samarajju": ['mw'],
    "samarakarman": ['cae', 'mw'],
    "samarakāmadīpikā": ['mw'],
    "samarakātara": ['mw'],
    "samarakṣibhū": ['cae'],
    "samarakṣibhūmi": ['cae'],
    "samarakṣiti": ['cae', 'mw'],
    "samaramanoharī": ['mw'],
    "samaramardana": ['mw'],
    "samaramūrdhan": ['cae', 'mw'],
    "samarapuṃgava": ['mw'],
    "samarasa": ['mw'],
    "samarasatva": ['mw'],
    "samarasiṃha": ['mw'],
    "samarasvāmin": ['mw'],
    "samarasāra": ['mw'],
    "samarasārasaṃgraha": ['mw'],
    "samarasīkaraṇa": ['mw'],
    "samarasīman": ['cae', 'mw'],
    "samarata": ['mw'],
    "samaratha": ['mw'],
    "samaratuṅga": ['ddsa', 'mw'],
    "samaravarman": ['mw'],
    "samaravasudhā": ['mw'],
    "samaravijaya": ['mw'],
    "samaravijayin": ['mw'],
    "samaravyasanin": ['mw'],
    "samaravīra": ['mw'],
    "samarañjita": ['mw'],
    "samaraśiras": ['mw'],
    "samaraśūra": ['mw'],
    "samaraḥ": ['ap90'],
    "samaraṃhas": ['mw'],
    "samaraṃjaya": ['mw'],
    "samaraṇa": ['ddsa', 'gra', 'mw'],
    "samarc": ['mw'],
    "samarca": ['cae', 'mw'],
    "samarcaka": ['mw'],
    "samarcana": ['cae', 'mw'],
    "samarcanaṃ": ['ap90'],
    "samarcita": ['mw'],
    "samarcitaka": ['bhs'],
    "samarcā": ['mw'],
    "samard": ['mw'],
    "samardhaka": ['ap90', 'mw'],
    "samardhana": ['cae', 'mw'],
    "samardhayitṛ": ['mw'],
    "samardhuka": ['cae', 'mw'],
    "samardhukā": ['mw'],
    "samarekha": ['cae', 'ddsa', 'mw'],
    "samargha": ['cae', 'mw'],
    "samarh": ['mw'],
    "samarhaṇa": ['mw'],
    "samaria": ['gra'],
    "samarjana": ['bhs'],
    "samarjitaka": ['bhs'],
    "samarocita": ['mw'],
    "samaroddeśa": ['mw'],
    "samarodyata": ['mw'],
    "samaropāya": ['cae', 'mw'],
    "samarotsava": ['ddsa', 'mw'],
    "samarpaka": ['mw'],
    "samarpakatā": ['mw'],
    "samarpayitavya": ['cae', 'mw'],
    "samarpayitṛ": ['mw'],
    "samarpaṇa": ['cae', 'mw'],
    "samarpaṇaṃ": ['ap90'],
    "samarpaṇīya": ['cae', 'mw'],
    "samarpita": ['ap90', 'bhs', 'mw'],
    "samarpitavat": ['mw'],
    "samarpitṛ": ['cae'],
    "samarpya": ['cae', 'mw'],
    "samarth": ['ap90', 'mw'],
    "samartha": ['ap90', 'cae', 'ddsa', 'mw'],
    "samarthaka": ['mw'],
    "samarthakaṃ": ['ap90'],
    "samarthana": ['cae', 'ddsa', 'mw'],
    "samarthanaṃ": ['ap90'],
    "samarthanā": ['mw'],
    "samarthanīya": ['cae', 'mw'],
    "samarthapadavidhi": ['mw'],
    "samarthatara": ['mw'],
    "samarthatva": ['mw'],
    "samarthatā": ['ap90', 'cae', 'mw'],
    "samarthay": ['cae'],
    "samarthayukta": ['mw'],
    "samarthita": ['ap90', 'mw'],
    "samarthitavat": ['mw'],
    "samarthya": ['cae', 'mw'],
    "samarti": ['mw'],
    "samaruci": ['bhs'],
    "samarudgaṇa": ['ddsa'],
    "samary": ['cae', 'gra'],
    "samarya": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "samaryajit": ['cae', 'gra', 'mw'],
    "samaryarājia": ['gra'],
    "samaryarājya": ['gra', 'mw'],
    "samaryāda": ['ap90', 'cae', 'mw'],
    "samaryādam": ['mw'],
    "samarāgama": ['mw'],
    "samarāgra": ['cae', 'mw'],
    "samarājira": ['mw'],
    "samarākhya": ['mw'],
    "samarātithi": ['mw'],
    "samarāṅgana": ['cae', 'mw'],
    "samarāṅgaṇa": ['cae', 'mw'],
    "samarūpa": ['mw'],
    "samarūpya": ['mw'],
    "samarṇa": ['ap90'],
    "samarṇṇa": ['mw'],
    "samas": ['ap90', 'mw'],
    "samasama": ['bhs'],
    "samasamayavartin": ['mw'],
    "samasamayavartitā": ['mw'],
    "samasamībhūta": ['bhs'],
    "samasana": ['mw'],
    "samasanaṃ": ['ap90'],
    "samasanād": ['mw'],
    "samasarvaguṇa": ['cae', 'mw'],
    "samasaurabha": ['mw'],
    "samasaṃdhi": ['mw'],
    "samasaṃdhita": ['mw'],
    "samasaṃdhitas": ['mw'],
    "samasaṃkhyāta": ['mw'],
    "samasaṃsthita": ['cae', 'ddsa', 'mw'],
    "samasaṃsthāna": ['mw'],
    "samasiddhānta": ['mw'],
    "samasparśa": ['mw'],
    "samassāsa": ['cped'],
    "samassāsesi": ['cped'],
    "samassāseti": ['cped'],
    "samassāsetvā": ['cped'],
    "samasta": ['ap90', 'cae', 'ddsa', 'mw'],
    "samastabala": ['mw'],
    "samastadevatāpūjāvidhi": ['mw'],
    "samastadhātṛ": ['cae', 'mw'],
    "samastakālanirṇayādhikāra": ['mw'],
    "samastaloka": ['mw'],
    "samastamantradevatāprakāśikā": ['mw'],
    "samastasākṣi": ['mw'],
    "samastavastuviṣaya": ['mw'],
    "samastaviṣayika": ['mw'],
    "samastavyastarūpaka": ['cae', 'mw'],
    "samastha": ['cae', 'ddsa', 'mw'],
    "samasthala": ['mw'],
    "samasthalī": ['mw'],
    "samasthalīkṛ": ['mw'],
    "samasthalīkṛta": ['mw'],
    "samasthāna": ['mw'],
    "samastāgniprayoga": ['mw'],
    "samasupti": ['mw'],
    "samasvara": ['mw'],
    "samasya": ['mw'],
    "samasyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "samasyāpūraṇavidhi": ['mw'],
    "samasyārthā": ['mw'],
    "samasyārṇava": ['mw'],
    "samasyāsaṃgraha": ['mw'],
    "samasūpika": ['bhs'],
    "samasūtraga": ['mw'],
    "samasūtrastha": ['mw'],
    "samat": ['mw'],
    "samataṭa": ['mw'],
    "samatha": ['bhs', 'cped', 'mw'],
    "samathabhāvanā": ['cped'],
    "samati": ['bhs'],
    "samatibhindati": ['bhs'],
    "samatikkama": ['cped'],
    "samatikkamana": ['cped'],
    "samatikkamati": ['cped'],
    "samatikkami": ['cped'],
    "samatikkamitvā": ['cped'],
    "samatikkanta": ['cped'],
    "samatikram": ['ap90', 'mw'],
    "samatikrama": ['bhs', 'cae', 'ddsa', 'mw'],
    "samatikramaḥ": ['ap90'],
    "samatikramaṇa": ['bhs'],
    "samatikrāma": ['bhs'],
    "samatikrāmayitar": ['bhs'],
    "samatikrāmaṇa": ['bhs'],
    "samatikrānta": ['mw'],
    "samatipraśaṃs": ['mw'],
    "samatirikta": ['mw'],
    "samatisruta": ['mw'],
    "samatisṛṣṭa": ['mw'],
    "samatittika": ['cped'],
    "samativah": ['mw'],
    "samativatta": ['cped'],
    "samativattati": ['cped'],
    "samativatti": ['cped'],
    "samativattita": ['cped'],
    "samativijjhati": ['cped'],
    "samativṛt": ['mw'],
    "samatiyā": ['mw'],
    "samatraya": ['mw'],
    "samatribhuja": ['mw'],
    "samatryaṃśa": ['mw'],
    "samatryaṃśā": ['mw'],
    "samatsara": ['cae', 'ddsa', 'mw'],
    "samatta": ['cped'],
    "samattha": ['cped'],
    "samatthatā": ['cped'],
    "samatulita": ['mw'],
    "samatulā": ['cae', 'ddsa', 'mw'],
    "samatva": ['mw'],
    "samatviṣ": ['mw'],
    "samatā": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "samatājñāna": ['bhs', 'mw'],
    "samatārthasaṃbhavā": ['bhs'],
    "samatī": ['ap90', 'mw'],
    "samatīrthaka": ['mw'],
    "samatīrthika": ['bhs'],
    "samatīta": ['ap90', 'mw'],
    "samatṛṇamaṇiloṣṭakāñcana": ['mw'],
    "samaujas": ['mw'],
    "samauliratna": ['mw'],
    "samav": ['mw'],
    "samavabodhana": ['mw'],
    "samavabudh": ['mw'],
    "samavacchad": ['mw'],
    "samavacchanna": ['mw'],
    "samavadhā": ['mw'],
    "samavadhāna": ['mw'],
    "samavadhānaṃ": ['ap90'],
    "samavadhāya": ['bhs'],
    "samavadhīraya": ['mw'],
    "samavadiś": ['mw'],
    "samavado": ['mw'],
    "samavadru": ['mw'],
    "samavadā": ['mw'],
    "samavagam": ['mw'],
    "samavaguh": ['mw'],
    "samavaguṇṭhita": ['mw'],
    "samavagāḍha": ['bhs'],
    "samavahanti": ['bhs'],
    "samavaharati": ['bhs'],
    "samavahita": ['mw'],
    "samavahā": ['mw'],
    "samavahāra": ['cae', 'mw'],
    "samavahāsya": ['cae', 'mw'],
    "samavahṛ": ['mw'],
    "samavakāra": ['mw'],
    "samavakāraḥ": ['ap90'],
    "samavakṝ": ['mw'],
    "samavakṣip": ['mw'],
    "samavalamb": ['mw'],
    "samavalok": ['mw'],
    "samavalī": ['mw'],
    "samavamṛś": ['mw'],
    "samavana": ['mw'],
    "samavanamati": ['bhs'],
    "samavanata": ['mw'],
    "samavanī": ['mw'],
    "samavapluta": ['mw'],
    "samavapīḍ": ['mw'],
    "samavartin": ['cae', 'mw'],
    "samavaruddha": ['mw'],
    "samavarudh": ['mw'],
    "samavarṇa": ['cae', 'ddsa', 'mw'],
    "samavarṣaṇa": ['mw'],
    "samavasanna": ['mw'],
    "samavasarati": ['bhs'],
    "samavasaraṇa": ['bhs', 'mw'],
    "samavasarga": ['bhs', 'mw'],
    "samavasargya": ['mw'],
    "samavaskand": ['mw'],
    "samavaskanda": ['mw'],
    "samavaso": ['mw'],
    "samavasrava": ['cae', 'mw'],
    "samavasru": ['mw'],
    "samavasrāviṇī": ['mw'],
    "samavasthita": ['ap90', 'cae', 'mw'],
    "samavasthā": ['ap90', 'cae', 'mw'],
    "samavasthāna": ['mw'],
    "samavasthāpita": ['mw'],
    "samavasṛ": ['mw'],
    "samavasṛj": ['mw'],
    "samavasṛjya": ['ddsa', 'mw'],
    "samavasṛta": ['mw'],
    "samavasṛti": ['mw'],
    "samavatarati": ['bhs'],
    "samavatta": ['cae', 'mw'],
    "samavattadhāna": ['cae', 'mw'],
    "samavattadhānī": ['mw'],
    "samavatāra": ['cae', 'ddsa', 'mw'],
    "samavatāraḥ": ['ap90'],
    "samavatṝ": ['mw'],
    "samavavṛt": ['mw'],
    "samavavṛtta": ['mw'],
    "samavayaska": ['mw'],
    "samavaśeṣita": ['mw'],
    "samavaśyāna": ['mw'],
    "samavaṣṭambh": ['mw'],
    "samave": ['ap90', 'mw'],
    "samavedha": ['mw'],
    "samavegavaśa": ['mw'],
    "samavekkhati": ['cped'],
    "samavekkhi": ['cped'],
    "samavekṣ": ['mw'],
    "samavekṣaṇa": ['cae'],
    "samavekṣita": ['mw'],
    "samavepākinī": ['cped'],
    "samaveta": ['ap90', 'cae', 'mw'],
    "samavetatva": ['ddsa', 'mw'],
    "samavetārtha": ['mw'],
    "samaveṣa": ['cae', 'mw'],
    "samavibhakta": ['mw'],
    "samavibhaktāṅga": ['mw'],
    "samavibhāga": ['mw'],
    "samaviṣama": ['cae', 'ddsa', 'mw'],
    "samaviṣamakara": ['mw'],
    "samavyatha": ['mw'],
    "samavyāptika": ['mw'],
    "samavākāra": ['mw'],
    "samavāp": ['mw'],
    "samavāpta": ['mw'],
    "samavāptakāma": ['ddsa', 'mw'],
    "samavāpti": ['mw'],
    "samavāptiḥ": ['ap90'],
    "samavārj": ['mw'],
    "samavāya": ['cae', 'cped', 'mw'],
    "samavāyakhaṇḍana": ['mw'],
    "samavāyana": ['mw'],
    "samavāyapramāṇavādārtha": ['mw'],
    "samavāyasambandha": ['mw'],
    "samavāyatas": ['mw'],
    "samavāyatva": ['mw'],
    "samavāyavāda": ['mw'],
    "samavāyaḥ": ['ap90'],
    "samavāyi": ['mw'],
    "samavāyika": ['mw'],
    "samavāyikāraṇa": ['mw'],
    "samavāyikāraṇatva": ['mw'],
    "samavāyin": ['ap90', 'mw'],
    "samavāyitva": ['mw'],
    "samavāyīkṛta": ['mw'],
    "samavīrya": ['mw'],
    "samavṛtta": ['cae', 'mw'],
    "samavṛttakarṇa": ['mw'],
    "samavṛttaśaṅku": ['mw'],
    "samavṛtti": ['cae', 'mw'],
    "samavṛttisāra": ['mw'],
    "samaya": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "samayabandhana": ['mw'],
    "samayabheda": ['mw'],
    "samayabhedin": ['cae', 'mw'],
    "samayabhedoparacanacakra": ['mw'],
    "samayacyuti": ['mw'],
    "samayadharma": ['mw'],
    "samayajña": ['mw'],
    "samayakalpataru": ['mw'],
    "samayakamalākara": ['mw'],
    "samayakriyā": ['cae', 'ddsa', 'mw'],
    "samayakāma": ['mw'],
    "samayakāra": ['mw'],
    "samayamayūkha": ['mw'],
    "samayamātṛkā": ['mw'],
    "samayanaya": ['mw'],
    "samayanirṇaya": ['mw'],
    "samayapada": ['mw'],
    "samayaparirakṣaṇa": ['mw'],
    "samayapradīpa": ['mw'],
    "samayaprakāśa": ['mw'],
    "samayapūrvam": ['cae'],
    "samayarahasya": ['mw'],
    "samayaratna": ['mw'],
    "samayasetuvārita": ['mw'],
    "samayasundaragaṇi": ['mw'],
    "samayasāra": ['mw'],
    "samayasūkta": ['mw'],
    "samayati": ['bhs'],
    "samayavajra": ['mw'],
    "samayavelā": ['mw'],
    "samayavidhāna": ['mw'],
    "samayavidyā": ['cae', 'mw'],
    "samayavimukta": ['bhs'],
    "samayaviparīta": ['mw'],
    "samayavyabhicāra": ['mw'],
    "samayavyabhicārin": ['cae', 'mw'],
    "samayaḥ": ['ap90'],
    "samaye": ['mw'],
    "samayin": ['bhs'],
    "samayitavya": ['mw'],
    "samayocita": ['cae', 'mw'],
    "samayocitam": ['mw'],
    "samayocitaśloka": ['mw'],
    "samayoddyota": ['mw'],
    "samayoga": ['mw'],
    "samayollaṅghitatva": ['mw'],
    "samayuga": ['mw'],
    "samayā": ['ap90', 'cae', 'ddsa', 'mw'],
    "samayācāra": ['cae', 'ddsa', 'mw'],
    "samayācāranirūpaṇa": ['mw'],
    "samayācāratantra": ['mw'],
    "samayādhvam": ['cae'],
    "samayādhyuṣita": ['cae', 'mw'],
    "samayākṛ": ['mw'],
    "samayāloka": ['mw'],
    "samayānandasaṃtoṣa": ['mw'],
    "samayānusāreṇa": ['mw'],
    "samayānuvartin": ['mw'],
    "samayārṇamātṛkā": ['mw'],
    "samayātantra": ['mw'],
    "samayāviṣita": ['cae'],
    "samayāṣṭanirūpaṇa": ['mw'],
    "samayīkṛ": ['mw'],
    "samañc": ['mw'],
    "samañcana": ['cae', 'mw'],
    "samañj": ['mw'],
    "samañjana": ['cae', 'mw'],
    "samañjanavat": ['mw'],
    "samañjanīya": ['mw'],
    "samañjasa": ['cae', 'mw'],
    "samañjasam": ['mw'],
    "samañjasā": ['mw'],
    "samañjasārthadīpikā": ['mw'],
    "samaññā": ['cped'],
    "samaññāta": ['cped'],
    "samaś": ['ap90', 'mw'],
    "samaśana": ['mw'],
    "samaśanīya": ['mw'],
    "samaśarkara": ['mw'],
    "samaśarīra": ['bhs'],
    "samaśarīraśri": ['bhs'],
    "samaśas": ['cae', 'mw'],
    "samaśaśin": ['mw'],
    "samaśaṅku": ['mw'],
    "samaśnuva": ['cae', 'ddsa', 'mw'],
    "samaśodhana": ['mw'],
    "samaśreṇi": ['ddsa', 'mw'],
    "samaśreṇigata": ['mw'],
    "samaśruti": ['mw'],
    "samaśīla": ['cae', 'mw'],
    "samaśīlin": ['cae', 'mw'],
    "samaśīrṣikā": ['ddsa', 'mw'],
    "samaṁ": ['cped'],
    "samaṃgā": ['ap90'],
    "samaṃjasa": ['ap90'],
    "samaṃta": ['ap90'],
    "samaṅga": ['cae', 'mw'],
    "samaṅgala": ['ddsa', 'mw'],
    "samaṅgin": ['bhs', 'cae', 'mw'],
    "samaṅginī": ['bhs', 'mw'],
    "samaṅgira": ['bhs'],
    "samaṅgitā": ['bhs', 'cped'],
    "samaṅgā": ['mw'],
    "samaṅgī": ['cped'],
    "samaṅgībhūta": ['bhs', 'cped'],
    "samaṅka": ['cae', 'mw'],
    "samaṇa": ['cped'],
    "samaṇadhamma": ['cped'],
    "samaṇakuttika": ['cped'],
    "samaṇasaṅgha": ['cped'],
    "samaṇasāruppa": ['cped'],
    "samaṇuddesa": ['cped'],
    "samaṇī": ['cped'],
    "samaṇṭha": ['mw'],
    "samaṣṭhila": ['mw'],
    "samaṣṭhilā": ['mw'],
    "samaṣṭi": ['cae', 'ddsa', 'mw'],
    "samaṣṭitā": ['mw'],
    "samaṣṭiḥ": ['ap90'],
    "samaṣṭyabhiprāya": ['mw'],
    "samb": ['mw'],
    "sambaddha": ['cped', 'mw'],
    "sambaddhadarpa": ['mw'],
    "sambaddham": ['ddsa', 'mw'],
    "sambaddhasainyaugha": ['mw'],
    "sambaddhānta": ['mw'],
    "sambadhyamāna": ['mw'],
    "sambadhyamānaka": ['mw'],
    "sambahula": ['cped', 'mw'],
    "sambala": ['bhs', 'cae', 'cped', 'mw'],
    "sambalana": ['mw'],
    "sambandh": ['mw'],
    "sambandha": ['cped', 'mw'],
    "sambandhagaṇapati": ['mw'],
    "sambandhaka": ['mw'],
    "sambandhanirṇaya": ['mw'],
    "sambandhapañcāśikā": ['mw'],
    "sambandharahasya": ['mw'],
    "sambandhatattva": ['mw'],
    "sambandhati": ['cped'],
    "sambandhavarjita": ['mw'],
    "sambandhaviveka": ['mw'],
    "sambandhavyavasthāvikāśa": ['mw'],
    "sambandhavārttika": ['mw'],
    "sambandhayitṛ": ['mw'],
    "sambandhi": ['cped', 'mw'],
    "sambandhibhinna": ['mw'],
    "sambandhikatva": ['mw'],
    "sambandhin": ['mw'],
    "sambandhitva": ['mw'],
    "sambandhitvā": ['cped'],
    "sambandhitā": ['mw'],
    "sambandhiśabda": ['mw'],
    "sambandhoddyota": ['mw'],
    "sambandhopadeśa": ['mw'],
    "sambandhu": ['mw'],
    "sambara": ['bhs', 'mw'],
    "sambaratantra": ['bhs'],
    "sambarya": ['mw'],
    "sambat": ['mw'],
    "sambaṃh": ['mw'],
    "sambhagga": ['cped'],
    "sambhagna": ['mw'],
    "sambhaj": ['mw'],
    "sambhaja": ['mw'],
    "sambhajana": ['mw'],
    "sambhajanīya": ['mw'],
    "sambhakta": ['mw'],
    "sambhakti": ['ddsa', 'mw'],
    "sambhaktṛ": ['mw'],
    "sambhakṣ": ['mw'],
    "sambhakṣa": ['mw'],
    "sambhal": ['mw'],
    "sambhala": ['mw'],
    "sambhalī": ['mw'],
    "sambhalīya": ['mw'],
    "sambhama": ['cped'],
    "sambhamati": ['cped'],
    "sambhami": ['cped'],
    "sambhamitvā": ['cped'],
    "sambhandhana": ['cped'],
    "sambhara": ['gra', 'mw'],
    "sambharaṇa": ['gra', 'mw'],
    "sambharaṇī": ['mw'],
    "sambharaṇīya": ['mw'],
    "sambharodbhava": ['mw'],
    "sambhartsita": ['mw'],
    "sambharāja": ['bhs'],
    "sambhata": ['cped'],
    "sambhatta": ['cped'],
    "sambhava": ['cped', 'ddsa', 'mw'],
    "sambhavakāṇḍa": ['mw'],
    "sambhavana": ['cped', 'mw'],
    "sambhavaparvan": ['mw'],
    "sambhavati": ['cped'],
    "sambhavesī": ['cped'],
    "sambhavi": ['cped'],
    "sambhavin": ['mw'],
    "sambhaviṣṇu": ['mw'],
    "sambhavya": ['mw'],
    "sambhañj": ['mw'],
    "sambhañjati": ['cped'],
    "sambhañji": ['cped'],
    "sambhañjitvā": ['cped'],
    "sambheda": ['cped', 'mw'],
    "sambhedana": ['mw'],
    "sambhedavat": ['mw'],
    "sambhedya": ['mw'],
    "sambhid": ['mw'],
    "sambhindati": ['cped'],
    "sambhinna": ['cped', 'mw'],
    "sambhinnabuddhi": ['mw'],
    "sambhinnamaryāda": ['mw'],
    "sambhinnapralāpa": ['mw'],
    "sambhinnapralāpika": ['mw'],
    "sambhinnasarvāṅga": ['mw'],
    "sambhinnatā": ['mw'],
    "sambhinnavyañjanā": ['mw'],
    "sambhinnavṛtta": ['mw'],
    "sambhodhi": ['cped'],
    "sambhoga": ['cped', 'mw'],
    "sambhogakāya": ['mw'],
    "sambhogakṣama": ['mw'],
    "sambhogavat": ['mw'],
    "sambhogaveśman": ['mw'],
    "sambhogayakṣiṇī": ['mw'],
    "sambhogin": ['mw'],
    "sambhogya": ['mw'],
    "sambhogyatā": ['mw'],
    "sambhoja": ['mw'],
    "sambhojaka": ['mw'],
    "sambhojana": ['mw'],
    "sambhojanī": ['mw'],
    "sambhojanīya": ['mw'],
    "sambhojya": ['mw'],
    "sambhoktṛ": ['mw'],
    "sambhoti": ['cped'],
    "sambhram": ['mw'],
    "sambhrama": ['mw'],
    "sambhramabhṛt": ['mw'],
    "sambhramajvalita": ['mw'],
    "sambhraś": ['mw'],
    "sambhraṃś": ['mw'],
    "sambhrāj": ['mw'],
    "sambhrānta": ['mw'],
    "sambhrāntajana": ['mw'],
    "sambhrāntamanas": ['mw'],
    "sambhrānti": ['mw'],
    "sambhu": ['mw'],
    "sambhugna": ['mw'],
    "sambhuj": ['mw'],
    "sambhukta": ['mw'],
    "sambhuñjati": ['cped'],
    "sambhuñji": ['cped'],
    "sambhuñjitvā": ['cped'],
    "sambhā": ['mw'],
    "sambhāra": ['cped', 'mw'],
    "sambhāratva": ['mw'],
    "sambhārayajus": ['mw'],
    "sambhāraśīla": ['mw'],
    "sambhārin": ['mw'],
    "sambhārya": ['mw'],
    "sambhāvana": ['mw'],
    "sambhāvanojjhita": ['mw'],
    "sambhāvanā": ['cped', 'mw'],
    "sambhāvanīya": ['cped', 'mw'],
    "sambhāvayitavya": ['mw'],
    "sambhāvayitṛ": ['mw'],
    "sambhāvesi": ['cped'],
    "sambhāveti": ['cped'],
    "sambhāvetvā": ['cped'],
    "sambhāvin": ['mw'],
    "sambhāvita": ['cped', 'mw'],
    "sambhāvitatama": ['mw'],
    "sambhāvitatara": ['mw'],
    "sambhāvitavya": ['mw'],
    "sambhāvitātman": ['mw'],
    "sambhāvya": ['mw'],
    "sambhāṇḍaya": ['mw'],
    "sambhāṣ": ['mw'],
    "sambhāṣa": ['mw'],
    "sambhāṣaṇa": ['mw'],
    "sambhāṣaṇanipuṇa": ['mw'],
    "sambhāṣaṇīya": ['mw'],
    "sambhāṣin": ['mw'],
    "sambhāṣita": ['mw'],
    "sambhāṣya": ['mw'],
    "sambhāṣā": ['mw'],
    "sambhīta": ['cped', 'mw'],
    "sambhū": ['mw'],
    "sambhūta": ['cped', 'mw'],
    "sambhūtabhūrigajavājipadātisainya": ['mw'],
    "sambhūtasaṃtrāsa": ['mw'],
    "sambhūtatva": ['mw'],
    "sambhūtavijaya": ['mw'],
    "sambhūti": ['mw'],
    "sambhūtivijaya": ['mw'],
    "sambhūya": ['mw'],
    "sambhūyagamana": ['mw'],
    "sambhūyakārin": ['mw'],
    "sambhūyas": ['mw'],
    "sambhūyasya": ['mw'],
    "sambhūyayāna": ['mw'],
    "sambhūṣ": ['mw'],
    "sambhṛ": ['mw'],
    "sambhṛta": ['mw'],
    "sambhṛtabala": ['mw'],
    "sambhṛtakratu": ['gra', 'mw'],
    "sambhṛtasambhāra": ['mw'],
    "sambhṛtasneha": ['mw'],
    "sambhṛtatama": ['mw'],
    "sambhṛtauṣadha": ['mw'],
    "sambhṛtaśruta": ['mw'],
    "sambhṛtaśrī": ['mw'],
    "sambhṛti": ['mw'],
    "sambhṛtvan": ['mw'],
    "sambhṛtya": ['mw'],
    "sambhṛtārtha": ['mw'],
    "sambhṛtāśua": ['gra'],
    "sambhṛtāśva": ['gra', 'mw'],
    "sambhṛtāṅga": ['mw'],
    "sambhṛṣṭa": ['mw'],
    "sambodha": ['mw'],
    "sambodhana": ['cped', 'mw'],
    "sambodhayitṛ": ['mw'],
    "sambodhesi": ['cped'],
    "sambodheti": ['cped'],
    "sambodhi": ['mw'],
    "sambodhita": ['mw'],
    "sambodhya": ['mw'],
    "sambodhyaṅga": ['mw'],
    "sambojjhaṅga": ['cped'],
    "sambrū": ['mw'],
    "sambubodhayiṣu": ['mw'],
    "sambuddha": ['cped', 'mw'],
    "sambuddhi": ['mw'],
    "sambudh": ['mw'],
    "sambudhyamāna": ['mw'],
    "sambujjhati": ['cped'],
    "sambujjhi": ['cped'],
    "sambujjhitvā": ['cped'],
    "sambuka": ['cped'],
    "sambādh": ['mw'],
    "sambādha": ['cped', 'gra', 'mw'],
    "sambādhaka": ['mw'],
    "sambādhana": ['cped', 'mw'],
    "sambādhanā": ['mw'],
    "sambādhatandrī": ['mw'],
    "sambādhavartin": ['mw'],
    "sambādhavartman": ['mw'],
    "sambādhesi": ['cped'],
    "sambādheti": ['cped'],
    "sambādhetvā": ['cped'],
    "sambāhana": ['cped'],
    "sambāhati": ['cped'],
    "sambāhi": ['cped'],
    "sambāhitvā": ['cped'],
    "sambāl̤ha": ['mw'],
    "sambīja": ['mw'],
    "sambṛh": ['mw'],
    "sambṛṃh": ['mw'],
    "sambṛṃhaṇa": ['mw'],
    "same": ['ap90', 'mw'],
    "sameddhṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "samedh": ['ap90', 'mw'],
    "samedha": ['cae', 'ddsa', 'mw'],
    "samedhana": ['cae', 'mw'],
    "samedhita": ['ap90', 'mw'],
    "sameghalekha": ['mw'],
    "samej": ['mw'],
    "samekkhana": ['cped'],
    "samekkhati": ['cped'],
    "samekkhi": ['cped'],
    "samekkhita": ['cped'],
    "samekkhitvā": ['cped'],
    "samekkhiya": ['cped'],
    "samena": ['cped'],
    "samer": ['mw'],
    "samerita": ['cped'],
    "samesi": ['cped'],
    "sameta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sametamāya": ['mw'],
    "sameti": ['bhs', 'cped'],
    "sametvā": ['cped'],
    "sameḍī": ['mw'],
    "sami": ['ap90', 'mw'],
    "samid": ['mw'],
    "samidanta": ['mw'],
    "samiddha": ['ap90', 'cped', 'ddsa', 'mw'],
    "samiddhadarpa": ['mw'],
    "samiddhahoma": ['cae', 'mw'],
    "samiddhavat": ['mw'],
    "samiddhaśaraṇa": ['mw'],
    "samiddhi": ['cae', 'cped'],
    "samiddhoma": ['mw'],
    "samiddhāgni": ['cae', 'gra', 'mw'],
    "samiddhāra": ['cae', 'mw'],
    "samiddhārcis": ['mw'],
    "samiddhārin": ['mw'],
    "samiddhārthaka": ['mw'],
    "samiddṛṣada": ['mw'],
    "samidh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "samidha": ['mw'],
    "samidham": ['mw'],
    "samidhaḥ": ['ap90'],
    "samidhe": ['mw'],
    "samidhya": ['mw'],
    "samidhyamāna": ['mw'],
    "samidhyamānavat": ['mw'],
    "samidhā": ['bhs', 'mw'],
    "samididhmavraścana": ['ddsa', 'mw'],
    "samidvant": ['cae'],
    "samidvat": ['ap90', 'ddsa', 'mw'],
    "samidādhāna": ['cae', 'mw'],
    "samidāharaṇa": ['mw'],
    "samijjhana": ['cped'],
    "samijjhati": ['cped'],
    "samijjhi": ['cped'],
    "samijjhitvā": ['cped'],
    "samika": ['mw'],
    "samikaṃ": ['ap90'],
    "samillatā": ['cae'],
    "samin": ['mw'],
    "saminakṣ": ['mw'],
    "samindh": ['mw'],
    "samindhana": ['cae', 'mw'],
    "saminv": ['mw'],
    "samira": ['mw'],
    "samiraḥ": ['ap90'],
    "samirita": ['bhs'],
    "samit": ['ap90', 'cae', 'ddsa', 'mw'],
    "samita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "samitakāraka": ['bhs'],
    "samitam": ['bhs', 'mw'],
    "samitatta": ['cped'],
    "samitaṁ": ['cped'],
    "samitha": ['cae', 'ddsa', 'gra', 'mw'],
    "samithaḥ": ['ap90'],
    "samithuna": ['mw'],
    "samiti": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "samitimardana": ['mw'],
    "samitiśobhana": ['cae', 'mw'],
    "samitiśālin": ['mw'],
    "samitiḥ": ['ap90'],
    "samitiṃgama": ['mw'],
    "samitiṃjaya": ['ap90', 'cae', 'mw'],
    "samitkalāpa": ['mw'],
    "samitkuśa": ['mw'],
    "samitkāṣṭha": ['cae', 'mw'],
    "samitpāntha": ['mw'],
    "samitpāṇi": ['cae', 'mw'],
    "samitpūla": ['cae', 'mw'],
    "samitra": ['cae', 'mw'],
    "samitsajja": ['mw'],
    "samitsamāropaṇaprātaraupāsanaprayoga": ['mw'],
    "samitsamāropaṇavidhāna": ['mw'],
    "samittva": ['mw'],
    "samitā": ['ap90', 'mw'],
    "samitāvi": ['cped'],
    "samitāvin": ['bhs'],
    "samitāyus": ['bhs'],
    "samitṛ": ['mw'],
    "samiya": ['bhs'],
    "samiñjati": ['cped'],
    "samiñjayati": ['bhs'],
    "samiśra": ['mw'],
    "samiṃdh": ['ap90'],
    "samiṃdhanaṃ": ['ap90'],
    "samiṅg": ['mw'],
    "samiṣ": ['cae', 'gra', 'mw'],
    "samiṣaṇya": ['mw'],
    "samiṣṭa": ['mw'],
    "samiṣṭayajus": ['mw'],
    "samiṣṭi": ['cae', 'mw'],
    "samma": ['cped'],
    "sammad": ['mw'],
    "sammada": ['cped', 'mw'],
    "sammadakkhāta": ['cped'],
    "sammadamaya": ['mw'],
    "sammadavat": ['mw'],
    "sammadaññā": ['cped'],
    "sammadaññāya": ['cped'],
    "sammaddana": ['cped'],
    "sammaddasa": ['cped'],
    "sammaddati": ['cped'],
    "sammaddi": ['cped'],
    "sammaddita": ['cped'],
    "sammadditvā": ['cped'],
    "sammadeva": ['cped'],
    "sammadin": ['mw'],
    "sammaggata": ['cped'],
    "sammagna": ['mw'],
    "sammahas": ['mw'],
    "sammajjanta": ['cped'],
    "sammajjanī": ['cped'],
    "sammajjati": ['cped'],
    "sammajji": ['cped'],
    "sammajjita": ['cped'],
    "sammajjitabba": ['cped'],
    "sammajjitvā": ['cped'],
    "sammakkhesi": ['cped'],
    "sammakkheti": ['cped'],
    "sammakkhetvā": ['cped'],
    "sammakkhita": ['cped'],
    "samman": ['mw'],
    "sammanas": ['mw'],
    "sammand": ['mw'],
    "sammaniman": ['mw'],
    "sammannati": ['cped'],
    "sammanni": ['cped'],
    "sammannita": ['cped'],
    "sammannitvā": ['cped'],
    "sammantavya": ['mw'],
    "sammantesi": ['cped'],
    "sammanteti": ['cped'],
    "sammantetvā": ['cped'],
    "sammanth": ['mw'],
    "sammantita": ['cped'],
    "sammantr": ['mw'],
    "sammantraṇīya": ['mw'],
    "sammantrita": ['mw'],
    "sammapaññā": ['cped'],
    "sammappadhāna": ['cped'],
    "sammarda": ['mw'],
    "sammardana": ['mw'],
    "sammardin": ['mw'],
    "sammarśana": ['mw'],
    "sammarśin": ['mw'],
    "sammarṣa": ['mw'],
    "sammasati": ['cped'],
    "sammasi": ['cped'],
    "sammasita": ['cped'],
    "sammasitvā": ['cped'],
    "sammata": ['cped', 'ddsa', 'mw'],
    "sammath": ['mw'],
    "sammathita": ['mw'],
    "sammati": ['cped', 'mw'],
    "sammatiman": ['mw'],
    "sammatta": ['cped', 'mw'],
    "sammatā": ['mw'],
    "sammatāla": ['cped'],
    "sammatīya": ['mw'],
    "sammaya": ['mw'],
    "sammayana": ['mw'],
    "sammaṭṭha": ['cped'],
    "sammeda": ['mw'],
    "sammedamāhātmya": ['mw'],
    "sammegha": ['mw'],
    "sammelana": ['mw'],
    "sammeta": ['mw'],
    "sammi": ['mw'],
    "sammih": ['mw'],
    "sammikṣ": ['mw'],
    "sammil": ['mw'],
    "sammilita": ['mw'],
    "sammimardiṣu": ['mw'],
    "sammimikṣ": ['mw'],
    "sammimānayiṣu": ['mw'],
    "sammissa": ['cped'],
    "sammissatā": ['cped'],
    "sammissesi": ['cped'],
    "sammisseti": ['cped'],
    "sammissetvā": ['cped'],
    "sammissita": ['cped'],
    "sammita": ['mw'],
    "sammitam": ['mw'],
    "sammitatva": ['mw'],
    "sammitavarṇā": ['mw'],
    "sammiti": ['mw'],
    "sammiñjana": ['cped'],
    "sammiñjanta": ['cped'],
    "sammiñjati": ['cped'],
    "sammiñji": ['cped'],
    "sammiñjita": ['cped'],
    "sammiñjitvā": ['cped'],
    "sammiśla": ['gra', 'mw'],
    "sammiśra": ['mw'],
    "sammiśraṇa": ['mw'],
    "sammiśrita": ['mw'],
    "sammocita": ['mw'],
    "sammoda": ['mw'],
    "sammodagandha": ['mw'],
    "sammodaka": ['cped'],
    "sammodamāna": ['cped', 'mw'],
    "sammodana": ['mw'],
    "sammodanā": ['cped'],
    "sammodanīkathā": ['mw'],
    "sammodanīya": ['cped', 'mw'],
    "sammodati": ['cped'],
    "sammodi": ['cped'],
    "sammodika": ['mw'],
    "sammoditvā": ['cped'],
    "sammoha": ['cped', 'mw'],
    "sammohaka": ['mw'],
    "sammohamaulin": ['mw'],
    "sammohana": ['mw'],
    "sammohanatantra": ['mw'],
    "sammohanī": ['mw'],
    "sammohita": ['mw'],
    "sammohā": ['mw'],
    "sammokṣ": ['mw'],
    "sammosa": ['cped'],
    "sammrakṣita": ['mw'],
    "sammuc": ['mw'],
    "sammucchati": ['cped'],
    "sammucchi": ['cped'],
    "sammucchita": ['cped'],
    "sammucchitvā": ['cped'],
    "sammud": ['mw'],
    "sammudita": ['cped'],
    "sammugdha": ['mw'],
    "sammugdham": ['mw'],
    "sammuh": ['mw'],
    "sammukha": ['cped', 'ddsa', 'mw'],
    "sammukham": ['mw'],
    "sammukhavinaya": ['mw'],
    "sammukhaya": ['mw'],
    "sammukhe": ['mw'],
    "sammukhin": ['mw'],
    "sammukhā": ['cped'],
    "sammukhī": ['mw'],
    "sammukhībhū": ['mw'],
    "sammukhībhūta": ['cped'],
    "sammukhīkṛ": ['mw'],
    "sammukhīna": ['mw'],
    "sammukhīnatva": ['mw'],
    "sammurch": ['mw'],
    "sammussati": ['cped'],
    "sammussi": ['cped'],
    "sammussitvā": ['cped'],
    "sammuti": ['cped'],
    "sammuyha": ['cped'],
    "sammuyhana": ['cped'],
    "sammuyhati": ['cped'],
    "sammuyhi": ['cped'],
    "sammuyhitvā": ['cped'],
    "sammuñjanī": ['cped'],
    "sammuṣ": ['mw'],
    "sammuṭṭha": ['cped'],
    "sammyakṣ": ['mw'],
    "sammā": ['cped', 'mw'],
    "sammāda": ['mw'],
    "sammādiṭṭhi": ['cped'],
    "sammādiṭṭhika": ['cped'],
    "sammājīva": ['cped'],
    "sammākammanta": ['cped'],
    "sammāna": ['cped', 'mw'],
    "sammānakara": ['mw'],
    "sammānana": ['mw'],
    "sammānanā": ['cped'],
    "sammānanīya": ['mw'],
    "sammānin": ['mw'],
    "sammānita": ['mw'],
    "sammānitavimānita": ['mw'],
    "sammānya": ['mw'],
    "sammāpariṇāmāye": ['bhs'],
    "sammāpaṭipanna": ['cped'],
    "sammāpaṭipatti": ['cped'],
    "sammārga": ['mw'],
    "sammārjaka": ['mw'],
    "sammārjana": ['mw'],
    "sammārjita": ['mw'],
    "sammārṣṭi": ['mw'],
    "sammāsambodhi": ['cped'],
    "sammāsambuddha": ['cped'],
    "sammāsamādhi": ['cped'],
    "sammāsati": ['cped'],
    "sammāsaṅkappa": ['cped'],
    "sammātura": ['mw'],
    "sammātṛ": ['gra', 'mw'],
    "sammāvattanā": ['cped'],
    "sammāvimutti": ['cped'],
    "sammāvācā": ['cped'],
    "sammīl": ['mw'],
    "sammīlana": ['mw'],
    "sammīlita": ['mw'],
    "sammīlitadruma": ['mw'],
    "sammīlya": ['mw'],
    "sammūrch": ['mw'],
    "sammūrcha": ['mw'],
    "sammūrchaja": ['mw'],
    "sammūrchana": ['mw'],
    "sammūrchanodbhava": ['mw'],
    "sammūrchita": ['mw'],
    "sammūrchitavat": ['mw'],
    "sammūtraṇa": ['mw'],
    "sammūḍha": ['mw'],
    "sammūḍhacetas": ['mw'],
    "sammūḍhahṛdaya": ['mw'],
    "sammūḍhapiḍakā": ['mw'],
    "sammūḍhatva": ['mw'],
    "sammūḍhatā": ['mw'],
    "sammūḍhā": ['mw'],
    "sammūḷha": ['cped'],
    "sammṛd": ['mw'],
    "sammṛj": ['mw'],
    "sammṛta": ['mw'],
    "sammṛś": ['mw'],
    "sammṛṇ": ['mw'],
    "sammṛṣṭa": ['mw'],
    "samocaka": ['bhs'],
    "samodahana": ['bhs', 'cped'],
    "samodahati": ['cped'],
    "samodahi": ['cped'],
    "samodahita": ['cped'],
    "samodahitvā": ['cped'],
    "samodaka": ['mw'],
    "samodaya": ['bhs'],
    "samodhāna": ['cped'],
    "samodhānesi": ['cped'],
    "samodhāneti": ['cped'],
    "samodhānetvā": ['cped'],
    "samodita": ['bhs'],
    "samoha": ['cae', 'cped', 'gra', 'mw'],
    "samoham": ['mw'],
    "samohita": ['cped'],
    "samokas": ['cae', 'ddsa', 'gra', 'mw'],
    "samokirati": ['cped'],
    "samokiraṇa": ['cped'],
    "samokiri": ['cped'],
    "samokiritvā": ['cped'],
    "samokiṇṇa": ['cped'],
    "samonamati": ['bhs'],
    "samopamā": ['mw'],
    "samopeta": ['mw'],
    "samopta": ['mw'],
    "samosarati": ['cped'],
    "samosaraṇa": ['cped'],
    "samosari": ['cped'],
    "samosaritvā": ['cped'],
    "samosaṭa": ['cped'],
    "samota": ['mw'],
    "samotarati": ['cped'],
    "samotari": ['cped'],
    "samotaritvā": ['cped'],
    "samotata": ['cped'],
    "samotiṇṇa": ['cped'],
    "samottaratas": ['mw'],
    "sampa": ['bhs', 'mw'],
    "sampac": ['mw'],
    "sampacchanivārapūjā": ['mw'],
    "sampacchukravārapūjā": ['mw'],
    "sampad": ['mw'],
    "sampada": ['mw'],
    "sampadhūpāyati": ['cped'],
    "sampadin": ['mw'],
    "sampadosa": ['cped'],
    "sampadussana": ['cped'],
    "sampadussati": ['cped'],
    "sampadussi": ['cped'],
    "sampadussitvā": ['cped'],
    "sampaduṭṭha": ['cped'],
    "sampadvara": ['mw'],
    "sampadvasu": ['mw'],
    "sampadvinimaya": ['mw'],
    "sampadvipada": ['mw'],
    "sampadā": ['cped'],
    "sampadālana": ['cped'],
    "sampadāna": ['cped'],
    "sampadāḷesi": ['cped'],
    "sampadāḷeti": ['cped'],
    "sampadāḷetvā": ['cped'],
    "sampadāḷita": ['cped'],
    "sampahaṁsaka": ['cped'],
    "sampahaṁsakasana": ['cped'],
    "sampahaṁsana": ['cped'],
    "sampahaṁsati": ['cped'],
    "sampahaṁseti": ['cped'],
    "sampahaṁsetvā": ['cped'],
    "sampahaṁsi": ['cped'],
    "sampahaṁsita": ['cped'],
    "sampahaṭṭha": ['cped'],
    "sampahāra": ['cped'],
    "sampajañña": ['cped'],
    "sampajjalita": ['cped'],
    "sampajjana": ['cped'],
    "sampajjati": ['cped'],
    "sampajji": ['cped'],
    "sampajjimāna": ['cped'],
    "sampajjitvā": ['cped'],
    "sampajāna": ['cped'],
    "sampajānakārī": ['cped'],
    "sampakampati": ['cped'],
    "sampakampi": ['cped'],
    "sampakampita": ['cped'],
    "sampakva": ['ddsa', 'mw'],
    "sampalāy": ['mw'],
    "sampanna": ['cped', 'mw'],
    "sampannadanta": ['mw'],
    "sampannaka": ['mw'],
    "sampannakrama": ['mw'],
    "sampannakṣīrā": ['mw'],
    "sampannapānīya": ['mw'],
    "sampannarūpa": ['mw'],
    "sampannatama": ['mw'],
    "sampannatara": ['mw'],
    "sampannatā": ['mw'],
    "sampannaṃkāram": ['mw'],
    "sampara": ['mw'],
    "samparcana": ['mw'],
    "sampareta": ['cped', 'mw'],
    "samparibhraṣṭa": ['mw'],
    "samparibhū": ['mw'],
    "samparicar": ['mw'],
    "samparicintita": ['mw'],
    "samparidah": ['mw'],
    "samparigrah": ['mw'],
    "samparigraha": ['mw'],
    "samparihṛ": ['mw'],
    "samparihṛṣ": ['mw'],
    "samparikamp": ['mw'],
    "samparikaḍḍhati": ['cped'],
    "samparikhyā": ['mw'],
    "samparikram": ['mw'],
    "samparikīrt": ['mw'],
    "samparikīrtita": ['mw'],
    "samparimud": ['mw'],
    "samparimārgaṇa": ['mw'],
    "sampariplu": ['mw'],
    "samparipluta": ['mw'],
    "sampariprepsu": ['mw'],
    "samparipālana": ['mw'],
    "samparipūj": ['mw'],
    "samparipūrṇa": ['mw'],
    "samparipūrṇavidya": ['mw'],
    "samparipṛṣṭa": ['mw'],
    "samparirabh": ['mw'],
    "samparirakṣ": ['mw'],
    "samparistṛ": ['mw'],
    "samparitoṣita": ['mw'],
    "samparituṣ": ['mw'],
    "samparityaj": ['mw'],
    "samparityakta": ['mw'],
    "samparityaktajīvita": ['mw'],
    "samparivajjesi": ['cped'],
    "samparivajjeti": ['cped'],
    "samparivajjetvā": ['cped'],
    "samparivajjita": ['cped'],
    "samparivarta": ['mw'],
    "samparivattati": ['cped'],
    "samparivatteti": ['cped'],
    "samparivatti": ['cped'],
    "samparivattitvā": ['cped'],
    "sampariveṣṭita": ['mw'],
    "samparivāresi": ['cped'],
    "samparivāreti": ['cped'],
    "samparivāretvā": ['cped'],
    "samparivārita": ['cped', 'mw'],
    "samparivṛ": ['mw'],
    "samparivṛj": ['mw'],
    "samparivṛt": ['mw'],
    "samparivṛta": ['mw'],
    "samparivṛtta": ['mw'],
    "sampariśoṣaṇa": ['mw'],
    "sampariśri": ['mw'],
    "sampariśrita": ['mw'],
    "sampariśrānta": ['mw'],
    "sampariṣvakta": ['mw'],
    "sampariṣvañj": ['mw'],
    "samparka": ['mw'],
    "samparkin": ['mw'],
    "samparkīya": ['mw'],
    "samparyāp": ['mw'],
    "samparyāsana": ['mw'],
    "samparāya": ['cped', 'mw'],
    "samparāyaka": ['mw'],
    "samparāyika": ['cped'],
    "samparī": ['mw'],
    "samparīvṛta": ['mw'],
    "samparīya": ['mw'],
    "sampassamāna": ['cped'],
    "sampassanta": ['cped'],
    "sampassati": ['cped'],
    "sampassi": ['cped'],
    "sampassitvā": ['cped'],
    "sampasāda": ['cped'],
    "sampasādaniya": ['cped'],
    "sampasādesi": ['cped'],
    "sampasādeti": ['cped'],
    "sampasādetvā": ['cped'],
    "sampasādita": ['cped'],
    "sampasāresi": ['cped'],
    "sampasāreti": ['cped'],
    "sampasāretvā": ['cped'],
    "sampasārita": ['cped'],
    "sampasīdana": ['cped'],
    "sampasīdati": ['cped'],
    "sampasīdi": ['cped'],
    "sampasīditvā": ['cped'],
    "sampat": ['mw'],
    "sampati": ['cped'],
    "sampatita": ['cped', 'mw'],
    "sampatkumāra": ['mw'],
    "sampatkumāramaṅgalāśāsana": ['mw'],
    "sampatkumāraprapatti": ['mw'],
    "sampatkumārastotra": ['mw'],
    "sampatkumāravijaya": ['mw'],
    "sampatnī": ['mw'],
    "sampatnīya": ['mw'],
    "sampatpradā": ['mw'],
    "sampatsaṃtānacandrikā": ['mw'],
    "sampatta": ['cped'],
    "sampatti": ['cped', 'mw'],
    "sampattika": ['mw'],
    "sampavana": ['mw'],
    "sampavattesi": ['cped'],
    "sampavatteti": ['cped'],
    "sampavattita": ['cped'],
    "sampavedhati": ['cped'],
    "sampavedheti": ['cped'],
    "sampavedhi": ['cped'],
    "sampavedhita": ['cped'],
    "sampavāyati": ['cped'],
    "sampayoga": ['cped'],
    "sampayojesi": ['cped'],
    "sampayojeti": ['cped'],
    "sampayojetvā": ['cped'],
    "sampayojita": ['cped'],
    "sampayutta": ['cped'],
    "sampayāta": ['cped'],
    "sampaś": ['mw'],
    "sampaṭh": ['mw'],
    "sampaṭicchana": ['cped'],
    "sampaṭicchati": ['cped'],
    "sampaṭicchi": ['cped'],
    "sampaṭicchita": ['cped'],
    "sampaṭicchitvā": ['cped'],
    "sampeṣa": ['mw'],
    "sampeṣaṇa": ['mw'],
    "sampha": ['cped'],
    "samphala": ['mw'],
    "samphalīya": ['mw'],
    "samphappalapa": ['cped'],
    "samphassa": ['cped'],
    "sampheṭa": ['mw'],
    "samphulla": ['cped', 'mw'],
    "samphusanā": ['cped'],
    "samphusati": ['cped'],
    "samphusi": ['cped'],
    "samphusita": ['cped'],
    "samphusitvā": ['cped'],
    "samphussanta": ['cped'],
    "samphāla": ['mw'],
    "sampiba": ['mw'],
    "sampidhāna": ['mw'],
    "sampipādayiṣita": ['mw'],
    "sampipādayiṣitatva": ['mw'],
    "sampipādayiṣā": ['mw'],
    "sampiyamāna": ['cped'],
    "sampiyanta": ['cped'],
    "sampiyita": ['cped'],
    "sampiyitvā": ['cped'],
    "sampiyāyanā": ['cped'],
    "sampiyāyati": ['cped'],
    "sampiyāyi": ['cped'],
    "sampiṇḍ": ['mw'],
    "sampiṇḍana": ['cped'],
    "sampiṇḍesi": ['cped'],
    "sampiṇḍeti": ['cped'],
    "sampiṇḍetvā": ['cped'],
    "sampiṇḍita": ['cped', 'mw'],
    "sampiṇḍitāṅguli": ['mw'],
    "sampiṣ": ['mw'],
    "sampiṣṭa": ['mw'],
    "samplava": ['mw'],
    "samplu": ['mw'],
    "sampluta": ['mw'],
    "samplutodaka": ['mw'],
    "sampoṣya": ['mw'],
    "samprabhagna": ['mw'],
    "samprabhava": ['mw'],
    "samprabhinna": ['mw'],
    "samprabhā": ['mw'],
    "samprabhāṣ": ['mw'],
    "samprabodhita": ['mw'],
    "samprabuddha": ['mw'],
    "samprabudh": ['mw'],
    "samprabādh": ['mw'],
    "sampracakṣ": ['mw'],
    "sampracar": ['mw'],
    "sampracchid": ['mw'],
    "samprach": ['mw'],
    "sampraci": ['mw'],
    "sampracodita": ['mw'],
    "sampracud": ['mw'],
    "sampracyu": ['mw'],
    "samprada": ['mw'],
    "sampradah": ['mw'],
    "sampradarśita": ['mw'],
    "sampradatta": ['mw'],
    "sampradhāna": ['mw'],
    "sampradhāraṇa": ['mw'],
    "sampradhārita": ['mw'],
    "sampradhārya": ['mw'],
    "sampradhāv": ['mw'],
    "sampradhṛ": ['mw'],
    "sampradhṛṣ": ['mw'],
    "sampradiś": ['mw'],
    "sampradiṣṭa": ['mw'],
    "sampradru": ['mw'],
    "sampradruta": ['mw'],
    "sampraduta": ['mw'],
    "sampraduṣ": ['mw'],
    "sampraduṣṭa": ['mw'],
    "sampradā": ['mw'],
    "sampradāna": ['mw'],
    "sampradānīya": ['mw'],
    "sampradātavya": ['ddsa', 'mw'],
    "sampradātṛ": ['mw'],
    "sampradāya": ['mw'],
    "sampradāyacandrikā": ['mw'],
    "sampradāyanirūpaṇa": ['mw'],
    "sampradāyapaddhati": ['mw'],
    "sampradāyapariśuddhi": ['mw'],
    "sampradāyapradyotaka": ['mw'],
    "sampradāyapradīpa": ['mw'],
    "sampradāyapradīpapaddhati": ['mw'],
    "sampradāyaprakāśinī": ['mw'],
    "sampradāyaprāpta": ['mw'],
    "sampradāyatas": ['mw'],
    "sampradāyavid": ['mw'],
    "sampradāyavigama": ['mw'],
    "sampradāyin": ['mw'],
    "sampradīp": ['mw'],
    "sampradīpta": ['mw'],
    "sampradūṣaṇa": ['mw'],
    "sampradṛś": ['mw'],
    "sampragai": ['mw'],
    "sampragarjita": ['mw'],
    "sampraghṛṣ": ['mw'],
    "sampragrah": ['mw'],
    "sampragāh": ['mw'],
    "sampragṝ": ['mw'],
    "sampraharṣa": ['mw'],
    "sampraharṣaṇa": ['mw'],
    "sampraharṣaṇā": ['mw'],
    "sampraharṣin": ['mw'],
    "sampraharṣita": ['mw'],
    "samprahas": ['mw'],
    "samprahita": ['mw'],
    "samprahā": ['mw'],
    "samprahāra": ['mw'],
    "samprahāri": ['mw'],
    "samprahārin": ['mw'],
    "samprahāsa": ['mw'],
    "samprahṛ": ['mw'],
    "samprahṛṣ": ['mw'],
    "samprahṛṣṭa": ['mw'],
    "samprahṛṣṭamanas": ['mw'],
    "samprahṛṣṭamukha": ['mw'],
    "samprahṛṣṭatanūruha": ['mw'],
    "sampraiṣa": ['mw'],
    "samprajan": ['mw'],
    "samprajanya": ['mw'],
    "samprajval": ['mw'],
    "samprajvalita": ['mw'],
    "samprajñā": ['mw'],
    "samprajñāta": ['mw'],
    "samprajñātayogin": ['mw'],
    "samprajñātāvasthā": ['mw'],
    "samprajāna": ['mw'],
    "samprajāta": ['mw'],
    "samprajātā": ['mw'],
    "samprakalpita": ['mw'],
    "samprakamp": ['mw'],
    "samprakhyāna": ['mw'],
    "samprakliś": ['mw'],
    "samprakram": ['mw'],
    "samprakāś": ['mw'],
    "samprakāśa": ['mw'],
    "samprakāśaka": ['mw'],
    "samprakāśana": ['ddsa', 'mw'],
    "samprakāśanatā": ['mw'],
    "samprakāśita": ['mw'],
    "samprakāśya": ['mw'],
    "samprakīrtita": ['mw'],
    "samprakīrṇa": ['mw'],
    "samprakḷp": ['mw'],
    "samprakḷpta": ['mw'],
    "samprakṛ": ['mw'],
    "samprakṛṣ": ['mw'],
    "samprakṣai": ['mw'],
    "samprakṣip": ['mw'],
    "samprakṣubh": ['mw'],
    "samprakṣubhita": ['mw'],
    "samprakṣubhitamānasa": ['mw'],
    "samprakṣāla": ['mw'],
    "samprakṣālana": ['mw'],
    "samprakṣālanī": ['mw'],
    "sampralubh": ['mw'],
    "sampralup": ['mw'],
    "sampralāpa": ['mw'],
    "sampralī": ['mw'],
    "sampralīna": ['mw'],
    "sampramanth": ['mw'],
    "sampramardana": ['mw'],
    "sampramath": ['mw'],
    "sampramathya": ['mw'],
    "sampramatta": ['mw'],
    "samprameha": ['mw'],
    "sampramoda": ['mw'],
    "sampramoha": ['mw'],
    "sampramokṣ": ['mw'],
    "sampramoṣa": ['mw'],
    "sampramuc": ['mw'],
    "sampramucya": ['mw'],
    "sampramugdha": ['mw'],
    "sampramugdhatva": ['mw'],
    "sampramuh": ['mw'],
    "sampramukhita": ['mw'],
    "sampramukti": ['mw'],
    "sampramuṣita": ['mw'],
    "sampramāda": ['mw'],
    "sampramāpaṇa": ['mw'],
    "sampramārga": ['mw'],
    "sampramūḍha": ['mw'],
    "sampramṛd": ['mw'],
    "sampranaṣṭa": ['mw'],
    "sampranṛtta": ['mw'],
    "samprapac": ['mw'],
    "samprapad": ['mw'],
    "samprapada": ['mw'],
    "samprapanna": ['mw'],
    "samprapuṣpita": ['mw'],
    "samprapīḍ": ['mw'],
    "samprapīḍita": ['mw'],
    "samprapūj": ['mw'],
    "sampraruc": ['mw'],
    "samprarudh": ['mw'],
    "sampraruṣṭa": ['mw'],
    "samprasad": ['mw'],
    "samprasah": ['mw'],
    "samprasahya": ['mw'],
    "samprasakta": ['mw'],
    "samprasanna": ['mw'],
    "samprasarpaṇa": ['mw'],
    "samprasatti": ['ddsa', 'mw'],
    "samprasava": ['mw'],
    "samprasañj": ['mw'],
    "samprasic": ['mw'],
    "samprasiddha": ['mw'],
    "samprasiddhi": ['mw'],
    "sampraspṛś": ['mw'],
    "samprasru": ['mw'],
    "samprasthita": ['mw'],
    "samprasthā": ['mw'],
    "samprastuta": ['mw'],
    "samprastāra": ['mw'],
    "samprasupta": ['mw'],
    "samprasāda": ['mw'],
    "samprasādana": ['mw'],
    "samprasādh": ['mw'],
    "samprasādhana": ['mw'],
    "samprasādhya": ['mw'],
    "samprasāra": ['mw'],
    "samprasāraṇa": ['mw'],
    "samprasū": ['mw'],
    "samprasūta": ['mw'],
    "samprasūti": ['mw'],
    "samprasṛ": ['mw'],
    "samprasṛp": ['mw'],
    "sampratap": ['mw'],
    "sampratapta": ['mw'],
    "sampratardana": ['mw'],
    "sampratark": ['mw'],
    "samprathita": ['mw'],
    "samprathā": ['mw'],
    "samprathāna": ['mw'],
    "samprati": ['ddsa', 'mw'],
    "sampratibhā": ['mw'],
    "sampratibhāsa": ['mw'],
    "sampratibhāṣ": ['mw'],
    "sampratibudh": ['mw'],
    "sampratigrah": ['mw'],
    "sampratigraha": ['mw'],
    "sampratihan": ['mw'],
    "sampratijñā": ['mw'],
    "sampratijñāta": ['mw'],
    "sampratilakṣ": ['mw'],
    "sampratimukta": ['mw'],
    "sampratinand": ['mw'],
    "sampratinandita": ['mw'],
    "sampratipad": ['mw'],
    "sampratipanna": ['mw'],
    "sampratipatti": ['ddsa', 'mw'],
    "sampratipattimat": ['mw'],
    "sampratiprāṇa": ['mw'],
    "sampratipādana": ['mw'],
    "sampratipādita": ['mw'],
    "sampratipāl": ['mw'],
    "sampratipūj": ['mw'],
    "sampratipūjita": ['mw'],
    "sampratipūjā": ['mw'],
    "sampratirodhaka": ['mw'],
    "sampratisaṃcara": ['mw'],
    "samprativedhakī": ['mw'],
    "samprativedhikī": ['mw'],
    "samprativid": ['mw'],
    "sampratiśru": ['mw'],
    "sampratiṣidh": ['mw'],
    "sampratiṣṭhita": ['mw'],
    "sampratiṣṭhā": ['mw'],
    "sampratiṣṭhāna": ['mw'],
    "sampratolī": ['mw'],
    "sampratti": ['mw'],
    "samprattikarman": ['mw'],
    "sampratuṣ": ['mw'],
    "sampratyavekṣaṇatā": ['mw'],
    "sampratyaya": ['mw'],
    "sampratyāgata": ['mw'],
    "sampratyāyaka": ['mw'],
    "sampratyāyakatva": ['mw'],
    "sampratāpana": ['mw'],
    "sampratī": ['mw'],
    "sampratīkṣ": ['mw'],
    "sampratīkṣa": ['ddsa', 'mw'],
    "sampratīkṣya": ['mw'],
    "sampratīkṣā": ['mw'],
    "sampratīta": ['mw'],
    "sampratīti": ['mw'],
    "sampratīṣ": ['mw'],
    "sampratṝ": ['mw'],
    "sampravac": ['mw'],
    "sampravad": ['mw'],
    "sampravadana": ['mw'],
    "sampravartaka": ['mw'],
    "sampravartana": ['mw'],
    "sampravartin": ['mw'],
    "samprave": ['mw'],
    "sampraveśa": ['mw'],
    "sampraveśita": ['mw'],
    "sampraveṣṭ": ['mw'],
    "sampravicar": ['mw'],
    "sampraviddha": ['mw'],
    "sampravihṛ": ['mw'],
    "sampravilāpana": ['mw'],
    "sampravip": ['mw'],
    "sampraviś": ['mw'],
    "sampraviṣṭa": ['mw'],
    "sampravyathita": ['mw'],
    "sampravāda": ['mw'],
    "sampravādana": ['mw'],
    "sampravādita": ['mw'],
    "sampravāha": ['mw'],
    "sampravṛ": ['mw'],
    "sampravṛdh": ['mw'],
    "sampravṛt": ['mw'],
    "sampravṛtta": ['mw'],
    "sampravṛtti": ['mw'],
    "sampravṛṣṭa": ['mw'],
    "samprayam": ['mw'],
    "samprayat": ['mw'],
    "samprayoga": ['mw'],
    "samprayogikā": ['mw'],
    "samprayogin": ['mw'],
    "samprayojita": ['mw'],
    "samprayojya": ['mw'],
    "samprayoktavya": ['mw'],
    "samprayuddha": ['mw'],
    "samprayudh": ['mw'],
    "samprayuj": ['mw'],
    "samprayukta": ['mw'],
    "samprayuktaka": ['mw'],
    "samprayā": ['mw'],
    "samprayāc": ['mw'],
    "samprayāsa": ['mw'],
    "samprayāta": ['mw'],
    "samprayāṇa": ['mw'],
    "sampraśna": ['ddsa', 'gra', 'mw'],
    "sampraśraya": ['mw'],
    "sampraśrita": ['mw'],
    "sampraśānta": ['mw'],
    "sampraśās": ['mw'],
    "sampraṇad": ['mw'],
    "sampraṇam": ['mw'],
    "sampraṇardita": ['mw'],
    "sampraṇaś": ['mw'],
    "sampraṇetṛ": ['mw'],
    "sampraṇidhā": ['mw'],
    "sampraṇud": ['mw'],
    "sampraṇudita": ['mw'],
    "sampraṇāda": ['mw'],
    "sampraṇādita": ['mw'],
    "sampraṇī": ['mw'],
    "sampraṇīta": ['mw'],
    "sampraṣṭavya": ['mw'],
    "sampre": ['mw'],
    "sampreddha": ['mw'],
    "samprekṣ": ['mw'],
    "samprekṣaka": ['mw'],
    "samprekṣaṇa": ['mw'],
    "samprekṣita": ['mw'],
    "samprepsu": ['mw'],
    "samprer": ['mw'],
    "samprerṇa": ['mw'],
    "sampreṣ": ['mw'],
    "sampreṣa": ['mw'],
    "sampreṣaṇa": ['mw'],
    "sampreṣaṇī": ['mw'],
    "sampreṣita": ['mw'],
    "sampriya": ['ddsa', 'mw'],
    "sampriyatā": ['mw'],
    "sampriyā": ['mw'],
    "samprokta": ['mw'],
    "samprokṣ": ['mw'],
    "samprokṣaṇa": ['mw'],
    "samprokṣaṇakrama": ['mw'],
    "samprokṣaṇasaṃgraha": ['mw'],
    "samprokṣaṇavidhi": ['mw'],
    "samprokṣaṇī": ['mw'],
    "samprokṣita": ['mw'],
    "samprorṇu": ['mw'],
    "samprādru": ['mw'],
    "samprānta": ['mw'],
    "samprāp": ['mw'],
    "samprāpta": ['mw'],
    "samprāptavidya": ['mw'],
    "samprāptavya": ['ddsa', 'mw'],
    "samprāptayauvana": ['mw'],
    "samprāpti": ['mw'],
    "samprāptidvādaśī": ['mw'],
    "samprāpya": ['mw'],
    "samprārth": ['mw'],
    "samprārthita": ['mw'],
    "samprāv": ['mw'],
    "samprāś": ['mw'],
    "samprī": ['mw'],
    "samprīta": ['mw'],
    "samprītamānasa": ['mw'],
    "samprīti": ['mw'],
    "samprītimat": ['mw'],
    "samprīṇana": ['mw'],
    "samprīṇita": ['mw'],
    "sampsā": ['mw'],
    "sampucchati": ['cped'],
    "sampucchi": ['cped'],
    "sampupphita": ['cped'],
    "samputh": ['mw'],
    "sampuñja": ['mw'],
    "sampuṇṇa": ['cped'],
    "sampuṣ": ['mw'],
    "sampuṣka": ['mw'],
    "sampuṣṭi": ['mw'],
    "sampuṭa": ['mw'],
    "sampuṭaka": ['mw'],
    "sampuṭikā": ['mw'],
    "sampuṭī": ['mw'],
    "sampuṭīkaraṇa": ['mw'],
    "sampuṭīkṛ": ['mw'],
    "sampuṭṭha": ['cped'],
    "sampā": ['mw'],
    "sampācana": ['mw'],
    "sampāda": ['mw'],
    "sampādaka": ['cped', 'mw'],
    "sampādakatva": ['mw'],
    "sampādam": ['mw'],
    "sampādana": ['mw'],
    "sampādanīya": ['mw'],
    "sampādayitṛ": ['mw'],
    "sampādeka": ['cped'],
    "sampādesi": ['cped'],
    "sampādeti": ['cped'],
    "sampādetvā": ['cped'],
    "sampādin": ['mw'],
    "sampādita": ['cped', 'mw'],
    "sampāditatva": ['mw'],
    "sampādiyati": ['cped'],
    "sampādya": ['mw'],
    "sampādyatva": ['mw'],
    "sampāka": ['mw'],
    "sampāl": ['mw'],
    "sampālita": ['mw'],
    "sampāpana": ['cped'],
    "sampāpuṇanta": ['cped'],
    "sampāpuṇi": ['cped'],
    "sampāpuṇitvā": ['cped'],
    "sampāpuṇāti": ['cped'],
    "sampāra": ['mw'],
    "sampāraṇa": ['gra', 'mw'],
    "sampārin": ['mw'],
    "sampāta": ['cped', 'mw'],
    "sampātaka": ['mw'],
    "sampātam": ['mw'],
    "sampātapāṭava": ['mw'],
    "sampātasūkta": ['mw'],
    "sampātavat": ['mw'],
    "sampātaya": ['mw'],
    "sampāti": ['mw'],
    "sampātika": ['mw'],
    "sampātin": ['mw'],
    "sampātāyāta": ['mw'],
    "sampāvana": ['mw'],
    "sampāṭa": ['mw'],
    "sampāṭha": ['mw'],
    "sampāṭhya": ['mw'],
    "sampīti": ['mw'],
    "sampīḍ": ['mw'],
    "sampīḍa": ['mw'],
    "sampīḍana": ['mw'],
    "sampīḍita": ['mw'],
    "sampīḍā": ['mw'],
    "sampīḷesi": ['cped'],
    "sampīḷeti": ['cped'],
    "sampīḷetvā": ['cped'],
    "sampīḷita": ['cped'],
    "sampīṇesi": ['cped'],
    "sampīṇeti": ['cped'],
    "sampīṇetvā": ['cped'],
    "sampīṇita": ['cped'],
    "sampū": ['mw'],
    "sampūj": ['mw'],
    "sampūjaka": ['mw'],
    "sampūjana": ['mw'],
    "sampūjanīya": ['mw'],
    "sampūjayitavya": ['mw'],
    "sampūjenta": ['cped'],
    "sampūjesi": ['cped'],
    "sampūjeti": ['cped'],
    "sampūjetvā": ['cped'],
    "sampūjita": ['cped', 'mw'],
    "sampūjya": ['mw'],
    "sampūjā": ['mw'],
    "sampūraka": ['mw'],
    "sampūraṇa": ['mw'],
    "sampūraṇīya": ['mw'],
    "sampūresi": ['cped'],
    "sampūreti": ['cped'],
    "sampūretvā": ['cped'],
    "sampūrita": ['cped', 'mw'],
    "sampūrti": ['mw'],
    "sampūrva": ['mw'],
    "sampūrṇa": ['mw'],
    "sampūrṇakumbha": ['mw'],
    "sampūrṇakālīna": ['mw'],
    "sampūrṇakāma": ['mw'],
    "sampūrṇalakṣaṇa": ['mw'],
    "sampūrṇamūrchā": ['mw'],
    "sampūrṇaphalabhāj": ['mw'],
    "sampūrṇapuccha": ['mw'],
    "sampūrṇapuṇyamahiman": ['mw'],
    "sampūrṇasaṃhitā": ['mw'],
    "sampūrṇaspṛha": ['mw'],
    "sampūrṇaspṛhatā": ['mw'],
    "sampūrṇatara": ['mw'],
    "sampūrṇatā": ['mw'],
    "sampūrṇatāyukta": ['mw'],
    "sampūrṇavidya": ['mw'],
    "sampūrṇavrata": ['mw'],
    "sampūrṇā": ['mw'],
    "sampūrṇāṅga": ['mw'],
    "sampūyana": ['mw'],
    "sampṛ": ['mw'],
    "sampṛc": ['gra', 'mw'],
    "sampṛccham": ['mw'],
    "sampṛkta": ['mw'],
    "sampṛktatva": ['mw'],
    "sampṛṇa": ['mw'],
    "sampṛṣṭa": ['mw'],
    "sampṝ": ['mw'],
    "samrāj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "samrāja": ['mw'],
    "samrājia": ['gra'],
    "samrājñī": ['gra', 'mw'],
    "samrāḍ": ['mw'],
    "samrāḍdughā": ['mw'],
    "samrāḍyantra": ['mw'],
    "samrāḍāsandī": ['mw'],
    "samrāṭ": ['mw'],
    "samrāṭsiddhānta": ['mw'],
    "samu": ['mw'],
    "samubbahana": ['cped'],
    "samubbahanta": ['cped'],
    "samubbahati": ['cped'],
    "samubbahi": ['cped'],
    "samubbahitvā": ['cped'],
    "samubbhavati": ['cped'],
    "samubbhavi": ['cped'],
    "samubbhavitvā": ['cped'],
    "samubbhūta": ['cped'],
    "samubdha": ['mw'],
    "samubh": ['mw'],
    "samubj": ['mw'],
    "samubjita": ['mw'],
    "samuc": ['mw'],
    "samucca": ['mw'],
    "samuccal": ['mw'],
    "samuccar": ['mw'],
    "samuccara": ['mw'],
    "samuccaraḥ": ['ap90'],
    "samuccaya": ['cae', 'cped', 'ddsa', 'mw'],
    "samuccayana": ['cae', 'mw'],
    "samuccayaḥ": ['ap90'],
    "samuccayopamā": ['cae', 'mw'],
    "samuccayālaṃkāra": ['mw'],
    "samuccetavya": ['mw'],
    "samucceya": ['mw'],
    "samucchad": ['mw'],
    "samucchal": ['mw'],
    "samucchanna": ['mw'],
    "samuccheda": ['cped', 'mw'],
    "samucchedana": ['mw'],
    "samucchedaḥ": ['ap90'],
    "samucchid": ['ap90', 'mw'],
    "samucchindana": ['cped'],
    "samucchindati": ['cped'],
    "samucchindi": ['cped'],
    "samucchinditvā": ['cped'],
    "samucchindiya": ['cped'],
    "samucchinna": ['mw'],
    "samucchinnavāsana": ['mw'],
    "samucchitti": ['cae', 'mw'],
    "samucchoṣaṇa": ['bhs'],
    "samucchraya": ['bhs', 'cae', 'mw'],
    "samucchrayaḥ": ['ap90'],
    "samucchrayaṇa": ['bhs'],
    "samucchri": ['ap90', 'mw'],
    "samucchrita": ['bhs', 'cae', 'mw'],
    "samucchritabhuja": ['mw'],
    "samucchritadhvajavat": ['mw'],
    "samucchriti": ['mw'],
    "samucchrāya": ['mw'],
    "samucchrāyaḥ": ['ap90'],
    "samucchuṣ": ['mw'],
    "samucchvas": ['mw'],
    "samucchvasita": ['cae', 'mw'],
    "samucchvasitaṃ": ['ap90'],
    "samucchvāsa": ['mw'],
    "samucchvāsita": ['mw'],
    "samucci": ['ap90', 'mw'],
    "samuccicīṣā": ['mw'],
    "samuccita": ['mw'],
    "samuccitīkṛta": ['mw'],
    "samuccāra": ['mw'],
    "samuccāraṇa": ['mw'],
    "samucita": ['cae', 'cped', 'mw'],
    "samud": ['cae', 'ddsa', 'mw'],
    "samudakta": ['ap90', 'mw'],
    "samudanta": ['cae', 'ddsa', 'mw'],
    "samudasta": ['mw'],
    "samudaya": ['bhs', 'cae', 'cped', 'mw'],
    "samudayasacca": ['cped'],
    "samudayaḥ": ['ap90'],
    "samudayāstaṃgama": ['bhs'],
    "samudañc": ['mw'],
    "samudbandh": ['mw'],
    "samudbandhana": ['cae', 'mw'],
    "samudbhava": ['cae', 'mw'],
    "samudbhavaḥ": ['ap90'],
    "samudbheda": ['cae', 'mw'],
    "samudbhrānta": ['mw'],
    "samudbhāsana": ['mw'],
    "samudbhū": ['mw'],
    "samudbhūta": ['cae', 'mw'],
    "samudbhūti": ['cae', 'mw'],
    "samudbodha": ['mw'],
    "samudbodhana": ['mw'],
    "samudbudh": ['mw'],
    "samudbṛh": ['mw'],
    "samudda": ['cped'],
    "samuddaṇḍa": ['cae', 'mw'],
    "samuddaṭṭhaka": ['cped'],
    "samuddeśa": ['cae', 'mw'],
    "samuddeśaḥ": ['ap90'],
    "samuddeśīya": ['mw'],
    "samuddharati": ['cped'],
    "samuddharaṇa": ['cae', 'cped', 'mw'],
    "samuddharaṇaṃ": ['ap90'],
    "samuddhari": ['cped'],
    "samuddharitvā": ['cped'],
    "samuddhartṛ": ['ap90', 'cae', 'mw'],
    "samuddharṣa": ['mw'],
    "samuddhasta": ['mw'],
    "samuddhata": ['ap90', 'cae', 'mw'],
    "samuddhatalāṅgūla": ['mw'],
    "samuddhatataraṃgin": ['mw'],
    "samuddhaṭa": ['cped'],
    "samuddhura": ['mw'],
    "samuddhuta": ['mw'],
    "samuddhvasta": ['mw'],
    "samuddhā": ['mw'],
    "samuddhānana": ['bhs'],
    "samuddhāra": ['cae', 'mw'],
    "samuddhū": ['mw'],
    "samuddhūta": ['mw'],
    "samuddhūṣara": ['mw'],
    "samuddhṛ": ['ap90', 'mw'],
    "samuddhṛta": ['ap90', 'mw'],
    "samuddhṛṣ": ['mw'],
    "samuddidhīrṣu": ['mw'],
    "samuddita": ['bhs'],
    "samuddiś": ['mw'],
    "samuddiśati": ['bhs'],
    "samuddiśya": ['cae', 'mw'],
    "samuddiṣṭa": ['mw'],
    "samuddru": ['mw'],
    "samuddyut": ['mw'],
    "samuddīp": ['mw'],
    "samuddṛpta": ['mw'],
    "samuddṝ": ['mw'],
    "samudesi": ['cped'],
    "samudeta": ['mw'],
    "samudeti": ['cped'],
    "samudga": ['ap90', 'cae', 'mw'],
    "samudgaka": ['mw'],
    "samudgakaḥ": ['ap90'],
    "samudgala": ['mw'],
    "samudgam": ['ap90', 'mw'],
    "samudgama": ['cae', 'mw'],
    "samudgamaḥ": ['ap90'],
    "samudgata": ['bhs', 'mw'],
    "samudgatarāja": ['bhs'],
    "samudgataśrī": ['bhs'],
    "samudgayamaka": ['mw'],
    "samudghaṭ": ['mw'],
    "samudghaṭana": ['bhs'],
    "samudghaṭita": ['bhs'],
    "samudghāta": ['bhs', 'mw'],
    "samudghātana": ['bhs'],
    "samudghātin": ['mw'],
    "samudghātita": ['bhs'],
    "samudghāṭa": ['bhs', 'mw'],
    "samudghāṭana": ['bhs'],
    "samudghāṭayati": ['bhs'],
    "samudghāṭin": ['bhs'],
    "samudghṛṣ": ['mw'],
    "samudgiraṇaṃ": ['ap90'],
    "samudgrah": ['mw'],
    "samudgranth": ['mw'],
    "samudguñj": ['mw'],
    "samudgāra": ['mw'],
    "samudgīrṇa": ['mw'],
    "samudgīta": ['mw'],
    "samudgītaṃ": ['ap90'],
    "samudi": ['ap90', 'mw'],
    "samudita": ['ap90', 'bhs', 'cped', 'mw'],
    "samuditvara": ['mw'],
    "samuditṛ": ['mw'],
    "samudra": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "samudrabandhayajvan": ['mw'],
    "samudrabhava": ['mw'],
    "samudrabuddhi": ['bhs'],
    "samudraculuka": ['mw'],
    "samudradatta": ['cae', 'mw'],
    "samudradayitā": ['mw'],
    "samudradeva": ['mw'],
    "samudradevatā": ['mw'],
    "samudraga": ['cae', 'mw'],
    "samudragamana": ['mw'],
    "samudragupta": ['mw'],
    "samudragā": ['mw'],
    "samudragāmin": ['mw'],
    "samudragṛha": ['cae', 'mw'],
    "samudragṛhaka": ['cae'],
    "samudraja": ['cae', 'mw'],
    "samudrajyeṣṭha": ['cae', 'gra', 'mw'],
    "samudrakaccha": ['bhs'],
    "samudrakalekha": ['bhs'],
    "samudrakallola": ['ddsa', 'mw'],
    "samudrakapha": ['mw'],
    "samudrakara": ['mw'],
    "samudrakarabhāṣya": ['mw'],
    "samudrakaṭaka": ['mw'],
    "samudrakukṣi": ['mw'],
    "samudrakāntā": ['mw'],
    "samudrakāñcī": ['mw'],
    "samudralavaṇa": ['mw'],
    "samudralekhaka": ['mw'],
    "samudramahiṣī": ['mw'],
    "samudramathana": ['mw'],
    "samudramekhalā": ['mw'],
    "samudramālin": ['cae', 'mw'],
    "samudramātra": ['mw'],
    "samudramīṅkhaya": ['gra', 'mw'],
    "samudranavanīta": ['mw'],
    "samudranavanītaka": ['mw'],
    "samudranemi": ['cae', 'mw'],
    "samudranemīpati": ['mw'],
    "samudranemīśvara": ['mw'],
    "samudraniṣkuṭa": ['mw'],
    "samudraparyanta": ['mw'],
    "samudrapatnī": ['cae', 'mw'],
    "samudraphala": ['mw'],
    "samudraphena": ['mw'],
    "samudrapheṇa": ['mw'],
    "samudrapratiṣṭhāna": ['bhs'],
    "samudrapriya": ['mw'],
    "samudraputra": ['bhs'],
    "samudraraśana": ['cae', 'mw'],
    "samudraraśanā": ['mw'],
    "samudrasalileśaya": ['mw'],
    "samudrasaṃyāna": ['mw'],
    "samudrasena": ['mw'],
    "samudrasnāna": ['mw'],
    "samudrasnānavidhi": ['mw'],
    "samudrasthalī": ['mw'],
    "samudrasubhagā": ['mw'],
    "samudrasāra": ['mw'],
    "samudrasūri": ['mw'],
    "samudratas": ['cae', 'gra', 'mw'],
    "samudratatā": ['mw'],
    "samudrataṭa": ['mw'],
    "samudratva": ['mw'],
    "samudratīra": ['cae', 'mw'],
    "samudratīrīya": ['mw'],
    "samudravahni": ['mw'],
    "samudravallabhā": ['cae', 'mw'],
    "samudravarman": ['mw'],
    "samudravarṇana": ['mw'],
    "samudravasana": ['cae', 'mw'],
    "samudravasanā": ['mw'],
    "samudravastra": ['mw'],
    "samudravelā": ['cae', 'mw'],
    "samudravetāḍī": ['bhs'],
    "samudravijaya": ['mw'],
    "samudravyacas": ['gra', 'mw'],
    "samudravyavahārin": ['cae', 'mw'],
    "samudravākya": ['mw'],
    "samudravāsas": ['gra', 'mw'],
    "samudravāsin": ['cae', 'mw'],
    "samudrayoṣit": ['cae', 'mw'],
    "samudrayāna": ['mw'],
    "samudrayānamīmāṃsā": ['mw'],
    "samudrayātrika": ['bhs'],
    "samudrayātrā": ['cae', 'mw'],
    "samudrayāyin": ['cae'],
    "samudraśoṣa": ['mw'],
    "samudraśrī": ['mw'],
    "samudraśukti": ['mw'],
    "samudraśūra": ['mw'],
    "samudreka": ['ddsa'],
    "samudreṣṭha": ['mw'],
    "samudrikta": ['mw'],
    "samudriya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "samudronmādana": ['mw'],
    "samudropapluta": ['mw'],
    "samudrya": ['cae', 'mw'],
    "samudrā": ['bhs', 'mw'],
    "samudrābhisāriṇī": ['mw'],
    "samudrādi": ['mw'],
    "samudrāmbarā": ['mw'],
    "samudrāmbhas": ['mw'],
    "samudrānta": ['cae', 'mw'],
    "samudrāntā": ['mw'],
    "samudrārtha": ['cae', 'gra', 'mw'],
    "samudrāru": ['mw'],
    "samudrāvagāhana": ['mw'],
    "samudrāvaraṇa": ['mw'],
    "samudrāvarohaṇa": ['mw'],
    "samudrāy": ['cae'],
    "samudrāya": ['ddsa', 'mw'],
    "samudrāyaṇa": ['ddsa', 'mw'],
    "samudrīya": ['mw'],
    "samudvah": ['ap90', 'mw'],
    "samudvaha": ['mw'],
    "samudvahaḥ": ['ap90'],
    "samudvartate": ['bhs'],
    "samudvas": ['mw'],
    "samudvega": ['mw'],
    "samudvegaḥ": ['ap90'],
    "samudvigna": ['mw'],
    "samudvij": ['mw'],
    "samudvāha": ['cae', 'mw'],
    "samudvāhaḥ": ['ap90'],
    "samudvīkṣ": ['mw'],
    "samudvṛh": ['mw'],
    "samudvṛt": ['mw'],
    "samudvṛtta": ['mw'],
    "samudya": ['mw'],
    "samudyam": ['mw'],
    "samudyama": ['cae', 'mw'],
    "samudyamaḥ": ['ap90'],
    "samudyamin": ['mw'],
    "samudyata": ['mw'],
    "samudyoga": ['cae', 'mw'],
    "samudyogaḥ": ['ap90'],
    "samudyuj": ['mw'],
    "samudyā": ['mw'],
    "samudyāta": ['mw'],
    "samudācar": ['mw'],
    "samudācarati": ['bhs', 'cped'],
    "samudācaraṇa": ['cped'],
    "samudācari": ['cped'],
    "samudācarita": ['cped', 'mw'],
    "samudācaritvā": ['cped'],
    "samudāciṇṇa": ['cped'],
    "samudācāra": ['bhs', 'cae', 'cped', 'mw'],
    "samudācāravat": ['mw'],
    "samudācāraḥ": ['ap90'],
    "samudācāraṇa": ['bhs'],
    "samudācārika": ['bhs'],
    "samudācārin": ['bhs', 'mw'],
    "samudāgacchati": ['bhs'],
    "samudāgam": ['mw'],
    "samudāgama": ['bhs', 'cped', 'mw'],
    "samudāgamana": ['bhs'],
    "samudāgamaḥ": ['ap90'],
    "samudāgata": ['bhs', 'cped', 'mw'],
    "samudāharati": ['cped'],
    "samudāharaṇa": ['cped', 'mw'],
    "samudāharaṇaṃ": ['ap90'],
    "samudāhari": ['cped'],
    "samudāharitvā": ['cped'],
    "samudāhaṭa": ['cped'],
    "samudāhāra": ['bhs', 'cped', 'mw'],
    "samudāhāraka": ['bhs'],
    "samudāhṛ": ['mw'],
    "samudāhṛta": ['mw'],
    "samudāna": ['bhs'],
    "samudānana": ['bhs'],
    "samudānaya": ['bhs', 'mw'],
    "samudānayana": ['bhs', 'mw'],
    "samudānayati": ['bhs'],
    "samudānayatā": ['mw'],
    "samudānayitavya": ['mw'],
    "samudānetar": ['bhs'],
    "samudānetavya": ['mw'],
    "samudānita": ['mw'],
    "samudānītatva": ['mw'],
    "samudānīya": ['bhs'],
    "samudāvah": ['mw'],
    "samudāya": ['cae', 'cped', 'mw'],
    "samudāyaprakaraṇa": ['mw'],
    "samudāyaḥ": ['ap90'],
    "samudāyin": ['mw'],
    "samudāyāti": ['bhs'],
    "samudīkṣ": ['mw'],
    "samudīr": ['ap90', 'mw'],
    "samudīraṇa": ['cae', 'cped', 'mw'],
    "samudīraṇaṃ": ['ap90'],
    "samudīresi": ['cped'],
    "samudīreti": ['cped'],
    "samudīretvā": ['cped'],
    "samudīrita": ['cped', 'mw'],
    "samudīrṇa": ['cae', 'mw'],
    "samudīrṇakhara": ['mw'],
    "samudīrṇamānasa": ['mw'],
    "samudīṣ": ['mw'],
    "samugga": ['cped'],
    "samuggacchati": ['cped'],
    "samuggacchi": ['cped'],
    "samuggahetvā": ['cped'],
    "samuggahita": ['cped'],
    "samuggama": ['cped'],
    "samuggantvā": ['cped'],
    "samuggaṇhi": ['cped'],
    "samuggaṇhāti": ['cped'],
    "samugghāta": ['cped'],
    "samugghātaka": ['cped'],
    "samugghātesi": ['cped'],
    "samugghāteti": ['cped'],
    "samugghātetvā": ['cped'],
    "samugghātita": ['cped'],
    "samuggirati": ['cped'],
    "samuggiraṇa": ['cped'],
    "samuggiri": ['cped'],
    "samuhitṛ": ['mw'],
    "samuhya": ['mw'],
    "samuhyapurīṣa": ['mw'],
    "samujjala": ['cped'],
    "samujjh": ['mw'],
    "samujjhita": ['ap90', 'cped', 'mw'],
    "samujjihīrṣu": ['mw'],
    "samujjval": ['mw'],
    "samujjvala": ['cae', 'mw'],
    "samujjṛmbh": ['mw'],
    "samujjṛṃbh": ['ap90'],
    "samujjṛṃbhaṇaṃ": ['ap90'],
    "samujyate": ['bhs'],
    "samukha": ['ap90', 'mw'],
    "samukkaṅsesi": ['cped'],
    "samukkaṅseti": ['cped'],
    "samukkaṅsetvā": ['cped'],
    "samukkaṅsita": ['cped'],
    "samukta": ['mw'],
    "samukṣ": ['mw'],
    "samukṣaṇa": ['cae', 'ddsa', 'mw'],
    "samukṣaṇaṃ": ['ap90'],
    "samukṣita": ['mw'],
    "samula": ['bhs'],
    "samulbaṇa": ['mw'],
    "samullambita": ['cae', 'mw'],
    "samullapana": ['cped'],
    "samullapati": ['cped'],
    "samullapi": ['cped'],
    "samullapita": ['cped'],
    "samullapitvā": ['cped'],
    "samullas": ['ap90', 'mw'],
    "samullasita": ['mw'],
    "samullaṅgh": ['mw'],
    "samullekha": ['mw'],
    "samullikh": ['mw'],
    "samullokita": ['bhs'],
    "samullup": ['mw'],
    "samullāpa": ['bhs', 'cped'],
    "samullāsa": ['mw'],
    "samullāsaḥ": ['ap90'],
    "samullāsin": ['ddsa', 'mw'],
    "samund": ['mw'],
    "samundana": ['mw'],
    "samunmajj": ['mw'],
    "samunmajjate": ['bhs'],
    "samunmiśra": ['mw'],
    "samunmiṣ": ['mw'],
    "samunmukha": ['mw'],
    "samunmīl": ['mw'],
    "samunmīlita": ['mw'],
    "samunmūl": ['mw'],
    "samunmūlana": ['cae', 'mw'],
    "samunmūlanaṃ": ['ap90'],
    "samunmṛj": ['mw'],
    "samunna": ['ap90', 'mw'],
    "samunnad": ['mw'],
    "samunnada": ['mw'],
    "samunnaddha": ['ap90', 'mw'],
    "samunnah": ['ap90', 'mw'],
    "samunnam": ['ap90', 'mw'],
    "samunnamana": ['mw'],
    "samunnasa": ['mw'],
    "samunnata": ['ap90', 'cae', 'mw'],
    "samunnatalāṅgula": ['mw'],
    "samunnati": ['cae', 'mw'],
    "samunnatiḥ": ['ap90'],
    "samunnaya": ['mw'],
    "samunnayana": ['mw'],
    "samunnayaḥ": ['ap90'],
    "samunneya": ['mw'],
    "samunnidra": ['mw'],
    "samunnāda": ['mw'],
    "samunnāha": ['mw'],
    "samunnī": ['ap90', 'mw'],
    "samunnīta": ['mw'],
    "samupabbūḷha": ['cped'],
    "samupabhoga": ['mw'],
    "samupabhogaḥ": ['ap90'],
    "samupabhuj": ['mw'],
    "samupabṛh": ['mw'],
    "samupacarati": ['bhs'],
    "samupacchāda": ['mw'],
    "samupaci": ['mw'],
    "samupacita": ['cae', 'mw'],
    "samupacitajala": ['mw'],
    "samupacāra": ['mw'],
    "samupadarśayati": ['bhs'],
    "samupadhā": ['mw'],
    "samupadhāv": ['mw'],
    "samupadiś": ['mw'],
    "samupadru": ['mw'],
    "samupadruta": ['mw'],
    "samupadṛś": ['mw'],
    "samupagacchati": ['cped'],
    "samupagacchi": ['cped'],
    "samupagam": ['mw'],
    "samupagama": ['mw'],
    "samupagamana": ['cped'],
    "samupagamaḥ": ['ap90'],
    "samupagamma": ['cped'],
    "samupagantavya": ['ddsa', 'mw'],
    "samupagantvā": ['cped'],
    "samupagata": ['cped', 'mw'],
    "samupaghrā": ['mw'],
    "samupaguh": ['mw'],
    "samupahata": ['mw'],
    "samupahava": ['cae', 'mw'],
    "samupahvara": ['mw'],
    "samupahve": ['mw'],
    "samupahāsa": ['bhs'],
    "samupahṛ": ['mw'],
    "samupajan": ['mw'],
    "samupajanita": ['mw'],
    "samupajoṣam": ['ap90', 'mw'],
    "samupajñā": ['mw'],
    "samupajāta": ['mw'],
    "samupajātakopa": ['mw'],
    "samupajātābhiniveśam": ['mw'],
    "samupakalpita": ['mw'],
    "samupakaraṇa": ['bhs'],
    "samupakram": ['mw'],
    "samupakrama": ['mw'],
    "samupakramya": ['mw'],
    "samupakrānta": ['mw'],
    "samupakḷp": ['mw'],
    "samupakḷpta": ['mw'],
    "samupakṛṣ": ['mw'],
    "samupalabh": ['mw'],
    "samupalakṣ": ['mw'],
    "samupanayana": ['mw'],
    "samupanikṣipati": ['bhs'],
    "samupanyas": ['mw'],
    "samupanyasta": ['mw'],
    "samupanāmayati": ['bhs'],
    "samupanī": ['mw'],
    "samupanīta": ['mw'],
    "samupapad": ['mw'],
    "samupapadyati": ['bhs'],
    "samupapluta": ['mw'],
    "samupapādita": ['mw'],
    "samuparudh": ['mw'],
    "samuparuj": ['mw'],
    "samupasad": ['mw'],
    "samupasaṃhṛ": ['mw'],
    "samupasaṃhṛta": ['mw'],
    "samupasev": ['mw'],
    "samupasobhita": ['cped'],
    "samupaspṛś": ['mw'],
    "samupastambha": ['mw'],
    "samupasthita": ['cae', 'mw'],
    "samupasthiti": ['mw'],
    "samupasthitiḥ": ['ap90'],
    "samupasthā": ['ap90', 'mw'],
    "samupasthāna": ['mw'],
    "samupasṛ": ['mw'],
    "samupasṛp": ['mw'],
    "samupatap": ['mw'],
    "samupavah": ['mw'],
    "samupavas": ['mw'],
    "samupaveśa": ['mw'],
    "samupaveśana": ['mw'],
    "samupaveśanaṃ": ['ap90'],
    "samupaveśaḥ": ['ap90'],
    "samupaveśita": ['mw'],
    "samupaviś": ['ap90', 'mw'],
    "samupaviṣṭa": ['mw'],
    "samupavṛt": ['mw'],
    "samupayoṣam": ['mw'],
    "samupayuj": ['mw'],
    "samupayukta": ['mw'],
    "samupayuktavat": ['mw'],
    "samupayā": ['mw'],
    "samupayāta": ['mw'],
    "samupaśam": ['mw'],
    "samupaśobhita": ['bhs'],
    "samupaśru": ['mw'],
    "samupaṣṭambha": ['mw'],
    "samupe": ['ap90', 'mw'],
    "samupekṣ": ['mw'],
    "samupekṣaka": ['mw'],
    "samupepsu": ['cae', 'mw'],
    "samupeta": ['ap90', 'cae', 'cped', 'mw'],
    "samupeti": ['cped'],
    "samupopaviṣṭa": ['mw'],
    "samupoḍha": ['ap90', 'mw'],
    "samupoṣ": ['mw'],
    "samupoṣaka": ['mw'],
    "samupoṣita": ['mw'],
    "samuppajjati": ['cped'],
    "samuppajji": ['cped'],
    "samuppajjitvā": ['cped'],
    "samupābhicchāda": ['mw'],
    "samupācar": ['mw'],
    "samupādayati": ['bhs'],
    "samupādā": ['mw'],
    "samupādāya": ['bhs', 'mw'],
    "samupāgam": ['mw'],
    "samupāgata": ['cped', 'mw'],
    "samupāghrā": ['mw'],
    "samupāhita": ['bhs'],
    "samupāhṛ": ['mw'],
    "samupākrānta": ['mw'],
    "samupākṛ": ['mw'],
    "samupālambha": ['mw'],
    "samupānayana": ['cae', 'mw'],
    "samupānī": ['bhs', 'mw'],
    "samupānīta": ['mw'],
    "samupārabdha": ['mw'],
    "samupārj": ['mw'],
    "samupārjana": ['cae', 'mw'],
    "samupārjanaṃ": ['ap90'],
    "samupārjita": ['mw'],
    "samupāruh": ['mw'],
    "samupāruj": ['mw'],
    "samupārūḍha": ['mw'],
    "samupās": ['mw'],
    "samupāsthita": ['mw'],
    "samupāsthā": ['mw'],
    "samupātta": ['mw'],
    "samupāvartayati": ['bhs'],
    "samupāviś": ['mw'],
    "samupāvṛ": ['mw'],
    "samupāyukta": ['mw'],
    "samupāyā": ['mw'],
    "samupāyāta": ['mw'],
    "samupāś": ['mw'],
    "samupāśrayati": ['bhs'],
    "samupāśrita": ['mw'],
    "samussaya": ['cped'],
    "samussita": ['cped'],
    "samussāhesi": ['cped'],
    "samussāheti": ['cped'],
    "samussāhetvā": ['cped'],
    "samussāhita": ['cped'],
    "samussāpesi": ['cped'],
    "samussāpeti": ['cped'],
    "samussāpetvā": ['cped'],
    "samussāpita": ['cped'],
    "samuta": ['cae', 'mw'],
    "samutka": ['cae', 'ddsa', 'mw'],
    "samutkaca": ['mw'],
    "samutkampin": ['bhs', 'mw'],
    "samutkarṣa": ['cae', 'mw'],
    "samutkarṣaḥ": ['ap90'],
    "samutkarṣika": ['bhs'],
    "samutkaṇṭakita": ['mw'],
    "samutkaṇṭha": ['mw'],
    "samutkaṇṭhā": ['mw'],
    "samutkaṭa": ['mw'],
    "samutkhalī": ['bhs'],
    "samutkhan": ['mw'],
    "samutkleśa": ['mw'],
    "samutkliṣṭa": ['mw'],
    "samutkram": ['ap90', 'mw'],
    "samutkrama": ['mw'],
    "samutkramaḥ": ['ap90'],
    "samutkrośa": ['mw'],
    "samutkrośaḥ": ['ap90'],
    "samutkruṣṭa": ['mw'],
    "samutkīrtayati": ['bhs'],
    "samutkīrṇa": ['mw'],
    "samutkṛt": ['mw'],
    "samutkṛṣ": ['mw'],
    "samutkṣepa": ['mw'],
    "samutkṣepaṇa": ['mw'],
    "samutkṣip": ['mw'],
    "samutpad": ['ap90', 'mw'],
    "samutpanna": ['cae', 'mw'],
    "samutpat": ['ap90', 'mw'],
    "samutpatana": ['cae', 'mw'],
    "samutpatanaṃ": ['ap90'],
    "samutpatita": ['mw'],
    "samutpatiṣṇu": ['mw'],
    "samutpatti": ['cae', 'mw'],
    "samutpattiḥ": ['ap90'],
    "samutpaṭ": ['ap90', 'mw'],
    "samutphulla": ['cae', 'mw'],
    "samutphāla": ['mw'],
    "samutpipatiṣu": ['mw'],
    "samutpiñja": ['mw'],
    "samutpiñjala": ['mw'],
    "samutpiñjalaka": ['mw'],
    "samutpiṃja": ['ap90'],
    "samutpiṣṭa": ['mw'],
    "samutplu": ['mw'],
    "samutpuṃsana": ['mw'],
    "samutpuṭaka": ['bhs'],
    "samutpāda": ['cae', 'mw'],
    "samutpādana": ['mw'],
    "samutpādanaṃ": ['ap90'],
    "samutpādya": ['cae', 'mw'],
    "samutpāta": ['mw'],
    "samutpāṭa": ['mw'],
    "samutpāṭaḥ": ['ap90'],
    "samutpāṭita": ['mw'],
    "samutpīḍana": ['mw'],
    "samutpṛ": ['mw'],
    "samutsad": ['mw'],
    "samutsah": ['mw'],
    "samutsanna": ['mw'],
    "samutsarga": ['cae', 'mw'],
    "samutsargaḥ": ['ap90'],
    "samutsarpaṇa": ['mw'],
    "samutsava": ['mw'],
    "samutsavaḥ": ['ap90'],
    "samutsedha": ['cae', 'mw'],
    "samutsedhaḥ": ['ap90'],
    "samutsikta": ['mw'],
    "samutsuka": ['ap90', 'cae', 'mw'],
    "samutsukatva": ['mw'],
    "samutsukatā": ['mw'],
    "samutsukay": ['cae'],
    "samutsukaya": ['mw'],
    "samutsāha": ['mw'],
    "samutsāhatā": ['mw'],
    "samutsāraka": ['mw'],
    "samutsāraṇa": ['cae', 'mw'],
    "samutsāraṇaṃ": ['ap90'],
    "samutsṛ": ['mw'],
    "samutsṛj": ['mw'],
    "samutsṛp": ['mw'],
    "samutsṛṣṭa": ['mw'],
    "samuttara": ['bhs', 'mw'],
    "samuttarati": ['cped'],
    "samuttaraṇa": ['cped'],
    "samuttari": ['cped'],
    "samuttaritvā": ['cped'],
    "samuttejaka": ['bhs', 'cped', 'mw'],
    "samuttejana": ['cped', 'mw'],
    "samuttejayati": ['bhs'],
    "samuttejayitar": ['bhs'],
    "samuttejesi": ['cped'],
    "samuttejeti": ['cped'],
    "samuttejetvā": ['cped'],
    "samuttejita": ['cped', 'mw'],
    "samuttha": ['ap90', 'cae', 'mw'],
    "samuttheya": ['mw'],
    "samutthita": ['ap90', 'cae', 'mw'],
    "samutthā": ['ap90', 'mw'],
    "samutthāna": ['cae', 'mw'],
    "samutthānaka": ['bhs'],
    "samutthānavyaya": ['cae', 'mw'],
    "samutthānaṃ": ['ap90'],
    "samutthāpaka": ['bhs', 'mw'],
    "samutthāpya": ['mw'],
    "samuttij": ['mw'],
    "samuttiṇṇa": ['cped'],
    "samuttras": ['mw'],
    "samuttrasta": ['cae', 'mw'],
    "samuttuṅga": ['mw'],
    "samuttāna": ['mw'],
    "samuttāra": ['bhs', 'mw'],
    "samuttāraṇa": ['bhs'],
    "samuttīrṇa": ['mw'],
    "samuttṝ": ['mw'],
    "samuñcita": ['bhs'],
    "samuñja": ['mw'],
    "samuṃd": ['ap90'],
    "samuṃdanaṃ": ['ap90'],
    "samuṣ": ['mw'],
    "samuṣita": ['mw'],
    "samuṣka": ['mw'],
    "samuṣyala": ['mw'],
    "samuṭṭhāna": ['cped'],
    "samuṭṭhānika": ['cped'],
    "samuṭṭhāpaka": ['cped'],
    "samuṭṭhāpesi": ['cped'],
    "samuṭṭhāpeti": ['cped'],
    "samuṭṭhāpetvā": ['cped'],
    "samuṭṭhāpita": ['cped'],
    "samvṛh": ['mw'],
    "samvṛtaskandha": ['bhs'],
    "samya": ['bhs'],
    "samyac": ['ap90', 'gra'],
    "samyag": ['mw'],
    "samyagavabodha": ['ddsa', 'mw'],
    "samyagbodha": ['cae', 'mw'],
    "samyagdagdha": ['mw'],
    "samyagdarśana": ['cae', 'mw'],
    "samyagdarśanasampanna": ['mw'],
    "samyagdarśin": ['cae', 'mw'],
    "samyagdaṇḍana": ['mw'],
    "samyagdṛś": ['cae', 'mw'],
    "samyagdṛṣṭi": ['bhs', 'mw'],
    "samyagdṛṣṭika": ['bhs'],
    "samyagdṛṣṭitva": ['mw'],
    "samyaggamana": ['mw'],
    "samyaggata": ['mw'],
    "samyagghuta": ['mw'],
    "samyaggoptṛ": ['mw'],
    "samyagguṇa": ['mw'],
    "samyagjñāna": ['mw'],
    "samyagjñānatva": ['mw'],
    "samyagnamanapatha": ['bhs'],
    "samyagukta": ['mw'],
    "samyagvadamāna": ['bhs'],
    "samyagvartamāna": ['mw'],
    "samyagvarṇaprayoga": ['mw'],
    "samyagvijayin": ['cae', 'mw'],
    "samyagvyavasita": ['cae', 'mw'],
    "samyagvyāyāma": ['mw'],
    "samyagvāc": ['mw'],
    "samyagvānta": ['cae', 'mw'],
    "samyagvṛtta": ['mw'],
    "samyagvṛtti": ['cae', 'mw'],
    "samyagyoga": ['mw'],
    "samyagājñā": ['bhs', 'mw'],
    "samyagājīva": ['mw'],
    "samyak": ['bhs', 'cae', 'ddsa', 'mw'],
    "samyakcāritra": ['mw'],
    "samyakkarmānta": ['mw'],
    "samyakkārin": ['mw'],
    "samyakpradhāna": ['bhs'],
    "samyakprahāṇa": ['mw'],
    "samyakpravṛtti": ['mw'],
    "samyakprayoga": ['mw'],
    "samyakpraṇidhāna": ['mw'],
    "samyakpālana": ['cae', 'mw'],
    "samyakpāṭha": ['mw'],
    "samyaksambodha": ['mw'],
    "samyaksambodhi": ['mw'],
    "samyaksambuddha": ['mw'],
    "samyaksambuddhi": ['mw'],
    "samyaksamādhi": ['mw'],
    "samyaksattva": ['mw'],
    "samyaksatya": ['mw'],
    "samyaksaṃbodhi": ['bhs'],
    "samyaksaṃbuddha": ['bhs'],
    "samyaksaṃkalpa": ['cae', 'mw'],
    "samyaksmṛti": ['mw'],
    "samyaksthiti": ['mw'],
    "samyaktva": ['mw'],
    "samyaktvakaumudī": ['mw'],
    "samyaktvamithyātvasarvasaṃgrasana": ['bhs', 'mw'],
    "samyaktvaniyata": ['bhs'],
    "samyaktvaprakāśa": ['mw'],
    "samyaktvādhyayana": ['mw'],
    "samyaktvādhyāpana": ['mw'],
    "samyaktā": ['cae', 'mw'],
    "samyakśraddhāna": ['mw'],
    "samyañc": ['cae', 'ddsa', 'mw'],
    "samyaṅ": ['mw'],
    "samyaṅmati": ['mw'],
    "samā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "samābandh": ['mw'],
    "samābhuj": ['mw'],
    "samābhā": ['mw'],
    "samābhāṣ": ['mw'],
    "samābhāṣaṇa": ['cae', 'ddsa', 'mw'],
    "samābhāṣaṇaṃ": ['ap90'],
    "samābhṛ": ['mw'],
    "samābhṛta": ['mw'],
    "samābṛṃhayitar": ['bhs'],
    "samābṛṃhaṇa": ['bhs'],
    "samācakṣ": ['mw'],
    "samācam": ['mw'],
    "samācar": ['ap90', 'mw'],
    "samācara": ['mw'],
    "samācaranta": ['cped'],
    "samācarati": ['cped'],
    "samācaraṇa": ['cped', 'mw'],
    "samācaraṇaṃ": ['ap90'],
    "samācaraṇīya": ['ddsa', 'mw'],
    "samācari": ['cped'],
    "samācarita": ['mw'],
    "samācaritvā": ['cped'],
    "samācayana": ['mw'],
    "samācayanaṃ": ['ap90'],
    "samācchad": ['mw'],
    "samācchanna": ['mw'],
    "samācchid": ['mw'],
    "samāceṣṭita": ['cae', 'mw'],
    "samāci": ['mw'],
    "samācita": ['mw'],
    "samācāra": ['cae', 'cped', 'mw'],
    "samācāraḥ": ['ap90'],
    "samācārin": ['bhs'],
    "samācīrṇa": ['mw'],
    "samādahanta": ['cped'],
    "samādahati": ['cped'],
    "samādahi": ['cped'],
    "samādahitvā": ['cped'],
    "samādana": ['cped'],
    "samādapaka": ['bhs', 'cped'],
    "samādapana": ['bhs'],
    "samādapesi": ['cped'],
    "samādapetar": ['cped'],
    "samādapeti": ['bhs', 'cped'],
    "samādapetvā": ['cped'],
    "samādapita": ['cped'],
    "samādara": ['mw'],
    "samādaraṇīya": ['mw'],
    "samādatta": ['bhs', 'mw'],
    "samādayati": ['bhs'],
    "samādeya": ['cae', 'mw'],
    "samādeśa": ['cae', 'mw'],
    "samādeśana": ['mw'],
    "samādeśaḥ": ['ap90'],
    "samādheya": ['cae', 'ddsa', 'mw'],
    "samādhi": ['bhs', 'cae', 'cped', 'mw'],
    "samādhibala": ['cped', 'mw'],
    "samādhibhaṅga": ['mw'],
    "samādhibheda": ['mw'],
    "samādhibhedin": ['mw'],
    "samādhibhāvanā": ['cped'],
    "samādhibhṛt": ['ddsa', 'mw'],
    "samādhibāvanā": ['cped'],
    "samādhigarbha": ['bhs', 'mw'],
    "samādhihastyuttaraśrī": ['bhs'],
    "samādhija": ['cped'],
    "samādhimant": ['cae'],
    "samādhimat": ['mw'],
    "samādhimatikā": ['mw'],
    "samādhimervabhyudgatajñāna": ['bhs'],
    "samādhimudrāvipulamakuṭaprajñāprabha": ['bhs'],
    "samādhin": ['ap90', 'mw'],
    "samādhiniṣṭha": ['mw'],
    "samādhiparihāṇi": ['mw'],
    "samādhiprakaraṇa": ['mw'],
    "samādhirāja": ['bhs', 'mw'],
    "samādhirājasupratiṣṭhita": ['bhs'],
    "samādhisamatā": ['bhs'],
    "samādhisambojjhaṅga": ['cped'],
    "samādhisamānatā": ['mw'],
    "samādhisaṁvattanika": ['cped'],
    "samādhisaṃyuktaka": ['bhs'],
    "samādhistha": ['cae', 'mw'],
    "samādhisthala": ['mw'],
    "samādhita": ['cae', 'mw'],
    "samādhitaṃ": ['bhs'],
    "samādhitsu": ['mw'],
    "samādhitsā": ['mw'],
    "samādhitva": ['mw'],
    "samādhividhi": ['mw'],
    "samādhivigraha": ['mw'],
    "samādhiyati": ['cped'],
    "samādhiyi": ['cped'],
    "samādhiyoga": ['mw'],
    "samādhiyogarddhitapovidyāviraktimat": ['mw'],
    "samādhiḥ": ['ap90'],
    "samādhmā": ['mw'],
    "samādhmāta": ['ap90', 'mw'],
    "samādhyai": ['mw'],
    "samādhyalaṃkṛta": ['bhs'],
    "samādhyate": ['bhs'],
    "samādhyāyikatā": ['bhs'],
    "samādhā": ['ap90', 'mw'],
    "samādhāna": ['bhs', 'cae', 'cped', 'mw'],
    "samādhānamātra": ['mw'],
    "samādhānarūpaka": ['cae', 'mw'],
    "samādhānaṃ": ['ap90'],
    "samādhānīya": ['mw'],
    "samādhātavya": ['cae', 'mw'],
    "samādhāv": ['mw'],
    "samādhāyaka": ['mw'],
    "samādhūta": ['mw'],
    "samādinna": ['bhs', 'cped'],
    "samādisati": ['cped'],
    "samādisi": ['cped'],
    "samādisitvā": ['cped'],
    "samādiyanta": ['cped'],
    "samādiyati": ['bhs', 'cped'],
    "samādiyi": ['cped'],
    "samādiyitvā": ['cped'],
    "samādiś": ['ap90', 'mw'],
    "samādiṣṭa": ['mw'],
    "samādiṭṭha": ['cped'],
    "samādru": ['mw'],
    "samādā": ['ap90', 'mw'],
    "samādāna": ['bhs', 'cae', 'mw'],
    "samādānana": ['bhs'],
    "samādānaṃ": ['ap90'],
    "samādānika": ['bhs', 'mw'],
    "samādāpaka": ['bhs', 'mw'],
    "samādāpana": ['bhs', 'mw'],
    "samādāpanikā": ['bhs'],
    "samādāpayati": ['bhs'],
    "samādāpayitar": ['bhs'],
    "samādāti": ['cped'],
    "samādāya": ['bhs', 'cped', 'mw'],
    "samādāyaka": ['bhs'],
    "samādṛta": ['mw'],
    "samāgacchati": ['cped'],
    "samāgacchi": ['cped'],
    "samāgalita": ['mw'],
    "samāgam": ['ap90', 'mw'],
    "samāgama": ['cae', 'cped', 'mw'],
    "samāgamakārin": ['mw'],
    "samāgamakṣaṇa": ['mw'],
    "samāgamamanoratha": ['mw'],
    "samāgamana": ['cae', 'mw'],
    "samāgamaprārthanā": ['mw'],
    "samāgamaḥ": ['ap90'],
    "samāgamin": ['mw'],
    "samāgamma": ['cped'],
    "samāgamopāya": ['mw'],
    "samāgantavya": ['mw'],
    "samāgantvā": ['cped'],
    "samāgata": ['ap90', 'cped', 'mw'],
    "samāgati": ['mw'],
    "samāgatiḥ": ['ap90'],
    "samāgatā": ['mw'],
    "samāghrā": ['mw'],
    "samāghrāṇa": ['mw'],
    "samāghāta": ['cae', 'mw'],
    "samāghātaḥ": ['ap90'],
    "samāgāḍha": ['mw'],
    "samāgāḍhatara": ['bhs'],
    "samāgṛbhāya": ['mw'],
    "samāgṛhīta": ['bhs'],
    "samāhan": ['mw'],
    "samāhanana": ['mw'],
    "samāhanati": ['cped'],
    "samāhara": ['ddsa', 'mw'],
    "samāharaṇa": ['mw'],
    "samāharaṇaṃ": ['ap90'],
    "samāhartṛ": ['ap90', 'cae', 'mw'],
    "samāhata": ['cped', 'mw'],
    "samāhita": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "samāhitadhī": ['mw'],
    "samāhitamanas": ['mw'],
    "samāhitamanobuddhi": ['mw'],
    "samāhitamati": ['cae', 'mw'],
    "samāhitikā": ['cae', 'mw'],
    "samāhitātman": ['mw'],
    "samāhva": ['mw'],
    "samāhvaya": ['cae', 'mw'],
    "samāhvayaḥ": ['ap90'],
    "samāhvaḥ": ['ap90'],
    "samāhve": ['ap90', 'mw'],
    "samāhvā": ['ap90', 'mw'],
    "samāhvāna": ['cae', 'mw'],
    "samāhvānaṃ": ['ap90'],
    "samāhvātṛ": ['cae', 'mw'],
    "samāhvī": ['mw'],
    "samāhāra": ['cae', 'mw'],
    "samāhāravarṇa": ['mw'],
    "samāhāraḥ": ['ap90'],
    "samāhārya": ['mw'],
    "samāhūta": ['mw'],
    "samāhṛ": ['ap90', 'mw'],
    "samāhṛta": ['ap90', 'mw'],
    "samāhṛti": ['mw'],
    "samāhṛtiḥ": ['ap90'],
    "samāhṛtya": ['mw'],
    "samāja": ['cae', 'ddsa', 'mw'],
    "samājasaṃniveśana": ['mw'],
    "samājaḥ": ['ap90'],
    "samājika": ['mw'],
    "samājikaḥ": ['ap90'],
    "samājuhūṣamāṇa": ['mw'],
    "samājñapta": ['mw'],
    "samājñā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "samājñāna": ['mw'],
    "samājñāta": ['mw'],
    "samākampate": ['bhs'],
    "samākara": ['mw'],
    "samākarṇ": ['mw'],
    "samākarṇitaka": ['ddsa', 'mw'],
    "samākarṣa": ['mw'],
    "samākarṣaṇa": ['cae', 'mw'],
    "samākarṣin": ['ap90', 'mw'],
    "samākarṣiṇī": ['mw'],
    "samākaḍḍhana": ['cped'],
    "samākaḍḍhati": ['cped'],
    "samākaḍḍhi": ['cped'],
    "samākaḍḍhitvā": ['cped'],
    "samākhyā": ['ap90', 'cae', 'mw'],
    "samākhyābhakṣa": ['mw'],
    "samākhyāna": ['cae', 'mw'],
    "samākhyāta": ['ap90', 'mw'],
    "samākhyāya": ['mw'],
    "samākhyāyam": ['mw'],
    "samākiṇṇa": ['cped'],
    "samāklinna": ['mw'],
    "samākram": ['ap90', 'mw'],
    "samākramaṇa": ['cae', 'mw'],
    "samākramaṇaṃ": ['ap90'],
    "samākrand": ['mw'],
    "samākrandana": ['cae', 'mw'],
    "samākruṣṭa": ['mw'],
    "samākrānta": ['mw'],
    "samākrīḍ": ['mw'],
    "samākula": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "samākulatva": ['mw'],
    "samākulatā": ['mw'],
    "samākuñcita": ['mw'],
    "samākāra": ['ddsa', 'mw'],
    "samākāraṇa": ['mw'],
    "samākāṅkṣ": ['mw'],
    "samākīrṇa": ['mw'],
    "samākṛ": ['mw'],
    "samākṛta": ['mw'],
    "samākṛṣ": ['ap90', 'mw'],
    "samākṛṣṭa": ['mw'],
    "samākṝ": ['mw'],
    "samākṣara": ['mw'],
    "samākṣarapadakrama": ['mw'],
    "samākṣarākāra": ['bhs'],
    "samākṣarāvakara": ['mw'],
    "samākṣepa": ['mw'],
    "samākṣika": ['mw'],
    "samākṣip": ['mw'],
    "samākṣipta": ['mw'],
    "samālabdha": ['mw'],
    "samālabh": ['ap90', 'mw'],
    "samālabhana": ['cae', 'mw'],
    "samālagna": ['mw'],
    "samālakṣ": ['mw'],
    "samālakṣya": ['cae', 'ddsa', 'mw'],
    "samālamb": ['mw'],
    "samālambana": ['mw'],
    "samālambha": ['cae', 'mw'],
    "samālambham": ['cae', 'mw'],
    "samālambhana": ['cae', 'mw'],
    "samālambhanahasta": ['cae'],
    "samālambhin": ['cae', 'mw'],
    "samālambin": ['mw'],
    "samālambita": ['mw'],
    "samālap": ['mw'],
    "samālaṃb": ['ap90'],
    "samālaṃbanaṃ": ['ap90'],
    "samālaṃbhaḥ": ['ap90'],
    "samālaṃbin": ['ap90'],
    "samālikh": ['mw'],
    "samālip": ['mw'],
    "samālipta": ['mw'],
    "samāliṅg": ['mw'],
    "samāliṅga": ['bhs'],
    "samāliṅgana": ['cae', 'mw'],
    "samāliṅgita": ['mw'],
    "samāloc": ['mw'],
    "samāloca": ['mw'],
    "samālocin": ['mw'],
    "samālok": ['mw'],
    "samāloka": ['cae', 'mw'],
    "samālokana": ['mw'],
    "samālokin": ['mw'],
    "samālokya": ['mw'],
    "samāluḍ": ['mw'],
    "samālya": ['mw'],
    "samālāpa": ['cae', 'mw'],
    "samālāpaḥ": ['ap90'],
    "samālī": ['mw'],
    "samāma": ['cae', 'mw'],
    "samāmantr": ['mw'],
    "samāmnā": ['ap90', 'mw'],
    "samāmnāna": ['mw'],
    "samāmnānaṃ": ['ap90'],
    "samāmnāta": ['cae', 'mw'],
    "samāmnātṛ": ['mw'],
    "samāmnāya": ['cae', 'mw'],
    "samāmnāyamaya": ['mw'],
    "samāmnāyaḥ": ['ap90'],
    "samāmnāyika": ['mw'],
    "samāmya": ['mw'],
    "samāna": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "samānabala": ['mw'],
    "samānabalatva": ['mw'],
    "samānabandhu": ['cae', 'gra', 'mw'],
    "samānabarhis": ['cae', 'mw'],
    "samānabhāva": ['cped'],
    "samānabhṛt": ['mw'],
    "samānabrahmacārin": ['mw'],
    "samānabrāhmaṇa": ['mw'],
    "samānabrāhmaṇīya": ['mw'],
    "samānabrāhmaṇīyatva": ['mw'],
    "samānadakṣa": ['gra', 'mw'],
    "samānadakṣiṇa": ['mw'],
    "samānadevata": ['cae', 'mw'],
    "samānadevatya": ['cae', 'mw'],
    "samānadharman": ['cae', 'mw'],
    "samānadhiṣṇya": ['mw'],
    "samānaduḥkha": ['mw'],
    "samānadṛś": ['mw'],
    "samānagati": ['mw'],
    "samānagatitva": ['mw'],
    "samānagotra": ['cae', 'mw'],
    "samānagrāma": ['mw'],
    "samānagrāmīya": ['mw'],
    "samānaguṇa": ['cae', 'mw'],
    "samānajana": ['cae', 'mw'],
    "samānajanapada": ['mw'],
    "samānajanman": ['cae', 'mw'],
    "samānajanya": ['mw'],
    "samānajñātitvamaya": ['mw'],
    "samānajāti": ['cae', 'mw'],
    "samānajātīya": ['cae', 'mw'],
    "samānajātīyatva": ['mw'],
    "samānaka": ['bhs'],
    "samānakaraṇa": ['mw'],
    "samānakarmaka": ['mw'],
    "samānakarman": ['mw'],
    "samānakartṛka": ['ddsa', 'mw'],
    "samānakartṛkatva": ['mw'],
    "samānakartṛkatā": ['mw'],
    "samānakartṛtva": ['mw'],
    "samānakhyāna": ['mw'],
    "samānakāla": ['cae', 'mw'],
    "samānakālam": ['mw'],
    "samānakālīna": ['cae', 'mw'],
    "samānakālīnatva": ['mw'],
    "samānakāraka": ['mw'],
    "samānakāraṇa": ['mw'],
    "samānakṣema": ['mw'],
    "samānakṣematva": ['mw'],
    "samānaloka": ['mw'],
    "samānam": ['mw'],
    "samānamāna": ['mw'],
    "samānamūrdhan": ['mw'],
    "samānana": ['mw'],
    "samānand": ['mw'],
    "samānanidhana": ['mw'],
    "samānanāman": ['mw'],
    "samānapakṣa": ['cae', 'mw'],
    "samānaprabhṛti": ['cae', 'mw'],
    "samānaprasiddhi": ['mw'],
    "samānapratipatti": ['cae', 'mw'],
    "samānapravaragrantha": ['mw'],
    "samānaprayojana": ['mw'],
    "samānapreman": ['cae', 'mw'],
    "samānapātra": ['mw'],
    "samānaruci": ['cae', 'mw'],
    "samānarucitā": ['mw'],
    "samānarāga": ['cae'],
    "samānarūpa": ['cae', 'mw'],
    "samānarūpā": ['mw'],
    "samānarṣi": ['mw'],
    "samānasalila": ['mw'],
    "samānasambandhana": ['mw'],
    "samānasaṁvāsaka": ['cped'],
    "samānasaṃkhya": ['mw'],
    "samānasaṃvāsika": ['bhs'],
    "samānasthāna": ['mw'],
    "samānastotriya": ['mw'],
    "samānasukhaduḥkha": ['cae', 'mw'],
    "samānasukhaduḥkhatā": ['bhs', 'mw'],
    "samānasūtranipāta": ['mw'],
    "samānasūtranipāte": ['mw'],
    "samānatantra": ['mw'],
    "samānatas": ['cae', 'gra', 'mw'],
    "samānatejas": ['mw'],
    "samānatra": ['cae', 'mw'],
    "samānattatā": ['cped'],
    "samānattā": ['cped'],
    "samānatva": ['cae', 'mw'],
    "samānatā": ['cae', 'mw'],
    "samānavacana": ['mw'],
    "samānavarcas": ['cae', 'gra', 'mw'],
    "samānavarcasa": ['cae', 'mw'],
    "samānavarṇa": ['cae', 'mw'],
    "samānavasana": ['mw'],
    "samānavassika": ['cped'],
    "samānavayas": ['mw'],
    "samānavayaska": ['mw'],
    "samānavidya": ['cae', 'mw'],
    "samānavidyatā": ['mw'],
    "samānavratabhṛt": ['mw'],
    "samānavratacārin": ['mw'],
    "samānavratacāritva": ['mw'],
    "samānaya": ['mw'],
    "samānayama": ['mw'],
    "samānayana": ['cae', 'mw'],
    "samānayanaṃ": ['ap90'],
    "samānayati": ['ap90'],
    "samānayogakṣema": ['mw'],
    "samānayogakṣematva": ['mw'],
    "samānayojana": ['cae', 'gra', 'mw'],
    "samānayoni": ['cae', 'mw'],
    "samānaśabdā": ['cae', 'mw'],
    "samānaśayya": ['mw'],
    "samānaśayyatā": ['mw'],
    "samānaśākhīya": ['mw'],
    "samānaśīla": ['mw'],
    "samānesi": ['cped'],
    "samāneti": ['cped'],
    "samānetvā": ['cped'],
    "samānicaya": ['cae', 'ddsa', 'mw'],
    "samānikā": ['mw'],
    "samānitam": ['ddsa', 'mw'],
    "samānodaka": ['cae', 'ddsa', 'mw'],
    "samānodakabhāva": ['mw'],
    "samānodarka": ['cae', 'mw'],
    "samānodarya": ['cae', 'mw'],
    "samānolba": ['mw'],
    "samānopamā": ['cae', 'mw'],
    "samānopādhyāya": ['mw'],
    "samānottamamadhyamādhama": ['mw'],
    "samānta": ['cae', 'ddsa', 'mw'],
    "samāntara": ['mw'],
    "samāntare": ['mw'],
    "samānyā": ['cae', 'ddsa', 'mw'],
    "samānābhihāra": ['mw'],
    "samānācārya": ['mw'],
    "samānādhikaraṇa": ['cae', 'mw'],
    "samānādhikaraṇatva": ['mw'],
    "samānādhikaraṇatā": ['mw'],
    "samānādhikāra": ['mw'],
    "samānākhyāna": ['mw'],
    "samānākṣara": ['cae', 'mw'],
    "samānālaṃkāra": ['mw'],
    "samānārtha": ['cae', 'mw'],
    "samānārthaka": ['mw'],
    "samānārthaprayojana": ['mw'],
    "samānārthatva": ['mw'],
    "samānārthatā": ['bhs', 'mw'],
    "samānārṣapravara": ['mw'],
    "samānārṣeya": ['cae', 'mw'],
    "samānāsa": ['mw'],
    "samānāsyaprayatna": ['mw'],
    "samānī": ['ap90', 'mw'],
    "samānīta": ['cped', 'mw'],
    "samāp": ['ap90', 'mw'],
    "samāpa": ['mw'],
    "samāpad": ['ap90', 'mw'],
    "samāpadana": ['bhs'],
    "samāpadyana": ['bhs', 'mw'],
    "samāpadyate": ['bhs'],
    "samāpajja": ['cped'],
    "samāpajjamāna": ['cped'],
    "samāpajjana": ['cped'],
    "samāpajjanta": ['cped'],
    "samāpajjati": ['cped'],
    "samāpajji": ['cped'],
    "samāpajjitvā": ['cped'],
    "samāpaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "samāpakakakriyā": ['mw'],
    "samāpakatva": ['mw'],
    "samāpana": ['cae', 'cped', 'ddsa', 'mw'],
    "samāpanaṃ": ['ap90'],
    "samāpanna": ['ap90', 'bhs', 'cped', 'mw'],
    "samāpanā": ['mw'],
    "samāpanīya": ['mw'],
    "samāpat": ['mw'],
    "samāpatita": ['mw'],
    "samāpatti": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "samāpattidṛṣṭa": ['mw'],
    "samāpattiḥ": ['ap90'],
    "samāpayitavya": ['mw'],
    "samāpaḥ": ['ap90'],
    "samāpesi": ['cped'],
    "samāpeti": ['cped'],
    "samāpetvā": ['cped'],
    "samāphala": ['mw'],
    "samāpikā": ['mw'],
    "samāpin": ['cae', 'mw'],
    "samāpipayiṣu": ['mw'],
    "samāpita": ['cped', 'mw'],
    "samāplava": ['cae', 'mw'],
    "samāplu": ['mw'],
    "samāpluta": ['ap90', 'mw'],
    "samāplāva": ['cae', 'mw'],
    "samāprabhāra": ['bhs'],
    "samāprach": ['mw'],
    "samāpriya": ['mw'],
    "samāpta": ['ap90', 'bhs', 'cae', 'mw'],
    "samāptabhūyiṣṭha": ['mw'],
    "samāptacinta": ['mw'],
    "samāptalambha": ['bhs', 'mw'],
    "samāptaprayoga": ['mw'],
    "samāptaprāya": ['mw'],
    "samāptapunarātta": ['mw'],
    "samāptapunarāttaka": ['mw'],
    "samāptapunarāttatva": ['mw'],
    "samāptaśikṣa": ['mw'],
    "samāpti": ['cae', 'mw'],
    "samāptika": ['ap90', 'cae', 'mw'],
    "samāptisādhana": ['mw'],
    "samāptivāda": ['mw'],
    "samāptiḥ": ['ap90'],
    "samāptyarthā": ['mw'],
    "samāptāla": ['mw'],
    "samāptālaḥ": ['ap90'],
    "samāpya": ['cae', 'mw'],
    "samāpyai": ['mw'],
    "samāpyāyita": ['mw'],
    "samāpā": ['mw'],
    "samāpādana": ['mw'],
    "samāpādanaṃ": ['ap90'],
    "samāpādanīya": ['mw'],
    "samāpādya": ['mw'],
    "samāpādyaṃ": ['ap90'],
    "samāpīḍayati": ['bhs'],
    "samāpū": ['mw'],
    "samāpūrṇa": ['mw'],
    "samāpṝ": ['mw'],
    "samārabdha": ['mw'],
    "samārabdhatara": ['mw'],
    "samārabh": ['ap90', 'mw'],
    "samārabhati": ['cped'],
    "samārabhi": ['cped'],
    "samārabhitvā": ['cped'],
    "samārabhya": ['mw'],
    "samāraddha": ['cped'],
    "samāraka": ['cped', 'mw'],
    "samārambha": ['cae', 'cped', 'mw'],
    "samārambhaṇa": ['cae', 'mw'],
    "samārambhin": ['mw'],
    "samārata": ['mw'],
    "samāraṃbhaḥ": ['ap90'],
    "samārbuda": ['mw'],
    "samārdava": ['ddsa', 'mw'],
    "samārdhaga": ['mw'],
    "samārgaṇa": ['mw'],
    "samārgaṇaguṇa": ['mw'],
    "samārjana": ['bhs'],
    "samārjayati": ['bhs'],
    "samāroha": ['mw'],
    "samārohaḥ": ['ap90'],
    "samārohaṇa": ['cae', 'mw'],
    "samārohaṇīyā": ['mw'],
    "samāropa": ['cae', 'mw'],
    "samāropaka": ['bhs', 'mw'],
    "samāropana": ['cped'],
    "samāropaṇa": ['mw'],
    "samāropaṇaṃ": ['ap90'],
    "samāropesi": ['cped'],
    "samāropeti": ['cped'],
    "samāropetvā": ['cped'],
    "samāropita": ['ap90', 'cped', 'mw'],
    "samāropitabhāra": ['mw'],
    "samāropitakārmuka": ['mw'],
    "samāropitavikrama": ['mw'],
    "samārtha": ['mw'],
    "samārthaka": ['cae', 'ddsa', 'mw'],
    "samārthin": ['mw'],
    "samārudh": ['mw'],
    "samāruh": ['ap90', 'mw'],
    "samāruhana": ['cped'],
    "samāruhati": ['cped'],
    "samāruhi": ['cped'],
    "samāruhitvā": ['cped'],
    "samārurukṣu": ['cae', 'mw'],
    "samāruyha": ['cped'],
    "samārādh": ['mw'],
    "samārādhana": ['cae', 'ddsa', 'mw'],
    "samārādhanaṃ": ['ap90'],
    "samārāṇa": ['ddsa', 'mw'],
    "samārūḍha": ['cae', 'mw'],
    "samārūḷha": ['cped'],
    "samārṣa": ['cae', 'mw'],
    "samās": ['mw'],
    "samāsa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "samāsabaddhamanoramā": ['mw'],
    "samāsabahula": ['mw'],
    "samāsabhāvanā": ['mw'],
    "samāsacakra": ['mw'],
    "samāsacandrikā": ['mw'],
    "samāsacūḍāmaṇi": ['mw'],
    "samāsad": ['ap90', 'mw'],
    "samāsakta": ['ap90', 'cae', 'mw'],
    "samāsakti": ['mw'],
    "samāsaktiḥ": ['ap90'],
    "samāsama": ['ddsa', 'mw'],
    "samāsamañjarī": ['mw'],
    "samāsana": ['mw'],
    "samāsanna": ['cae', 'mw'],
    "samāsapaṭala": ['mw'],
    "samāsaprakaraṇa": ['mw'],
    "samāsaprāya": ['mw'],
    "samāsapāda": ['mw'],
    "samāsarjana": ['mw'],
    "samāsarjanaṃ": ['ap90'],
    "samāsasaṃgraha": ['mw'],
    "samāsasaṃhitā": ['mw'],
    "samāsasaṃjña": ['mw'],
    "samāsatas": ['mw'],
    "samāsatattvanirūpaṇa": ['mw'],
    "samāsatti": ['mw'],
    "samāsavat": ['mw'],
    "samāsavidhi": ['mw'],
    "samāsavyāsayogatas": ['mw'],
    "samāsavāda": ['mw'],
    "samāsavādasāra": ['mw'],
    "samāsañj": ['mw'],
    "samāsañjana": ['mw'],
    "samāsaśikṣā": ['mw'],
    "samāsaśobhā": ['mw'],
    "samāsaḥ": ['ap90'],
    "samāsaṃj": ['ap90'],
    "samāsaṃjanaṃ": ['ap90'],
    "samāsaṅga": ['mw'],
    "samāsecana": ['mw'],
    "samāseka": ['mw'],
    "samāsesi": ['cped'],
    "samāseti": ['cped'],
    "samāsetvā": ['cped'],
    "samāsev": ['mw'],
    "samāsevana": ['mw'],
    "samāsevita": ['mw'],
    "samāsic": ['mw'],
    "samāsin": ['mw'],
    "samāsita": ['cped', 'mw'],
    "samāskand": ['mw'],
    "samāskanna": ['mw'],
    "samāsokta": ['ddsa', 'mw'],
    "samāsokti": ['cae', 'mw'],
    "samāstha": ['mw'],
    "samāsthita": ['cae', 'mw'],
    "samāsthā": ['mw'],
    "samāstṛ": ['mw'],
    "samāsvad": ['mw'],
    "samāsyā": ['cae', 'mw'],
    "samāsādana": ['mw'],
    "samāsādanaṃ": ['ap90'],
    "samāsādhyāhāra": ['mw'],
    "samāsādita": ['mw'],
    "samāsādya": ['cae', 'mw'],
    "samāsānta": ['cae', 'ddsa', 'mw'],
    "samāsārdha": ['ddsa', 'mw'],
    "samāsārtha": ['mw'],
    "samāsārthaprakāśikā": ['mw'],
    "samāsārthā": ['mw'],
    "samāsārṇava": ['mw'],
    "samāsāvali": ['mw'],
    "samāsāṅga": ['mw'],
    "samāsīna": ['mw'],
    "samāsṛj": ['mw'],
    "samāsṛṣṭa": ['mw'],
    "samātan": ['mw'],
    "samātata": ['mw'],
    "samāti": ['gra', 'mw'],
    "samātmaka": ['mw'],
    "samātman": ['mw'],
    "samātta": ['bhs'],
    "samātīta": ['mw'],
    "samātṛ": ['mw'],
    "samātṛcakravāla": ['mw'],
    "samātṛka": ['mw'],
    "samāvac": ['mw'],
    "samāvacchas": ['cae', 'mw'],
    "samāvad": ['mw'],
    "samāvadbhāj": ['mw'],
    "samāvadindriya": ['mw'],
    "samāvadvīrya": ['cae', 'mw'],
    "samāvah": ['mw'],
    "samāvaha": ['cae', 'mw'],
    "samāvahanta": ['cped'],
    "samāvahati": ['cped'],
    "samāvahi": ['cped'],
    "samāvaj": ['mw'],
    "samāvajjāmī": ['ddsa', 'mw'],
    "samāvalokya": ['mw'],
    "samāvant": ['cae'],
    "samāvap": ['mw'],
    "samāvarjana": ['mw'],
    "samāvarjita": ['mw'],
    "samāvarjitaketu": ['mw'],
    "samāvarjitanetraśobha": ['mw'],
    "samāvarta": ['cae', 'mw'],
    "samāvartamāna": ['mw'],
    "samāvartana": ['ddsa', 'mw'],
    "samāvartanakarman": ['mw'],
    "samāvartanaprayoga": ['mw'],
    "samāvartanavidhi": ['mw'],
    "samāvartanaṃ": ['ap90'],
    "samāvartanādiprayoga": ['mw'],
    "samāvartanīya": ['mw'],
    "samāvartayati": ['bhs'],
    "samāvartin": ['mw'],
    "samāvas": ['ap90', 'mw'],
    "samāvat": ['ddsa', 'mw'],
    "samāve": ['mw'],
    "samāvedya": ['mw'],
    "samāveśa": ['cae', 'mw'],
    "samāveśana": ['cae', 'mw'],
    "samāveśaḥ": ['ap90'],
    "samāveśita": ['mw'],
    "samāveṣṭ": ['mw'],
    "samāvid": ['mw'],
    "samāviddha": ['mw'],
    "samāvigna": ['cae', 'mw'],
    "samāvikarta": ['mw'],
    "samāviś": ['ap90', 'mw'],
    "samāviṣṭa": ['ap90', 'cae', 'mw'],
    "samāvraj": ['mw'],
    "samāvyadh": ['mw'],
    "samāvāpa": ['cae', 'mw'],
    "samāvāpti": ['mw'],
    "samāvāsa": ['mw'],
    "samāvāsaḥ": ['ap90'],
    "samāvāsita": ['mw'],
    "samāvāsitakaṭaka": ['mw'],
    "samāvāya": ['cae', 'mw'],
    "samāvāyaḥ": ['ap90'],
    "samāvṛ": ['ap90', 'mw'],
    "samāvṛj": ['mw'],
    "samāvṛt": ['ap90', 'mw'],
    "samāvṛta": ['ap90', 'mw'],
    "samāvṛtta": ['cae', 'mw'],
    "samāvṛttaka": ['mw'],
    "samāvṛttavrata": ['mw'],
    "samāvṛttaḥ": ['ap90'],
    "samāvṛtti": ['mw'],
    "samāvṛttika": ['mw'],
    "samāvṛttiḥ": ['ap90'],
    "samāya": ['bhs', 'mw'],
    "samāyam": ['mw'],
    "samāyasta": ['mw'],
    "samāyata": ['ap90', 'mw'],
    "samāyatta": ['cae', 'mw'],
    "samāyaḥ": ['ap90'],
    "samāyin": ['mw'],
    "samāyoga": ['cae', 'cped', 'mw'],
    "samāyogaḥ": ['ap90'],
    "samāyu": ['mw'],
    "samāyuj": ['ap90', 'mw'],
    "samāyukta": ['ap90', 'cae', 'mw'],
    "samāyuta": ['ap90', 'cae', 'cped', 'mw'],
    "samāyā": ['mw'],
    "samāyāta": ['cped', 'mw'],
    "samāyāti": ['cped'],
    "samāñjana": ['mw'],
    "samāśa": ['cae', 'mw'],
    "samāśaṃs": ['mw'],
    "samāśaṅkita": ['mw'],
    "samāśir": ['cae', 'gra', 'mw'],
    "samāśleṣa": ['cae', 'mw'],
    "samāśleṣaḥ": ['ap90'],
    "samāśleṣaṇa": ['mw'],
    "samāśliṣ": ['mw'],
    "samāśliṣṭa": ['mw'],
    "samāśraya": ['cae', 'mw'],
    "samāśrayaḥ": ['ap90'],
    "samāśrayaṇa": ['mw'],
    "samāśrayaṇasampradāya": ['mw'],
    "samāśrayaṇīya": ['mw'],
    "samāśrayin": ['mw'],
    "samāśri": ['ap90', 'mw'],
    "samāśrita": ['cae', 'mw'],
    "samāśritatva": ['mw'],
    "samāśru": ['mw'],
    "samāśvas": ['ap90', 'mw'],
    "samāśvasta": ['cae', 'mw'],
    "samāśvāsa": ['cae', 'mw'],
    "samāśvāsana": ['cae', 'mw'],
    "samāśvāsanaṃ": ['ap90'],
    "samāśvāsaḥ": ['ap90'],
    "samāśvāsita": ['mw'],
    "samāśvāsya": ['mw'],
    "samāṃsa": ['cae', 'ddsa', 'mw'],
    "samāṃsamīnā": ['ap90', 'mw'],
    "samāṃśa": ['cae', 'ddsa', 'mw'],
    "samāṃśabhāgin": ['mw'],
    "samāṃśahārin": ['mw'],
    "samāṃśaka": ['cae', 'mw'],
    "samāṃśena": ['mw'],
    "samāṃśika": ['mw'],
    "samāṃśin": ['cae', 'mw'],
    "samāṃśā": ['mw'],
    "samāṅghrika": ['ddsa', 'mw'],
    "samī": ['mw'],
    "samībhāva": ['mw'],
    "samībhū": ['mw'],
    "samībhūta": ['mw'],
    "samīc": ['gra'],
    "samīca": ['mw'],
    "samīcaka": ['mw'],
    "samīcakaḥ": ['ap90'],
    "samīcaḥ": ['ap90'],
    "samīcchā": ['mw'],
    "samīcī": ['ap90', 'mw'],
    "samīcīna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "samīcīnatva": ['mw'],
    "samīcīnatā": ['mw'],
    "samīdaḥ": ['ap90'],
    "samīdā": ['mw'],
    "samīh": ['ap90', 'mw'],
    "samīhana": ['mw'],
    "samīhati": ['bhs'],
    "samīhita": ['ap90', 'cae', 'mw'],
    "samīhā": ['ap90', 'cae', 'mw'],
    "samīj": ['mw'],
    "samīka": ['cae', 'ddsa', 'gra', 'mw'],
    "samīkaraṇa": ['cae', 'ddsa', 'mw'],
    "samīkaraṇaṃ": ['ap90'],
    "samīkaronti": ['bhs'],
    "samīkaṃ": ['ap90'],
    "samīkriyā": ['mw'],
    "samīkāra": ['mw'],
    "samīkṛ": ['ap90', 'cae', 'mw'],
    "samīkṛta": ['mw'],
    "samīkṛti": ['mw'],
    "samīkṣ": ['ap90', 'mw'],
    "samīkṣa": ['mw'],
    "samīkṣam": ['bhs'],
    "samīkṣaḥ": ['ap90'],
    "samīkṣaṇa": ['cae', 'mw'],
    "samīkṣaṇaṃ": ['ap90'],
    "samīkṣita": ['mw'],
    "samīkṣitavadana": ['bhs'],
    "samīkṣitavya": ['cae', 'mw'],
    "samīkṣitārtha": ['bhs'],
    "samīkṣya": ['cae', 'mw'],
    "samīkṣyakārin": ['ap90', 'bhs'],
    "samīkṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "samīna": ['ap90', 'mw'],
    "samīnikā": ['ap90', 'mw'],
    "samīpa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "samīpabhāj": ['mw'],
    "samīpacārī": ['cped'],
    "samīpadeśa": ['cae', 'mw'],
    "samīpaga": ['cae', 'cped', 'mw'],
    "samīpagamana": ['mw'],
    "samīpaja": ['cae', 'mw'],
    "samīpajala": ['mw'],
    "samīpaka": ['mw'],
    "samīpakāla": ['mw'],
    "samīpamaraṇacihna": ['mw'],
    "samīpanayana": ['mw'],
    "samīpasahakāra": ['mw'],
    "samīpasaptamī": ['mw'],
    "samīpastha": ['cae', 'mw'],
    "samīpasthāna": ['mw'],
    "samīpatara": ['mw'],
    "samīpataravartin": ['mw'],
    "samīpatas": ['mw'],
    "samīpatva": ['mw'],
    "samīpatā": ['mw'],
    "samīpavartin": ['cae', 'mw'],
    "samīpaṭṭha": ['cped'],
    "samīpopagata": ['mw'],
    "samīpsita": ['mw'],
    "samīpāvasita": ['mw'],
    "samīpī": ['mw'],
    "samīpībhū": ['mw'],
    "samīpīkṛ": ['mw'],
    "samīr": ['ap90', 'mw'],
    "samīra": ['cae', 'ddsa', 'mw'],
    "samīragajakesarin": ['mw'],
    "samīralakṣman": ['mw'],
    "samīrasāra": ['mw'],
    "samīrati": ['cped'],
    "samīraḥ": ['ap90'],
    "samīraṇa": ['cae', 'cped', 'mw'],
    "samīraṇasahāya": ['mw'],
    "samīraṇaḥ": ['ap90'],
    "samīresi": ['cped'],
    "samīreti": ['cped'],
    "samīretvā": ['cped'],
    "samīrita": ['cped', 'mw'],
    "samīrṇa": ['mw'],
    "samīya": ['ddsa', 'mw'],
    "samīyate": ['ap90'],
    "samīḍ": ['mw'],
    "samīṣ": ['mw'],
    "samīṣantī": ['mw'],
    "samīṣita": ['cae', 'mw'],
    "samīṭṭhāna": ['cped'],
    "samūh": ['ap90', 'mw'],
    "samūha": ['cae', 'cped', 'ddsa', 'mw'],
    "samūhagandha": ['mw'],
    "samūhaka": ['mw'],
    "samūhakārya": ['mw'],
    "samūhakṣāraka": ['mw'],
    "samūhana": ['cae', 'mw'],
    "samūhanati": ['cped'],
    "samūhanaṃ": ['ap90'],
    "samūhanī": ['ap90', 'mw'],
    "samūhata": ['bhs', 'cped'],
    "samūhati": ['bhs'],
    "samūhaḥ": ['ap90'],
    "samūhin": ['mw'],
    "samūhya": ['mw'],
    "samūhyaḥ": ['ap90'],
    "samūhā": ['mw'],
    "samūla": ['ap90', 'cae', 'ddsa', 'mw'],
    "samūlaghātam": ['mw'],
    "samūlaka": ['bhs', 'cped', 'mw'],
    "samūlakāṣam": ['cae', 'mw'],
    "samūlam": ['mw'],
    "samūra": ['mw'],
    "samūraḥ": ['ap90'],
    "samūrtaka": ['mw'],
    "samūru": ['mw'],
    "samūruka": ['mw'],
    "samūḍha": ['ap90', 'ddsa', 'mw'],
    "samūḍhacchandas": ['mw'],
    "samūḍhadvādaśāhapaddhati": ['mw'],
    "samūḍhapuṇḍarīkapaddhati": ['mw'],
    "samūḍharūpin": ['mw'],
    "samṛ": ['ap90', 'mw'],
    "samṛc": ['mw'],
    "samṛch": ['mw'],
    "samṛddha": ['ap90', 'cae', 'mw'],
    "samṛddharāṣṭra": ['bhs'],
    "samṛddhatejas": ['mw'],
    "samṛddhavega": ['mw'],
    "samṛddhayajña": ['bhs'],
    "samṛddhayaśas": ['mw'],
    "samṛddhi": ['cae', 'mw'],
    "samṛddhikaraṇa": ['mw'],
    "samṛddhikāma": ['mw'],
    "samṛddhimat": ['mw'],
    "samṛddhin": ['cae', 'mw'],
    "samṛddhisamaya": ['mw'],
    "samṛddhivat": ['mw'],
    "samṛddhivṛddhilābha": ['mw'],
    "samṛddhiḥ": ['ap90'],
    "samṛddhārtha": ['mw'],
    "samṛddhīkṛ": ['mw'],
    "samṛdh": ['ap90', 'cae', 'gra', 'mw'],
    "samṛdha": ['cae', 'gra', 'mw'],
    "samṛta": ['ddsa', 'mw'],
    "samṛtasoma": ['mw'],
    "samṛtayajña": ['mw'],
    "samṛti": ['cae', 'gra', 'mw'],
    "samṛṣ": ['mw'],
    "san": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sana": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sanad": ['mw'],
    "sanadrayi": ['cae', 'ddsa', 'gra', 'mw'],
    "sanadvāja": ['cae', 'gra', 'mw'],
    "sanadīgirikānana": ['mw'],
    "sanaga": ['cae', 'mw'],
    "sanaj": ['cae', 'ddsa', 'gra', 'mw'],
    "sanaja": ['cae', 'ddsa', 'gra', 'mw'],
    "sanajā": ['cae', 'gra', 'mw'],
    "sanaka": ['cae', 'ddsa', 'gra', 'mw'],
    "sanakasaṃhitā": ['mw'],
    "sanakaḥ": ['ap90'],
    "sanakha": ['mw'],
    "sanakānīka": ['mw'],
    "sanakāt": ['mw'],
    "sanaladānalada": ['mw'],
    "sanam": ['mw'],
    "sanana": ['cae', 'gra', 'mw'],
    "sananda": ['ddsa', 'mw'],
    "sanandaka": ['mw'],
    "sanandana": ['mw'],
    "sanandanasaṃhitā": ['mw'],
    "sanandita": ['bhs'],
    "sanandī": ['mw'],
    "sanantana": ['cped'],
    "sanaparṇī": ['mw'],
    "sanaprokta": ['mw'],
    "sanara": ['ddsa', 'gra', 'mw'],
    "sanaradvipa": ['mw'],
    "sanarmahāsa": ['mw'],
    "sanas": ['cae', 'mw'],
    "sanasaya": ['mw'],
    "sanasūtra": ['ap90'],
    "sanat": ['ap90', 'mw'],
    "sanati": ['cped'],
    "sanatkumāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "sanatkumāraja": ['mw'],
    "sanatkumārakalpa": ['mw'],
    "sanatkumārapulastyasaṃvāda": ['mw'],
    "sanatkumārasaṃhitā": ['mw'],
    "sanatkumārastava": ['mw'],
    "sanatkumāratantra": ['mw'],
    "sanatkumāropapurāṇa": ['mw'],
    "sanatkumārīya": ['mw'],
    "sanatna": ['cae'],
    "sanatra": ['mw'],
    "sanatsujāta": ['mw'],
    "sanatsujātavedānta": ['mw'],
    "sanatsujātīya": ['mw'],
    "sanatā": ['cae', 'ddsa', 'gra', 'mw'],
    "sanava": ['mw'],
    "sanavanīta": ['mw'],
    "sanavitta": ['gra', 'mw'],
    "sanaya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sanaśruta": ['ddsa', 'gra', 'mw'],
    "sanaḥ": ['ap90', 'mw'],
    "sanaḥśruta": ['mw'],
    "sanaṅgavya": ['mw'],
    "sanaṅgu": ['mw'],
    "sanda": ['cped'],
    "sandacchāya": ['cped'],
    "sandahana": ['cped'],
    "sandahati": ['cped'],
    "sandahi": ['cped'],
    "sandahita": ['cped'],
    "sandahitvā": ['cped'],
    "sandamāna": ['cped'],
    "sandana": ['cped'],
    "sandassaka": ['cped'],
    "sandassana": ['cped'],
    "sandassesi": ['cped'],
    "sandasseti": ['cped'],
    "sandassetvā": ['cped'],
    "sandassita": ['cped'],
    "sandassiyamāna": ['cped'],
    "sandati": ['cped'],
    "sandaṃśa": ['ddsa'],
    "sandeha": ['cped', 'ddsa'],
    "sandehara": ['cped'],
    "sandesa": ['cped'],
    "sandesāgāra": ['cped'],
    "sandeśa": ['ddsa'],
    "sandeśya": ['ddsa'],
    "sandhamati": ['cped'],
    "sandhami": ['cped'],
    "sandhamitvā": ['cped'],
    "sandhana": ['cped'],
    "sandhaya": ['ddsa'],
    "sandhi": ['cped', 'ddsa'],
    "sandhicchedaka": ['cped'],
    "sandhimukha": ['cped'],
    "sandhin": ['ddsa'],
    "sandhinigrahadvāreṇa": ['ddsa'],
    "sandhitsu": ['ddsa'],
    "sandhovati": ['cped'],
    "sandhukṣaṇa": ['ddsa'],
    "sandhya": ['ddsa'],
    "sandhyakṣara": ['ddsa'],
    "sandhyārāga": ['ddsa'],
    "sandhyāya": ['ddsa'],
    "sandhyāṃśa": ['ddsa'],
    "sandhā": ['ddsa'],
    "sandhāna": ['cped'],
    "sandhāraka": ['cped'],
    "sandhāraṇa": ['cped'],
    "sandhārenta": ['cped'],
    "sandhāresi": ['cped'],
    "sandhāreti": ['cped'],
    "sandhāretvā": ['cped'],
    "sandhārita": ['cped'],
    "sandhātar": ['cped'],
    "sandhāvamāna": ['cped'],
    "sandhāvanta": ['cped'],
    "sandhāvati": ['cped'],
    "sandhāvi": ['cped'],
    "sandhāvita": ['cped'],
    "sandhāvitvā": ['cped'],
    "sandhāya": ['cped'],
    "sandhīyati": ['cped'],
    "sandhīyi": ['cped'],
    "sandhīśvara": ['ddsa'],
    "sandhūpesi": ['cped'],
    "sandhūpeti": ['cped'],
    "sandhūpetvā": ['cped'],
    "sandhūpita": ['cped'],
    "sandhūpāyati": ['cped'],
    "sandhūpāyi": ['cped'],
    "sandi": ['cped'],
    "sandiddha": ['cped'],
    "sandissamāna": ['cped'],
    "sandissati": ['cped'],
    "sandita": ['cped'],
    "sanditvā": ['cped'],
    "sandiṭṭha": ['cped'],
    "sandiṭṭhika": ['cped'],
    "sandoha": ['cped', 'ddsa'],
    "sandālesi": ['cped'],
    "sandāleti": ['cped'],
    "sandāletvā": ['cped'],
    "sandālita": ['cped'],
    "sandāna": ['cped'],
    "sandī": ['mw'],
    "sandīpana": ['cped'],
    "sandīpanā": ['cped'],
    "sandīpesi": ['cped'],
    "sandīpeti": ['cped'],
    "sandīpetvā": ['cped'],
    "sandīpita": ['cped'],
    "sanemi": ['cae', 'ddsa', 'gra', 'mw'],
    "saneru": ['gra', 'mw'],
    "sani": ['cae', 'ddsa', 'gra', 'mw'],
    "sanidra": ['cae', 'ddsa', 'mw'],
    "sanigaḍacaraṇa": ['cae', 'ddsa', 'mw'],
    "sanigaḍacaraṇatva": ['mw'],
    "sanigraha": ['mw'],
    "sanikāma": ['mw'],
    "sanikāra": ['cae', 'mw'],
    "sanimant": ['cae'],
    "sanimat": ['mw'],
    "sanimeṣa": ['cae', 'mw'],
    "saninda": ['cae', 'mw'],
    "sanindam": ['mw'],
    "sanirghāta": ['mw'],
    "sanirghṛṇa": ['mw'],
    "sanirveda": ['cae', 'mw'],
    "sanirvedam": ['mw'],
    "sanirviśeṣa": ['mw'],
    "sanisrasa": ['mw'],
    "sanisrasākṣa": ['mw'],
    "sanit": ['gra'],
    "sanita": ['ap90'],
    "saniti": ['cae', 'ddsa', 'gra', 'mw'],
    "sanitra": ['cae', 'gra', 'mw'],
    "sanitur": ['cae', 'ddsa', 'gra', 'mw'],
    "sanitva": ['cae', 'mw'],
    "sanitvan": ['cae', 'gra', 'mw'],
    "sanitṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "saniyama": ['cae', 'mw'],
    "saniyamatva": ['mw'],
    "saniśvāsam": ['cae', 'mw'],
    "saniḥ": ['ap90'],
    "saniḥśvāsam": ['cae', 'mw'],
    "saniṣpeṣam": ['mw'],
    "saniṣy": ['gra'],
    "saniṣyada": ['mw'],
    "saniṣyu": ['cae', 'ddsa', 'gra', 'mw'],
    "saniṣādīka": ['mw'],
    "saniṣṭha": ['cae', 'gra', 'mw'],
    "saniṣṭhīva": ['mw'],
    "saniṣṭhīvaṃ": ['ap90'],
    "sanmantra": ['cae', 'mw'],
    "sanmati": ['mw'],
    "sanmaulika": ['mw'],
    "sanmaṅgala": ['cae', 'ddsa', 'mw'],
    "sanmaṇi": ['cae', 'mw'],
    "sanmitra": ['cae', 'mw'],
    "sanmiśrakeśava": ['mw'],
    "sanmuhūrta": ['mw'],
    "sanmuni": ['mw'],
    "sanmāna": ['mw'],
    "sanmārga": ['cae', 'mw'],
    "sanmārgamaṇidarpaṇa": ['mw'],
    "sanmārgastha": ['mw'],
    "sanmārgayodhin": ['mw'],
    "sanmārgālokana": ['mw'],
    "sanmātra": ['cae', 'mw'],
    "sanmātura": ['mw'],
    "sanmātṛ": ['mw'],
    "sanna": ['ap90', 'cae', 'ddsa', 'mw'],
    "sannabhāva": ['mw'],
    "sannabhāvatva": ['mw'],
    "sannada": ['mw'],
    "sannaddha": ['cped'],
    "sannadhī": ['mw'],
    "sannahana": ['ddsa'],
    "sannaharṣa": ['mw'],
    "sannajihva": ['mw'],
    "sannaka": ['ap90', 'mw'],
    "sannakadru": ['mw'],
    "sannakadruma": ['mw'],
    "sannakaṇṭha": ['mw'],
    "sannamaya": ['mw'],
    "sannamusala": ['ddsa', 'mw'],
    "sannamusale": ['cae', 'mw'],
    "sannanauka": ['mw'],
    "sannata": ['ddsa'],
    "sannatara": ['ap90', 'mw'],
    "sannavāc": ['mw'],
    "sannayha": ['cped'],
    "sannayhati": ['cped'],
    "sannayhi": ['cped'],
    "sannayhitvā": ['cped'],
    "sannaśarīra": ['mw'],
    "sannesi": ['cped'],
    "sanneti": ['cped'],
    "sannetvā": ['cped'],
    "sanni": ['cae', 'mw'],
    "sannibha": ['cped'],
    "sannicaya": ['cped'],
    "sannicita": ['cped'],
    "sannidhi": ['cped'],
    "sannidhikata": ['cped'],
    "sannidhikāraka": ['cped'],
    "sannidhāna": ['cped'],
    "sannihita": ['cped'],
    "sannikaṭṭha": ['cped'],
    "sannikāsa": ['cped'],
    "sannimat": ['mw'],
    "sannimitta": ['ddsa', 'mw'],
    "sannimittam": ['mw'],
    "sannimitte": ['mw'],
    "sannipatana": ['cped'],
    "sannipatanta": ['cped'],
    "sannipatati": ['cped'],
    "sannipati": ['cped'],
    "sannipatita": ['cped'],
    "sannipatitvā": ['cped'],
    "sannipāta": ['cped'],
    "sannipātana": ['cped'],
    "sannipātesi": ['cped'],
    "sannipāteti": ['cped'],
    "sannipātetvā": ['cped'],
    "sannipātika": ['cped'],
    "sannipātita": ['cped'],
    "sannirumbhana": ['cped'],
    "sannirumbhesi": ['cped'],
    "sannirumbheti": ['cped'],
    "sannirumbhetvā": ['cped'],
    "sannirumbhita": ['cped'],
    "sannisarga": ['mw'],
    "sannisinna": ['cped'],
    "sannissita": ['cped'],
    "sannisīdati": ['cped'],
    "sannisīdi": ['cped'],
    "sannisīditvā": ['cped'],
    "sannita": ['cped'],
    "sannivasati": ['cped'],
    "sannivasi": ['cped'],
    "sannivesa": ['cped'],
    "sannivāresi": ['cped'],
    "sannivāreti": ['cped'],
    "sannivāretvā": ['cped'],
    "sannivāsa": ['cped', 'mw'],
    "sanniyacchana": ['ddsa'],
    "sanniyyātana": ['cped'],
    "sanniṭṭhāna": ['cped'],
    "sannyasana": ['ddsa'],
    "sannāha": ['cped'],
    "sannāman": ['mw'],
    "sannīkṛ": ['cae', 'ddsa'],
    "sannīkṛta": ['mw'],
    "sannīyate": ['bhs'],
    "sano": ['mw'],
    "sanojā": ['cae', 'gra', 'mw'],
    "sant": ['cae'],
    "santa": ['bhs', 'cped', 'mw'],
    "santabhāva": ['cped'],
    "santajjayamāna": ['cped'],
    "santajjenta": ['cped'],
    "santajjesi": ['cped'],
    "santajjeti": ['cped'],
    "santajjetvā": ['cped'],
    "santajjita": ['cped'],
    "santaka": ['bhs', 'cped', 'mw'],
    "santakāya": ['cped'],
    "santakṣaṇa": ['ddsa'],
    "santamānasa": ['cped'],
    "santappamāna": ['cped'],
    "santappati": ['cped'],
    "santappenta": ['cped'],
    "santappesi": ['cped'],
    "santappeti": ['cped'],
    "santappetvā": ['cped'],
    "santappi": ['cped'],
    "santappita": ['cped'],
    "santappiya": ['cped'],
    "santarabāhira": ['cped'],
    "santarabāhiraṁ": ['cped'],
    "santaramāna": ['cped'],
    "santarati": ['cped'],
    "santari": ['cped'],
    "santasana": ['cped'],
    "santasanta": ['cped'],
    "santasati": ['cped'],
    "santasi": ['cped'],
    "santasita": ['cped'],
    "santasitvā": ['cped'],
    "santatara": ['cped'],
    "santataṁ": ['cped'],
    "santati": ['cped'],
    "santatta": ['cped'],
    "santevāsika": ['cped'],
    "santhambhesi": ['cped'],
    "santhambheti": ['cped'],
    "santhambhetvā": ['cped'],
    "santhambhita": ['cped'],
    "santhara": ['cped'],
    "santharati": ['cped'],
    "santharaṇa": ['cped'],
    "santhari": ['cped'],
    "santharitvā": ['cped'],
    "santharāpeti": ['cped'],
    "santhata": ['cped'],
    "santhava": ['cped'],
    "santhāgāra": ['cped'],
    "santhāra": ['cped'],
    "santi": ['cped', 'mw'],
    "santika": ['bhs', 'cped'],
    "santikamma": ['cped'],
    "santike": ['bhs'],
    "santikā": ['cped'],
    "santikāvacara": ['cped'],
    "santipada": ['cped'],
    "santiṭṭhati": ['cped'],
    "santosa": ['cped'],
    "santoṣa": ['ddsa'],
    "santusita": ['cped'],
    "santussaka": ['cped'],
    "santussamāna": ['cped'],
    "santussana": ['cped'],
    "santussati": ['cped'],
    "santussi": ['cped'],
    "santuṣṭa": ['ddsa'],
    "santuṭṭha": ['cped'],
    "santuṭṭhatā": ['cped'],
    "santuṭṭhi": ['cped'],
    "santya": ['cae', 'ddsa', 'gra', 'mw'],
    "santyajya": ['ddsa'],
    "santāna": ['cped', 'ddsa'],
    "santāneti": ['cped'],
    "santāpa": ['cped'],
    "santāpesi": ['cped'],
    "santāpeti": ['cped'],
    "santāpetvā": ['cped'],
    "santāpita": ['cped'],
    "santāsa": ['cped'],
    "santāsī": ['cped'],
    "santīraṇa": ['cped'],
    "sanucara": ['cped'],
    "sanucārika": ['cped'],
    "sanutar": ['cae', 'ddsa', 'gra', 'mw'],
    "sanutara": ['cae', 'gra', 'mw'],
    "sanutrī": ['cae'],
    "sanutya": ['cae', 'gra', 'mw'],
    "sanutṛ": ['ddsa', 'gra', 'mw'],
    "sanyas": ['ddsa', 'gra', 'mw'],
    "sanyaṃs": ['cae'],
    "sanā": ['ap90', 'ddsa', 'gra', 'mw'],
    "sanābha": ['mw'],
    "sanābhi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sanābhika": ['cped'],
    "sanābhya": ['cae', 'mw'],
    "sanābhyaḥ": ['ap90'],
    "sanājur": ['cae', 'gra', 'mw'],
    "sanājū": ['gra', 'mw'],
    "sanākavanita": ['mw'],
    "sanāla": ['cae', 'mw'],
    "sanāliṅga": ['mw'],
    "sanālī": ['mw'],
    "sanāma": ['cae', 'mw'],
    "sanāmagrāha": ['mw'],
    "sanāmaka": ['mw'],
    "sanāman": ['ap90', 'cae', 'gra', 'mw'],
    "sanāru": ['cae', 'mw'],
    "sanārāśaṃsa": ['mw'],
    "sanāt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sanātana": ['ap90', 'cae', 'ddsa', 'mw'],
    "sanātanasiddhānta": ['mw'],
    "sanātanatama": ['mw'],
    "sanātanī": ['mw'],
    "sanātha": ['ap90', 'cae', 'ddsa', 'mw'],
    "sanāthatā": ['cae', 'mw'],
    "sanāthīkṛ": ['cae', 'mw'],
    "sanāy": ['gra'],
    "sanāya": ['mw'],
    "sanāyu": ['cae', 'gra', 'mw'],
    "sanī": ['ap90', 'mw'],
    "sanīhāra": ['mw'],
    "sanīla": ['ap90'],
    "sanīsrasa": ['mw'],
    "sanīyas": ['mw'],
    "sanīyaṃs": ['cae'],
    "sanīḍa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sanīḍe": ['mw'],
    "sanūdaparvata": ['mw'],
    "sanūpura": ['cae', 'mw'],
    "sap": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sapa": ['cae', 'ddsa', 'mw'],
    "sapadi": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sapadma": ['cae', 'mw'],
    "sapadmaka": ['cae', 'mw'],
    "sapadāna": ['cped'],
    "sapadānacārikā": ['cped'],
    "sapadānaṁ": ['cped'],
    "sapajāpatika": ['cped'],
    "sapakṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "sapakṣaka": ['mw'],
    "sapakṣapātam": ['mw'],
    "sapakṣatva": ['mw'],
    "sapakṣatā": ['mw'],
    "sapallava": ['mw'],
    "sapalāśa": ['cae', 'mw'],
    "sapannaga": ['mw'],
    "sapara": ['mw'],
    "saparia": ['gra'],
    "saparibādha": ['cae', 'mw'],
    "saparibṛṃhaṇa": ['cae', 'mw'],
    "saparicchada": ['cae', 'mw'],
    "sapariggaha": ['cped'],
    "saparihāram": ['cae', 'mw'],
    "saparihāsa": ['mw'],
    "saparijana": ['cae', 'mw'],
    "saparikara": ['mw'],
    "saparikrama": ['cae', 'mw'],
    "saparitoṣa": ['mw'],
    "saparitoṣam": ['cae', 'mw'],
    "saparivyaya": ['cae', 'mw'],
    "saparivāha": ['cae', 'mw'],
    "saparivāra": ['mw'],
    "sapariśeṣa": ['mw'],
    "sapariśraya": ['mw'],
    "sapariśritkam": ['mw'],
    "sapariṣatka": ['cae', 'mw'],
    "saparvata": ['mw'],
    "saparvatavanadruma": ['mw'],
    "saparvatavanārṇava": ['mw'],
    "sapary": ['cae', 'gra'],
    "saparya": ['ddsa', 'gra', 'mw'],
    "saparyeṇya": ['cae', 'gra', 'mw'],
    "saparyu": ['cae', 'gra', 'mw'],
    "saparyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "saparyāsaptaka": ['mw'],
    "saparyāsāra": ['mw'],
    "saparyāṇa": ['cae', 'ddsa', 'mw'],
    "saparākrama": ['mw'],
    "saparṇa": ['mw'],
    "saparṣatka": ['mw'],
    "sapatha": ['cped'],
    "sapati": ['bhs', 'cped'],
    "sapatna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sapatnabalasūdana": ['mw'],
    "sapatnacātana": ['mw'],
    "sapatnadambhana": ['mw'],
    "sapatnadūṣaṇa": ['mw'],
    "sapatnaghn": ['gra'],
    "sapatnaghnī": ['mw'],
    "sapatnahan": ['cae', 'gra', 'mw'],
    "sapatnaja": ['mw'],
    "sapatnajit": ['cae', 'mw'],
    "sapatnakarśana": ['mw'],
    "sapatnakṣayaṇa": ['cae', 'mw'],
    "sapatnakṣit": ['mw'],
    "sapatnanāśa": ['mw'],
    "sapatnasāda": ['mw'],
    "sapatnasāha": ['cae', 'mw'],
    "sapatnatur": ['cae', 'mw'],
    "sapatnatva": ['mw'],
    "sapatnatā": ['mw'],
    "sapatnavṛddhi": ['mw'],
    "sapatnaśrī": ['mw'],
    "sapatnya": ['mw'],
    "sapatnāri": ['mw'],
    "sapatnī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sapatnībādhana": ['mw'],
    "sapatnīduhitṛ": ['mw'],
    "sapatnījana": ['cae', 'mw'],
    "sapatnīka": ['ap90', 'cae', 'mw'],
    "sapatnīkṛta": ['mw'],
    "sapatnīputra": ['mw'],
    "sapatnīspardhā": ['mw'],
    "sapatnītas": ['mw'],
    "sapatnītva": ['mw'],
    "sapatnīśa": ['mw'],
    "sapatrākaraṇaṃ": ['ap90'],
    "sapatrākṛ": ['ap90'],
    "sapatrākṛtiḥ": ['ap90'],
    "sapatta": ['cped'],
    "sapattabhāra": ['cped'],
    "sapattana": ['mw'],
    "sapattra": ['cae', 'mw'],
    "sapattraka": ['mw'],
    "sapattralekha": ['mw'],
    "sapattrita": ['mw'],
    "sapattrā": ['mw'],
    "sapattrākaraṇa": ['mw'],
    "sapattrākṛ": ['mw'],
    "sapattrākṛta": ['mw'],
    "sapattrākṛti": ['mw'],
    "sapattī": ['cped'],
    "sapatāka": ['mw'],
    "sapaura": ['mw'],
    "sapauṣṇamaitra": ['mw'],
    "sapavitra": ['cae', 'mw'],
    "sapavitraka": ['mw'],
    "sapavitratā": ['mw'],
    "sapaśu": ['cae', 'mw'],
    "sapaṅkaja": ['cae', 'mw'],
    "sapaṇa": ['mw'],
    "sapaṭaham": ['mw'],
    "sapaṭṭī": ['mw'],
    "sapekha": ['cped'],
    "sapekkha": ['cped'],
    "sapha": ['cae', 'mw'],
    "saphala": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "saphalaka": ['mw'],
    "saphalaprārthana": ['mw'],
    "saphalatva": ['mw'],
    "saphalay": ['cae'],
    "saphalaya": ['mw'],
    "saphalodarka": ['cae', 'mw'],
    "saphalodaya": ['mw'],
    "saphalī": ['mw'],
    "saphalībhū": ['mw'],
    "saphalībhūta": ['mw'],
    "saphalīkaraṇa": ['mw'],
    "saphalīkṛ": ['cae', 'mw'],
    "saphalīkṛta": ['mw'],
    "saphara": ['mw'],
    "sapharaḥ": ['ap90'],
    "sapharī": ['cped'],
    "saphatva": ['mw'],
    "saphena": ['cae', 'mw'],
    "saphenapuñja": ['mw'],
    "sapi": ['cped'],
    "sapidhāna": ['mw'],
    "sapin": ['mw'],
    "sapita": ['cped'],
    "sapitva": ['cae', 'gra', 'mw'],
    "sapitvā": ['cped'],
    "sapitṛka": ['cae', 'mw'],
    "sapitṛrājanya": ['mw'],
    "sapiśāca": ['mw'],
    "sapiṃḍaḥ": ['ap90'],
    "sapiṃḍīkaraṇaṃ": ['ap90'],
    "sapiṇḍa": ['cae', 'mw'],
    "sapiṇḍana": ['cae', 'mw'],
    "sapiṇḍanaprayoga": ['mw'],
    "sapiṇḍanirṇaya": ['mw'],
    "sapiṇḍatā": ['mw'],
    "sapiṇḍaya": ['mw'],
    "sapiṇḍī": ['mw'],
    "sapiṇḍīkaraṇa": ['cae', 'mw'],
    "sapiṇḍīkaraṇakhaṇḍana": ['mw'],
    "sapiṇḍīkaraṇāntakarman": ['mw'],
    "sapiṇḍīkaraṇānvaṣṭakā": ['mw'],
    "sapiṇḍīkramaṇa": ['mw'],
    "sapiṇḍīkṛ": ['mw'],
    "sapiṇḍīkṛta": ['mw'],
    "sapota": ['mw'],
    "sappa": ['cped'],
    "sappaccaya": ['cped'],
    "sappana": ['cped'],
    "sappati": ['cped'],
    "sappañña": ['cped'],
    "sappaṭigha": ['cped'],
    "sappi": ['cped'],
    "sappinī": ['cped'],
    "sappotaka": ['cped'],
    "sappurisa": ['cped'],
    "sappāya": ['cped'],
    "sappāyatā": ['cped'],
    "sappāṇaka": ['cped'],
    "sappāṭihīrakata": ['cped'],
    "sappītika": ['cped'],
    "saprabha": ['bhs', 'cae', 'mw'],
    "saprabhatva": ['mw'],
    "saprabhāva": ['cae', 'mw'],
    "saprabhṛti": ['mw'],
    "sapragātha": ['mw'],
    "saprahāsam": ['cae', 'mw'],
    "sapraiṣa": ['mw'],
    "sapraja": ['cae', 'mw'],
    "saprajas": ['cae', 'mw'],
    "saprajña": ['cae', 'mw'],
    "saprajāpatika": ['mw'],
    "saprakāraka": ['ddsa', 'mw'],
    "saprakṛtika": ['mw'],
    "sapramodam": ['cae', 'mw'],
    "sapramodanam": ['cae', 'mw'],
    "sapramāda": ['mw'],
    "sapramāṇa": ['mw'],
    "saprapañca": ['mw'],
    "saprasava": ['ap90', 'cae', 'mw'],
    "saprasavatva": ['mw'],
    "saprastāra": ['mw'],
    "saprasveda": ['mw'],
    "saprasāda": ['mw'],
    "saprasādam": ['mw'],
    "saprasādarādhākṛṣṇapratiṣṭhāvidhi": ['mw'],
    "sapratha": ['mw'],
    "saprathas": ['cae', 'gra', 'mw'],
    "saprathastama": ['mw'],
    "sapratibandha": ['cae', 'mw'],
    "sapratibha": ['mw'],
    "sapratibhaya": ['mw'],
    "sapratibhayatā": ['mw'],
    "sapratigha": ['mw'],
    "sapratipādana": ['mw'],
    "saprativāpa": ['mw'],
    "sapratiṣṭha": ['mw'],
    "sapratoda": ['mw'],
    "sapratyabhijñam": ['cae', 'mw'],
    "sapratyaya": ['ap90', 'cae', 'mw'],
    "sapratyayaka": ['mw'],
    "sapratyādhāna": ['cae', 'mw'],
    "sapratyāśam": ['cae', 'mw'],
    "sapratīkāśa": ['mw'],
    "sapratīkṣam": ['mw'],
    "sapratīśa": ['bhs', 'mw'],
    "sapravargya": ['mw'],
    "sapravāda": ['mw'],
    "saprayoganivartana": ['mw'],
    "saprayogarahasya": ['mw'],
    "sapraśrayam": ['cae', 'mw'],
    "sapraśrayaṃ": ['ap90'],
    "sapraṇava": ['cae', 'mw'],
    "sapraṇaya": ['ap90', 'cae', 'mw'],
    "sapraṇayam": ['mw'],
    "sapraṇāmam": ['cae', 'mw'],
    "saprema": ['bhs', 'mw'],
    "sapreman": ['mw'],
    "sapreṣya": ['mw'],
    "sapru": ['mw'],
    "saprāya": ['mw'],
    "saprāṇa": ['cae', 'mw'],
    "sapsara": ['cae', 'gra', 'mw'],
    "sapta": ['gra', 'mw'],
    "saptaaśva": ['gra'],
    "saptabhadra": ['mw'],
    "saptabhauma": ['cae', 'mw'],
    "saptabhaṅgan": ['mw'],
    "saptabhaṅginaya": ['mw'],
    "saptabhaṅgīnaya": ['mw'],
    "saptabhaṅgītaraṃgiṇī": ['mw'],
    "saptabhuvana": ['mw'],
    "saptabhūma": ['mw'],
    "saptabhūmi": ['cae', 'mw'],
    "saptabhūmika": ['mw'],
    "saptabhūmikāvicāra": ['mw'],
    "saptabhūmimaya": ['mw'],
    "saptabodhyaṅgakusumāḍhya": ['mw'],
    "saptabuddhastotra": ['mw'],
    "saptabudhna": ['cae', 'gra', 'mw'],
    "saptabāhya": ['mw'],
    "saptacakra": ['cae', 'gra', 'mw'],
    "saptacaru": ['mw'],
    "saptacatvāriṃśa": ['mw'],
    "saptacatvāriṃśat": ['cae', 'mw'],
    "saptacchada": ['cae', 'mw'],
    "saptacchadā": ['mw'],
    "saptacchandas": ['mw'],
    "saptacchidra": ['cae', 'mw'],
    "saptacitika": ['mw'],
    "saptadaśa": ['cae', 'mw'],
    "saptadaśacchadi": ['mw'],
    "saptadaśadhā": ['cae', 'mw'],
    "saptadaśaka": ['mw'],
    "saptadaśama": ['mw'],
    "saptadaśan": ['cae', 'mw'],
    "saptadaśarca": ['mw'],
    "saptadaśarātra": ['mw'],
    "saptadaśastoma": ['mw'],
    "saptadaśasāmidhenīka": ['mw'],
    "saptadaśatā": ['mw'],
    "saptadaśavartani": ['mw'],
    "saptadaśavat": ['mw'],
    "saptadaśavidha": ['mw'],
    "saptadaśaśarāva": ['mw'],
    "saptadaśin": ['mw'],
    "saptadaśābhikḷpta": ['mw'],
    "saptadaśākṣara": ['mw'],
    "saptadaśāra": ['mw'],
    "saptadaśāratni": ['mw'],
    "saptadaśāratnitā": ['mw'],
    "saptadhā": ['ap90', 'cae', 'mw'],
    "saptadhānya": ['mw'],
    "saptadhānyamaya": ['mw'],
    "saptadhāra": ['mw'],
    "saptadhārātīrtha": ['mw'],
    "saptadhātu": ['cae', 'gra', 'mw'],
    "saptadhātuka": ['mw'],
    "saptadhātumaya": ['mw'],
    "saptadhātuvarūthaka": ['mw'],
    "saptadina": ['mw'],
    "saptadivasa": ['mw'],
    "saptadvārāvakīrṇa": ['cae', 'mw'],
    "saptadvīpa": ['cae', 'mw'],
    "saptadvīpadharāpati": ['mw'],
    "saptadvīpapati": ['mw'],
    "saptadvīpavant": ['cae'],
    "saptadvīpavat": ['mw'],
    "saptadvīpavatī": ['mw'],
    "saptadvīpavatīpati": ['mw'],
    "saptadvīpā": ['mw'],
    "saptadīdhiti": ['mw'],
    "saptagaṅga": ['mw'],
    "saptagaṅgam": ['mw'],
    "saptagaṇa": ['cae', 'mw'],
    "saptagodāvara": ['mw'],
    "saptagodāvaram": ['mw'],
    "saptagodāvarī": ['mw'],
    "saptagrahī": ['mw'],
    "saptagranthanibarhaṇaśaivavaiṣṇavavicāra": ['mw'],
    "saptagranthī": ['mw'],
    "saptagu": ['cae', 'gra', 'mw'],
    "saptaguṇa": ['cae', 'mw'],
    "saptagṛdhra": ['mw'],
    "saptaha": ['mw'],
    "saptahan": ['cae', 'gra', 'mw'],
    "saptahasta": ['mw'],
    "saptahautra": ['mw'],
    "saptahautraprayoga": ['mw'],
    "saptahautrasūcī": ['mw'],
    "saptahaya": ['mw'],
    "saptahotṛ": ['cae', 'gra', 'mw'],
    "saptajana": ['mw'],
    "saptajihva": ['cae', 'gra', 'mw'],
    "saptajihvānana": ['cae'],
    "saptajvāla": ['mw'],
    "saptajāmi": ['gra', 'mw'],
    "saptajāni": ['mw'],
    "saptaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "saptakapāla": ['mw'],
    "saptakarṇa": ['mw'],
    "saptakathāmaya": ['mw'],
    "saptakoṇa": ['mw'],
    "saptakumārikāvadāna": ['mw'],
    "saptakuṭīraka": ['bhs'],
    "saptakī": ['ap90', 'mw'],
    "saptakṛd": ['bhs'],
    "saptakṛdbhavaparama": ['mw'],
    "saptakṛt": ['mw'],
    "saptakṛtvas": ['cae', 'mw'],
    "saptala": ['mw'],
    "saptalakṣaṇa": ['mw'],
    "saptalakṣaṇabhāṣya": ['mw'],
    "saptalakṣaṇamaya": ['mw'],
    "saptalikā": ['mw'],
    "saptaloka": ['mw'],
    "saptalokamaya": ['mw'],
    "saptalokī": ['ddsa', 'mw'],
    "saptalā": ['ap90', 'ddsa', 'mw'],
    "saptama": ['ap90', 'cae', 'ddsa', 'mw'],
    "saptamahābhāga": ['mw'],
    "saptamaithunasaṃyuktasūtra": ['bhs'],
    "saptamaka": ['mw'],
    "saptamakalā": ['mw'],
    "saptamantra": ['mw'],
    "saptamarīci": ['mw'],
    "saptamaṅgalamāhātmya": ['mw'],
    "saptamaṭhāmnāyadaśanāmābhidhāna": ['mw'],
    "saptamaṭhāmnāyika": ['mw'],
    "saptamuñja": ['mw'],
    "saptamuṣṭika": ['mw'],
    "saptamyarkavrata": ['mw'],
    "saptamānuṣa": ['gra', 'mw'],
    "saptamārga": ['mw'],
    "saptamāsya": ['mw'],
    "saptamātṛ": ['gra', 'mw'],
    "saptamāṣṭama": ['mw'],
    "saptamī": ['mw'],
    "saptamīpratirūpaka": ['mw'],
    "saptamīsamāsa": ['mw'],
    "saptamīsnapana": ['mw'],
    "saptamīvrata": ['mw'],
    "saptamīya": ['mw'],
    "saptamūrtimaya": ['mw'],
    "saptamṛttikā": ['mw'],
    "saptan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "saptanalī": ['ddsa', 'mw'],
    "saptanavata": ['ddsa', 'mw'],
    "saptanavati": ['mw'],
    "saptanavatitama": ['mw'],
    "saptanidhana": ['mw'],
    "saptanāman": ['gra', 'mw'],
    "saptanāmā": ['mw'],
    "saptanāḍika": ['mw'],
    "saptanāḍīcakra": ['mw'],
    "saptapad": ['cae', 'mw'],
    "saptapada": ['cae', 'gra', 'mw'],
    "saptapadārthacandrikā": ['mw'],
    "saptapadārthanirūpaṇa": ['mw'],
    "saptapadārthī": ['mw'],
    "saptapadārthīvyākhyā": ['mw'],
    "saptapadārthīṭīkā": ['mw'],
    "saptapadī": ['mw'],
    "saptapadīgamana": ['mw'],
    "saptapadīkaraṇa": ['mw'],
    "saptapalāśa": ['mw'],
    "saptaparvatamāhātmya": ['mw'],
    "saptaparāka": ['mw'],
    "saptaparṇa": ['bhs', 'cae', 'mw'],
    "saptaparṇaka": ['mw'],
    "saptaparṇī": ['mw'],
    "saptapattra": ['cae', 'mw'],
    "saptapañcāśa": ['mw'],
    "saptapañcāśat": ['mw'],
    "saptaprakṛti": ['mw'],
    "saptapuruṣa": ['mw'],
    "saptaputra": ['cae', 'gra', 'mw'],
    "saptaputrasū": ['mw'],
    "saptapākasaṃsthāvidhi": ['mw'],
    "saptapākayajñabhāṣya": ['mw'],
    "saptapākayajñaśeṣa": ['mw'],
    "saptapātāla": ['mw'],
    "saptarakta": ['mw'],
    "saptaratna": ['mw'],
    "saptaratnamaya": ['mw'],
    "saptaratnapadmavikrāntagāmin": ['bhs'],
    "saptaratnapadmavikārin": ['mw'],
    "saptaratnābhivṛṣṭa": ['bhs'],
    "saptaraśmi": ['cae', 'gra', 'mw'],
    "saptarca": ['cae', 'ddsa', 'mw'],
    "saptaruci": ['mw'],
    "saptarātra": ['cae', 'mw'],
    "saptarātraka": ['mw'],
    "saptarātrika": ['mw'],
    "saptarāva": ['mw'],
    "saptarāśika": ['mw'],
    "saptarṣi": ['cae', 'mw'],
    "saptarṣicāra": ['mw'],
    "saptarṣija": ['mw'],
    "saptarṣika": ['mw'],
    "saptarṣikuṇḍa": ['mw'],
    "saptarṣiloka": ['mw'],
    "saptarṣimat": ['mw'],
    "saptarṣimata": ['mw'],
    "saptarṣisaṃvat": ['mw'],
    "saptarṣismṛti": ['mw'],
    "saptarṣismṛtisaṃgraha": ['mw'],
    "saptarṣistotra": ['mw'],
    "saptarṣitā": ['mw'],
    "saptarṣīśvaramāhātmya": ['mw'],
    "saptasama": ['mw'],
    "saptasamudravat": ['mw'],
    "saptasamudrānta": ['mw'],
    "saptasamādhipariṣkāradāyaka": ['mw'],
    "saptasaptaka": ['mw'],
    "saptasaptakavettṛ": ['mw'],
    "saptasaptata": ['mw'],
    "saptasaptati": ['mw'],
    "saptasaptatitama": ['mw'],
    "saptasapti": ['cae', 'mw'],
    "saptasaptin": ['mw'],
    "saptasaṃkhyā": ['mw'],
    "saptasaṃkhyāka": ['mw'],
    "saptasaṃsthā": ['mw'],
    "saptasaṃsthāna": ['mw'],
    "saptasaṃsthāprayoga": ['mw'],
    "saptasirā": ['mw'],
    "saptasomapaddhati": ['mw'],
    "saptasomasaṃsthāpaddhati": ['mw'],
    "saptaspardhā": ['mw'],
    "saptasrotas": ['mw'],
    "saptasrotomāhātmya": ['mw'],
    "saptastava": ['mw'],
    "saptasthalamāhātmya": ['mw'],
    "saptasvasṛ": ['cae', 'gra', 'mw'],
    "saptasāgara": ['mw'],
    "saptasāgaradāna": ['mw'],
    "saptasāgaraka": ['mw'],
    "saptasāgaramahādānaprayoga": ['mw'],
    "saptasāgaramekhala": ['mw'],
    "saptasāgaramāhātmya": ['mw'],
    "saptasāgaraprādānikā": ['mw'],
    "saptasāgaravidhi": ['mw'],
    "saptasārasvata": ['mw'],
    "saptasū": ['mw'],
    "saptasūryopadeśa": ['bhs'],
    "saptasūtra": ['mw'],
    "saptasūtrasaṃnyāsapaddhati": ['mw'],
    "saptata": ['mw'],
    "saptatanti": ['mw'],
    "saptatantra": ['cae', 'mw'],
    "saptatantu": ['cae', 'gra', 'mw'],
    "saptataya": ['cae', 'mw'],
    "saptatha": ['cae', 'ddsa', 'gra', 'mw'],
    "saptati": ['cae', 'ddsa', 'gra', 'mw'],
    "saptatihāyana": ['mw'],
    "saptatima": ['mw'],
    "saptatiratnamālikā": ['mw'],
    "saptatisambandha": ['mw'],
    "saptatisaṃkhyāka": ['mw'],
    "saptatitama": ['mw'],
    "saptatiḥ": ['ap90'],
    "saptatriṃśa": ['mw'],
    "saptatriṃśadrātra": ['mw'],
    "saptatriṃśat": ['mw'],
    "saptatriṃśati": ['mw'],
    "saptavadhri": ['cae', 'gra', 'mw'],
    "saptavarga": ['cae', 'mw'],
    "saptavarman": ['mw'],
    "saptavarūtha": ['mw'],
    "saptavarṣa": ['cae', 'mw'],
    "saptavat": ['mw'],
    "saptavatī": ['mw'],
    "saptavelam": ['mw'],
    "saptavibhaktinirṇaya": ['mw'],
    "saptavidha": ['cae', 'mw'],
    "saptavidhatā": ['mw'],
    "saptavidāru": ['mw'],
    "saptaviṃśa": ['cae', 'mw'],
    "saptaviṃśaka": ['mw'],
    "saptaviṃśat": ['cae', 'mw'],
    "saptaviṃśati": ['cae', 'mw'],
    "saptaviṃśatika": ['mw'],
    "saptaviṃśatima": ['mw'],
    "saptaviṃśatirātra": ['mw'],
    "saptaviṃśatisādhulakṣaṇa": ['mw'],
    "saptaviṃśatitama": ['mw'],
    "saptaviṃśatiśata": ['mw'],
    "saptaviṃśin": ['mw'],
    "saptavyasanakathā": ['mw'],
    "saptavādin": ['mw'],
    "saptavāra": ['mw'],
    "saptavārṣika": ['mw'],
    "saptavārṣikā": ['cae'],
    "saptavṛṣa": ['cae', 'mw'],
    "saptayama": ['mw'],
    "saptayojanī": ['ddsa', 'mw'],
    "saptaāsia": ['gra'],
    "saptaāsya": ['gra'],
    "saptaśaktistotra": ['mw'],
    "saptaśalāka": ['mw'],
    "saptaśalākacakra": ['mw'],
    "saptaśalākacakravidhi": ['mw'],
    "saptaśapha": ['cae', 'mw'],
    "saptaśata": ['cae', 'mw'],
    "saptaśatabhāṣya": ['mw'],
    "saptaśatabījamantravidhāna": ['mw'],
    "saptaśatachāyā": ['mw'],
    "saptaśatadaṃśoddhāra": ['mw'],
    "saptaśatadhyāna": ['mw'],
    "saptaśataguptavatīvyākhyā": ['mw'],
    "saptaśatajapārthanyāsadhyāna": ['mw'],
    "saptaśataka": ['cae', 'mw'],
    "saptaśatakavacavivaraṇa": ['mw'],
    "saptaśatakāvya": ['mw'],
    "saptaśatamantrahomavidhāna": ['mw'],
    "saptaśatamantravibhāga": ['mw'],
    "saptaśatamāhātmya": ['mw'],
    "saptaśatamūla": ['mw'],
    "saptaśatanyāsa": ['mw'],
    "saptaśataprayogapaṭala": ['mw'],
    "saptaśatastotra": ['mw'],
    "saptaśatavidhāna": ['mw'],
    "saptaśatavivṛti": ['mw'],
    "saptaśatavyākhyā": ['mw'],
    "saptaśatikā": ['mw'],
    "saptaśatikāprajñāpāramitā": ['bhs'],
    "saptaśatikāvidhi": ['mw'],
    "saptaśatyutkīlana": ['mw'],
    "saptaśatī": ['mw'],
    "saptaśatīkalpa": ['mw'],
    "saptaśiras": ['cae', 'mw'],
    "saptaśirā": ['mw'],
    "saptaśiva": ['gra', 'mw'],
    "saptaśivā": ['mw'],
    "saptaślokī": ['mw'],
    "saptaślokībhāgavata": ['mw'],
    "saptaślokīrāmāyaṇa": ['mw'],
    "saptaślokīvivaraṇa": ['mw'],
    "saptaśrotas": ['mw'],
    "saptaśālivaṭī": ['mw'],
    "saptaśīrṣa": ['cae', 'mw'],
    "saptaśīrṣaka": ['bhs'],
    "saptaśīrṣan": ['cae', 'gra', 'mw'],
    "saptaṛṣi": ['gra', 'mw'],
    "saptaṛṣivat": ['mw'],
    "saptaṛṣīṇa": ['mw'],
    "saptaṣaṣṭa": ['mw'],
    "saptaṣaṣṭi": ['mw'],
    "saptaṣaṣṭibhāga": ['mw'],
    "saptaṣaṣṭisahasra": ['mw'],
    "saptaṣaṣṭitama": ['mw'],
    "saptaṣaṣṭiśata": ['mw'],
    "sapti": ['cae', 'ddsa', 'gra', 'mw'],
    "saptia": ['gra'],
    "saptika": ['mw'],
    "saptin": ['cae', 'mw'],
    "saptitā": ['mw'],
    "saptiḥ": ['ap90'],
    "saptonā": ['ddsa', 'mw'],
    "saptotsada": ['mw'],
    "saptotsāda": ['mw'],
    "saptotsādatā": ['mw'],
    "saptottara": ['mw'],
    "saptya": ['cae', 'gra', 'mw'],
    "saptācaladānapaddhati": ['mw'],
    "saptādri": ['mw'],
    "saptāgāram": ['mw'],
    "saptāgārika": ['mw'],
    "saptāha": ['bhs', 'cae', 'mw'],
    "saptāhika": ['bhs'],
    "saptāhvā": ['mw'],
    "saptākṣara": ['cae', 'mw'],
    "saptālāpaka": ['bhs'],
    "saptāmra": ['bhs'],
    "saptāmraka": ['mw'],
    "saptārci": ['mw'],
    "saptārcis": ['cae', 'mw'],
    "saptārṇava": ['mw'],
    "saptārṇavajaleśaya": ['mw'],
    "saptārṣa": ['mw'],
    "saptāsra": ['mw'],
    "saptāsthita": ['mw'],
    "saptāsthitā": ['mw'],
    "saptāsya": ['cae', 'gra', 'mw'],
    "saptātman": ['mw'],
    "saptāviṃśati": ['mw'],
    "saptāśra": ['mw'],
    "saptāśva": ['cae', 'gra', 'mw'],
    "saptāśvavāhana": ['mw'],
    "saptāśīta": ['mw'],
    "saptāśīti": ['mw'],
    "saptāśītitama": ['mw'],
    "saptāśītiślokasūtra": ['mw'],
    "saptāśīviṣa": ['bhs'],
    "saptāṃśu": ['mw'],
    "saptāṃśupuṃgava": ['mw'],
    "saptāṅga": ['cae', 'ddsa', 'mw'],
    "saptāṣṭan": ['mw'],
    "saptīvant": ['cae'],
    "saptīvat": ['gra', 'mw'],
    "sapuccha": ['mw'],
    "sapulaka": ['cae', 'mw'],
    "sapulakam": ['mw'],
    "sapuraścaraṇa": ['mw'],
    "sapurohita": ['cae', 'mw'],
    "sapurolāsa": ['mw'],
    "sapuronuvākya": ['mw'],
    "sapuruṣa": ['cae', 'mw'],
    "sapurīṣa": ['mw'],
    "saputra": ['cae', 'mw'],
    "saputradāra": ['mw'],
    "saputrajñātibāndhava": ['mw'],
    "saputraka": ['mw'],
    "saputrin": ['mw'],
    "sapuṣpa": ['cae', 'mw'],
    "sapuṣpabali": ['mw'],
    "sapāda": ['ap90', 'cae', 'mw'],
    "sapādalakṣa": ['mw'],
    "sapādalakṣaśikharin": ['mw'],
    "sapādalakṣmāpāla": ['mw'],
    "sapādamatsya": ['mw'],
    "sapādapīṭha": ['mw'],
    "sapādavandanam": ['cae', 'mw'],
    "sapāduka": ['mw'],
    "sapāka": ['cped'],
    "sapāla": ['cae', 'mw'],
    "sapātra": ['cae', 'mw'],
    "sapātrī": ['bhs'],
    "sapītaka": ['mw'],
    "sapīti": ['cae', 'gra', 'mw'],
    "sapītikā": ['mw'],
    "sapītiḥ": ['ap90'],
    "sapīḍa": ['mw'],
    "sapūrva": ['bhs', 'mw'],
    "sapṛṣadājya": ['mw'],
    "sapṛṣata": ['mw'],
    "sapṛṣṭhībhūto": ['bhs'],
    "sara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sarabha": ['cped', 'mw'],
    "sarabhaka": ['mw'],
    "sarabhasa": ['ap90', 'cae', 'mw'],
    "sarabhasam": ['mw'],
    "sarabhañña": ['cped'],
    "sarabhaṅga": ['bhs', 'cped'],
    "sarabhāṇaka": ['cped'],
    "sarabū": ['bhs', 'cped'],
    "sarada": ['cped'],
    "saradasamaya": ['cped'],
    "saragh": ['cae', 'ddsa', 'gra', 'mw'],
    "saraghā": ['ap90', 'ddsa', 'mw'],
    "sarah": ['gra'],
    "saraha": ['bhs', 'mw'],
    "sarahasya": ['ap90', 'cae', 'ddsa', 'mw'],
    "saraja": ['cped', 'mw'],
    "sarajas": ['ap90', 'mw'],
    "sarajasa": ['mw'],
    "sarajasam": ['mw'],
    "sarajasatā": ['mw'],
    "sarajaska": ['mw'],
    "sarajat": ['gra', 'mw'],
    "saraka": ['cae', 'cped', 'mw'],
    "sarakaḥ": ['ap90'],
    "sarakta": ['mw'],
    "saraktagaura": ['mw'],
    "sarala": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "saraladrava": ['cae', 'mw'],
    "saralaka": ['bhs'],
    "saralakāṣṭha": ['mw'],
    "saralaskandhasaṃghaṭṭajanman": ['mw'],
    "saralasyanda": ['mw'],
    "saralatva": ['mw'],
    "saralatā": ['mw'],
    "saralaya": ['ddsa', 'mw'],
    "saralayāyin": ['mw'],
    "saralayāyinī": ['mw'],
    "saralita": ['mw'],
    "saralā": ['mw'],
    "saralābhāṣya": ['mw'],
    "saralāya": ['mw'],
    "saralāṅga": ['mw'],
    "saralāṅguliśobhin": ['mw'],
    "saralī": ['mw'],
    "saralīkaraṇa": ['mw'],
    "saralīkṛ": ['mw'],
    "saramā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "saramāputra": ['cae', 'mw'],
    "saramāsuta": ['cae', 'mw'],
    "saramātmaja": ['cae', 'mw'],
    "sarandhra": ['cae', 'mw'],
    "saranta": ['cped'],
    "sarapas": ['gra', 'mw'],
    "sarapattrikā": ['mw'],
    "sararūka": ['mw'],
    "saras": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sarasa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sarasabhāratī": ['mw'],
    "sarasakavikulānanda": ['mw'],
    "sarasam": ['mw'],
    "sarasamprata": ['mw'],
    "sarasara": ['mw'],
    "sarasarāya": ['mw'],
    "sarasarāyate": ['bhs'],
    "sarasatva": ['mw'],
    "sarasatā": ['mw'],
    "sarasavāṇī": ['mw'],
    "sarasaśabdasaraṇi": ['mw'],
    "sarasi": ['mw'],
    "sarasija": ['cae', 'ddsa', 'mw'],
    "sarasijamukhī": ['cae', 'mw'],
    "sarasijanman": ['mw'],
    "sarasijākṣī": ['cae', 'mw'],
    "sarasika": ['mw'],
    "sarasikaḥ": ['ap90'],
    "sarasiruha": ['cae', 'mw'],
    "sarasiruhajanman": ['mw'],
    "sarasiruhasūnu": ['mw'],
    "sarastīra": ['ddsa', 'mw'],
    "sarasvant": ['cae'],
    "sarasvat": ['ap90', 'gra', 'mw'],
    "sarasvati": ['mw'],
    "sarasvatikṛta": ['mw'],
    "sarasvativat": ['mw'],
    "sarasvatyaṣṭakastotra": ['mw'],
    "sarasvatī": ['ap90', 'bhs', 'mw'],
    "sarasvatībālavāṇī": ['mw'],
    "sarasvatīdaśaślokī": ['mw'],
    "sarasvatīdaṇḍaka": ['mw'],
    "sarasvatīdvādaśanāmastotra": ['mw'],
    "sarasvatīdānavidhi": ['mw'],
    "sarasvatīkaṇṭhābharaṇa": ['cae', 'mw'],
    "sarasvatīkuṭumba": ['mw'],
    "sarasvatīkuṭumbaduhitṛ": ['mw'],
    "sarasvatīkṛta": ['mw'],
    "sarasvatīmantra": ['mw'],
    "sarasvatīmāhātmya": ['mw'],
    "sarasvatīnivāsa": ['mw'],
    "sarasvatīprakriyā": ['mw'],
    "sarasvatīprayoga": ['mw'],
    "sarasvatīpurāṇa": ['mw'],
    "sarasvatīpūjana": ['mw'],
    "sarasvatīpūjā": ['mw'],
    "sarasvatīpūjāvidhāna": ['mw'],
    "sarasvatīrahasyopaniṣad": ['mw'],
    "sarasvatīsaras": ['mw'],
    "sarasvatīstava": ['mw'],
    "sarasvatīstotra": ['mw'],
    "sarasvatīsvāmin": ['mw'],
    "sarasvatīsūkta": ['mw'],
    "sarasvatīsūtra": ['mw'],
    "sarasvatītantra": ['mw'],
    "sarasvatītīrtha": ['mw'],
    "sarasvatītīrthamāhātmya": ['mw'],
    "sarasvatīvat": ['gra', 'mw'],
    "sarasvatīvilāsa": ['mw'],
    "sarasvatīvinaśana": ['mw'],
    "sarasvatīvrata": ['mw'],
    "sarasvatīṣaṭślokī": ['mw'],
    "sarasya": ['cae', 'mw'],
    "sarasā": ['mw'],
    "sarasāṅgayaṣṭi": ['mw'],
    "sarasī": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sarasīja": ['cae', 'ddsa', 'mw'],
    "sarasījalocana": ['mw'],
    "sarasījekṣaṇa": ['mw'],
    "sarasījākṣa": ['mw'],
    "sarasīkaḥ": ['ap90'],
    "sarasīkṛ": ['ddsa', 'mw'],
    "sarasīruh": ['mw'],
    "sarasīruha": ['cae', 'mw'],
    "sarasīruhabandhu": ['mw'],
    "sarasīruhekṣaṇa": ['cae', 'mw'],
    "sarasīruhākṣa": ['cae', 'mw'],
    "sarat": ['mw'],
    "saratha": ['ap90', 'cae', 'gra', 'mw'],
    "saratham": ['cae', 'ddsa', 'mw'],
    "sarathapādāta": ['mw'],
    "sarathin": ['mw'],
    "sarati": ['bhs', 'cped'],
    "saratni": ['mw'],
    "saratniḥ": ['ap90'],
    "saratuṇḍa": ['cped'],
    "saratva": ['mw'],
    "saratīra": ['cped'],
    "saravatī": ['mw'],
    "saravya": ['ap90'],
    "saraya": ['mw'],
    "sarayu": ['cae', 'ddsa', 'gra', 'mw'],
    "sarayuḥ": ['ap90'],
    "sarayū": ['cae', 'mw'],
    "sarayūtaṭa": ['mw'],
    "sarayūvana": ['mw'],
    "saraśana": ['mw'],
    "saraśmi": ['cae', 'gra', 'mw'],
    "saraḍ": ['mw'],
    "saraḍa": ['bhs', 'mw'],
    "saraḥ": ['mw'],
    "saraḥkāka": ['mw'],
    "saraḥpriya": ['mw'],
    "saraṃgaḥ": ['ap90'],
    "saraṃḍaḥ": ['ap90'],
    "saraṅga": ['mw'],
    "saraṇa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "saraṇadeva": ['mw'],
    "saraṇajīvin": ['mw'],
    "saraṇaraṇikam": ['mw'],
    "saraṇi": ['cae', 'ddsa', 'mw'],
    "saraṇiḥ": ['ap90'],
    "saraṇy": ['gra'],
    "saraṇya": ['ddsa', 'mw'],
    "saraṇyu": ['cae', 'ddsa', 'gra', 'mw'],
    "saraṇyuḥ": ['ap90'],
    "saraṇyū": ['mw'],
    "saraṇā": ['mw'],
    "saraṇāgamana": ['cped'],
    "saraṇīya": ['cped'],
    "saraṇḍa": ['mw'],
    "saraṣaṭṭa": ['mw'],
    "saraṭ": ['ap90', 'ddsa', 'gra', 'mw'],
    "saraṭa": ['bhs', 'cae', 'ddsa', 'mw'],
    "saraṭaka": ['mw'],
    "saraṭapatanapraśānti": ['mw'],
    "saraṭaśāstra": ['mw'],
    "saraṭaḥ": ['ap90'],
    "saraṭiḥ": ['ap90'],
    "saraṭu": ['mw'],
    "saraṭuḥ": ['ap90'],
    "sarb": ['ap90', 'mw'],
    "sarca": ['mw'],
    "sardigṛdi": ['mw'],
    "sarepha": ['mw'],
    "saretas": ['cae', 'mw'],
    "sarga": ['cae', 'ddsa', 'gra', 'mw'],
    "sargabandha": ['cae', 'mw'],
    "sargaka": ['mw'],
    "sargakartṛ": ['cae', 'mw'],
    "sargakartṛtva": ['mw'],
    "sargakrama": ['mw'],
    "sargakālīna": ['mw'],
    "sargakṛt": ['cae', 'mw'],
    "sargapralayakaṇṭakoddhāra": ['mw'],
    "sargapratakta": ['cae', 'gra', 'mw'],
    "sargatakta": ['cae', 'gra', 'mw'],
    "sargaḥ": ['ap90'],
    "sargya": ['mw'],
    "sari": ['cped', 'mw'],
    "sarid": ['mw'],
    "saridadhipati": ['mw'],
    "saridbhartṛ": ['mw'],
    "sariddvīpa": ['mw'],
    "saridubhaya": ['mw'],
    "saridvadhū": ['mw'],
    "saridvarā": ['mw'],
    "saridvat": ['ap90'],
    "saridāśrita": ['mw'],
    "sarika": ['mw'],
    "sarikā": ['ap90', 'mw'],
    "sarila": ['mw'],
    "sarilaṃ": ['ap90'],
    "sariman": ['ap90', 'mw'],
    "sarin": ['cae', 'gra', 'mw'],
    "sarinmaruvanāśraya": ['mw'],
    "sarinmukha": ['mw'],
    "sarinnātha": ['mw'],
    "sarira": ['cae', 'ddsa', 'mw'],
    "sarisrara": ['mw'],
    "sarisrut": ['mw'],
    "sarit": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sarita": ['bhs', 'mw'],
    "saritabba": ['cped'],
    "saritar": ['cped'],
    "saritkapha": ['mw'],
    "saritpati": ['cae', 'mw'],
    "saritsuraṅgā": ['mw'],
    "saritsuta": ['mw'],
    "saritsāgara": ['mw'],
    "saritvat": ['mw'],
    "saritvā": ['cped'],
    "saritā": ['bhs', 'cped'],
    "sariḥ": ['ap90'],
    "sariṇyu": ['mw'],
    "sariṣapa": ['mw'],
    "sariṣapaḥ": ['ap90'],
    "sarj": ['ap90', 'cae', 'gra', 'mw'],
    "sarja": ['cae', 'ddsa', 'mw'],
    "sarjagandhā": ['mw'],
    "sarjaka": ['mw'],
    "sarjakaḥ": ['ap90'],
    "sarjamaṇi": ['mw'],
    "sarjana": ['cae', 'mw'],
    "sarjanaṃ": ['ap90'],
    "sarjaniryāsaka": ['mw'],
    "sarjanāman": ['mw'],
    "sarjanī": ['mw'],
    "sarjara": ['bhs'],
    "sarjarasa": ['cae', 'ddsa', 'mw'],
    "sarjavṛkṣa": ['mw'],
    "sarjayitavya": ['mw'],
    "sarjaḥ": ['ap90'],
    "sarji": ['mw'],
    "sarjikā": ['mw'],
    "sarjikākṣāra": ['mw'],
    "sarjikṣāra": ['mw'],
    "sarjiḥ": ['ap90'],
    "sarju": ['mw'],
    "sarjya": ['mw'],
    "sarjyaḥ": ['ap90'],
    "sarjī": ['mw'],
    "sarjīkṣāra": ['mw'],
    "sarjū": ['mw'],
    "sarjūra": ['mw'],
    "sarjūḥ": ['ap90'],
    "sarka": ['mw'],
    "sarkaḥ": ['ap90'],
    "sarkṣa": ['mw'],
    "sarma": ['cae', 'gra', 'mw'],
    "sarmaḥ": ['ap90'],
    "saro": ['mw'],
    "sarobindu": ['ddsa', 'mw'],
    "sarodaka": ['mw'],
    "sarodapāna": ['mw'],
    "sarodha": ['mw'],
    "saroga": ['cae', 'mw'],
    "sarogatā": ['mw'],
    "sarogin": ['mw'],
    "sarogitā": ['mw'],
    "saroja": ['cae', 'cped', 'ddsa', 'mw'],
    "sarojadṛś": ['cae', 'mw'],
    "sarojakalikā": ['mw'],
    "sarojakhaṇḍa": ['mw'],
    "sarojala": ['mw'],
    "sarojanayanā": ['cae', 'mw'],
    "sarojanetra": ['cae'],
    "sarojanetrā": ['mw'],
    "sarojanman": ['mw'],
    "sarojarāga": ['mw'],
    "sarojasundara": ['mw'],
    "sarojatā": ['mw'],
    "sarojin": ['mw'],
    "sarojinī": ['cae', 'mw'],
    "sarojīya": ['mw'],
    "saroma": ['ddsa', 'mw'],
    "saromakaṇṭaka": ['mw'],
    "saromavikriya": ['mw'],
    "saromāñca": ['mw'],
    "saromāñcam": ['mw'],
    "saropānta": ['ddsa', 'mw'],
    "sarorakṣa": ['ddsa', 'mw'],
    "saroruh": ['mw'],
    "saroruha": ['cae', 'cped', 'mw'],
    "saroruhadṛś": ['cae', 'mw'],
    "saroruhavajra": ['mw'],
    "saroruhiṇī": ['cae', 'mw'],
    "saroruhākṣī": ['cae', 'mw'],
    "saroruhāsana": ['mw'],
    "sarotsava": ['mw'],
    "sarovara": ['cae', 'mw'],
    "saroṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "saroṣarāgopahata": ['mw'],
    "saroṣasambhrama": ['mw'],
    "saroṣasmitam": ['cae', 'mw'],
    "sarpa": ['cae', 'ddsa', 'gra', 'mw'],
    "sarpabala": ['mw'],
    "sarpabali": ['mw'],
    "sarpabalikarman": ['mw'],
    "sarpabalividhi": ['mw'],
    "sarpabandha": ['mw'],
    "sarpabhuj": ['mw'],
    "sarpabhṛtā": ['mw'],
    "sarpacchattra": ['mw'],
    "sarpacchattraka": ['mw'],
    "sarpacīranivāsana": ['mw'],
    "sarpadamanī": ['mw'],
    "sarpadantī": ['mw'],
    "sarpadaṃṣṭra": ['mw'],
    "sarpadaṃṣṭrikā": ['mw'],
    "sarpadaṃṣṭrā": ['mw'],
    "sarpadaṃṣṭrī": ['mw'],
    "sarpadaṇḍā": ['mw'],
    "sarpadaṇḍī": ['mw'],
    "sarpadaṣṭa": ['cae', 'mw'],
    "sarpadevajana": ['mw'],
    "sarpadevī": ['mw'],
    "sarpadhāraka": ['mw'],
    "sarpadviṣ": ['mw'],
    "sarpagandhā": ['mw'],
    "sarpagati": ['mw'],
    "sarpaghātinī": ['mw'],
    "sarpahan": ['mw'],
    "sarpahṛdayacandana": ['mw'],
    "sarpajāti": ['mw'],
    "sarpakaṅkālikā": ['mw'],
    "sarpakaṅkālī": ['mw'],
    "sarpakoṭara": ['mw'],
    "sarpalatā": ['mw'],
    "sarpamaṇi": ['mw'],
    "sarpamudraka": ['cae', 'mw'],
    "sarpamālin": ['mw'],
    "sarpamālā": ['mw'],
    "sarpanetrā": ['mw'],
    "sarpanirmocana": ['mw'],
    "sarpanāma": ['mw'],
    "sarpanāmā": ['mw'],
    "sarpapati": ['mw'],
    "sarpaphaṇa": ['mw'],
    "sarpaphaṇaja": ['mw'],
    "sarpapurakṣetramāhātmya": ['mw'],
    "sarpapuṃgava": ['mw'],
    "sarpapuṇyajana": ['mw'],
    "sarpapuṣpī": ['mw'],
    "sarparāja": ['cae', 'mw'],
    "sarparājñī": ['cae', 'mw'],
    "sarparūpin": ['cae', 'mw'],
    "sarpar̥ṣi": ['ddsa'],
    "sarpasahā": ['mw'],
    "sarpasattra": ['mw'],
    "sarpasattrin": ['mw'],
    "sarpasaṃskāra": ['mw'],
    "sarpasugandhā": ['mw'],
    "sarpasāman": ['mw'],
    "sarpasāt": ['mw'],
    "sarpat": ['mw'],
    "sarpatanu": ['mw'],
    "sarpatva": ['mw'],
    "sarpatvasambhāvanā": ['mw'],
    "sarpatā": ['cae', 'ddsa', 'mw'],
    "sarpatṛṇa": ['mw'],
    "sarpauṣadhi": ['mw'],
    "sarpavallī": ['mw'],
    "sarpaveda": ['mw'],
    "sarpavid": ['cae', 'mw'],
    "sarpavidyā": ['cae', 'mw'],
    "sarpavināśa": ['cae'],
    "sarpavināśana": ['mw'],
    "sarpavivara": ['cae', 'mw'],
    "sarpaviṣaharamantra": ['mw'],
    "sarpaviṣapratiṣedha": ['mw'],
    "sarpavyāpādana": ['mw'],
    "sarpavṛścikaromavat": ['mw'],
    "sarpayāga": ['mw'],
    "sarpaśapharī": ['mw'],
    "sarpaśattra": ['cae'],
    "sarpaśiras": ['mw'],
    "sarpaśīrṣa": ['mw'],
    "sarpaśīrṣan": ['mw'],
    "sarpaśīrṣin": ['mw'],
    "sarpaḥ": ['ap90'],
    "sarpaṇa": ['cae', 'ddsa', 'mw'],
    "sarpaṇaṃ": ['ap90'],
    "sarpaṛṣi": ['mw'],
    "sarpetarajana": ['mw'],
    "sarpeśvara": ['cae', 'ddsa', 'mw'],
    "sarpeśvaratīrtha": ['mw'],
    "sarpeṣṭa": ['mw'],
    "sarpi": ['cae', 'ddsa', 'mw'],
    "sarpikā": ['mw'],
    "sarpimaṇḍa": ['mw'],
    "sarpin": ['ap90', 'cae', 'mw'],
    "sarpir": ['mw'],
    "sarpirabdhi": ['mw'],
    "sarpiranna": ['cae', 'gra', 'mw'],
    "sarpirdānaratna": ['mw'],
    "sarpirgrīva": ['mw'],
    "sarpirilā": ['mw'],
    "sarpirmaṇḍa": ['mw'],
    "sarpirmehin": ['mw'],
    "sarpirmiśra": ['mw'],
    "sarpirmālin": ['mw'],
    "sarpirāsuti": ['cae', 'ddsa', 'gra', 'mw'],
    "sarpis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sarpisaro": ['bhs'],
    "sarpissamudra": ['mw'],
    "sarpissāt": ['mw'],
    "sarpita": ['mw'],
    "sarpiḥ": ['mw'],
    "sarpiḥpradyotika": ['bhs'],
    "sarpiḥsamudra": ['mw'],
    "sarpiṇī": ['ap90', 'mw'],
    "sarpiṣ": ['mw'],
    "sarpiṣka": ['mw'],
    "sarpiṣkuṇḍikā": ['mw'],
    "sarpiṣkāmya": ['mw'],
    "sarpiṣmant": ['cae'],
    "sarpiṣmat": ['ap90', 'ddsa', 'mw'],
    "sarpiṣvant": ['cae'],
    "sarpiṣvat": ['mw'],
    "sarpiṣṭama": ['mw'],
    "sarpiṣṭara": ['mw'],
    "sarpiṣṭas": ['mw'],
    "sarpiṣṭva": ['mw'],
    "sarpiṣṭā": ['mw'],
    "sarpya": ['mw'],
    "sarpābha": ['mw'],
    "sarpādanī": ['mw'],
    "sarpāhuti": ['mw'],
    "sarpākhya": ['mw'],
    "sarpākṣa": ['mw'],
    "sarpākṣī": ['mw'],
    "sarpānta": ['mw'],
    "sarpāpahārin": ['mw'],
    "sarpāri": ['cae', 'mw'],
    "sarpāriketana": ['mw'],
    "sarpārāti": ['mw'],
    "sarpāsya": ['mw'],
    "sarpāsyā": ['mw'],
    "sarpāvali": ['mw'],
    "sarpāvāsa": ['mw'],
    "sarpāya": ['mw'],
    "sarpāśana": ['mw'],
    "sarpāṅgābhihata": ['mw'],
    "sarpāṅgī": ['mw'],
    "sarpī": ['cae', 'ddsa', 'mw'],
    "sarpībhū": ['ddsa', 'mw'],
    "sarpīṣṭa": ['mw'],
    "sartavai": ['cae', 'mw'],
    "sartave": ['cae', 'ddsa', 'mw'],
    "sartṛ": ['cae', 'mw'],
    "saru": ['ap90', 'cae', 'mw'],
    "saruc": ['cae', 'ddsa', 'mw'],
    "sarudbhava": ['mw'],
    "sarudhira": ['mw'],
    "sarudhiram": ['mw'],
    "sarudhiramūtra": ['mw'],
    "sarudhiramūtratā": ['mw'],
    "saruha": ['cped'],
    "saruj": ['cae', 'mw'],
    "saruja": ['cae', 'mw'],
    "sarujasiddhācārya": ['mw'],
    "sarujatva": ['mw'],
    "saruṣ": ['cae', 'mw'],
    "sarv": ['ap90', 'mw'],
    "sarva": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sarvabala": ['bhs', 'mw'],
    "sarvabalavegavatī": ['bhs'],
    "sarvabandha": ['bhs'],
    "sarvabandhavimocana": ['mw'],
    "sarvabhadra": ['bhs'],
    "sarvabhakṣa": ['cae', 'mw'],
    "sarvabhakṣatva": ['mw'],
    "sarvabhakṣin": ['cae', 'mw'],
    "sarvabhakṣya": ['mw'],
    "sarvabhakṣā": ['mw'],
    "sarvabhauma": ['mw'],
    "sarvabhavottāraṇa": ['mw'],
    "sarvabhavāraṇi": ['mw'],
    "sarvabhayaṃkara": ['mw'],
    "sarvabhaṭṭa": ['mw'],
    "sarvabhogin": ['mw'],
    "sarvabhogya": ['cae', 'mw'],
    "sarvabhogīṇa": ['mw'],
    "sarvabhuj": ['mw'],
    "sarvabhāj": ['mw'],
    "sarvabhāsa": ['mw'],
    "sarvabhāva": ['cae', 'mw'],
    "sarvabhāvakara": ['mw'],
    "sarvabhāvana": ['mw'],
    "sarvabhāvādhiṣṭhātṛ": ['mw'],
    "sarvabhāvādhiṣṭhātṛtva": ['mw'],
    "sarvabhūmi": ['mw'],
    "sarvabhūta": ['cae', 'mw'],
    "sarvabhūtadamana": ['mw'],
    "sarvabhūtadamanī": ['mw'],
    "sarvabhūtaguhāśaya": ['cae', 'mw'],
    "sarvabhūtahara": ['mw'],
    "sarvabhūtahita": ['mw'],
    "sarvabhūtakṛt": ['cae', 'mw'],
    "sarvabhūtamaya": ['cae', 'mw'],
    "sarvabhūtapitāmaha": ['mw'],
    "sarvabhūtaprasādana": ['bhs'],
    "sarvabhūtaruta": ['bhs'],
    "sarvabhūtarutagrahaṇī": ['bhs', 'mw'],
    "sarvabhūtastha": ['mw'],
    "sarvabhūtasthita": ['cae', 'mw'],
    "sarvabhūtepsita": ['mw'],
    "sarvabhūtādhipati": ['mw'],
    "sarvabhūtāntaka": ['mw'],
    "sarvabhūtāntarātman": ['cae', 'mw'],
    "sarvabhūtātmabhūta": ['mw'],
    "sarvabhūtātmaka": ['mw'],
    "sarvabhūtātmamedhas": ['mw'],
    "sarvabhūtātman": ['cae', 'mw'],
    "sarvabhṛt": ['cae', 'mw'],
    "sarvabuddha": ['mw'],
    "sarvabuddhakṣetrakāyasvabhāvasaṃdarśana": ['bhs'],
    "sarvabuddhakṣetrasaṃdarśana": ['mw'],
    "sarvabuddhanirmāṇapratibhāsacūḍa": ['bhs'],
    "sarvabuddhasaṃbhūtagarbhamaṇimakuṭa": ['bhs'],
    "sarvabuddhasaṃdarśana": ['mw'],
    "sarvabuddhavijayāvatāra": ['mw'],
    "sarvabuddhaviṣayāvatārajñānālokālaṃkāra": ['bhs'],
    "sarvabāhu": ['mw'],
    "sarvabāhya": ['mw'],
    "sarvabīja": ['mw'],
    "sarvabījin": ['mw'],
    "sarvacakravicāra": ['mw'],
    "sarvacakrā": ['bhs', 'mw'],
    "sarvacandra": ['mw'],
    "sarvacarita": ['mw'],
    "sarvacarmīṇa": ['mw'],
    "sarvacaru": ['cae', 'mw'],
    "sarvacaṇḍāla": ['bhs', 'mw'],
    "sarvacchandaka": ['mw'],
    "sarvacārin": ['mw'],
    "sarvada": ['cae', 'ddsa', 'mw'],
    "sarvadada": ['bhs'],
    "sarvadaivasattva": ['mw'],
    "sarvadaivatya": ['mw'],
    "sarvadamana": ['cae', 'mw'],
    "sarvadarāja": ['mw'],
    "sarvadarśana": ['cae', 'mw'],
    "sarvadarśanasaṃgraha": ['mw'],
    "sarvadarśanaśiromaṇi": ['mw'],
    "sarvadarśin": ['bhs', 'cae', 'mw'],
    "sarvadarśitā": ['bhs'],
    "sarvadaya": ['bhs'],
    "sarvadaṇḍa": ['bhs'],
    "sarvadaṇḍadhara": ['mw'],
    "sarvadeva": ['ddsa', 'mw'],
    "sarvadevagupta": ['bhs'],
    "sarvadevahutāśana": ['mw'],
    "sarvadevamaya": ['cae', 'mw'],
    "sarvadevamukha": ['mw'],
    "sarvadevamūrtipratiṣṭhāvidhi": ['mw'],
    "sarvadevapratiṣṭhā": ['mw'],
    "sarvadevapratiṣṭhākarman": ['mw'],
    "sarvadevapratiṣṭhākramavidhi": ['mw'],
    "sarvadevapratiṣṭhāvidhi": ['mw'],
    "sarvadevapūjanaprakāra": ['mw'],
    "sarvadevapūjanaprayoga": ['mw'],
    "sarvadevasādhāraṇanityapūjāvidhi": ['mw'],
    "sarvadevasūkta": ['mw'],
    "sarvadevasūri": ['mw'],
    "sarvadevata": ['mw'],
    "sarvadevatya": ['cae', 'mw'],
    "sarvadevatāmaya": ['cae', 'mw'],
    "sarvadevatāpratiṣṭhāsārasaṃgraha": ['mw'],
    "sarvadevatāpuṣpādipūjana": ['mw'],
    "sarvadeveśa": ['mw'],
    "sarvadevātmaka": ['mw'],
    "sarvadevātman": ['mw'],
    "sarvadevīmayī": ['mw'],
    "sarvadeśavṛttāntasaṃgraha": ['mw'],
    "sarvadeśya": ['mw'],
    "sarvadeśīya": ['mw'],
    "sarvadhana": ['mw'],
    "sarvadhanin": ['mw'],
    "sarvadhanvin": ['mw'],
    "sarvadhara": ['mw'],
    "sarvadharmabhāvanārambhasaṃbhavateja": ['bhs'],
    "sarvadharmadhātuspharaṇaghoṣa": ['bhs'],
    "sarvadharmadhātusāgaranigarjitaghoṣa": ['bhs'],
    "sarvadharmadhātutalabhedaketurāja": ['bhs'],
    "sarvadharmamaya": ['cae', 'mw'],
    "sarvadharmamudra": ['mw'],
    "sarvadharmamudrā": ['bhs'],
    "sarvadharman": ['mw'],
    "sarvadharmanigarjitarāja": ['bhs'],
    "sarvadharmanirnādachattramaṇḍalanirghoṣa": ['bhs'],
    "sarvadharmapadaprabheda": ['bhs', 'mw'],
    "sarvadharmaprabharāja": ['bhs'],
    "sarvadharmaprakāśa": ['mw'],
    "sarvadharmapraveśamudra": ['mw'],
    "sarvadharmapraveśamudrā": ['bhs'],
    "sarvadharmapraveśana": ['mw'],
    "sarvadharmasamatā": ['bhs', 'mw'],
    "sarvadharmasamatājñānamudrā": ['mw'],
    "sarvadharmasamavasaraṇasāgaramudra": ['mw'],
    "sarvadharmasamavasaraṇasāgaramudrā": ['bhs'],
    "sarvadharmasamavaśaraṇasāgaramudrā": ['mw'],
    "sarvadharmasamudrābhyudgatavegarāja": ['bhs'],
    "sarvadharmasamādhiprabhaghoṣa": ['bhs'],
    "sarvadharmasukhākrānta": ['bhs'],
    "sarvadharmasvabhāvasamatāvipañcita": ['bhs'],
    "sarvadharmasvabhāvavicaya": ['bhs'],
    "sarvadharmasāgaranirghoṣaprabharāja": ['bhs'],
    "sarvadharmasāgaranirghoṣarāja": ['bhs'],
    "sarvadharmavaipulyasaṃgrahasūtra": ['bhs'],
    "sarvadharmavid": ['cae', 'mw'],
    "sarvadharmavīryavegadhvaja": ['bhs'],
    "sarvadharmeśvararāja": ['bhs'],
    "sarvadharmodgata": ['bhs', 'mw'],
    "sarvadharmopapanna": ['bhs'],
    "sarvadharmottaraghoṣa": ['mw'],
    "sarvadharmāpravṛttinirdeśa": ['bhs', 'mw'],
    "sarvadharmātikramaṇa": ['bhs', 'mw'],
    "sarvadhurāvaha": ['mw'],
    "sarvadhurīṇa": ['mw'],
    "sarvadhā": ['cae', 'gra', 'mw'],
    "sarvadhāman": ['mw'],
    "sarvadhārin": ['mw'],
    "sarvadhārī": ['mw'],
    "sarvadigvijaya": ['mw'],
    "sarvadiśapradīpaprabharāja": ['bhs'],
    "sarvadiṅmukham": ['mw'],
    "sarvadravya": ['mw'],
    "sarvadraṣṭṛ": ['cae', 'mw'],
    "sarvadryañc": ['mw'],
    "sarvadryaṃc": ['ap90'],
    "sarvaduḥkhakṣaya": ['mw'],
    "sarvaduḥkhapraśamana": ['bhs'],
    "sarvaduṣṭāntakṛt": ['mw'],
    "sarvadvārika": ['mw'],
    "sarvadā": ['ap90', 'cae', 'ddsa', 'mw'],
    "sarvadāha": ['mw'],
    "sarvadāna": ['mw'],
    "sarvadānavidhi": ['mw'],
    "sarvadānādhika": ['mw'],
    "sarvadāsa": ['mw'],
    "sarvadātṛ": ['mw'],
    "sarvadātṛtva": ['mw'],
    "sarvadṛś": ['mw'],
    "sarvaga": ['cae', 'mw'],
    "sarvagambhīra": ['mw'],
    "sarvagandha": ['cae', 'mw'],
    "sarvagandhamaya": ['mw'],
    "sarvagandhaprabhāsavatī": ['bhs'],
    "sarvagandhavaha": ['cae', 'mw'],
    "sarvagandhika": ['mw'],
    "sarvagandhā": ['mw'],
    "sarvagandhārcimukhavajramaṇivicitra": ['bhs'],
    "sarvagata": ['cae', 'mw'],
    "sarvagatatva": ['mw'],
    "sarvagati": ['mw'],
    "sarvagatva": ['mw'],
    "sarvagavī": ['mw'],
    "sarvagaṇa": ['cae', 'gra', 'mw'],
    "sarvagila": ['mw'],
    "sarvagraha": ['mw'],
    "sarvagraharūpin": ['mw'],
    "sarvagranthi": ['mw'],
    "sarvagranthika": ['mw'],
    "sarvagrāsa": ['mw'],
    "sarvagrāsam": ['mw'],
    "sarvagu": ['mw'],
    "sarvaguhyamaya": ['mw'],
    "sarvaguru": ['mw'],
    "sarvaguṇa": ['mw'],
    "sarvaguṇasampanna": ['mw'],
    "sarvaguṇasaṃcayagata": ['bhs', 'mw'],
    "sarvaguṇaviśuddhigarbha": ['bhs', 'mw'],
    "sarvaguṇin": ['mw'],
    "sarvaguṇopeta": ['mw'],
    "sarvaguṇālaṃkāravyūha": ['bhs', 'mw'],
    "sarvagā": ['mw'],
    "sarvagāmin": ['bhs', 'mw'],
    "sarvagātra": ['mw'],
    "sarvagātrajñānapratibhāsacandra": ['bhs'],
    "sarvagāyatra": ['mw'],
    "sarvagṛhya": ['mw'],
    "sarvahara": ['cae', 'mw'],
    "sarvaharaṇa": ['cae', 'mw'],
    "sarvahari": ['mw'],
    "sarvaharṣakara": ['mw'],
    "sarvahatyā": ['mw'],
    "sarvahemamaya": ['mw'],
    "sarvahita": ['mw'],
    "sarvahoma": ['mw'],
    "sarvahomapaddhati": ['mw'],
    "sarvahut": ['cae', 'gra', 'mw'],
    "sarvahuta": ['cae', 'mw'],
    "sarvahutatva": ['mw'],
    "sarvahuti": ['mw'],
    "sarvahāra": ['mw'],
    "sarvahāram": ['mw'],
    "sarvahārin": ['mw'],
    "sarvahāsya": ['mw'],
    "sarvahāyas": ['mw'],
    "sarvahṛd": ['cae', 'gra', 'mw'],
    "sarvahṛdā": ['mw'],
    "sarvaiśvarya": ['mw'],
    "sarvaja": ['mw'],
    "sarvajagaddhitapraṇidhānacandra": ['bhs'],
    "sarvajagadduḥkhapraśāntyāśvāsanaghoṣa": ['bhs'],
    "sarvajagadrakṣāpraṇidhānavīryaprabhā": ['bhs'],
    "sarvajagat": ['mw'],
    "sarvajana": ['cae', 'mw'],
    "sarvajanapriya": ['mw'],
    "sarvajanapriyā": ['mw'],
    "sarvajanatā": ['mw'],
    "sarvajanavaśyahanumanmantra": ['mw'],
    "sarvajanman": ['cae', 'mw'],
    "sarvajanīna": ['mw'],
    "sarvajanīnatva": ['mw'],
    "sarvajanīya": ['mw'],
    "sarvajaya": ['mw'],
    "sarvajayā": ['mw'],
    "sarvajaṭa": ['mw'],
    "sarvajinmahāvrataprayoga": ['mw'],
    "sarvajit": ['cae', 'mw'],
    "sarvajjagābhimukharūpa": ['bhs'],
    "sarvajvara": ['mw'],
    "sarvajvarahara": ['mw'],
    "sarvajvarajvarāpaha": ['mw'],
    "sarvajvaravipāka": ['mw'],
    "sarvajyotis": ['mw'],
    "sarvajyotiṣasaṃgraha": ['mw'],
    "sarvajyāni": ['mw'],
    "sarvajña": ['bhs', 'cae', 'mw'],
    "sarvajñabhaṭṭa": ['mw'],
    "sarvajñadeva": ['mw'],
    "sarvajñajñānaviśeṣābhiṣekavant": ['bhs'],
    "sarvajñajñānin": ['mw'],
    "sarvajñamitra": ['bhs', 'mw'],
    "sarvajñammanya": ['mw'],
    "sarvajñammanyatā": ['mw'],
    "sarvajñamānin": ['mw'],
    "sarvajñanārāyaṇa": ['mw'],
    "sarvajñaputra": ['mw'],
    "sarvajñarāmeśvarabhaṭṭāraka": ['mw'],
    "sarvajñasūnu": ['mw'],
    "sarvajñatva": ['mw'],
    "sarvajñatā": ['mw'],
    "sarvajñaviṣṇu": ['mw'],
    "sarvajñavyavasthāpaka": ['mw'],
    "sarvajñavāsudeva": ['mw'],
    "sarvajñaśrīnārāyaṇa": ['mw'],
    "sarvajñā": ['mw'],
    "sarvajñāna": ['mw'],
    "sarvajñānamaya": ['cae', 'mw'],
    "sarvajñānatantra": ['mw'],
    "sarvajñānavid": ['mw'],
    "sarvajñānottama": ['mw'],
    "sarvajñānottamatantra": ['mw'],
    "sarvajñānottara": ['mw'],
    "sarvajñānottaravṛtti": ['mw'],
    "sarvajñārdhaśarīriṇī": ['mw'],
    "sarvajñātmagiri": ['mw'],
    "sarvajñātmamuni": ['mw'],
    "sarvajñātṛ": ['cae', 'mw'],
    "sarvajñātṛtva": ['mw'],
    "sarvajñīya": ['mw'],
    "sarvajāgata": ['mw'],
    "sarvajīva": ['mw'],
    "sarvajīvamaya": ['mw'],
    "sarvajīvin": ['mw'],
    "sarvaka": ['ap90', 'bhs', 'mw'],
    "sarvakara": ['mw'],
    "sarvakarmakārin": ['mw'],
    "sarvakarman": ['cae', 'ddsa', 'mw'],
    "sarvakarmasaha": ['mw'],
    "sarvakarmika": ['bhs'],
    "sarvakarmīṇa": ['mw'],
    "sarvakartṛ": ['mw'],
    "sarvakartṛtva": ['mw'],
    "sarvake": ['mw'],
    "sarvakesara": ['mw'],
    "sarvakeśa": ['mw'],
    "sarvakeśaka": ['mw'],
    "sarvakeśin": ['mw'],
    "sarvakratu": ['mw'],
    "sarvakratumaya": ['mw'],
    "sarvakratutā": ['mw'],
    "sarvakuśalamūlapāramitā": ['mw'],
    "sarvakāla": ['cae', 'mw'],
    "sarvakālajña": ['bhs'],
    "sarvakālaka": ['bhs'],
    "sarvakālam": ['mw'],
    "sarvakālamitra": ['mw'],
    "sarvakālaprasāda": ['mw'],
    "sarvakālavicārin": ['mw'],
    "sarvakāle": ['mw'],
    "sarvakālika": ['bhs'],
    "sarvakālikāgama": ['mw'],
    "sarvakālīna": ['mw'],
    "sarvakāma": ['cae', 'mw'],
    "sarvakāmada": ['mw'],
    "sarvakāmadugha": ['cae', 'mw'],
    "sarvakāmaduh": ['cae', 'mw'],
    "sarvakāmagama": ['mw'],
    "sarvakāmamaya": ['mw'],
    "sarvakāmasamṛddha": ['mw'],
    "sarvakāmavara": ['mw'],
    "sarvakāmika": ['cae', 'mw'],
    "sarvakāmin": ['cae', 'mw'],
    "sarvakāmya": ['mw'],
    "sarvakāraka": ['mw'],
    "sarvakāraṇa": ['mw'],
    "sarvakāraṇakāraṇa": ['mw'],
    "sarvakārin": ['mw'],
    "sarvakāñcana": ['mw'],
    "sarvakāṣam": ['mw'],
    "sarvakṛcchra": ['mw'],
    "sarvakṛt": ['mw'],
    "sarvakṛṣṇa": ['mw'],
    "sarvakṣatriyamardana": ['mw'],
    "sarvakṣaya": ['mw'],
    "sarvakṣetratīrthamāhātmya": ['mw'],
    "sarvakṣit": ['mw'],
    "sarvakṣitipatitva": ['mw'],
    "sarvakṣāra": ['mw'],
    "sarvalaghu": ['mw'],
    "sarvalakṣaṇa": ['mw'],
    "sarvalakṣaṇalakṣita": ['mw'],
    "sarvalakṣaṇapratimaṇḍitaviśuddhiśrīgarbha": ['bhs'],
    "sarvalakṣaṇapustaka": ['mw'],
    "sarvalakṣaṇatātparya": ['mw'],
    "sarvalauha": ['mw'],
    "sarvaliṅga": ['mw'],
    "sarvaliṅgapradātṛ": ['mw'],
    "sarvaliṅgasaṃnyāsa": ['mw'],
    "sarvaliṅgasaṃnyāsanirṇaya": ['mw'],
    "sarvaliṅgasādhanī": ['mw'],
    "sarvaliṅgatā": ['mw'],
    "sarvaliṅgin": ['mw'],
    "sarvaliṅgādhyāya": ['mw'],
    "sarvalocanā": ['mw'],
    "sarvaloha": ['mw'],
    "sarvalohamaya": ['mw'],
    "sarvalohita": ['mw'],
    "sarvaloka": ['cae', 'mw'],
    "sarvalokabhayacchambhitatvavidhvaṃsanakara": ['bhs'],
    "sarvalokabhayaṃkara": ['mw'],
    "sarvalokabhayāstambhitatvaviddhvaṃsanakara": ['mw'],
    "sarvalokabhṛt": ['mw'],
    "sarvalokadhātuvyavalokana": ['mw'],
    "sarvalokadhātūdgatamakuṭa": ['bhs'],
    "sarvalokadhātūpadravodvegapratyuttīrṇa": ['bhs', 'mw'],
    "sarvalokaguru": ['mw'],
    "sarvalokahitaiṣiṇ": ['bhs'],
    "sarvalokakṛt": ['mw'],
    "sarvalokamaheśvara": ['mw'],
    "sarvalokamaya": ['mw'],
    "sarvalokapitāmaha": ['mw'],
    "sarvalokaprajāpati": ['mw'],
    "sarvalokapriyadarśana": ['bhs'],
    "sarvalokavid": ['cae', 'mw'],
    "sarvalokeśa": ['mw'],
    "sarvalokeśvara": ['mw'],
    "sarvalokin": ['mw'],
    "sarvalokāgrabhūta": ['bhs'],
    "sarvalokāntarātman": ['mw'],
    "sarvaluṇṭāka": ['mw'],
    "sarvalā": ['ap90', 'mw'],
    "sarvalālasa": ['mw'],
    "sarvalī": ['mw'],
    "sarvam": ['mw'],
    "sarvamahat": ['mw'],
    "sarvamahāpṛthivīrājamaṇiraśmipramuktā": ['bhs'],
    "sarvamahī": ['mw'],
    "sarvamalāpagata": ['bhs', 'mw'],
    "sarvamanorama": ['cae', 'mw'],
    "sarvamantraśāpavimocana": ['mw'],
    "sarvamantropayuktaparibhāṣā": ['mw'],
    "sarvamantrotkīlana": ['mw'],
    "sarvamantrotkīlanaśāpavimocanastotra": ['mw'],
    "sarvamaya": ['cae', 'mw'],
    "sarvamaṃsāda": ['mw'],
    "sarvamaṅgala": ['cae', 'mw'],
    "sarvamaṅgalamantrapaṭala": ['mw'],
    "sarvamaṅgalā": ['mw'],
    "sarvamaṇiratnasamuccaya": ['bhs'],
    "sarvamaṇḍalasādhanī": ['mw'],
    "sarvambhari": ['mw'],
    "sarvamedha": ['cae', 'mw'],
    "sarvamedhya": ['mw'],
    "sarvamedhyatva": ['mw'],
    "sarvamitra": ['bhs', 'mw'],
    "sarvamukha": ['mw'],
    "sarvamukhatva": ['mw'],
    "sarvamāgadhaka": ['mw'],
    "sarvamānyacampū": ['mw'],
    "sarvamāramaṇḍalapramardanaghoṣa": ['bhs'],
    "sarvamāramaṇḍalavidhvaṃsanajñānamudrā": ['mw'],
    "sarvamāramaṇḍalavidhvaṃsanakarī": ['mw'],
    "sarvamāramaṇḍalavikiraṇajñānadhvaja": ['bhs'],
    "sarvamātrikāpuṣpāñjali": ['mw'],
    "sarvamātrā": ['mw'],
    "sarvamātṛ": ['mw'],
    "sarvamāya": ['mw'],
    "sarvamāṃsāda": ['cae'],
    "sarvamūlya": ['mw'],
    "sarvamūrdhanya": ['mw'],
    "sarvamūrti": ['mw'],
    "sarvamūṣaka": ['mw'],
    "sarvamṛtyu": ['mw'],
    "sarvanagararakṣāsaṃbhavatejaḥśrī": ['bhs'],
    "sarvanakṣatreṣṭi": ['mw'],
    "sarvanara": ['cae', 'mw'],
    "sarvanidhana": ['mw'],
    "sarvanikṣepā": ['bhs', 'mw'],
    "sarvanilaya": ['mw'],
    "sarvanirodhavirodhasaṃpraśamana": ['bhs'],
    "sarvanirākṛti": ['mw'],
    "sarvanivaraṇaviṣkambhin": ['mw'],
    "sarvaniyantṛ": ['cae', 'mw'],
    "sarvaniyantṛtva": ['mw'],
    "sarvaniyojaka": ['mw'],
    "sarvanāman": ['cae', 'mw'],
    "sarvanāmasthāna": ['mw'],
    "sarvanāmatva": ['mw'],
    "sarvanāmatā": ['mw'],
    "sarvanāmaśaktivāda": ['mw'],
    "sarvanāśa": ['cae', 'mw'],
    "sarvanāśin": ['mw'],
    "sarvanīvaraṇaviṣkambhin": ['bhs'],
    "sarvapad": ['mw'],
    "sarvapada": ['mw'],
    "sarvapaddhati": ['mw'],
    "sarvapariphulla": ['mw'],
    "sarvaparokṣa": ['mw'],
    "sarvaparus": ['mw'],
    "sarvapatha": ['mw'],
    "sarvapathīna": ['mw'],
    "sarvapathīnatā": ['mw'],
    "sarvapati": ['cae', 'mw'],
    "sarvapattrīṇa": ['mw'],
    "sarvapaścimarocanaprabha": ['bhs'],
    "sarvapaśu": ['mw'],
    "sarvapaṭṭamara": ['mw'],
    "sarvaphalatyāgacaturdaśī": ['mw'],
    "sarvaphalatyāgacaturdaśīvrata": ['mw'],
    "sarvaprabha": ['bhs'],
    "sarvaprabhu": ['cae', 'mw'],
    "sarvaprabhāsasamuccaya": ['bhs'],
    "sarvaprada": ['mw'],
    "sarvaprakāra": ['mw'],
    "sarvaprakāram": ['mw'],
    "sarvaprathamam": ['bhs', 'mw'],
    "sarvapratyakṣa": ['mw'],
    "sarvapratyayamālā": ['mw'],
    "sarvaprayatna": ['mw'],
    "sarvaprayatnena": ['mw'],
    "sarvapraṇidhānasāgaranirghoṣamaṇirājacūḍa": ['bhs'],
    "sarvapriya": ['bhs', 'mw'],
    "sarvaprāpti": ['mw'],
    "sarvaprāyaścitta": ['cae', 'mw'],
    "sarvaprāyaścittalakṣaṇa": ['mw'],
    "sarvaprāyaścittaprayoga": ['mw'],
    "sarvaprāyaścittavidhi": ['mw'],
    "sarvaprāyaścitti": ['cae', 'mw'],
    "sarvaprāyaścittīya": ['mw'],
    "sarvaprāṇa": ['mw'],
    "sarvaprāṇena": ['mw'],
    "sarvapurakṣetramāhātmya": ['mw'],
    "sarvapuruṣa": ['mw'],
    "sarvapurāṇa": ['mw'],
    "sarvapurāṇasāra": ['mw'],
    "sarvapurāṇārthasaṃgraha": ['mw'],
    "sarvapuṇya": ['mw'],
    "sarvapuṇyasamuccaya": ['bhs', 'mw'],
    "sarvapā": ['mw'],
    "sarvapāda": ['mw'],
    "sarvapālaka": ['mw'],
    "sarvapāpahara": ['mw'],
    "sarvapāparogaharaśatamānadāna": ['mw'],
    "sarvapāraśava": ['mw'],
    "sarvapārśvamukha": ['mw'],
    "sarvapārṣada": ['mw'],
    "sarvapārṣadatva": ['mw'],
    "sarvapātrīṇa": ['mw'],
    "sarvapāvana": ['mw'],
    "sarvapāñcālaka": ['mw'],
    "sarvapūjita": ['mw'],
    "sarvapūraka": ['mw'],
    "sarvapūrtikarastava": ['mw'],
    "sarvapūruṣa": ['mw'],
    "sarvapūrva": ['mw'],
    "sarvapūrṇa": ['mw'],
    "sarvapūrṇatva": ['mw'],
    "sarvapūta": ['mw'],
    "sarvapṛthvīmaya": ['mw'],
    "sarvapṛṣṭha": ['mw'],
    "sarvapṛṣṭhahautraprayoga": ['mw'],
    "sarvapṛṣṭhaprayoga": ['mw'],
    "sarvapṛṣṭheṣṭi": ['mw'],
    "sarvapṛṣṭheṣṭihautra": ['mw'],
    "sarvapṛṣṭheṣṭihautrapaddhati": ['mw'],
    "sarvapṛṣṭheṣṭiprayoga": ['mw'],
    "sarvapṛṣṭhā": ['mw'],
    "sarvapṛṣṭhāptoryāmahautraprayoga": ['mw'],
    "sarvapṛṣṭhāptoryāmaprayoga": ['mw'],
    "sarvapṛṣṭhāptoryāmasāman": ['mw'],
    "sarvarakṣaṇa": ['mw'],
    "sarvarakṣaṇakavaca": ['mw'],
    "sarvarakṣin": ['mw'],
    "sarvarakṣita": ['mw'],
    "sarvarasa": ['cae', 'mw'],
    "sarvarasottama": ['mw'],
    "sarvaratha": ['gra'],
    "sarvarathā": ['mw'],
    "sarvaratna": ['mw'],
    "sarvaratnaka": ['mw'],
    "sarvaratnamaya": ['mw'],
    "sarvaratnarucirā": ['bhs'],
    "sarvaratnasamanvita": ['mw'],
    "sarvaratnavarṇasamantaprabhāsaśrī": ['bhs'],
    "sarvaratnavicitravarṇamaṇikuṇḍala": ['bhs'],
    "sarvaratnā": ['mw'],
    "sarvarodhavirodhasampraśamana": ['mw'],
    "sarvarodhavirodhasaṃpraśamana": ['bhs'],
    "sarvaroga": ['mw'],
    "sarvaroganidāna": ['mw'],
    "sarvarogaśānti": ['mw'],
    "sarvarohita": ['mw'],
    "sarvartu": ['mw'],
    "sarvartuka": ['cae', 'mw'],
    "sarvartukavana": ['mw'],
    "sarvartuparivarta": ['mw'],
    "sarvartuphala": ['mw'],
    "sarvarutakauśalya": ['bhs', 'mw'],
    "sarvarutasaṃgrahaṇīlipi": ['bhs'],
    "sarvarutasaṃgrahiṇilipi": ['mw'],
    "sarvarāj": ['cae', 'mw'],
    "sarvarāja": ['bhs'],
    "sarvarājendra": ['mw'],
    "sarvarājendrā": ['bhs', 'mw'],
    "sarvarājya": ['cae', 'mw'],
    "sarvarāsa": ['mw'],
    "sarvarātra": ['cae', 'mw'],
    "sarvarātram": ['mw'],
    "sarvarī": ['ap90', 'mw'],
    "sarvarūpa": ['cae', 'mw'],
    "sarvarūpabhāj": ['mw'],
    "sarvarūpasaṃdarśana": ['bhs', 'mw'],
    "sarvarūpasaṃdarśanā": ['bhs'],
    "sarvarūpatā": ['mw'],
    "sarvarūpin": ['mw'],
    "sarvasaguṇa": ['mw'],
    "sarvasaha": ['bhs', 'cae', 'mw'],
    "sarvasahā": ['mw'],
    "sarvasamarpaṇastotra": ['mw'],
    "sarvasamatā": ['cae', 'mw'],
    "sarvasambhava": ['mw'],
    "sarvasammataśikṣā": ['mw'],
    "sarvasampad": ['mw'],
    "sarvasampanna": ['mw'],
    "sarvasampannasasya": ['mw'],
    "sarvasampatti": ['mw'],
    "sarvasampradāyābhedasiddhānta": ['mw'],
    "sarvasampāta": ['mw'],
    "sarvasamādhisāgarāvabhāsasiṃha": ['bhs'],
    "sarvasamāhara": ['mw'],
    "sarvasamāsa": ['mw'],
    "sarvasamṛddha": ['mw'],
    "sarvasanta": ['bhs'],
    "sarvasara": ['mw'],
    "sarvasasya": ['mw'],
    "sarvasasyabhū": ['mw'],
    "sarvasasyavat": ['mw'],
    "sarvasattvacittacaritānugata": ['bhs'],
    "sarvasattvakuśalamūlanigarjitasvara": ['bhs'],
    "sarvasattvapriyadarśana": ['bhs', 'mw'],
    "sarvasattvapāpajahana": ['bhs', 'mw'],
    "sarvasattvatrātar": ['bhs'],
    "sarvasattvatrātṛ": ['mw'],
    "sarvasattvaujohārī": ['mw'],
    "sarvasattvojohārī": ['bhs'],
    "sarvasattvāvabhāsateja": ['bhs'],
    "sarvasatya": ['mw'],
    "sarvasauvarṇa": ['mw'],
    "sarvasaṃgata": ['mw'],
    "sarvasaṃgraha": ['mw'],
    "sarvasaṃhāra": ['cae', 'mw'],
    "sarvasaṃhārin": ['cae', 'mw'],
    "sarvasaṃjñā": ['bhs', 'mw'],
    "sarvasaṃnahana": ['mw'],
    "sarvasaṃnahanārthaka": ['mw'],
    "sarvasaṃnāha": ['mw'],
    "sarvasaṃsargalavaṇa": ['mw'],
    "sarvasaṃstha": ['cae', 'mw'],
    "sarvasaṃsthā": ['mw'],
    "sarvasaṃsthāna": ['mw'],
    "sarvasaṃśliṣṭa": ['mw'],
    "sarvasaṅgaparityāga": ['mw'],
    "sarvasaṅgā": ['mw'],
    "sarvasena": ['cae', 'gra', 'mw'],
    "sarvasenādhinātha": ['mw'],
    "sarvasenāpati": ['mw'],
    "sarvasiddhi": ['mw'],
    "sarvasiddhā": ['mw'],
    "sarvasiddhānta": ['mw'],
    "sarvasiddhāntasaṃgraha": ['mw'],
    "sarvasiddhārtha": ['cae', 'mw'],
    "sarvasmṛt": ['mw'],
    "sarvasmṛti": ['mw'],
    "sarvasmṛtisaṃgraha": ['mw'],
    "sarvastenakṛt": ['cae'],
    "sarvasteyakṛt": ['mw'],
    "sarvasthānagavāṭa": ['mw'],
    "sarvastoma": ['mw'],
    "sarvasukhaduḥkhanirabhinandin": ['bhs', 'mw'],
    "sarvasukhakṛt": ['mw'],
    "sarvasukhāya": ['mw'],
    "sarvasulabha": ['mw'],
    "sarvasurabhi": ['mw'],
    "sarvasva": ['cae', 'mw'],
    "sarvasvadakṣiṇa": ['mw'],
    "sarvasvadaṇḍa": ['mw'],
    "sarvasvaharaṇa": ['mw'],
    "sarvasvahāra": ['mw'],
    "sarvasvaphalin": ['mw'],
    "sarvasvarahasya": ['mw'],
    "sarvasvaralakṣaṇa": ['mw'],
    "sarvasvarita": ['mw'],
    "sarvasvarāṅgarutaghoṣaśrī": ['bhs'],
    "sarvasvarṇamaya": ['mw'],
    "sarvasvin": ['mw'],
    "sarvasvā": ['mw'],
    "sarvasvāmiguṇopeta": ['mw'],
    "sarvasvāmin": ['mw'],
    "sarvasvāra": ['mw'],
    "sarvasvāya": ['mw'],
    "sarvasāda": ['mw'],
    "sarvasādhana": ['mw'],
    "sarvasādhu": ['cae', 'mw'],
    "sarvasādhuniṣevita": ['mw'],
    "sarvasādhāraṇa": ['mw'],
    "sarvasādhāraṇaprayoga": ['mw'],
    "sarvasāha": ['mw'],
    "sarvasākṣin": ['mw'],
    "sarvasāmprata": ['mw'],
    "sarvasāmrājyamedhasahasranāman": ['mw'],
    "sarvasāmya": ['mw'],
    "sarvasāmānya": ['mw'],
    "sarvasāra": ['mw'],
    "sarvasāranirṇaya": ['mw'],
    "sarvasārasaṃgraha": ['mw'],
    "sarvasārasaṃgrahaṇī": ['bhs', 'mw'],
    "sarvasāraṅga": ['mw'],
    "sarvasāropaniṣad": ['mw'],
    "sarvasūkta": ['mw'],
    "sarvasūkṣma": ['mw'],
    "sarvasūtra": ['mw'],
    "sarvata": ['cae', 'mw'],
    "sarvatamonuda": ['mw'],
    "sarvatantra": ['mw'],
    "sarvatantramaya": ['mw'],
    "sarvatantrasiddhānta": ['mw'],
    "sarvatantraśiromaṇi": ['mw'],
    "sarvatanu": ['cae', 'mw'],
    "sarvatanū": ['cae', 'mw'],
    "sarvatapomaya": ['mw'],
    "sarvatara": ['mw'],
    "sarvatas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sarvatathāgata": ['mw'],
    "sarvatathāgatabandhanajñānamudrā": ['mw'],
    "sarvatathāgatadharmacakranirghoṣacūḍa": ['bhs'],
    "sarvatathāgatadharmavāṅniṣprapañcajñānamudrā": ['mw'],
    "sarvatathāgataprabhāmaṇḍalapramuñcanamaṇiratnanigarjitacūḍa": ['bhs'],
    "sarvatathāgataprabhāmaṇḍalavairocanā": ['bhs'],
    "sarvatathāgataprajñājñānamudrā": ['mw'],
    "sarvatathāgatasamājādhiṣṭhānajñānamudrā": ['mw'],
    "sarvatathāgatasaṃtoṣaṇī": ['bhs', 'mw'],
    "sarvatathāgatasiṃhāsanasaṃpratiṣṭhitamaṇimakuṭa": ['bhs'],
    "sarvatathāgatasuratasukhā": ['bhs', 'mw'],
    "sarvatathāgatavajrābhiṣekajñānamudrā": ['mw'],
    "sarvatathāgatavikurvitapratibhāsadhvajamaṇirājajālasaṃchāditacūḍa": ['bhs'],
    "sarvatathāgataviśvakarmajñānamudrā": ['mw'],
    "sarvatathāgatavyavalokana": ['mw'],
    "sarvatathāgatākarṣaṇī": ['bhs', 'mw'],
    "sarvatathāgatānurāgaṇajñānamudrā": ['mw'],
    "sarvatathāgatānurāgaṇī": ['bhs', 'mw'],
    "sarvatathāgatāśāparipūraṇajñānamudrā": ['mw'],
    "sarvataś": ['mw'],
    "sarvataścakṣus": ['mw'],
    "sarvataḥ": ['mw'],
    "sarvataḥpāṇipāda": ['ddsa', 'mw'],
    "sarvataḥsarvendriyaśakti": ['mw'],
    "sarvataḥśrutimat": ['mw'],
    "sarvataḥśubhā": ['mw'],
    "sarvatejas": ['mw'],
    "sarvatejomaya": ['cae', 'mw'],
    "sarvathā": ['ap90', 'cae', 'ddsa', 'mw'],
    "sarvathāviṣaya": ['mw'],
    "sarvati": ['mw'],
    "sarvatiktā": ['mw'],
    "sarvato": ['mw'],
    "sarvatobhadra": ['cae', 'mw'],
    "sarvatobhadracakra": ['mw'],
    "sarvatobhadracakravyākhyāna": ['mw'],
    "sarvatobhadradevatāsthāpanaprayoga": ['mw'],
    "sarvatobhadrahoma": ['mw'],
    "sarvatobhadraka": ['mw'],
    "sarvatobhadralakṣaṇa": ['mw'],
    "sarvatobhadraliṅgatobhadra": ['mw'],
    "sarvatobhadramaṇḍala": ['mw'],
    "sarvatobhadramaṇḍaladevatāmantra": ['mw'],
    "sarvatobhadramaṇḍalakrama": ['mw'],
    "sarvatobhadramaṇḍalādikārikā": ['mw'],
    "sarvatobhadraphalavicāra": ['mw'],
    "sarvatobhadraprayoga": ['mw'],
    "sarvatobhadrikā": ['mw'],
    "sarvatobhadrā": ['mw'],
    "sarvatobhadrādicakrāvali": ['mw'],
    "sarvatobhāva": ['mw'],
    "sarvatodhura": ['mw'],
    "sarvatodhāra": ['mw'],
    "sarvatodikka": ['mw'],
    "sarvatodikkam": ['mw'],
    "sarvatodiśam": ['cae', 'mw'],
    "sarvatodiśas": ['mw'],
    "sarvatogāmin": ['ddsa', 'mw'],
    "sarvatokṣiśiromukha": ['mw'],
    "sarvatomukha": ['cae', 'mw'],
    "sarvatomukhakārikā": ['mw'],
    "sarvatomukhapaddhati": ['mw'],
    "sarvatomukhaprakaraṇa": ['mw'],
    "sarvatomukhaprayoga": ['mw'],
    "sarvatomukhaudgātraprayoga": ['mw'],
    "sarvatomukhodgatṛtva": ['mw'],
    "sarvatomārgam": ['mw'],
    "sarvatovilāsa": ['mw'],
    "sarvatovṛtta": ['cae', 'mw'],
    "sarvatra": ['ap90', 'cae', 'ddsa', 'mw'],
    "sarvatraga": ['cae', 'mw'],
    "sarvatragata": ['cae', 'mw'],
    "sarvatragāmin": ['mw'],
    "sarvatragāminīpratipattijñānabala": ['mw'],
    "sarvatraiṣṭubha": ['mw'],
    "sarvatraka": ['bhs'],
    "sarvatrasattva": ['mw'],
    "sarvatratāye": ['bhs'],
    "sarvatryadhvanāmacakranirghoṣacūḍa": ['bhs'],
    "sarvatrāpi": ['mw'],
    "sarvatrāpratigha": ['mw'],
    "sarvatva": ['cae', 'mw'],
    "sarvatyāga": ['cae', 'ddsa', 'mw'],
    "sarvatā": ['cae', 'ddsa', 'mw'],
    "sarvatāpana": ['mw'],
    "sarvatāt": ['gra'],
    "sarvatāti": ['cae', 'gra', 'mw'],
    "sarvatātā": ['mw'],
    "sarvatīkṣṇa": ['mw'],
    "sarvatīrtha": ['mw'],
    "sarvatīrthamaya": ['mw'],
    "sarvatīrthayātrāvidhi": ['mw'],
    "sarvatīrtheśvara": ['mw'],
    "sarvatīrthātmaka": ['mw'],
    "sarvatūryaninādin": ['mw'],
    "sarvaugha": ['mw'],
    "sarvauṣadha": ['cae', 'mw'],
    "sarvauṣadhanidāna": ['mw'],
    "sarvauṣadhi": ['bhs', 'cae', 'ddsa', 'mw'],
    "sarvauṣadhigaṇa": ['mw'],
    "sarvauṣadhiniṣyandā": ['bhs', 'mw'],
    "sarvauṣadhirasa": ['mw'],
    "sarvauṣadhivarga": ['mw'],
    "sarvauṣadhī": ['mw'],
    "sarvavaidalyasaṃgraha": ['bhs', 'mw'],
    "sarvavaināśika": ['mw'],
    "sarvavajradharamantra": ['bhs'],
    "sarvavallabha": ['mw'],
    "sarvavallabhā": ['mw'],
    "sarvavani": ['mw'],
    "sarvavarman": ['mw'],
    "sarvavartikā": ['mw'],
    "sarvavarṇa": ['cae', 'mw'],
    "sarvavarṇikā": ['mw'],
    "sarvavarṇin": ['mw'],
    "sarvavat": ['mw'],
    "sarvaveda": ['mw'],
    "sarvavedamaya": ['mw'],
    "sarvavedas": ['cae', 'mw'],
    "sarvavedasa": ['cae', 'mw'],
    "sarvavedasadakṣiṇa": ['mw'],
    "sarvavedasin": ['mw'],
    "sarvavedatrirātra": ['mw'],
    "sarvavedin": ['mw'],
    "sarvaveditṛ": ['mw'],
    "sarvavedārtha": ['mw'],
    "sarvavedātman": ['mw'],
    "sarvavega": ['mw'],
    "sarvavettṛ": ['mw'],
    "sarvavettṛtva": ['mw'],
    "sarvaveṣin": ['mw'],
    "sarvavibhūti": ['mw'],
    "sarvavid": ['cae', 'mw'],
    "sarvavidya": ['cae', 'mw'],
    "sarvavidyā": ['mw'],
    "sarvavidyālaṃkāra": ['mw'],
    "sarvavidyāmaya": ['mw'],
    "sarvavidyāsiddhāntavarṇana": ['mw'],
    "sarvavidyāvinoda": ['mw'],
    "sarvavidyāvinodabhaṭṭācārya": ['mw'],
    "sarvavigraha": ['mw'],
    "sarvavihārīyayantra": ['mw'],
    "sarvavijñāna": ['mw'],
    "sarvavijñānatā": ['mw'],
    "sarvavijñānin": ['mw'],
    "sarvavijñānitā": ['mw'],
    "sarvavikhyāta": ['mw'],
    "sarvavikrayin": ['cae', 'mw'],
    "sarvavikṣepatā": ['bhs', 'mw'],
    "sarvavinda": ['mw'],
    "sarvavināśa": ['mw'],
    "sarvavittva": ['mw'],
    "sarvaviśrambhin": ['mw'],
    "sarvaviśva": ['mw'],
    "sarvaviṣaya": ['mw'],
    "sarvaviṣayāvabhāsālaṃkārapratibhānadarśanagarbha": ['bhs'],
    "sarvaviṣṭutiprayoga": ['mw'],
    "sarvavrata": ['cae', 'mw'],
    "sarvavratodyāpana": ['mw'],
    "sarvavratodyāpanaprayoga": ['mw'],
    "sarvavyādhicikitsaka": ['bhs'],
    "sarvavyāpad": ['cae', 'mw'],
    "sarvavyāpin": ['cae', 'mw'],
    "sarvavyāpitva": ['mw'],
    "sarvavyūharatisvabhāvanayasaṃdarśana": ['bhs', 'mw'],
    "sarvavyūhālaṃkārapratibhāsasaṃdarśanagarbha": ['bhs'],
    "sarvavādin": ['mw'],
    "sarvavādisammata": ['mw'],
    "sarvavāgīśvareśvara": ['mw'],
    "sarvavāram": ['mw'],
    "sarvavārṣikaparvan": ['mw'],
    "sarvavāsa": ['mw'],
    "sarvavāsaka": ['mw'],
    "sarvavāsin": ['mw'],
    "sarvavātasaha": ['mw'],
    "sarvavāṅmaya": ['mw'],
    "sarvavāṅnidhana": ['mw'],
    "sarvavīra": ['cae', 'gra', 'mw'],
    "sarvavīrabhaṭṭāraka": ['mw'],
    "sarvavīrajit": ['mw'],
    "sarvavīrya": ['mw'],
    "sarvavṛddha": ['mw'],
    "sarvavṛkṣapraphullanasukhasaṃvāsā": ['bhs'],
    "sarvayajña": ['mw'],
    "sarvayamaka": ['mw'],
    "sarvayantrin": ['mw'],
    "sarvayatna": ['cae', 'mw'],
    "sarvayatnavat": ['mw'],
    "sarvayatnena": ['mw'],
    "sarvayogin": ['mw'],
    "sarvayoni": ['cae', 'mw'],
    "sarvayonitva": ['mw'],
    "sarvayoṣit": ['mw'],
    "sarvaśabdaga": ['mw'],
    "sarvaśaikyāyasa": ['mw'],
    "sarvaśak": ['mw'],
    "sarvaśakti": ['cae', 'mw'],
    "sarvaśaktyā": ['mw'],
    "sarvaśarīra": ['cae', 'mw'],
    "sarvaśarīratā": ['mw'],
    "sarvaśarīryātman": ['mw'],
    "sarvaśas": ['ap90', 'cae', 'ddsa', 'mw'],
    "sarvaśastrin": ['mw'],
    "sarvaśaṅkā": ['mw'],
    "sarvaśeṣa": ['mw'],
    "sarvaśilparāja": ['bhs'],
    "sarvaśiṣya": ['mw'],
    "sarvaśiṣyatā": ['mw'],
    "sarvaśokavināśin": ['mw'],
    "sarvaśokāpagata": ['bhs'],
    "sarvaśreṣṭha": ['cae', 'mw'],
    "sarvaśrutipurāṇasārasaṃgraha": ['mw'],
    "sarvaśrāvya": ['mw'],
    "sarvaśubhaṃkara": ['mw'],
    "sarvaśuddhavāla": ['mw'],
    "sarvaśukla": ['mw'],
    "sarvaśveta": ['cae', 'mw'],
    "sarvaśvetā": ['bhs', 'mw'],
    "sarvaśākuna": ['mw'],
    "sarvaśānti": ['mw'],
    "sarvaśāntikṛt": ['mw'],
    "sarvaśāntiprayoga": ['mw'],
    "sarvaśāsa": ['cae', 'gra', 'mw'],
    "sarvaśāstra": ['mw'],
    "sarvaśāstramaya": ['mw'],
    "sarvaśāstrapravetṛ": ['mw'],
    "sarvaśāstravid": ['mw'],
    "sarvaśāstraviśārada": ['mw'],
    "sarvaśāstrārthanirṇaya": ['mw'],
    "sarvaśīghra": ['cae', 'mw'],
    "sarvaśūnya": ['cae', 'ddsa', 'mw'],
    "sarvaśūnyatva": ['mw'],
    "sarvaśūnyatvavādin": ['mw'],
    "sarvaśūnyatā": ['mw'],
    "sarvaśūra": ['bhs', 'mw'],
    "sarvaṃdada": ['bhs', 'mw'],
    "sarvaṃdama": ['mw'],
    "sarvaṃdamana": ['mw'],
    "sarvaṃdamaḥ": ['ap90'],
    "sarvaṃhara": ['mw'],
    "sarvaṃjaya": ['bhs'],
    "sarvaṃkaṣa": ['ap90', 'cae', 'mw'],
    "sarvaṃkaṣā": ['mw'],
    "sarvaṃsaha": ['bhs', 'cae', 'ddsa', 'mw'],
    "sarvaṃsahā": ['mw'],
    "sarvehi": ['bhs'],
    "sarvela": ['mw'],
    "sarvendriyasambhava": ['mw'],
    "sarveśa": ['cae', 'mw'],
    "sarveśvara": ['cae', 'ddsa', 'mw'],
    "sarveśvarastutiratnamālā": ['mw'],
    "sarveśvaratattvanirṇaya": ['mw'],
    "sarveśvaratva": ['mw'],
    "sarveśā": ['mw'],
    "sarveṇa": ['bhs'],
    "sarveṣṭada": ['mw'],
    "sarvocchedana": ['ddsa', 'mw'],
    "sarvocchitti": ['cae', 'mw'],
    "sarvodaya": ['bhs'],
    "sarvodyukta": ['mw'],
    "sarvodātta": ['mw'],
    "sarvollāsatantra": ['mw'],
    "sarvopadha": ['mw'],
    "sarvopakārin": ['mw'],
    "sarvopakāriṇī": ['mw'],
    "sarvopaniṣad": ['mw'],
    "sarvopaniṣadarthānubhūtiprakāśa": ['mw'],
    "sarvopaniṣatsāra": ['mw'],
    "sarvopaniṣatsārapraśnottara": ['mw'],
    "sarvoparama": ['cae', 'mw'],
    "sarvoparamatva": ['mw'],
    "sarvopādhi": ['mw'],
    "sarvopāyakauśalyapraveśana": ['mw'],
    "sarvorutrivedin": ['mw'],
    "sarvotkarṣa": ['mw'],
    "sarvottama": ['mw'],
    "sarvottamastotra": ['mw'],
    "sarvottaratvābhidhāna": ['mw'],
    "sarvotuka": ['bhs'],
    "sarvābharaṇabhūṣita": ['mw'],
    "sarvābharaṇavat": ['mw'],
    "sarvābhayaprada": ['mw'],
    "sarvābhayaṃkara": ['mw'],
    "sarvābhibhū": ['bhs', 'mw'],
    "sarvābhisaṃdhaka": ['cae', 'mw'],
    "sarvābhisaṃdhin": ['mw'],
    "sarvābhisāra": ['cae', 'mw'],
    "sarvābhiśaṅkin": ['mw'],
    "sarvābhiśaṅkitva": ['mw'],
    "sarvābhyantara": ['mw'],
    "sarvābhāva": ['cae', 'mw'],
    "sarvācāra": ['mw'],
    "sarvācārya": ['mw'],
    "sarvādbhutaśānti": ['mw'],
    "sarvādhika": ['mw'],
    "sarvādhikaraṇa": ['mw'],
    "sarvādhikaraṇeṣu": ['mw'],
    "sarvādhikya": ['mw'],
    "sarvādhikāra": ['mw'],
    "sarvādhikārin": ['mw'],
    "sarvādhipatya": ['mw'],
    "sarvādhyakṣa": ['mw'],
    "sarvādhāra": ['mw'],
    "sarvādi": ['mw'],
    "sarvādya": ['mw'],
    "sarvādṛśa": ['mw'],
    "sarvāgamopaniṣad": ['mw'],
    "sarvāgneya": ['mw'],
    "sarvāgrayaṇakālanirṇaya": ['mw'],
    "sarvāhammānin": ['mw'],
    "sarvāhna": ['mw'],
    "sarvāhṇa": ['cae', 'mw'],
    "sarvāhṇam": ['mw'],
    "sarvāhṇika": ['mw'],
    "sarvājīva": ['cae', 'mw'],
    "sarvākaraprabhākara": ['mw'],
    "sarvākaraprabhākaravaropeta": ['mw'],
    "sarvākāra": ['ddsa', 'mw'],
    "sarvākārajñatā": ['bhs'],
    "sarvākāram": ['mw'],
    "sarvākāraprabhākara": ['bhs'],
    "sarvākāraraśmikusuma": ['bhs'],
    "sarvākāravaropeta": ['bhs'],
    "sarvākāśatalāsaṃbhedavijñaptimaṇiratnavibhūṣitacūḍa": ['bhs'],
    "sarvākṣa": ['mw'],
    "sarvālokakara": ['mw'],
    "sarvāmaratva": ['mw'],
    "sarvāmbhonidhi": ['mw'],
    "sarvāmātya": ['mw'],
    "sarvānanda": ['mw'],
    "sarvānavadyakāriṇī": ['mw'],
    "sarvānavadyāṅga": ['cae', 'mw'],
    "sarvānnabhakṣaka": ['mw'],
    "sarvānnabhojin": ['mw'],
    "sarvānnabhūti": ['mw'],
    "sarvānnin": ['mw'],
    "sarvānnīna": ['mw'],
    "sarvānta": ['bhs', 'mw'],
    "sarvāntaka": ['mw'],
    "sarvāntakṛt": ['mw'],
    "sarvāntara": ['mw'],
    "sarvāntarastha": ['mw'],
    "sarvāntaryāmin": ['mw'],
    "sarvāntarātman": ['mw'],
    "sarvānte": ['mw'],
    "sarvānubhū": ['cae', 'mw'],
    "sarvānubhūti": ['mw'],
    "sarvānudātta": ['mw'],
    "sarvānudāttatva": ['mw'],
    "sarvānukrama": ['cae', 'mw'],
    "sarvānukramaṇikā": ['cae', 'mw'],
    "sarvānukramaṇī": ['cae', 'mw'],
    "sarvānukramaṇīvṛtti": ['mw'],
    "sarvānukārin": ['mw'],
    "sarvānukāriṇī": ['mw'],
    "sarvānumati": ['mw'],
    "sarvānunāsika": ['mw'],
    "sarvānusyūta": ['mw'],
    "sarvānusyūtatva": ['mw'],
    "sarvānuṣṭubha": ['mw'],
    "sarvānya": ['mw'],
    "sarvāparatva": ['mw'],
    "sarvāpekṣa": ['mw'],
    "sarvāpti": ['cae', 'mw'],
    "sarvāpuṣṭiprayoga": ['mw'],
    "sarvārambha": ['mw'],
    "sarvārambheṇa": ['mw'],
    "sarvāraṇyaka": ['mw'],
    "sarvārhaṇa": ['mw'],
    "sarvāriṣṭaśānti": ['mw'],
    "sarvārtha": ['cae', 'mw'],
    "sarvārthacintaka": ['mw'],
    "sarvārthacintāmaṇi": ['mw'],
    "sarvārthadarśa": ['bhs', 'mw'],
    "sarvārthadarśin": ['bhs'],
    "sarvārthakartṛ": ['mw'],
    "sarvārthakuśala": ['mw'],
    "sarvārtham": ['mw'],
    "sarvārthanāman": ['bhs', 'mw'],
    "sarvārthasiddha": ['bhs', 'cae', 'mw'],
    "sarvārthasiddhi": ['mw'],
    "sarvārthasādhaka": ['cae', 'mw'],
    "sarvārthasādhakastotra": ['mw'],
    "sarvārthasādhana": ['mw'],
    "sarvārthasādhikā": ['mw'],
    "sarvārthasārasaṃgraha": ['mw'],
    "sarvārthatva": ['mw'],
    "sarvārthatā": ['mw'],
    "sarvārtheṣu": ['mw'],
    "sarvārthānusādhin": ['mw'],
    "sarvārthānusādhinī": ['mw'],
    "sarvārtuka": ['bhs'],
    "sarvāsambhava": ['mw'],
    "sarvāstitvavādin": ['mw'],
    "sarvāstivāda": ['bhs', 'mw'],
    "sarvāstivādin": ['mw'],
    "sarvāstra": ['mw'],
    "sarvāstramahājvālā": ['mw'],
    "sarvāstravid": ['mw'],
    "sarvāstrā": ['mw'],
    "sarvāsya": ['mw'],
    "sarvātisārin": ['mw'],
    "sarvātithi": ['mw'],
    "sarvātithivrata": ['mw'],
    "sarvātithya": ['mw'],
    "sarvātiśāyin": ['mw'],
    "sarvātmabhūti": ['cae', 'mw'],
    "sarvātmadṛś": ['mw'],
    "sarvātmaka": ['mw'],
    "sarvātmakatva": ['mw'],
    "sarvātmakena": ['mw'],
    "sarvātman": ['cae', 'mw'],
    "sarvātmanā": ['mw'],
    "sarvātmatva": ['mw'],
    "sarvātmatvadarśana": ['mw'],
    "sarvātodyaparigraha": ['mw'],
    "sarvāvant": ['bhs', 'cae'],
    "sarvāvaraṇavikiraṇajñānavikrāmin": ['bhs'],
    "sarvāvasara": ['mw'],
    "sarvāvasaram": ['mw'],
    "sarvāvastham": ['cae'],
    "sarvāvasthā": ['mw'],
    "sarvāvasu": ['mw'],
    "sarvāvat": ['mw'],
    "sarvāvatham": ['mw'],
    "sarvāvāsa": ['cae', 'mw'],
    "sarvāvāsin": ['cae', 'mw'],
    "sarvāvṛddha": ['mw'],
    "sarvāyasa": ['mw'],
    "sarvāyu": ['cae', 'mw'],
    "sarvāyudha": ['mw'],
    "sarvāyudhopeta": ['mw'],
    "sarvāyus": ['cae', 'mw'],
    "sarvāyutva": ['mw'],
    "sarvāyuṣa": ['cae', 'mw'],
    "sarvāñc": ['mw'],
    "sarvāśaya": ['mw'],
    "sarvāścaryamaya": ['cae', 'mw'],
    "sarvāśin": ['cae', 'mw'],
    "sarvāśramin": ['mw'],
    "sarvāśraya": ['mw'],
    "sarvāśya": ['mw'],
    "sarvāṅga": ['cae', 'gra', 'mw'],
    "sarvāṅgabhaṅga": ['mw'],
    "sarvāṅgam": ['mw'],
    "sarvāṅganyāsa": ['mw'],
    "sarvāṅgarūpa": ['mw'],
    "sarvāṅgasundara": ['mw'],
    "sarvāṅgasundararasa": ['mw'],
    "sarvāṅgasundarī": ['mw'],
    "sarvāṅgavedanāsāmānyakarmaprakāśa": ['mw'],
    "sarvāṅgayogadīpikā": ['mw'],
    "sarvāṅgika": ['cae', 'mw'],
    "sarvāṅgīṇa": ['cae', 'mw'],
    "sarvāṅka": ['mw'],
    "sarvāṇī": ['ap90', 'mw'],
    "sarvīya": ['mw'],
    "sarā": ['ddsa', 'mw'],
    "sarāga": ['ap90', 'cae', 'cped', 'mw'],
    "sarāgam": ['mw'],
    "sarāganetra": ['mw'],
    "sarāgatva": ['mw'],
    "sarāgatā": ['mw'],
    "sarāhu": ['mw'],
    "sarājaka": ['cae', 'mw'],
    "sarājan": ['cae', 'mw'],
    "sarājika": ['cped'],
    "sarāpura": ['bhs'],
    "sarārī": ['mw'],
    "sarāsara": ['mw'],
    "sarāthin": ['cae'],
    "sarāti": ['cae', 'gra', 'mw'],
    "sarātri": ['mw'],
    "sarātrim": ['bhs'],
    "sarāva": ['ap90', 'mw'],
    "sarāvatī": ['bhs'],
    "sarāṣṭra": ['mw'],
    "sarāṣṭraka": ['mw'],
    "sarāṭa": ['mw'],
    "sarī": ['mw'],
    "sarīman": ['ap90', 'cae', 'gra', 'mw'],
    "sarīra": ['cped'],
    "sarīradhātu": ['cped'],
    "sarīrakicca": ['cped'],
    "sarīramaṁsa": ['cped'],
    "sarīranissanda": ['cped'],
    "sarīrappabhā": ['cped'],
    "sarīrasaṇṭhāna": ['cped'],
    "sarīravalañja": ['cped'],
    "sarīravalañjaṭṭhāna": ['cped'],
    "sarīravant": ['cped'],
    "sarīravaṇṇa": ['cped'],
    "sarīraṭṭha": ['cped'],
    "sarīsapa": ['cped'],
    "sarīsṛp": ['mw'],
    "sarīsṛpa": ['cae', 'ddsa', 'gra', 'mw'],
    "sarīsṛpaḥ": ['ap90'],
    "sarīḍham": ['mw'],
    "sarūpa": ['ap90', 'cae', 'cped', 'gra', 'mw'],
    "sarūpakṛt": ['mw'],
    "sarūpatva": ['mw'],
    "sarūpatā": ['ap90', 'cped', 'mw'],
    "sarūpavatsā": ['mw'],
    "sarūpaya": ['mw'],
    "sarūpaṃkaraṇa": ['mw'],
    "sarūpin": ['mw'],
    "sarūpopamā": ['mw'],
    "sarūpā": ['mw'],
    "sar̥ṣika": ['ddsa'],
    "sarṇīka": ['cae', 'mw'],
    "sarṇṇa": ['mw'],
    "sarṣapa": ['cae', 'ddsa', 'mw'],
    "sarṣapaka": ['mw'],
    "sarṣapakanda": ['mw'],
    "sarṣapakaṇa": ['mw'],
    "sarṣapakī": ['mw'],
    "sarṣapamiśra": ['mw'],
    "sarṣapasneha": ['mw'],
    "sarṣapataila": ['cae', 'mw'],
    "sarṣapaśāka": ['mw'],
    "sarṣapaḥ": ['ap90'],
    "sarṣapika": ['mw'],
    "sarṣapikā": ['mw'],
    "sarṣapāruṇa": ['mw'],
    "sarṣapāya": ['mw'],
    "sarṣapī": ['mw'],
    "sarṣigaṇa": ['mw'],
    "sarṣimarudgaṇa": ['mw'],
    "sarṣīkā": ['mw'],
    "sarṣṭika": ['mw'],
    "sas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sasa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sasabhya": ['cae', 'mw'],
    "sasaciva": ['cae', 'mw'],
    "sasadbhāva": ['mw'],
    "sasahāya": ['cae', 'mw'],
    "sasainya": ['cae', 'mw'],
    "sasainyabalavāhana": ['mw'],
    "sasakhi": ['mw'],
    "sasakhīgaṇā": ['mw'],
    "sasakhījanā": ['cae'],
    "sasakhīkā": ['cae', 'mw'],
    "sasakkaṁ": ['cped'],
    "sasalakkhaṇa": ['cped'],
    "sasalañchana": ['cped'],
    "sasambhrama": ['mw'],
    "sasambhramam": ['mw'],
    "sasambhāra": ['cped'],
    "sasambhārayajuṣka": ['mw'],
    "sasamidgaṇa": ['mw'],
    "sasampad": ['mw'],
    "sasampada": ['mw'],
    "sasampraiṣa": ['mw'],
    "sasampātin": ['mw'],
    "sasanaṃ": ['ap90'],
    "sasaptadvīpa": ['mw'],
    "sasaptaka": ['mw'],
    "sasarpa": ['mw'],
    "sasarparī": ['gra', 'mw'],
    "sasasya": ['mw'],
    "sasati": ['cped'],
    "sasattha": ['cped'],
    "sasattrin": ['cae', 'mw'],
    "sasattva": ['ap90', 'cae', 'mw'],
    "sasattvā": ['mw'],
    "sasatya": ['mw'],
    "sasaurabha": ['cae', 'mw'],
    "sasaurāṣṭra": ['mw'],
    "sasavas": ['ddsa', 'gra', 'mw'],
    "sasavisāṇa": ['cped'],
    "sasaṃbhrama": ['ap90', 'cae'],
    "sasaṃdeha": ['ap90', 'mw'],
    "sasaṃdhya": ['ap90', 'cae', 'mw'],
    "sasaṃdhyāśa": ['cae'],
    "sasaṃdhyāṃśa": ['mw'],
    "sasaṃgraha": ['mw'],
    "sasaṃhāra": ['mw'],
    "sasaṃjña": ['cae', 'mw'],
    "sasaṃkaṭa": ['mw'],
    "sasaṃketa": ['cae', 'mw'],
    "sasaṃnāma": ['mw'],
    "sasaṃrambha": ['cae', 'ddsa', 'mw'],
    "sasaṃrambham": ['mw'],
    "sasaṃtatika": ['mw'],
    "sasaṃtāna": ['cae', 'mw'],
    "sasaṃvid": ['mw'],
    "sasaṃvāda": ['mw'],
    "sasaṃvādam": ['mw'],
    "sasaṃśaya": ['cae', 'mw'],
    "sasaṅga": ['mw'],
    "sasaṅgatva": ['mw'],
    "sasaṅka": ['cped'],
    "sasaṭa": ['mw'],
    "sasena": ['cped', 'mw'],
    "sasita": ['mw'],
    "sasitopala": ['mw'],
    "sasitotpalamālin": ['cae', 'mw'],
    "sasj": ['ap90'],
    "sasmaya": ['cae', 'mw'],
    "sasmayam": ['mw'],
    "sasmeram": ['cae', 'mw'],
    "sasmita": ['ap90', 'cae', 'mw'],
    "sasmitam": ['mw'],
    "sasneha": ['cae', 'ddsa', 'mw'],
    "sasnehabahumāna": ['mw'],
    "sasneham": ['mw'],
    "sasni": ['cae', 'ddsa', 'gra', 'mw'],
    "sasnitama": ['mw'],
    "sasoma": ['cae', 'mw'],
    "sasomapītha": ['mw'],
    "sasomatva": ['mw'],
    "sasphuliṅga": ['mw'],
    "sasphura": ['mw'],
    "saspiñjara": ['mw'],
    "saspṛha": ['ap90', 'cae', 'mw'],
    "saspṛham": ['mw'],
    "sasra": ['cae', 'ddsa', 'gra', 'mw'],
    "sasraj": ['mw'],
    "sasri": ['cae', 'ddsa', 'gra', 'mw'],
    "sasrotas": ['cae', 'mw'],
    "sasrut": ['cae', 'gra', 'mw'],
    "sasrīvṛkṣa": ['mw'],
    "sassa": ['cped'],
    "sassakamma": ['cped'],
    "sassakāla": ['cped'],
    "sassamaṇabrāhmaṇa": ['cped'],
    "sassata": ['cped'],
    "sassatadiṭṭhi": ['cped'],
    "sassatavāda": ['cped'],
    "sassatavādī": ['cped'],
    "sassati": ['cped'],
    "sassatika": ['cped'],
    "sassirīka": ['cped'],
    "sassu": ['cped'],
    "sassāmika": ['cped'],
    "sastara": ['mw'],
    "sasthaṇḍilaka": ['mw'],
    "sasthāna": ['mw'],
    "sasthāsnucārin": ['mw'],
    "sasthāvan": ['mw'],
    "sasthāṇujaṅgama": ['mw'],
    "sasthūṇa": ['cae', 'mw'],
    "sasthūṇacchinna": ['mw'],
    "sastrīka": ['cae', 'mw'],
    "sastutaśastra": ['mw'],
    "sasubrahmaṇya": ['mw'],
    "sasudarśana": ['mw'],
    "sasugandha": ['cae', 'mw'],
    "sasugandhigātra": ['mw'],
    "sasuhṛd": ['mw'],
    "sasuhṛjjana": ['mw'],
    "sasuhṛnmitrabāndhava": ['mw'],
    "sasundarīka": ['mw'],
    "sasuparṇa": ['mw'],
    "sasura": ['cae', 'cped', 'mw'],
    "sasuracāpam": ['mw'],
    "sasuta": ['cae', 'mw'],
    "sasutvan": ['mw'],
    "sasuvarṇa": ['cae', 'mw'],
    "sasvadha": ['mw'],
    "sasvana": ['cae', 'mw'],
    "sasvanam": ['mw'],
    "sasvar": ['cae', 'ddsa', 'gra', 'mw'],
    "sasvara": ['cae', 'ddsa', 'mw'],
    "sasvaram": ['mw'],
    "sasvartā": ['cae', 'gra', 'mw'],
    "sasveda": ['ap90', 'cae', 'mw'],
    "sasvedā": ['mw'],
    "sasvāhākāra": ['cae', 'mw'],
    "sasya": ['cae', 'ddsa', 'mw'],
    "sasyad": ['gra', 'mw'],
    "sasyahan": ['mw'],
    "sasyahantṛ": ['mw'],
    "sasyaka": ['ap90', 'mw'],
    "sasyakreṇī": ['mw'],
    "sasyakṣetra": ['cae', 'mw'],
    "sasyamañjarī": ['mw'],
    "sasyamālin": ['cae', 'mw'],
    "sasyamārin": ['mw'],
    "sasyaprada": ['cae', 'mw'],
    "sasyapravṛddhi": ['mw'],
    "sasyapāla": ['cae', 'mw'],
    "sasyapūrṇa": ['cae', 'mw'],
    "sasyarakṣaka": ['cae', 'mw'],
    "sasyarakṣā": ['mw'],
    "sasyasaṃvara": ['mw'],
    "sasyasaṃvaraṇa": ['mw'],
    "sasyavat": ['mw'],
    "sasyaveda": ['mw'],
    "sasyaśuka": ['mw'],
    "sasyaśālin": ['mw'],
    "sasyaśīrṣaka": ['mw'],
    "sasyaṃ": ['ap90'],
    "sasyeṣṭi": ['mw'],
    "sasyād": ['cae', 'mw'],
    "sasyānanda": ['mw'],
    "sasyānte": ['cae', 'mw'],
    "sasyāvāpa": ['cae', 'mw'],
    "sasādhana": ['mw'],
    "sasādhanopavarganirūpaṇa": ['mw'],
    "sasādhvasa": ['ap90', 'cae', 'mw'],
    "sasādhvasam": ['mw'],
    "sasādhvīka": ['cae', 'mw'],
    "sasādi": ['mw'],
    "sasāgara": ['cae', 'mw'],
    "sasākṣika": ['cae', 'ddsa', 'mw'],
    "sasākṣikam": ['mw'],
    "sasāra": ['cae', 'mw'],
    "sasārathi": ['cae', 'mw'],
    "sasāravāṇa": ['mw'],
    "sasārtha": ['cae', 'mw'],
    "sasātyaka": ['mw'],
    "sasāvarṇa": ['mw'],
    "sasāṃnāyyaka": ['mw'],
    "sasī": ['cped'],
    "sasīmaka": ['mw'],
    "sasīman": ['mw'],
    "sasīsaṁ": ['cped'],
    "sasīta": ['cae', 'mw'],
    "sasūka": ['mw'],
    "sasūnu": ['mw'],
    "sasūta": ['cae', 'mw'],
    "sasūti": ['mw'],
    "sasṛjāna": ['mw'],
    "sat": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sata": ['cae', 'cped', 'mw'],
    "satadhā": ['cped'],
    "sataka": ['cped'],
    "satakkaku": ['cped'],
    "satakkhattuṁ": ['cped'],
    "satakṣan": ['mw'],
    "satala": ['mw'],
    "satalatra": ['mw'],
    "satamaska": ['mw'],
    "satamasā": ['mw'],
    "satamūlī": ['cped'],
    "satandra": ['mw'],
    "satantra": ['mw'],
    "satanu": ['cae', 'mw'],
    "satapadī": ['cped'],
    "satapas": ['mw'],
    "satapatta": ['cped'],
    "sataporisa": ['cped'],
    "satapuññalakkhaṇa": ['cped'],
    "satapāka": ['cped'],
    "satarasa": ['bhs'],
    "sataraṁsī": ['cped'],
    "satarka": ['ap90', 'mw'],
    "satarṣa": ['mw'],
    "satarṣam": ['mw'],
    "satas": ['cae', 'ddsa', 'gra', 'mw'],
    "satasahassa": ['cped'],
    "satata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "satatadhṛti": ['cae', 'mw'],
    "satatadurgata": ['mw'],
    "satataga": ['mw'],
    "satatagata": ['cae'],
    "satatagati": ['cae', 'mw'],
    "satatajvara": ['bhs', 'mw'],
    "satataka": ['mw'],
    "satatam": ['mw'],
    "satatamānasa": ['mw'],
    "satataparigrahadharmakāṅkṣiṇī": ['bhs', 'mw'],
    "satataparigraham": ['mw'],
    "satatasamita": ['bhs'],
    "satatasamitābhiyukta": ['bhs', 'mw'],
    "satataspandana": ['mw'],
    "satatayukta": ['cae', 'mw'],
    "satatayāyin": ['cae', 'mw'],
    "satataśāstrin": ['mw'],
    "satataṁ": ['cped'],
    "satati": ['cae', 'mw'],
    "satatotthita": ['mw'],
    "satattva": ['cae', 'ddsa', 'mw'],
    "satattvaratnamālāvyākhyāna": ['mw'],
    "satattvatas": ['mw'],
    "satatābhiyoga": ['mw'],
    "sataḥ": ['mw'],
    "sataḥpaṅkti": ['mw'],
    "satejas": ['cae', 'mw'],
    "satejastva": ['mw'],
    "satejobhūta": ['bhs'],
    "satekiccha": ['cped'],
    "satera": ['mw'],
    "sateraka": ['mw'],
    "sateraḥ": ['ap90'],
    "sathuta": ['cped'],
    "sathūtkāra": ['ap90', 'mw'],
    "sati": ['cped', 'ddsa', 'mw'],
    "satila": ['mw'],
    "satimant": ['cped'],
    "satimira": ['mw'],
    "satindriya": ['cped'],
    "satipaṭṭhāna": ['cped'],
    "satisambojjhaṅga": ['cped'],
    "satisammosa": ['cped'],
    "satisamoha": ['cped'],
    "satisampajañña": ['cped'],
    "satitarā": ['mw'],
    "satiḥ": ['ap90'],
    "satkadamba": ['mw'],
    "satkalpavṛkṣa": ['mw'],
    "satkalā": ['mw'],
    "satkaratva": ['mw'],
    "satkaraṇa": ['cae', 'mw'],
    "satkarmacandrikā": ['mw'],
    "satkarmacintāmaṇi": ['mw'],
    "satkarmadarpaṇa": ['mw'],
    "satkarmadīpikā": ['mw'],
    "satkarmakalpadruma": ['mw'],
    "satkarman": ['cae', 'mw'],
    "satkartavya": ['cae', 'mw'],
    "satkartṛ": ['cae', 'mw'],
    "satkathā": ['cae', 'ddsa', 'mw'],
    "satkavi": ['cae', 'mw'],
    "satkavimiśra": ['mw'],
    "satkavitva": ['mw'],
    "satkiṣku": ['mw'],
    "satkriya": ['mw'],
    "satkriyā": ['cae', 'mw'],
    "satkriyākalpamañjarī": ['mw'],
    "satkula": ['cae', 'mw'],
    "satkulatā": ['mw'],
    "satkulodbhava": ['mw'],
    "satkulīna": ['cae', 'mw'],
    "satkāra": ['cae', 'mw'],
    "satkārya": ['cae', 'mw'],
    "satkāryavāda": ['mw'],
    "satkāryavādasiddhānta": ['mw'],
    "satkāryavādin": ['mw'],
    "satkārārha": ['mw'],
    "satkāvya": ['mw'],
    "satkāvyakalpadruma": ['mw'],
    "satkāya": ['bhs'],
    "satkāyadṛṣṭi": ['bhs', 'mw'],
    "satkāñcanāra": ['mw'],
    "satkāṇḍa": ['mw'],
    "satkīrti": ['cae', 'mw'],
    "satkīrticandrodaya": ['mw'],
    "satkṛ": ['cae', 'mw'],
    "satkṛta": ['mw'],
    "satkṛti": ['cae', 'mw'],
    "satkṛtya": ['bhs', 'mw'],
    "satkṛtyamuktāvalī": ['mw'],
    "satkṣetra": ['cae', 'mw'],
    "sato": ['mw'],
    "satobṛhant": ['cae'],
    "satobṛhat": ['ddsa', 'mw'],
    "satobṛhatī": ['mw'],
    "satoda": ['mw'],
    "satoka": ['cae', 'mw'],
    "satomaghavan": ['cae', 'mw'],
    "satomahant": ['cae'],
    "satomahat": ['gra', 'mw'],
    "satomukhā": ['mw'],
    "satoraṇa": ['mw'],
    "satovīra": ['cae', 'gra', 'mw'],
    "satpaddhati": ['mw'],
    "satpadyaratnākara": ['mw'],
    "satpakṣin": ['mw'],
    "satparigraha": ['mw'],
    "satpath": ['mw'],
    "satpatha": ['mw'],
    "satpathīna": ['mw'],
    "satpati": ['cae', 'ddsa', 'gra', 'mw'],
    "satpattra": ['mw'],
    "satpaśu": ['mw'],
    "satphala": ['mw'],
    "satphalin": ['mw'],
    "satprabhā": ['mw'],
    "satprakriyāvyākṛti": ['mw'],
    "satpramuditā": ['mw'],
    "satpratigraha": ['cae', 'mw'],
    "satpratijña": ['mw'],
    "satpratipakṣa": ['mw'],
    "satpratipakṣabādhagrantha": ['mw'],
    "satpratipakṣadeśanābhāsaprakaraṇa": ['mw'],
    "satpratipakṣagrantha": ['mw'],
    "satpratipakṣagrantharahasya": ['mw'],
    "satpratipakṣakroḍa": ['mw'],
    "satpratipakṣapattra": ['mw'],
    "satpratipakṣapūrvapakṣagranthadīdhitiṭīkā": ['mw'],
    "satpratipakṣapūrvapakṣagranthaprakāśa": ['mw'],
    "satpratipakṣapūrvapakṣagrantharahasya": ['mw'],
    "satpratipakṣapūrvapakṣagranthaṭīkā": ['mw'],
    "satpratipakṣasiddhāntagranthadīdhitiṭīkā": ['mw'],
    "satpratipakṣasiddhāntagranthaṭīkā": ['mw'],
    "satpratipakṣasiddhāntakroḍa": ['mw'],
    "satpratipakṣasiddhāntarahasya": ['mw'],
    "satpratipakṣasiddhāntānugama": ['mw'],
    "satpratipakṣatā": ['mw'],
    "satpratipakṣatāvyavahārakroḍa": ['mw'],
    "satpratipakṣavibhāga": ['mw'],
    "satpratipakṣavicāra": ['mw'],
    "satpratipakṣaviṣayatāśūnyatvavicāra": ['mw'],
    "satpratipakṣavāda": ['mw'],
    "satpratipakṣin": ['mw'],
    "satpratipakṣita": ['mw'],
    "satpratipakṣitva": ['mw'],
    "satpratipakṣitā": ['mw'],
    "satpuruṣa": ['bhs', 'cae', 'mw'],
    "satpuruṣāṣṭaka": ['mw'],
    "satputra": ['cae', 'mw'],
    "satpuṣpa": ['mw'],
    "satpātra": ['mw'],
    "satpātravarṣa": ['mw'],
    "satpātravarṣin": ['mw'],
    "satr": ['mw'],
    "satra": ['ap90', 'mw'],
    "satram": ['mw'],
    "satrapa": ['ap90', 'ddsa', 'mw'],
    "satrapam": ['mw'],
    "satre": ['gra'],
    "satrijātaka": ['mw'],
    "satrikūṭa": ['mw'],
    "satrā": ['cae', 'ddsa', 'gra', 'mw'],
    "satrāc": ['gra', 'mw'],
    "satrādāvan": ['gra', 'mw'],
    "satrāha": ['cae', 'gra', 'mw'],
    "satrāhan": ['cae', 'gra', 'mw'],
    "satrāja": ['mw'],
    "satrājit": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "satrājita": ['mw'],
    "satrākara": ['gra', 'mw'],
    "satrāsa": ['mw'],
    "satrāsah": ['cae', 'gra'],
    "satrāsaha": ['mw'],
    "satrāsam": ['ddsa', 'mw'],
    "satrāsāh": ['mw'],
    "satrāsāha": ['gra', 'mw'],
    "satrāsāhīya": ['mw'],
    "satrāyate": ['ap90'],
    "satrāñc": ['cae', 'ddsa'],
    "satsahāya": ['mw'],
    "satsampradāya": ['mw'],
    "satsampradāyapradīpikā": ['mw'],
    "satsamprayoga": ['mw'],
    "satsamāgama": ['mw'],
    "satsaṃga": ['cae'],
    "satsaṃgati": ['cae', 'mw'],
    "satsaṃgraha": ['mw'],
    "satsaṃkalpa": ['mw'],
    "satsaṃnidhāna": ['mw'],
    "satsaṃsarga": ['mw'],
    "satsaṃvinmaya": ['mw'],
    "satsaṃvinmayatva": ['mw'],
    "satsaṅga": ['ddsa', 'mw'],
    "satsaṅgavijaya": ['mw'],
    "satsi": ['ddsa'],
    "satsiddhāntamārtaṇḍa": ['mw'],
    "satsukhānubhava": ['mw'],
    "satsāra": ['mw'],
    "satta": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sattabhūmaka": ['cped'],
    "sattadasa": ['cped'],
    "sattaguṇa": ['cped'],
    "sattaka": ['cped'],
    "sattakkhattuṁ": ['cped'],
    "sattama": ['cae', 'cped', 'ddsa', 'mw'],
    "sattamatā": ['mw'],
    "sattamī": ['cped'],
    "sattapaṇṇī": ['cped'],
    "sattarasa": ['cped'],
    "sattaratana": ['cped'],
    "sattaratta": ['cped'],
    "sattarka": ['ddsa', 'mw'],
    "sattarkasiddhāñjana": ['mw'],
    "sattasattati": ['cped'],
    "sattasaṭṭhi": ['cped'],
    "sattatantimatta": ['cped'],
    "sattati": ['cped'],
    "sattatiṁsā": ['cped'],
    "sattattva": ['mw'],
    "sattattvabindu": ['mw'],
    "sattattvaratnamālā": ['mw'],
    "sattavīsati": ['cped'],
    "sattha": ['cped'],
    "satthagamanīya": ['cped'],
    "satthaka": ['cped'],
    "satthakamma": ['cped'],
    "satthakavāta": ['cped'],
    "satthavāha": ['cped'],
    "satthi": ['cped'],
    "satthu": ['cped'],
    "satti": ['cae', 'cped', 'mw'],
    "sattisūla": ['cped'],
    "sattra": ['cae', 'mw'],
    "sattragṛha": ['mw'],
    "sattrapariveṣaṇa": ['mw'],
    "sattraphalada": ['mw'],
    "sattrarāj": ['cae', 'mw'],
    "sattrasad": ['cae', 'mw'],
    "sattrasadman": ['mw'],
    "sattrasadya": ['cae', 'mw'],
    "sattratva": ['mw'],
    "sattravardhana": ['mw'],
    "sattravasati": ['mw'],
    "sattraya": ['mw'],
    "sattrayāga": ['mw'],
    "sattraśālā": ['mw'],
    "sattraṃ": ['ap90'],
    "sattri": ['mw'],
    "sattrin": ['ap90', 'cae', 'mw'],
    "sattriya": ['cae', 'mw'],
    "sattriḥ": ['ap90'],
    "sattrotthāna": ['mw'],
    "sattrya": ['mw'],
    "sattrā": ['ap90'],
    "sattrāgāra": ['mw'],
    "sattrāpaya": ['mw'],
    "sattrāpaśraya": ['mw'],
    "sattrāya": ['mw'],
    "sattrāyaṇa": ['cae', 'mw'],
    "sattrībhū": ['mw'],
    "sattrīya": ['cae', 'mw'],
    "sattu": ['cped'],
    "sattubhastā": ['cped'],
    "sattva": ['cae', 'ddsa', 'mw'],
    "sattvabhārata": ['mw'],
    "sattvadhāman": ['cae', 'mw'],
    "sattvadhātu": ['bhs', 'mw'],
    "sattvagaganacittapratibhāsabimba": ['bhs'],
    "sattvaguṇa": ['mw'],
    "sattvaguṇin": ['mw'],
    "sattvahara": ['mw'],
    "sattvaka": ['mw'],
    "sattvakartṛ": ['cae', 'ddsa', 'mw'],
    "sattvakaṣāya": ['mw'],
    "sattvalakṣaṇā": ['cae', 'mw'],
    "sattvaloka": ['mw'],
    "sattvamaya": ['cae', 'mw'],
    "sattvamejaya": ['ap90', 'mw'],
    "sattvamūrti": ['mw'],
    "sattvapati": ['mw'],
    "sattvapradhāna": ['mw'],
    "sattvaprakāśa": ['mw'],
    "sattvarājan": ['bhs'],
    "sattvarāśi": ['cae', 'mw'],
    "sattvasaha": ['bhs'],
    "sattvasampanna": ['mw'],
    "sattvasamplava": ['mw'],
    "sattvasamāviṣṭa": ['mw'],
    "sattvasarga": ['mw'],
    "sattvasaṃrambha": ['mw'],
    "sattvasaṃśuddhi": ['mw'],
    "sattvastha": ['cae', 'mw'],
    "sattvasthāna": ['mw'],
    "sattvasāra": ['bhs', 'mw'],
    "sattvatā": ['mw'],
    "sattvavant": ['cae'],
    "sattvavara": ['mw'],
    "sattvavat": ['ap90', 'mw'],
    "sattvavatī": ['bhs', 'mw'],
    "sattvavihita": ['mw'],
    "sattvaviplava": ['mw'],
    "sattvavṛtti": ['mw'],
    "sattvaśabda": ['cae'],
    "sattvaśālin": ['cae', 'mw'],
    "sattvaśīla": ['mw'],
    "sattvaṃ": ['ap90'],
    "sattvocchrita": ['mw'],
    "sattvodreka": ['mw'],
    "sattvodrikta": ['mw'],
    "sattvotkarṣa": ['cae', 'mw'],
    "sattvotsāha": ['mw'],
    "sattvotsāhavat": ['mw'],
    "sattvottarajñānin": ['bhs'],
    "sattvādhika": ['mw'],
    "sattvādhīna": ['mw'],
    "sattvānurūpa": ['mw'],
    "sattvātman": ['mw'],
    "sattvāvajaya": ['mw'],
    "sattvāvāsa": ['bhs'],
    "sattā": ['ap90', 'cae', 'ddsa', 'mw'],
    "sattāha": ['cped'],
    "sattājātiprāmāṇya": ['mw'],
    "sattāka": ['mw'],
    "sattākatva": ['mw'],
    "sattāmātra": ['mw'],
    "sattāmātrātman": ['mw'],
    "sattāvat": ['mw'],
    "sattāvāpya": ['mw'],
    "sattṛ": ['cae', 'ddsa', 'mw'],
    "satuhina": ['ddsa', 'mw'],
    "satuṅga": ['mw'],
    "satuṣa": ['mw'],
    "satvac": ['cae', 'mw'],
    "satvaca": ['mw'],
    "satvacas": ['cae', 'mw'],
    "satvakka": ['cae', 'mw'],
    "satvan": ['cae', 'ddsa', 'gra', 'mw'],
    "satvana": ['cae', 'gra', 'mw'],
    "satvanāyat": ['mw'],
    "satvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "satvaram": ['mw'],
    "satvararacanam": ['mw'],
    "satvarataram": ['mw'],
    "satvaratva": ['mw'],
    "satvaratā": ['mw'],
    "satvaritam": ['mw'],
    "satvat": ['ddsa', 'mw'],
    "satvata": ['mw'],
    "satvāsiñcāmiprayoga": ['mw'],
    "satvī": ['mw'],
    "satya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "satyabandha": ['mw'],
    "satyabhedin": ['mw'],
    "satyabhāmā": ['cae', 'mw'],
    "satyabhāmābhyudaya": ['mw'],
    "satyabhāmābhyudayakāvya": ['mw'],
    "satyabhāmābhyudayavyākhyāna": ['mw'],
    "satyabhāmāpariṇaya": ['mw'],
    "satyabhāmāvilāsa": ['mw'],
    "satyabhānu": ['bhs'],
    "satyabhārata": ['mw'],
    "satyabhāṣaṇa": ['cae', 'mw'],
    "satyabhūya": ['cae', 'mw'],
    "satyabodha": ['mw'],
    "satyabodhaparamahaṃsaparivrājaka": ['mw'],
    "satyabodhatīrtha": ['mw'],
    "satyabodhavijayastotra": ['mw'],
    "satyacūḍāmaṇi": ['mw'],
    "satyadarśin": ['bhs', 'cae', 'mw'],
    "satyadeva": ['mw'],
    "satyadhana": ['mw'],
    "satyadhara": ['mw'],
    "satyadharma": ['cae', 'mw'],
    "satyadharman": ['cae', 'gra', 'mw'],
    "satyadharmaparāyaṇa": ['mw'],
    "satyadharmapatha": ['mw'],
    "satyadharmatīrtha": ['mw'],
    "satyadharmavipulakīrti": ['bhs', 'mw'],
    "satyadhvaja": ['mw'],
    "satyadhvajāvatāra": ['mw'],
    "satyadhvṛt": ['gra', 'mw'],
    "satyadhāman": ['mw'],
    "satyadhṛta": ['mw'],
    "satyadhṛti": ['cae', 'mw'],
    "satyadūta": ['mw'],
    "satyadṛś": ['bhs', 'cae', 'mw'],
    "satyaga": ['mw'],
    "satyaghna": ['mw'],
    "satyagir": ['cae', 'mw'],
    "satyagirvāhas": ['gra', 'mw'],
    "satyagranthin": ['mw'],
    "satyahavis": ['mw'],
    "satyahavya": ['mw'],
    "satyahita": ['mw'],
    "satyajit": ['cae', 'mw'],
    "satyajiti": ['cae', 'mw'],
    "satyajyotis": ['mw'],
    "satyajña": ['cae', 'mw'],
    "satyajñānānandatīrtha": ['mw'],
    "satyajā": ['mw'],
    "satyaka": ['ap90', 'bhs', 'ddsa', 'mw'],
    "satyakarman": ['cae', 'gra', 'mw'],
    "satyakarṇa": ['mw'],
    "satyaketu": ['bhs', 'mw'],
    "satyakhāna": ['mw'],
    "satyakriyā": ['mw'],
    "satyakāma": ['cae', 'mw'],
    "satyakāmatīrtha": ['mw'],
    "satyakāruṇyavedin": ['mw'],
    "satyakāya": ['mw'],
    "satyakīrti": ['mw'],
    "satyakṛt": ['mw'],
    "satyakṣetramāhātmya": ['mw'],
    "satyalaukika": ['mw'],
    "satyaloka": ['cae', 'mw'],
    "satyam": ['mw'],
    "satyamadvan": ['gra', 'mw'],
    "satyamanman": ['cae', 'gra', 'mw'],
    "satyamantra": ['cae', 'gra', 'mw'],
    "satyamaudgala": ['mw'],
    "satyamaya": ['cae', 'mw'],
    "satyambharā": ['mw'],
    "satyamedhas": ['mw'],
    "satyamugra": ['bhs', 'cae', 'gra', 'mw'],
    "satyamāna": ['mw'],
    "satyamūla": ['cae'],
    "satyamṛṣāviveka": ['mw'],
    "satyanetra": ['mw'],
    "satyanidhi": ['mw'],
    "satyanidhitīrtha": ['mw'],
    "satyanidhivilāsa": ['mw'],
    "satyanāma": ['bhs', 'mw'],
    "satyanāman": ['cae', 'mw'],
    "satyanāmatā": ['mw'],
    "satyanārāyaṇa": ['mw'],
    "satyanārāyaṇakathā": ['mw'],
    "satyanārāyaṇavratakathā": ['mw'],
    "satyanātha": ['mw'],
    "satyanāthamāhātmyaratnākara": ['mw'],
    "satyanāthastuti": ['mw'],
    "satyanāthatīrtha": ['mw'],
    "satyanāthavilāsa": ['mw'],
    "satyanāthayati": ['mw'],
    "satyanāthābhyudaya": ['mw'],
    "satyapa": ['mw'],
    "satyapara": ['mw'],
    "satyaparākrama": ['cae', 'mw'],
    "satyaparākramatīrtha": ['mw'],
    "satyaparāyaṇatīrtha": ['mw'],
    "satyaphala": ['mw'],
    "satyaprabha": ['bhs'],
    "satyaprabodhabhaṭṭāraka": ['mw'],
    "satyaprasava": ['cae', 'mw'],
    "satyaprasavas": ['cae', 'mw'],
    "satyapratijña": ['cae', 'mw'],
    "satyapratiśrava": ['mw'],
    "satyapratiṣṭhāna": ['mw'],
    "satyapravāda": ['mw'],
    "satyapriyatīrtha": ['mw'],
    "satyaprāśū": ['mw'],
    "satyapura": ['mw'],
    "satyapuṣṭi": ['cae', 'mw'],
    "satyapāla": ['mw'],
    "satyapāramitā": ['mw'],
    "satyapāśa": ['mw'],
    "satyapūrṇatīrtha": ['mw'],
    "satyapūta": ['mw'],
    "satyarata": ['mw'],
    "satyaratha": ['mw'],
    "satyarathi": ['mw'],
    "satyarathā": ['mw'],
    "satyarādhas": ['cae', 'gra', 'mw'],
    "satyarājan": ['cae', 'mw'],
    "satyarūpa": ['mw'],
    "satyasad": ['mw'],
    "satyasah": ['mw'],
    "satyasahas": ['mw'],
    "satyasatvan": ['cae', 'gra', 'mw'],
    "satyasatī": ['mw'],
    "satyasava": ['cae', 'gra', 'mw'],
    "satyasavana": ['mw'],
    "satyasavas": ['cae', 'mw'],
    "satyasaṃdha": ['cae', 'mw'],
    "satyasaṃdhatā": ['mw'],
    "satyasaṃdhatīrtha": ['mw'],
    "satyasaṃdhā": ['mw'],
    "satyasaṃgara": ['cae', 'mw'],
    "satyasaṃhita": ['mw'],
    "satyasaṃkalpa": ['cae', 'mw'],
    "satyasaṃkalpatva": ['mw'],
    "satyasaṃkalpatīrtha": ['mw'],
    "satyasaṃkāśa": ['mw'],
    "satyasaṃnibha": ['mw'],
    "satyasaṃrakṣaṇa": ['mw'],
    "satyasaṃrakṣin": ['mw'],
    "satyasaṃtuṣṭatīrtha": ['mw'],
    "satyasaṃśrava": ['mw'],
    "satyasena": ['mw'],
    "satyasravas": ['mw'],
    "satyastha": ['mw'],
    "satyasvapna": ['mw'],
    "satyasvapnatā": ['mw'],
    "satyasādhana": ['mw'],
    "satyasākṣin": ['mw'],
    "satyasāman": ['mw'],
    "satyasāra": ['mw'],
    "satyasūtra": ['mw'],
    "satyatama": ['mw'],
    "satyatapas": ['mw'],
    "satyatara": ['mw'],
    "satyatas": ['cae', 'mw'],
    "satyatitikṣāvat": ['mw'],
    "satyatva": ['mw'],
    "satyatā": ['cae', 'mw'],
    "satyatāt": ['cae', 'gra', 'mw'],
    "satyatāti": ['cae', 'gra', 'mw'],
    "satyaujas": ['cae', 'mw'],
    "satyavac": ['gra'],
    "satyavaca": ['bhs'],
    "satyavacana": ['bhs', 'cae', 'mw'],
    "satyavacanārtham": ['mw'],
    "satyavacas": ['mw'],
    "satyavadana": ['cae', 'mw'],
    "satyavadanaśīla": ['mw'],
    "satyavadya": ['mw'],
    "satyavaktṛ": ['mw'],
    "satyavant": ['cae'],
    "satyavara": ['mw'],
    "satyavaratīrtha": ['mw'],
    "satyavardhana": ['bhs'],
    "satyavarman": ['mw'],
    "satyavartman": ['mw'],
    "satyavaryārya": ['mw'],
    "satyavasu": ['mw'],
    "satyavat": ['ap90', 'mw'],
    "satyavatī": ['mw'],
    "satyavatīputra": ['cae'],
    "satyavatīsuta": ['mw'],
    "satyavidyā": ['mw'],
    "satyavijayatīrtha": ['mw'],
    "satyavijayaśiṣya": ['mw'],
    "satyavikrama": ['cae', 'mw'],
    "satyavrata": ['cae', 'mw'],
    "satyavrataparāyaṇa": ['mw'],
    "satyavratasmṛti": ['mw'],
    "satyavratatīrtha": ['mw'],
    "satyavyavasthā": ['mw'],
    "satyavāc": ['cae', 'gra', 'mw'],
    "satyavācaka": ['cae', 'mw'],
    "satyavāda": ['cae', 'mw'],
    "satyavādin": ['cae', 'mw'],
    "satyavādinī": ['bhs', 'mw'],
    "satyavāditva": ['mw'],
    "satyavāditā": ['mw'],
    "satyavāha": ['mw'],
    "satyavāhana": ['mw'],
    "satyavāka": ['cae', 'mw'],
    "satyavākya": ['bhs', 'cae', 'mw'],
    "satyavākyatā": ['mw'],
    "satyavīratīrtha": ['mw'],
    "satyavṛdh": ['mw'],
    "satyavṛtta": ['mw'],
    "satyavṛtti": ['mw'],
    "satyayaj": ['cae', 'gra', 'mw'],
    "satyayajña": ['cae', 'mw'],
    "satyayauvana": ['mw'],
    "satyayoni": ['cae', 'gra', 'mw'],
    "satyayuga": ['mw'],
    "satyayugādyā": ['mw'],
    "satyaśapatha": ['mw'],
    "satyaśavas": ['cae', 'gra', 'mw'],
    "satyaśravas": ['cae', 'gra', 'mw'],
    "satyaśrut": ['cae', 'gra', 'mw'],
    "satyaśrāvaṇa": ['mw'],
    "satyaśrī": ['mw'],
    "satyaśuṣma": ['cae', 'gra', 'mw'],
    "satyaśīla": ['cae', 'mw'],
    "satyaśīlin": ['cae', 'mw'],
    "satyaṃkāra": ['cae', 'mw'],
    "satyaṃkārakṛta": ['mw'],
    "satyaṃkāraḥ": ['ap90'],
    "satyaṃvaca": ['bhs'],
    "satyepsu": ['mw'],
    "satyetara": ['mw'],
    "satyeyu": ['mw'],
    "satyeśasthāpanapūjā": ['mw'],
    "satyeṣṭatīrtha": ['mw'],
    "satyodaka": ['mw'],
    "satyodya": ['mw'],
    "satyokti": ['cae', 'ddsa', 'gra', 'mw'],
    "satyopayācana": ['mw'],
    "satyopākhyāna": ['mw'],
    "satyotkarṣa": ['mw'],
    "satyottara": ['mw'],
    "satyā": ['ap90', 'mw'],
    "satyābharaṇa": ['bhs'],
    "satyābhidhyāyin": ['mw'],
    "satyābhidhāna": ['mw'],
    "satyābhinavatīrtha": ['mw'],
    "satyābhinavodaya": ['mw'],
    "satyābhisaṃdha": ['mw'],
    "satyābhisaṃdhin": ['mw'],
    "satyābhisaṃdhāna": ['mw'],
    "satyābhiyācana": ['mw'],
    "satyābhiyācanā": ['bhs', 'mw'],
    "satyācārya": ['mw'],
    "satyādhiṣṭhāna": ['bhs'],
    "satyāgni": ['mw'],
    "satyākṛ": ['ap90', 'mw'],
    "satyākṛti": ['mw'],
    "satyākṛtiḥ": ['ap90'],
    "satyālāpin": ['cae', 'mw'],
    "satyānanda": ['mw'],
    "satyānandacidātman": ['mw'],
    "satyānandacidātmatā": ['mw'],
    "satyānandanātha": ['mw'],
    "satyānandaparamahaṃsaparivrājaka": ['mw'],
    "satyānandatīrtha": ['mw'],
    "satyānurakta": ['mw'],
    "satyānṛta": ['cae', 'gra', 'mw'],
    "satyāpana": ['ddsa', 'mw'],
    "satyāpanaṃ": ['ap90'],
    "satyāpariṇaya": ['mw'],
    "satyāpariṇayakāvya": ['mw'],
    "satyāpaya": ['ddsa', 'mw'],
    "satyātmaja": ['mw'],
    "satyātmaka": ['cae', 'mw'],
    "satyātman": ['cae', 'mw'],
    "satyāvan": ['mw'],
    "satyāvatāra": ['bhs'],
    "satyāyana": ['mw'],
    "satyāyu": ['mw'],
    "satyāśis": ['mw'],
    "satyāśraya": ['mw'],
    "satyāṅga": ['mw'],
    "satyāṣāḍha": ['mw'],
    "satyāṣāḍhahiraṇyakeśin": ['mw'],
    "satyāṣāḍhaprayoga": ['mw'],
    "satyāṣāḍhī": ['mw'],
    "satāgiri": ['bhs'],
    "satālavṛnta": ['mw'],
    "satānanda": ['mw'],
    "satānūnaptrin": ['mw'],
    "satāpa": ['ddsa', 'mw'],
    "satāra": ['mw'],
    "satārā": ['mw'],
    "satāsat": ['mw'],
    "satī": ['ap90', 'cped', 'ddsa', 'mw'],
    "satīdehatyāga": ['mw'],
    "satīka": ['mw'],
    "satīla": ['mw'],
    "satīlaka": ['mw'],
    "satīlakaḥ": ['ap90'],
    "satīlaḥ": ['ap90'],
    "satīlā": ['mw'],
    "satīna": ['cae', 'gra', 'mw'],
    "satīnaka": ['mw'],
    "satīnakaṅkata": ['gra', 'mw'],
    "satīnamanyu": ['gra', 'mw'],
    "satīnasatvan": ['gra', 'mw'],
    "satīnaḥ": ['ap90'],
    "satīpratiṣṭhā": ['mw'],
    "satīputra": ['mw'],
    "satīrtha": ['cae', 'mw'],
    "satīrthaḥ": ['ap90'],
    "satīrthya": ['cae', 'mw'],
    "satīsaras": ['mw'],
    "satītva": ['mw'],
    "satītvaṃ": ['ap90'],
    "satītā": ['mw'],
    "satīvrata": ['mw'],
    "satīvratā": ['mw'],
    "satīvṛtti": ['mw'],
    "satīya": ['mw'],
    "satīśvara": ['mw'],
    "satīśvaraliṅga": ['mw'],
    "satūla": ['mw'],
    "satūrya": ['cae', 'mw'],
    "satūryam": ['mw'],
    "satṛṇa": ['cae', 'mw'],
    "satṛṇam": ['mw'],
    "satṛṇābhyavahārin": ['cae', 'mw'],
    "satṛṣ": ['mw'],
    "satṛṣa": ['mw'],
    "satṛṣṇa": ['mw'],
    "satṛṣṇam": ['cae', 'mw'],
    "sat‍tra": ['ddsa'],
    "sat‍trin": ['ddsa'],
    "sat‍trāyaṇa": ['ddsa'],
    "saubala": ['cae', 'ddsa', 'mw'],
    "saubalaka": ['mw'],
    "saubalaḥ": ['ap90'],
    "saubaleya": ['cae', 'mw'],
    "saubaleyī": ['mw'],
    "saubalya": ['mw'],
    "saubalī": ['ap90', 'mw'],
    "saubha": ['cae', 'ddsa', 'mw'],
    "saubhadra": ['bhs', 'cae', 'ddsa', 'mw'],
    "saubhadraḥ": ['ap90'],
    "saubhadreya": ['mw'],
    "saubhadvār": ['mw'],
    "saubhadvāra": ['mw'],
    "saubhaga": ['cae', 'ddsa', 'gra', 'mw'],
    "saubhagatva": ['cae', 'gra', 'mw'],
    "saubhagaṃ": ['ap90'],
    "saubhaki": ['mw'],
    "saubhanivāsin": ['mw'],
    "saubhapati": ['mw'],
    "saubhara": ['ddsa', 'mw'],
    "saubhari": ['mw'],
    "saubharisaṃhitā": ['mw'],
    "saubharāj": ['mw'],
    "saubharāja": ['mw'],
    "saubharāyaṇa": ['mw'],
    "saubharī": ['mw'],
    "saubhava": ['mw'],
    "saubhaṃ": ['ap90'],
    "saubheya": ['mw'],
    "saubheṣaja": ['mw'],
    "saubhika": ['mw'],
    "saubhikaḥ": ['ap90'],
    "saubhikṣa": ['mw'],
    "saubhikṣya": ['mw'],
    "saubhrava": ['mw'],
    "saubhrātra": ['cae', 'ddsa', 'mw'],
    "saubhrātraṃ": ['ap90'],
    "saubhādhipati": ['mw'],
    "saubhāgineya": ['mw'],
    "saubhāgineyaḥ": ['ap90'],
    "saubhāgya": ['cae', 'ddsa', 'gra', 'mw'],
    "saubhāgyabhāskara": ['mw'],
    "saubhāgyacihna": ['mw'],
    "saubhāgyacintāmaṇi": ['mw'],
    "saubhāgyadevatā": ['cae', 'mw'],
    "saubhāgyagaurīvratavidhi": ['mw'],
    "saubhāgyaghaṇṭā": ['mw'],
    "saubhāgyahṛdaya": ['mw'],
    "saubhāgyakalpadruma": ['mw'],
    "saubhāgyakalpalatā": ['mw'],
    "saubhāgyakavaca": ['mw'],
    "saubhāgyakramadīpikā": ['mw'],
    "saubhāgyakāṇḍa": ['mw'],
    "saubhāgyalaharī": ['mw'],
    "saubhāgyalakṣmyupaniṣad": ['mw'],
    "saubhāgyalakṣmīkalpeśyāmalāmbāstotra": ['mw'],
    "saubhāgyalakṣmītantreśyāmalāmbāvarmaratna": ['mw'],
    "saubhāgyalatikāpaddhati": ['mw'],
    "saubhāgyamada": ['mw'],
    "saubhāgyamañjarī": ['mw'],
    "saubhāgyamālāmantra": ['mw'],
    "saubhāgyaphala": ['mw'],
    "saubhāgyaratnākara": ['mw'],
    "saubhāgyasundarītīrtha": ['mw'],
    "saubhāgyasundarīvratakathā": ['mw'],
    "saubhāgyatantra": ['mw'],
    "saubhāgyatantrapārāyaṇavidhi": ['mw'],
    "saubhāgyatantu": ['mw'],
    "saubhāgyatṛtīyā": ['mw'],
    "saubhāgyavardhinī": ['mw'],
    "saubhāgyavat": ['ap90', 'mw'],
    "saubhāgyavattva": ['mw'],
    "saubhāgyavattā": ['mw'],
    "saubhāgyavatī": ['mw'],
    "saubhāgyavidyeśvarastotra": ['mw'],
    "saubhāgyavidyā": ['mw'],
    "saubhāgyavilopin": ['mw'],
    "saubhāgyavrata": ['mw'],
    "saubhāgyavāyana": ['mw'],
    "saubhāgyaśayanavrata": ['mw'],
    "saubhāgyaśayanavratakathā": ['mw'],
    "saubhāgyaśubhodaya": ['mw'],
    "saubhāgyaśuṇṭhī": ['mw'],
    "saubhāgyaṃ": ['ap90'],
    "saubhāgyodaya": ['mw'],
    "saubhāgyopaniṣad": ['mw'],
    "saubhāgyārcanakalpalatā": ['mw'],
    "saubhāgyāṣṭaka": ['mw'],
    "saubhāgyāṣṭakatṛtīyāvrata": ['mw'],
    "saubhāsika": ['bhs', 'mw'],
    "saubhāsinika": ['mw'],
    "saubhāñjana": ['mw'],
    "saubhāṣaṇika": ['bhs'],
    "saubhīkaḥ": ['ap90'],
    "saubhūta": ['mw'],
    "saucakya": ['mw'],
    "sauci": ['mw'],
    "saucika": ['ddsa', 'mw'],
    "saucikya": ['mw'],
    "saucitti": ['mw'],
    "sauciḥ": ['ap90'],
    "saucuka": ['mw'],
    "saucīka": ['mw'],
    "saudaka": ['cped'],
    "saudakṣa": ['mw'],
    "saudakṣeya": ['mw'],
    "saudanteya": ['mw'],
    "saudanti": ['mw'],
    "saudarya": ['cae', 'ddsa', 'mw'],
    "saudaryaṃ": ['ap90'],
    "saudarśana": ['mw'],
    "saudarśanika": ['mw'],
    "saudarśanīya": ['mw'],
    "saudatta": ['mw'],
    "sauddesa": ['cped'],
    "saudeva": ['mw'],
    "saudevika": ['mw'],
    "saudha": ['ap90', 'cae', 'ddsa', 'mw'],
    "saudhakāra": ['mw'],
    "saudhamauli": ['mw'],
    "saudhamūrdhan": ['mw'],
    "saudhanvana": ['cae', 'ddsa', 'gra', 'mw'],
    "saudhanya": ['mw'],
    "saudharma": ['mw'],
    "saudharmaja": ['mw'],
    "saudharmendra": ['mw'],
    "saudharmya": ['cae', 'ddsa', 'mw'],
    "saudhatala": ['mw'],
    "saudhavāsa": ['mw'],
    "saudhaśikhara": ['mw'],
    "saudhotaki": ['mw'],
    "saudhotsaṅga": ['mw'],
    "saudhāgra": ['mw'],
    "saudhākara": ['ddsa', 'mw'],
    "saudhāla": ['mw'],
    "saudhālaya": ['mw'],
    "saudhāmitrika": ['mw'],
    "saudhāra": ['mw'],
    "saudhāta": ['mw'],
    "saudhātaki": ['mw'],
    "saudhātakyā": ['mw'],
    "saudhāvati": ['mw'],
    "saudhāvatāna": ['mw'],
    "saudhāvatānika": ['mw'],
    "saudhāya": ['mw'],
    "saudhāṅgaṇa": ['ddsa', 'mw'],
    "saudhṛteya": ['mw'],
    "saudyumni": ['mw'],
    "saudāmanī": ['ap90', 'cae', 'ddsa', 'mw'],
    "saudāmeya": ['mw'],
    "saudāminī": ['cae', 'ddsa', 'mw'],
    "saudāminīya": ['mw'],
    "saudāmnī": ['mw'],
    "saudāsa": ['cae', 'ddsa', 'mw'],
    "saudāsaka": ['bhs'],
    "saudāsi": ['mw'],
    "saudāyika": ['ap90', 'mw'],
    "saugamya": ['mw'],
    "saugamyaṃ": ['ap90'],
    "saugandha": ['mw'],
    "saugandhaka": ['mw'],
    "saugandhika": ['cae', 'ddsa', 'mw'],
    "saugandhikavana": ['mw'],
    "saugandhikavat": ['mw'],
    "saugandhikā": ['bhs', 'mw'],
    "saugandhikāharaṇa": ['mw'],
    "saugandhikāpariṇaya": ['mw'],
    "saugandhikāvivaraṇavyākhyā": ['mw'],
    "saugandhya": ['cae', 'mw'],
    "saugandhī": ['bhs'],
    "saugata": ['bhs', 'cae', 'ddsa', 'mw'],
    "saugataḥ": ['ap90'],
    "saugatika": ['mw'],
    "saugatikaḥ": ['ap90'],
    "saugaṃdha": ['ap90'],
    "saugaṃdhika": ['ap90'],
    "saugaṃdhyaṃ": ['ap90'],
    "sauhaviṣa": ['mw'],
    "sauhitya": ['cae', 'ddsa', 'mw'],
    "sauhityaṃ": ['ap90'],
    "sauhma": ['ddsa', 'mw'],
    "sauhmanāgara": ['mw'],
    "sauhotra": ['mw'],
    "sauhotri": ['mw'],
    "sauhārda": ['cae', 'ddsa', 'mw'],
    "sauhārdanidhi": ['mw'],
    "sauhārdavyañjaka": ['mw'],
    "sauhārdaḥ": ['ap90'],
    "sauhārdya": ['cae', 'ddsa', 'mw'],
    "sauhārdyaṃ": ['ap90'],
    "sauhṛda": ['cae', 'ddsa', 'mw'],
    "sauhṛdaya": ['mw'],
    "sauhṛdayya": ['mw'],
    "sauhṛdya": ['cae', 'mw'],
    "saujanya": ['cae', 'ddsa', 'mw'],
    "saujanyavat": ['mw'],
    "saujanyaṃ": ['ap90'],
    "saujas": ['mw'],
    "saujaska": ['mw'],
    "saujāmi": ['ddsa', 'mw'],
    "saujāta": ['ddsa', 'mw'],
    "saukanya": ['mw'],
    "saukara": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "saukaraka": ['mw'],
    "saukarasadma": ['mw'],
    "saukaratīrtha": ['mw'],
    "saukarika": ['bhs', 'mw'],
    "saukarya": ['cae', 'ddsa', 'mw'],
    "saukaryaṃ": ['ap90'],
    "saukarāyaṇa": ['mw'],
    "saukarīya": ['mw'],
    "saukha": ['mw'],
    "saukharātrika": ['mw'],
    "saukhasuptika": ['mw'],
    "saukhasuptikaḥ": ['ap90'],
    "saukhavatī": ['mw'],
    "saukhayānika": ['mw'],
    "saukhaśayyika": ['mw'],
    "saukhaśāyanika": ['ddsa', 'mw'],
    "saukhaśāyanikaḥ": ['ap90'],
    "saukhaśāyika": ['mw'],
    "saukhika": ['ap90', 'mw'],
    "saukhya": ['cae', 'ddsa', 'mw'],
    "saukhyada": ['mw'],
    "saukhyadāyaka": ['mw'],
    "saukhyadāyin": ['mw'],
    "saukhyaśāyika": ['mw'],
    "saukhyaṃ": ['ap90'],
    "saukhyāspada": ['mw'],
    "saukhīya": ['mw'],
    "saukti": ['mw'],
    "sauktika": ['mw'],
    "saukumāra": ['cae'],
    "saukumāraka": ['mw'],
    "saukumārya": ['cae', 'ddsa', 'mw'],
    "saukumāryaṃ": ['ap90'],
    "saukṛti": ['mw'],
    "saukṛtya": ['cae', 'gra', 'mw'],
    "saukṛtyāyana": ['mw'],
    "saukṣma": ['mw'],
    "saukṣmaka": ['mw'],
    "saukṣmya": ['cae', 'ddsa', 'mw'],
    "saukṣmyatva": ['mw'],
    "saukṣmyaṃ": ['ap90'],
    "saulabha": ['mw'],
    "saulabhya": ['ddsa', 'mw'],
    "saulabhyaṃ": ['ap90'],
    "saulabhāyana": ['mw'],
    "saulakṣaṇya": ['ddsa', 'mw'],
    "sauloha": ['mw'],
    "saulohya": ['mw'],
    "saulvika": ['mw'],
    "saulvikaḥ": ['ap90'],
    "saulābha": ['mw'],
    "saulābhya": ['mw'],
    "sauma": ['cae', 'mw'],
    "saumadatti": ['cae', 'ddsa', 'mw'],
    "saumadāyana": ['mw'],
    "saumaki": ['mw'],
    "saumakratava": ['mw'],
    "saumakratavīya": ['mw'],
    "saumamitrika": ['mw'],
    "saumana": ['ddsa', 'mw'],
    "saumanasa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "saumanasya": ['cae', 'mw'],
    "saumanasyaka": ['bhs'],
    "saumanasyavat": ['mw'],
    "saumanasyaṃ": ['ap90'],
    "saumanasyāyanī": ['ap90', 'mw'],
    "saumanasā": ['ap90', 'mw'],
    "saumanasāyana": ['mw'],
    "saumanasāyanī": ['mw'],
    "saumanasī": ['mw'],
    "saumanottarika": ['mw'],
    "saumanta": ['ddsa', 'mw'],
    "saumantriṇa": ['ddsa', 'mw'],
    "saumanāyana": ['mw'],
    "saumapauṣa": ['mw'],
    "saumapauṣin": ['mw'],
    "saumarājya": ['mw'],
    "saumatāyana": ['mw'],
    "saumatāyanaka": ['mw'],
    "saumaśuṣmāyana": ['mw'],
    "saumaṅgala": ['mw'],
    "saumaṅgalya": ['ddsa', 'mw'],
    "saumbhavatsabāhu": ['bhs'],
    "saumecaka": ['mw'],
    "saumecakaṃ": ['ap90'],
    "saumedha": ['mw'],
    "saumedhika": ['mw'],
    "saumedhikaḥ": ['ap90'],
    "saumendra": ['mw'],
    "saumerava": ['ddsa', 'mw'],
    "saumeru": ['bhs'],
    "saumeruka": ['ap90', 'mw'],
    "saumia": ['gra'],
    "saumika": ['ap90', 'cae', 'ddsa', 'mw'],
    "saumikī": ['mw'],
    "saumila": ['cae', 'ddsa'],
    "saumilakā": ['bhs'],
    "saumilika": ['mw'],
    "saumilla": ['cae', 'mw'],
    "saumillaḥ": ['ap90'],
    "saumitra": ['cae', 'ddsa', 'mw'],
    "saumitraḥ": ['ap90'],
    "saumitri": ['cae', 'mw'],
    "saumitrā": ['bhs'],
    "saumitrīya": ['mw'],
    "saumivi": ['mw'],
    "saumiśri": ['mw'],
    "saumuci": ['mw'],
    "saumukhya": ['cae', 'mw'],
    "saumuktivāda": ['mw'],
    "saumya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "saumyadarśana": ['cae', 'mw'],
    "saumyadarśanā": ['mw'],
    "saumyadhātu": ['mw'],
    "saumyagandhā": ['mw'],
    "saumyagandhī": ['mw'],
    "saumyagiri": ['mw'],
    "saumyagola": ['mw'],
    "saumyagraha": ['mw'],
    "saumyajāmātṛ": ['mw'],
    "saumyajāmātṛmuni": ['mw'],
    "saumyajāmātṛmunīndrastotra": ['mw'],
    "saumyajāmātṛyogīndrastuti": ['mw'],
    "saumyaka": ['bhs'],
    "saumyakṛcchra": ['mw'],
    "saumyamukha": ['mw'],
    "saumyanāman": ['cae', 'mw'],
    "saumyaprabhāva": ['mw'],
    "saumyarūpa": ['cae', 'mw'],
    "saumyatva": ['mw'],
    "saumyatā": ['cae', 'mw'],
    "saumyavapus": ['cae', 'mw'],
    "saumyavāra": ['mw'],
    "saumyavāsara": ['mw'],
    "saumyaśrī": ['mw'],
    "saumyaśānti": ['mw'],
    "saumyopacāra": ['mw'],
    "saumyopayantṛ": ['mw'],
    "saumyā": ['mw'],
    "saumyākṛti": ['cae', 'mw'],
    "saumyārci": ['mw'],
    "saumyī": ['mw'],
    "saumāgna": ['mw'],
    "saumāpa": ['mw'],
    "saumāpauṣṇa": ['mw'],
    "saumāraudra": ['mw'],
    "saumātra": ['mw'],
    "saumāyana": ['mw'],
    "saumāyanaka": ['mw'],
    "saumāyanaḥ": ['ap90'],
    "saumī": ['cae', 'ddsa', 'mw'],
    "sauna": ['ap90', 'cae', 'ddsa', 'mw'],
    "saunadharmya": ['mw'],
    "saunahotra": ['mw'],
    "saunanda": ['mw'],
    "saunandin": ['mw'],
    "saunandā": ['mw'],
    "saunapāla": ['mw'],
    "saunavya": ['mw'],
    "saunavyāyanī": ['mw'],
    "saunaṃdaṃ": ['ap90'],
    "saunaṃdin": ['ap90'],
    "saundarya": ['cae', 'ddsa', 'mw'],
    "saundaryalaharī": ['mw'],
    "saundaryapurāṇa": ['mw'],
    "saundaryastotra": ['mw'],
    "saundaryavyākhyā": ['mw'],
    "saunetra": ['mw'],
    "saunika": ['cae', 'ddsa', 'mw'],
    "saunikaḥ": ['ap90'],
    "saunāga": ['ddsa', 'mw'],
    "saunāmi": ['mw'],
    "saunīteya": ['mw'],
    "saupa": ['mw'],
    "saupaddava": ['cped'],
    "saupaghāta": ['cped'],
    "saupaghātaṁ": ['cped'],
    "saupanisa": ['cped'],
    "saupanthya": ['mw'],
    "sauparama": ['bhs'],
    "sauparva": ['mw'],
    "sauparya": ['mw'],
    "sauparṇa": ['cae', 'ddsa', 'mw'],
    "sauparṇaketava": ['mw'],
    "sauparṇavrata": ['mw'],
    "sauparṇaṃ": ['ap90'],
    "sauparṇeya": ['mw'],
    "sauparṇeyaḥ": ['ap90'],
    "sauparṇeyī": ['mw'],
    "sauparṇya": ['ddsa', 'mw'],
    "sauparṇī": ['mw'],
    "sauparṇīkādrava": ['mw'],
    "saupasagga": ['cped'],
    "saupastambi": ['mw'],
    "saupathi": ['mw'],
    "saupavajja": ['cped'],
    "saupika": ['mw'],
    "saupiṅgala": ['mw'],
    "saupiṣṭa": ['mw'],
    "sauprajāstva": ['cae', 'mw'],
    "sauprakhya": ['mw'],
    "sauprakhyīya": ['mw'],
    "saupratīka": ['mw'],
    "sauptika": ['ap90', 'cae', 'ddsa', 'mw'],
    "sauptikaparvan": ['mw'],
    "sauptikavadha": ['cae'],
    "saupuṣpi": ['mw'],
    "saupādisesa": ['cped'],
    "saupādāna": ['cped'],
    "saupāhanā": ['cped'],
    "saupāka": ['mw'],
    "saupāmāyani": ['mw'],
    "saupāraka": ['bhs'],
    "saupātava": ['mw'],
    "saupāyāsa": ['cped'],
    "saupāyāsaṁ": ['cped'],
    "saupūta": ['mw'],
    "saura": ['ap90', 'cae', 'ddsa', 'mw'],
    "saurabha": ['ap90', 'cae', 'ddsa', 'mw'],
    "saurabhaka": ['mw'],
    "saurabheya": ['ap90', 'cae', 'mw'],
    "saurabheyaka": ['mw'],
    "saurabheyatantra": ['mw'],
    "saurabheyī": ['mw'],
    "saurabhuvana": ['mw'],
    "saurabhya": ['bhs', 'cae', 'mw'],
    "saurabhyada": ['mw'],
    "saurabhyaṃ": ['ap90'],
    "saurabhī": ['ap90', 'mw'],
    "sauradharma": ['mw'],
    "sauradharmottara": ['mw'],
    "sauradhrī": ['mw'],
    "sauradivasa": ['mw'],
    "sauragaṇitadvādaśahorāprakāśa": ['mw'],
    "sauraja": ['mw'],
    "sauraka": ['ddsa', 'mw'],
    "saurakāyaṇopaniṣad": ['mw'],
    "sauraloka": ['mw'],
    "sauramantra": ['mw'],
    "sauramasa": ['mw'],
    "sauramāsa": ['mw'],
    "sauranakta": ['mw'],
    "saurapakṣagaṇita": ['mw'],
    "saurapara": ['mw'],
    "saurapata": ['mw'],
    "saurapaurāṇikamatasamarthana": ['mw'],
    "saurapi": ['mw'],
    "saurapurāṇa": ['mw'],
    "saurapāta": ['mw'],
    "saurasa": ['ddsa', 'mw'],
    "saurasaindhava": ['ddsa', 'mw'],
    "saurasaiṃdhava": ['ap90'],
    "saurasaṃhitā": ['mw'],
    "saurasaṃvatsara": ['mw'],
    "saurasena": ['mw'],
    "saurasenāḥ": ['ap90'],
    "sauraseya": ['mw'],
    "sauraseyaḥ": ['ap90'],
    "saurasiddhānta": ['mw'],
    "saurasya": ['mw'],
    "saurasyaṃ": ['ap90'],
    "saurasā": ['mw'],
    "saurasūkta": ['mw'],
    "saurata": ['ddsa', 'mw'],
    "sauratantra": ['mw'],
    "sauratha": ['mw'],
    "saurathaḥ": ['ap90'],
    "sauratheya": ['mw'],
    "saurathī": ['mw'],
    "sauratya": ['bhs', 'ddsa', 'mw'],
    "sauratīrtha": ['mw'],
    "sauraṇa": ['mw'],
    "sauraṭī": ['mw'],
    "saureya": ['mw'],
    "saureyaka": ['mw'],
    "sauri": ['mw'],
    "saurika": ['ap90', 'cae', 'ddsa', 'mw'],
    "saurindhra": ['mw'],
    "saurindhrī": ['mw'],
    "sauriratna": ['mw'],
    "sauriḥ": ['ap90'],
    "saurohika": ['mw'],
    "saurohitika": ['mw'],
    "sauropapurāṇa": ['mw'],
    "saurpārakīya": ['bhs'],
    "saurvala": ['mw'],
    "saurya": ['ap90', 'cae', 'ddsa', 'mw'],
    "sauryabhagavat": ['mw'],
    "sauryacāndramasa": ['mw'],
    "sauryamārutaka": ['mw'],
    "sauryaprabha": ['mw'],
    "sauryapṛṣṭha": ['mw'],
    "sauryavaiśvānara": ['mw'],
    "sauryavarcasa": ['mw'],
    "sauryavāruṇa": ['mw'],
    "sauryayāma": ['mw'],
    "sauryin": ['mw'],
    "sauryodayika": ['mw'],
    "sauryodayikā": ['bhs'],
    "sauryāyaṇi": ['mw'],
    "sauryāyaṇin": ['mw'],
    "saurājya": ['cae', 'ddsa', 'mw'],
    "saurājyavat": ['mw'],
    "saurājyaṃ": ['ap90'],
    "saurāki": ['mw'],
    "saurāva": ['mw'],
    "saurāṅga": ['mw'],
    "saurāṣṭra": ['ap90', 'cae', 'ddsa', 'mw'],
    "saurāṣṭradeśa": ['mw'],
    "saurāṣṭraka": ['cae', 'mw'],
    "saurāṣṭrakaḥ": ['ap90'],
    "saurāṣṭramaṇḍala": ['mw'],
    "saurāṣṭramṛttikā": ['mw'],
    "saurāṣṭranagara": ['mw'],
    "saurāṣṭreya": ['mw'],
    "saurāṣṭrika": ['mw'],
    "saurāṣṭākṣarīmantra": ['mw'],
    "saurāṭī": ['mw'],
    "saurī": ['ap90', 'mw'],
    "saurīya": ['ap90', 'mw'],
    "sausnātika": ['mw'],
    "sausnātikaḥ": ['ap90'],
    "saussala": ['ddsa', 'mw'],
    "sausthitya": ['mw'],
    "sausthya": ['mw'],
    "saustra": ['mw'],
    "sausuka": ['mw'],
    "sausukīya": ['mw'],
    "sausumna": ['mw'],
    "sausurāda": ['mw'],
    "sausvarya": ['ddsa', 'mw'],
    "sausāma": ['mw'],
    "sausāyana": ['mw'],
    "sausāyanaka": ['mw'],
    "sauta": ['mw'],
    "sautaṃgama": ['mw'],
    "sautaṃgamīya": ['mw'],
    "sauti": ['cae', 'mw'],
    "sautikya": ['mw'],
    "sautiḥ": ['ap90'],
    "sautra": ['ap90', 'cae', 'ddsa', 'mw'],
    "sautranāḍi": ['mw'],
    "sautri": ['mw'],
    "sautrika": ['ddsa', 'mw'],
    "sautrāmadhanus": ['ddsa'],
    "sautrāmaṇa": ['cae', 'ddsa', 'mw'],
    "sautrāmaṇadhanus": ['mw'],
    "sautrāmaṇi": ['mw'],
    "sautrāmaṇika": ['mw'],
    "sautrāmaṇī": ['ap90', 'mw'],
    "sautrāmaṇīhautra": ['mw'],
    "sautrāmaṇīpaddhati": ['mw'],
    "sautrāmaṇīprayoga": ['mw'],
    "sautrāmaṇīsūtra": ['mw'],
    "sautrāmaṇītva": ['mw'],
    "sautrāmaṇīviniyogasūtrārtha": ['mw'],
    "sautrāmaṇīya": ['mw'],
    "sautrāntika": ['bhs', 'ddsa', 'mw'],
    "sautrāṃtikāḥ": ['ap90'],
    "sautsukya": ['ddsa', 'mw'],
    "sauttara": ['cped'],
    "sauttaracchada": ['cped'],
    "sautthiti": ['mw'],
    "sautvana": ['mw'],
    "sautya": ['cae', 'ddsa', 'mw'],
    "sautyaṃ": ['ap90'],
    "sauva": ['ap90', 'cae', 'ddsa', 'mw'],
    "sauvagrāmika": ['ap90', 'mw'],
    "sauvakṣaseya": ['mw'],
    "sauvalya": ['mw'],
    "sauvara": ['ap90', 'cae', 'mw'],
    "sauvarcala": ['ap90', 'ddsa', 'mw'],
    "sauvarcalikā": ['bhs'],
    "sauvarcalā": ['mw'],
    "sauvarcalīya": ['mw'],
    "sauvarcanasa": ['mw'],
    "sauvarcasa": ['bhs', 'mw'],
    "sauvarṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "sauvarṇabalaja": ['mw'],
    "sauvarṇabhedinī": ['mw'],
    "sauvarṇabālaja": ['mw'],
    "sauvarṇaharmya": ['mw'],
    "sauvarṇaka": ['bhs'],
    "sauvarṇakāyana": ['mw'],
    "sauvarṇanābha": ['mw'],
    "sauvarṇaparṇa": ['mw'],
    "sauvarṇaretasa": ['mw'],
    "sauvarṇika": ['bhs', 'mw'],
    "sauvarṇikā": ['mw'],
    "sauvarṇya": ['mw'],
    "sauvastika": ['ap90', 'bhs', 'mw'],
    "sauvaśva": ['mw'],
    "sauvaśvabhārya": ['mw'],
    "sauvaśvi": ['mw'],
    "sauvaśvia": ['gra'],
    "sauvaśvya": ['cae', 'gra', 'mw'],
    "sauvida": ['cae', 'mw'],
    "sauvidalla": ['cae', 'ddsa', 'mw'],
    "sauvidallaka": ['mw'],
    "sauvidallatva": ['mw'],
    "sauvidaḥ": ['ap90'],
    "sauviṣṭakṛt": ['ddsa', 'mw'],
    "sauviṣṭakṛta": ['cae', 'mw'],
    "sauviṣṭi": ['mw'],
    "sauvratya": ['cae', 'mw'],
    "sauvādhyāyika": ['ap90', 'mw'],
    "sauvādumṛdava": ['mw'],
    "sauvāsa": ['mw'],
    "sauvāsinī": ['ddsa', 'mw'],
    "sauvāstava": ['ap90', 'mw'],
    "sauvāta": ['mw'],
    "sauvīra": ['cae', 'ddsa', 'mw'],
    "sauvīrabhakta": ['mw'],
    "sauvīraka": ['cae', 'mw'],
    "sauvīrakaḥ": ['ap90'],
    "sauvīrapāṇa": ['mw'],
    "sauvīrarāja": ['mw'],
    "sauvīrasāra": ['mw'],
    "sauvīraṃ": ['ap90'],
    "sauvīrikā": ['mw'],
    "sauvīrya": ['mw'],
    "sauvīryaṃ": ['ap90'],
    "sauvīryā": ['mw'],
    "sauvīrābhīra": ['mw'],
    "sauvīrāmla": ['mw'],
    "sauvīrāyaṇa": ['mw'],
    "sauvīrāyaṇabhakta": ['mw'],
    "sauvīrāñjana": ['mw'],
    "sauvīrī": ['mw'],
    "sauyajñaka": ['mw'],
    "sauyavasa": ['mw'],
    "sauyavasi": ['cae', 'ddsa', 'mw'],
    "sauyāmi": ['ddsa', 'mw'],
    "sauyāmuna": ['mw'],
    "sauśabda": ['mw'],
    "sauśabdya": ['cae', 'ddsa', 'mw'],
    "sauśalya": ['mw'],
    "sauśami": ['mw'],
    "sauśamikantha": ['mw'],
    "sauśarmaka": ['mw'],
    "sauśarmaṇa": ['mw'],
    "sauśarmi": ['mw'],
    "sauśilya": ['mw'],
    "sauśrava": ['mw'],
    "sauśravasa": ['cae', 'ddsa', 'gra', 'mw'],
    "sauśravasaṃ": ['ap90'],
    "sauśriya": ['mw'],
    "sauśromateya": ['mw'],
    "sauśruta": ['mw'],
    "sauśrutapārthava": ['mw'],
    "sauśāmya": ['cae', 'mw'],
    "sauśīlya": ['cae', 'ddsa', 'mw'],
    "sauśīlyaṃ": ['ap90'],
    "sauḍala": ['mw'],
    "sauḍhāmitri": ['mw'],
    "sauṃdaryaṃ": ['ap90'],
    "sauṃḍī": ['ap90'],
    "sauṇḍī": ['mw'],
    "sauṣadha": ['mw'],
    "sauṣadmana": ['ddsa', 'mw'],
    "sauṣira": ['mw'],
    "sauṣirya": ['mw'],
    "sauṣmiki": ['mw'],
    "sauṣumṇa": ['cae', 'ddsa', 'mw'],
    "sauṣupta": ['mw'],
    "sauṣāma": ['mw'],
    "sauṣṭava": ['mw'],
    "sauṣṭhava": ['cae', 'ddsa', 'mw'],
    "sauṣṭhavaṃ": ['ap90'],
    "sava": ['cae', 'ddsa', 'gra', 'mw'],
    "savacana": ['mw'],
    "savadhūka": ['mw'],
    "savahā": ['mw'],
    "savaidika": ['mw'],
    "savaiklavyam": ['cae', 'mw'],
    "savailakṣya": ['ap90', 'cae', 'mw'],
    "savailakṣyam": ['mw'],
    "savailakṣyasmitam": ['cae', 'mw'],
    "savaira": ['cae', 'mw'],
    "savairāgyam": ['cae', 'mw'],
    "savaiyākhya": ['mw'],
    "savajja": ['cped'],
    "savajrasaṃghāta": ['mw'],
    "savakāṇḍa": ['mw'],
    "savala": ['mw'],
    "savalatā": ['ddsa', 'mw'],
    "savalga": ['ddsa', 'mw'],
    "savana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "savanabhāj": ['mw'],
    "savanadevatā": ['mw'],
    "savanagata": ['mw'],
    "savanakarman": ['cae', 'mw'],
    "savanakrama": ['mw'],
    "savanakāla": ['mw'],
    "savanakṛt": ['mw'],
    "savanamukha": ['mw'],
    "savanamukhīya": ['mw'],
    "savanapaṅkti": ['mw'],
    "savanaprayoga": ['mw'],
    "savanasamīṣantī": ['mw'],
    "savanasaṃsthā": ['mw'],
    "savanastha": ['mw'],
    "savanatraya": ['mw'],
    "savanavid": ['mw'],
    "savanavidha": ['mw'],
    "savanaśas": ['mw'],
    "savanaṃ": ['ap90'],
    "savanika": ['mw'],
    "savanta": ['cped'],
    "savantī": ['cped'],
    "savanānta": ['mw'],
    "savanānukalpam": ['mw'],
    "savanīya": ['cae', 'ddsa', 'mw'],
    "savanīyakāla": ['mw'],
    "savanīyapaśu": ['mw'],
    "savanīyapātra": ['mw'],
    "savapati": ['mw'],
    "savapuṣa": ['mw'],
    "savara": ['bhs', 'mw'],
    "savaraḥ": ['ap90'],
    "savargīya": ['mw'],
    "savarman": ['mw'],
    "savarya": ['mw'],
    "savarūtha": ['mw'],
    "savarūthin": ['mw'],
    "savarṇa": ['ap90', 'cae', 'gra', 'mw'],
    "savarṇana": ['mw'],
    "savarṇanaṃ": ['ap90'],
    "savarṇatva": ['mw'],
    "savarṇavarṇa": ['mw'],
    "savarṇaya": ['mw'],
    "savarṇiliṅgin": ['mw'],
    "savarṇopāyin": ['mw'],
    "savarṇā": ['mw'],
    "savarṇābha": ['mw'],
    "savarṇāsavarṇavivāha": ['mw'],
    "savarṇīkaraṇa": ['mw'],
    "savas": ['mw'],
    "savasesa": ['cped'],
    "savat": ['mw'],
    "savatha": ['ddsa', 'mw'],
    "savati": ['cped'],
    "savatsa": ['mw'],
    "savatya": ['mw'],
    "savavidha": ['mw'],
    "savayas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "savayasa": ['cae', 'mw'],
    "savayaska": ['cae', 'mw'],
    "savaḥ": ['ap90'],
    "savaṃśā": ['mw'],
    "savaṅka": ['cped'],
    "savaṇa": ['cped'],
    "savaṇīya": ['cped'],
    "savedanam": ['mw'],
    "savedas": ['cae', 'gra', 'mw'],
    "savedha": ['mw'],
    "savedika": ['mw'],
    "savega": ['cae', 'mw'],
    "savegam": ['mw'],
    "savepathu": ['cae', 'mw'],
    "savepitam": ['mw'],
    "savera": ['cped'],
    "savetāla": ['cae', 'mw'],
    "saveśa": ['ap90', 'mw'],
    "saveśīya": ['mw'],
    "saveṇuvīṇam": ['mw'],
    "saveṇuvīṇāpaṇavānunāda": ['mw'],
    "saveṇī": ['mw'],
    "saveṣa": ['mw'],
    "saveṣṭana": ['cae', 'mw'],
    "savi": ['cped'],
    "savibhaktika": ['mw'],
    "savibhattika": ['cped'],
    "savibhrama": ['ap90', 'mw'],
    "savibhramam": ['mw'],
    "savibhāsa": ['mw'],
    "savicikitsitam": ['mw'],
    "savicāra": ['mw'],
    "savid": ['mw'],
    "savidha": ['ap90', 'cae', 'mw'],
    "savidham": ['mw'],
    "savidhībhū": ['mw'],
    "savidhīkṛ": ['cae', 'mw'],
    "savidiś": ['ddsa', 'mw'],
    "savidya": ['mw'],
    "savidyut": ['cae', 'mw'],
    "savidyuta": ['cae', 'mw'],
    "savidyutstanita": ['mw'],
    "savighāta": ['cped'],
    "savigraha": ['ap90', 'mw'],
    "savihaṃga": ['mw'],
    "savijñāna": ['cae', 'mw'],
    "savijñānaka": ['bhs'],
    "savijñānatva": ['mw'],
    "savikalpa": ['ap90', 'cae', 'mw'],
    "savikalpaka": ['cae'],
    "saviklavam": ['cae', 'mw'],
    "savikrama": ['mw'],
    "savikrośam": ['mw'],
    "savikāra": ['cae', 'mw'],
    "savikāśa": ['ap90', 'mw'],
    "savilakṣam": ['cae', 'mw'],
    "savilakṣasmitam": ['cae', 'mw'],
    "savilambagāmin": ['bhs'],
    "savilambam": ['mw'],
    "savilāsa": ['mw'],
    "savilāsam": ['mw'],
    "savimarśa": ['cae', 'mw'],
    "savimarśam": ['mw'],
    "savinaya": ['ap90', 'cae', 'mw'],
    "savinayam": ['mw'],
    "savisaṃkulam": ['mw'],
    "savismaya": ['ap90', 'cae', 'mw'],
    "savismayam": ['mw'],
    "savistara": ['ap90', 'cae', 'mw'],
    "savistaram": ['mw'],
    "savitakka": ['cped'],
    "savitara": ['ddsa', 'mw'],
    "savitarka": ['ap90', 'cae', 'mw'],
    "savitarkam": ['mw'],
    "savitave": ['mw'],
    "savitra": ['mw'],
    "savitraṃ": ['ap90'],
    "savitriya": ['ap90', 'mw'],
    "savitrī": ['ap90', 'cae', 'ddsa', 'mw'],
    "savitta": ['cae', 'mw'],
    "savitvā": ['cped'],
    "savitṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "savitṛdaivata": ['mw'],
    "savitṛdatta": ['mw'],
    "savitṛdevata": ['mw'],
    "savitṛla": ['ap90', 'mw'],
    "savitṛprasūta": ['mw'],
    "savitṛprasūtatā": ['mw'],
    "savitṛputra": ['mw'],
    "savitṛsuta": ['mw'],
    "savitṛsutadina": ['mw'],
    "savitṛtanaya": ['mw'],
    "savivadha": ['mw'],
    "savivadhatva": ['mw'],
    "saviveka": ['mw'],
    "saviññāṇaka": ['cped'],
    "saviśaṅka": ['mw'],
    "saviśeṣa": ['ap90', 'cae', 'mw'],
    "saviśeṣaka": ['ap90', 'mw'],
    "saviśeṣakautūhalam": ['cae', 'mw'],
    "saviśeṣakānta": ['mw'],
    "saviśeṣam": ['mw'],
    "saviśeṣataram": ['mw'],
    "saviśeṣatas": ['mw'],
    "saviśeṣaṇa": ['cae', 'mw'],
    "saviśeṣaṇarūpaka": ['mw'],
    "saviśrambha": ['cae', 'mw'],
    "saviśrambham": ['mw'],
    "saviśvāsam": ['mw'],
    "saviḍālambha": ['mw'],
    "saviṃśa": ['mw'],
    "saviṣa": ['cae', 'mw'],
    "saviṣāda": ['cae', 'mw'],
    "saviṣādam": ['mw'],
    "saviṣāśis": ['mw'],
    "saviṣāṇa": ['mw'],
    "saviṣṭara": ['mw'],
    "savrata": ['cae', 'ddsa', 'gra', 'mw'],
    "savratin": ['mw'],
    "savraṇa": ['bhs', 'cae', 'mw'],
    "savrīḍa": ['ap90', 'cae', 'mw'],
    "savrīḍam": ['mw'],
    "savupādāna": ['cped'],
    "savya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "savyabhicaraṇa": ['mw'],
    "savyabhicāra": ['mw'],
    "savyabhicāragrantharahasya": ['mw'],
    "savyabhicārakroḍa": ['mw'],
    "savyabhicāranirukti": ['mw'],
    "savyabhicārapūrvapakṣagranthadīdhitiṭīkā": ['mw'],
    "savyabhicārapūrvapakṣagranthaloka": ['mw'],
    "savyabhicārapūrvapakṣagranthaṭīkā": ['mw'],
    "savyabhicārapūrvapakṣakroḍa": ['mw'],
    "savyabhicārasiddhāntagranthadīdhitiṭīkā": ['mw'],
    "savyabhicārasiddhāntagranthaloka": ['mw'],
    "savyabhicārasiddhāntagranthaprakāśa": ['mw'],
    "savyabhicārasiddhāntagrantharahasya": ['mw'],
    "savyabhicārasiddhāntagranthaṭīkā": ['mw'],
    "savyabhicārasāmānyanirukti": ['mw'],
    "savyabhicārasāmānyaniruktikroḍa": ['mw'],
    "savyabhicāravāda": ['mw'],
    "savyabhicāraḥ": ['ap90'],
    "savyabāhu": ['mw'],
    "savyacārin": ['mw'],
    "savyadha": ['mw'],
    "savyajana": ['mw'],
    "savyajānu": ['mw'],
    "savyapatrapa": ['mw'],
    "savyapekṣa": ['ap90', 'cae', 'mw'],
    "savyapādalekhā": ['mw'],
    "savyasācin": ['cae', 'ddsa', 'mw'],
    "savyatas": ['cae', 'gra', 'mw'],
    "savyatha": ['cae', 'ddsa', 'mw'],
    "savyañjana": ['cped', 'mw'],
    "savyaṣṭhā": ['cae', 'mw'],
    "savyaṣṭhṛ": ['cae'],
    "savyaṣṭṛ": ['mw'],
    "savyaṣṭṛsārathī": ['mw'],
    "savye": ['mw'],
    "savyetara": ['cae', 'ddsa', 'mw'],
    "savyetaratas": ['mw'],
    "savyeṣṭha": ['cae', 'mw'],
    "savyeṣṭhasārathī": ['mw'],
    "savyeṣṭhṛ": ['mw'],
    "savyeṣṭṛ": ['ap90'],
    "savyonnata": ['mw'],
    "savyottāna": ['mw'],
    "savyādhara": ['mw'],
    "savyādhi": ['cae', 'mw'],
    "savyāhṛti": ['mw'],
    "savyāhṛtipraṇavaka": ['cae', 'mw'],
    "savyāja": ['ap90', 'cae', 'ddsa', 'mw'],
    "savyājam": ['mw'],
    "savyānata": ['mw'],
    "savyāpagrahaṇa": ['mw'],
    "savyāpasavya": ['mw'],
    "savyāpraṣṭi": ['mw'],
    "savyāpāra": ['ap90', 'cae', 'mw'],
    "savyāvṛt": ['cae', 'mw'],
    "savyāvṛtta": ['cae', 'mw'],
    "savyāyugya": ['mw'],
    "savyāśūnya": ['mw'],
    "savācas": ['mw'],
    "savākchala": ['mw'],
    "savālakhilya": ['mw'],
    "savārija": ['mw'],
    "savārttika": ['mw'],
    "savāsa": ['mw'],
    "savāsas": ['cae', 'ddsa', 'mw'],
    "savāsin": ['cae', 'mw'],
    "savātya": ['mw'],
    "savātṛ": ['mw'],
    "savāya": ['ddsa'],
    "savīman": ['cae', 'ddsa', 'gra', 'mw'],
    "savīra": ['cae', 'mw'],
    "savīrya": ['cae', 'ddsa', 'mw'],
    "savīryatva": ['mw'],
    "savīvadha": ['mw'],
    "savīvadhatva": ['mw'],
    "savīvadhatā": ['mw'],
    "savṛddhika": ['ap90', 'mw'],
    "savṛdh": ['cae', 'gra', 'mw'],
    "savṛkṣakṣupalata": ['mw'],
    "savṛt": ['mw'],
    "savṛtasoma": ['mw'],
    "savṛtayajña": ['mw'],
    "savṛtta": ['mw'],
    "savṛtti": ['cae', 'mw'],
    "savṛttika": ['mw'],
    "savṛttikatā": ['mw'],
    "savṛṣaṇa": ['cae', 'mw'],
    "savṛṣṭika": ['mw'],
    "say": ['ap90', 'mw'],
    "saya": ['mw'],
    "sayajñapātra": ['mw'],
    "sayakṣman": ['mw'],
    "sayambhū": ['cped'],
    "sayamāna": ['cped'],
    "sayana": ['cae', 'cped', 'mw'],
    "sayanighara": ['cped'],
    "sayanta": ['cped'],
    "sayantra": ['mw'],
    "sayantrajalaśaila": ['mw'],
    "sayantrika": ['mw'],
    "sayathīme": ['bhs'],
    "sayati": ['cped', 'mw'],
    "sayatna": ['cae', 'ddsa', 'mw'],
    "sayatnam": ['mw'],
    "sayatva": ['cae', 'mw'],
    "sayauvana": ['cae', 'mw'],
    "sayava": ['mw'],
    "sayañjāta": ['cped'],
    "sayaṁ": ['cped'],
    "sayaṁkata": ['cped'],
    "sayaṁvara": ['cped'],
    "sayha": ['cped'],
    "sayi": ['cped'],
    "sayitvā": ['cped'],
    "sayoga": ['mw'],
    "sayoni": ['ap90', 'cae', 'gra', 'mw'],
    "sayonitva": ['mw'],
    "sayonitā": ['mw'],
    "sayoṣaṇa": ['mw'],
    "sayudhiṣṭhira": ['mw'],
    "sayugvan": ['cae', 'gra', 'mw'],
    "sayuj": ['cae', 'gra', 'mw'],
    "sayujya": ['mw'],
    "sayujyatā": ['mw'],
    "sayuktva": ['mw'],
    "sayyaka": ['bhs'],
    "sayyathāpi": ['bhs'],
    "sayyathāpīdaṃ": ['bhs'],
    "sayyathīdaṃ": ['bhs'],
    "sayākaravat": ['mw'],
    "sayāna": ['cped'],
    "sayāpeti": ['cped'],
    "sayāpita": ['cped'],
    "sayāvaka": ['cae', 'mw'],
    "sayāvan": ['cae', 'gra', 'mw'],
    "sayūthya": ['mw'],
    "sayūthyaḥ": ['ap90'],
    "sañc": ['mw'],
    "sañca": ['cae', 'mw'],
    "sañcaka": ['cae', 'ddsa', 'mw'],
    "sañcakṣe": ['ddsa'],
    "sañcalana": ['cped'],
    "sañcalati": ['cped'],
    "sañcali": ['cped'],
    "sañcalita": ['cped'],
    "sañcaranta": ['cped'],
    "sañcarati": ['cped'],
    "sañcaraṇa": ['cped'],
    "sañcari": ['cped'],
    "sañcarita": ['cped'],
    "sañcaritta": ['cped'],
    "sañcaritvā": ['cped'],
    "sañcat": ['mw'],
    "sañcaya": ['cped', 'ddsa'],
    "sañcetanika": ['cped'],
    "sañcetanā": ['cped'],
    "sañcetesi": ['cped'],
    "sañceteti": ['cped'],
    "sañcetetvā": ['cped'],
    "sañchanna": ['cped'],
    "sañchindati": ['cped'],
    "sañchindi": ['cped'],
    "sañchinditvā": ['cped'],
    "sañchinna": ['cped'],
    "sañchādesi": ['cped'],
    "sañchādeti": ['cped'],
    "sañchādetvā": ['cped'],
    "sañchādita": ['cped'],
    "sañcicca": ['cped'],
    "sañcikā": ['mw'],
    "sañcinana": ['cped'],
    "sañcinanta": ['cped'],
    "sañcini": ['cped'],
    "sañcinitvā": ['cped'],
    "sañcināti": ['cped'],
    "sañcita": ['cped'],
    "sañciṇṇa": ['cped'],
    "sañcodita": ['cped'],
    "sañcopana": ['cped'],
    "sañcu": ['mw'],
    "sañcuṇṇesi": ['cped'],
    "sañcuṇṇeti": ['cped'],
    "sañcuṇṇetvā": ['cped'],
    "sañcuṇṇita": ['cped'],
    "sañcādhara": ['mw'],
    "sañcāna": ['mw'],
    "sañcāra": ['cped'],
    "sañcāraṇa": ['cped'],
    "sañcāresi": ['cped'],
    "sañcāreti": ['cped'],
    "sañcāretvā": ['cped'],
    "sañcārita": ['cped'],
    "sañj": ['cae', 'ddsa', 'gra', 'mw'],
    "sañja": ['mw'],
    "sañjagghana": ['cped'],
    "sañjagghati": ['cped'],
    "sañjagghi": ['cped'],
    "sañjagghitvā": ['cped'],
    "sañjaka": ['ddsa', 'mw'],
    "sañjana": ['cae', 'ddsa', 'mw'],
    "sañjanana": ['cped', 'ddsa'],
    "sañjanesi": ['cped'],
    "sañjaneti": ['cped'],
    "sañjanetvā": ['cped'],
    "sañjanita": ['cped'],
    "sañjanī": ['mw'],
    "sañjapāla": ['ddsa'],
    "sañjatara": ['mw'],
    "sañjaya": ['ddsa'],
    "sañjhā": ['cped'],
    "sañjhāghaṇa": ['cped'],
    "sañjhātapa": ['cped'],
    "sañji": ['mw'],
    "sañjighṛkṣu": ['ddsa'],
    "sañjimat": ['mw'],
    "sañjvara": ['ddsa'],
    "sañjña": ['ddsa'],
    "sañjñita": ['ddsa'],
    "sañjñopasarjanībhū": ['ddsa'],
    "sañjñātarūpa": ['ddsa'],
    "sañjānana": ['cped'],
    "sañjānanta": ['cped'],
    "sañjāni": ['cped'],
    "sañjānita": ['cped'],
    "sañjānitvā": ['cped'],
    "sañjānāti": ['cped'],
    "sañjāta": ['cped', 'ddsa'],
    "sañjāti": ['cped'],
    "sañjāyamāna": ['cped'],
    "sañjāyati": ['cped'],
    "sañjāyi": ['cped'],
    "sañjāyitvā": ['cped'],
    "sañjīvana": ['cped'],
    "saññatta": ['cped'],
    "saññatti": ['cped'],
    "saññita": ['cped'],
    "saññā": ['cped'],
    "saññākkhandha": ['cped'],
    "saññāpaka": ['cped'],
    "saññāpana": ['cped'],
    "saññāpesi": ['cped'],
    "saññāpeti": ['cped'],
    "saññāpetvā": ['cped'],
    "saññāpita": ['cped'],
    "saññāṇa": ['cped'],
    "saññī": ['cped'],
    "saśabda": ['ap90', 'cae', 'mw'],
    "saśabdam": ['mw'],
    "saśailavanakānana": ['mw'],
    "saśakala": ['mw'],
    "saśakya": ['bhs'],
    "saśalka": ['cae', 'mw'],
    "saśalya": ['ap90', 'cae', 'mw'],
    "saśapatham": ['cae', 'mw'],
    "saśara": ['cae', 'mw'],
    "saśaracāpahasta": ['cae', 'mw'],
    "saśarin": ['mw'],
    "saśarkara": ['mw'],
    "saśarāsana": ['mw'],
    "saśarīra": ['mw'],
    "saśastra": ['mw'],
    "saśastramarutvatīya": ['mw'],
    "saśasya": ['ap90', 'mw'],
    "saśasyā": ['mw'],
    "saśatru": ['cae', 'mw'],
    "saśayana": ['cae', 'mw'],
    "saśaṅka": ['cae', 'ddsa', 'mw'],
    "saśaṅkam": ['mw'],
    "saśaṅkha": ['mw'],
    "saśaṅkhagoṣa": ['mw'],
    "saśc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "saścat": ['mw'],
    "saśeṣa": ['cae', 'mw'],
    "saśeṣatva": ['mw'],
    "saśeṣānna": ['mw'],
    "saśibira": ['mw'],
    "saśikhara": ['mw'],
    "saśikhaṇḍin": ['mw'],
    "saśiras": ['cae', 'mw'],
    "saśiraska": ['cae', 'mw'],
    "saśiraḥkampam": ['cae', 'mw'],
    "saśirāvamajjana": ['mw'],
    "saśiṣya": ['cae', 'mw'],
    "saśleṣa": ['cae', 'mw'],
    "saśleṣatva": ['mw'],
    "saślāgham": ['cae', 'mw'],
    "saśmaśru": ['ap90', 'mw'],
    "saśoka": ['cae', 'mw'],
    "saśokam": ['mw'],
    "saśokatā": ['mw'],
    "saśraddha": ['cae', 'mw'],
    "saśrama": ['mw'],
    "saśrī": ['mw'],
    "saśrīka": ['ap90', 'cae', 'mw'],
    "saśrīkatva": ['mw'],
    "saśrīkatā": ['mw'],
    "saśuc": ['cae', 'mw'],
    "saśukra": ['mw'],
    "saśukratva": ['mw'],
    "saśvāsa": ['cae', 'mw'],
    "saśyāna": ['mw'],
    "saśyāparṇa": ['ddsa', 'mw'],
    "saśādvala": ['cae', 'mw'],
    "saśālka": ['mw'],
    "saśālmala": ['mw'],
    "saśīrṣan": ['cae', 'mw'],
    "saśītkāra": ['mw'],
    "saśītkāram": ['mw'],
    "saśūka": ['mw'],
    "saśūlam": ['mw'],
    "saśṛṅgāra": ['cae', 'mw'],
    "saśṛṅgārakam": ['cae', 'mw'],
    "saūmi": ['cped'],
    "saḍa": ['mw'],
    "saḍha": ['bhs'],
    "saḍiṇḍimam": ['cae', 'ddsa', 'mw'],
    "saḍḍa": ['ddsa', 'mw'],
    "saḷāyatana": ['cped'],
    "saṁharanta": ['cped'],
    "saṁharati": ['cped'],
    "saṁharaṇa": ['cped'],
    "saṁhari": ['cped'],
    "saṁharita": ['cped'],
    "saṁharitvā": ['cped'],
    "saṁhata": ['cped'],
    "saṁhaṭa": ['cped'],
    "saṁhita": ['cped'],
    "saṁhitā": ['cped'],
    "saṁhāra": ['cped'],
    "saṁhāraka": ['cped'],
    "saṁhārima": ['cped'],
    "saṁkaḍḍhati": ['cped'],
    "saṁkaḍḍhi": ['cped'],
    "saṁkaḍḍhitvā": ['cped'],
    "saṁkilesa": ['cped'],
    "saṁkilesika": ['cped'],
    "saṁkilissana": ['cped'],
    "saṁkilissati": ['cped'],
    "saṁkilissi": ['cped'],
    "saṁkilissitvā": ['cped'],
    "saṁkiliṭṭha": ['cped'],
    "saṁrakkhanā": ['cped'],
    "saṁrakkhati": ['cped'],
    "saṁrakkhi": ['cped'],
    "saṁrakkhita": ['cped'],
    "saṁrakkhitvā": ['cped'],
    "saṁsagga": ['cped'],
    "saṁsandati": ['cped'],
    "saṁsandesi": ['cped'],
    "saṁsandeti": ['cped'],
    "saṁsandetvā": ['cped'],
    "saṁsandi": ['cped'],
    "saṁsandita": ['cped'],
    "saṁsanditvā": ['cped'],
    "saṁsappana": ['cped'],
    "saṁsappati": ['cped'],
    "saṁsappi": ['cped'],
    "saṁsappitvā": ['cped'],
    "saṁsarati": ['cped'],
    "saṁsaraṇa": ['cped'],
    "saṁsari": ['cped'],
    "saṁsarita": ['cped'],
    "saṁsaritvā": ['cped'],
    "saṁsatta": ['cped'],
    "saṁsaya": ['cped'],
    "saṁsaṭṭha": ['cped'],
    "saṁsedaja": ['cped'],
    "saṁseva": ['cped'],
    "saṁsevamāna": ['cped'],
    "saṁsevanā": ['cped'],
    "saṁsevati": ['cped'],
    "saṁsevi": ['cped'],
    "saṁsevita": ['cped'],
    "saṁsevitvā": ['cped'],
    "saṁsevī": ['cped'],
    "saṁsibbita": ['cped'],
    "saṁsiddha": ['cped'],
    "saṁsiddhi": ['cped'],
    "saṁsijjhati": ['cped'],
    "saṁsijjhi": ['cped'],
    "saṁsita": ['cped'],
    "saṁsuddha": ['cped'],
    "saṁsuddhagahaṇika": ['cped'],
    "saṁsādeti": ['cped'],
    "saṁsāgara": ['cped'],
    "saṁsāmetvā": ['cped'],
    "saṁsāra": ['cped'],
    "saṁsāracakka": ['cped'],
    "saṁsāradukkha": ['cped'],
    "saṁsīdamāna": ['cped'],
    "saṁsīdana": ['cped'],
    "saṁsīdati": ['cped'],
    "saṁsīdi": ['cped'],
    "saṁsīditvā": ['cped'],
    "saṁsīna": ['cped'],
    "saṁsūcaka": ['cped'],
    "saṁvacchara": ['cped'],
    "saṁvaddhana": ['cped'],
    "saṁvara": ['cped'],
    "saṁvarati": ['cped'],
    "saṁvaraṇa": ['cped'],
    "saṁvari": ['cped'],
    "saṁvaritvā": ['cped'],
    "saṁvarī": ['cped'],
    "saṁvasati": ['cped'],
    "saṁvasi": ['cped'],
    "saṁvasita": ['cped'],
    "saṁvasitvā": ['cped'],
    "saṁvattanika": ['cped'],
    "saṁvattati": ['cped'],
    "saṁvattesi": ['cped'],
    "saṁvatteti": ['cped'],
    "saṁvattetvā": ['cped'],
    "saṁvatti": ['cped'],
    "saṁvattita": ['cped'],
    "saṁvaḍḍha": ['cped'],
    "saṁvaḍḍhamāna": ['cped'],
    "saṁvaḍḍhati": ['cped'],
    "saṁvaḍḍhesi": ['cped'],
    "saṁvaḍḍheti": ['cped'],
    "saṁvaḍḍhetvā": ['cped'],
    "saṁvaḍḍhi": ['cped'],
    "saṁvaḍḍhita": ['cped'],
    "saṁvaḍḍhitvā": ['cped'],
    "saṁvaṇṇanā": ['cped'],
    "saṁvaṇṇesi": ['cped'],
    "saṁvaṇṇetabba": ['cped'],
    "saṁvaṇṇeti": ['cped'],
    "saṁvaṇṇetvā": ['cped'],
    "saṁvaṇṇita": ['cped'],
    "saṁvaṭṭakappa": ['cped'],
    "saṁvaṭṭana": ['cped'],
    "saṁvaṭṭati": ['cped'],
    "saṁvaṭṭi": ['cped'],
    "saṁvega": ['cped'],
    "saṁvejana": ['cped'],
    "saṁvejaniya": ['cped'],
    "saṁvejanīya": ['cped'],
    "saṁvejesi": ['cped'],
    "saṁvejeti": ['cped'],
    "saṁvejetvā": ['cped'],
    "saṁvejita": ['cped'],
    "saṁvibhaga": ['cped'],
    "saṁvibhajana": ['cped'],
    "saṁvibhajati": ['cped'],
    "saṁvibhaji": ['cped'],
    "saṁvibhajita": ['cped'],
    "saṁvibhajitvā": ['cped'],
    "saṁvibhajja": ['cped'],
    "saṁvibhatta": ['cped'],
    "saṁvibhāgī": ['cped'],
    "saṁvidahana": ['cped'],
    "saṁvidahati": ['cped'],
    "saṁvidahi": ['cped'],
    "saṁvidahitabba": ['cped'],
    "saṁvidahitvā": ['cped'],
    "saṁvidamāna": ['cped'],
    "saṁvidhāna": ['cped'],
    "saṁvidhātuṁ": ['cped'],
    "saṁvidhāya": ['cped'],
    "saṁvidhāyaka": ['cped'],
    "saṁvigga": ['cped'],
    "saṁvihita": ['cped'],
    "saṁvijjamāna": ['cped'],
    "saṁvijjati": ['cped'],
    "saṁvijji": ['cped'],
    "saṁvuta": ['cped'],
    "saṁvutindriya": ['cped'],
    "saṁvāsa": ['cped'],
    "saṁvāsaka": ['cped'],
    "saṁvāsam kappeti": ['cped'],
    "saṁyama": ['cped'],
    "saṁyamana": ['cped'],
    "saṁyamenta": ['cped'],
    "saṁyamesi": ['cped'],
    "saṁyameti": ['cped'],
    "saṁyametvā": ['cped'],
    "saṁyamita": ['cped'],
    "saṁyamī": ['cped'],
    "saṁyata": ['cped'],
    "saṁyatacārī": ['cped'],
    "saṁyatta": ['cped'],
    "saṁyoga": ['cped'],
    "saṁyojana": ['cped'],
    "saṁyojaniya": ['cped'],
    "saṁyojenta": ['cped'],
    "saṁyojesi": ['cped'],
    "saṁyojeti": ['cped'],
    "saṁyojetvā": ['cped'],
    "saṁyojita": ['cped'],
    "saṁyujjati": ['cped'],
    "saṁyujji": ['cped'],
    "saṁyuta": ['cped'],
    "saṁyutta": ['cped'],
    "saṁyūhati": ['cped'],
    "saṁyūhi": ['cped'],
    "saṁyūḷha": ['cped'],
    "saṃ": ['mw'],
    "saṃb": ['ap90'],
    "saṃbaddha": ['ap90', 'cae'],
    "saṃbahula": ['bhs'],
    "saṃbalaḥ": ['ap90'],
    "saṃbandha": ['cae'],
    "saṃbandhana": ['cae'],
    "saṃbandhibāndhava": ['cae'],
    "saṃbandhin": ['cae'],
    "saṃbandhitā": ['cae'],
    "saṃbandhu": ['cae'],
    "saṃbaraḥ": ['ap90'],
    "saṃbaṃ": ['ap90'],
    "saṃbaṃdh": ['ap90'],
    "saṃbaṃdha": ['ap90'],
    "saṃbaṃdhaka": ['ap90'],
    "saṃbaṃdhin": ['ap90'],
    "saṃbhagna": ['ap90', 'cae'],
    "saṃbhaj": ['ap90'],
    "saṃbhakta": ['ap90', 'cae'],
    "saṃbhaktiḥ": ['ap90'],
    "saṃbhakṣa": ['cae'],
    "saṃbhakṣaḥ": ['ap90'],
    "saṃbhakṣaṇa": ['bhs'],
    "saṃbhala": ['cae'],
    "saṃbhalī": ['ap90'],
    "saṃbhara": ['cae'],
    "saṃbharaṇa": ['cae'],
    "saṃbhava": ['cae'],
    "saṃbhavagiri": ['bhs'],
    "saṃbhavaka": ['bhs'],
    "saṃbhavana": ['cae'],
    "saṃbhavaḥ": ['ap90'],
    "saṃbhavin": ['cae'],
    "saṃbhavyaḥ": ['ap90'],
    "saṃbhavā": ['bhs'],
    "saṃbheda": ['cae'],
    "saṃbhedana": ['bhs', 'cae'],
    "saṃbhedaḥ": ['ap90'],
    "saṃbhedya": ['cae'],
    "saṃbhid": ['ap90'],
    "saṃbhinatti": ['bhs'],
    "saṃbhinna": ['ap90', 'bhs', 'cae'],
    "saṃbhinnapralāpa": ['bhs'],
    "saṃbhinnapralāpika": ['bhs'],
    "saṃbhinnavyañjana": ['bhs'],
    "saṃbhoga": ['cae'],
    "saṃbhogakāya": ['bhs'],
    "saṃbhogavant": ['cae'],
    "saṃbhogaḥ": ['ap90'],
    "saṃbhogin": ['ap90', 'cae'],
    "saṃbhogya": ['cae'],
    "saṃbhoja": ['cae'],
    "saṃbhojakaḥ": ['ap90'],
    "saṃbhojana": ['cae'],
    "saṃbhojanaṃ": ['ap90'],
    "saṃbhojya": ['cae'],
    "saṃbhram": ['ap90'],
    "saṃbhrama": ['cae'],
    "saṃbhramaḥ": ['ap90'],
    "saṃbhramaṇa": ['bhs'],
    "saṃbhrānta": ['cae'],
    "saṃbhrānti": ['cae'],
    "saṃbhrāṃta": ['ap90'],
    "saṃbhuj": ['ap90'],
    "saṃbhukta": ['ap90'],
    "saṃbhuta": ['bhs'],
    "saṃbhuva": ['bhs'],
    "saṃbhuṇati": ['bhs'],
    "saṃbhāra": ['bhs', 'cae'],
    "saṃbhāraḥ": ['ap90'],
    "saṃbhāraṇa": ['bhs'],
    "saṃbhārikā": ['bhs'],
    "saṃbhārya": ['cae'],
    "saṃbhāvanaṃ": ['ap90'],
    "saṃbhāvanā": ['cae'],
    "saṃbhāvanāguṇa": ['cae'],
    "saṃbhāvanīya": ['cae'],
    "saṃbhāvayitavya": ['cae'],
    "saṃbhāvita": ['ap90', 'cae'],
    "saṃbhāvya": ['ap90', 'cae'],
    "saṃbhāṣ": ['ap90'],
    "saṃbhāṣa": ['cae'],
    "saṃbhāṣaḥ": ['ap90'],
    "saṃbhāṣaṇatā": ['bhs'],
    "saṃbhāṣin": ['cae'],
    "saṃbhāṣita": ['ap90'],
    "saṃbhāṣya": ['cae'],
    "saṃbhāṣā": ['ap90'],
    "saṃbhīta": ['cae'],
    "saṃbhū": ['ap90'],
    "saṃbhūta": ['ap90', 'bhs', 'cae'],
    "saṃbhūti": ['cae'],
    "saṃbhūtiḥ": ['ap90'],
    "saṃbhūya": ['ap90', 'cae'],
    "saṃbhṛ": ['ap90'],
    "saṃbhṛta": ['ap90', 'cae'],
    "saṃbhṛti": ['cae'],
    "saṃbhṛtiḥ": ['ap90'],
    "saṃbhṛtya": ['cae'],
    "saṃbodha": ['cae'],
    "saṃbodhaka": ['bhs'],
    "saṃbodhana": ['cae'],
    "saṃbodhanaṃ": ['ap90'],
    "saṃbodhaḥ": ['ap90'],
    "saṃbodhi": ['bhs'],
    "saṃbodhisattva": ['bhs'],
    "saṃbodhya": ['cae'],
    "saṃbodhyaṅga": ['bhs'],
    "saṃbuddha": ['ap90', 'bhs', 'cae'],
    "saṃbuddhi": ['bhs', 'cae'],
    "saṃbuddhiḥ": ['ap90'],
    "saṃbudh": ['ap90'],
    "saṃbudhyate": ['bhs'],
    "saṃbādh": ['ap90'],
    "saṃbādha": ['ap90', 'bhs', 'cae'],
    "saṃbādhanaṃ": ['ap90'],
    "saṃcagghati": ['bhs'],
    "saṃcakita": ['mw'],
    "saṃcakāna": ['cae', 'mw'],
    "saṃcakās": ['mw'],
    "saṃcakṣ": ['mw'],
    "saṃcakṣas": ['mw'],
    "saṃcal": ['ap90', 'mw'],
    "saṃcala": ['ap90', 'cae', 'mw'],
    "saṃcalana": ['mw'],
    "saṃcalanaṃ": ['ap90'],
    "saṃcalanāḍi": ['mw'],
    "saṃcalatthā": ['bhs'],
    "saṃcar": ['ap90', 'mw'],
    "saṃcara": ['cae', 'mw'],
    "saṃcarabhāgin": ['mw'],
    "saṃcaraḥ": ['ap90'],
    "saṃcaraṇa": ['cae', 'gra', 'mw'],
    "saṃcaraṇaṃ": ['ap90'],
    "saṃcareṇia": ['gra'],
    "saṃcareṇya": ['mw'],
    "saṃcaritra": ['bhs', 'mw'],
    "saṃcariṣṇu": ['cae', 'mw'],
    "saṃcarvaṇa": ['cae', 'mw'],
    "saṃcaskārayiṣu": ['mw'],
    "saṃcat": ['ap90'],
    "saṃcaukṣa": ['bhs'],
    "saṃcaya": ['bhs', 'cae', 'mw'],
    "saṃcayana": ['cae', 'mw'],
    "saṃcayanaṃ": ['ap90'],
    "saṃcayanīya": ['mw'],
    "saṃcayavant": ['cae'],
    "saṃcayavat": ['mw'],
    "saṃcayaḥ": ['ap90'],
    "saṃcayika": ['mw'],
    "saṃcayin": ['ap90', 'cae', 'mw'],
    "saṃcayitva": ['mw'],
    "saṃcaḥ": ['ap90'],
    "saṃcchedaḥ": ['ap90'],
    "saṃcetanikāhāra": ['bhs'],
    "saṃcetanā": ['bhs'],
    "saṃcetanīyatā": ['bhs'],
    "saṃceya": ['cae', 'mw'],
    "saṃceṣṭ": ['mw'],
    "saṃchad": ['ap90', 'mw'],
    "saṃchand": ['mw'],
    "saṃchanna": ['ap90', 'cae', 'mw'],
    "saṃchardana": ['mw'],
    "saṃchedana": ['bhs'],
    "saṃchedya": ['mw'],
    "saṃchettavya": ['cae', 'mw'],
    "saṃchettṛ": ['cae', 'mw'],
    "saṃchid": ['ap90', 'mw'],
    "saṃchidā": ['mw'],
    "saṃchinna": ['mw'],
    "saṃchādana": ['bhs'],
    "saṃchādanaṃ": ['ap90'],
    "saṃchādanī": ['mw'],
    "saṃci": ['ap90', 'mw'],
    "saṃcikīrṣu": ['mw'],
    "saṃcikṣipsu": ['mw'],
    "saṃcint": ['mw'],
    "saṃcintana": ['cae', 'mw'],
    "saṃcintita": ['mw'],
    "saṃcintitavat": ['mw'],
    "saṃcintya": ['bhs', 'cae', 'mw'],
    "saṃcinvānaka": ['mw'],
    "saṃcit": ['mw'],
    "saṃcita": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃcitakarman": ['mw'],
    "saṃciti": ['cae', 'mw'],
    "saṃcitiḥ": ['ap90'],
    "saṃcitora": ['bhs'],
    "saṃcitrā": ['mw'],
    "saṃciṃt": ['ap90'],
    "saṃciṃtanaṃ": ['ap90'],
    "saṃciṃtita": ['ap90'],
    "saṃciṣkārayiṣu": ['mw'],
    "saṃcodaka": ['bhs', 'mw'],
    "saṃcodana": ['cae', 'mw'],
    "saṃcodanā": ['mw'],
    "saṃcodayati": ['bhs'],
    "saṃcodayitavya": ['mw'],
    "saṃcodita": ['mw'],
    "saṃcud": ['mw'],
    "saṃcyu": ['mw'],
    "saṃcāku": ['mw'],
    "saṃcāla": ['mw'],
    "saṃcālaka": ['mw'],
    "saṃcālī": ['ap90', 'mw'],
    "saṃcāra": ['cae', 'mw'],
    "saṃcārajīvin": ['mw'],
    "saṃcāraka": ['ap90', 'cae', 'mw'],
    "saṃcārapatha": ['cae', 'mw'],
    "saṃcārapūta": ['mw'],
    "saṃcāravyādhi": ['bhs', 'mw'],
    "saṃcārayitrī": ['mw'],
    "saṃcārayitṛ": ['mw'],
    "saṃcāraḥ": ['ap90'],
    "saṃcāraṇa": ['bhs', 'cae', 'mw'],
    "saṃcāraṇaṃ": ['ap90'],
    "saṃcāraṇī": ['bhs', 'mw'],
    "saṃcāraṇīya": ['cae', 'mw'],
    "saṃcāri": ['mw'],
    "saṃcāribhāva": ['mw'],
    "saṃcāricuṇḍikā": ['mw'],
    "saṃcārikā": ['ap90', 'bhs', 'mw'],
    "saṃcārima": ['bhs'],
    "saṃcārin": ['ap90', 'cae', 'mw'],
    "saṃcārita": ['ap90', 'mw'],
    "saṃcāritva": ['mw'],
    "saṃcāritā": ['mw'],
    "saṃcāriṃstva": ['mw'],
    "saṃcāriṇī": ['mw'],
    "saṃcārya": ['mw'],
    "saṃcāyya": ['mw'],
    "saṃcāyyaḥ": ['ap90'],
    "saṃcīvaraya": ['mw'],
    "saṃcūrṇ": ['ap90', 'mw'],
    "saṃcūrṇana": ['cae', 'mw'],
    "saṃcūrṇanaṃ": ['ap90'],
    "saṃcūrṇita": ['mw'],
    "saṃcūṣ": ['mw'],
    "saṃcṛt": ['cae', 'gra', 'mw'],
    "saṃdadasvas": ['mw'],
    "saṃdadi": ['cae', 'gra', 'mw'],
    "saṃdagdha": ['mw'],
    "saṃdah": ['ap90', 'mw'],
    "saṃdalita": ['mw'],
    "saṃdarbha": ['cae', 'mw'],
    "saṃdarbhacintāmaṇi": ['mw'],
    "saṃdarbhagrantha": ['mw'],
    "saṃdarbhavat": ['mw'],
    "saṃdarbhaviruddha": ['mw'],
    "saṃdarbhaśuddha": ['mw'],
    "saṃdarbhaśuddhi": ['mw'],
    "saṃdarbhaḥ": ['ap90'],
    "saṃdarbhita": ['bhs', 'mw'],
    "saṃdarbhāmṛtatoṣiṇī": ['mw'],
    "saṃdarpa": ['cae', 'mw'],
    "saṃdarśa": ['cae', 'mw'],
    "saṃdarśaka": ['bhs'],
    "saṃdarśana": ['cae', 'mw'],
    "saṃdarśanadvīpa": ['mw'],
    "saṃdarśanapatha": ['mw'],
    "saṃdarśanatā": ['bhs'],
    "saṃdarśanaṃ": ['ap90'],
    "saṃdarśanī": ['mw'],
    "saṃdarśayitṛ": ['mw'],
    "saṃdarśita": ['mw'],
    "saṃdas": ['mw'],
    "saṃdaśasya": ['mw'],
    "saṃdaṃś": ['ap90', 'mw'],
    "saṃdaṃśa": ['cae', 'mw'],
    "saṃdaṃśaka": ['mw'],
    "saṃdaṃśakaḥ": ['ap90'],
    "saṃdaṃśaḥ": ['ap90'],
    "saṃdaṃśikā": ['ap90', 'bhs', 'mw'],
    "saṃdaṃśita": ['mw'],
    "saṃdaṣṭa": ['ap90', 'cae', 'mw'],
    "saṃdaṣṭadantacchada": ['mw'],
    "saṃdaṣṭaka": ['mw'],
    "saṃdaṣṭakusumaśayana": ['mw'],
    "saṃdaṣṭatā": ['mw'],
    "saṃdaṣṭauṣṭha": ['mw'],
    "saṃdaṣṭayamaka": ['mw'],
    "saṃdaṣṭādhara": ['mw'],
    "saṃdegdhṛ": ['mw'],
    "saṃdegha": ['cae', 'mw'],
    "saṃdeha": ['cae', 'mw'],
    "saṃdehabhañjana": ['mw'],
    "saṃdehabhañjikā": ['mw'],
    "saṃdehabhṛt": ['mw'],
    "saṃdehacchedana": ['mw'],
    "saṃdehadolā": ['mw'],
    "saṃdehadolāstha": ['mw'],
    "saṃdehadāyin": ['mw'],
    "saṃdehagandha": ['mw'],
    "saṃdehapada": ['cae', 'mw'],
    "saṃdehasamuccaya": ['mw'],
    "saṃdehatva": ['mw'],
    "saṃdehaviṣauṣadhi": ['mw'],
    "saṃdehayāna": ['mw'],
    "saṃdehaḥ": ['ap90'],
    "saṃdehin": ['ap90', 'mw'],
    "saṃdehya": ['mw'],
    "saṃdehālaṃkāra": ['mw'],
    "saṃdehālaṃkṛti": ['mw'],
    "saṃdehāpanodana": ['mw'],
    "saṃdeśa": ['cae', 'mw'],
    "saṃdeśagir": ['mw'],
    "saṃdeśahara": ['cae', 'mw'],
    "saṃdeśaharā": ['mw'],
    "saṃdeśahāra": ['mw'],
    "saṃdeśahāraka": ['mw'],
    "saṃdeśahārin": ['cae', 'mw'],
    "saṃdeśaka": ['mw'],
    "saṃdeśakaṃ": ['ap90'],
    "saṃdeśapada": ['mw'],
    "saṃdeśavāc": ['mw'],
    "saṃdeśaḥ": ['ap90'],
    "saṃdeśita": ['mw'],
    "saṃdeśokti": ['mw'],
    "saṃdeśya": ['cae', 'mw'],
    "saṃdeśārtha": ['cae', 'mw'],
    "saṃdeṣṭavya": ['cae', 'mw'],
    "saṃdha": ['cae', 'mw'],
    "saṃdham": ['mw'],
    "saṃdhanajit": ['mw'],
    "saṃdhanv": ['mw'],
    "saṃdhanīya": ['mw'],
    "saṃdhartṛ": ['cae', 'mw'],
    "saṃdharṣita": ['mw'],
    "saṃdhay": ['cae'],
    "saṃdhaya": ['mw'],
    "saṃdheya": ['ap90', 'cae', 'mw'],
    "saṃdhi": ['bhs', 'cae', 'gra', 'mw'],
    "saṃdhibandha": ['cae', 'mw'],
    "saṃdhibandhana": ['cae', 'mw'],
    "saṃdhibhaṅga": ['mw'],
    "saṃdhicamasa": ['mw'],
    "saṃdhicaura": ['mw'],
    "saṃdhiccheda": ['mw'],
    "saṃdhicchedaka": ['bhs', 'mw'],
    "saṃdhicchedana": ['cae', 'mw'],
    "saṃdhicchettar": ['bhs'],
    "saṃdhicchidā": ['mw'],
    "saṃdhicora": ['mw'],
    "saṃdhidūṣaṇa": ['cae', 'mw'],
    "saṃdhiga": ['mw'],
    "saṃdhigacikitsā": ['mw'],
    "saṃdhigranthi": ['mw'],
    "saṃdhigupta": ['mw'],
    "saṃdhigṛha": ['mw'],
    "saṃdhihati": ['bhs'],
    "saṃdhihāraka": ['mw'],
    "saṃdhija": ['mw'],
    "saṃdhijā": ['mw'],
    "saṃdhijīvaka": ['mw'],
    "saṃdhika": ['mw'],
    "saṃdhikaḥ": ['ap90'],
    "saṃdhikuśala": ['mw'],
    "saṃdhikā": ['ap90', 'mw'],
    "saṃdhikāṣṭha": ['mw'],
    "saṃdhilā": ['ap90', 'mw'],
    "saṃdhimat": ['mw'],
    "saṃdhimati": ['mw'],
    "saṃdhimukta": ['mw'],
    "saṃdhimukti": ['mw'],
    "saṃdhin": ['cae', 'mw'],
    "saṃdhinirmocana": ['bhs', 'mw'],
    "saṃdhināla": ['mw'],
    "saṃdhinī": ['ap90', 'mw'],
    "saṃdhinīkṣīra": ['cae', 'mw'],
    "saṃdhiprabandhana": ['mw'],
    "saṃdhipāda": ['mw'],
    "saṃdhipūjā": ['mw'],
    "saṃdhirandhrakā": ['mw'],
    "saṃdhirodha": ['mw'],
    "saṃdhirāga": ['mw'],
    "saṃdhirūpa": ['mw'],
    "saṃdhisambhava": ['mw'],
    "saṃdhisarpaṇa": ['mw'],
    "saṃdhisitāsitaroga": ['mw'],
    "saṃdhistotra": ['mw'],
    "saṃdhita": ['ap90', 'cae', 'mw'],
    "saṃdhitas": ['mw'],
    "saṃdhitaskara": ['mw'],
    "saṃdhitavya": ['mw'],
    "saṃdhiteṣu": ['mw'],
    "saṃdhitsu": ['cae', 'mw'],
    "saṃdhivelā": ['cae', 'mw'],
    "saṃdhivicakṣaṇa": ['mw'],
    "saṃdhivid": ['mw'],
    "saṃdhivigraha": ['cae', 'mw'],
    "saṃdhivigrahaka": ['mw'],
    "saṃdhivigrahakāryādhikārin": ['mw'],
    "saṃdhivigrahakāyastha": ['mw'],
    "saṃdhivigrahayānadvaidhībhāvasamāśrayagrantha": ['mw'],
    "saṃdhivigrahika": ['mw'],
    "saṃdhivigrahādhikāra": ['mw'],
    "saṃdhivigrahādhikārin": ['mw'],
    "saṃdhiviparyaya": ['cae', 'mw'],
    "saṃdhiśūla": ['mw'],
    "saṃdhiḥ": ['ap90'],
    "saṃdhiṣāman": ['mw'],
    "saṃdhmā": ['mw'],
    "saṃdhovita": ['bhs'],
    "saṃdhukṣ": ['ap90', 'mw'],
    "saṃdhukṣaṇa": ['cae', 'mw'],
    "saṃdhukṣaṇaṃ": ['ap90'],
    "saṃdhukṣita": ['ap90', 'bhs', 'mw'],
    "saṃdhukṣya": ['mw'],
    "saṃdhunakam": ['bhs'],
    "saṃdhvāna": ['mw'],
    "saṃdhy": ['mw'],
    "saṃdhya": ['bhs', 'cae', 'mw'],
    "saṃdhyadhyāya": ['mw'],
    "saṃdhyai": ['mw'],
    "saṃdhyakṣara": ['cae', 'mw'],
    "saṃdhyarkṣa": ['mw'],
    "saṃdhyopaniṣad": ['mw'],
    "saṃdhyopasthāna": ['mw'],
    "saṃdhyopāsana": ['mw'],
    "saṃdhyopāsanavidhi": ['mw'],
    "saṃdhyā": ['ap90', 'mw'],
    "saṃdhyābala": ['mw'],
    "saṃdhyābali": ['cae', 'mw'],
    "saṃdhyābhra": ['cae', 'mw'],
    "saṃdhyābhāṣya": ['bhs', 'mw'],
    "saṃdhyācala": ['mw'],
    "saṃdhyācalatarpaṇavidhi": ['mw'],
    "saṃdhyādibrahmakarman": ['mw'],
    "saṃdhyākalpa": ['mw'],
    "saṃdhyākramapaddhati": ['mw'],
    "saṃdhyākāla": ['cae', 'mw'],
    "saṃdhyākālika": ['mw'],
    "saṃdhyākārikā": ['mw'],
    "saṃdhyākārya": ['cae', 'mw'],
    "saṃdhyāmantra": ['mw'],
    "saṃdhyāmantravyākhyā": ['mw'],
    "saṃdhyāmantravyākhyāna": ['mw'],
    "saṃdhyāmaya": ['mw'],
    "saṃdhyāmaṅgala": ['mw'],
    "saṃdhyāmāhātmya": ['mw'],
    "saṃdhyānirṇaya": ['mw'],
    "saṃdhyānirṇayakalpavallī": ['mw'],
    "saṃdhyānyāsa": ['mw'],
    "saṃdhyānāṭin": ['mw'],
    "saṃdhyāpaddhati": ['mw'],
    "saṃdhyāpayoda": ['cae', 'mw'],
    "saṃdhyāpañcīkaraṇavārttika": ['mw'],
    "saṃdhyāprayoga": ['mw'],
    "saṃdhyāprāyaścitta": ['mw'],
    "saṃdhyāpuṣpī": ['mw'],
    "saṃdhyāpātra": ['mw'],
    "saṃdhyārāga": ['mw'],
    "saṃdhyārāma": ['mw'],
    "saṃdhyāsamaya": ['cae', 'mw'],
    "saṃdhyāsūtrapravacana": ['mw'],
    "saṃdhyātraya": ['mw'],
    "saṃdhyātrayaprayoga": ['mw'],
    "saṃdhyātrayavidhi": ['mw'],
    "saṃdhyātva": ['mw'],
    "saṃdhyātṛ": ['mw'],
    "saṃdhyāvandana": ['cae', 'mw'],
    "saṃdhyāvandanabhāṣya": ['mw'],
    "saṃdhyāvandanagurubhāṣya": ['mw'],
    "saṃdhyāvandanalaghubhāṣya": ['mw'],
    "saṃdhyāvandanamantra": ['mw'],
    "saṃdhyāvandanavidhi": ['mw'],
    "saṃdhyāvandanavivaraṇa": ['mw'],
    "saṃdhyāvandanopāsanakrama": ['mw'],
    "saṃdhyāvidhi": ['cae', 'mw'],
    "saṃdhyāvidhimantrasamūhaṭīkā": ['mw'],
    "saṃdhyāvidyā": ['mw'],
    "saṃdhyāvāsa": ['mw'],
    "saṃdhyāy": ['cae'],
    "saṃdhyāya": ['mw'],
    "saṃdhyāśatasūtrībhāṣya": ['mw'],
    "saṃdhyāśaṅkha": ['cae', 'mw'],
    "saṃdhyāśaṅkhadhvani": ['mw'],
    "saṃdhyāṃsa": ['mw'],
    "saṃdhyāṃśa": ['cae', 'mw'],
    "saṃdhyāṃśaka": ['cae', 'mw'],
    "saṃdhyāṃśu": ['mw'],
    "saṃdhā": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃdhābhāṣita": ['mw'],
    "saṃdhābhāṣya": ['mw'],
    "saṃdhāna": ['bhs', 'cae', 'mw'],
    "saṃdhānabhāva": ['mw'],
    "saṃdhānakalpavallī": ['mw'],
    "saṃdhānakaraṇa": ['mw'],
    "saṃdhānakartṛ": ['mw'],
    "saṃdhānakārin": ['mw'],
    "saṃdhānakṛt": ['mw'],
    "saṃdhānatāla": ['mw'],
    "saṃdhānaṃ": ['ap90'],
    "saṃdhānikā": ['mw'],
    "saṃdhānin": ['ap90'],
    "saṃdhāninī": ['ap90', 'mw'],
    "saṃdhānita": ['ap90', 'mw'],
    "saṃdhānāsana": ['mw'],
    "saṃdhānī": ['ap90', 'mw'],
    "saṃdhānīya": ['cae', 'mw'],
    "saṃdhāra": ['bhs'],
    "saṃdhāraka": ['bhs'],
    "saṃdhāraṇa": ['cae', 'mw'],
    "saṃdhāraṇaṃ": ['ap90'],
    "saṃdhāraṇā": ['mw'],
    "saṃdhāraṇīya": ['mw'],
    "saṃdhārya": ['cae', 'mw'],
    "saṃdhātavya": ['cae', 'mw'],
    "saṃdhātṛ": ['cae', 'mw'],
    "saṃdhāv": ['mw'],
    "saṃdhāvacana": ['mw'],
    "saṃdhāvati": ['bhs'],
    "saṃdhāvaṇikā": ['bhs'],
    "saṃdhāveṇikā": ['mw'],
    "saṃdhāya": ['bhs', 'mw'],
    "saṃdhāyagamana": ['mw'],
    "saṃdhāyasambhāṣā": ['mw'],
    "saṃdhāyin": ['cae', 'mw'],
    "saṃdhāyya": ['bhs'],
    "saṃdhāyāsana": ['mw'],
    "saṃdhīraṇa": ['mw'],
    "saṃdhīśvara": ['mw'],
    "saṃdhū": ['mw'],
    "saṃdhūkṣaṇatā": ['bhs'],
    "saṃdhūkṣita": ['bhs'],
    "saṃdhūmāya": ['mw'],
    "saṃdhūmāyate": ['bhs'],
    "saṃdhūyate": ['bhs'],
    "saṃdhṛ": ['ap90', 'mw'],
    "saṃdhṛta": ['mw'],
    "saṃdhṛti": ['cae', 'mw'],
    "saṃdidarśayiṣu": ['mw'],
    "saṃdidhakṣu": ['mw'],
    "saṃdidṛkṣu": ['mw'],
    "saṃdigdha": ['ap90', 'cae', 'mw'],
    "saṃdigdhabuddhi": ['cae', 'mw'],
    "saṃdigdhalekhya": ['mw'],
    "saṃdigdhamati": ['mw'],
    "saṃdigdhaniścaya": ['mw'],
    "saṃdigdhaphala": ['mw'],
    "saṃdigdhapunaruktatva": ['mw'],
    "saṃdigdhatva": ['mw'],
    "saṃdigdhatā": ['mw'],
    "saṃdigdhākṣara": ['mw'],
    "saṃdigdhārtha": ['mw'],
    "saṃdigdhīkṛta": ['mw'],
    "saṃdih": ['ap90', 'cae', 'gra', 'mw'],
    "saṃdita": ['ap90', 'cae', 'mw'],
    "saṃdiś": ['ap90', 'mw'],
    "saṃdiśya": ['mw'],
    "saṃdiṣṭa": ['ap90', 'mw'],
    "saṃdiṣṭavat": ['mw'],
    "saṃdiṣṭārtha": ['mw'],
    "saṃdo": ['mw'],
    "saṃdoha": ['cae', 'mw'],
    "saṃdohana": ['cae', 'mw'],
    "saṃdohaḥ": ['ap90'],
    "saṃdohyā": ['mw'],
    "saṃdola": ['mw'],
    "saṃdoṣa": ['bhs'],
    "saṃdrava": ['mw'],
    "saṃdraṣṭavya": ['cae', 'mw'],
    "saṃdraṣṭṛ": ['cae', 'mw'],
    "saṃdru": ['mw'],
    "saṃdrāva": ['mw'],
    "saṃdrāvaḥ": ['ap90'],
    "saṃdugdha": ['mw'],
    "saṃduh": ['mw'],
    "saṃduhyā": ['mw'],
    "saṃduṣ": ['ap90', 'mw'],
    "saṃduṣṭa": ['ap90', 'cae', 'mw'],
    "saṃdveṣa": ['bhs'],
    "saṃdā": ['mw'],
    "saṃdāha": ['mw'],
    "saṃdāhaḥ": ['ap90'],
    "saṃdāmitaka": ['mw'],
    "saṃdāna": ['cae', 'gra', 'mw'],
    "saṃdānatā": ['mw'],
    "saṃdānaṃ": ['ap90'],
    "saṃdānikā": ['mw'],
    "saṃdāninī": ['ap90', 'mw'],
    "saṃdānita": ['ap90', 'cae', 'mw'],
    "saṃdānitaka": ['mw'],
    "saṃdārayati": ['bhs'],
    "saṃdātṛ": ['cae', 'mw'],
    "saṃdāva": ['mw'],
    "saṃdāvaḥ": ['ap90'],
    "saṃdāya": ['cae', 'mw'],
    "saṃdāyin": ['cae', 'mw'],
    "saṃdī": ['ap90', 'mw'],
    "saṃdīkṣita": ['mw'],
    "saṃdīna": ['mw'],
    "saṃdīp": ['ap90', 'mw'],
    "saṃdīpaka": ['cae', 'mw'],
    "saṃdīpana": ['ap90', 'cae', 'mw'],
    "saṃdīpanavat": ['mw'],
    "saṃdīpanī": ['mw'],
    "saṃdīpita": ['mw'],
    "saṃdīpta": ['ap90', 'cae', 'mw'],
    "saṃdīptalocana": ['mw'],
    "saṃdīpya": ['mw'],
    "saṃdūṣaṇa": ['cae', 'mw'],
    "saṃdūṣaṇakara": ['mw'],
    "saṃdūṣaṇaṃ": ['ap90'],
    "saṃdūṣaṇā": ['bhs'],
    "saṃdūṣita": ['ap90', 'mw'],
    "saṃdṛbdha": ['cae', 'mw'],
    "saṃdṛbdhatva": ['mw'],
    "saṃdṛbh": ['ap90'],
    "saṃdṛś": ['ap90', 'cae', 'gra', 'mw'],
    "saṃdṛśa": ['mw'],
    "saṃdṛśya": ['mw'],
    "saṃdṛśyati": ['bhs'],
    "saṃdṛṣṭa": ['cae', 'mw'],
    "saṃdṛṣṭi": ['cae', 'gra', 'mw'],
    "saṃdṛṣṭika": ['bhs', 'mw'],
    "saṃga": ['cae', 'gra', 'mw'],
    "saṃgai": ['ap90', 'mw'],
    "saṃgam": ['ap90', 'mw'],
    "saṃgama": ['cae', 'gra', 'mw'],
    "saṃgamadatta": ['mw'],
    "saṃgamajñāna": ['mw'],
    "saṃgamaka": ['mw'],
    "saṃgamamaṇi": ['cae', 'mw'],
    "saṃgamana": ['cae', 'gra', 'mw'],
    "saṃgamanaṃ": ['ap90'],
    "saṃgamanera": ['mw'],
    "saṃgamantrā": ['bhs'],
    "saṃgamanī": ['gra'],
    "saṃgamanīya": ['cae', 'mw'],
    "saṃgamasvāmin": ['mw'],
    "saṃgamasādhvasa": ['mw'],
    "saṃgamatantrarāja": ['mw'],
    "saṃgamaśrījñāna": ['mw'],
    "saṃgamaḥ": ['ap90'],
    "saṃgameśa": ['mw'],
    "saṃgameśvara": ['mw'],
    "saṃgameśvaramāhātmya": ['mw'],
    "saṃgameśvarastotra": ['mw'],
    "saṃgameśvarasvāmin": ['mw'],
    "saṃgamin": ['cae', 'mw'],
    "saṃgamita": ['mw'],
    "saṃgamitavat": ['mw'],
    "saṃgamāditya": ['mw'],
    "saṃgandharāja": ['bhs'],
    "saṃgara": ['cae', 'mw'],
    "saṃgarakṣama": ['mw'],
    "saṃgarastha": ['mw'],
    "saṃgaraḥ": ['ap90'],
    "saṃgaraṇa": ['cae', 'mw'],
    "saṃgarj": ['mw'],
    "saṃgat": ['mw'],
    "saṃgata": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃgatagātra": ['mw'],
    "saṃgataka": ['mw'],
    "saṃgatasaṃdhi": ['mw'],
    "saṃgatha": ['cae', 'gra', 'mw'],
    "saṃgathā": ['mw'],
    "saṃgati": ['bhs', 'cae', 'gra', 'mw'],
    "saṃgatika": ['mw'],
    "saṃgatilakṣaṇa": ['mw'],
    "saṃgatimālā": ['mw'],
    "saṃgatin": ['mw'],
    "saṃgatiprakāśa": ['mw'],
    "saṃgativicāra": ['mw'],
    "saṃgativāda": ['mw'],
    "saṃgatiḥ": ['ap90'],
    "saṃgatyanumiti": ['mw'],
    "saṃgatyanumitivāda": ['mw'],
    "saṃgatyā": ['mw'],
    "saṃgatārtha": ['cae', 'mw'],
    "saṃgava": ['cae', 'gra', 'mw'],
    "saṃgavakāla": ['mw'],
    "saṃgavavelā": ['mw'],
    "saṃgavaḥ": ['ap90'],
    "saṃgaveṣati": ['bhs'],
    "saṃgavinī": ['cae', 'mw'],
    "saṃgaḥ": ['ap90'],
    "saṃgaṇanā": ['bhs', 'cae', 'mw'],
    "saṃgaṇayati": ['bhs'],
    "saṃgaṇikā": ['ap90', 'bhs', 'mw'],
    "saṃgerī": ['bhs'],
    "saṃgha": ['cae', 'mw'],
    "saṃghabhadra": ['mw'],
    "saṃghabheda": ['bhs', 'mw'],
    "saṃghabhedaka": ['mw'],
    "saṃghabodhi": ['mw'],
    "saṃghacārin": ['cae', 'mw'],
    "saṃghadāsa": ['mw'],
    "saṃghaguhya": ['mw'],
    "saṃghagupta": ['mw'],
    "saṃghajīvin": ['mw'],
    "saṃghaka": ['mw'],
    "saṃghamitra": ['mw'],
    "saṃghapati": ['mw'],
    "saṃghapatitva": ['mw'],
    "saṃghapuruṣa": ['mw'],
    "saṃghapuṣpī": ['mw'],
    "saṃgharakṣita": ['bhs', 'mw'],
    "saṃgharakṣitāvadāna": ['bhs'],
    "saṃgharṣa": ['cae', 'mw'],
    "saṃgharṣayitṛ": ['mw'],
    "saṃgharṣaśālin": ['mw'],
    "saṃgharṣaḥ": ['ap90'],
    "saṃgharṣaṇa": ['mw'],
    "saṃgharṣin": ['cae', 'mw'],
    "saṃgharṣā": ['mw'],
    "saṃghasa": ['mw'],
    "saṃghasāmagrīdattaka": ['bhs'],
    "saṃghata": ['bhs'],
    "saṃghatala": ['mw'],
    "saṃghatitha": ['mw'],
    "saṃghavardhana": ['mw'],
    "saṃghavṛtti": ['cae', 'mw'],
    "saṃghavṛttitā": ['mw'],
    "saṃghaśas": ['cae', 'mw'],
    "saṃghaḥ": ['ap90'],
    "saṃghaṭ": ['ap90', 'mw'],
    "saṃghaṭa": ['mw'],
    "saṃghaṭaka": ['mw'],
    "saṃghaṭana": ['bhs', 'cae', 'mw'],
    "saṃghaṭanā": ['ap90', 'mw'],
    "saṃghaṭati": ['bhs'],
    "saṃghaṭita": ['bhs', 'mw'],
    "saṃghaṭṭ": ['ap90', 'mw'],
    "saṃghaṭṭa": ['cae', 'mw'],
    "saṃghaṭṭacakra": ['mw'],
    "saṃghaṭṭaka": ['bhs'],
    "saṃghaṭṭana": ['mw'],
    "saṃghaṭṭanaṃ": ['ap90'],
    "saṃghaṭṭapaṇita": ['mw'],
    "saṃghaṭṭati": ['bhs'],
    "saṃghaṭṭaḥ": ['ap90'],
    "saṃghaṭṭin": ['mw'],
    "saṃghaṭṭita": ['mw'],
    "saṃghaṭṭā": ['mw'],
    "saṃghin": ['bhs'],
    "saṃghoṣa": ['bhs', 'mw'],
    "saṃghoṣiṇī": ['mw'],
    "saṃghrā": ['mw'],
    "saṃghuṣ": ['ap90'],
    "saṃghuṣita": ['mw'],
    "saṃghuṣṭa": ['ap90', 'mw'],
    "saṃghuṣṭaka": ['mw'],
    "saṃghādhipa": ['mw'],
    "saṃghānanda": ['mw'],
    "saṃghānna": ['mw'],
    "saṃghārāma": ['mw'],
    "saṃghāta": ['bhs', 'cae', 'mw'],
    "saṃghātacārin": ['mw'],
    "saṃghātaja": ['mw'],
    "saṃghātaka": ['mw'],
    "saṃghātakaṭhina": ['mw'],
    "saṃghātam": ['mw'],
    "saṃghātana": ['mw'],
    "saṃghātaparvata": ['mw'],
    "saṃghātapattrikā": ['mw'],
    "saṃghātavat": ['mw'],
    "saṃghātavihārin": ['mw'],
    "saṃghātaśūlavat": ['mw'],
    "saṃghātaḥ": ['ap90'],
    "saṃghātikā": ['mw'],
    "saṃghātya": ['mw'],
    "saṃghāvaśeṣa": ['bhs', 'mw'],
    "saṃghāvaśeṣaka": ['bhs'],
    "saṃghāṇakaḥ": ['ap90'],
    "saṃghāṭa": ['bhs', 'mw'],
    "saṃghāṭasūtra": ['bhs', 'mw'],
    "saṃghāṭi": ['bhs', 'mw'],
    "saṃghāṭikā": ['ap90', 'bhs', 'mw'],
    "saṃghāṭī": ['mw'],
    "saṃghī": ['mw'],
    "saṃghībhū": ['mw'],
    "saṃghṛṣ": ['ap90', 'mw'],
    "saṃghṛṣṭa": ['mw'],
    "saṃgin": ['ap90', 'mw'],
    "saṃgir": ['cae', 'gra', 'mw'],
    "saṃgira": ['cae', 'mw'],
    "saṃgopana": ['cae', 'mw'],
    "saṃgopanīya": ['mw'],
    "saṃgopāyati": ['bhs'],
    "saṃgrabh": ['mw'],
    "saṃgrah": ['ap90', 'mw'],
    "saṃgraha": ['bhs', 'cae', 'mw'],
    "saṃgrahacūḍāmaṇi": ['mw'],
    "saṃgrahagrahaṇī": ['mw'],
    "saṃgrahagrantha": ['mw'],
    "saṃgrahaka": ['bhs'],
    "saṃgrahakāra": ['mw'],
    "saṃgrahaparvan": ['mw'],
    "saṃgrahaprakāśikā": ['mw'],
    "saṃgraharatnamālā": ['mw'],
    "saṃgraharāmāyaṇa": ['mw'],
    "saṃgrahavaidyanāthīya": ['mw'],
    "saṃgrahavastu": ['bhs', 'mw'],
    "saṃgrahavat": ['mw'],
    "saṃgrahavivaraṇa": ['mw'],
    "saṃgrahaśloka": ['mw'],
    "saṃgrahaḥ": ['ap90'],
    "saṃgrahaṇa": ['cae', 'mw'],
    "saṃgrahaṇaṃ": ['ap90'],
    "saṃgrahaṇī": ['bhs', 'mw'],
    "saṃgrahaṇīratna": ['mw'],
    "saṃgrahaṇīya": ['mw'],
    "saṃgrahin": ['cae', 'mw'],
    "saṃgrahītavya": ['mw'],
    "saṃgrahītṛ": ['ap90', 'cae', 'mw'],
    "saṃgrama": ['bhs'],
    "saṃgranthana": ['bhs', 'cae', 'mw'],
    "saṃgras": ['mw'],
    "saṃgrasana": ['cae', 'mw'],
    "saṃgrathana": ['mw'],
    "saṃgrathita": ['cae', 'mw'],
    "saṃgrāha": ['bhs', 'mw'],
    "saṃgrāhaka": ['bhs', 'cae', 'mw'],
    "saṃgrāhakaḥ": ['ap90'],
    "saṃgrāhaḥ": ['ap90'],
    "saṃgrāhin": ['ap90', 'cae', 'mw'],
    "saṃgrāhita": ['mw'],
    "saṃgrāhya": ['cae', 'mw'],
    "saṃgrām": ['mw'],
    "saṃgrāma": ['cae', 'mw'],
    "saṃgrāmabhūmi": ['cae', 'mw'],
    "saṃgrāmacandra": ['mw'],
    "saṃgrāmadatta": ['mw'],
    "saṃgrāmadeva": ['mw'],
    "saṃgrāmagupta": ['mw'],
    "saṃgrāmajit": ['cae', 'mw'],
    "saṃgrāmakarman": ['mw'],
    "saṃgrāmamūrdhan": ['cae', 'mw'],
    "saṃgrāmamṛtyu": ['mw'],
    "saṃgrāmanagara": ['mw'],
    "saṃgrāmapaṭaha": ['mw'],
    "saṃgrāmapāla": ['mw'],
    "saṃgrāmarāja": ['mw'],
    "saṃgrāmasiddhi": ['mw'],
    "saṃgrāmasiṃha": ['mw'],
    "saṃgrāmasāhi": ['mw'],
    "saṃgrāmatulā": ['mw'],
    "saṃgrāmatūrya": ['cae', 'mw'],
    "saṃgrāmavardhana": ['mw'],
    "saṃgrāmavarṣa": ['mw'],
    "saṃgrāmavijaya": ['mw'],
    "saṃgrāmayati": ['bhs'],
    "saṃgrāmaśiras": ['cae', 'mw'],
    "saṃgrāmaśīrṣa": ['bhs'],
    "saṃgrāmaḥ": ['ap90'],
    "saṃgrāmika": ['mw'],
    "saṃgrāmin": ['cae', 'mw'],
    "saṃgrāmya": ['mw'],
    "saṃgrāmāgra": ['cae', 'mw'],
    "saṃgrāmāpīḍa": ['mw'],
    "saṃgrāmārthin": ['mw'],
    "saṃgrāmāśis": ['mw'],
    "saṃgrāmāṅgana": ['mw'],
    "saṃgupta": ['ap90', 'cae', 'mw'],
    "saṃguptalekha": ['mw'],
    "saṃgupti": ['cae', 'mw'],
    "saṃguptārtha": ['mw'],
    "saṃguṇa": ['mw'],
    "saṃguṇaya": ['mw'],
    "saṃguṇīkṛta": ['mw'],
    "saṃgā": ['mw'],
    "saṃgāh": ['mw'],
    "saṃgāvaḥ": ['ap90'],
    "saṃgāyana": ['mw'],
    "saṃgāyati": ['bhs'],
    "saṃgīrṇa": ['ap90', 'mw'],
    "saṃgīta": ['ap90', 'cae', 'mw'],
    "saṃgītacintāmaṇi": ['mw'],
    "saṃgītadarpaṇa": ['mw'],
    "saṃgītadāmodara": ['mw'],
    "saṃgītaka": ['cae', 'mw'],
    "saṃgītakagṛha": ['cae', 'mw'],
    "saṃgītakalikā": ['mw'],
    "saṃgītakalpadruma": ['mw'],
    "saṃgītakalānidhi": ['mw'],
    "saṃgītakapada": ['cae', 'mw'],
    "saṃgītakaumudī": ['mw'],
    "saṃgītakaṃ": ['ap90'],
    "saṃgītamakaranda": ['mw'],
    "saṃgītamuktāvalī": ['mw'],
    "saṃgītamādhava": ['mw'],
    "saṃgītamīmāṃsā": ['mw'],
    "saṃgītanipāta": ['bhs'],
    "saṃgītanārāyaṇa": ['mw'],
    "saṃgītanṛttaratnākara": ['mw'],
    "saṃgītanṛtyākara": ['mw'],
    "saṃgītapuṣpāñjali": ['mw'],
    "saṃgītapārijāta": ['mw'],
    "saṃgītaraghunandana": ['mw'],
    "saṃgītaratna": ['mw'],
    "saṃgītaratnamālā": ['mw'],
    "saṃgītaratnākara": ['cae', 'mw'],
    "saṃgītaratnāvalī": ['mw'],
    "saṃgītarāgalakṣaṇa": ['mw'],
    "saṃgītarāghava": ['mw'],
    "saṃgītarāja": ['mw'],
    "saṃgītasahāyinī": ['cae', 'mw'],
    "saṃgītasarvasva": ['mw'],
    "saṃgītasiddhānta": ['mw'],
    "saṃgītasudhā": ['mw'],
    "saṃgītasudhākara": ['mw'],
    "saṃgītasundarasetu": ['mw'],
    "saṃgītasāgara": ['mw'],
    "saṃgītasāra": ['mw'],
    "saṃgītasārasaṃgraha": ['cae', 'mw'],
    "saṃgītasāroddhāra": ['mw'],
    "saṃgītasārāmṛta": ['mw'],
    "saṃgītatāla": ['mw'],
    "saṃgītaveśman": ['cae', 'mw'],
    "saṃgītavidyā": ['cae', 'mw'],
    "saṃgītavinodenṛtyādhyāya": ['mw'],
    "saṃgītavyāpṛta": ['mw'],
    "saṃgītavṛttaratnākara": ['mw'],
    "saṃgītaśiromaṇi": ['mw'],
    "saṃgītaśālā": ['mw'],
    "saṃgītaśāstra": ['mw'],
    "saṃgīti": ['bhs', 'cae', 'mw'],
    "saṃgītiparyāya": ['bhs', 'mw'],
    "saṃgītiprāsāda": ['mw'],
    "saṃgītiḥ": ['ap90'],
    "saṃgītopaniṣad": ['mw'],
    "saṃgītopaniṣatsāra": ['mw'],
    "saṃgītāmṛta": ['mw'],
    "saṃgītārtha": ['mw'],
    "saṃgītārṇava": ['mw'],
    "saṃgītāvasāna": ['mw'],
    "saṃgūhayati": ['bhs'],
    "saṃgūḍha": ['ap90', 'mw'],
    "saṃgṛbhita": ['mw'],
    "saṃgṛbhāya": ['mw'],
    "saṃgṛbhīta": ['mw'],
    "saṃgṛbhītṛ": ['cae', 'mw'],
    "saṃgṛhīta": ['ap90', 'mw'],
    "saṃgṛhītagrāhin": ['bhs'],
    "saṃgṛhītapakva": ['bhs'],
    "saṃgṛhītarāṣṭra": ['mw'],
    "saṃgṛhīti": ['mw'],
    "saṃgṛhītṛ": ['cae', 'mw'],
    "saṃgṝ": ['ap90', 'mw'],
    "saṃha": ['mw'],
    "saṃhan": ['ap90', 'mw'],
    "saṃhanana": ['cae', 'mw'],
    "saṃhananabalopeta": ['mw'],
    "saṃhananavat": ['mw'],
    "saṃhananaṃ": ['ap90'],
    "saṃhananopeta": ['mw'],
    "saṃhananīya": ['mw'],
    "saṃhantrī": ['mw'],
    "saṃhantṛ": ['mw'],
    "saṃhanu": ['cae', 'mw'],
    "saṃhara": ['mw'],
    "saṃharati": ['bhs'],
    "saṃharaṇa": ['cae', 'mw'],
    "saṃharaṇaṃ": ['ap90'],
    "saṃhartavya": ['cae', 'mw'],
    "saṃhartṛ": ['ap90', 'cae', 'mw'],
    "saṃharākhya": ['mw'],
    "saṃharṣa": ['cae', 'mw'],
    "saṃharṣaka": ['bhs'],
    "saṃharṣayogin": ['mw'],
    "saṃharṣaḥ": ['ap90'],
    "saṃharṣaṇa": ['cae', 'mw'],
    "saṃharṣaṇā": ['bhs'],
    "saṃharṣaṇīya": ['bhs'],
    "saṃharṣin": ['cae', 'mw'],
    "saṃharṣita": ['mw'],
    "saṃhat": ['cae', 'ddsa', 'gra', 'mw'],
    "saṃhata": ['ap90', 'cae', 'mw'],
    "saṃhatabhrū": ['mw'],
    "saṃhatabhrūkuṭimukha": ['mw'],
    "saṃhatahasta": ['mw'],
    "saṃhatahastatva": ['mw'],
    "saṃhatajānu": ['mw'],
    "saṃhatajānuka": ['mw'],
    "saṃhatakulīna": ['mw'],
    "saṃhatala": ['mw'],
    "saṃhatamūrti": ['mw'],
    "saṃhatapucchi": ['mw'],
    "saṃhatastanī": ['mw'],
    "saṃhatatala": ['mw'],
    "saṃhatatva": ['mw'],
    "saṃhatatā": ['ap90', 'mw'],
    "saṃhatavākkala": ['mw'],
    "saṃhatavṛttoru": ['mw'],
    "saṃhati": ['cae', 'mw'],
    "saṃhatiśalin": ['mw'],
    "saṃhatiḥ": ['ap90'],
    "saṃhatoru": ['mw'],
    "saṃhatya": ['mw'],
    "saṃhatyakārin": ['mw'],
    "saṃhatyakāritva": ['mw'],
    "saṃhatyakāritā": ['mw'],
    "saṃhatāpana": ['mw'],
    "saṃhatāñjali": ['mw'],
    "saṃhatāśva": ['mw'],
    "saṃhatāṅga": ['mw'],
    "saṃhatībhāva": ['mw'],
    "saṃhavana": ['mw'],
    "saṃhavanaṃ": ['ap90'],
    "saṃhi": ['mw'],
    "saṃhita": ['ap90', 'cae', 'ddsa', 'mw'],
    "saṃhitapuṣpikā": ['mw'],
    "saṃhiteṣu": ['mw'],
    "saṃhiti": ['mw'],
    "saṃhitika": ['mw'],
    "saṃhitopaniṣad": ['mw'],
    "saṃhitopaniṣadbrāhmaṇa": ['mw'],
    "saṃhitoru": ['mw'],
    "saṃhitā": ['ap90', 'mw'],
    "saṃhitābhāṣya": ['mw'],
    "saṃhitādaṇḍaka": ['mw'],
    "saṃhitādhyayana": ['mw'],
    "saṃhitādhyāyin": ['mw'],
    "saṃhitādīpaka": ['mw'],
    "saṃhitāhomapaddhati": ['mw'],
    "saṃhitājapa": ['mw'],
    "saṃhitākalpa": ['mw'],
    "saṃhitākāra": ['mw'],
    "saṃhitānta": ['mw'],
    "saṃhitāpradīpa": ['mw'],
    "saṃhitāprakāra": ['mw'],
    "saṃhitāpāṭha": ['cae', 'mw'],
    "saṃhitāratnākara": ['mw'],
    "saṃhitārṇava": ['mw'],
    "saṃhitāsamānalakṣaṇa": ['mw'],
    "saṃhitāskandha": ['mw'],
    "saṃhitāsāra": ['mw'],
    "saṃhitāsārāvalī": ['mw'],
    "saṃhitāsūtra": ['mw'],
    "saṃhitāvat": ['mw'],
    "saṃhitāvidhi": ['mw'],
    "saṃhitāvidhivivaraṇa": ['mw'],
    "saṃhitībhāva": ['mw'],
    "saṃhlāda": ['mw'],
    "saṃhlādin": ['cae', 'mw'],
    "saṃhotra": ['cae', 'gra', 'mw'],
    "saṃhriyamāṇa": ['mw'],
    "saṃhriyamāṇabusam": ['mw'],
    "saṃhriyamāṇayavam": ['mw'],
    "saṃhrād": ['mw'],
    "saṃhrāda": ['cae', 'mw'],
    "saṃhrādana": ['cae', 'mw'],
    "saṃhrādaḥ": ['ap90'],
    "saṃhrādi": ['cae', 'mw'],
    "saṃhrādikaṇṭha": ['mw'],
    "saṃhrādin": ['cae', 'mw'],
    "saṃhrādīya": ['mw'],
    "saṃhrīṇa": ['ap90', 'mw'],
    "saṃhu": ['mw'],
    "saṃhvayana": ['cae'],
    "saṃhve": ['mw'],
    "saṃhvārita": ['mw'],
    "saṃhā": ['mw'],
    "saṃhāna": ['mw'],
    "saṃhāra": ['cae', 'mw'],
    "saṃhārabhairava": ['mw'],
    "saṃhārabuddhimat": ['mw'],
    "saṃhāraka": ['ap90', 'mw'],
    "saṃhārakāla": ['mw'],
    "saṃhārakālāya": ['mw'],
    "saṃhārakārin": ['mw'],
    "saṃhāramudrā": ['mw'],
    "saṃhāravarman": ['mw'],
    "saṃhāravegavat": ['mw'],
    "saṃhāraḥ": ['ap90'],
    "saṃhārika": ['mw'],
    "saṃhārin": ['bhs', 'cae', 'mw'],
    "saṃhārya": ['cae', 'mw'],
    "saṃhārāpayitavya": ['bhs'],
    "saṃhāta": ['bhs', 'cae', 'mw'],
    "saṃhātaḥ": ['ap90'],
    "saṃhātya": ['mw'],
    "saṃhāyyam": ['mw'],
    "saṃhūti": ['mw'],
    "saṃhūtiḥ": ['ap90'],
    "saṃhṛ": ['ap90', 'mw'],
    "saṃhṛta": ['ap90', 'mw'],
    "saṃhṛtabusam": ['mw'],
    "saṃhṛtayavam": ['mw'],
    "saṃhṛti": ['cae', 'mw'],
    "saṃhṛtimat": ['mw'],
    "saṃhṛtiḥ": ['ap90'],
    "saṃhṛṣ": ['ap90', 'mw'],
    "saṃhṛṣita": ['mw'],
    "saṃhṛṣṭa": ['ap90', 'cae', 'mw'],
    "saṃhṛṣṭamanas": ['mw'],
    "saṃhṛṣṭaroman": ['mw'],
    "saṃhṛṣṭaromāṅga": ['mw'],
    "saṃhṛṣṭavadana": ['mw'],
    "saṃhṛṣṭavat": ['mw'],
    "saṃhṛṣṭin": ['mw'],
    "saṃj": ['ap90'],
    "saṃja": ['mw'],
    "saṃjalp": ['ap90', 'mw'],
    "saṃjalpa": ['cae', 'mw'],
    "saṃjalpaḥ": ['ap90'],
    "saṃjalpita": ['mw'],
    "saṃjan": ['ap90', 'mw'],
    "saṃjana": ['bhs'],
    "saṃjanaka": ['bhs'],
    "saṃjanana": ['cae', 'mw'],
    "saṃjanayitar": ['bhs'],
    "saṃjanita": ['mw'],
    "saṃjap": ['mw'],
    "saṃjapāla": ['mw'],
    "saṃjarbhurāṇa": ['mw'],
    "saṃjavana": ['mw'],
    "saṃjavanaṃ": ['ap90'],
    "saṃjaya": ['bhs', 'cae', 'gra', 'mw'],
    "saṃjayakaviśekhara": ['mw'],
    "saṃjayantī": ['bhs', 'mw'],
    "saṃjayat": ['mw'],
    "saṃjayaḥ": ['ap90'],
    "saṃjayin": ['mw'],
    "saṃjayinvairaṭīputra": ['bhs'],
    "saṃjaḥ": ['ap90'],
    "saṃji": ['mw'],
    "saṃjighṛkṣu": ['mw'],
    "saṃjihāna": ['mw'],
    "saṃjihīrṣu": ['cae', 'mw'],
    "saṃjijīvayiṣu": ['cae', 'mw'],
    "saṃjijīviṣu": ['cae', 'mw'],
    "saṃjit": ['cae', 'gra', 'mw'],
    "saṃjita": ['bhs', 'mw'],
    "saṃjiti": ['cae', 'mw'],
    "saṃjughukṣu": ['mw'],
    "saṃjughukṣā": ['mw'],
    "saṃjuṣṭa": ['cae', 'mw'],
    "saṃjval": ['mw'],
    "saṃjvalana": ['cae', 'mw'],
    "saṃjvar": ['mw'],
    "saṃjvara": ['cae', 'mw'],
    "saṃjvarakara": ['mw'],
    "saṃjvaravat": ['mw'],
    "saṃjvaraḥ": ['ap90'],
    "saṃjvarātura": ['mw'],
    "saṃjvālya": ['mw'],
    "saṃjvārin": ['mw'],
    "saṃjña": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃjñaka": ['mw'],
    "saṃjñakā": ['cae'],
    "saṃjñapana": ['bhs', 'cae', 'mw'],
    "saṃjñapanaṃ": ['ap90'],
    "saṃjñapita": ['mw'],
    "saṃjñapta": ['mw'],
    "saṃjñaptahoma": ['mw'],
    "saṃjñapti": ['bhs', 'cae', 'mw'],
    "saṃjñaptiḥ": ['ap90'],
    "saṃjñatā": ['cae', 'mw'],
    "saṃjñeya": ['mw'],
    "saṃjñikā": ['mw'],
    "saṃjñin": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃjñita": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃjñitva": ['mw'],
    "saṃjñopasarjanībhū": ['mw'],
    "saṃjñotpāda": ['bhs'],
    "saṃjñu": ['ap90', 'mw'],
    "saṃjñā": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃjñābhikṣu": ['bhs'],
    "saṃjñādhikāra": ['mw'],
    "saṃjñākaraṇa": ['mw'],
    "saṃjñākaraṇapariśiṣṭa": ['mw'],
    "saṃjñākarman": ['mw'],
    "saṃjñāna": ['cae', 'gra', 'mw'],
    "saṃjñānanā": ['bhs', 'mw'],
    "saṃjñānaṃ": ['ap90'],
    "saṃjñānī": ['mw'],
    "saṃjñāpada": ['bhs'],
    "saṃjñāpana": ['mw'],
    "saṃjñāpanaṃ": ['ap90'],
    "saṃjñāparibhāṣā": ['mw'],
    "saṃjñāpita": ['mw'],
    "saṃjñāprakaraṇa": ['mw'],
    "saṃjñāprakriyā": ['mw'],
    "saṃjñāpti": ['bhs'],
    "saṃjñāpādavyākhyā": ['mw'],
    "saṃjñāpāṭī": ['mw'],
    "saṃjñārtham": ['cae', 'mw'],
    "saṃjñāsamuccaya": ['mw'],
    "saṃjñāstra": ['mw'],
    "saṃjñāsuta": ['mw'],
    "saṃjñāsūtra": ['mw'],
    "saṃjñāta": ['mw'],
    "saṃjñātantra": ['mw'],
    "saṃjñātarūpa": ['cae', 'gra', 'mw'],
    "saṃjñāti": ['cae', 'mw'],
    "saṃjñātva": ['mw'],
    "saṃjñātṛ": ['mw'],
    "saṃjñāvat": ['ap90', 'mw'],
    "saṃjñāvedayita": ['bhs'],
    "saṃjñāviveka": ['mw'],
    "saṃjñāviṣaya": ['mw'],
    "saṃjñāya": ['bhs'],
    "saṃjñībhūtaka": ['mw'],
    "saṃjñīkṛta": ['bhs'],
    "saṃjā": ['ap90', 'mw'],
    "saṃjāna": ['bhs'],
    "saṃjānayati": ['bhs'],
    "saṃjānāti": ['bhs'],
    "saṃjāta": ['ap90', 'cae', 'mw'],
    "saṃjātakautuka": ['mw'],
    "saṃjātakopa": ['mw'],
    "saṃjātalajja": ['mw'],
    "saṃjātanidrāpralaya": ['mw'],
    "saṃjātanirveda": ['mw'],
    "saṃjātapāśa": ['mw'],
    "saṃjātavepathu": ['mw'],
    "saṃjātaviśrambha": ['mw'],
    "saṃjāterṣya": ['mw'],
    "saṃjāvana": ['mw'],
    "saṃjīv": ['ap90', 'mw'],
    "saṃjīva": ['bhs', 'cae', 'mw'],
    "saṃjīvaka": ['cae', 'mw'],
    "saṃjīvakaraṇa": ['mw'],
    "saṃjīvakī": ['mw'],
    "saṃjīvana": ['cae', 'mw'],
    "saṃjīvanaṃ": ['ap90'],
    "saṃjīvanī": ['mw'],
    "saṃjīvin": ['cae', 'mw'],
    "saṃjīvinī": ['mw'],
    "saṃjīvita": ['mw'],
    "saṃjīvārma": ['mw'],
    "saṃjūrv": ['mw'],
    "saṃjṛmbh": ['mw'],
    "saṃjṝ": ['mw'],
    "saṃkacchana": ['bhs'],
    "saṃkakṣa": ['mw'],
    "saṃkakṣikā": ['bhs', 'mw'],
    "saṃkal": ['ap90', 'mw'],
    "saṃkala": ['mw'],
    "saṃkalana": ['cae', 'mw'],
    "saṃkalanaṃ": ['ap90'],
    "saṃkalaḥ": ['ap90'],
    "saṃkalikā": ['bhs'],
    "saṃkalikācūrṇa": ['mw'],
    "saṃkalita": ['ap90', 'mw'],
    "saṃkalitaikya": ['mw'],
    "saṃkalitin": ['mw'],
    "saṃkalitā": ['mw'],
    "saṃkaliyati": ['bhs'],
    "saṃkalpa": ['bhs', 'cae', 'gra', 'mw'],
    "saṃkalpabhava": ['cae', 'mw'],
    "saṃkalpacandrikā": ['mw'],
    "saṃkalpadurgabhañjana": ['mw'],
    "saṃkalpaja": ['cae', 'mw'],
    "saṃkalpajanman": ['cae', 'mw'],
    "saṃkalpajūti": ['mw'],
    "saṃkalpaka": ['cae', 'mw'],
    "saṃkalpakaumudī": ['mw'],
    "saṃkalpakulmala": ['mw'],
    "saṃkalpamūla": ['mw'],
    "saṃkalpana": ['cae', 'mw'],
    "saṃkalpanāmaya": ['mw'],
    "saṃkalpanīya": ['cae', 'mw'],
    "saṃkalpaprabhava": ['mw'],
    "saṃkalparāma": ['mw'],
    "saṃkalparūpa": ['mw'],
    "saṃkalpasambhava": ['mw'],
    "saṃkalpasampatti": ['mw'],
    "saṃkalpasiddha": ['mw'],
    "saṃkalpasiddhi": ['mw'],
    "saṃkalpasmṛtidurgabhañjana": ['mw'],
    "saṃkalpasūryodaya": ['mw'],
    "saṃkalpavant": ['cae'],
    "saṃkalpavat": ['mw'],
    "saṃkalpayoni": ['cae', 'mw'],
    "saṃkalpaśrāddhaprayoga": ['mw'],
    "saṃkalpaḥ": ['ap90'],
    "saṃkalpita": ['ap90', 'mw'],
    "saṃkalpā": ['mw'],
    "saṃkalpātmaka": ['mw'],
    "saṃkaluṣa": ['cae', 'mw'],
    "saṃkalā": ['mw'],
    "saṃkalībhūta": ['bhs'],
    "saṃkamp": ['mw'],
    "saṃkampana": ['bhs'],
    "saṃkan": ['mw'],
    "saṃkara": ['cae', 'mw'],
    "saṃkaraja": ['mw'],
    "saṃkarajāta": ['mw'],
    "saṃkarajāti": ['mw'],
    "saṃkarajātīya": ['mw'],
    "saṃkaraka": ['mw'],
    "saṃkaramīmāṃsā": ['mw'],
    "saṃkarasaṃkara": ['mw'],
    "saṃkarasveda": ['mw'],
    "saṃkaratā": ['mw'],
    "saṃkaraḥ": ['ap90'],
    "saṃkarin": ['cae', 'mw'],
    "saṃkarita": ['mw'],
    "saṃkartam": ['cae', 'mw'],
    "saṃkarāpātrakṛtyā": ['cae', 'mw'],
    "saṃkarāśva": ['mw'],
    "saṃkarī": ['mw'],
    "saṃkarīkaraṇa": ['cae', 'mw'],
    "saṃkarīkṛ": ['mw'],
    "saṃkarṣa": ['cae', 'mw'],
    "saṃkarṣabhāṭṭadīpikā": ['mw'],
    "saṃkarṣakāṇḍa": ['mw'],
    "saṃkarṣaṇa": ['cae', 'mw'],
    "saṃkarṣaṇakāṇḍa": ['mw'],
    "saṃkarṣaṇamaya": ['mw'],
    "saṃkarṣaṇasūtravicāra": ['mw'],
    "saṃkarṣaṇavidyā": ['mw'],
    "saṃkarṣaṇaśaraṇa": ['mw'],
    "saṃkarṣaṇaṃ": ['ap90'],
    "saṃkarṣaṇeśvaratīrtha": ['mw'],
    "saṃkarṣin": ['mw'],
    "saṃkasuka": ['ap90', 'cae', 'mw'],
    "saṃkasusamācāra": ['bhs'],
    "saṃkath": ['ap90', 'mw'],
    "saṃkathana": ['cae', 'mw'],
    "saṃkathanaṃ": ['ap90'],
    "saṃkathita": ['mw'],
    "saṃkathya": ['bhs'],
    "saṃkathā": ['ap90', 'mw'],
    "saṃkaśya": ['bhs'],
    "saṃkaṣṭa": ['mw'],
    "saṃkaṣṭacaturthīkathā": ['mw'],
    "saṃkaṣṭacaturthīvratakathā": ['mw'],
    "saṃkaṣṭaharacaturthīvrata": ['mw'],
    "saṃkaṣṭaharacaturthīvratakālanirṇaya": ['mw'],
    "saṃkaṣṭaharaṇastotra": ['mw'],
    "saṃkaṣṭanāśanagaṇapatistotra": ['mw'],
    "saṃkaṣṭanāśanastotra": ['mw'],
    "saṃkaṣṭanāśanavrata": ['mw'],
    "saṃkaṣṭavrata": ['mw'],
    "saṃkaṭa": ['ap90', 'cae', 'mw'],
    "saṃkaṭacaturthī": ['mw'],
    "saṃkaṭaharacaturthīvrata": ['mw'],
    "saṃkaṭamuha": ['mw'],
    "saṃkaṭamukha": ['mw'],
    "saṃkaṭanāśana": ['mw'],
    "saṃkaṭastha": ['mw'],
    "saṃkaṭastotra": ['mw'],
    "saṃkaṭika": ['mw'],
    "saṃkaṭin": ['mw'],
    "saṃkaṭottīrṇa": ['mw'],
    "saṃkaṭā": ['mw'],
    "saṃkaṭākṣa": ['mw'],
    "saṃkaṭānāmāṣṭaka": ['mw'],
    "saṃkaṭāpanna": ['mw'],
    "saṃkaṭāya": ['mw'],
    "saṃkaṭīkṛta": ['bhs'],
    "saṃkaṭṭati": ['bhs'],
    "saṃketa": ['bhs', 'cae', 'mw'],
    "saṃketabhūmi": ['mw'],
    "saṃketacandrodaya": ['mw'],
    "saṃketagraha": ['mw'],
    "saṃketagrahaṇa": ['mw'],
    "saṃketagṛhaka": ['mw'],
    "saṃketahetu": ['mw'],
    "saṃketaka": ['cae', 'mw'],
    "saṃketakagṛhaka": ['cae'],
    "saṃketakaumudī": ['mw'],
    "saṃketakaḥ": ['ap90'],
    "saṃketaketana": ['cae', 'mw'],
    "saṃketamañjarī": ['mw'],
    "saṃketamilita": ['mw'],
    "saṃketana": ['mw'],
    "saṃketanaṃ": ['ap90'],
    "saṃketaniketa": ['mw'],
    "saṃketaniketana": ['mw'],
    "saṃketapaddhati": ['mw'],
    "saṃketapūrvakam": ['mw'],
    "saṃketarutapraveśa": ['bhs', 'mw'],
    "saṃketastava": ['mw'],
    "saṃketastha": ['cae', 'mw'],
    "saṃketasthāna": ['cae', 'mw'],
    "saṃketatraya": ['mw'],
    "saṃketavākya": ['mw'],
    "saṃketaya": ['mw'],
    "saṃketayati": ['ap90'],
    "saṃketayāmala": ['mw'],
    "saṃketaśikṣā": ['mw'],
    "saṃketaḥ": ['ap90'],
    "saṃketika": ['bhs'],
    "saṃketita": ['ap90', 'mw'],
    "saṃketodyāna": ['cae', 'mw'],
    "saṃketīkṛ": ['mw'],
    "saṃketīkṛta": ['mw'],
    "saṃkha": ['bhs'],
    "saṃkhid": ['mw'],
    "saṃkhya": ['bhs', 'cae', 'mw'],
    "saṃkhyaka": ['ap90', 'mw'],
    "saṃkhyatva": ['mw'],
    "saṃkhyatā": ['mw'],
    "saṃkhyaṃ": ['ap90'],
    "saṃkhyeya": ['cae', 'mw'],
    "saṃkhyā": ['ap90', 'cae', 'mw'],
    "saṃkhyāka": ['mw'],
    "saṃkhyākaumudī": ['mw'],
    "saṃkhyālipi": ['bhs', 'mw'],
    "saṃkhyāmaṅgalagranthi": ['mw'],
    "saṃkhyāmuṣṭyadhikaraṇakṣepa": ['mw'],
    "saṃkhyāmātra": ['mw'],
    "saṃkhyāna": ['cae', 'mw'],
    "saṃkhyānaṃ": ['ap90'],
    "saṃkhyānidānaṭīkā": ['mw'],
    "saṃkhyānāman": ['cae', 'mw'],
    "saṃkhyāpada": ['cae', 'mw'],
    "saṃkhyāparimāṇanibandha": ['mw'],
    "saṃkhyāparityakta": ['mw'],
    "saṃkhyāratna": ['mw'],
    "saṃkhyāratnakośa": ['mw'],
    "saṃkhyāsamāpana": ['mw'],
    "saṃkhyāta": ['ap90', 'bhs', 'mw'],
    "saṃkhyātas": ['mw'],
    "saṃkhyātasaṃkhyeya": ['mw'],
    "saṃkhyātiga": ['cae', 'mw'],
    "saṃkhyātā": ['cae', 'mw'],
    "saṃkhyātānudeśa": ['mw'],
    "saṃkhyāvat": ['ap90', 'mw'],
    "saṃkhyāvidhāna": ['mw'],
    "saṃkhyāvācaka": ['mw'],
    "saṃkhyāvṛttikara": ['mw'],
    "saṃkhyāyoga": ['mw'],
    "saṃkhyāśabda": ['mw'],
    "saṃkhyāśas": ['mw'],
    "saṃkhyāṅkabindu": ['mw'],
    "saṃkhād": ['mw'],
    "saṃkhādaka": ['mw'],
    "saṃkhādakin": ['mw'],
    "saṃkila": ['mw'],
    "saṃkilaḥ": ['ap90'],
    "saṃkilikilāyate": ['bhs'],
    "saṃkiliṣṭa": ['bhs'],
    "saṃkirati": ['bhs'],
    "saṃkleda": ['cae', 'mw'],
    "saṃkledaḥ": ['ap90'],
    "saṃkleśa": ['bhs', 'cae', 'mw'],
    "saṃkleśana": ['mw'],
    "saṃkleśanirvāṇa": ['mw'],
    "saṃklinna": ['mw'],
    "saṃkliś": ['mw'],
    "saṃkliśyati": ['bhs'],
    "saṃkliṣṭa": ['mw'],
    "saṃkliṣṭakarman": ['mw'],
    "saṃkoca": ['cae', 'mw'],
    "saṃkocaka": ['mw'],
    "saṃkocakārin": ['mw'],
    "saṃkocana": ['cae', 'mw'],
    "saṃkocanaṃ": ['ap90'],
    "saṃkocanī": ['mw'],
    "saṃkocanīya": ['mw'],
    "saṃkocanīyatva": ['mw'],
    "saṃkocapattraka": ['mw'],
    "saṃkocapiśuna": ['mw'],
    "saṃkocarekhā": ['mw'],
    "saṃkocaḥ": ['ap90'],
    "saṃkocin": ['mw'],
    "saṃkocita": ['mw'],
    "saṃkram": ['ap90', 'mw'],
    "saṃkrama": ['bhs', 'cae', 'mw'],
    "saṃkramadvādaśāha": ['mw'],
    "saṃkramaka": ['bhs'],
    "saṃkramayajña": ['mw'],
    "saṃkramaḥ": ['ap90'],
    "saṃkramaṇa": ['bhs', 'cae', 'mw'],
    "saṃkramaṇaka": ['bhs'],
    "saṃkramaṇakā": ['mw'],
    "saṃkramaṇaṃ": ['ap90'],
    "saṃkramita": ['mw'],
    "saṃkramitṛ": ['mw'],
    "saṃkramīkṛ": ['mw'],
    "saṃkrand": ['mw'],
    "saṃkranda": ['cae', 'mw'],
    "saṃkrandana": ['cae', 'gra', 'mw'],
    "saṃkrandananandana": ['mw'],
    "saṃkraṃdanaḥ": ['ap90'],
    "saṃkrośa": ['cae', 'mw'],
    "saṃkruddha": ['mw'],
    "saṃkrudh": ['mw'],
    "saṃkruś": ['mw'],
    "saṃkrāma": ['cae', 'mw'],
    "saṃkrāmayitavya": ['mw'],
    "saṃkrāmaḥ": ['ap90'],
    "saṃkrāmaṇa": ['cae', 'mw'],
    "saṃkrāmaṇaviropaṇa": ['mw'],
    "saṃkrāmaṇī": ['bhs', 'mw'],
    "saṃkrāmin": ['mw'],
    "saṃkrāmita": ['mw'],
    "saṃkrānta": ['cae', 'mw'],
    "saṃkrānti": ['cae', 'mw'],
    "saṃkrānticakra": ['mw'],
    "saṃkrāntidṛṣṭi": ['bhs'],
    "saṃkrāntikaumudī": ['mw'],
    "saṃkrāntilakṣaṇa": ['mw'],
    "saṃkrāntinirṇaya": ['mw'],
    "saṃkrāntipaṭala": ['mw'],
    "saṃkrāntiphala": ['mw'],
    "saṃkrāntiprakaraṇa": ['mw'],
    "saṃkrāntiviveka": ['mw'],
    "saṃkrāntivyavasthānirṇaya": ['mw'],
    "saṃkrāntivādin": ['mw'],
    "saṃkrāntiśānti": ['mw'],
    "saṃkrāntyudyāpana": ['mw'],
    "saṃkrāntā": ['mw'],
    "saṃkrāṃta": ['ap90'],
    "saṃkrāṃtiḥ": ['ap90'],
    "saṃkrī": ['mw'],
    "saṃkrīḍ": ['ap90', 'mw'],
    "saṃkrīḍa": ['cae', 'mw'],
    "saṃkrīḍana": ['mw'],
    "saṃkrīḍanaṃ": ['ap90'],
    "saṃkrīḍita": ['mw'],
    "saṃkrīḍitaṃ": ['ap90'],
    "saṃkuc": ['ap90', 'mw'],
    "saṃkucana": ['mw'],
    "saṃkucita": ['ap90', 'cae', 'mw'],
    "saṃkula": ['ap90', 'cae', 'mw'],
    "saṃkulakaluṣa": ['mw'],
    "saṃkulita": ['cae', 'mw'],
    "saṃkulīkṛ": ['cae'],
    "saṃkulīkṛta": ['mw'],
    "saṃkup": ['mw'],
    "saṃkupita": ['mw'],
    "saṃkusuka": ['mw'],
    "saṃkusuma": ['bhs'],
    "saṃkusumita": ['bhs', 'mw'],
    "saṃkusumitagandhottamarāja": ['bhs'],
    "saṃkusumitarāja": ['bhs'],
    "saṃkuñc": ['mw'],
    "saṃkuñcana": ['bhs'],
    "saṃkuñcayati": ['bhs'],
    "saṃkuñcita": ['mw'],
    "saṃkuṭṭakā": ['bhs'],
    "saṃkā": ['mw'],
    "saṃkālana": ['cae', 'mw'],
    "saṃkāra": ['bhs', 'cae', 'mw'],
    "saṃkārakūṭa": ['mw'],
    "saṃkāraḥ": ['ap90'],
    "saṃkārin": ['ap90', 'bhs'],
    "saṃkārya": ['bhs'],
    "saṃkārī": ['ap90', 'mw'],
    "saṃkāyikā": ['bhs', 'mw'],
    "saṃkāś": ['mw'],
    "saṃkāśa": ['ap90', 'cae', 'gra', 'mw'],
    "saṃkāśya": ['bhs', 'mw'],
    "saṃkīla": ['mw'],
    "saṃkīrt": ['mw'],
    "saṃkīrtana": ['cae', 'mw'],
    "saṃkīrtanaṃ": ['ap90'],
    "saṃkīrti": ['mw'],
    "saṃkīrtita": ['mw'],
    "saṃkīrṇa": ['ap90', 'cae', 'mw'],
    "saṃkīrṇacārin": ['cae', 'mw'],
    "saṃkīrṇajāti": ['mw'],
    "saṃkīrṇaneri": ['mw'],
    "saṃkīrṇanāga": ['mw'],
    "saṃkīrṇarāgādhyāya": ['mw'],
    "saṃkīrṇatā": ['mw'],
    "saṃkīrṇaviṣkambhaka": ['mw'],
    "saṃkīrṇayoni": ['cae', 'mw'],
    "saṃkīrṇayuddha": ['mw'],
    "saṃkīrṇā": ['mw'],
    "saṃkīrṇāra": ['mw'],
    "saṃkīrṇīkaraṇa": ['mw'],
    "saṃkīyati": ['bhs'],
    "saṃkūjita": ['mw'],
    "saṃkūjitaṃ": ['ap90'],
    "saṃkūṭana": ['mw'],
    "saṃkḷp": ['ap90', 'mw'],
    "saṃkḷpta": ['cae', 'mw'],
    "saṃkḷpti": ['cae', 'mw'],
    "saṃkṛ": ['ap90', 'mw'],
    "saṃkṛt": ['mw'],
    "saṃkṛti": ['cae', 'mw'],
    "saṃkṛtta": ['mw'],
    "saṃkṛṣ": ['ap90', 'mw'],
    "saṃkṛṣṭa": ['mw'],
    "saṃkṝ": ['ap90', 'mw'],
    "saṃkṝt": ['ap90', 'mw'],
    "saṃkṣam": ['mw'],
    "saṃkṣap": ['mw'],
    "saṃkṣar": ['mw'],
    "saṃkṣara": ['cae', 'mw'],
    "saṃkṣarita": ['mw'],
    "saṃkṣaya": ['cae', 'mw'],
    "saṃkṣayati": ['bhs'],
    "saṃkṣayaḥ": ['ap90'],
    "saṃkṣayita": ['mw'],
    "saṃkṣepa": ['cae', 'mw'],
    "saṃkṣepabhāgavatāmṛta": ['mw'],
    "saṃkṣepabhārata": ['mw'],
    "saṃkṣepagāyatrīnyāsa": ['mw'],
    "saṃkṣepaka": ['cae', 'mw'],
    "saṃkṣepalakṣaṇa": ['mw'],
    "saṃkṣepam": ['mw'],
    "saṃkṣepamātra": ['mw'],
    "saṃkṣepapuraścaraṇavidhi": ['mw'],
    "saṃkṣepapūjāvidhi": ['mw'],
    "saṃkṣeparāmāyaṇa": ['mw'],
    "saṃkṣepasiddhivyavasthā": ['mw'],
    "saṃkṣepatas": ['cae', 'mw'],
    "saṃkṣepatithinirṇayasāra": ['mw'],
    "saṃkṣepavimarśādhiroha": ['mw'],
    "saṃkṣepaya": ['bhs'],
    "saṃkṣepayogavāsiṣṭha": ['mw'],
    "saṃkṣepaśaṃkarajaya": ['mw'],
    "saṃkṣepaśārīraka": ['mw'],
    "saṃkṣepaśārīrakabhāṣya": ['mw'],
    "saṃkṣepaśārīrakaphalalakṣaṇa": ['mw'],
    "saṃkṣepaśārīrakasambandhokti": ['mw'],
    "saṃkṣepaśārīrakavyākhyāna": ['mw'],
    "saṃkṣepaśārīrakaṭīkā": ['mw'],
    "saṃkṣepaḥ": ['ap90'],
    "saṃkṣepaṇa": ['mw'],
    "saṃkṣepaṇaṃ": ['ap90'],
    "saṃkṣepaṇīya": ['mw'],
    "saṃkṣeptṛ": ['cae', 'mw'],
    "saṃkṣepādhyātmasāra": ['mw'],
    "saṃkṣepāhnikacandrikā": ['mw'],
    "saṃkṣepāmṛta": ['mw'],
    "saṃkṣepārcanavidhi": ['mw'],
    "saṃkṣi": ['ap90', 'mw'],
    "saṃkṣip": ['ap90', 'mw'],
    "saṃkṣipavikṣipa": ['bhs'],
    "saṃkṣipta": ['ap90', 'cae', 'mw'],
    "saṃkṣiptabhārata": ['mw'],
    "saṃkṣiptabhāṣya": ['mw'],
    "saṃkṣiptabuddhi": ['bhs'],
    "saṃkṣiptacalārcāvidhi": ['mw'],
    "saṃkṣiptadairghya": ['mw'],
    "saṃkṣiptagati": ['mw'],
    "saṃkṣiptahomaprakāra": ['mw'],
    "saṃkṣiptaka": ['mw'],
    "saṃkṣiptakādambarī": ['mw'],
    "saṃkṣiptanirṇayasindhu": ['mw'],
    "saṃkṣiptarāgānugāpūjāpaddhati": ['mw'],
    "saṃkṣiptarāmāyaṇapāṭhaprayoga": ['mw'],
    "saṃkṣiptasāra": ['mw'],
    "saṃkṣiptasārasaṃgraha": ['mw'],
    "saṃkṣiptatva": ['mw'],
    "saṃkṣiptavedānta": ['mw'],
    "saṃkṣiptavedāntaśāstraprakriyā": ['mw'],
    "saṃkṣiptaśyāmāpūjāpaddhati": ['mw'],
    "saṃkṣiptaśāstrārthapaddhati": ['mw'],
    "saṃkṣiptena": ['bhs', 'mw'],
    "saṃkṣipti": ['mw'],
    "saṃkṣiptikā": ['mw'],
    "saṃkṣiptiḥ": ['ap90'],
    "saṃkṣiptā": ['mw'],
    "saṃkṣobha": ['cae', 'mw'],
    "saṃkṣobhaḥ": ['ap90'],
    "saṃkṣobhaṇa": ['mw'],
    "saṃkṣobhin": ['mw'],
    "saṃkṣobhita": ['mw'],
    "saṃkṣubdha": ['mw'],
    "saṃkṣubh": ['ap90', 'mw'],
    "saṃkṣubhita": ['mw'],
    "saṃkṣud": ['mw'],
    "saṃkṣālana": ['cae', 'mw'],
    "saṃkṣālanā": ['mw'],
    "saṃkṣāra": ['cae', 'mw'],
    "saṃkṣūyate": ['bhs'],
    "saṃkṣṇu": ['mw'],
    "saṃlabdha": ['mw'],
    "saṃlabh": ['mw'],
    "saṃlag": ['mw'],
    "saṃlagna": ['ap90', 'cae', 'mw'],
    "saṃlagnikā": ['bhs'],
    "saṃlajj": ['mw'],
    "saṃlakṣ": ['ap90', 'mw'],
    "saṃlakṣaṇa": ['mw'],
    "saṃlakṣaṇaṃ": ['ap90'],
    "saṃlakṣaṇā": ['bhs'],
    "saṃlakṣita": ['mw'],
    "saṃlakṣya": ['cae', 'ddsa', 'mw'],
    "saṃlal": ['mw'],
    "saṃlalita": ['ap90'],
    "saṃlambha": ['bhs'],
    "saṃlap": ['ap90', 'mw'],
    "saṃlapana": ['cae', 'mw'],
    "saṃlapanoṣṇatā": ['mw'],
    "saṃlaptaka": ['bhs', 'mw'],
    "saṃlaya": ['cae', 'mw'],
    "saṃlayana": ['mw'],
    "saṃlayanaṃ": ['ap90'],
    "saṃlayaḥ": ['ap90'],
    "saṃlaṅgh": ['mw'],
    "saṃlaṅghana": ['mw'],
    "saṃlaṅghita": ['mw'],
    "saṃlekha": ['bhs', 'mw'],
    "saṃlepa": ['mw'],
    "saṃlih": ['mw'],
    "saṃlikh": ['ap90', 'mw'],
    "saṃlikhi": ['bhs'],
    "saṃlikhita": ['bhs', 'mw'],
    "saṃlipsu": ['mw'],
    "saṃlobhana": ['bhs'],
    "saṃlok": ['mw'],
    "saṃlokin": ['mw'],
    "saṃloḍana": ['mw'],
    "saṃloḍanaṃ": ['ap90'],
    "saṃlubh": ['mw'],
    "saṃlulita": ['cae', 'mw'],
    "saṃlup": ['mw'],
    "saṃluḍ": ['ap90', 'mw'],
    "saṃluḍita": ['bhs'],
    "saṃlālita": ['mw'],
    "saṃlāpa": ['cae', 'mw'],
    "saṃlāpaka": ['mw'],
    "saṃlāpakaḥ": ['ap90'],
    "saṃlāpayati": ['bhs'],
    "saṃlāpaḥ": ['ap90'],
    "saṃlāpin": ['mw'],
    "saṃlāpita": ['mw'],
    "saṃlī": ['ap90', 'mw'],
    "saṃlīna": ['ap90', 'cae', 'mw'],
    "saṃlīnakarṇa": ['mw'],
    "saṃlīnamānasa": ['mw'],
    "saṃlīyanā": ['bhs'],
    "saṃlīḍha": ['ap90', 'mw'],
    "saṃlūṣitā": ['bhs'],
    "saṃmad": ['ap90'],
    "saṃmada": ['ap90', 'cae'],
    "saṃmadin": ['cae'],
    "saṃmagna": ['cae'],
    "saṃman": ['ap90'],
    "saṃmanas": ['cae'],
    "saṃmantrita": ['bhs'],
    "saṃmarda": ['cae'],
    "saṃmardaḥ": ['ap90'],
    "saṃmarjitaka": ['bhs'],
    "saṃmarśana": ['cae'],
    "saṃmata": ['ap90', 'bhs', 'cae'],
    "saṃmataka": ['bhs'],
    "saṃmataraśmi": ['bhs'],
    "saṃmati": ['cae'],
    "saṃmatiḥ": ['ap90'],
    "saṃmatta": ['ap90', 'cae'],
    "saṃmayana": ['cae'],
    "saṃmaṃtr": ['ap90'],
    "saṃmaṃtraṇaṃ": ['ap90'],
    "saṃmegha": ['cae'],
    "saṃmelana": ['cae'],
    "saṃmelanaṃ": ['ap90'],
    "saṃmil": ['ap90'],
    "saṃmilāyati": ['bhs'],
    "saṃmita": ['ap90', 'cae'],
    "saṃmitaṃ": ['bhs'],
    "saṃmiti": ['bhs'],
    "saṃmiñjana": ['bhs'],
    "saṃmiñjayati": ['bhs'],
    "saṃmiñjita": ['bhs'],
    "saṃmiśla": ['cae'],
    "saṃmiślaḥ": ['ap90'],
    "saṃmiśr": ['ap90'],
    "saṃmiśra": ['ap90', 'cae'],
    "saṃmlāna": ['bhs'],
    "saṃmodana": ['bhs'],
    "saṃmodanīya": ['bhs'],
    "saṃmodate": ['bhs'],
    "saṃmodaḥ": ['ap90'],
    "saṃmodika": ['bhs'],
    "saṃmoha": ['cae'],
    "saṃmohaka": ['cae'],
    "saṃmohana": ['cae'],
    "saṃmohanaṃ": ['ap90'],
    "saṃmohaḥ": ['ap90'],
    "saṃmoṣa": ['bhs'],
    "saṃmudita": ['bhs'],
    "saṃmugdha": ['ap90', 'cae'],
    "saṃmuh": ['ap90'],
    "saṃmukha": ['ap90', 'bhs', 'cae'],
    "saṃmukham": ['bhs'],
    "saṃmukhavinaya": ['bhs'],
    "saṃmukhin": ['ap90'],
    "saṃmukhā": ['bhs'],
    "saṃmukhīkṛ": ['cae'],
    "saṃmukhīna": ['cae'],
    "saṃmula": ['bhs'],
    "saṃmurcch": ['ap90'],
    "saṃmā": ['ap90', 'cae'],
    "saṃmādaḥ": ['ap90'],
    "saṃmāna": ['cae'],
    "saṃmānana": ['cae'],
    "saṃmānanaṃ": ['ap90'],
    "saṃmānanīya": ['cae'],
    "saṃmānaḥ": ['ap90'],
    "saṃmānya": ['cae'],
    "saṃmārga": ['cae'],
    "saṃmārjaka": ['cae'],
    "saṃmārjakaḥ": ['ap90'],
    "saṃmārjana": ['cae'],
    "saṃmārjanaṃ": ['ap90'],
    "saṃmārjanī": ['ap90'],
    "saṃmātura": ['ap90'],
    "saṃmātṛ": ['cae'],
    "saṃmāyati": ['bhs'],
    "saṃmīl": ['ap90'],
    "saṃmīlana": ['cae'],
    "saṃmīlanaṃ": ['ap90'],
    "saṃmīlita": ['cae'],
    "saṃmūrchanaṃ": ['ap90'],
    "saṃmūrchita": ['cae'],
    "saṃmūḍha": ['ap90', 'cae'],
    "saṃmūḍhaka": ['bhs'],
    "saṃmṛd": ['ap90'],
    "saṃmṛj": ['ap90'],
    "saṃmṛta": ['ap90'],
    "saṃmṛśati": ['bhs'],
    "saṃmṛṣṭa": ['ap90', 'cae'],
    "saṃnad": ['mw'],
    "saṃnaddha": ['ap90', 'cae', 'mw'],
    "saṃnaddhakavaca": ['mw'],
    "saṃnaddhavya": ['mw'],
    "saṃnah": ['ap90', 'mw'],
    "saṃnahana": ['cae', 'mw'],
    "saṃnahanaṃ": ['ap90'],
    "saṃnahanīya": ['mw'],
    "saṃnahya": ['bhs'],
    "saṃnakha": ['cae', 'mw'],
    "saṃnam": ['ap90', 'mw'],
    "saṃnamana": ['mw'],
    "saṃnamasya": ['mw'],
    "saṃnard": ['mw'],
    "saṃnas": ['mw'],
    "saṃnata": ['ap90', 'cae', 'mw'],
    "saṃnatabhrū": ['mw'],
    "saṃnatatara": ['mw'],
    "saṃnateyu": ['mw'],
    "saṃnati": ['cae', 'mw'],
    "saṃnatihoma": ['mw'],
    "saṃnatimant": ['cae'],
    "saṃnatimat": ['mw'],
    "saṃnatiḥ": ['ap90'],
    "saṃnatāṅga": ['mw'],
    "saṃnaya": ['cae', 'gra', 'mw'],
    "saṃnayana": ['mw'],
    "saṃnayanaṃ": ['ap90'],
    "saṃnayaḥ": ['ap90'],
    "saṃnaś": ['mw'],
    "saṃnaṣṭa": ['mw'],
    "saṃneya": ['mw'],
    "saṃnibaddha": ['mw'],
    "saṃnibandha": ['mw'],
    "saṃnibandhana": ['mw'],
    "saṃnibarhaṇa": ['mw'],
    "saṃnibaṃdhaḥ": ['ap90'],
    "saṃnibha": ['ap90', 'cae', 'mw'],
    "saṃnibhṛta": ['mw'],
    "saṃniboddhavya": ['mw'],
    "saṃnibudh": ['mw'],
    "saṃnicaya": ['cae', 'mw'],
    "saṃnicayaḥ": ['ap90'],
    "saṃnicita": ['mw'],
    "saṃnidarśita": ['mw'],
    "saṃnidha": ['mw'],
    "saṃnidhi": ['bhs', 'cae', 'mw'],
    "saṃnidhikāra": ['mw'],
    "saṃnidhivartin": ['mw'],
    "saṃnidhiviyoga": ['mw'],
    "saṃnidhā": ['ap90', 'mw'],
    "saṃnidhāna": ['cae', 'mw'],
    "saṃnidhānaṃ": ['ap90'],
    "saṃnidhānin": ['bhs', 'mw'],
    "saṃnidhātṛ": ['ap90', 'cae', 'mw'],
    "saṃnidhāyin": ['cae', 'mw'],
    "saṃnidāgha": ['mw'],
    "saṃnidāhayati": ['bhs'],
    "saṃnigam": ['mw'],
    "saṃnighṛṣ": ['mw'],
    "saṃnigrah": ['mw'],
    "saṃnigraha": ['cae', 'mw'],
    "saṃnihan": ['mw'],
    "saṃnihana": ['mw'],
    "saṃnihatī": ['mw'],
    "saṃnihita": ['ap90', 'cae', 'mw'],
    "saṃnihitataratva": ['mw'],
    "saṃnihitāpāya": ['mw'],
    "saṃnikarṣa": ['cae', 'mw'],
    "saṃnikarṣatattvaviveka": ['mw'],
    "saṃnikarṣatā": ['mw'],
    "saṃnikarṣatāvāda": ['mw'],
    "saṃnikarṣavicāra": ['mw'],
    "saṃnikarṣavāda": ['mw'],
    "saṃnikarṣavādārtha": ['mw'],
    "saṃnikarṣaḥ": ['ap90'],
    "saṃnikarṣaṇa": ['mw'],
    "saṃnikarṣaṇaṃ": ['ap90'],
    "saṃnikuñc": ['mw'],
    "saṃnikāś": ['mw'],
    "saṃnikāśa": ['cae', 'mw'],
    "saṃnikīrṇa": ['mw'],
    "saṃnikṛṣ": ['mw'],
    "saṃnikṛṣya": ['mw'],
    "saṃnikṛṣṭa": ['ap90', 'cae', 'mw'],
    "saṃnikṛṣṭe": ['mw'],
    "saṃnikṣip": ['mw'],
    "saṃnikṣāra": ['mw'],
    "saṃnilī": ['mw'],
    "saṃnimagna": ['mw'],
    "saṃnimajj": ['mw'],
    "saṃnimantr": ['mw'],
    "saṃnimitta": ['cae'],
    "saṃnimīl": ['mw'],
    "saṃninī": ['mw'],
    "saṃnipat": ['ap90', 'mw'],
    "saṃnipatita": ['mw'],
    "saṃnipatya": ['mw'],
    "saṃnipatyakārin": ['mw'],
    "saṃnipatyopakāraka": ['mw'],
    "saṃnipāta": ['bhs', 'cae', 'mw'],
    "saṃnipātacandrikā": ['mw'],
    "saṃnipātacikitsā": ['mw'],
    "saṃnipātajvara": ['mw'],
    "saṃnipātaka": ['mw'],
    "saṃnipātakalikā": ['mw'],
    "saṃnipātakalikāṭīkā": ['mw'],
    "saṃnipātakaḥ": ['ap90'],
    "saṃnipātamañjarī": ['mw'],
    "saṃnipātana": ['cae', 'mw'],
    "saṃnipātanidrā": ['mw'],
    "saṃnipātanud": ['mw'],
    "saṃnipātanāḍīlakṣaṇa": ['mw'],
    "saṃnipātapaṭa": ['mw'],
    "saṃnipātaḥ": ['ap90'],
    "saṃnipātika": ['mw'],
    "saṃnipātin": ['mw'],
    "saṃnipātita": ['mw'],
    "saṃnipātitva": ['mw'],
    "saṃnipātya": ['cae', 'mw'],
    "saṃnirgam": ['mw'],
    "saṃnirjinati": ['bhs'],
    "saṃnirmath": ['mw'],
    "saṃnirmita": ['mw'],
    "saṃnirnāda": ['bhs'],
    "saṃniroddhavya": ['cae', 'mw'],
    "saṃnirodha": ['mw'],
    "saṃnirodhaḥ": ['ap90'],
    "saṃniruddha": ['mw'],
    "saṃniruddhaguda": ['mw'],
    "saṃnirudh": ['ap90', 'mw'],
    "saṃnirvap": ['mw'],
    "saṃnisarga": ['mw'],
    "saṃnisūdita": ['mw'],
    "saṃnisṛṣṭa": ['mw'],
    "saṃnitāla": ['mw'],
    "saṃnivap": ['mw'],
    "saṃnivapana": ['mw'],
    "saṃnivapanīya": ['mw'],
    "saṃnivartana": ['cae', 'mw'],
    "saṃnivartita": ['mw'],
    "saṃnivas": ['mw'],
    "saṃniveśa": ['cae', 'mw'],
    "saṃniveśana": ['cae', 'mw'],
    "saṃniveśanā": ['bhs'],
    "saṃniveśayitavya": ['mw'],
    "saṃniveśaḥ": ['ap90'],
    "saṃniveśin": ['mw'],
    "saṃniveśita": ['mw'],
    "saṃniveśya": ['cae', 'mw'],
    "saṃnivid": ['mw'],
    "saṃniviś": ['ap90', 'mw'],
    "saṃniviṣṭa": ['ap90', 'cae', 'mw'],
    "saṃnivāpa": ['cae', 'mw'],
    "saṃnivāraka": ['bhs'],
    "saṃnivāraṇa": ['cae', 'mw'],
    "saṃnivārya": ['cae', 'mw'],
    "saṃnivāsa": ['cae', 'mw'],
    "saṃnivāsayati": ['bhs'],
    "saṃnivāsin": ['mw'],
    "saṃnivāya": ['mw'],
    "saṃnivṛ": ['mw'],
    "saṃnivṛt": ['ap90', 'mw'],
    "saṃnivṛtta": ['ap90', 'cae', 'mw'],
    "saṃnivṛtti": ['mw'],
    "saṃnivṛttiḥ": ['ap90'],
    "saṃniyacchana": ['cae', 'mw'],
    "saṃniyam": ['mw'],
    "saṃniyama": ['mw'],
    "saṃniyantṛ": ['cae', 'mw'],
    "saṃniyata": ['mw'],
    "saṃniyoga": ['cae', 'mw'],
    "saṃniyogaḥ": ['ap90'],
    "saṃniyojana": ['bhs'],
    "saṃniyojita": ['mw'],
    "saṃniyojya": ['mw'],
    "saṃniyuj": ['ap90', 'mw'],
    "saṃniyukta": ['mw'],
    "saṃniśam": ['mw'],
    "saṃniścaya": ['cae', 'mw'],
    "saṃniśraya": ['bhs', 'mw'],
    "saṃniśrita": ['bhs', 'mw'],
    "saṃniṣad": ['mw'],
    "saṃniṣaṇṇa": ['mw'],
    "saṃniṣaṇṇaka": ['bhs'],
    "saṃniṣedhati": ['bhs'],
    "saṃniṣevita": ['mw'],
    "saṃniṣevya": ['mw'],
    "saṃniṣic": ['mw'],
    "saṃniṣṭhāpana": ['bhs'],
    "saṃnodana": ['mw'],
    "saṃnodayitavya": ['mw'],
    "saṃnu": ['mw'],
    "saṃnud": ['mw'],
    "saṃnyas": ['ap90', 'mw'],
    "saṃnyasa": ['bhs'],
    "saṃnyasana": ['cae', 'mw'],
    "saṃnyasanaṃ": ['ap90'],
    "saṃnyasta": ['ap90', 'mw'],
    "saṃnyastadeha": ['mw'],
    "saṃnyastaśastra": ['mw'],
    "saṃnyupta": ['mw'],
    "saṃnyāsa": ['cae', 'mw'],
    "saṃnyāsabhedanirṇaya": ['mw'],
    "saṃnyāsadharmasaṃgraha": ['mw'],
    "saṃnyāsadīpikā": ['mw'],
    "saṃnyāsagrahaṇa": ['mw'],
    "saṃnyāsagrahaṇapaddhati": ['mw'],
    "saṃnyāsagrahaṇaratnamālā": ['mw'],
    "saṃnyāsagrāhyapaddhati": ['mw'],
    "saṃnyāsakarmakārikā": ['mw'],
    "saṃnyāsanirṇaya": ['mw'],
    "saṃnyāsapadamañjarī": ['mw'],
    "saṃnyāsapaddhati": ['mw'],
    "saṃnyāsapallī": ['mw'],
    "saṃnyāsarīti": ['mw'],
    "saṃnyāsavat": ['mw'],
    "saṃnyāsavidhi": ['mw'],
    "saṃnyāsaḥ": ['ap90'],
    "saṃnyāsidarśana": ['mw'],
    "saṃnyāsika": ['mw'],
    "saṃnyāsin": ['ap90', 'cae', 'mw'],
    "saṃnyāsisamārādhana": ['mw'],
    "saṃnyāsisaṃdhyā": ['mw'],
    "saṃnyāsitva": ['mw'],
    "saṃnyāsitā": ['mw'],
    "saṃnyāsopaniṣad": ['mw'],
    "saṃnyāsāhnika": ['mw'],
    "saṃnyāsāśramavicāra": ['mw'],
    "saṃnāda": ['cae', 'mw'],
    "saṃnādana": ['cae', 'mw'],
    "saṃnādita": ['mw'],
    "saṃnāha": ['cae', 'mw'],
    "saṃnāhaḥ": ['ap90'],
    "saṃnāhya": ['mw'],
    "saṃnāhyaḥ": ['ap90'],
    "saṃnāma": ['mw'],
    "saṃnāmana": ['bhs'],
    "saṃnāmayati": ['bhs'],
    "saṃnāmayitavya": ['mw'],
    "saṃnāyya": ['mw'],
    "saṃnī": ['ap90', 'mw'],
    "saṃnṛt": ['mw'],
    "saṃpaccate": ['bhs'],
    "saṃpad": ['ap90', 'cae'],
    "saṃpadin": ['bhs'],
    "saṃpadā": ['bhs'],
    "saṃpanna": ['ap90', 'cae'],
    "saṃpannadanta": ['cae'],
    "saṃpannaka": ['bhs'],
    "saṃpannakṣīrā": ['cae'],
    "saṃpare": ['ap90'],
    "saṃparidīpayate": ['bhs'],
    "saṃparigraha": ['cae'],
    "saṃparikartayati": ['bhs'],
    "saṃparikālayati": ['bhs'],
    "saṃparimārjati": ['bhs'],
    "saṃparipaśyati": ['bhs'],
    "saṃparipraśnīkṛta": ['bhs'],
    "saṃparipṛcchita": ['bhs'],
    "saṃparitakṣṇoti": ['bhs'],
    "saṃparivarta": ['bhs'],
    "saṃparivartana": ['bhs'],
    "saṃparivartayati": ['bhs'],
    "saṃpariveṭhita": ['bhs'],
    "saṃparka": ['cae'],
    "saṃparkaḥ": ['ap90'],
    "saṃparāhata": ['bhs'],
    "saṃparāmārj": ['bhs'],
    "saṃparāya": ['bhs', 'cae'],
    "saṃparāyakaṃ": ['ap90'],
    "saṃparāyaḥ": ['ap90'],
    "saṃparāyika": ['bhs'],
    "saṃparāyikaṃ": ['ap90'],
    "saṃpat": ['ap90'],
    "saṃpatti": ['cae'],
    "saṃpattiḥ": ['ap90'],
    "saṃpavana": ['cae'],
    "saṃpaśyana": ['bhs'],
    "saṃpeṣaṇaṃ": ['ap90'],
    "saṃpheṭa": ['cae'],
    "saṃpheṭaḥ": ['ap90'],
    "saṃphulla": ['ap90', 'cae'],
    "saṃphālaḥ": ['ap90'],
    "saṃpiba": ['cae'],
    "saṃpidadhāti": ['bhs'],
    "saṃpipāsati": ['bhs'],
    "saṃpiṃḍita": ['ap90'],
    "saṃpiṇḍā": ['bhs'],
    "saṃpiṣ": ['ap90'],
    "saṃplava": ['cae'],
    "saṃplavaḥ": ['ap90'],
    "saṃplu": ['ap90'],
    "saṃpluta": ['cae'],
    "saṃprabha": ['bhs'],
    "saṃprabhaṇati": ['bhs'],
    "saṃprabhaṇita": ['bhs'],
    "saṃprabhinna": ['ap90'],
    "saṃprabhāsati": ['bhs'],
    "saṃprabhāṣaṇa": ['bhs'],
    "saṃprabhīta": ['bhs'],
    "saṃpracalati": ['bhs'],
    "saṃpracchanna": ['bhs'],
    "saṃpracchedana": ['bhs'],
    "saṃpracitrayati": ['bhs'],
    "saṃpradarśana": ['bhs'],
    "saṃpradhānaṃ": ['ap90'],
    "saṃpradhāraṇa": ['cae'],
    "saṃpradhāraṇaṃ": ['ap90'],
    "saṃpradhṛ": ['ap90'],
    "saṃpradā": ['ap90'],
    "saṃpradālayati": ['bhs'],
    "saṃpradāna": ['cae'],
    "saṃpradānaṃ": ['ap90'],
    "saṃpradānīyaṃ": ['ap90'],
    "saṃpradātṛ": ['cae'],
    "saṃpradāya": ['cae'],
    "saṃpradāyam": ['cae'],
    "saṃpradāyaḥ": ['ap90'],
    "saṃpragarjati": ['bhs'],
    "saṃpraghuṣṭa": ['bhs'],
    "saṃpragraha": ['bhs'],
    "saṃpraharṣa": ['cae'],
    "saṃpraharṣaka": ['bhs'],
    "saṃpraharṣaṇa": ['bhs'],
    "saṃprahāra": ['cae'],
    "saṃprahāraḥ": ['ap90'],
    "saṃprahārya": ['bhs'],
    "saṃprahāsa": ['cae'],
    "saṃpraiṣa": ['cae'],
    "saṃpraiṣaḥ": ['ap90'],
    "saṃprajanya": ['bhs'],
    "saṃprajvālana": ['bhs'],
    "saṃprajñā": ['bhs'],
    "saṃprajāna": ['bhs'],
    "saṃprakampana": ['bhs'],
    "saṃprakaroti": ['bhs'],
    "saṃprakhyāna": ['bhs'],
    "saṃprakirati": ['bhs'],
    "saṃprakāśaka": ['bhs'],
    "saṃprakāśanatā": ['bhs'],
    "saṃprakṣālaka": ['bhs'],
    "saṃprakṣālanaṃ": ['ap90'],
    "saṃpralāpa": ['cae'],
    "saṃpramathana": ['bhs'],
    "saṃpramoda": ['cae'],
    "saṃpramodaḥ": ['ap90'],
    "saṃpramoha": ['cae'],
    "saṃpramohaḥ": ['ap90'],
    "saṃpramoṣa": ['bhs'],
    "saṃpramoṣaḥ": ['ap90'],
    "saṃpramudita": ['bhs'],
    "saṃpramukti": ['cae'],
    "saṃpramuñcana": ['bhs'],
    "saṃpramuṣyate": ['bhs'],
    "saṃpramārjayati": ['bhs'],
    "saṃpranadahe": ['bhs'],
    "saṃprapad": ['ap90'],
    "saṃprapadaḥ": ['ap90'],
    "saṃprapanna": ['ap90'],
    "saṃprapīta": ['bhs'],
    "saṃprapūra": ['bhs'],
    "saṃpraraṇati": ['bhs'],
    "saṃpraroha": ['bhs'],
    "saṃprarūḍha": ['bhs'],
    "saṃprasanna": ['cae'],
    "saṃprasava": ['bhs'],
    "saṃpraskandati": ['bhs'],
    "saṃprasthā": ['ap90'],
    "saṃprasthāna": ['bhs'],
    "saṃprasthānaṃ": ['ap90'],
    "saṃprasuptaka": ['bhs'],
    "saṃprasāda": ['cae'],
    "saṃprasādaḥ": ['ap90'],
    "saṃprasādhanaṃ": ['ap90'],
    "saṃprasāraṇa": ['cae'],
    "saṃprasāraṇaṃ": ['ap90'],
    "saṃpratakṣṇoti": ['bhs'],
    "saṃprati": ['ap90', 'cae'],
    "saṃpraticchādana": ['bhs'],
    "saṃpratigraha": ['bhs'],
    "saṃpratigrāhin": ['bhs'],
    "saṃpratijāta": ['bhs'],
    "saṃpratilabhate": ['bhs'],
    "saṃpratimānayati": ['bhs'],
    "saṃpratipad": ['ap90'],
    "saṃpratipatti": ['cae'],
    "saṃpratipattiḥ": ['ap90'],
    "saṃpratipādanaṃ": ['ap90'],
    "saṃpratipūrṇa": ['bhs'],
    "saṃpratirodhakaḥ": ['ap90'],
    "saṃprativedhaka": ['bhs'],
    "saṃprativigacchati": ['bhs'],
    "saṃpratiṣṭhita": ['cae'],
    "saṃpratiṣṭhā": ['cae'],
    "saṃpratti": ['cae'],
    "saṃprattiḥ": ['ap90'],
    "saṃpratyavekṣaṇatā": ['bhs'],
    "saṃpratyaya": ['cae'],
    "saṃpratyayaḥ": ['ap90'],
    "saṃpratyayita": ['bhs'],
    "saṃpratyeṣaka": ['bhs'],
    "saṃpratyeṣaṇa": ['bhs'],
    "saṃpratyeṣṭavya": ['bhs'],
    "saṃpratāpana": ['cae'],
    "saṃpratāpanaṃ": ['ap90'],
    "saṃpratāḍana": ['bhs'],
    "saṃpratī": ['ap90'],
    "saṃpratīcchaka": ['bhs'],
    "saṃpratīcchana": ['bhs'],
    "saṃpratīcchati": ['bhs'],
    "saṃpratīkṣya": ['cae'],
    "saṃpratīkṣā": ['ap90'],
    "saṃpratīta": ['ap90'],
    "saṃpratītiḥ": ['ap90'],
    "saṃpravad": ['ap90'],
    "saṃpravadanaṃ": ['ap90'],
    "saṃpravartanaṃ": ['ap90'],
    "saṃpravartika": ['bhs'],
    "saṃpravarṇayate": ['bhs'],
    "saṃpravarṣati": ['bhs'],
    "saṃpravarṣaṇa": ['bhs'],
    "saṃpravaṇatā": ['bhs'],
    "saṃpravedhati": ['bhs'],
    "saṃpraveśa": ['cae'],
    "saṃpraveśana": ['bhs'],
    "saṃpraveśaḥ": ['ap90'],
    "saṃpraviś": ['ap90'],
    "saṃpravutta": ['bhs'],
    "saṃpravyadhati": ['bhs'],
    "saṃpravādayati": ['bhs'],
    "saṃpravādita": ['bhs'],
    "saṃpravārayati": ['bhs'],
    "saṃpravāraṇa": ['bhs'],
    "saṃpravāti": ['bhs'],
    "saṃpravṛt": ['ap90'],
    "saṃpravṛtta": ['bhs', 'cae'],
    "saṃpravṛṣṭaṃ": ['ap90'],
    "saṃprayoga": ['cae'],
    "saṃprayogaḥ": ['ap90'],
    "saṃprayogin": ['ap90'],
    "saṃprayuj": ['ap90'],
    "saṃprayukta": ['ap90', 'cae'],
    "saṃprayāṇaṃ": ['ap90'],
    "saṃpraśamana": ['bhs'],
    "saṃpraśaṃsā": ['bhs'],
    "saṃpraśna": ['cae'],
    "saṃpraśnaḥ": ['ap90'],
    "saṃpraśodhayati": ['bhs'],
    "saṃpraṇetṛ": ['ap90', 'cae'],
    "saṃprekṣ": ['ap90'],
    "saṃprekṣaṇa": ['bhs'],
    "saṃprekṣaṇaṃ": ['ap90'],
    "saṃpremaka": ['bhs'],
    "saṃprepsu": ['cae'],
    "saṃpreraṇa": ['cae'],
    "saṃpreṣ": ['ap90'],
    "saṃpreṣate": ['bhs'],
    "saṃpreṣayati": ['bhs'],
    "saṃpreṣaṇa": ['cae'],
    "saṃpriya": ['cae'],
    "saṃprokṣaṇa": ['cae'],
    "saṃprokṣaṇaṃ": ['ap90'],
    "saṃprāp": ['ap90'],
    "saṃprāpaka": ['bhs'],
    "saṃprāpayitar": ['bhs'],
    "saṃprāpaṇa": ['bhs'],
    "saṃprāpta": ['cae'],
    "saṃprāpti": ['cae'],
    "saṃprāptiḥ": ['ap90'],
    "saṃprāvṛta": ['bhs'],
    "saṃprī": ['ap90'],
    "saṃprīta": ['cae'],
    "saṃprīti": ['cae'],
    "saṃprītiḥ": ['ap90'],
    "saṃpuraskaroti": ['bhs'],
    "saṃpuṣpita": ['bhs'],
    "saṃpuṣṭi": ['cae'],
    "saṃpuṭa": ['bhs', 'cae'],
    "saṃpuṭaka": ['cae'],
    "saṃpuṭakā": ['ap90'],
    "saṃpuṭaḥ": ['ap90'],
    "saṃpuṭita": ['bhs'],
    "saṃpā": ['ap90', 'cae'],
    "saṃpādaka": ['cae'],
    "saṃpādana": ['cae'],
    "saṃpādanaṃ": ['ap90'],
    "saṃpādayitṛ": ['cae'],
    "saṃpādaḥ": ['ap90'],
    "saṃpāditatva": ['cae'],
    "saṃpādya": ['cae'],
    "saṃpāka": ['ap90'],
    "saṃpāraṇa": ['cae'],
    "saṃpārin": ['cae'],
    "saṃpāta": ['cae'],
    "saṃpātaḥ": ['ap90'],
    "saṃpāti": ['cae'],
    "saṃpātikaḥ": ['ap90'],
    "saṃpātin": ['cae'],
    "saṃpātiḥ": ['ap90'],
    "saṃpāṭaḥ": ['ap90'],
    "saṃpītiḥ": ['ap90'],
    "saṃpīḍ": ['ap90'],
    "saṃpīḍa": ['cae'],
    "saṃpīḍanaṃ": ['ap90'],
    "saṃpīḍaḥ": ['ap90'],
    "saṃpīḍita": ['bhs'],
    "saṃpūj": ['ap90'],
    "saṃpūjana": ['cae'],
    "saṃpūjanaṃ": ['ap90'],
    "saṃpūjita": ['bhs'],
    "saṃpūjya": ['cae'],
    "saṃpūrṇa": ['ap90', 'bhs', 'cae'],
    "saṃpūrṇapuccha": ['cae'],
    "saṃpūrṇaśrīvaktrā": ['bhs'],
    "saṃpṛc": ['ap90'],
    "saṃpṛkta": ['ap90', 'cae'],
    "saṃpṛṇa": ['cae'],
    "saṃrabdha": ['ap90', 'cae', 'mw'],
    "saṃrabdham": ['mw'],
    "saṃrabdhamāna": ['mw'],
    "saṃrabdhanetra": ['mw'],
    "saṃrabdhatara": ['mw'],
    "saṃrabh": ['ap90', 'mw'],
    "saṃrajanīya": ['bhs'],
    "saṃrakta": ['ap90', 'cae', 'mw'],
    "saṃraktalocana": ['mw'],
    "saṃraktanayana": ['mw'],
    "saṃrakṣ": ['ap90', 'mw'],
    "saṃrakṣa": ['cae', 'ddsa', 'mw'],
    "saṃrakṣaka": ['cae', 'mw'],
    "saṃrakṣaḥ": ['ap90'],
    "saṃrakṣaṇa": ['cae', 'mw'],
    "saṃrakṣaṇavat": ['mw'],
    "saṃrakṣaṇaṃ": ['ap90'],
    "saṃrakṣaṇīya": ['cae', 'mw'],
    "saṃrakṣikā": ['cae'],
    "saṃrakṣin": ['mw'],
    "saṃrakṣita": ['mw'],
    "saṃrakṣitavya": ['mw'],
    "saṃrakṣitin": ['mw'],
    "saṃrakṣya": ['cae', 'mw'],
    "saṃrakṣā": ['mw'],
    "saṃram": ['mw'],
    "saṃrambha": ['cae', 'mw'],
    "saṃrambhadṛś": ['mw'],
    "saṃrambhaparuṣa": ['mw'],
    "saṃrambharasa": ['mw'],
    "saṃrambharūkṣa": ['mw'],
    "saṃrambhatāmra": ['mw'],
    "saṃrambhavat": ['mw'],
    "saṃrambhavega": ['mw'],
    "saṃrambhaṇa": ['mw'],
    "saṃrambhin": ['cae', 'mw'],
    "saṃrambhitva": ['mw'],
    "saṃrambhitā": ['mw'],
    "saṃrañj": ['mw'],
    "saṃrañjana": ['bhs', 'mw'],
    "saṃrañjanīya": ['bhs', 'mw'],
    "saṃrañjita": ['mw'],
    "saṃraṃbhaḥ": ['ap90'],
    "saṃraṃbhin": ['ap90'],
    "saṃraṃj": ['ap90'],
    "saṃrej": ['mw'],
    "saṃrih": ['mw'],
    "saṃrihāṇaṃ": ['ap90'],
    "saṃrodana": ['cae', 'mw'],
    "saṃrodha": ['cae', 'mw'],
    "saṃrodhana": ['cae', 'mw'],
    "saṃrodhanaṃ": ['ap90'],
    "saṃrodhaḥ": ['ap90'],
    "saṃrodhya": ['cae', 'mw'],
    "saṃroha": ['cae', 'mw'],
    "saṃrohaṇa": ['cae', 'mw'],
    "saṃrohin": ['cae', 'mw'],
    "saṃropaṇa": ['cae', 'mw'],
    "saṃropita": ['mw'],
    "saṃroṣita": ['mw'],
    "saṃru": ['mw'],
    "saṃruc": ['mw'],
    "saṃruddha": ['ap90', 'cae', 'mw'],
    "saṃruddhaceṣṭa": ['mw'],
    "saṃruddhaprajanana": ['mw'],
    "saṃrudh": ['ap90', 'mw'],
    "saṃrugṇa": ['ap90', 'mw'],
    "saṃruh": ['ap90', 'mw'],
    "saṃruj": ['mw'],
    "saṃrujana": ['mw'],
    "saṃruṣ": ['mw'],
    "saṃruṣita": ['cae', 'mw'],
    "saṃrā": ['mw'],
    "saṃrāddha": ['mw'],
    "saṃrāddhi": ['mw'],
    "saṃrādh": ['ap90', 'mw'],
    "saṃrādhaka": ['mw'],
    "saṃrādhana": ['bhs', 'cae', 'mw'],
    "saṃrādhanaṃ": ['ap90'],
    "saṃrādhati": ['bhs'],
    "saṃrādhayat": ['mw'],
    "saṃrādhita": ['mw'],
    "saṃrādhya": ['cae', 'mw'],
    "saṃrāga": ['cae', 'mw'],
    "saṃrāgayati": ['bhs'],
    "saṃrāgaḥ": ['ap90'],
    "saṃrāj": ['mw'],
    "saṃrājitṛ": ['mw'],
    "saṃrāva": ['cae', 'mw'],
    "saṃrāvaḥ": ['ap90'],
    "saṃrāvaṇa": ['mw'],
    "saṃrāvin": ['mw'],
    "saṃrī": ['mw'],
    "saṃrūḍha": ['ap90', 'cae', 'mw'],
    "saṃrūḍhavraṇa": ['mw'],
    "saṃrūṣ": ['mw'],
    "saṃsac": ['mw'],
    "saṃsad": ['ap90', 'cae', 'gra', 'mw'],
    "saṃsada": ['mw'],
    "saṃsadana": ['mw'],
    "saṃsah": ['mw'],
    "saṃsaha": ['mw'],
    "saṃsahasra": ['cae', 'gra', 'mw'],
    "saṃsahāyaka": ['mw'],
    "saṃsajjamāna": ['mw'],
    "saṃsakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "saṃsaktacetas": ['mw'],
    "saṃsaktacitta": ['mw'],
    "saṃsaktahasta": ['mw'],
    "saṃsaktajala": ['mw'],
    "saṃsaktaka": ['bhs'],
    "saṃsaktamanas": ['mw'],
    "saṃsaktatā": ['mw'],
    "saṃsaktavadanāśvāsa": ['mw'],
    "saṃsaktayuga": ['mw'],
    "saṃsakti": ['cae', 'mw'],
    "saṃsaktiḥ": ['ap90'],
    "saṃsamaka": ['cae', 'mw'],
    "saṃsan": ['mw'],
    "saṃsanana": ['mw'],
    "saṃsaptaka": ['mw'],
    "saṃsaptakī": ['mw'],
    "saṃsaraṇa": ['cae', 'mw'],
    "saṃsaraṇaṃ": ['ap90'],
    "saṃsarga": ['cae', 'mw'],
    "saṃsargadoṣa": ['mw'],
    "saṃsargaja": ['mw'],
    "saṃsargaka": ['mw'],
    "saṃsargaprakaraṇa": ['mw'],
    "saṃsargatas": ['mw'],
    "saṃsargavat": ['mw'],
    "saṃsargavattva": ['mw'],
    "saṃsargavidyā": ['mw'],
    "saṃsargaya": ['mw'],
    "saṃsargaḥ": ['ap90'],
    "saṃsargin": ['ap90', 'cae', 'mw'],
    "saṃsargitva": ['mw'],
    "saṃsargitā": ['mw'],
    "saṃsargābhāva": ['mw'],
    "saṃsargī": ['mw'],
    "saṃsarin": ['bhs'],
    "saṃsarjana": ['cae', 'mw'],
    "saṃsarjanaṃ": ['ap90'],
    "saṃsarpa": ['cae', 'mw'],
    "saṃsarpaddhvajinīvimardavilasaddhūlīmaya": ['mw'],
    "saṃsarpamāṇaka": ['cae', 'mw'],
    "saṃsarpat": ['mw'],
    "saṃsarpaḥ": ['ap90'],
    "saṃsarpaṇa": ['cae', 'mw'],
    "saṃsarpaṇaṃ": ['ap90'],
    "saṃsarpin": ['ap90', 'cae', 'mw'],
    "saṃsarpitā": ['mw'],
    "saṃsaryā": ['mw'],
    "saṃsati": ['bhs'],
    "saṃsava": ['mw'],
    "saṃsañj": ['mw'],
    "saṃsaṃj": ['ap90'],
    "saṃsaṃyu": ['mw'],
    "saṃsaṅga": ['cae', 'mw'],
    "saṃsaṅgin": ['mw'],
    "saṃsaṅginītva": ['mw'],
    "saṃseka": ['ddsa', 'mw'],
    "saṃsekaḥ": ['ap90'],
    "saṃsev": ['mw'],
    "saṃsevana": ['cae', 'mw'],
    "saṃsevin": ['mw'],
    "saṃsevita": ['mw'],
    "saṃsevitṛ": ['mw'],
    "saṃsevya": ['cae', 'mw'],
    "saṃsevā": ['cae', 'mw'],
    "saṃsic": ['cae', 'mw'],
    "saṃsiddha": ['ap90', 'cae', 'mw'],
    "saṃsiddharasa": ['mw'],
    "saṃsiddharūpa": ['mw'],
    "saṃsiddhi": ['cae', 'mw'],
    "saṃsiddhiḥ": ['ap90'],
    "saṃsiddhārtha": ['mw'],
    "saṃsidh": ['ap90', 'mw'],
    "saṃsikta": ['mw'],
    "saṃsiktareṇu": ['mw'],
    "saṃsisṛkṣu": ['mw'],
    "saṃsiv": ['mw'],
    "saṃskand": ['mw'],
    "saṃskandha": ['mw'],
    "saṃskaraṇa": ['cae', 'ddsa', 'mw'],
    "saṃskartavya": ['mw'],
    "saṃskartṛ": ['ap90', 'cae', 'mw'],
    "saṃskhalita": ['mw'],
    "saṃskriyā": ['ap90', 'cae', 'mw'],
    "saṃskāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "saṃskārabhāskara": ['mw'],
    "saṃskārabhūṣaṇa": ['mw'],
    "saṃskāradīdhiti": ['mw'],
    "saṃskāragaṅgādhara": ['mw'],
    "saṃskāragaṇapati": ['mw'],
    "saṃskārahīna": ['mw'],
    "saṃskāraja": ['mw'],
    "saṃskāraka": ['ap90', 'mw'],
    "saṃskārakamalākara": ['mw'],
    "saṃskārakartṛ": ['mw'],
    "saṃskārakatva": ['mw'],
    "saṃskārakaumudī": ['mw'],
    "saṃskārakaustubha": ['mw'],
    "saṃskārakaustubhadīdhiti": ['mw'],
    "saṃskāramaya": ['mw'],
    "saṃskāramayūkha": ['mw'],
    "saṃskāramuktāvalī": ['mw'],
    "saṃskāranirṇaya": ['mw'],
    "saṃskāranāman": ['mw'],
    "saṃskāranṛsiṃha": ['mw'],
    "saṃskārapaddhati": ['mw'],
    "saṃskārapaddhatirahasya": ['mw'],
    "saṃskārapariśiṣṭa": ['mw'],
    "saṃskārapradīpa": ['mw'],
    "saṃskārapradīpikā": ['mw'],
    "saṃskāraprakaraṇa": ['mw'],
    "saṃskāraprakāśa": ['mw'],
    "saṃskāraprayoga": ['mw'],
    "saṃskārapūta": ['mw'],
    "saṃskārarahita": ['mw'],
    "saṃskāraratna": ['mw'],
    "saṃskāraratnamālā": ['mw'],
    "saṃskārasampanna": ['mw'],
    "saṃskārasaukhya": ['mw'],
    "saṃskārasiddhidīpikā": ['mw'],
    "saṃskārasāgara": ['mw'],
    "saṃskārasāra": ['mw'],
    "saṃskāratattva": ['mw'],
    "saṃskāratva": ['mw'],
    "saṃskāratvajātikhaṇḍana": ['mw'],
    "saṃskāratā": ['mw'],
    "saṃskāravarjita": ['mw'],
    "saṃskāravat": ['mw'],
    "saṃskāravattva": ['mw'],
    "saṃskāravidhi": ['mw'],
    "saṃskāraviśiṣṭa": ['mw'],
    "saṃskāravādārtha": ['mw'],
    "saṃskāraḥ": ['ap90'],
    "saṃskāroddyota": ['mw'],
    "saṃskārya": ['cae', 'ddsa', 'mw'],
    "saṃskārādhikārin": ['mw'],
    "saṃskārādimat": ['mw'],
    "saṃskṛ": ['ap90', 'mw'],
    "saṃskṛta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "saṃskṛtamaya": ['mw'],
    "saṃskṛtamañjarī": ['mw'],
    "saṃskṛtamālā": ['mw'],
    "saṃskṛtaratnamālā": ['mw'],
    "saṃskṛtatra": ['gra', 'mw'],
    "saṃskṛtatva": ['mw'],
    "saṃskṛtavat": ['mw'],
    "saṃskṛtavākyaratnāvalī": ['mw'],
    "saṃskṛti": ['cae', 'mw'],
    "saṃskṛtokti": ['mw'],
    "saṃskṛtrima": ['mw'],
    "saṃskṛtātman": ['cae', 'mw'],
    "saṃsmaraṇa": ['cae', 'mw'],
    "saṃsmaraṇaṃ": ['ap90'],
    "saṃsmaraṇīya": ['cae', 'mw'],
    "saṃsmaraṇīyaśobha": ['mw'],
    "saṃsmartavya": ['cae', 'mw'],
    "saṃsmera": ['cae', 'mw'],
    "saṃsmi": ['mw'],
    "saṃsmāraka": ['mw'],
    "saṃsmāraṇa": ['mw'],
    "saṃsmārita": ['mw'],
    "saṃsmṛ": ['ap90', 'mw'],
    "saṃsmṛta": ['cae', 'mw'],
    "saṃsmṛti": ['cae', 'mw'],
    "saṃsmṛtiḥ": ['ap90'],
    "saṃsmṛtopasthita": ['mw'],
    "saṃsnehana": ['mw'],
    "saṃsnih": ['mw'],
    "saṃsnā": ['mw'],
    "saṃsnāna": ['mw'],
    "saṃsnāta": ['mw'],
    "saṃsodhya": ['mw'],
    "saṃspand": ['mw'],
    "saṃspardh": ['mw'],
    "saṃspardhin": ['cae', 'mw'],
    "saṃspardhā": ['cae', 'ddsa', 'mw'],
    "saṃspariśa": ['bhs'],
    "saṃsparśa": ['cae', 'mw'],
    "saṃsparśaja": ['cae', 'mw'],
    "saṃsparśana": ['cae', 'mw'],
    "saṃsparśaḥ": ['ap90'],
    "saṃsparśin": ['cae', 'mw'],
    "saṃsparśā": ['mw'],
    "saṃsparśāna": ['mw'],
    "saṃsparśī": ['ap90'],
    "saṃspaṣṭa": ['mw'],
    "saṃsphal": ['mw'],
    "saṃspheṭa": ['mw'],
    "saṃspheṭaḥ": ['ap90'],
    "saṃsphoṭa": ['cae', 'mw'],
    "saṃsphur": ['mw'],
    "saṃsphuṭa": ['ap90', 'mw'],
    "saṃsphāla": ['mw'],
    "saṃsphālaḥ": ['ap90'],
    "saṃsphāna": ['mw'],
    "saṃsphārayati": ['bhs'],
    "saṃsphāyana": ['mw'],
    "saṃsphīta": ['cae'],
    "saṃsphīya": ['mw'],
    "saṃspraṣṭṛ": ['mw'],
    "saṃspṛh": ['mw'],
    "saṃspṛś": ['ap90', 'cae', 'mw'],
    "saṃspṛśati": ['bhs'],
    "saṃspṛṣṭa": ['ap90', 'cae', 'mw'],
    "saṃspṛṣṭamaithunā": ['mw'],
    "saṃsrava": ['cae', 'gra', 'mw'],
    "saṃsravabhāga": ['mw'],
    "saṃsravaḥ": ['ap90'],
    "saṃsravaṇa": ['mw'],
    "saṃsraṣṭṛ": ['mw'],
    "saṃsru": ['mw'],
    "saṃsrāva": ['cae', 'mw'],
    "saṃsrāvabhāga": ['mw'],
    "saṃsrāvaṇa": ['cae', 'mw'],
    "saṃsrāvya": ['cae', 'mw'],
    "saṃst": ['mw'],
    "saṃstabdha": ['ap90', 'cae', 'mw'],
    "saṃstabhya": ['mw'],
    "saṃstambh": ['mw'],
    "saṃstambha": ['cae', 'mw'],
    "saṃstambhana": ['cae', 'mw'],
    "saṃstambhanīya": ['mw'],
    "saṃstambhayitṛ": ['cae', 'ddsa', 'mw'],
    "saṃstambhayiṣu": ['mw'],
    "saṃstambhin": ['cae', 'mw'],
    "saṃstambhita": ['mw'],
    "saṃstara": ['cae', 'mw'],
    "saṃstaraka": ['bhs'],
    "saṃstaraḥ": ['ap90'],
    "saṃstaraṇa": ['cae', 'mw'],
    "saṃstaraṇaka": ['bhs'],
    "saṃstava": ['cae', 'mw'],
    "saṃstavana": ['bhs', 'mw'],
    "saṃstavaprīti": ['mw'],
    "saṃstavasthira": ['mw'],
    "saṃstavaḥ": ['ap90'],
    "saṃstavāna": ['ap90', 'mw'],
    "saṃstaṃbh": ['ap90'],
    "saṃstaṃbhaḥ": ['ap90'],
    "saṃstha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "saṃsthihati": ['bhs'],
    "saṃsthita": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃsthitahoma": ['mw'],
    "saṃsthitaka": ['bhs'],
    "saṃsthitavat": ['mw'],
    "saṃsthitayajus": ['mw'],
    "saṃsthiti": ['cae', 'mw'],
    "saṃsthitika": ['mw'],
    "saṃsthitikā": ['bhs'],
    "saṃsthitiḥ": ['ap90'],
    "saṃsthula": ['mw'],
    "saṃsthā": ['ap90', 'mw'],
    "saṃsthāgāra": ['bhs', 'mw'],
    "saṃsthājapa": ['mw'],
    "saṃsthākṛta": ['mw'],
    "saṃsthāna": ['cae', 'mw'],
    "saṃsthānabhukti": ['mw'],
    "saṃsthānacārin": ['mw'],
    "saṃsthānaka": ['cae', 'mw'],
    "saṃsthānavat": ['mw'],
    "saṃsthānaṃ": ['ap90'],
    "saṃsthāpaddhati": ['mw'],
    "saṃsthāpaka": ['ap90', 'mw'],
    "saṃsthāpana": ['bhs', 'cae', 'mw'],
    "saṃsthāpanaṃ": ['ap90'],
    "saṃsthāpanā": ['mw'],
    "saṃsthāpanīya": ['mw'],
    "saṃsthāpayitavya": ['mw'],
    "saṃsthāpita": ['ap90', 'mw'],
    "saṃsthāpya": ['mw'],
    "saṃsthāsnu": ['mw'],
    "saṃsthātva": ['mw'],
    "saṃsthāvan": ['gra'],
    "saṃsthāvayavavat": ['mw'],
    "saṃstir": ['gra', 'mw'],
    "saṃstobha": ['mw'],
    "saṃstu": ['ap90', 'mw'],
    "saṃstubh": ['cae', 'mw'],
    "saṃstuta": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃstutaka": ['bhs', 'mw'],
    "saṃstutaprāya": ['mw'],
    "saṃstutatva": ['mw'],
    "saṃstuti": ['cae', 'mw'],
    "saṃstutiḥ": ['ap90'],
    "saṃstuva": ['bhs'],
    "saṃstyāna": ['cae', 'mw'],
    "saṃstyāya": ['cae', 'mw'],
    "saṃstyāyaḥ": ['ap90'],
    "saṃstāra": ['cae', 'mw'],
    "saṃstāraka": ['mw'],
    "saṃstārapaṅkti": ['mw'],
    "saṃstāraḥ": ['ap90'],
    "saṃstāva": ['mw'],
    "saṃstāvaḥ": ['ap90'],
    "saṃstīrṇa": ['cae', 'mw'],
    "saṃstūpa": ['bhs', 'mw'],
    "saṃstṛ": ['ap90', 'mw'],
    "saṃstṛta": ['cae', 'mw'],
    "saṃstṝ": ['mw'],
    "saṃsu": ['mw'],
    "saṃsud": ['cae', 'gra'],
    "saṃsude": ['mw'],
    "saṃsukhita": ['mw'],
    "saṃsupta": ['cae', 'mw'],
    "saṃsutasoma": ['mw'],
    "saṃsvad": ['mw'],
    "saṃsvap": ['mw'],
    "saṃsvañj": ['mw'],
    "saṃsveda": ['cae', 'mw'],
    "saṃsvedaja": ['mw'],
    "saṃsvedayu": ['mw'],
    "saṃsvedin": ['mw'],
    "saṃsvid": ['mw'],
    "saṃsvinna": ['bhs'],
    "saṃsvāra": ['cae', 'mw'],
    "saṃsvṛ": ['mw'],
    "saṃsyand": ['mw'],
    "saṃsyandana": ['bhs'],
    "saṃsyandati": ['bhs'],
    "saṃsyandin": ['cae'],
    "saṃsyuta": ['mw'],
    "saṃsyūta": ['mw'],
    "saṃsāda": ['cae', 'mw'],
    "saṃsādana": ['bhs', 'mw'],
    "saṃsādayati": ['bhs'],
    "saṃsādaḥ": ['ap90'],
    "saṃsādh": ['ap90', 'mw'],
    "saṃsādhaka": ['mw'],
    "saṃsādhana": ['cae', 'ddsa', 'mw'],
    "saṃsādhya": ['cae', 'mw'],
    "saṃsāra": ['bhs', 'cae', 'mw'],
    "saṃsārabandhana": ['mw'],
    "saṃsārabīja": ['mw'],
    "saṃsāracakra": ['mw'],
    "saṃsāradevī": ['mw'],
    "saṃsāraduḥkha": ['mw'],
    "saṃsāragamana": ['cae', 'mw'],
    "saṃsāraguru": ['mw'],
    "saṃsārakānana": ['mw'],
    "saṃsārakāntāra": ['mw'],
    "saṃsārakārāgṛha": ['mw'],
    "saṃsārakūpa": ['mw'],
    "saṃsāramaṇḍala": ['mw'],
    "saṃsāramokṣa": ['mw'],
    "saṃsāramokṣaṇa": ['mw'],
    "saṃsāramuktikāraṇavāda": ['mw'],
    "saṃsāramārga": ['cae', 'mw'],
    "saṃsāranirṇaya": ['mw'],
    "saṃsārapadavī": ['mw'],
    "saṃsāraparitāpa": ['mw'],
    "saṃsāraparivartana": ['mw'],
    "saṃsārapariśrama": ['mw'],
    "saṃsārapatha": ['mw'],
    "saṃsārasamudra": ['mw'],
    "saṃsārasaraṇi": ['mw'],
    "saṃsārasaṅga": ['mw'],
    "saṃsārasukha": ['mw'],
    "saṃsārasāgara": ['mw'],
    "saṃsārasāra": ['mw'],
    "saṃsārasārathi": ['mw'],
    "saṃsārataraṇi": ['mw'],
    "saṃsārataraṇī": ['mw'],
    "saṃsārataru": ['mw'],
    "saṃsāravana": ['mw'],
    "saṃsāravarjita": ['mw'],
    "saṃsāravartman": ['mw'],
    "saṃsāravat": ['mw'],
    "saṃsāraviṣavṛkṣa": ['mw'],
    "saṃsāraviṭapāṅkura": ['mw'],
    "saṃsāravṛkṣa": ['mw'],
    "saṃsāraśrāntacitta": ['mw'],
    "saṃsāraḥ": ['ap90'],
    "saṃsāraṇa": ['mw'],
    "saṃsārika": ['bhs'],
    "saṃsārin": ['ap90', 'cae', 'mw'],
    "saṃsāritva": ['mw'],
    "saṃsārodadhi": ['mw'],
    "saṃsārottaraṇa": ['bhs'],
    "saṃsāryātman": ['mw'],
    "saṃsārābdhi": ['mw'],
    "saṃsārānala": ['mw'],
    "saṃsārānta": ['cae', 'mw'],
    "saṃsārārṇava": ['cae', 'mw'],
    "saṃsārāvarta": ['mw'],
    "saṃsārāṅgāra": ['mw'],
    "saṃsīdana": ['bhs', 'mw'],
    "saṃsū": ['mw'],
    "saṃsūc": ['ap90', 'mw'],
    "saṃsūcaka": ['mw'],
    "saṃsūcana": ['cae', 'mw'],
    "saṃsūcanaṃ": ['ap90'],
    "saṃsūcin": ['mw'],
    "saṃsūcita": ['mw'],
    "saṃsūcya": ['mw'],
    "saṃsūda": ['cae'],
    "saṃsṛ": ['ap90', 'mw'],
    "saṃsṛj": ['ap90', 'cae', 'gra', 'mw'],
    "saṃsṛp": ['ap90', 'cae', 'mw'],
    "saṃsṛti": ['mw'],
    "saṃsṛticakra": ['mw'],
    "saṃsṛticakravāla": ['mw'],
    "saṃsṛtiḥ": ['ap90'],
    "saṃsṛṣṭa": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃsṛṣṭabhāva": ['mw'],
    "saṃsṛṣṭadhaya": ['mw'],
    "saṃsṛṣṭahoma": ['mw'],
    "saṃsṛṣṭajit": ['gra', 'mw'],
    "saṃsṛṣṭakarman": ['mw'],
    "saṃsṛṣṭamaithuna": ['mw'],
    "saṃsṛṣṭarūpa": ['mw'],
    "saṃsṛṣṭatva": ['mw'],
    "saṃsṛṣṭatā": ['ap90'],
    "saṃsṛṣṭi": ['cae', 'mw'],
    "saṃsṛṣṭin": ['ap90', 'mw'],
    "saṃsṛṣṭiḥ": ['ap90'],
    "saṃtakṣ": ['ap90', 'mw'],
    "saṃtakṣaṇa": ['mw'],
    "saṃtakṣaṇaṃ": ['ap90'],
    "saṃtam": ['ap90', 'mw'],
    "saṃtamaka": ['mw'],
    "saṃtamakaḥ": ['ap90'],
    "saṃtamas": ['ap90', 'mw'],
    "saṃtamasa": ['cae', 'mw'],
    "saṃtamasin": ['bhs'],
    "saṃtan": ['ap90', 'mw'],
    "saṃtani": ['cae', 'gra', 'mw'],
    "saṃtanika": ['mw'],
    "saṃtanu": ['mw'],
    "saṃtap": ['ap90', 'mw'],
    "saṃtapana": ['cae', 'mw'],
    "saṃtapanaṃ": ['ap90'],
    "saṃtapta": ['ap90', 'cae', 'mw'],
    "saṃtaptacāmīkara": ['mw'],
    "saṃtaptahṛdaya": ['mw'],
    "saṃtaptarajata": ['mw'],
    "saṃtaptavakṣas": ['mw'],
    "saṃtaptāyas": ['mw'],
    "saṃtapyamāna": ['mw'],
    "saṃtapyamānamanas": ['mw'],
    "saṃtaram": ['cae', 'mw'],
    "saṃtaraṇa": ['cae', 'mw'],
    "saṃtaraṇaṃ": ['ap90'],
    "saṃtardana": ['mw'],
    "saṃtarj": ['mw'],
    "saṃtarjana": ['cae', 'mw'],
    "saṃtarjanaṃ": ['ap90'],
    "saṃtarjita": ['mw'],
    "saṃtark": ['mw'],
    "saṃtarpaka": ['cae', 'mw'],
    "saṃtarpaṇa": ['mw'],
    "saṃtarpaṇaṃ": ['ap90'],
    "saṃtarpaṇīya": ['mw'],
    "saṃtarpita": ['mw'],
    "saṃtarpya": ['cae', 'mw'],
    "saṃtarutra": ['cae', 'gra', 'mw'],
    "saṃtarā": ['gra'],
    "saṃtarām": ['cae', 'mw'],
    "saṃtata": ['ap90', 'cae', 'mw'],
    "saṃtatadruma": ['mw'],
    "saṃtatajvara": ['mw'],
    "saṃtatam": ['mw'],
    "saṃtatavarṣin": ['mw'],
    "saṃtatavepathu": ['mw'],
    "saṃtateyu": ['mw'],
    "saṃtati": ['bhs', 'cae', 'mw'],
    "saṃtatihoma": ['mw'],
    "saṃtatika": ['bhs', 'mw'],
    "saṃtatimat": ['mw'],
    "saṃtatiḥ": ['ap90'],
    "saṃtatābhyāsa": ['mw'],
    "saṃtatāpad": ['mw'],
    "saṃtatāśrunipātana": ['mw'],
    "saṃtavītvat": ['mw'],
    "saṃtaḍ": ['mw'],
    "saṃtaḥ": ['ap90'],
    "saṃtejana": ['cae', 'mw'],
    "saṃtha": ['bhs'],
    "saṃthaṇā": ['bhs'],
    "saṃtij": ['mw'],
    "saṃtiraṇa": ['bhs'],
    "saṃtiḥ": ['ap90'],
    "saṃtiṣṭhate": ['bhs'],
    "saṃtodin": ['cae', 'mw'],
    "saṃtoṣa": ['cae', 'mw'],
    "saṃtoṣaka": ['mw'],
    "saṃtoṣavat": ['mw'],
    "saṃtoṣaḥ": ['ap90'],
    "saṃtoṣaṇa": ['cae', 'mw'],
    "saṃtoṣaṇaṃ": ['ap90'],
    "saṃtoṣaṇā": ['bhs'],
    "saṃtoṣaṇīya": ['cae', 'mw'],
    "saṃtoṣaṇīyarūpa": ['mw'],
    "saṃtoṣin": ['mw'],
    "saṃtoṣita": ['mw'],
    "saṃtoṣya": ['mw'],
    "saṃtoṣā": ['mw'],
    "saṃtoṣānanda": ['mw'],
    "saṃtoṣṭavya": ['mw'],
    "saṃtrai": ['mw'],
    "saṃtras": ['ap90', 'mw'],
    "saṃtrasin": ['bhs'],
    "saṃtrasta": ['mw'],
    "saṃtrastagocara": ['mw'],
    "saṃtrāsa": ['cae', 'mw'],
    "saṃtrāsana": ['cae', 'mw'],
    "saṃtrāsanī": ['bhs'],
    "saṃtrāsaḥ": ['ap90'],
    "saṃtrāsita": ['mw'],
    "saṃtrāyati": ['mw'],
    "saṃtrāṇa": ['cae', 'mw'],
    "saṃtud": ['mw'],
    "saṃtul": ['mw'],
    "saṃtutikā": ['bhs'],
    "saṃtuṣ": ['ap90', 'mw'],
    "saṃtuṣita": ['bhs', 'mw'],
    "saṃtuṣitaka": ['bhs', 'mw'],
    "saṃtuṣṭa": ['ap90', 'cae', 'mw'],
    "saṃtuṣṭatarṇakavatī": ['mw'],
    "saṃtuṣṭi": ['cae', 'mw'],
    "saṃtuṣṭiḥ": ['ap90'],
    "saṃtva": ['mw'],
    "saṃtvar": ['mw'],
    "saṃtvarita": ['mw'],
    "saṃtvaritam": ['mw'],
    "saṃtvarā": ['cae', 'mw'],
    "saṃtyaj": ['ap90', 'mw'],
    "saṃtyajana": ['mw'],
    "saṃtyajanaṃ": ['ap90'],
    "saṃtyajya": ['cae', 'mw'],
    "saṃtyakta": ['ap90', 'cae', 'mw'],
    "saṃtyāga": ['cae', 'mw'],
    "saṃtyāgin": ['mw'],
    "saṃtyājya": ['mw'],
    "saṃtāna": ['bhs', 'cae', 'mw'],
    "saṃtānadīpikā": ['mw'],
    "saṃtānagaṇapati": ['mw'],
    "saṃtānagopāla": ['mw'],
    "saṃtānagopālavidhi": ['mw'],
    "saṃtānaja": ['mw'],
    "saṃtānaka": ['mw'],
    "saṃtānakamaya": ['mw'],
    "saṃtānakarman": ['mw'],
    "saṃtānakartṛ": ['mw'],
    "saṃtānakaḥ": ['ap90'],
    "saṃtānakākīrṇa": ['mw'],
    "saṃtānakāraṇya": ['mw'],
    "saṃtānapradasūryastotra": ['mw'],
    "saṃtānarāmastotra": ['mw'],
    "saṃtānasaṃdhi": ['mw'],
    "saṃtānasaṃhitā": ['mw'],
    "saṃtānavardhana": ['mw'],
    "saṃtānavat": ['mw'],
    "saṃtānavivekāvali": ['mw'],
    "saṃtānaḥ": ['ap90'],
    "saṃtānika": ['mw'],
    "saṃtānikā": ['ap90', 'mw'],
    "saṃtānin": ['mw'],
    "saṃtāninī": ['mw'],
    "saṃtānārtham": ['mw'],
    "saṃtānīya": ['mw'],
    "saṃtāpa": ['cae', 'mw'],
    "saṃtāpahara": ['cae', 'mw'],
    "saṃtāpahāraka": ['mw'],
    "saṃtāpakara": ['mw'],
    "saṃtāpakārin": ['cae', 'mw'],
    "saṃtāpana": ['ap90', 'cae', 'mw'],
    "saṃtāpavat": ['mw'],
    "saṃtāpaḥ": ['ap90'],
    "saṃtāpita": ['ap90', 'mw'],
    "saṃtāpya": ['cae', 'mw'],
    "saṃtāra": ['cae', 'mw'],
    "saṃtāraka": ['bhs', 'mw'],
    "saṃtārakavidhi": ['mw'],
    "saṃtāraṇa": ['bhs'],
    "saṃtārita": ['mw'],
    "saṃtārya": ['mw'],
    "saṃtāy": ['mw'],
    "saṃtāḍana": ['cae', 'mw'],
    "saṃtāḍya": ['mw'],
    "saṃtīraṇa": ['bhs'],
    "saṃtīrya": ['bhs'],
    "saṃtīrṇa": ['mw'],
    "saṃtṛd": ['mw'],
    "saṃtṛdya": ['mw'],
    "saṃtṛp": ['mw'],
    "saṃtṛpti": ['cae'],
    "saṃtṛṇṇa": ['mw'],
    "saṃtṛṣita": ['bhs'],
    "saṃtṝ": ['ap90', 'mw'],
    "saṃvac": ['mw'],
    "saṃvad": ['ap90', 'mw'],
    "saṃvadana": ['cae', 'ddsa', 'mw'],
    "saṃvadanaṃ": ['ap90'],
    "saṃvaditavya": ['mw'],
    "saṃvah": ['ap90', 'mw'],
    "saṃvaha": ['mw'],
    "saṃvahana": ['mw'],
    "saṃvahaḥ": ['ap90'],
    "saṃvahitṛ": ['mw'],
    "saṃvala": ['cae', 'mw'],
    "saṃvalana": ['cae', 'mw'],
    "saṃvalanaṃ": ['ap90'],
    "saṃvalg": ['mw'],
    "saṃvalgana": ['mw'],
    "saṃvalgita": ['ap90', 'mw'],
    "saṃvalita": ['ap90', 'cae', 'mw'],
    "saṃvalitā": ['bhs'],
    "saṃvan": ['mw'],
    "saṃvanana": ['cae', 'gra', 'mw'],
    "saṃvananaṃ": ['ap90'],
    "saṃvand": ['mw'],
    "saṃvanin": ['mw'],
    "saṃvap": ['mw'],
    "saṃvapana": ['mw'],
    "saṃvara": ['bhs', 'cae', 'mw'],
    "saṃvaraviṃśaka": ['mw'],
    "saṃvaravyākhyā": ['mw'],
    "saṃvaraḥ": ['ap90'],
    "saṃvaraṇa": ['cae', 'gra', 'mw'],
    "saṃvaraṇanātaka": ['mw'],
    "saṃvaraṇanāṭaka": ['mw'],
    "saṃvaraṇasraj": ['mw'],
    "saṃvaraṇaṃ": ['ap90'],
    "saṃvaraṇīya": ['mw'],
    "saṃvardhaka": ['ap90', 'bhs', 'mw'],
    "saṃvardhana": ['cae', 'mw'],
    "saṃvardhanaṃ": ['ap90'],
    "saṃvardhanīya": ['mw'],
    "saṃvardhayitṛ": ['mw'],
    "saṃvardhita": ['ap90', 'mw'],
    "saṃvarga": ['cae', 'gra', 'mw'],
    "saṃvargajit": ['mw'],
    "saṃvargam": ['cae', 'mw'],
    "saṃvargavidyā": ['mw'],
    "saṃvargaya": ['mw'],
    "saṃvargaḥ": ['ap90'],
    "saṃvargaṇa": ['mw'],
    "saṃvargya": ['mw'],
    "saṃvarjana": ['mw'],
    "saṃvarjanaṃ": ['ap90'],
    "saṃvarmaya": ['mw'],
    "saṃvarmita": ['mw'],
    "saṃvarodayatantra": ['mw'],
    "saṃvarta": ['bhs', 'cae', 'gra', 'mw'],
    "saṃvartaka": ['bhs', 'cae', 'mw'],
    "saṃvartakalpa": ['mw'],
    "saṃvartakaḥ": ['ap90'],
    "saṃvartakin": ['ap90', 'mw'],
    "saṃvartakābhra": ['mw'],
    "saṃvartakāgni": ['mw'],
    "saṃvartam": ['mw'],
    "saṃvartamaruttīya": ['mw'],
    "saṃvartana": ['bhs', 'mw'],
    "saṃvartanaka": ['bhs'],
    "saṃvartanī": ['bhs', 'mw'],
    "saṃvartanīya": ['bhs', 'mw'],
    "saṃvartasmṛti": ['mw'],
    "saṃvartati": ['bhs'],
    "saṃvartavāta": ['mw'],
    "saṃvartaḥ": ['ap90'],
    "saṃvarti": ['mw'],
    "saṃvartikā": ['ap90', 'mw'],
    "saṃvartita": ['mw'],
    "saṃvartāgni": ['mw'],
    "saṃvartāmbhas": ['mw'],
    "saṃvartārka": ['mw'],
    "saṃvarya": ['mw'],
    "saṃvarṇ": ['mw'],
    "saṃvarṇana": ['bhs', 'cae', 'mw'],
    "saṃvarṇita": ['mw'],
    "saṃvarṇitamānasa": ['mw'],
    "saṃvarṣaṇa": ['mw'],
    "saṃvas": ['ap90', 'mw'],
    "saṃvasana": ['bhs', 'cae', 'gra', 'mw'],
    "saṃvasatha": ['mw'],
    "saṃvasathaḥ": ['ap90'],
    "saṃvasati": ['mw'],
    "saṃvastraya": ['mw'],
    "saṃvastraṇa": ['mw'],
    "saṃvasu": ['cae', 'gra', 'mw'],
    "saṃvasāna": ['mw'],
    "saṃvat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "saṃvatsam": ['cae', 'ddsa', 'gra', 'mw'],
    "saṃvatsara": ['cae', 'ddsa', 'gra', 'mw'],
    "saṃvatsarabhrami": ['mw'],
    "saṃvatsarabhukti": ['mw'],
    "saṃvatsarabhṛt": ['mw'],
    "saṃvatsarabhṛta": ['cae', 'mw'],
    "saṃvatsarabhṛtin": ['mw'],
    "saṃvatsarabhṛtokha": ['mw'],
    "saṃvatsarabrāhmaṇa": ['mw'],
    "saṃvatsaradīdhiti": ['mw'],
    "saṃvatsaradīkṣa": ['mw'],
    "saṃvatsaradīkṣita": ['mw'],
    "saṃvatsaradīpamāhātmya": ['mw'],
    "saṃvatsaradīpavratamāhātmya": ['mw'],
    "saṃvatsarakalpalatā": ['mw'],
    "saṃvatsarakara": ['mw'],
    "saṃvatsarakaumudī": ['mw'],
    "saṃvatsarakaustubha": ['mw'],
    "saṃvatsarakṛtya": ['mw'],
    "saṃvatsarakṛtyadīdhiti": ['mw'],
    "saṃvatsarakṛtyaprakāśa": ['mw'],
    "saṃvatsaramaya": ['mw'],
    "saṃvatsaramukhī": ['mw'],
    "saṃvatsaranirodha": ['cae', 'mw'],
    "saṃvatsaranirodhatas": ['mw'],
    "saṃvatsaraparvan": ['mw'],
    "saṃvatsaraphala": ['mw'],
    "saṃvatsaraprabarha": ['mw'],
    "saṃvatsaraprabhṛti": ['mw'],
    "saṃvatsarapradīpa": ['mw'],
    "saṃvatsaraprakaraṇa": ['mw'],
    "saṃvatsaraprakāśa": ['mw'],
    "saṃvatsarapratimā": ['mw'],
    "saṃvatsarapravalha": ['mw'],
    "saṃvatsarapravāta": ['mw'],
    "saṃvatsararaya": ['mw'],
    "saṃvatsararūpa": ['mw'],
    "saṃvatsarasahasra": ['cae', 'mw'],
    "saṃvatsarasammita": ['mw'],
    "saṃvatsarasattra": ['mw'],
    "saṃvatsarasattrabhāṣya": ['mw'],
    "saṃvatsarasattrasad": ['mw'],
    "saṃvatsarasvadita": ['mw'],
    "saṃvatsarasāta": ['mw'],
    "saṃvatsaratama": ['cae', 'mw'],
    "saṃvatsaravelā": ['mw'],
    "saṃvatsaravidha": ['mw'],
    "saṃvatsaravāsin": ['cae', 'mw'],
    "saṃvatsaraḥ": ['ap90'],
    "saṃvatsarika": ['mw'],
    "saṃvatsaropasatka": ['mw'],
    "saṃvatsaropāsita": ['mw'],
    "saṃvatsarotsavakalpalatā": ['mw'],
    "saṃvatsarotsavakālanirṇaya": ['mw'],
    "saṃvatsarādiphala": ['mw'],
    "saṃvatsarāntarhita": ['mw'],
    "saṃvatsarātyāsam": ['mw'],
    "saṃvatsarāvara": ['mw'],
    "saṃvatsarāyuṣa": ['cae', 'mw'],
    "saṃvatsarīya": ['cae', 'mw'],
    "saṃvatsarīṇa": ['cae', 'gra', 'mw'],
    "saṃvavṛtvas": ['mw'],
    "saṃvañc": ['mw'],
    "saṃvaṃh": ['mw'],
    "saṃve": ['mw'],
    "saṃveda": ['cae', 'mw'],
    "saṃvedana": ['cae', 'mw'],
    "saṃvedanaṃ": ['ap90'],
    "saṃvedanīya": ['mw'],
    "saṃvedaḥ": ['ap90'],
    "saṃvedhati": ['bhs'],
    "saṃvedin": ['bhs'],
    "saṃvedita": ['mw'],
    "saṃvedya": ['mw'],
    "saṃvedyatva": ['mw'],
    "saṃvedyatā": ['mw'],
    "saṃvega": ['bhs', 'cae', 'ddsa', 'mw'],
    "saṃvegadhāriṇī": ['bhs', 'mw'],
    "saṃvegaḥ": ['ap90'],
    "saṃvejana": ['mw'],
    "saṃvejanīya": ['bhs', 'mw'],
    "saṃvejayitavya": ['bhs'],
    "saṃvejita": ['bhs'],
    "saṃvep": ['mw'],
    "saṃvevidāna": ['mw'],
    "saṃveśa": ['cae', 'mw'],
    "saṃveśaka": ['mw'],
    "saṃveśana": ['cae', 'gra', 'mw'],
    "saṃveśanaṃ": ['ap90'],
    "saṃveśanīya": ['mw'],
    "saṃveśapati": ['mw'],
    "saṃveśaḥ": ['ap90'],
    "saṃveśin": ['mw'],
    "saṃveśya": ['mw'],
    "saṃveṣa": ['mw'],
    "saṃveṣṭ": ['mw'],
    "saṃveṣṭa": ['mw'],
    "saṃveṣṭana": ['mw'],
    "saṃvibhaj": ['ap90', 'mw'],
    "saṃvibhajana": ['mw'],
    "saṃvibhajanīya": ['mw'],
    "saṃvibhajya": ['mw'],
    "saṃvibhakta": ['mw'],
    "saṃvibhaktṛ": ['mw'],
    "saṃvibhā": ['mw'],
    "saṃvibhāga": ['cae', 'mw'],
    "saṃvibhāgamanas": ['mw'],
    "saṃvibhāgaruci": ['mw'],
    "saṃvibhāgarucitā": ['mw'],
    "saṃvibhāgaśīla": ['mw'],
    "saṃvibhāgaśīlavat": ['mw'],
    "saṃvibhāgaḥ": ['ap90'],
    "saṃvibhāgin": ['ap90', 'mw'],
    "saṃvibhāgitva": ['mw'],
    "saṃvibhāgitā": ['mw'],
    "saṃvibhāgya": ['mw'],
    "saṃvibhāgīkṛ": ['mw'],
    "saṃvibhājya": ['mw'],
    "saṃvibhāvya": ['mw'],
    "saṃvibhāṣ": ['mw'],
    "saṃvicetavya": ['mw'],
    "saṃvicint": ['mw'],
    "saṃvid": ['ap90', 'cae', 'gra', 'mw'],
    "saṃvida": ['mw'],
    "saṃviddha": ['mw'],
    "saṃvidh": ['cae', 'mw'],
    "saṃvidheya": ['mw'],
    "saṃvidhi": ['mw'],
    "saṃvidhitsu": ['mw'],
    "saṃvidhā": ['ap90', 'cae', 'mw'],
    "saṃvidhāna": ['cae', 'mw'],
    "saṃvidhānaka": ['mw'],
    "saṃvidhānakaṃ": ['ap90'],
    "saṃvidhānavat": ['mw'],
    "saṃvidhānaṃ": ['ap90'],
    "saṃvidhātavya": ['mw'],
    "saṃvidhātṛ": ['mw'],
    "saṃvidita": ['ap90', 'cae', 'mw'],
    "saṃviditam": ['mw'],
    "saṃvidvas": ['mw'],
    "saṃvidvyatikrama": ['mw'],
    "saṃvidya": ['cae', 'mw'],
    "saṃvidyate": ['bhs'],
    "saṃvidyut": ['mw'],
    "saṃvidā": ['ap90'],
    "saṃvidāna": ['cae', 'mw'],
    "saṃvidāta": ['ap90'],
    "saṃvighnita": ['mw'],
    "saṃvigna": ['ap90', 'cae', 'mw'],
    "saṃvignamānasa": ['mw'],
    "saṃvihas": ['mw'],
    "saṃviheṭhayati": ['bhs'],
    "saṃvihita": ['mw'],
    "saṃvihval": ['mw'],
    "saṃvihṛ": ['mw'],
    "saṃvij": ['ap90', 'mw'],
    "saṃvijñā": ['mw'],
    "saṃvijñāna": ['cae', 'ddsa', 'mw'],
    "saṃvijñānabhūta": ['mw'],
    "saṃvijñāta": ['ap90', 'mw'],
    "saṃvikta": ['mw'],
    "saṃviktaṃ": ['ap90'],
    "saṃvilaṅgh": ['mw'],
    "saṃvimarda": ['mw'],
    "saṃvimaṭṭha": ['bhs'],
    "saṃvimṛś": ['mw'],
    "saṃvind": ['mw'],
    "saṃvinmaya": ['mw'],
    "saṃvinī": ['mw'],
    "saṃvip": ['mw'],
    "saṃvirāj": ['mw'],
    "saṃvisṛj": ['mw'],
    "saṃvitark": ['mw'],
    "saṃvitka": ['mw'],
    "saṃvitprakāśa": ['mw'],
    "saṃvitsiddhi": ['mw'],
    "saṃvitti": ['cae', 'mw'],
    "saṃvittiḥ": ['ap90'],
    "saṃvivardhayiṣu": ['mw'],
    "saṃvivyāna": ['mw'],
    "saṃvivṛdh": ['mw'],
    "saṃviś": ['ap90', 'mw'],
    "saṃviśvasta": ['bhs'],
    "saṃviṣ": ['mw'],
    "saṃviṣā": ['mw'],
    "saṃviṣṭa": ['ap90', 'mw'],
    "saṃvlaya": ['mw'],
    "saṃvlī": ['mw'],
    "saṃvlīna": ['mw'],
    "saṃvoḍhṛ": ['mw'],
    "saṃvraj": ['mw'],
    "saṃvraśc": ['mw'],
    "saṃvraścam": ['cae', 'mw'],
    "saṃvrāta": ['mw'],
    "saṃvuvūrṣu": ['mw'],
    "saṃvyac": ['mw'],
    "saṃvyadh": ['mw'],
    "saṃvyapāśrita": ['mw'],
    "saṃvyath": ['mw'],
    "saṃvyavaharaṇa": ['mw'],
    "saṃvyavahita": ['mw'],
    "saṃvyavahāra": ['cae', 'mw'],
    "saṃvyavahārate": ['bhs'],
    "saṃvyavahāravat": ['mw'],
    "saṃvyavahāraḥ": ['ap90'],
    "saṃvyavahārika": ['mw'],
    "saṃvyavahārin": ['bhs'],
    "saṃvyavahārya": ['mw'],
    "saṃvyavahṛ": ['mw'],
    "saṃvyavasya": ['ddsa', 'mw'],
    "saṃvye": ['ap90', 'mw'],
    "saṃvyādha": ['cae', 'mw'],
    "saṃvyāna": ['cae', 'mw'],
    "saṃvyānaṃ": ['ap90'],
    "saṃvyāpya": ['mw'],
    "saṃvyātha": ['mw'],
    "saṃvyāya": ['mw'],
    "saṃvyāyita": ['mw'],
    "saṃvyūha": ['mw'],
    "saṃvyūhima": ['mw'],
    "saṃvyūḍha": ['mw'],
    "saṃvā": ['mw'],
    "saṃvāc": ['cae', 'gra', 'mw'],
    "saṃvācaka": ['bhs'],
    "saṃvācya": ['bhs', 'mw'],
    "saṃvāda": ['cae', 'gra', 'mw'],
    "saṃvādaka": ['mw'],
    "saṃvādana": ['mw'],
    "saṃvādaḥ": ['ap90'],
    "saṃvādha": ['mw'],
    "saṃvādin": ['ap90', 'cae', 'mw'],
    "saṃvādita": ['mw'],
    "saṃvāditā": ['mw'],
    "saṃvāditṛ": ['mw'],
    "saṃvādya": ['mw'],
    "saṃvādābhijayana": ['mw'],
    "saṃvāha": ['cae', 'mw'],
    "saṃvāhaka": ['cae', 'mw'],
    "saṃvāhakaḥ": ['ap90'],
    "saṃvāhana": ['cae', 'mw'],
    "saṃvāhanaṃ": ['ap90'],
    "saṃvāhaḥ": ['ap90'],
    "saṃvāhin": ['mw'],
    "saṃvāhinī": ['mw'],
    "saṃvāhita": ['bhs'],
    "saṃvāhitavya": ['mw'],
    "saṃvāhya": ['mw'],
    "saṃvāpa": ['mw'],
    "saṃvāra": ['bhs', 'mw'],
    "saṃvārayiṣṇu": ['mw'],
    "saṃvāraḥ": ['ap90'],
    "saṃvāraṇa": ['mw'],
    "saṃvārya": ['cae', 'mw'],
    "saṃvāsa": ['cae', 'mw'],
    "saṃvāsana": ['bhs'],
    "saṃvāsaḥ": ['ap90'],
    "saṃvāsika": ['bhs'],
    "saṃvāsin": ['cae', 'mw'],
    "saṃvāsita": ['ap90', 'mw'],
    "saṃvāsya": ['bhs'],
    "saṃvāvadūka": ['mw'],
    "saṃvāñch": ['mw'],
    "saṃvāś": ['mw'],
    "saṃvāṭikā": ['mw'],
    "saṃvīj": ['mw'],
    "saṃvīkṣ": ['mw'],
    "saṃvīkṣaṇa": ['mw'],
    "saṃvīkṣaṇaṃ": ['ap90'],
    "saṃvīta": ['ap90', 'cae', 'mw'],
    "saṃvītarāga": ['mw'],
    "saṃvītin": ['mw'],
    "saṃvītāṅga": ['mw'],
    "saṃvṛ": ['ap90', 'mw'],
    "saṃvṛddha": ['ap90', 'cae', 'mw'],
    "saṃvṛddhi": ['cae', 'mw'],
    "saṃvṛdh": ['ap90', 'mw'],
    "saṃvṛh": ['mw'],
    "saṃvṛj": ['cae', 'ddsa', 'gra', 'mw'],
    "saṃvṛkta": ['ap90', 'mw'],
    "saṃvṛktadhṛṣṇu": ['gra', 'mw'],
    "saṃvṛt": ['ap90', 'cae', 'mw'],
    "saṃvṛta": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃvṛtamantra": ['mw'],
    "saṃvṛtamantratā": ['mw'],
    "saṃvṛtasaṃvārya": ['cae', 'mw'],
    "saṃvṛtatva": ['mw'],
    "saṃvṛtatā": ['mw'],
    "saṃvṛti": ['bhs', 'cae', 'mw'],
    "saṃvṛtimat": ['mw'],
    "saṃvṛtiḥ": ['ap90'],
    "saṃvṛtta": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃvṛttateja": ['bhs'],
    "saṃvṛtti": ['cae', 'mw'],
    "saṃvṛttiḥ": ['ap90'],
    "saṃvṛtākāra": ['mw'],
    "saṃvṛṃh": ['mw'],
    "saṃvṛṣ": ['mw'],
    "saṃya": ['mw'],
    "saṃyad": ['mw'],
    "saṃyadhāpināma": ['bhs'],
    "saṃyadvara": ['mw'],
    "saṃyadvasu": ['mw'],
    "saṃyadvāma": ['mw'],
    "saṃyadvīra": ['gra', 'mw'],
    "saṃyagavabodhi": ['bhs'],
    "saṃyaj": ['ap90', 'mw'],
    "saṃyam": ['ap90', 'mw'],
    "saṃyama": ['cae', 'mw'],
    "saṃyamadhana": ['cae', 'mw'],
    "saṃyamaka": ['mw'],
    "saṃyamana": ['cae', 'mw'],
    "saṃyamanaṃ": ['ap90'],
    "saṃyamanī": ['bhs', 'mw'],
    "saṃyamapuṇyatīrtha": ['mw'],
    "saṃyamavat": ['mw'],
    "saṃyamaḥ": ['ap90'],
    "saṃyamin": ['ap90', 'cae', 'mw'],
    "saṃyamināmamālikā": ['mw'],
    "saṃyaminī": ['mw'],
    "saṃyaminīpati": ['mw'],
    "saṃyamita": ['ap90', 'cae', 'mw'],
    "saṃyamitā": ['mw'],
    "saṃyamya": ['mw'],
    "saṃyamāgni": ['mw'],
    "saṃyamāmbhas": ['mw'],
    "saṃyantavya": ['mw'],
    "saṃyantrita": ['mw'],
    "saṃyantṛ": ['cae', 'mw'],
    "saṃyas": ['mw'],
    "saṃyat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "saṃyata": ['ap90', 'cae', 'mw'],
    "saṃyatacetas": ['mw'],
    "saṃyataka": ['mw'],
    "saṃyatamaithuna": ['mw'],
    "saṃyatamukha": ['mw'],
    "saṃyatamānasa": ['mw'],
    "saṃyataprāṇa": ['mw'],
    "saṃyatavastra": ['mw'],
    "saṃyatavat": ['mw'],
    "saṃyatavāc": ['mw'],
    "saṃyatendriya": ['cae', 'mw'],
    "saṃyathīdaṃ": ['bhs'],
    "saṃyati": ['mw'],
    "saṃyatin": ['mw'],
    "saṃyatopaskara": ['mw'],
    "saṃyatta": ['ap90', 'cae', 'mw'],
    "saṃyattva": ['mw'],
    "saṃyatvara": ['ap90', 'mw'],
    "saṃyatāhāra": ['cae', 'mw'],
    "saṃyatākṣa": ['mw'],
    "saṃyatātman": ['mw'],
    "saṃyatāñjali": ['mw'],
    "saṃyatī": ['mw'],
    "saṃyavana": ['mw'],
    "saṃyaḥ": ['ap90'],
    "saṃyaṃtṛ": ['ap90'],
    "saṃyoddhavya": ['mw'],
    "saṃyoddhṛ": ['mw'],
    "saṃyodha": ['mw'],
    "saṃyodhakaṇṭaka": ['mw'],
    "saṃyoga": ['bhs', 'cae', 'ddsa', 'mw'],
    "saṃyogamantra": ['mw'],
    "saṃyogapṛthaktva": ['mw'],
    "saṃyogaviruddha": ['mw'],
    "saṃyogaḥ": ['ap90'],
    "saṃyogin": ['ap90', 'cae', 'ddsa', 'mw'],
    "saṃyogita": ['mw'],
    "saṃyogitva": ['mw'],
    "saṃyojaka": ['mw'],
    "saṃyojana": ['bhs', 'cae', 'mw'],
    "saṃyojanaṃ": ['ap90'],
    "saṃyojayitavya": ['mw'],
    "saṃyojita": ['mw'],
    "saṃyojitakarayugala": ['mw'],
    "saṃyojya": ['mw'],
    "saṃyu": ['mw'],
    "saṃyudh": ['mw'],
    "saṃyuga": ['cae', 'ddsa', 'mw'],
    "saṃyugagoṣpada": ['mw'],
    "saṃyugamūrdhan": ['mw'],
    "saṃyugaḥ": ['ap90'],
    "saṃyuj": ['ap90', 'cae', 'mw'],
    "saṃyukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "saṃyuktaka": ['bhs'],
    "saṃyuktam": ['mw'],
    "saṃyuktasamavetasamavāya": ['mw'],
    "saṃyuktasamavāya": ['mw'],
    "saṃyuktasaṃcayapiṭaka": ['mw'],
    "saṃyuktasaṃyoga": ['mw'],
    "saṃyuktā": ['mw'],
    "saṃyuktābhidharmaśāstra": ['mw'],
    "saṃyuktāgama": ['bhs', 'mw'],
    "saṃyuktākṣara": ['mw'],
    "saṃyup": ['mw'],
    "saṃyuta": ['ap90', 'cae', 'mw'],
    "saṃyuti": ['mw'],
    "saṃyuyutsu": ['mw'],
    "saṃyuyūṣu": ['mw'],
    "saṃyā": ['ap90', 'mw'],
    "saṃyāc": ['mw'],
    "saṃyāja": ['mw'],
    "saṃyājana": ['mw'],
    "saṃyājya": ['cae', 'mw'],
    "saṃyājyā": ['mw'],
    "saṃyāma": ['ap90', 'mw'],
    "saṃyāmavat": ['mw'],
    "saṃyāna": ['cae', 'mw'],
    "saṃyānaḥ": ['ap90'],
    "saṃyānī": ['mw'],
    "saṃyāsa": ['cae', 'mw'],
    "saṃyāta": ['mw'],
    "saṃyāti": ['mw'],
    "saṃyātrika": ['mw'],
    "saṃyātrā": ['ap90', 'mw'],
    "saṃyāva": ['mw'],
    "saṃyāvaḥ": ['ap90'],
    "saṃśabd": ['mw'],
    "saṃśabda": ['mw'],
    "saṃśabdana": ['cae', 'mw'],
    "saṃśabdanaṃ": ['ap90'],
    "saṃśabdaḥ": ['ap90'],
    "saṃśabdita": ['bhs'],
    "saṃśabdya": ['mw'],
    "saṃśad": ['mw'],
    "saṃśak": ['mw'],
    "saṃśakalā": ['mw'],
    "saṃśam": ['ap90', 'mw'],
    "saṃśama": ['cae', 'mw'],
    "saṃśamaka": ['bhs'],
    "saṃśamana": ['cae', 'mw'],
    "saṃśamanīya": ['mw'],
    "saṃśap": ['mw'],
    "saṃśapta": ['cae', 'mw'],
    "saṃśaptaka": ['cae', 'ddsa', 'mw'],
    "saṃśaptakavadhaparvan": ['mw'],
    "saṃśaptakaḥ": ['ap90'],
    "saṃśaptavat": ['mw'],
    "saṃśara": ['cae', 'mw'],
    "saṃśaraṇa": ['mw'],
    "saṃśaraṇaṃ": ['ap90'],
    "saṃśaya": ['bhs', 'cae', 'ddsa', 'mw'],
    "saṃśayaccheda": ['mw'],
    "saṃśayacchedin": ['mw'],
    "saṃśayacchedya": ['mw'],
    "saṃśayagata": ['mw'],
    "saṃśayakara": ['cae', 'mw'],
    "saṃśayakāraṇārthāpattipūrvapakṣarahasya": ['mw'],
    "saṃśayakāraṇārthāpattirahasya": ['mw'],
    "saṃśayapakṣatārahasya": ['mw'],
    "saṃśayapakṣatāvāda": ['mw'],
    "saṃśayaparīkṣā": ['mw'],
    "saṃśayasama": ['mw'],
    "saṃśayasamaprakaraṇa": ['mw'],
    "saṃśayastha": ['mw'],
    "saṃśayatattvanirūpaṇa": ['mw'],
    "saṃśayavāda": ['mw'],
    "saṃśayavādārtha": ['mw'],
    "saṃśayaḥ": ['ap90'],
    "saṃśayin": ['mw'],
    "saṃśayita": ['ap90', 'cae', 'ddsa', 'mw'],
    "saṃśayitavya": ['mw'],
    "saṃśayitṛ": ['mw'],
    "saṃśayocchedin": ['mw'],
    "saṃśayopamā": ['cae', 'mw'],
    "saṃśayopeta": ['mw'],
    "saṃśayākṣepa": ['mw'],
    "saṃśayālu": ['bhs', 'cae', 'ddsa', 'mw'],
    "saṃśayāna": ['ap90'],
    "saṃśayānumiti": ['mw'],
    "saṃśayānumitirahasya": ['mw'],
    "saṃśayāpanna": ['mw'],
    "saṃśayāpannamānasa": ['mw'],
    "saṃśayātiśaya": ['mw'],
    "saṃśayātmaka": ['mw'],
    "saṃśayātman": ['cae', 'mw'],
    "saṃśayāvaha": ['cae', 'ddsa', 'mw'],
    "saṃśaṃs": ['mw'],
    "saṃśaṃsā": ['mw'],
    "saṃśaṅk": ['mw'],
    "saṃścat": ['ap90', 'mw'],
    "saṃścāya": ['mw'],
    "saṃśikṣ": ['mw'],
    "saṃśis": ['cae', 'mw'],
    "saṃśita": ['ap90', 'cae', 'mw'],
    "saṃśitatapas": ['mw'],
    "saṃśitavrata": ['cae', 'mw'],
    "saṃśitavāc": ['cae', 'mw'],
    "saṃśiti": ['cae', 'mw'],
    "saṃśitātman": ['mw'],
    "saṃśiñj": ['mw'],
    "saṃśiśariṣu": ['mw'],
    "saṃśiśrīṣu": ['mw'],
    "saṃśiśvan": ['gra', 'mw'],
    "saṃśiṣṭa": ['cae', 'mw'],
    "saṃśleṣa": ['cae', 'mw'],
    "saṃśleṣayati": ['bhs'],
    "saṃśleṣaḥ": ['ap90'],
    "saṃśleṣaṇa": ['cae', 'mw'],
    "saṃśleṣaṇaṃ": ['ap90'],
    "saṃśleṣin": ['cae', 'mw'],
    "saṃśleṣita": ['mw'],
    "saṃśliṣ": ['ap90', 'cae', 'mw'],
    "saṃśliṣṭa": ['ap90', 'cae', 'mw'],
    "saṃśliṣṭakarman": ['mw'],
    "saṃśliṣṭaśarīrakārin": ['mw'],
    "saṃślok": ['mw'],
    "saṃślāgh": ['mw'],
    "saṃśo": ['mw'],
    "saṃśobhita": ['mw'],
    "saṃśodhana": ['cae', 'mw'],
    "saṃśodhanaśamanīya": ['mw'],
    "saṃśodhanaṃ": ['ap90'],
    "saṃśodhita": ['mw'],
    "saṃśoka": ['mw'],
    "saṃśokaja": ['mw'],
    "saṃśoṣa": ['cae', 'mw'],
    "saṃśoṣaka": ['bhs'],
    "saṃśoṣaṇa": ['cae', 'mw'],
    "saṃśoṣin": ['cae', 'mw'],
    "saṃśoṣita": ['mw'],
    "saṃśraddhā": ['mw'],
    "saṃśrava": ['cae', 'mw'],
    "saṃśravas": ['mw'],
    "saṃśravasaḥsāma": ['mw'],
    "saṃśravaḥ": ['ap90'],
    "saṃśravaṇa": ['mw'],
    "saṃśravaṇaṃ": ['ap90'],
    "saṃśraya": ['cae', 'mw'],
    "saṃśrayakārita": ['mw'],
    "saṃśrayaḥ": ['ap90'],
    "saṃśrayaṇa": ['mw'],
    "saṃśrayaṇīya": ['mw'],
    "saṃśrayaṇīyatā": ['mw'],
    "saṃśrayin": ['cae', 'mw'],
    "saṃśrayitavya": ['mw'],
    "saṃśrayāt": ['mw'],
    "saṃśreṣiṇa": ['mw'],
    "saṃśri": ['ap90', 'mw'],
    "saṃśrita": ['ap90', 'cae', 'mw'],
    "saṃśritavat": ['mw'],
    "saṃśritavya": ['mw'],
    "saṃśritānurāga": ['mw'],
    "saṃśru": ['ap90', 'mw'],
    "saṃśruta": ['ap90', 'cae', 'mw'],
    "saṃśrutya": ['mw'],
    "saṃśrānta": ['cae', 'mw'],
    "saṃśrāva": ['mw'],
    "saṃśrāvaka": ['mw'],
    "saṃśrāvam": ['mw'],
    "saṃśrāvayitṛ": ['mw'],
    "saṃśrāvayitṛmat": ['mw'],
    "saṃśrāvita": ['mw'],
    "saṃśrāvitaka": ['bhs'],
    "saṃśrāvya": ['mw'],
    "saṃśrī": ['mw'],
    "saṃśubh": ['mw'],
    "saṃśuc": ['mw'],
    "saṃśuddha": ['ap90', 'bhs', 'cae', 'mw'],
    "saṃśuddhakilbiṣa": ['mw'],
    "saṃśuddhi": ['cae', 'mw'],
    "saṃśuddhiḥ": ['ap90'],
    "saṃśudh": ['ap90', 'mw'],
    "saṃśuṣ": ['mw'],
    "saṃśuṣka": ['cae', 'mw'],
    "saṃśuṣkamāṃsatvaksnāyu": ['mw'],
    "saṃśuṣkāsya": ['mw'],
    "saṃśvat": ['ap90', 'mw'],
    "saṃśvāyin": ['mw'],
    "saṃśyai": ['mw'],
    "saṃśyāna": ['ap90', 'mw'],
    "saṃśāna": ['mw'],
    "saṃśānta": ['cae', 'mw'],
    "saṃśānti": ['cae', 'mw'],
    "saṃśāruka": ['mw'],
    "saṃśās": ['mw'],
    "saṃśāsana": ['cae', 'mw'],
    "saṃśāsita": ['mw'],
    "saṃśī": ['ap90', 'mw'],
    "saṃśīlana": ['cae', 'mw'],
    "saṃśīlika": ['bhs'],
    "saṃśīna": ['mw'],
    "saṃśīta": ['mw'],
    "saṃśīti": ['mw'],
    "saṃśītiḥ": ['ap90'],
    "saṃśūna": ['cae', 'mw'],
    "saṃśṛkhalā": ['bhs'],
    "saṃśṛṅgī": ['mw'],
    "saṃśṝ": ['mw'],
    "saṃḍa": ['ap90'],
    "saṃḍiśa": ['mw'],
    "saṃḍiśaḥ": ['ap90'],
    "saṃḍīna": ['mw'],
    "saṃḍīnaṃ": ['ap90'],
    "saṃḍīnoḍḍīna": ['mw'],
    "saṃḍīvin": ['mw'],
    "saṃṣṭhula": ['mw'],
    "saṃṭaṅka": ['mw'],
    "saṅga": ['cped', 'ddsa', 'mw'],
    "saṅgacchati": ['cped'],
    "saṅgacchi": ['cped'],
    "saṅgaguptasūnu": ['mw'],
    "saṅgaha": ['cped'],
    "saṅgahetvā": ['cped'],
    "saṅgahita": ['cped'],
    "saṅgakara": ['mw'],
    "saṅgantvā": ['cped'],
    "saṅgara": ['ddsa'],
    "saṅgarahita": ['mw'],
    "saṅgata": ['cped', 'ddsa'],
    "saṅgatala": ['mw'],
    "saṅgatha": ['ddsa'],
    "saṅgati": ['cped', 'ddsa'],
    "saṅgatyāga": ['mw'],
    "saṅgavant": ['cae'],
    "saṅgavarjita": ['cae', 'mw'],
    "saṅgavicyuti": ['mw'],
    "saṅgayha": ['cped'],
    "saṅgaṇanā": ['ddsa'],
    "saṅgaṇhanta": ['cped'],
    "saṅgaṇhi": ['cped'],
    "saṅgaṇhitvā": ['cped'],
    "saṅgaṇhāti": ['cped'],
    "saṅgaṇikā": ['cped'],
    "saṅgaṇikārata": ['cped'],
    "saṅgaṇikārāma": ['cped'],
    "saṅgaṇikārāmatā": ['cped'],
    "saṅgaṭa": ['ddsa', 'mw'],
    "saṅgha": ['cped', 'ddsa'],
    "saṅghabhatta": ['cped'],
    "saṅghabheda": ['cped'],
    "saṅghabhedaka": ['cped'],
    "saṅghagata": ['cped'],
    "saṅghakamma": ['cped'],
    "saṅghamānaka": ['cped'],
    "saṅghatthera": ['cped'],
    "saṅghaṭesi": ['cped'],
    "saṅghaṭeti": ['cped'],
    "saṅghaṭetvā": ['cped'],
    "saṅghaṭita": ['cped'],
    "saṅghaṭṭana": ['cped'],
    "saṅghika": ['cped'],
    "saṅghuṭṭha": ['cped'],
    "saṅghārāma": ['ddsa'],
    "saṅghāta": ['cped', 'ddsa'],
    "saṅghāṇaka": ['mw'],
    "saṅghāṭi": ['cped'],
    "saṅghī": ['cped'],
    "saṅghībhū": ['ddsa'],
    "saṅgika": ['ddsa', 'mw'],
    "saṅgin": ['cae', 'ddsa', 'mw'],
    "saṅgiya": ['mw'],
    "saṅgopeti": ['cped'],
    "saṅgopita": ['cped'],
    "saṅgraha": ['ddsa'],
    "saṅgrāha": ['ddsa'],
    "saṅgrāma": ['ddsa'],
    "saṅgupti": ['ddsa'],
    "saṅgāha": ['cped'],
    "saṅgāhaka": ['cped'],
    "saṅgāma": ['cped'],
    "saṅgāmesi": ['cped'],
    "saṅgāmeti": ['cped'],
    "saṅgāmetvā": ['cped'],
    "saṅgāmita": ['cped'],
    "saṅgāmāvacara": ['cped'],
    "saṅgāyati": ['cped'],
    "saṅgāyi": ['cped'],
    "saṅgāyitvā": ['cped'],
    "saṅgīta": ['cped', 'ddsa'],
    "saṅgīti": ['cped'],
    "saṅgītikāraka": ['cped'],
    "saṅgṛhīti": ['ddsa'],
    "saṅkala": ['bhs'],
    "saṅkalana": ['cped'],
    "saṅkalpa": ['ddsa'],
    "saṅkama": ['cped'],
    "saṅkamana": ['cped'],
    "saṅkamati": ['cped'],
    "saṅkami": ['cped'],
    "saṅkamitvā": ['cped'],
    "saṅkamma": ['cped'],
    "saṅkampeti": ['cped'],
    "saṅkampi": ['cped'],
    "saṅkampita": ['cped'],
    "saṅkampitvā": ['cped'],
    "saṅkamāna": ['cped'],
    "saṅkanta": ['cped'],
    "saṅkantati": ['cped'],
    "saṅkanti": ['cped'],
    "saṅkantika": ['cped'],
    "saṅkantikaroga": ['cped'],
    "saṅkantita": ['cped'],
    "saṅkappa": ['cped'],
    "saṅkappesi": ['cped'],
    "saṅkappeti": ['cped'],
    "saṅkappetvā": ['cped'],
    "saṅkappita": ['cped'],
    "saṅkara": ['cped'],
    "saṅkasuka": ['ddsa'],
    "saṅkasāyati": ['cped'],
    "saṅkati": ['cped'],
    "saṅkatitvā": ['cped'],
    "saṅkayita": ['cped'],
    "saṅkaḍḍhati": ['cped'],
    "saṅkaḍḍhi": ['cped'],
    "saṅkaḍḍhitvā": ['cped'],
    "saṅkaṭa": ['ddsa'],
    "saṅkaṭīra": ['cped'],
    "saṅketa": ['cped', 'ddsa'],
    "saṅketakamma": ['cped'],
    "saṅketavākya": ['ddsa'],
    "saṅketaya": ['ddsa'],
    "saṅketodyāna": ['ddsa'],
    "saṅketīkṛ": ['ddsa'],
    "saṅkha": ['cped'],
    "saṅkhadhama": ['cped'],
    "saṅkhakuṭṭhī": ['cped'],
    "saṅkhalikā": ['cped'],
    "saṅkhamedhī": ['bhs'],
    "saṅkhamuṇḍika": ['cped'],
    "saṅkharaṇa": ['cped'],
    "saṅkhari": ['cped'],
    "saṅkharitvā": ['cped'],
    "saṅkharonta": ['cped'],
    "saṅkharoti": ['cped'],
    "saṅkhata": ['cped'],
    "saṅkhathāla": ['cped'],
    "saṅkhaya": ['cped'],
    "saṅkhepa": ['cped'],
    "saṅkheyya": ['cped'],
    "saṅkhipamāna": ['cped'],
    "saṅkhipanta": ['cped'],
    "saṅkhipati": ['cped'],
    "saṅkhipi": ['cped'],
    "saṅkhipitabba": ['cped'],
    "saṅkhipituṁ": ['cped'],
    "saṅkhipitvā": ['cped'],
    "saṅkhitta": ['cped'],
    "saṅkhobha": ['cped'],
    "saṅkhobhenta": ['cped'],
    "saṅkhobhesi": ['cped'],
    "saṅkhobheti": ['cped'],
    "saṅkhobhetvā": ['cped'],
    "saṅkhobhita": ['cped'],
    "saṅkhubhati": ['cped'],
    "saṅkhubhi": ['cped'],
    "saṅkhubhita": ['cped'],
    "saṅkhubhitvā": ['cped'],
    "saṅkhya": ['ddsa'],
    "saṅkhyeya": ['ddsa'],
    "saṅkhyā": ['cped', 'ddsa'],
    "saṅkhyāna": ['ddsa'],
    "saṅkhyānāman": ['ddsa'],
    "saṅkhyāta": ['ddsa'],
    "saṅkhyātiga": ['ddsa'],
    "saṅkhyāṅkabindu": ['ddsa'],
    "saṅkhā": ['cped'],
    "saṅkhādati": ['cped'],
    "saṅkhādi": ['cped'],
    "saṅkhādita": ['cped'],
    "saṅkhāditvā": ['cped'],
    "saṅkhāna": ['cped'],
    "saṅkhāra": ['cped'],
    "saṅkhāradukkha": ['cped'],
    "saṅkhārakkhandha": ['cped'],
    "saṅkhāraloka": ['cped'],
    "saṅkhāta": ['cped'],
    "saṅkhāya": ['cped'],
    "saṅki": ['cped'],
    "saṅkipa": ['cped'],
    "saṅkita": ['cped'],
    "saṅkittana": ['cped'],
    "saṅkitvā": ['cped'],
    "saṅkiṇṇa": ['cped'],
    "saṅkoca": ['cped', 'ddsa'],
    "saṅkocesi": ['cped'],
    "saṅkoceti": ['cped'],
    "saṅkocita": ['cped'],
    "saṅkranda": ['ddsa'],
    "saṅku": ['cped', 'mw'],
    "saṅkucana": ['cped'],
    "saṅkucati": ['cped'],
    "saṅkuci": ['cped'],
    "saṅkucita": ['cped'],
    "saṅkucitvā": ['cped'],
    "saṅkula": ['cped'],
    "saṅkupatha": ['cped'],
    "saṅkupita": ['cped'],
    "saṅkuṭita": ['cped'],
    "saṅkā": ['cae', 'ddsa', 'gra'],
    "saṅkāra": ['cped', 'ddsa'],
    "saṅkāracoḷa": ['cped'],
    "saṅkārakūṭa": ['cped'],
    "saṅkāraṭṭhāna": ['cped'],
    "saṅkāsa": ['cped'],
    "saṅkāsanā": ['cped'],
    "saṅkāyati": ['cped'],
    "saṅkāyi": ['cped'],
    "saṅkī": ['cped'],
    "saṅkīyati": ['cped'],
    "saṇahāṣa": ['mw'],
    "saṇasūtraṃ": ['ap90'],
    "saṇati": ['cped'],
    "saṇatūla": ['mw'],
    "saṇha": ['cped'],
    "saṇhakaraṇī": ['cped'],
    "saṇhesi": ['cped'],
    "saṇheti": ['cped'],
    "saṇhetvā": ['cped'],
    "saṇhita": ['cped'],
    "saṇi": ['mw'],
    "saṇḍa": ['cped', 'mw'],
    "saṇḍhikā": ['mw'],
    "saṇḍāsa": ['cped'],
    "saṇḍīvin": ['ddsa'],
    "saṇṭhahana": ['cped'],
    "saṇṭhahanta": ['cped'],
    "saṇṭhahitvā": ['cped'],
    "saṇṭhapana": ['cped'],
    "saṇṭhapesi": ['cped'],
    "saṇṭhapeti": ['cped'],
    "saṇṭhapetvā": ['cped'],
    "saṇṭhita": ['cped'],
    "saṇṭhiti": ['cped'],
    "saṇṭhāsi": ['cped'],
    "saṇṭhāti": ['cped'],
    "saṛkṣa": ['mw'],
    "saṛṇa": ['cae', 'mw'],
    "saṛṣika": ['cae', 'mw'],
    "saṛṣirājanya": ['mw'],
    "saṣki": ['mw'],
    "saṣkila": ['mw'],
    "saṣoḍaśika": ['mw'],
    "saṣṭubh": ['cae', 'mw'],
    "saṭ": ['ap90', 'mw'],
    "saṭa": ['ddsa', 'mw'],
    "saṭaṃ": ['ap90'],
    "saṭaṃkāra": ['mw'],
    "saṭh": ['ap90', 'mw'],
    "saṭha": ['cped'],
    "saṭhatā": ['cped'],
    "saṭhaḥ": ['bhs'],
    "saṭhi": ['ap90'],
    "saṭhī": ['mw'],
    "saṭi": ['mw'],
    "saṭiḥ": ['ap90'],
    "saṭvā": ['ap90', 'mw'],
    "saṭā": ['cae', 'mw'],
    "saṭāla": ['cae', 'ddsa', 'mw'],
    "saṭālu": ['cae', 'ddsa', 'mw'],
    "saṭāpāṭala": ['mw'],
    "saṭāṅka": ['mw'],
    "saṭīka": ['ap90', 'mw'],
    "saṭṭ": ['ap90', 'mw'],
    "saṭṭa": ['mw'],
    "saṭṭaka": ['mw'],
    "saṭṭakaṃ": ['ap90'],
    "saṭṭakaṭīkā": ['mw'],
    "saṭṭaya": ['mw'],
    "saṭṭayavyākhyā": ['mw'],
    "saṭṭha": ['cped'],
    "saṭṭhi": ['cped'],
    "saṭṭhihāyana": ['cped'],
    "saṭṭhuṁ": ['cped'],
    "sbṛ": ['ap90'],
    "sbṝ": ['mw'],
    "se": ['ddsa', 'mw'],
    "sebhya": ['mw'],
    "seca": ['mw'],
    "secaka": ['ap90', 'ddsa', 'mw'],
    "secana": ['cae', 'cped', 'mw'],
    "secanaghaṭa": ['cae', 'mw'],
    "secanaka": ['mw'],
    "secanaṃ": ['ap90'],
    "secanī": ['ap90', 'mw'],
    "secanīya": ['mw'],
    "secita": ['mw'],
    "secya": ['mw'],
    "secālin": ['mw'],
    "seda": ['cped'],
    "sedaka": ['cped'],
    "sedana": ['cped'],
    "seddhavya": ['mw'],
    "sedesi": ['cped'],
    "sedeti": ['cped'],
    "sedetvā": ['cped'],
    "sedha": ['cae', 'mw'],
    "sedhaka": ['mw'],
    "sedhana": ['mw'],
    "sedhanīya": ['mw'],
    "sedhaḥ": ['ap90'],
    "sedhā": ['cae', 'ddsa', 'mw'],
    "sedi": ['cae', 'ddsa', 'mw'],
    "sedita": ['cped'],
    "sedivas": ['ap90', 'mw'],
    "seduka": ['mw'],
    "sedāvakkhitta": ['cped'],
    "segava": ['mw'],
    "sehana": ['mw'],
    "sehloka": ['mw'],
    "sehnoka": ['mw'],
    "sehu": ['cae', 'mw'],
    "sehuṇḍa": ['mw'],
    "sehuṇḍā": ['mw'],
    "sehāna": ['mw'],
    "sek": ['ap90', 'mw'],
    "seka": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sekabhājana": ['mw'],
    "sekamiśrānna": ['mw'],
    "sekandhara": ['mw'],
    "sekandharapurī": ['mw'],
    "sekapātra": ['mw'],
    "sekayati": ['bhs'],
    "sekaḥ": ['ap90'],
    "sekaṃdhara": ['mw'],
    "sekaṃdharapurī": ['mw'],
    "sekha": ['cped'],
    "sekhara": ['cped'],
    "sekhayati": ['bhs'],
    "sekhiya": ['cped'],
    "sekima": ['mw'],
    "sekimaṃ": ['ap90'],
    "sekkha": ['cped'],
    "sektavya": ['mw'],
    "sektra": ['mw'],
    "sektraṃ": ['ap90'],
    "sektṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sekānta": ['mw'],
    "sel": ['ap90', 'mw'],
    "sela": ['bhs', 'cped', 'ddsa', 'mw'],
    "selaga": ['cae', 'ddsa', 'mw'],
    "selaka": ['bhs'],
    "selamaya": ['cped'],
    "seleyya": ['cped'],
    "selhāra": ['mw'],
    "selisa": ['mw'],
    "sella": ['mw'],
    "selu": ['bhs', 'ddsa', 'mw'],
    "selyapura": ['ddsa'],
    "selā": ['bhs'],
    "semantikā": ['mw'],
    "semantī": ['mw'],
    "semaṃtī": ['ap90'],
    "semha": ['cped'],
    "semhika": ['cped'],
    "semāna": ['cped'],
    "semānaka": ['cped'],
    "sena": ['ap90', 'cped', 'ddsa', 'mw'],
    "senahan": ['mw'],
    "senajit": ['cae', 'mw'],
    "senaka": ['cped', 'mw'],
    "senakula": ['mw'],
    "senarāja": ['bhs'],
    "senaskandha": ['mw'],
    "senaya": ['mw'],
    "sendra": ['cae', 'ddsa', 'mw'],
    "sendracāpa": ['cae', 'mw'],
    "sendradhṛti": ['mw'],
    "sendragaṇa": ['mw'],
    "sendraka": ['mw'],
    "sendratva": ['mw'],
    "sendratā": ['mw'],
    "sendriya": ['cae', 'mw'],
    "sendriyatva": ['mw'],
    "sendrāyudhapurogama": ['mw'],
    "sendrāyudhataḍit": ['mw'],
    "sendubha": ['mw'],
    "senduka": ['mw'],
    "senduḍa": ['mw'],
    "seni": ['mw'],
    "senia": ['gra'],
    "senikaguhā": ['bhs'],
    "senta": ['cped'],
    "senya": ['cae', 'ddsa', 'gra', 'mw'],
    "senā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "senābhaṅga": ['mw'],
    "senābhigoptṛ": ['mw'],
    "senābindu": ['mw'],
    "senābyūha": ['cped'],
    "senācara": ['cae', 'mw'],
    "senādhinātha": ['mw'],
    "senādhipa": ['mw'],
    "senādhipati": ['mw'],
    "senādhyakṣa": ['mw'],
    "senāgni": ['mw'],
    "senāgopa": ['mw'],
    "senāgra": ['cae', 'ddsa', 'mw'],
    "senāgraga": ['mw'],
    "senāgragāmin": ['mw'],
    "senāhan": ['mw'],
    "senājīva": ['mw'],
    "senājīvin": ['mw'],
    "senājū": ['cae', 'gra', 'mw'],
    "senākakṣa": ['mw'],
    "senākarman": ['mw'],
    "senāmukha": ['cae', 'mw'],
    "senāmukhī": ['mw'],
    "senānibhogīna": ['mw'],
    "senānigrāmaṇī": ['mw'],
    "senānātha": ['mw'],
    "senānī": ['cae', 'cped', 'gra', 'mw'],
    "senāpacca": ['cped'],
    "senāparicchad": ['mw'],
    "senāpati": ['cae', 'cped', 'mw'],
    "senāpatigrāma": ['bhs'],
    "senāpatipati": ['mw'],
    "senāpatitva": ['mw'],
    "senāpatya": ['cae', 'mw'],
    "senāpraṇetṛ": ['mw'],
    "senāpura": ['mw'],
    "senāpṛṣṭha": ['mw'],
    "senārakṣa": ['mw'],
    "senāsamudaya": ['mw'],
    "senāsana": ['cped'],
    "senāsanacārikā": ['cped'],
    "senāsanagāhāpaka": ['cped'],
    "senāsanapaññāpaka": ['cped'],
    "senāstha": ['mw'],
    "senāsthāna": ['mw'],
    "senāvindu": ['mw'],
    "senāvyūha": ['mw'],
    "senāvāha": ['cae', 'mw'],
    "senāvāsa": ['mw'],
    "senāyaka": ['cped'],
    "senāyoga": ['mw'],
    "senāṃjaya": ['bhs'],
    "senāṅga": ['cae', 'mw'],
    "senāṅgapati": ['mw'],
    "senīya": ['mw'],
    "sepha": ['mw'],
    "sephaḥ": ['ap90'],
    "sephālikā": ['cped'],
    "sepura": ['mw'],
    "sera": ['mw'],
    "seraḥ": ['ap90'],
    "sericārī": ['cped'],
    "seritā": ['cped'],
    "serivihārī": ['cped'],
    "seru": ['ap90', 'mw'],
    "serurāha": ['mw'],
    "serāha": ['mw'],
    "serāhaḥ": ['ap90'],
    "serāla": ['mw'],
    "serṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "serṣyam": ['mw'],
    "sesa": ['cped'],
    "sesesi": ['cped'],
    "seseti": ['cped'],
    "sesetvā": ['cped'],
    "sesita": ['cped'],
    "sessaṁ": ['cped'],
    "seta": ['cped'],
    "setacchatta": ['cped'],
    "setaka": ['bhs'],
    "setakuṭṭha": ['cped'],
    "setakī": ['mw'],
    "setapacchāda": ['cped'],
    "setavya": ['mw'],
    "setavyā": ['cped'],
    "setaṭṭhikā": ['cped'],
    "seti": ['bhs', 'cped'],
    "setikā": ['ap90'],
    "setra": ['mw'],
    "setraṃ": ['ap90'],
    "settha": ['cped'],
    "setu": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "setubandha": ['cae', 'mw'],
    "setubandhana": ['mw'],
    "setubheda": ['mw'],
    "setubhedin": ['mw'],
    "setubhettṛ": ['mw'],
    "setuja": ['mw'],
    "setuka": ['mw'],
    "setukara": ['mw'],
    "setukarman": ['mw'],
    "setukaḥ": ['ap90'],
    "setukhaṇḍa": ['mw'],
    "setukāvya": ['mw'],
    "setumaṅgalamantra": ['mw'],
    "setumāhātmya": ['mw'],
    "setupati": ['mw'],
    "setuprada": ['mw'],
    "setusaraṇi": ['mw'],
    "setusaṃgraha": ['mw'],
    "setusnānavidhi": ['mw'],
    "setuvṛkṣa": ['mw'],
    "setuyātrāvidhi": ['mw'],
    "setuśaila": ['mw'],
    "setuḥ": ['ap90'],
    "setuṣāman": ['mw'],
    "setṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "sev": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "seva": ['ap90', 'mw'],
    "sevadhi": ['ap90', 'mw'],
    "sevaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sevakottama": ['mw'],
    "sevakālu": ['mw'],
    "sevamāna": ['cped'],
    "sevana": ['cae', 'cped', 'ddsa', 'mw'],
    "sevanabhāvanākāvya": ['mw'],
    "sevanatā": ['bhs'],
    "sevanaṃ": ['ap90'],
    "sevanin": ['mw'],
    "sevanta": ['cped'],
    "sevantikāpariṇaya": ['mw'],
    "sevanā": ['cped'],
    "sevanī": ['ap90', 'mw'],
    "sevanīya": ['cae', 'mw'],
    "sevati": ['cped'],
    "sevatī": ['mw'],
    "sevi": ['ap90', 'cped', 'mw'],
    "sevikā": ['mw'],
    "sevin": ['ap90', 'cae', 'mw'],
    "sevita": ['ap90', 'cped', 'ddsa', 'mw'],
    "sevitabba": ['cped'],
    "sevitamanmatha": ['mw'],
    "sevitavya": ['cae', 'mw'],
    "sevitva": ['mw'],
    "sevitvā": ['cped'],
    "sevitā": ['mw'],
    "sevitṛ": ['ap90', 'cae', 'mw'],
    "sevya": ['ap90', 'cae', 'mw'],
    "sevyamāna": ['mw'],
    "sevyasevakau": ['mw'],
    "sevyatva": ['mw'],
    "sevyatā": ['mw'],
    "sevyā": ['mw'],
    "sevā": ['ap90', 'cae', 'cped', 'mw'],
    "sevābhirata": ['mw'],
    "sevābhṛt": ['mw'],
    "sevādakṣa": ['cae', 'mw'],
    "sevādharma": ['cae', 'mw'],
    "sevājana": ['mw'],
    "sevākaumudī": ['mw'],
    "sevākāku": ['mw'],
    "sevāla": ['cped'],
    "sevālin": ['mw'],
    "sevāphalastotra": ['mw'],
    "sevāphalastotravivṛti": ['mw'],
    "sevāphaloktivivṛti": ['mw'],
    "sevāsī": ['mw'],
    "sevātīrtha": ['mw'],
    "sevāvalamba": ['mw'],
    "sevāvasara": ['mw'],
    "sevāvicāra": ['mw'],
    "sevāvilāsinī": ['mw'],
    "sevāvyavahāra": ['mw'],
    "sevāvṛtti": ['mw'],
    "sevāñjali": ['mw'],
    "seya": ['gra', 'mw'],
    "seyana": ['mw'],
    "seyya": ['cped'],
    "seyyathidaṁ": ['cped'],
    "seyyathāpi": ['cped'],
    "seyyathīdaṁ": ['cped'],
    "seyyaṁ kappeti": ['cped'],
    "seyyo": ['cped'],
    "seyyā": ['bhs', 'cped'],
    "seśvara": ['mw'],
    "seśvarasāṃkhya": ['mw'],
    "seṅgara": ['mw'],
    "seṇi": ['cped'],
    "seṇiya": ['cped'],
    "seṣmīyāṇa": ['mw'],
    "seṣu": ['mw'],
    "seṣudhanvan": ['mw'],
    "seṣuka": ['mw'],
    "seṣṭi": ['mw'],
    "seṣṭika": ['mw'],
    "seṭa": ['mw'],
    "seṭha": ['mw'],
    "seṭu": ['mw'],
    "seṭuḥ": ['ap90'],
    "seṭṭha": ['cped'],
    "seṭṭhasammata": ['cped'],
    "seṭṭhatara": ['cped'],
    "seṭṭhi": ['cped'],
    "seṭṭhibhariyā": ['cped'],
    "seṭṭhijāyā": ['cped'],
    "seṭṭhāna": ['cped'],
    "seṭṭhī": ['cped'],
    "si": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sia": ['gra'],
    "sibbana": ['cped'],
    "sibbanī": ['cped'],
    "sibbanīmagga": ['cped'],
    "sibbati": ['cped'],
    "sibbenta": ['cped'],
    "sibbesi": ['cped'],
    "sibbeti": ['cped'],
    "sibbetvā": ['cped'],
    "sibbi": ['cped'],
    "sibbita": ['cped'],
    "sibbitvā": ['cped'],
    "sibbāpeti": ['cped'],
    "sibh": ['mw'],
    "sic": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sicaya": ['cae', 'ddsa', 'mw'],
    "sicayaḥ": ['ap90'],
    "siddha": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "siddhabhūmi": ['cae', 'mw'],
    "siddhabuddha": ['mw'],
    "siddhacandragaṇi": ['mw'],
    "siddhadarśana": ['mw'],
    "siddhadeva": ['mw'],
    "siddhadhāman": ['mw'],
    "siddhadhātu": ['mw'],
    "siddhadravya": ['mw'],
    "siddhagati": ['mw'],
    "siddhagaṅgā": ['mw'],
    "siddhagraha": ['mw'],
    "siddhaguru": ['mw'],
    "siddhahemakumāra": ['mw'],
    "siddhaheman": ['mw'],
    "siddhaikavīra": ['bhs'],
    "siddhaikavīratantra": ['mw'],
    "siddhaiśvarya": ['mw'],
    "siddhajala": ['mw'],
    "siddhajana": ['mw'],
    "siddhajātaka": ['bhs'],
    "siddhaka": ['bhs', 'mw'],
    "siddhakajjala": ['mw'],
    "siddhakalpa": ['mw'],
    "siddhakaḥ": ['ap90'],
    "siddhakerala": ['mw'],
    "siddhakhaṇḍa": ['mw'],
    "siddhakheṭīsāriṇī": ['mw'],
    "siddhakāma": ['mw'],
    "siddhakāmeśvarī": ['mw'],
    "siddhakārya": ['mw'],
    "siddhakṣetra": ['cae', 'mw'],
    "siddhakṣetraparvata": ['mw'],
    "siddhalakṣa": ['cae', 'mw'],
    "siddhalakṣmaṇa": ['mw'],
    "siddhalakṣmī": ['mw'],
    "siddhalakṣmīstotra": ['mw'],
    "siddhaloka": ['mw'],
    "siddhamanorama": ['mw'],
    "siddhamantra": ['cae', 'mw'],
    "siddhamata": ['mw'],
    "siddhamodaka": ['mw'],
    "siddhamānasa": ['mw'],
    "siddhamātrikā": ['mw'],
    "siddhamūlikānighaṇṭu": ['mw'],
    "siddhanandin": ['mw'],
    "siddhanara": ['mw'],
    "siddhanāgārjuna": ['mw'],
    "siddhanāgārjunatantra": ['mw'],
    "siddhanāgārjunīya": ['mw'],
    "siddhanārāyaṇa": ['mw'],
    "siddhanātha": ['mw'],
    "siddhapada": ['mw'],
    "siddhapakṣa": ['mw'],
    "siddhapatha": ['mw'],
    "siddhapati": ['mw'],
    "siddhaprayojana": ['mw'],
    "siddhaprāya": ['mw'],
    "siddhaprāṇeśvara": ['mw'],
    "siddhapura": ['cae', 'mw'],
    "siddhapuruṣa": ['mw'],
    "siddhapurī": ['mw'],
    "siddhaputra": ['mw'],
    "siddhapuṣpa": ['mw'],
    "siddhapāda": ['mw'],
    "siddhapātra": ['bhs', 'mw'],
    "siddhapīṭha": ['mw'],
    "siddharasa": ['mw'],
    "siddharasadaṇḍa": ['mw'],
    "siddharasāyana": ['mw'],
    "siddharatna": ['mw'],
    "siddharaṅgakalpa": ['mw'],
    "siddharudreśvaratīrtha": ['mw'],
    "siddharāja": ['mw'],
    "siddharājavarṇana": ['mw'],
    "siddharātrī": ['mw'],
    "siddharūpa": ['mw'],
    "siddharṣi": ['mw'],
    "siddhasalila": ['mw'],
    "siddhasambandha": ['mw'],
    "siddhasamākhya": ['mw'],
    "siddhasarit": ['mw'],
    "siddhasaṃgha": ['cae', 'mw'],
    "siddhasaṃkalpa": ['mw'],
    "siddhasena": ['mw'],
    "siddhasenadivākara": ['mw'],
    "siddhasenadivākṛt": ['mw'],
    "siddhasenasūri": ['mw'],
    "siddhasenavākyakāra": ['mw'],
    "siddhasevita": ['mw'],
    "siddhasiddha": ['mw'],
    "siddhasiddhānta": ['mw'],
    "siddhasiddhāntapaddhati": ['mw'],
    "siddhasiddhāñjana": ['mw'],
    "siddhasindhu": ['mw'],
    "siddhasopāna": ['mw'],
    "siddhasthala": ['mw'],
    "siddhasthālī": ['mw'],
    "siddhasthāna": ['mw'],
    "siddhasusiddha": ['mw'],
    "siddhasādhana": ['mw'],
    "siddhasādhanadoṣa": ['mw'],
    "siddhasādhita": ['mw'],
    "siddhasādhya": ['mw'],
    "siddhasādhyaka": ['mw'],
    "siddhasārasaṃhitā": ['mw'],
    "siddhasārasvata": ['mw'],
    "siddhasārasvatadīpikā": ['mw'],
    "siddhasārasvatastotra": ['mw'],
    "siddhattha": ['cped'],
    "siddhatthaka": ['cped'],
    "siddhatva": ['mw'],
    "siddhatvatā": ['mw'],
    "siddhatā": ['ap90'],
    "siddhatāpasa": ['mw'],
    "siddhatāpasī": ['mw'],
    "siddhaugha": ['mw'],
    "siddhauṣadha": ['cae', 'mw'],
    "siddhauṣadhasaṃgraha": ['mw'],
    "siddhauṣadhika": ['mw'],
    "siddhavana": ['mw'],
    "siddhavarti": ['mw'],
    "siddhavasti": ['mw'],
    "siddhavastu": ['mw'],
    "siddhavat": ['mw'],
    "siddhavaṭa": ['mw'],
    "siddhavaṭasthalakalpa": ['mw'],
    "siddhavaṭī": ['mw'],
    "siddhavidyā": ['mw'],
    "siddhavidyādīpikā": ['mw'],
    "siddhavāsa": ['mw'],
    "siddhavīrya": ['mw'],
    "siddhayoga": ['cae', 'mw'],
    "siddhayogamālā": ['mw'],
    "siddhayogasaṃgraha": ['mw'],
    "siddhayogeśvaratantra": ['mw'],
    "siddhayogin": ['mw'],
    "siddhayoginī": ['mw'],
    "siddhayoṣit": ['mw'],
    "siddhayāmala": ['mw'],
    "siddhayātra": ['bhs'],
    "siddhayātrika": ['mw'],
    "siddhaśabara": ['bhs'],
    "siddhaśābaratantra": ['mw'],
    "siddhecchā": ['mw'],
    "siddheśa": ['cae', 'mw'],
    "siddheśvara": ['cae', 'mw'],
    "siddheśvarastotra": ['mw'],
    "siddheśvaratantra": ['mw'],
    "siddheśvaratīrtha": ['mw'],
    "siddhi": ['cae', 'cped', 'ddsa', 'mw'],
    "siddhibhairavatantra": ['mw'],
    "siddhibhūmi": ['mw'],
    "siddhibhūmimārga": ['mw'],
    "siddhibīja": ['mw'],
    "siddhicāmuṇḍātīrtha": ['mw'],
    "siddhida": ['cae', 'mw'],
    "siddhidarśin": ['cae', 'mw'],
    "siddhidātrī": ['mw'],
    "siddhijñāna": ['mw'],
    "siddhika": ['mw'],
    "siddhikara": ['cae', 'mw'],
    "siddhikaraṇa": ['mw'],
    "siddhikaraṇavidhāna": ['mw'],
    "siddhikarī": ['mw'],
    "siddhikāraka": ['mw'],
    "siddhikāraṇa": ['mw'],
    "siddhikārin": ['cae', 'mw'],
    "siddhikṣetra": ['cae', 'mw'],
    "siddhilābha": ['mw'],
    "siddhimant": ['cae'],
    "siddhimantra": ['cae', 'mw'],
    "siddhimanvantara": ['mw'],
    "siddhimat": ['mw'],
    "siddhimārga": ['mw'],
    "siddhinṛsiṃha": ['mw'],
    "siddhiprada": ['mw'],
    "siddhiprāya": ['mw'],
    "siddhirasa": ['mw'],
    "siddhirasadaṇḍa": ['mw'],
    "siddhirāj": ['mw'],
    "siddhisopāna": ['mw'],
    "siddhisthāna": ['mw'],
    "siddhisādhaka": ['mw'],
    "siddhisādhana": ['mw'],
    "siddhitraya": ['mw'],
    "siddhivarti": ['mw'],
    "siddhivighna": ['mw'],
    "siddhivināyaka": ['mw'],
    "siddhivināyakapūjanavidhi": ['mw'],
    "siddhivināyakavrata": ['mw'],
    "siddhivāda": ['mw'],
    "siddhiyoga": ['cae', 'mw'],
    "siddhiyoginī": ['mw'],
    "siddhiyogya": ['mw'],
    "siddhiyātrika": ['mw'],
    "siddhiḥ": ['ap90'],
    "siddhodaka": ['ddsa', 'mw'],
    "siddhottamā": ['bhs'],
    "siddhy": ['mw'],
    "siddhya": ['bhs'],
    "siddhyartham": ['mw'],
    "siddhyasiddhi": ['mw'],
    "siddhā": ['mw'],
    "siddhābhīṣṭa": ['cae'],
    "siddhācala": ['mw'],
    "siddhācalapūjā": ['mw'],
    "siddhādeśa": ['cae', 'mw'],
    "siddhāgama": ['mw'],
    "siddhājña": ['mw'],
    "siddhāmbā": ['mw'],
    "siddhānanda": ['mw'],
    "siddhānna": ['mw'],
    "siddhānta": ['cae', 'mw'],
    "siddhāntabhāṣya": ['mw'],
    "siddhāntabindu": ['mw'],
    "siddhāntabinduvyākhyā": ['mw'],
    "siddhāntacandrikā": ['mw'],
    "siddhāntacandrikākhaṇḍana": ['mw'],
    "siddhāntacandrikāṭīkā": ['mw'],
    "siddhāntacandrodaya": ['mw'],
    "siddhāntacintāmaṇi": ['mw'],
    "siddhāntacintāratnasaṃgraha": ['mw'],
    "siddhāntacūḍāmaṇi": ['mw'],
    "siddhāntadarpaṇa": ['mw'],
    "siddhāntadharmāgama": ['mw'],
    "siddhāntadīpa": ['mw'],
    "siddhāntadīpaprabhā": ['mw'],
    "siddhāntadīpikā": ['mw'],
    "siddhāntagarbha": ['mw'],
    "siddhāntagrantha": ['mw'],
    "siddhāntagītā": ['mw'],
    "siddhāntagūḍhārthaprakāśaka": ['mw'],
    "siddhāntahorā": ['mw'],
    "siddhāntajyotsnā": ['mw'],
    "siddhāntajāhnavī": ['mw'],
    "siddhāntakalpalatā": ['mw'],
    "siddhāntakalpavallī": ['mw'],
    "siddhāntakalpavallīvyākhyāna": ['mw'],
    "siddhāntakaumudī": ['cae', 'mw'],
    "siddhāntakaumudīgūḍhaphakkikāprakāśa": ['mw'],
    "siddhāntakaumudīkoṭipattra": ['mw'],
    "siddhāntakaumudīsāra": ['mw'],
    "siddhāntakaumudīvilāsa": ['mw'],
    "siddhāntakoṭi": ['mw'],
    "siddhāntakārikā": ['mw'],
    "siddhāntalaghukhamāṇika": ['mw'],
    "siddhāntalakṣaṇa": ['mw'],
    "siddhāntalakṣaṇadīdhitiṭīkā": ['mw'],
    "siddhāntalakṣaṇakroḍa": ['mw'],
    "siddhāntalakṣaṇapariṣkāra": ['mw'],
    "siddhāntalakṣaṇaprakāśa": ['mw'],
    "siddhāntalakṣaṇarahasya": ['mw'],
    "siddhāntalakṣaṇavivekaprakaraṇa": ['mw'],
    "siddhāntalakṣaṇaṭīkā": ['mw'],
    "siddhāntalava": ['mw'],
    "siddhāntaleśa": ['mw'],
    "siddhāntamakaranda": ['mw'],
    "siddhāntamanoramā": ['mw'],
    "siddhāntamañjarī": ['mw'],
    "siddhāntamañjūṣā": ['mw'],
    "siddhāntamañjūṣākhaṇḍana": ['mw'],
    "siddhāntamaṇimañjarī": ['mw'],
    "siddhāntamudrā": ['mw'],
    "siddhāntamuktāvalī": ['mw'],
    "siddhāntamuktāvalīprakāśa": ['mw'],
    "siddhāntanaiyāyikamata": ['mw'],
    "siddhāntanirṇaya": ['mw'],
    "siddhāntanyāyacandrikā": ['mw'],
    "siddhāntapaddhati": ['mw'],
    "siddhāntapakṣa": ['mw'],
    "siddhāntapañcānana": ['mw'],
    "siddhāntapañjara": ['mw'],
    "siddhāntapaṭala": ['mw'],
    "siddhāntapīyūṣa": ['mw'],
    "siddhāntarahasya": ['mw'],
    "siddhāntaratna": ['mw'],
    "siddhāntaratnamālā": ['mw'],
    "siddhāntaratnākara": ['mw'],
    "siddhāntaratnāvalī": ['mw'],
    "siddhāntasamāsa": ['mw'],
    "siddhāntasaṃdarbha": ['mw'],
    "siddhāntasaṃgraha": ['mw'],
    "siddhāntasaṃgrahaṭīkā": ['mw'],
    "siddhāntasaṃhitāsārasamuccaya": ['mw'],
    "siddhāntasetukā": ['mw'],
    "siddhāntasiddhāñjana": ['mw'],
    "siddhāntasindhu": ['mw'],
    "siddhāntasudhānidhi": ['mw'],
    "siddhāntasundara": ['mw'],
    "siddhāntasvānubhūtiprakāśikā": ['mw'],
    "siddhāntasāra": ['mw'],
    "siddhāntasāradīpikā": ['mw'],
    "siddhāntasārasaṃgraha": ['mw'],
    "siddhāntasārvabhauma": ['mw'],
    "siddhāntasārāvalī": ['mw'],
    "siddhāntasūktamañjarī": ['mw'],
    "siddhāntasūtrabhāṣyaṭīkā": ['mw'],
    "siddhāntatari": ['mw'],
    "siddhāntatattva": ['mw'],
    "siddhāntatattvabindu": ['mw'],
    "siddhāntatattvabindusaṃdīpana": ['mw'],
    "siddhāntatattvadīpa": ['mw'],
    "siddhāntatattvaprakāśikā": ['mw'],
    "siddhāntatattvasarvasva": ['mw'],
    "siddhāntatattvaviveka": ['mw'],
    "siddhāntavaijayantī": ['mw'],
    "siddhāntaveda": ['mw'],
    "siddhāntavelā": ['mw'],
    "siddhāntavilāsa": ['mw'],
    "siddhāntaviveka": ['mw'],
    "siddhāntavyutpattilakṣaṇa": ['mw'],
    "siddhāntavyākhyā": ['mw'],
    "siddhāntavyāpti": ['mw'],
    "siddhāntavācaspati": ['mw'],
    "siddhāntavāgīśa": ['mw'],
    "siddhāntavāṅmālā": ['mw'],
    "siddhāntaya": ['ddsa', 'mw'],
    "siddhāntaśataka": ['mw'],
    "siddhāntaśekhara": ['mw'],
    "siddhāntaśikhāmaṇi": ['mw'],
    "siddhāntaśikṣā": ['mw'],
    "siddhāntaśiromaṇi": ['mw'],
    "siddhāntaśiromaṇiprakāśa": ['mw'],
    "siddhāntaśiromaṇivāsanāvārttika": ['mw'],
    "siddhāntaśiromaṇyudāharaṇa": ['mw'],
    "siddhāntin": ['mw'],
    "siddhāntita": ['mw'],
    "siddhāntācāra": ['mw'],
    "siddhāntādhikaraṇamālā": ['mw'],
    "siddhāntārṇava": ['mw'],
    "siddhāntīya": ['mw'],
    "siddhāpagā": ['mw'],
    "siddhāri": ['mw'],
    "siddhārtha": ['bhs', 'cae', 'ddsa', 'mw'],
    "siddhārthabuddhi": ['bhs'],
    "siddhārthacarita": ['mw'],
    "siddhārthaka": ['mw'],
    "siddhārthakārin": ['mw'],
    "siddhārthamati": ['bhs', 'mw'],
    "siddhārthamānin": ['cae', 'mw'],
    "siddhārthapṛcchā": ['mw'],
    "siddhārthasaṃhitā": ['mw'],
    "siddhārthin": ['mw'],
    "siddhārthā": ['bhs', 'mw'],
    "siddhāsana": ['mw'],
    "siddhāyikā": ['mw'],
    "siddhāñjana": ['cae', 'mw'],
    "siddhāñjanāya": ['mw'],
    "siddhāśrama": ['cae', 'ddsa', 'mw'],
    "siddhāśramapada": ['mw'],
    "siddhāśramatīrtha": ['mw'],
    "siddhāṃtin": ['ap90'],
    "siddhāṅganā": ['cae', 'ddsa', 'mw'],
    "siddhīkṛ": ['cae'],
    "siddhīkṛta": ['mw'],
    "siddhīśvara": ['cae', 'mw'],
    "sidguṇḍa": ['mw'],
    "sidh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sidhma": ['cae', 'ddsa', 'gra', 'mw'],
    "sidhmala": ['ap90', 'cae', 'mw'],
    "sidhmalā": ['mw'],
    "sidhman": ['cae', 'mw'],
    "sidhmapuṣpikā": ['mw'],
    "sidhmavat": ['mw'],
    "sidhmaṃ": ['ap90'],
    "sidhmā": ['ap90', 'mw'],
    "sidhra": ['ap90', 'cae', 'gra', 'mw'],
    "sidhraka": ['mw'],
    "sidhrakā": ['mw'],
    "sidhrakāvat": ['mw'],
    "sidhrakāvaṇa": ['mw'],
    "sidhrakāvaṇaṃ": ['ap90'],
    "sidhya": ['mw'],
    "sidhyaḥ": ['ap90'],
    "sig": ['mw'],
    "sigatā": ['mw'],
    "siggu": ['cped'],
    "sigruḍī": ['mw'],
    "sigvāta": ['mw'],
    "sigāla": ['cped'],
    "sigālaka": ['cped'],
    "sigṛḍī": ['mw'],
    "sihla": ['mw'],
    "sihlakī": ['ap90'],
    "sihlaḥ": ['ap90'],
    "sihuṃḍaḥ": ['ap90'],
    "sihuṇḍa": ['mw'],
    "siji": ['mw'],
    "sijimat": ['mw'],
    "sijjhana": ['cped'],
    "sijjhati": ['cped'],
    "sijjhi": ['cped'],
    "sik": ['mw'],
    "sikatila": ['ap90', 'cae', 'ddsa', 'mw'],
    "sikatopopta": ['mw'],
    "sikatottara": ['mw'],
    "sikatya": ['cae', 'mw'],
    "sikatā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sikatāmaya": ['ap90', 'mw'],
    "sikatāmeha": ['mw'],
    "sikatāmehin": ['mw'],
    "sikatāprāya": ['mw'],
    "sikatāsetu": ['mw'],
    "sikatāsindhu": ['mw'],
    "sikatātva": ['mw'],
    "sikatāvartman": ['mw'],
    "sikatāvat": ['mw'],
    "sikhara": ['cped'],
    "sikharī": ['cped'],
    "sikhaṇḍa": ['cped'],
    "sikhaṇḍī": ['cped'],
    "sikhā": ['cped'],
    "sikhī": ['cped'],
    "sikkhamāna": ['cped'],
    "sikkhamānā": ['cped'],
    "sikkhana": ['cped'],
    "sikkhanta": ['cped'],
    "sikkhati": ['cped'],
    "sikkhi": ['cped'],
    "sikkhita": ['cped'],
    "sikkhitabba": ['cped'],
    "sikkhitvā": ['cped'],
    "sikkhā": ['cped'],
    "sikkhākāma": ['cped'],
    "sikkhākāmatā": ['cped'],
    "sikkhāpada": ['cped'],
    "sikkhāpaka": ['cped'],
    "sikkhāpana": ['cped'],
    "sikkhāpanaka": ['cped'],
    "sikkhāsamādāna": ['cped'],
    "sikkā": ['cped'],
    "sikta": ['ap90', 'ddsa', 'mw'],
    "siktatā": ['mw'],
    "siktha": ['cae', 'mw'],
    "sikthaka": ['bhs', 'mw'],
    "sikthakaṃ": ['ap90'],
    "sikthaḥ": ['ap90'],
    "sikti": ['cae', 'gra', 'mw'],
    "siktiḥ": ['ap90'],
    "siktā": ['mw'],
    "sikyaṃ": ['ap90'],
    "sikṣya": ['mw'],
    "sikṣyaḥ": ['ap90'],
    "sil": ['mw'],
    "silaka": ['mw'],
    "silesa": ['cped'],
    "silesuma": ['cped'],
    "silha": ['cae', 'mw'],
    "silhabhūmikā": ['mw'],
    "silhaka": ['mw'],
    "silhakamaya": ['mw'],
    "silhakī": ['mw'],
    "silhasāra": ['mw'],
    "silikamadhyama": ['gra', 'mw'],
    "silisilika": ['mw'],
    "siliṭṭha": ['cped'],
    "siliṭṭhatā": ['cped'],
    "sillakī": ['mw'],
    "sillana": ['ddsa', 'mw'],
    "sillarāja": ['ddsa', 'mw'],
    "siloka": ['cped'],
    "siluccaya": ['cped'],
    "silutta": ['cped'],
    "silā": ['cped'],
    "silācī": ['cae', 'mw'],
    "silāghati": ['cped'],
    "silāghi": ['cped'],
    "silāguḷa": ['cped'],
    "silāmaya": ['cped'],
    "silāpaṭṭa": ['cped'],
    "silāpākāra": ['cped'],
    "silātthambha": ['cped'],
    "silāñjālā": ['cae', 'mw'],
    "silīvāka": ['mw'],
    "sim": ['mw'],
    "sima": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "simasimāya": ['ddsa', 'mw'],
    "simba": ['cae', 'ddsa', 'mw'],
    "simbalī": ['cped'],
    "simbarāja": ['mw'],
    "simbatikā": ['mw'],
    "simbh": ['mw'],
    "simbhuka": ['ddsa', 'mw'],
    "simisimāy": ['cae'],
    "simisimāya": ['ddsa', 'mw'],
    "simisimāyate": ['ap90'],
    "simā": ['ddsa', 'mw'],
    "simātva": ['mw'],
    "simīka": ['mw'],
    "sina": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sinavat": ['gra', 'mw'],
    "sindha": ['mw'],
    "sindhava": ['bhs', 'cped'],
    "sindhi": ['mw'],
    "sindhu": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sindhudatta": ['mw'],
    "sindhudeśa": ['mw'],
    "sindhudvīpa": ['mw'],
    "sindhugañja": ['mw'],
    "sindhuja": ['cae', 'mw'],
    "sindhujanman": ['mw'],
    "sindhujā": ['mw'],
    "sindhuka": ['mw'],
    "sindhukanyā": ['mw'],
    "sindhukapha": ['mw'],
    "sindhukara": ['mw'],
    "sindhukhela": ['mw'],
    "sindhukārikā": ['mw'],
    "sindhukṣit": ['mw'],
    "sindhula": ['mw'],
    "sindhulavaṇa": ['mw'],
    "sindhumadhya": ['mw'],
    "sindhumantha": ['mw'],
    "sindhumanthaja": ['mw'],
    "sindhumathya": ['mw'],
    "sindhumitra": ['mw'],
    "sindhumukha": ['mw'],
    "sindhumukhāgata": ['mw'],
    "sindhumātṛ": ['cae', 'gra', 'mw'],
    "sindhunada": ['mw'],
    "sindhunandana": ['mw'],
    "sindhunātha": ['cae', 'mw'],
    "sindhuparṇī": ['mw'],
    "sindhupatha": ['mw'],
    "sindhupati": ['cae', 'gra', 'mw'],
    "sindhupatnī": ['mw'],
    "sindhupiba": ['mw'],
    "sindhuprasūta": ['mw'],
    "sindhupulinda": ['mw'],
    "sindhuputra": ['mw'],
    "sindhupuṣpa": ['mw'],
    "sindhupāraja": ['mw'],
    "sindhura": ['ddsa', 'mw'],
    "sindhuradveṣin": ['mw'],
    "sindhuraṭṭha": ['cped'],
    "sindhurāgirimāhātmya": ['mw'],
    "sindhurāja": ['cae', 'mw'],
    "sindhurājñī": ['mw'],
    "sindhurāva": ['mw'],
    "sindhusamudrasaṃgama": ['mw'],
    "sindhusarja": ['mw'],
    "sindhusauvīra": ['mw'],
    "sindhusauvīraka": ['mw'],
    "sindhusaṃgama": ['mw'],
    "sindhusaṅgama": ['cped'],
    "sindhusāgara": ['mw'],
    "sindhusūnu": ['mw'],
    "sindhusṛtya": ['mw'],
    "sindhutas": ['cae', 'mw'],
    "sindhutīrasambhava": ['mw'],
    "sindhuvaktra": ['mw'],
    "sindhuveṣaṇa": ['mw'],
    "sindhuvāhas": ['gra', 'mw'],
    "sindhuvāra": ['cae', 'mw'],
    "sindhuvāraka": ['mw'],
    "sindhuvārikā": ['mw'],
    "sindhuvārita": ['bhs', 'mw'],
    "sindhuvāsin": ['mw'],
    "sindhuvāsinī": ['mw'],
    "sindhuvīrya": ['mw'],
    "sindhuvṛṣa": ['mw'],
    "sindhuśayana": ['mw'],
    "sindhuḍā": ['mw'],
    "sindhuṣeṇa": ['mw'],
    "sindhuṣāman": ['mw'],
    "sindhūdbhava": ['mw'],
    "sindhūpala": ['mw'],
    "sindhūttama": ['mw'],
    "sindhūttha": ['mw'],
    "sinduka": ['mw'],
    "sindukā": ['mw'],
    "sinduvāra": ['cae', 'ddsa', 'mw'],
    "sindī": ['cped'],
    "sindūra": ['cae', 'cped', 'ddsa', 'mw'],
    "sindūrakāraṇa": ['mw'],
    "sindūranirgama": ['mw'],
    "sindūraprakāra": ['mw'],
    "sindūraprakāraṭīkā": ['mw'],
    "sindūrapuṣpī": ['mw'],
    "sindūrarasa": ['mw'],
    "sindūratilaka": ['mw'],
    "sindūratilakā": ['mw'],
    "sindūrikā": ['mw'],
    "sindūrita": ['mw'],
    "sindūrī": ['mw'],
    "sineha": ['cped'],
    "sinehabindu": ['cped'],
    "sinehana": ['cped'],
    "sineheti": ['cped'],
    "siniddha": ['cped'],
    "sinimmita": ['cped'],
    "sinv": ['ap90', 'mw'],
    "sinva": ['gra', 'mw'],
    "sinvat": ['gra'],
    "sināna": ['cped'],
    "sinī": ['ap90', 'mw'],
    "sinīpati": ['mw'],
    "sinīvāka": ['mw'],
    "sinīvālī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sinīvālīkuhūśānti": ['mw'],
    "siona": ['gra'],
    "sionakṛt": ['gra'],
    "sionaśī": ['gra'],
    "sip": ['ddsa'],
    "siphinnā": ['ddsa', 'mw'],
    "sipila": ['mw'],
    "sippa": ['cped'],
    "sippasālā": ['cped'],
    "sippaṭṭhāna": ['cped'],
    "sippaṭṭhāyatana": ['cped'],
    "sippika": ['cped'],
    "sippikā": ['cped'],
    "sippī": ['cped'],
    "sipra": ['mw'],
    "sipraḥ": ['ap90'],
    "siprā": ['ap90', 'cae', 'ddsa', 'mw'],
    "siprāya": ['mw'],
    "sipunā": ['mw'],
    "sipāhaṇa": ['mw'],
    "sipāṭikā": ['cped'],
    "sira": ['mw'],
    "siraḥ": ['ap90'],
    "siri": ['cped'],
    "siridhra": ['mw'],
    "sirigabbha": ['cped'],
    "sirimant": ['cped'],
    "sirindhara": ['cped'],
    "sirindhra": ['mw'],
    "sirisayana": ['cped'],
    "sirivāsa": ['cped'],
    "siriṁsapa": ['cped'],
    "siro": ['cped'],
    "sirojāla": ['cped'],
    "siromaṇi": ['cped'],
    "siroruha": ['cped'],
    "sirotpāta": ['mw'],
    "siroveṭhana": ['cped'],
    "sirā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sirābīja": ['mw'],
    "sirāharṣa": ['mw'],
    "sirājāla": ['mw'],
    "sirājālavat": ['mw'],
    "sirāla": ['cae', 'ddsa', 'mw'],
    "sirālaka": ['mw'],
    "sirālu": ['mw'],
    "sirālā": ['mw'],
    "sirāmbu": ['mw'],
    "sirāmokṣa": ['mw'],
    "sirāmūla": ['mw'],
    "sirāpattra": ['mw'],
    "sirāpraharṣa": ['mw'],
    "sirāvedha": ['mw'],
    "sirāvedhana": ['mw'],
    "sirāvyadha": ['mw'],
    "sirāvyadhana": ['mw'],
    "sirāvṛtta": ['mw'],
    "sirī": ['cae', 'cped', 'gra', 'mw'],
    "sirīsa": ['cped'],
    "sisanis": ['mw'],
    "sisaṃgrāmayiṣu": ['mw'],
    "sisikṣā": ['ddsa', 'mw'],
    "sisira": ['cped'],
    "sisnāsu": ['ddsa', 'mw'],
    "sisrat": ['mw'],
    "sissa": ['cped'],
    "sisādhayiṣu": ['mw'],
    "sisṛkṣu": ['cae', 'mw'],
    "sisṛkṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "sita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sitacchada": ['mw'],
    "sitacchadā": ['mw'],
    "sitacchattra": ['mw'],
    "sitacchattrita": ['mw'],
    "sitacchattrā": ['mw'],
    "sitacchattrī": ['mw'],
    "sitacihna": ['mw'],
    "sitadarbha": ['mw'],
    "sitadhātu": ['mw'],
    "sitadru": ['mw'],
    "sitadruma": ['mw'],
    "sitadvija": ['mw'],
    "sitadīdhiti": ['cae', 'mw'],
    "sitadīpya": ['mw'],
    "sitadūrvā": ['mw'],
    "sitaguñjā": ['mw'],
    "sitahūṇa": ['mw'],
    "sitairaṇḍa": ['mw'],
    "sitajā": ['mw'],
    "sitaka": ['mw'],
    "sitakamala": ['cae', 'ddsa', 'mw'],
    "sitakamalamaya": ['mw'],
    "sitakara": ['cae', 'mw'],
    "sitakarman": ['mw'],
    "sitakarānana": ['mw'],
    "sitakarṇikā": ['mw'],
    "sitakarṇī": ['mw'],
    "sitakaṇṭha": ['mw'],
    "sitakaṇṭā": ['mw'],
    "sitakaṇṭārikā": ['mw'],
    "sitakaṭabhī": ['mw'],
    "sitaketu": ['bhs'],
    "sitakeśa": ['mw'],
    "sitakhaṇḍa": ['mw'],
    "sitakumbhī": ['mw'],
    "sitakuñjara": ['mw'],
    "sitakāca": ['mw'],
    "sitakācara": ['mw'],
    "sitakṛṣṇa": ['mw'],
    "sitakṣudrā": ['mw'],
    "sitakṣāra": ['mw'],
    "sitalatā": ['mw'],
    "sitalaśuna": ['mw'],
    "sitalohita": ['mw'],
    "sitamanas": ['cae', 'mw'],
    "sitamarica": ['mw'],
    "sitamaṇi": ['cae', 'mw'],
    "sitamaṇimaya": ['cae', 'mw'],
    "sitamegha": ['mw'],
    "sitamāraka": ['mw'],
    "sitamāṣa": ['mw'],
    "sitapadma": ['mw'],
    "sitapakṣa": ['cae', 'mw'],
    "sitaparṇī": ['mw'],
    "sitapaṭa": ['mw'],
    "sitapiṅgāṇa": ['mw'],
    "sitaprabha": ['mw'],
    "sitapuṅkhā": ['mw'],
    "sitapuṇḍarīka": ['mw'],
    "sitapuṣpa": ['mw'],
    "sitapuṣpika": ['bhs', 'mw'],
    "sitapuṣpā": ['mw'],
    "sitapuṣpāya": ['mw'],
    "sitapuṣpī": ['mw'],
    "sitapāṭalikā": ['mw'],
    "sitapīta": ['cae', 'mw'],
    "sitapītaharinnīla": ['mw'],
    "sitarakta": ['cae', 'mw'],
    "sitarañjana": ['mw'],
    "sitaraśmi": ['mw'],
    "sitaruci": ['mw'],
    "sitasapti": ['mw'],
    "sitasarṣapa": ['mw'],
    "sitasiddhārtha": ['mw'],
    "sitasiddhārthaka": ['mw'],
    "sitasindhu": ['mw'],
    "sitasiva": ['mw'],
    "sitasiṃhī": ['mw'],
    "sitasāra": ['mw'],
    "sitasāraka": ['mw'],
    "sitasāyakā": ['mw'],
    "sitasūraṇa": ['mw'],
    "sitatara": ['mw'],
    "sitatejas": ['cae', 'mw'],
    "sitaturaga": ['mw'],
    "sitatārā": ['bhs'],
    "sitavallīja": ['mw'],
    "sitavarman": ['mw'],
    "sitavarṣābhū": ['mw'],
    "sitavatī": ['bhs'],
    "sitaviśālākṣa": ['bhs'],
    "sitavājin": ['mw'],
    "sitavāraṇa": ['mw'],
    "sitayajñopavītin": ['mw'],
    "sitayāminī": ['mw'],
    "sitaśarkarā": ['mw'],
    "sitaśimbika": ['mw'],
    "sitaśiva": ['mw'],
    "sitaśiṃśapā": ['mw'],
    "sitaśmaśru": ['cae', 'mw'],
    "sitaśrī": ['bhs'],
    "sitaśyāma": ['mw'],
    "sitaśāyakā": ['mw'],
    "sitaśūka": ['mw'],
    "sitaśūraṇa": ['mw'],
    "sitekṣu": ['mw'],
    "sitetara": ['cae', 'ddsa', 'mw'],
    "sitetaragati": ['mw'],
    "sitetarasaroja": ['mw'],
    "sithila": ['cped'],
    "sithilabhāva": ['cped'],
    "sithilatta": ['cped'],
    "siti": ['ap90', 'mw'],
    "sitikaṇṭha": ['mw'],
    "sitiman": ['ap90', 'cae', 'ddsa', 'mw'],
    "sitimāraka": ['mw'],
    "sitivāra": ['mw'],
    "sitivāsas": ['ddsa', 'mw'],
    "sitodaka": ['bhs', 'mw'],
    "sitodara": ['mw'],
    "sitodbhava": ['mw'],
    "sitopala": ['mw'],
    "sitopalā": ['mw'],
    "sitotpala": ['cae', 'ddsa', 'mw'],
    "sitoṣṇavāraṇa": ['mw'],
    "sitta": ['cped'],
    "sittha": ['bhs', 'cped'],
    "sitthaka": ['cped'],
    "sitthāvakārakaṁ": ['cped'],
    "sitā": ['ap90', 'mw'],
    "sitābha": ['mw'],
    "sitābhikaṭabhī": ['mw'],
    "sitābhra": ['cae', 'mw'],
    "sitābhraka": ['mw'],
    "sitābhā": ['mw'],
    "sitābja": ['mw'],
    "sitādi": ['mw'],
    "sitāgra": ['mw'],
    "sitāhvaya": ['mw'],
    "sitājājī": ['mw'],
    "sitākhaṇḍa": ['mw'],
    "sitākhya": ['mw'],
    "sitākhyā": ['mw'],
    "sitālaka": ['mw'],
    "sitālarka": ['mw'],
    "sitālatā": ['mw'],
    "sitāli": ['mw'],
    "sitālikaṭabhī": ['mw'],
    "sitālikā": ['mw'],
    "sitāmbara": ['cae', 'mw'],
    "sitāmbhoja": ['mw'],
    "sitāmbuja": ['mw'],
    "sitāmoghā": ['mw'],
    "sitānana": ['mw'],
    "sitāpāka": ['mw'],
    "sitāpāṅga": ['cae', 'mw'],
    "sitārjaka": ['mw'],
    "sitārkaka": ['mw'],
    "sitāsita": ['cae', 'mw'],
    "sitāsitakamaladalanayanatā": ['mw'],
    "sitāsitalocana": ['bhs'],
    "sitāsitaroga": ['mw'],
    "sitāsitā": ['mw'],
    "sitātapatra": ['bhs', 'cae', 'mw'],
    "sitātapavāraṇa": ['cae', 'mw'],
    "sitātraya": ['mw'],
    "sitāvara": ['mw'],
    "sitāvarī": ['mw'],
    "sitāyudha": ['mw'],
    "sitāśva": ['mw'],
    "sitāṃśu": ['cae', 'ddsa', 'mw'],
    "sitāṃśuka": ['mw'],
    "sitāṃśutaila": ['mw'],
    "sitāṅga": ['bhs', 'mw'],
    "sitāṅgarāga": ['mw'],
    "sitāṅka": ['mw'],
    "sitīkṛ": ['ddsa', 'mw'],
    "sitīvāra": ['mw'],
    "siv": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "siva": ['cped', 'mw'],
    "sivaka": ['mw'],
    "sivara": ['mw'],
    "sivaraḥ": ['ap90'],
    "sivasa": ['mw'],
    "sivata": ['mw'],
    "sivikā": ['cped'],
    "sivāku": ['mw'],
    "siyaṁ": ['cped'],
    "siyaṁsu": ['cped'],
    "siyuṁ": ['cped'],
    "siyā": ['cped'],
    "siyāti": ['bhs'],
    "siñcaka": ['cped'],
    "siñcakacana": ['cped'],
    "siñcamāna": ['cped'],
    "siñcana": ['mw'],
    "siñcati": ['cped'],
    "siñcatā": ['mw'],
    "siñci": ['cped'],
    "siñcita": ['cped'],
    "siñcitvā": ['cped'],
    "siñcāpeti": ['cped'],
    "siñj": ['cae'],
    "siñjita": ['cae', 'ddsa', 'mw'],
    "siñjā": ['cae', 'mw'],
    "siñjāśvattha": ['mw'],
    "siāla": ['gra'],
    "siṁsapāvana": ['cped'],
    "siṃbā": ['ap90'],
    "siṃcitā": ['ap90'],
    "siṃdhu": ['ap90'],
    "siṃdhudeśaḥ": ['ap90'],
    "siṃdhukaḥ": ['ap90'],
    "siṃdhuraḥ": ['ap90'],
    "siṃdhuḥ": ['ap90'],
    "siṃdukaḥ": ['ap90'],
    "siṃdūraḥ": ['ap90'],
    "siṃdūrikā": ['ap90'],
    "siṃdūrita": ['ap90'],
    "siṃdūrī": ['ap90'],
    "siṃghaṇaṃ": ['ap90'],
    "siṃghiṇī": ['ap90'],
    "siṃha": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "siṃhabala": ['bhs', 'mw'],
    "siṃhabaladatta": ['mw'],
    "siṃhabhadra": ['mw'],
    "siṃhabhaṭa": ['mw'],
    "siṃhabhūbhṛt": ['mw'],
    "siṃhabhūpāla": ['mw'],
    "siṃhabāhu": ['mw'],
    "siṃhacandana": ['bhs'],
    "siṃhacandra": ['mw'],
    "siṃhacandrā": ['bhs', 'mw'],
    "siṃhacarman": ['cae', 'mw'],
    "siṃhadarpa": ['mw'],
    "siṃhadatta": ['bhs', 'cae', 'mw'],
    "siṃhadaṃṣṭra": ['cae', 'mw'],
    "siṃhadeva": ['cae', 'mw'],
    "siṃhadhvaja": ['bhs', 'mw'],
    "siṃhadhvani": ['cae', 'mw'],
    "siṃhadvār": ['cae', 'mw'],
    "siṃhadvāra": ['mw'],
    "siṃhadvīpa": ['mw'],
    "siṃhaga": ['mw'],
    "siṃhaghoṣa": ['bhs', 'mw'],
    "siṃhagiri": ['mw'],
    "siṃhagirīśvara": ['mw'],
    "siṃhagrīva": ['cae', 'mw'],
    "siṃhagupta": ['mw'],
    "siṃhagāminī": ['bhs', 'mw'],
    "siṃhahanu": ['bhs', 'mw'],
    "siṃhahanutā": ['mw'],
    "siṃhajaṭi": ['mw'],
    "siṃhajātaka": ['bhs'],
    "siṃhaka": ['bhs', 'mw'],
    "siṃhakalpā": ['bhs', 'mw'],
    "siṃhakarman": ['mw'],
    "siṃhakarṇa": ['mw'],
    "siṃhakarṇī": ['mw'],
    "siṃhakeli": ['mw'],
    "siṃhakesara": ['mw'],
    "siṃhakesarin": ['mw'],
    "siṃhaketu": ['bhs', 'mw'],
    "siṃhakeśarin": ['bhs'],
    "siṃhakośa": ['mw'],
    "siṃhakāraka": ['mw'],
    "siṃhala": ['bhs', 'cae', 'ddsa', 'mw'],
    "siṃhaladvīpa": ['mw'],
    "siṃhalagna": ['mw'],
    "siṃhalaka": ['mw'],
    "siṃhalakaṃ": ['ap90'],
    "siṃhalamba": ['mw'],
    "siṃhalarāja": ['bhs'],
    "siṃhalastha": ['mw'],
    "siṃhalasthā": ['mw'],
    "siṃhalatā": ['bhs'],
    "siṃhalaṃ": ['ap90'],
    "siṃhaloman": ['mw'],
    "siṃhalā": ['mw'],
    "siṃhalāsthāna": ['mw'],
    "siṃhalīla": ['mw'],
    "siṃhamahīpati": ['mw'],
    "siṃhamala": ['mw'],
    "siṃhamalla": ['mw'],
    "siṃhamati": ['bhs', 'mw'],
    "siṃhamukha": ['bhs', 'mw'],
    "siṃhamukhī": ['mw'],
    "siṃhamuktā": ['bhs'],
    "siṃhamāyā": ['mw'],
    "siṃhanandana": ['mw'],
    "siṃhanandi": ['bhs'],
    "siṃhanardin": ['mw'],
    "siṃhanāda": ['bhs', 'cae', 'mw'],
    "siṃhanādaguggulu": ['mw'],
    "siṃhanādaka": ['mw'],
    "siṃhanādanādin": ['bhs', 'mw'],
    "siṃhanādasādhana": ['mw'],
    "siṃhanādikā": ['mw'],
    "siṃhanādin": ['bhs', 'mw'],
    "siṃhanṛpa": ['mw'],
    "siṃhaparipṛcchā": ['bhs', 'mw'],
    "siṃhaparākrama": ['cae', 'mw'],
    "siṃhaparṇikā": ['mw'],
    "siṃhaparṇī": ['mw'],
    "siṃhapañjara": ['bhs'],
    "siṃhapippalī": ['mw'],
    "siṃhapota": ['bhs'],
    "siṃhapradīpa": ['mw'],
    "siṃhapragarjana": ['mw'],
    "siṃhapragarjita": ['mw'],
    "siṃhapratīka": ['cae', 'mw'],
    "siṃhapraṇāda": ['cae', 'mw'],
    "siṃhapucchikā": ['mw'],
    "siṃhapucchī": ['mw'],
    "siṃhapura": ['bhs', 'cae', 'mw'],
    "siṃhapuraka": ['mw'],
    "siṃhapuṣpī": ['mw'],
    "siṃhapūrvārdhakāyatā": ['mw'],
    "siṃharatha": ['mw'],
    "siṃharathā": ['mw'],
    "siṃharava": ['cae', 'mw'],
    "siṃharaśmi": ['mw'],
    "siṃharotsikā": ['mw'],
    "siṃharāj": ['mw'],
    "siṃharāja": ['mw'],
    "siṃharṣabha": ['cae', 'mw'],
    "siṃhasaudāsa": ['bhs'],
    "siṃhasaṃhanana": ['cae', 'mw'],
    "siṃhasaṃvat": ['mw'],
    "siṃhasena": ['mw'],
    "siṃhasiddhāntasindhu": ['mw'],
    "siṃhaskandha": ['cae', 'mw'],
    "siṃhastha": ['mw'],
    "siṃhasthamakarasthagurunirṇaya": ['mw'],
    "siṃhasthamāhātmya": ['mw'],
    "siṃhasthasnānapaddhati": ['mw'],
    "siṃhasvāmin": ['mw'],
    "siṃhasāgarakūṭavinanditarāja": ['bhs'],
    "siṃhasāhi": ['mw'],
    "siṃhatala": ['mw'],
    "siṃhateja": ['bhs'],
    "siṃhatilakasūri": ['mw'],
    "siṃhatuṇḍa": ['cae', 'mw'],
    "siṃhatuṇḍaka": ['mw'],
    "siṃhatva": ['mw'],
    "siṃhatā": ['mw'],
    "siṃhatāla": ['mw'],
    "siṃhatālākhya": ['mw'],
    "siṃhavaktra": ['mw'],
    "siṃhavarman": ['cae', 'ddsa', 'mw'],
    "siṃhavatsa": ['bhs', 'mw'],
    "siṃhavijṛmbhita": ['bhs', 'mw'],
    "siṃhavijṛmbhitaprabha": ['bhs'],
    "siṃhavijṛmbhitā": ['bhs'],
    "siṃhavikrama": ['mw'],
    "siṃhavikrānta": ['mw'],
    "siṃhavikrāntagati": ['mw'],
    "siṃhavikrāntagāmin": ['bhs', 'mw'],
    "siṃhavikrāntagāmitā": ['mw'],
    "siṃhavikrīḍita": ['bhs', 'mw'],
    "siṃhavinardita": ['bhs'],
    "siṃhavinnā": ['mw'],
    "siṃhaviṣkambhita": ['bhs', 'mw'],
    "siṃhaviṣṭara": ['mw'],
    "siṃhavyāghra": ['mw'],
    "siṃhavyāghrakroḍa": ['mw'],
    "siṃhavyāghralakṣaṇa": ['mw'],
    "siṃhavyāghralakṣaṇaprakāśa": ['mw'],
    "siṃhavyāghralakṣaṇarahasya": ['mw'],
    "siṃhavyāghralakṣaṇī": ['mw'],
    "siṃhavyāghraniṣevita": ['mw'],
    "siṃhavyāghrarahasya": ['mw'],
    "siṃhavyāghraṭippaṇī": ['mw'],
    "siṃhavyāghraṭīkā": ['mw'],
    "siṃhavyāghrāmiṣīkṛ": ['mw'],
    "siṃhavyāghrī": ['mw'],
    "siṃhavyāghrīya": ['mw'],
    "siṃhavāha": ['mw'],
    "siṃhavāhana": ['mw'],
    "siṃhavāhanā": ['mw'],
    "siṃhavāhin": ['mw'],
    "siṃhavāhinī": ['mw'],
    "siṃhayānā": ['mw'],
    "siṃhaśayyā": ['bhs'],
    "siṃhaśiśu": ['cae', 'mw'],
    "siṃhaśrī": ['mw'],
    "siṃhaśāva": ['cae', 'mw'],
    "siṃhaḥ": ['ap90'],
    "siṃhendra": ['mw'],
    "siṃhikeya": ['mw'],
    "siṃhikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "siṃhikāputra": ['mw'],
    "siṃhikāsuta": ['mw'],
    "siṃhikāsūnu": ['mw'],
    "siṃhikātanaya": ['mw'],
    "siṃhila": ['mw'],
    "siṃhinī": ['mw'],
    "siṃhiya": ['mw'],
    "siṃhoddhatā": ['mw'],
    "siṃhonnatā": ['mw'],
    "siṃhoraska": ['bhs'],
    "siṃhā": ['mw'],
    "siṃhācala": ['mw'],
    "siṃhācalamāhātmya": ['mw'],
    "siṃhācārya": ['mw'],
    "siṃhājina": ['mw'],
    "siṃhākṣa": ['mw'],
    "siṃhānana": ['mw'],
    "siṃhānuvāka": ['mw'],
    "siṃhāsana": ['cae', 'mw'],
    "siṃhāsanabhraṣṭa": ['mw'],
    "siṃhāsanacakra": ['mw'],
    "siṃhāsanadvātriṃśat": ['mw'],
    "siṃhāsanadvātriṃśati": ['mw'],
    "siṃhāsanadvātriṃśatikā": ['mw'],
    "siṃhāsanadvātriṃśatkathā": ['mw'],
    "siṃhāsanadvātriṃśatputrikāvārttā": ['mw'],
    "siṃhāsanadvātriṃśatputtalikāvārttā": ['mw'],
    "siṃhāsanadvātriṃśikā": ['mw'],
    "siṃhāsanaraṇa": ['mw'],
    "siṃhāsanastha": ['mw'],
    "siṃhāsanatraya": ['mw'],
    "siṃhāsapīṭha": ['bhs'],
    "siṃhāstra": ['mw'],
    "siṃhāsya": ['mw'],
    "siṃhāsyā": ['mw'],
    "siṃhāvaloka": ['mw'],
    "siṃhāvalokana": ['ddsa', 'mw'],
    "siṃhāvalokananyāyena": ['mw'],
    "siṃhāvalokanena": ['mw'],
    "siṃhāvalokita": ['mw'],
    "siṃhāy": ['cae'],
    "siṃhāya": ['ddsa', 'mw'],
    "siṃhāḍhya": ['mw'],
    "siṃhāṅgada": ['bhs'],
    "siṃhāṇa": ['bhs', 'mw'],
    "siṃhāṇaka": ['bhs', 'mw'],
    "siṃhāṇaṃ": ['ap90'],
    "siṃhī": ['ap90', 'ddsa', 'gra', 'mw'],
    "siṃhībhū": ['ddsa', 'mw'],
    "siṃhīkṛ": ['cae', 'mw'],
    "siṃhīlatā": ['mw'],
    "siṃjitaṃ": ['ap90'],
    "siṃjā": ['ap90'],
    "siṃsapā": ['mw'],
    "siṅga": ['cped'],
    "siṅgabhūpāla": ['mw'],
    "siṅghati": ['cped'],
    "siṅghaṇadeva": ['mw'],
    "siṅghi": ['cped'],
    "siṅghitvā": ['cped'],
    "siṅghiṇī": ['mw'],
    "siṅghāṇa": ['bhs', 'mw'],
    "siṅghāṇaka": ['mw'],
    "siṅghāṇikā": ['cped', 'mw'],
    "siṅghāṭaka": ['cped'],
    "siṅgivera": ['cped'],
    "siṅgābhaṭṭa": ['mw'],
    "siṅgābhaṭṭīya": ['mw'],
    "siṅgāpidi": ['mw'],
    "siṅgāra": ['cped'],
    "siṅgī": ['cped'],
    "siṅgīnada": ['cped'],
    "siṅgīvaṇṇa": ['cped'],
    "siṇḍākī": ['mw'],
    "siṣaṃgrāmayiṣu": ['mw'],
    "siṣevayiṣu": ['mw'],
    "siṣmiyāṇa": ['mw'],
    "siṣādhayiṣu": ['mw'],
    "siṣādhayiṣā": ['ap90', 'ddsa', 'mw'],
    "siṣāsani": ['cae', 'gra', 'mw'],
    "siṣāsatu": ['cae', 'gra', 'mw'],
    "siṣāsu": ['cae', 'ddsa', 'gra', 'mw'],
    "siṣṇu": ['cae', 'ddsa', 'gra', 'mw'],
    "siṣṇāsu": ['mw'],
    "siṭ": ['ap90', 'mw'],
    "skabdha": ['ap90', 'mw'],
    "skabh": ['ddsa', 'gra', 'mw'],
    "skabhana": ['ddsa', 'mw'],
    "skabhita": ['mw'],
    "skabhāy": ['cae', 'gra'],
    "skabhāya": ['ddsa'],
    "skabhīyas": ['gra', 'mw'],
    "skabhīyaṃs": ['cae'],
    "skad": ['ddsa', 'gra'],
    "skambh": ['cae', 'gra', 'mw'],
    "skambha": ['cae', 'ddsa', 'gra', 'mw'],
    "skambhadeṣṇa": ['cae', 'gra', 'mw'],
    "skambhana": ['cae', 'ddsa', 'gra', 'mw'],
    "skambhani": ['mw'],
    "skambhanī": ['mw'],
    "skambhasarjana": ['mw'],
    "skambhasarjanī": ['mw'],
    "skambhākṛta": ['bhs'],
    "skand": ['cae', 'gra', 'mw'],
    "skanda": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "skandabhaṭa": ['mw'],
    "skandabhaṭṭa": ['mw'],
    "skandadāsa": ['mw'],
    "skandagraha": ['mw'],
    "skandagupta": ['mw'],
    "skandaguru": ['mw'],
    "skandajananī": ['mw'],
    "skandajit": ['mw'],
    "skandaka": ['mw'],
    "skandakagrāma": ['mw'],
    "skandakavaca": ['mw'],
    "skandamātṛ": ['mw'],
    "skandana": ['cae', 'ddsa', 'mw'],
    "skandanīya": ['mw'],
    "skandapura": ['mw'],
    "skandapurāṇa": ['cae', 'mw'],
    "skandapurāṇasamuccaya": ['mw'],
    "skandapurāṇīya": ['mw'],
    "skandaputra": ['cae', 'ddsa', 'mw'],
    "skandarāja": ['mw'],
    "skandasahasranāman": ['mw'],
    "skandaskāraśaṃkara": ['mw'],
    "skandastotra": ['mw'],
    "skandasvāmin": ['mw'],
    "skandatva": ['mw'],
    "skandatā": ['mw'],
    "skandavarman": ['mw'],
    "skandaviśākha": ['mw'],
    "skandayāga": ['mw'],
    "skandayāmalatantra": ['mw'],
    "skandaṣaṣṭhī": ['mw'],
    "skandaṣaṣṭhīvrata": ['mw'],
    "skandeśvaratīrtha": ['mw'],
    "skandh": ['mw'],
    "skandha": ['bhs', 'cae', 'ddsa', 'mw'],
    "skandhabandhanā": ['mw'],
    "skandhacāpa": ['mw'],
    "skandhadeśa": ['cae', 'mw'],
    "skandhaja": ['mw'],
    "skandhaka": ['mw'],
    "skandhamallaka": ['mw'],
    "skandhamaya": ['mw'],
    "skandhamaṇi": ['mw'],
    "skandhamāra": ['bhs', 'mw'],
    "skandhaparinirvāṇa": ['mw'],
    "skandhaphala": ['mw'],
    "skandhapradeśa": ['mw'],
    "skandhapāda": ['mw'],
    "skandhapīṭha": ['mw'],
    "skandharuha": ['mw'],
    "skandharāja": ['mw'],
    "skandhas": ['cae', 'ddsa', 'gra', 'mw'],
    "skandhastambhi": ['mw'],
    "skandhasvāmin": ['mw'],
    "skandhasvāti": ['mw'],
    "skandhataru": ['mw'],
    "skandhavaha": ['mw'],
    "skandhavant": ['cae'],
    "skandhavat": ['mw'],
    "skandhaviśākha": ['mw'],
    "skandhavāha": ['mw'],
    "skandhavāhaka": ['mw'],
    "skandhavāhya": ['mw'],
    "skandhaśiras": ['cae', 'mw'],
    "skandhaśākhā": ['mw'],
    "skandhaśṛṅga": ['mw'],
    "skandhemukha": ['mw'],
    "skandhika": ['mw'],
    "skandhila": ['mw'],
    "skandhin": ['cae', 'mw'],
    "skandho": ['mw'],
    "skandhogrīvī": ['mw'],
    "skandhopaneya": ['mw'],
    "skandhopariṣvajānika": ['bhs'],
    "skandhya": ['cae', 'ddsa', 'mw'],
    "skandhā": ['mw'],
    "skandhāgni": ['mw'],
    "skandhākṣa": ['bhs', 'mw'],
    "skandhānala": ['mw'],
    "skandhāvāra": ['cae', 'ddsa', 'mw'],
    "skandhīkṛ": ['mw'],
    "skandilācārya": ['mw'],
    "skandin": ['ddsa', 'mw'],
    "skandita": ['cae', 'mw'],
    "skandola": ['mw'],
    "skandopaniṣad": ['mw'],
    "skandopapurāṇa": ['mw'],
    "skandya": ['mw'],
    "skandāgni": ['mw'],
    "skandāpasmāra": ['mw'],
    "skandāpasmārin": ['mw'],
    "skandārya": ['mw'],
    "skandāṃśaka": ['mw'],
    "skanna": ['ap90', 'ddsa', 'mw'],
    "skannabhāga": ['mw'],
    "skannatva": ['mw'],
    "skanttṛ": ['mw'],
    "skaunagarika": ['mw'],
    "skavana": ['mw'],
    "skaṃbh": ['ap90'],
    "skaṃbhanaṃ": ['ap90'],
    "skaṃbhaḥ": ['ap90'],
    "skaṃd": ['ap90'],
    "skaṃdakaḥ": ['ap90'],
    "skaṃdanaṃ": ['ap90'],
    "skaṃdaḥ": ['ap90'],
    "skaṃdh": ['ap90'],
    "skaṃdhas": ['ap90'],
    "skaṃdhaḥ": ['ap90'],
    "skaṃdhikaḥ": ['ap90'],
    "skaṃdhin": ['ap90'],
    "skhad": ['ap90', 'mw'],
    "skhadana": ['mw'],
    "skhadanaṃ": ['ap90'],
    "skhadyā": ['mw'],
    "skhadā": ['mw'],
    "skhal": ['ap90', 'cae', 'ddsa', 'mw'],
    "skhala": ['cae', 'ddsa', 'mw'],
    "skhalad": ['mw'],
    "skhaladvalaya": ['mw'],
    "skhaladvākya": ['mw'],
    "skhalan": ['mw'],
    "skhalana": ['cae', 'mw'],
    "skhalanaṃ": ['ap90'],
    "skhalanmati": ['mw'],
    "skhalat": ['mw'],
    "skhalita": ['ap90', 'cae', 'mw'],
    "skhalitagati": ['mw'],
    "skhalitasubhagam": ['mw'],
    "skhalitavat": ['mw'],
    "skhalitavīrya": ['mw'],
    "skhid": ['gra'],
    "skhuḍ": ['ap90', 'mw'],
    "skonagara": ['mw'],
    "skoṭikā": ['mw'],
    "sku": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "skumbh": ['mw'],
    "skund": ['mw'],
    "skuṃbh": ['ap90'],
    "skuṃd": ['ap90'],
    "skāmbhāyana": ['mw'],
    "skāmbhāyanya": ['mw'],
    "skānda": ['ddsa', 'mw'],
    "skāndabhāṣya": ['mw'],
    "skāndaviśākha": ['mw'],
    "skāndhin": ['mw'],
    "skāndāyana": ['mw'],
    "skāndāyanya": ['mw'],
    "skāṃda": ['ap90'],
    "skṛ": ['ddsa', 'gra', 'mw'],
    "skṛdhoyu": ['cae', 'gra', 'mw'],
    "skṛt": ['mw'],
    "sma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "smad": ['gra', 'mw'],
    "smadabhīśu": ['cae', 'gra', 'mw'],
    "smaddiṣṭi": ['cae', 'gra', 'mw'],
    "smadibha": ['cae', 'gra', 'mw'],
    "smadiṣṭa": ['cae', 'ddsa', 'gra', 'mw'],
    "smadrātiṣac": ['mw'],
    "smadrātiṣāc": ['gra'],
    "smadūdhan": ['gra'],
    "smadūdhnī": ['cae', 'mw'],
    "smahe": ['ddsa'],
    "sman": ['mw'],
    "smar": ['gra'],
    "smara": ['cae', 'ddsa', 'mw'],
    "smarabhāsita": ['mw'],
    "smarabhū": ['mw'],
    "smarabāṇapaṅkti": ['mw'],
    "smaracakra": ['mw'],
    "smaracandra": ['mw'],
    "smaracchattra": ['mw'],
    "smaradahana": ['mw'],
    "smaradaśā": ['ddsa', 'mw'],
    "smaradhvaja": ['mw'],
    "smaradhvajā": ['mw'],
    "smaradurmada": ['mw'],
    "smaradāyin": ['cae', 'mw'],
    "smaradīpana": ['cae', 'mw'],
    "smaradīpikā": ['mw'],
    "smaraguru": ['mw'],
    "smaragṛha": ['mw'],
    "smarahara": ['mw'],
    "smarajvara": ['mw'],
    "smarajīvanī": ['mw'],
    "smarakarman": ['mw'],
    "smarakathā": ['cae', 'mw'],
    "smarakāra": ['cae', 'mw'],
    "smarakūpaka": ['mw'],
    "smarakūpikā": ['mw'],
    "smaralekha": ['mw'],
    "smaralekhanī": ['mw'],
    "smaramandira": ['mw'],
    "smaramaya": ['mw'],
    "smaramoha": ['mw'],
    "smaramohita": ['mw'],
    "smaramuṣ": ['mw'],
    "smaranipuṇa": ['mw'],
    "smarapriyā": ['mw'],
    "smarapīḍita": ['mw'],
    "smararuj": ['mw'],
    "smarasaha": ['mw'],
    "smarasakha": ['cae', 'mw'],
    "smarasmarya": ['mw'],
    "smarastambha": ['mw'],
    "smarasāyakalakṣya": ['mw'],
    "smarasāyakalakṣyatā": ['mw'],
    "smaratattvaprakāśikā": ['mw'],
    "smaratva": ['mw'],
    "smaratā": ['mw'],
    "smaratāpamaya": ['ddsa', 'mw'],
    "smaravadhūya": ['mw'],
    "smaravallabha": ['mw'],
    "smaravatī": ['mw'],
    "smaravīthikā": ['mw'],
    "smaravṛddhi": ['mw'],
    "smaravṛddhisaṃjña": ['mw'],
    "smaraśabara": ['mw'],
    "smaraśaramaya": ['mw'],
    "smaraśatru": ['mw'],
    "smaraśāsana": ['cae', 'mw'],
    "smaraśāstra": ['mw'],
    "smaraḥ": ['ap90'],
    "smaraṇa": ['cae', 'mw'],
    "smaraṇabhū": ['mw'],
    "smaraṇakramamālā": ['mw'],
    "smaraṇamaṅgala": ['mw'],
    "smaraṇamaṅgalaikādaśaka": ['mw'],
    "smaraṇapadavī": ['mw'],
    "smaraṇaṃ": ['ap90'],
    "smaraṇika": ['bhs'],
    "smaraṇānugraha": ['mw'],
    "smaraṇāpatyatarpaka": ['mw'],
    "smaraṇāyaugapadya": ['mw'],
    "smaraṇī": ['mw'],
    "smaraṇīya": ['cae', 'ddsa', 'mw'],
    "smareṣudhīkṛ": ['mw'],
    "smaroddīpana": ['mw'],
    "smarodgītha": ['mw'],
    "smaronmāda": ['mw'],
    "smaropakaraṇa": ['mw'],
    "smarotsuka": ['mw'],
    "smartavya": ['cae', 'ddsa', 'mw'],
    "smartṛ": ['mw'],
    "smartṛtva": ['mw'],
    "smarya": ['mw'],
    "smarādhivāsa": ['mw'],
    "smarāgāra": ['mw'],
    "smarākula": ['mw'],
    "smarākulita": ['mw'],
    "smarākṛṣṭa": ['mw'],
    "smarāmra": ['mw'],
    "smarāndha": ['mw'],
    "smarāri": ['cae', 'mw'],
    "smarārta": ['mw'],
    "smarāsava": ['mw'],
    "smarātura": ['cae', 'mw'],
    "smarāṅkuśa": ['mw'],
    "smat": ['cae', 'ddsa', 'mw'],
    "smatpuraṃdhi": ['gra', 'mw'],
    "smaya": ['cae', 'ddsa', 'mw'],
    "smayadāna": ['mw'],
    "smayana": ['cae', 'mw'],
    "smayanutti": ['mw'],
    "smayanīya": ['mw'],
    "smayaḥ": ['ap90'],
    "smayin": ['cae', 'mw'],
    "smayādika": ['mw'],
    "smayāka": ['mw'],
    "smera": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "smeramukha": ['mw'],
    "smeratā": ['mw'],
    "smeraviṣkira": ['mw'],
    "smetavya": ['mw'],
    "smi": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "smita": ['ap90', 'cae', 'ddsa', 'mw'],
    "smitadṛś": ['mw'],
    "smitamukha": ['mw'],
    "smitapūrva": ['cae', 'mw'],
    "smitapūrvam": ['mw'],
    "smitapūrvābhibhāṣin": ['mw'],
    "smitapūrvābhibhāṣitā": ['mw'],
    "smitavāc": ['mw'],
    "smitaśobhin": ['mw'],
    "smitaśālin": ['mw'],
    "smiti": ['mw'],
    "smitiḥ": ['ap90'],
    "smitojjvala": ['cae', 'mw'],
    "smitīmukha": ['bhs'],
    "smiṭ": ['ap90', 'mw'],
    "smottara": ['mw'],
    "smā": ['gra', 'mw'],
    "smāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "smāraka": ['ap90', 'mw'],
    "smārakatva": ['mw'],
    "smāram": ['cae', 'ddsa', 'mw'],
    "smāraṇa": ['cae', 'mw'],
    "smāraṇaṃ": ['ap90'],
    "smāraṇā": ['mw'],
    "smāraṇī": ['mw'],
    "smārin": ['cae', 'mw'],
    "smārita": ['mw'],
    "smārta": ['ap90', 'cae', 'ddsa', 'mw'],
    "smārtabhaṭṭācārya": ['mw'],
    "smārtadīpikā": ['mw'],
    "smārtahomapariśiṣṭa": ['mw'],
    "smārtakarman": ['mw'],
    "smārtakutūhala": ['mw'],
    "smārtakāla": ['mw'],
    "smārtapadārthasaṃgraha": ['mw'],
    "smārtapaṇḍita": ['mw'],
    "smārtapradīpikā": ['mw'],
    "smārtaprayoga": ['mw'],
    "smārtaprayogakārikā": ['mw'],
    "smārtaprāyaścitta": ['mw'],
    "smārtaprāyaścittapaddhati": ['mw'],
    "smārtaprāyaścittavinirṇaya": ['mw'],
    "smārtaprāyaścittoddhāra": ['mw'],
    "smārtarāma": ['mw'],
    "smārtasamuccaya": ['mw'],
    "smārtasūtra": ['mw'],
    "smārtavyavasthārṇava": ['mw'],
    "smārtika": ['mw'],
    "smārtopāsanapaddhati": ['mw'],
    "smārtādhāna": ['mw'],
    "smārtādhānavidhi": ['mw'],
    "smārtānuṣṭhānapaddhati": ['mw'],
    "smārtāṇḍabilā": ['mw'],
    "smārya": ['mw'],
    "smīl": ['ap90', 'mw'],
    "smṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "smṛta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "smṛtamātra": ['mw'],
    "smṛtamātrāgata": ['mw'],
    "smṛti": ['bhs', 'cae', 'ddsa', 'mw'],
    "smṛtibhraṃśa": ['cae', 'mw'],
    "smṛtibhāskara": ['mw'],
    "smṛtibhū": ['cae', 'mw'],
    "smṛticandra": ['mw'],
    "smṛticandrikā": ['mw'],
    "smṛticandrodaya": ['mw'],
    "smṛticaraṇa": ['mw'],
    "smṛticintāmaṇi": ['mw'],
    "smṛtida": ['mw'],
    "smṛtidarpaṇa": ['mw'],
    "smṛtidīpa": ['mw'],
    "smṛtidīpikā": ['mw'],
    "smṛtigrantharāja": ['mw'],
    "smṛtigītā": ['mw'],
    "smṛtiharikā": ['mw'],
    "smṛtiharā": ['mw'],
    "smṛtihetu": ['mw'],
    "smṛtihīna": ['mw'],
    "smṛtijāta": ['mw'],
    "smṛtika": ['mw'],
    "smṛtikalpadruma": ['mw'],
    "smṛtikaraṇḍikā": ['mw'],
    "smṛtikaumudī": ['mw'],
    "smṛtikaumudīṭīkā": ['mw'],
    "smṛtiketurājaśri": ['bhs'],
    "smṛtikālataraṃga": ['mw'],
    "smṛtikārin": ['cae', 'mw'],
    "smṛtilabdhā": ['bhs'],
    "smṛtilopa": ['mw'],
    "smṛtimahārṇava": ['mw'],
    "smṛtimant": ['bhs', 'cae'],
    "smṛtimantaka": ['bhs'],
    "smṛtimat": ['mw'],
    "smṛtimattaka": ['bhs'],
    "smṛtimaya": ['cae', 'mw'],
    "smṛtimañjarī": ['mw'],
    "smṛtimañjūṣā": ['mw'],
    "smṛtimuktāphala": ['mw'],
    "smṛtimuktāvalī": ['mw'],
    "smṛtimīmāṃsā": ['mw'],
    "smṛtinibandha": ['mw'],
    "smṛtiparibhāṣā": ['mw'],
    "smṛtipariccheda": ['mw'],
    "smṛtipatha": ['mw'],
    "smṛtiprabandha": ['mw'],
    "smṛtipradīpa": ['mw'],
    "smṛtiprakāsa": ['mw'],
    "smṛtipratyavamarśa": ['mw'],
    "smṛtiprayojana": ['mw'],
    "smṛtiprāmāṇyārthavāda": ['mw'],
    "smṛtipāda": ['mw'],
    "smṛtipāṭhaka": ['cae', 'mw'],
    "smṛtirahasya": ['mw'],
    "smṛtiratna": ['mw'],
    "smṛtiratnakośa": ['mw'],
    "smṛtiratnamahodadhi": ['mw'],
    "smṛtiratnaviveka": ['mw'],
    "smṛtiratnākara": ['mw'],
    "smṛtiratnāvalī": ['mw'],
    "smṛtirañjanī": ['mw'],
    "smṛtirodha": ['mw'],
    "smṛtisammata": ['mw'],
    "smṛtisamuccaya": ['mw'],
    "smṛtisamudramukha": ['bhs'],
    "smṛtisarojasundara": ['mw'],
    "smṛtisarvasva": ['mw'],
    "smṛtisaṃgraha": ['mw'],
    "smṛtisaṃgraharatnavyākhyāna": ['mw'],
    "smṛtisaṃgrahasāra": ['mw'],
    "smṛtisaṃhitā": ['mw'],
    "smṛtisaṃskāra": ['mw'],
    "smṛtisaṃskārakaustubha": ['mw'],
    "smṛtisaṃskārarahasya": ['mw'],
    "smṛtisaṃskāravicāra": ['mw'],
    "smṛtisaṃskāravāda": ['mw'],
    "smṛtisiddha": ['mw'],
    "smṛtisiddhāntasaṃgraha": ['mw'],
    "smṛtisindhu": ['mw'],
    "smṛtisudhākara": ['mw'],
    "smṛtisādhya": ['mw'],
    "smṛtisāgara": ['mw'],
    "smṛtisāgarasaṃgraha": ['mw'],
    "smṛtisāgarasāra": ['mw'],
    "smṛtisāra": ['mw'],
    "smṛtisārasamuccaya": ['mw'],
    "smṛtisārasarvasva": ['mw'],
    "smṛtisārasaṃgraha": ['mw'],
    "smṛtisāravyavasthā": ['mw'],
    "smṛtisārāvalī": ['mw'],
    "smṛtitantra": ['mw'],
    "smṛtitattva": ['mw'],
    "smṛtitattvaprakāśa": ['mw'],
    "smṛtitattvaviveka": ['mw'],
    "smṛtitattvāmṛta": ['mw'],
    "smṛtivardhanī": ['mw'],
    "smṛtivartman": ['mw'],
    "smṛtivibhrama": ['cae', 'mw'],
    "smṛtivid": ['mw'],
    "smṛtivinaya": ['bhs', 'mw'],
    "smṛtivirodha": ['mw'],
    "smṛtiviruddha": ['mw'],
    "smṛtivivaraṇa": ['mw'],
    "smṛtiviveka": ['mw'],
    "smṛtiviṣaya": ['mw'],
    "smṛtivyavasthā": ['mw'],
    "smṛtivāda": ['mw'],
    "smṛtivākyāpeta": ['mw'],
    "smṛtiśaithilya": ['mw'],
    "smṛtiśataka": ['mw'],
    "smṛtiśekhara": ['mw'],
    "smṛtiśeṣa": ['mw'],
    "smṛtiśrī": ['bhs'],
    "smṛtiśāstra": ['cae', 'mw'],
    "smṛtiśīla": ['mw'],
    "smṛtiḥ": ['ap90'],
    "smṛto": ['mw'],
    "smṛty": ['mw'],
    "smṛtyadhikaraṇa": ['mw'],
    "smṛtyantara": ['mw'],
    "smṛtyapeta": ['mw'],
    "smṛtyapramoṣa": ['mw'],
    "smṛtyartharatnākara": ['mw'],
    "smṛtyarthasāgara": ['mw'],
    "smṛtyarthasāra": ['mw'],
    "smṛtyukta": ['mw'],
    "smṛtyupasthāna": ['bhs', 'mw'],
    "sna": ['mw'],
    "snai": ['ap90', 'mw'],
    "snaigdhya": ['ddsa', 'mw'],
    "snaigdhyaṃ": ['ap90'],
    "snaihika": ['mw'],
    "snapana": ['ap90', 'cae', 'ddsa', 'mw'],
    "snapita": ['ap90', 'mw'],
    "snas": ['ap90', 'mw'],
    "snasā": ['ap90', 'mw'],
    "snava": ['mw'],
    "snavana": ['mw'],
    "snavaḥ": ['ap90'],
    "snaya": ['mw'],
    "snedana": ['bhs'],
    "sneha": ['cae', 'cped', 'ddsa', 'mw'],
    "snehabaddha": ['mw'],
    "snehabandha": ['mw'],
    "snehabhaṅga": ['mw'],
    "snehabhāṇḍa": ['mw'],
    "snehabhāṇḍajīvin": ['mw'],
    "snehabhū": ['mw'],
    "snehabhūmi": ['cae', 'mw'],
    "snehabhūyiṣṭha": ['mw'],
    "snehabīja": ['mw'],
    "snehaccheda": ['ddsa', 'mw'],
    "snehadviṣ": ['mw'],
    "snehaghaṭa": ['cae', 'mw'],
    "snehaghnī": ['mw'],
    "snehaguru": ['cae', 'mw'],
    "snehaguṇita": ['mw'],
    "snehaka": ['bhs', 'mw'],
    "snehakartṛ": ['mw'],
    "snehakesarin": ['mw'],
    "snehakumbha": ['cae', 'mw'],
    "snehala": ['cae', 'ddsa', 'mw'],
    "snehalatā": ['mw'],
    "snehalavaṇa": ['mw'],
    "snehalābha": ['bhs'],
    "snehamaya": ['cae', 'mw'],
    "snehan": ['ap90', 'mw'],
    "snehana": ['ap90', 'cae', 'mw'],
    "snehanīya": ['mw'],
    "snehapakva": ['mw'],
    "snehaprasara": ['mw'],
    "snehaprasrava": ['mw'],
    "snehapravṛtti": ['mw'],
    "snehapriya": ['mw'],
    "snehapāna": ['mw'],
    "snehapātra": ['mw'],
    "snehapīta": ['mw'],
    "snehapūra": ['mw'],
    "snehapūrvam": ['mw'],
    "sneharasana": ['mw'],
    "sneharaṅga": ['mw'],
    "sneharekabhū": ['mw'],
    "snehasambhāṣa": ['mw'],
    "snehasaṃjvaravant": ['cae'],
    "snehasaṃjvaravat": ['mw'],
    "snehasaṃskṛta": ['mw'],
    "snehasaṃyukta": ['cae', 'mw'],
    "snehasāra": ['mw'],
    "snehavacas": ['mw'],
    "snehavant": ['cae'],
    "snehavara": ['mw'],
    "snehavarti": ['mw'],
    "snehavasti": ['mw'],
    "snehavat": ['ddsa', 'mw'],
    "snehavatī": ['mw'],
    "snehaviddha": ['mw'],
    "snehavimardita": ['mw'],
    "snehavyakti": ['mw'],
    "snehayitavya": ['mw'],
    "snehaśarkarā": ['mw'],
    "snehaḥ": ['ap90'],
    "snehin": ['ap90', 'cae', 'ddsa', 'mw'],
    "snehita": ['ap90', 'bhs', 'mw'],
    "snehitavya": ['mw'],
    "snehiti": ['mw'],
    "snehitī": ['gra'],
    "snehu": ['mw'],
    "snehuḥ": ['ap90'],
    "snehya": ['mw'],
    "snehābhyakta": ['mw'],
    "snehākta": ['mw'],
    "snehākula": ['mw'],
    "snehākūta": ['cae', 'mw'],
    "snehānuvṛtti": ['mw'],
    "snehāśa": ['mw'],
    "snehāśaya": ['mw'],
    "snehāṅkana": ['cae', 'mw'],
    "sneya": ['cae', 'mw'],
    "snigdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "snigdhabhinnāñjana": ['cae', 'mw'],
    "snigdhadala": ['mw'],
    "snigdhadāru": ['mw'],
    "snigdhagātra": ['bhs'],
    "snigdhajana": ['mw'],
    "snigdhaka": ['bhs'],
    "snigdhakandā": ['mw'],
    "snigdhakeśatā": ['mw'],
    "snigdham": ['mw'],
    "snigdhamudga": ['cae', 'mw'],
    "snigdhanakhatā": ['mw'],
    "snigdhaparṇī": ['mw'],
    "snigdhapattra": ['mw'],
    "snigdhapattraka": ['mw'],
    "snigdhaphalā": ['mw'],
    "snigdhapiṇḍītaka": ['mw'],
    "snigdhapāṇilekhatā": ['mw'],
    "snigdharāji": ['mw'],
    "snigdhatama": ['mw'],
    "snigdhataṇḍula": ['mw'],
    "snigdhatva": ['mw'],
    "snigdhatyāga": ['mw'],
    "snigdhatā": ['ap90', 'mw'],
    "snigdhavarṇa": ['mw'],
    "snigdhaśītarūkṣa": ['cae', 'mw'],
    "snigdhaśītarūkṣatva": ['mw'],
    "snigdhoṣṇa": ['mw'],
    "snigdhā": ['ap90', 'mw'],
    "snigdhāñjana": ['cae', 'mw'],
    "snih": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "snihiti": ['cae', 'mw'],
    "sniṭ": ['ap90', 'mw'],
    "snu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "snuc": ['mw'],
    "snughnikā": ['mw'],
    "snuh": ['ap90', 'ddsa', 'mw'],
    "snuhi": ['mw'],
    "snuhā": ['mw'],
    "snuhī": ['cae', 'mw'],
    "snuk": ['mw'],
    "snukchada": ['mw'],
    "snus": ['ap90', 'mw'],
    "snuta": ['ap90', 'mw'],
    "snuti": ['mw'],
    "snuṣā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "snuṣāga": ['cae', 'mw'],
    "snuṣātva": ['mw'],
    "snuṣāvat": ['mw'],
    "snuṣāśvaśurīyā": ['mw'],
    "snā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "snāna": ['cae', 'ddsa', 'mw'],
    "snānabhū": ['mw'],
    "snānabhūmi": ['mw'],
    "snānadroṇī": ['mw'],
    "snānadīpikā": ['mw'],
    "snānagṛha": ['cae', 'mw'],
    "snānakalaśa": ['mw'],
    "snānakumbha": ['mw'],
    "snānapaddhati": ['mw'],
    "snānasūtra": ['mw'],
    "snānasūtrabhāṣyavyākhyā": ['mw'],
    "snānasūtradīpikā": ['mw'],
    "snānasūtrapaddhati": ['mw'],
    "snānatīrtha": ['mw'],
    "snānatṛṇa": ['mw'],
    "snānavastra": ['cae', 'mw'],
    "snānaveśman": ['cae', 'mw'],
    "snānavidhi": ['mw'],
    "snānavidhikṣama": ['mw'],
    "snānavidhipaddhati": ['mw'],
    "snānavidhisūtrabhāṣya": ['mw'],
    "snānavāsas": ['mw'],
    "snānayātrika": ['mw'],
    "snānayātrā": ['mw'],
    "snānaśālā": ['mw'],
    "snānaśāṭī": ['cae', 'mw'],
    "snānaśīla": ['cae', 'mw'],
    "snānaṃ": ['ap90'],
    "snānin": ['cae', 'ddsa', 'mw'],
    "snānodaka": ['cae', 'ddsa', 'mw'],
    "snānopakaraṇa": ['cae', 'mw'],
    "snānottīrṇa": ['cae', 'mw'],
    "snānāgāra": ['mw'],
    "snānāmbu": ['cae', 'mw'],
    "snānīya": ['ap90', 'cae', 'mw'],
    "snānīyavastra": ['cae', 'mw'],
    "snānīyocchāditasnāta": ['mw'],
    "snāpaka": ['cae', 'ddsa', 'mw'],
    "snāpakaḥ": ['ap90'],
    "snāpana": ['cae', 'mw'],
    "snāpanavidhi": ['mw'],
    "snāpanaṃ": ['ap90'],
    "snāpanocchiṣṭabhojana": ['mw'],
    "snāpita": ['mw'],
    "snāsyat": ['mw'],
    "snāta": ['ap90', 'cae', 'mw'],
    "snātaka": ['cae', 'ddsa', 'mw'],
    "snātakavrata": ['mw'],
    "snātakavratin": ['mw'],
    "snātakaḥ": ['ap90'],
    "snātalipta": ['cae'],
    "snātavasya": ['mw'],
    "snātavat": ['mw'],
    "snātavrata": ['mw'],
    "snātavya": ['ddsa', 'mw'],
    "snātaśāṭaka": ['bhs'],
    "snātra": ['bhs', 'mw'],
    "snātva": ['cae', 'mw'],
    "snātvā": ['mw'],
    "snātvākālaka": ['mw'],
    "snātānulipta": ['cae', 'mw'],
    "snātṛ": ['gra', 'mw'],
    "snāva": ['mw'],
    "snāvaka": ['mw'],
    "snāvan": ['cae', 'ddsa', 'mw'],
    "snāvanya": ['mw'],
    "snāvasaṃtata": ['mw'],
    "snāvaḥ": ['ap90'],
    "snāvin": ['mw'],
    "snāvira": ['mw'],
    "snāyaka": ['bhs'],
    "snāyin": ['cae', 'ddsa', 'mw'],
    "snāyitā": ['mw'],
    "snāyu": ['cae', 'ddsa', 'mw'],
    "snāyubandha": ['cae', 'mw'],
    "snāyubandhana": ['mw'],
    "snāyujālavat": ['mw'],
    "snāyuka": ['mw'],
    "snāyukaḥ": ['ap90'],
    "snāyumarman": ['mw'],
    "snāyumaya": ['cae', 'mw'],
    "snāyunirmita": ['mw'],
    "snāyupāśa": ['mw'],
    "snāyurajju": ['mw'],
    "snāyuspanda": ['mw'],
    "snāyuyuta": ['cae', 'mw'],
    "snāyuḥ": ['ap90'],
    "snāyv": ['mw'],
    "snāyvarman": ['mw'],
    "snīhan": ['cae', 'ddsa', 'mw'],
    "snīhiti": ['cae', 'ddsa', 'gra', 'mw'],
    "snīhā": ['mw'],
    "snīḍha": ['mw'],
    "snūhan": ['cae', 'mw'],
    "so": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "sobbha": ['cped'],
    "sobha": ['mw'],
    "sobhagga": ['cped'],
    "sobhaggappatta": ['cped'],
    "sobhamāna": ['cped'],
    "sobhana": ['cped'],
    "sobhanta": ['cped'],
    "sobhari": ['cae', 'gra', 'mw'],
    "sobharī": ['gra', 'mw'],
    "sobharīyu": ['cae', 'gra', 'mw'],
    "sobhati": ['cped'],
    "sobhaya": ['mw'],
    "sobhaṇa": ['cped'],
    "sobhenta": ['cped'],
    "sobhesi": ['cped'],
    "sobheti": ['cped'],
    "sobhetvā": ['cped'],
    "sobhi": ['cped'],
    "sobhita": ['cped'],
    "sobhitvā": ['cped'],
    "sobhya": ['mw'],
    "sobhā": ['cped'],
    "sobhāñjana": ['mw'],
    "socamāna": ['cped'],
    "socanta": ['cped'],
    "socanā": ['cped'],
    "socati": ['cped'],
    "socchraya": ['mw'],
    "socchvāsa": ['ap90', 'cae', 'ddsa', 'mw'],
    "socchvāsam": ['mw'],
    "socchvāsatva": ['mw'],
    "soceyya": ['cped'],
    "soci": ['cped'],
    "socita": ['cped'],
    "socitabba": ['cped'],
    "socituṁ": ['cped'],
    "socitvā": ['cped'],
    "sodadhila": ['mw'],
    "sodaka": ['cae', 'cped', 'ddsa', 'mw'],
    "sodakumbha": ['mw'],
    "sodapūrvam": ['mw'],
    "sodara": ['ap90', 'cae', 'mw'],
    "sodarasneha": ['cae', 'mw'],
    "sodariya": ['cped'],
    "sodarka": ['mw'],
    "sodarya": ['cae', 'mw'],
    "sodaryasneha": ['cae', 'mw'],
    "sodaryavat": ['mw'],
    "sodaryaḥ": ['ap90'],
    "sodarī": ['mw'],
    "sodarīya": ['mw'],
    "sodaya": ['mw'],
    "sodayana": ['mw'],
    "sodbāṣpam": ['mw'],
    "soddharaṇa": ['mw'],
    "soddhāra": ['mw'],
    "soddhāravibhāgin": ['mw'],
    "sodha": ['mw'],
    "sodhaka": ['cped'],
    "sodhana": ['cped'],
    "sodhayamāna": ['cped'],
    "sodhenta": ['cped'],
    "sodhesi": ['cped'],
    "sodhetabba": ['cped'],
    "sodheti": ['cped'],
    "sodhetvā": ['cped'],
    "sodhita": ['cped'],
    "sodhāpesi": ['cped'],
    "sodhāpeti": ['cped'],
    "sodhāpetvā": ['cped'],
    "sodhāpita": ['cped'],
    "sodvega": ['ap90', 'cae', 'mw'],
    "sodvegam": ['mw'],
    "sodyama": ['mw'],
    "sodyoga": ['ap90', 'cae', 'mw'],
    "sogandhika": ['cped'],
    "sohajja": ['cped'],
    "sohalagrāma": ['mw'],
    "soham": ['mw'],
    "sohañji": ['mw'],
    "sohnoka": ['mw'],
    "sohāica": ['mw'],
    "soka": ['cped'],
    "sokaggi": ['cped'],
    "sokapareta": ['cped'],
    "sokasalla": ['cped'],
    "sokavinodana": ['cped'],
    "sokha": ['mw'],
    "sokhumma": ['cped'],
    "sokhya": ['cped'],
    "soktha": ['mw'],
    "sokthaka": ['mw'],
    "sokthya": ['mw'],
    "sokāpahata": ['cped'],
    "sokī": ['cped'],
    "sola": ['mw'],
    "solaṅka": ['mw'],
    "solika": ['mw'],
    "solkālātāvapothika": ['mw'],
    "sollekham": ['mw'],
    "sollekharekha": ['mw'],
    "solloka": ['mw'],
    "solluṃṭhaḥ": ['ap90'],
    "solluṇṭha": ['mw'],
    "solluṇṭhabhāṣaṇa": ['mw'],
    "solluṇṭhabhāṣita": ['mw'],
    "solluṇṭhana": ['mw'],
    "solluṇṭhavacana": ['mw'],
    "solluṇṭhokti": ['mw'],
    "sollāsa": ['mw'],
    "sollāsam": ['mw'],
    "solūka": ['mw'],
    "soma": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "somabandhu": ['mw'],
    "somabhakṣa": ['mw'],
    "somabhakṣajapa": ['mw'],
    "somabhakṣaprayoga": ['mw'],
    "somabhakṣaviveka": ['mw'],
    "somabhakṣayoḥprayoga": ['mw'],
    "somabhava": ['mw'],
    "somabhaṭṭa": ['mw'],
    "somabhojana": ['mw'],
    "somabhujagāvalī": ['mw'],
    "somabhuva": ['bhs'],
    "somabhāgavatācārya": ['mw'],
    "somabhāvā": ['mw'],
    "somabhū": ['mw'],
    "somabhūbhuj": ['mw'],
    "somabhūpāla": ['mw'],
    "somabhṛt": ['cae', 'mw'],
    "somabṛhaspati": ['mw'],
    "somacakṣas": ['mw'],
    "somacamasa": ['mw'],
    "somacandra": ['mw'],
    "somacandragaṇi": ['mw'],
    "somachattra": ['bhs'],
    "somacyuta": ['mw'],
    "somadaivajña": ['mw'],
    "somadaivatya": ['mw'],
    "somadakṣa": ['mw'],
    "somadarśana": ['bhs', 'mw'],
    "somadatta": ['bhs', 'cae', 'mw'],
    "somadatti": ['mw'],
    "somadattā": ['mw'],
    "somadeva": ['cae', 'mw'],
    "somadevaikanātha": ['mw'],
    "somadevasūri": ['mw'],
    "somadevata": ['mw'],
    "somadevatya": ['mw'],
    "somadevaśrīkaralālabhairavapurapati": ['mw'],
    "somadevī": ['mw'],
    "somadheya": ['mw'],
    "somadhāna": ['cae', 'gra', 'mw'],
    "somadhārā": ['mw'],
    "somadā": ['mw'],
    "somadīkṣāvidhi": ['mw'],
    "somagarbha": ['mw'],
    "somagaṇaka": ['mw'],
    "somaghṛta": ['mw'],
    "somagiri": ['mw'],
    "somagopā": ['gra', 'mw'],
    "somagraha": ['mw'],
    "somagrahaṇa": ['mw'],
    "somagupta": ['bhs'],
    "somagṛhapati": ['mw'],
    "somahautra": ['mw'],
    "somahautraprayoga": ['mw'],
    "somahotrāgniṣṭoma": ['mw'],
    "somahotṛsaptaka": ['mw'],
    "somahāra": ['cae', 'mw'],
    "somahārin": ['cae', 'mw'],
    "somahūti": ['mw'],
    "somaindra": ['mw'],
    "somaja": ['mw'],
    "somajambhan": ['mw'],
    "somajambhā": ['mw'],
    "somajuṣṭa": ['mw'],
    "somajā": ['mw'],
    "somajāmi": ['gra', 'mw'],
    "somaka": ['cae', 'ddsa', 'gra', 'mw'],
    "somakalaśa": ['mw'],
    "somakalpa": ['mw'],
    "somakanyā": ['mw'],
    "somakaraṇī": ['mw'],
    "somakarman": ['mw'],
    "somakarmapaddhati": ['mw'],
    "somakarmapradīpikā": ['mw'],
    "somakatva": ['mw'],
    "somakavi": ['mw'],
    "somakeśvara": ['mw'],
    "somakhaḍḍaka": ['mw'],
    "somakratavīya": ['mw'],
    "somakratu": ['mw'],
    "somakrayaṇa": ['mw'],
    "somakrayaṇī": ['mw'],
    "somakulyā": ['mw'],
    "somakāma": ['cae', 'gra', 'mw'],
    "somakānta": ['mw'],
    "somakārikā": ['mw'],
    "somakīrti": ['mw'],
    "somakṣaya": ['mw'],
    "somakṣīrā": ['mw'],
    "somakṣīrī": ['mw'],
    "somala": ['ap90'],
    "somaladevī": ['mw'],
    "somalatikā": ['mw'],
    "somalatā": ['mw'],
    "somalipta": ['cae', 'mw'],
    "somaloka": ['mw'],
    "somamad": ['cae', 'gra', 'mw'],
    "somamada": ['cae', 'mw'],
    "somamaitrāvaruṇa": ['mw'],
    "somamakha": ['mw'],
    "somamantrānukramaṇikā": ['mw'],
    "somamaya": ['mw'],
    "somamitra": ['mw'],
    "somamiśra": ['mw'],
    "somamād": ['gra'],
    "somamāna": ['mw'],
    "soman": ['ap90', 'cae', 'gra', 'mw'],
    "somanadin": ['bhs'],
    "somanandin": ['mw'],
    "somanandīśvara": ['mw'],
    "somanassa": ['cped'],
    "somanassajāta": ['cped'],
    "somanetra": ['mw'],
    "somanātha": ['mw'],
    "somanāthabhaṭṭa": ['mw'],
    "somanāthabhāṣya": ['mw'],
    "somanāthadīkṣita": ['mw'],
    "somanāthadīkṣitīya": ['mw'],
    "somanāthamahāpātra": ['mw'],
    "somanāthapattana": ['mw'],
    "somanāthapaṇḍita": ['mw'],
    "somanāthapaṭṭana": ['mw'],
    "somanāthapraśasti": ['mw'],
    "somanātharasa": ['mw'],
    "somanāthatīrtha": ['mw'],
    "somanāthīya": ['mw'],
    "somanīti": ['mw'],
    "somapa": ['cae', 'mw'],
    "somapada": ['mw'],
    "somapaddhati": ['mw'],
    "somapadārthakathana": ['mw'],
    "somaparibādh": ['gra', 'mw'],
    "somapariśrayaṇa": ['mw'],
    "somaparvan": ['cae', 'gra', 'mw'],
    "somaparyāṇahana": ['mw'],
    "somaparṇa": ['cae', 'mw'],
    "somapati": ['cae', 'gra', 'mw'],
    "somapatnī": ['mw'],
    "somapattra": ['mw'],
    "somapañcaka": ['mw'],
    "somapañcakaprayoga": ['mw'],
    "somapañcikā": ['mw'],
    "somapaṇḍita": ['mw'],
    "somapeya": ['gra', 'mw'],
    "somapitsaru": ['mw'],
    "somaprabha": ['cae', 'mw'],
    "somaprabhā": ['mw'],
    "somaprathama": ['mw'],
    "somapratiprasthātṛprayoga": ['mw'],
    "somapratīka": ['mw'],
    "somapravāka": ['mw'],
    "somaprayoga": ['mw'],
    "somaprayogakārikā": ['mw'],
    "somaprayogamantra": ['mw'],
    "somaprayogapaddhati": ['mw'],
    "somaprayogaprāyaścitta": ['mw'],
    "somaprayogaratnamālā": ['mw'],
    "somaprayogavṛtti": ['mw'],
    "somapraśna": ['mw'],
    "somaprāsa": ['bhs'],
    "somaprāyaścitta": ['mw'],
    "somapura": ['mw'],
    "somapurogava": ['mw'],
    "somapuruṣa": ['mw'],
    "somaputra": ['mw'],
    "somaputrī": ['mw'],
    "somapā": ['cae', 'gra', 'mw'],
    "somapāla": ['cae', 'mw'],
    "somapālavilāsa": ['mw'],
    "somapāna": ['cae', 'mw'],
    "somapātama": ['mw'],
    "somapāthin": ['mw'],
    "somapātra": ['cae', 'mw'],
    "somapāvan": ['cae', 'gra', 'mw'],
    "somapāyin": ['cae', 'mw'],
    "somapītha": ['cae', 'gra', 'mw'],
    "somapīthin": ['cae', 'mw'],
    "somapīti": ['cae', 'gra', 'mw'],
    "somapītin": ['mw'],
    "somapīvin": ['mw'],
    "somapīḍā": ['mw'],
    "somapūjā": ['mw'],
    "somapṛṣṭha": ['cae', 'gra', 'mw'],
    "somarabhas": ['gra', 'mw'],
    "somarakṣa": ['cae', 'mw'],
    "somarakṣi": ['mw'],
    "somarasa": ['mw'],
    "somarasodbhava": ['mw'],
    "somaraudra": ['mw'],
    "somaraśmi": ['mw'],
    "somaroga": ['mw'],
    "somarāga": ['mw'],
    "somarāja": ['mw'],
    "somarājadeva": ['mw'],
    "somarājaka": ['mw'],
    "somarājan": ['cae', 'gra', 'mw'],
    "somarājasuta": ['mw'],
    "somarājikā": ['mw'],
    "somarājin": ['mw'],
    "somarājya": ['mw'],
    "somarājī": ['mw'],
    "somarāta": ['cae', 'mw'],
    "somarāṣṭra": ['mw'],
    "somarūpa": ['cae', 'mw'],
    "somarūpatā": ['mw'],
    "somarṣi": ['mw'],
    "somasad": ['mw'],
    "somasakhi": ['cae', 'mw'],
    "somasalila": ['cae', 'mw'],
    "somasaptahautraprayoga": ['mw'],
    "somasaraṇa": ['mw'],
    "somasatsaru": ['mw'],
    "somasava": ['cae', 'mw'],
    "somasavana": ['cae', 'mw'],
    "somasaṃjña": ['mw'],
    "somasaṃsthā": ['mw'],
    "somasena": ['mw'],
    "somasiddhānta": ['mw'],
    "somasiddhāntin": ['mw'],
    "somasindhu": ['mw'],
    "somasundara": ['mw'],
    "somasut": ['cae', 'gra', 'mw'],
    "somasuta": ['mw'],
    "somasuti": ['cae', 'gra', 'mw'],
    "somasutvan": ['cae', 'gra', 'mw'],
    "somasutvat": ['mw'],
    "somasutyā": ['cae', 'mw'],
    "somasutā": ['mw'],
    "somasvāmin": ['mw'],
    "somasāman": ['mw'],
    "somasāra": ['mw'],
    "somasūkta": ['mw'],
    "somasūkṣman": ['mw'],
    "somasūryaprakāśa": ['mw'],
    "somasūtra": ['mw'],
    "somasūtrapañcavidhāna": ['mw'],
    "somasūtrapradakṣiṇā": ['mw'],
    "somatejas": ['mw'],
    "somatilakasūri": ['mw'],
    "somatva": ['mw'],
    "somatīrtha": ['cae', 'mw'],
    "somatīrthamāhātmya": ['mw'],
    "somaudgātra": ['mw'],
    "somavahana": ['mw'],
    "somavahniprakāśa": ['mw'],
    "somavalka": ['mw'],
    "somavalkā": ['mw'],
    "somavallari": ['mw'],
    "somavallarī": ['mw'],
    "somavallikā": ['mw'],
    "somavallī": ['mw'],
    "somavallīyogānanda": ['mw'],
    "somavant": ['cae'],
    "somavarcas": ['cae', 'mw'],
    "somavat": ['gra', 'mw'],
    "somavatyamāvāsyākathā": ['mw'],
    "somavatīkathā": ['mw'],
    "somavatītīrtha": ['mw'],
    "somavatīvrata": ['mw'],
    "somavatīvratakathā": ['mw'],
    "somavaṃśa": ['cae', 'mw'],
    "somavaṃśin": ['mw'],
    "somavaṃśya": ['cae', 'mw'],
    "somavaṃśīya": ['cae', 'mw'],
    "somaveśa": ['mw'],
    "somaveṣṭana": ['mw'],
    "somavidha": ['mw'],
    "somavidhāna": ['mw'],
    "somavihārakārikā": ['mw'],
    "somavikrayin": ['cae', 'mw'],
    "somavrata": ['mw'],
    "somavyāsa": ['mw'],
    "somavāha": ['mw'],
    "somavāmin": ['cae', 'mw'],
    "somavāra": ['mw'],
    "somavāravrata": ['mw'],
    "somavāravratakalpa": ['mw'],
    "somavāravratavidhi": ['mw'],
    "somavāravratodyāpana": ['mw'],
    "somavāravratācaraṇakrama": ['mw'],
    "somavāryamāvāsyāvrata": ['mw'],
    "somavārāmāvāsyapūjāpaddhati": ['mw'],
    "somavārāmāvāsyāvratakālanirṇaya": ['mw'],
    "somavārāmāvāsyāvratapūjā": ['mw'],
    "somavāsara": ['mw'],
    "somavāyavya": ['mw'],
    "somavīrya": ['mw'],
    "somavīthī": ['mw'],
    "somavṛddha": ['cae', 'gra', 'mw'],
    "somavṛddhivardhana": ['mw'],
    "somavṛkṣa": ['mw'],
    "somayajña": ['cae', 'mw'],
    "somayaśas": ['mw'],
    "somayoga": ['mw'],
    "somayogin": ['mw'],
    "somayoni": ['mw'],
    "somayāga": ['cae', 'mw'],
    "somayāgakārikā": ['mw'],
    "somayāgaprayoga": ['mw'],
    "somayājamāna": ['mw'],
    "somayājamānaprayoga": ['mw'],
    "somayājin": ['cae', 'mw'],
    "somayājyā": ['mw'],
    "somaśakalā": ['mw'],
    "somaśambha": ['mw'],
    "somaśambhu": ['mw'],
    "somaśarman": ['mw'],
    "somaśatadvayī": ['mw'],
    "somaśataka": ['mw'],
    "somaśekharākhyanibandha": ['mw'],
    "somaśita": ['cae', 'gra', 'mw'],
    "somaśrauta": ['mw'],
    "somaśravas": ['cae', 'mw'],
    "somaśreṣṭha": ['cae', 'mw'],
    "somaśrī": ['bhs', 'mw'],
    "somaśuṣma": ['mw'],
    "somaśuṣman": ['mw'],
    "somaśūra": ['mw'],
    "somaḥ": ['ap90'],
    "somejyā": ['cae', 'mw'],
    "somendra": ['mw'],
    "somendu": ['mw'],
    "someśvara": ['ddsa', 'mw'],
    "someśvarabhaṭṭa": ['mw'],
    "someśvaradeva": ['mw'],
    "someśvaradīkṣita": ['mw'],
    "somia": ['gra'],
    "somikā": ['ddsa', 'mw'],
    "somila": ['bhs', 'mw'],
    "somilaka": ['mw'],
    "somin": ['ap90', 'cae', 'gra', 'mw'],
    "sominī": ['mw'],
    "somma": ['cped'],
    "somodbhava": ['mw'],
    "somodbhavā": ['ddsa', 'mw'],
    "somodgīta": ['mw'],
    "somopanahana": ['mw'],
    "somotpatti": ['mw'],
    "somotpattipariśiṣṭa": ['mw'],
    "somoṣṇīṣa": ['mw'],
    "somya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "somyatā": ['mw'],
    "somā": ['bhs', 'mw'],
    "somābha": ['mw'],
    "somābhiṣava": ['mw'],
    "somābhiṣikta": ['cae', 'mw'],
    "somābhā": ['mw'],
    "somād": ['cae', 'gra', 'mw'],
    "somādhi": ['mw'],
    "somādhvaryava": ['mw'],
    "somādhāra": ['mw'],
    "somāditya": ['mw'],
    "somāgni": ['mw'],
    "somāgniyajamāna": ['mw'],
    "somāgniṣṭoma": ['mw'],
    "somāgnīdhraprayoga": ['mw'],
    "somāha": ['mw'],
    "somāharaṇa": ['mw'],
    "somāhuta": ['gra', 'mw'],
    "somāhuti": ['cae', 'mw'],
    "somāhvā": ['mw'],
    "somāhāra": ['mw'],
    "somākara": ['mw'],
    "somākhya": ['mw'],
    "somāla": ['mw'],
    "somālaka": ['mw'],
    "somālikā": ['mw'],
    "somāmbupa": ['mw'],
    "somānanda": ['mw'],
    "somānandabhāṣya": ['mw'],
    "somānandanātha": ['mw'],
    "somānandasūnu": ['mw'],
    "somānandācārya": ['mw'],
    "somāpa": ['mw'],
    "somāpahṛta": ['mw'],
    "somāpauṣṇa": ['mw'],
    "somāpi": ['mw'],
    "somāpūṣan": ['cae', 'gra', 'mw'],
    "somāraudra": ['mw'],
    "somārcis": ['mw'],
    "somārdhahārin": ['mw'],
    "somārdhāya": ['mw'],
    "somārha": ['mw'],
    "somārkapratisaṃkāśa": ['mw'],
    "somārthin": ['cae', 'mw'],
    "somārudra": ['cae', 'gra', 'mw'],
    "somārudrasūkta": ['mw'],
    "somārya": ['mw'],
    "somāsandī": ['mw'],
    "somātipavita": ['mw'],
    "somātipūta": ['mw'],
    "somātirikta": ['mw'],
    "somātmaka": ['mw'],
    "somāvarta": ['mw'],
    "somāvat": ['gra'],
    "somāvatī": ['cae', 'mw'],
    "somāyana": ['mw'],
    "somāśrama": ['mw'],
    "somāśrayāyaṇa": ['mw'],
    "somāṃśaka": ['mw'],
    "somāṃśu": ['cae', 'mw'],
    "somāṅga": ['mw'],
    "somāṅgapānakārikā": ['mw'],
    "somāṇḍabilā": ['mw'],
    "somāṇḍapille": ['mw'],
    "somāṣṭamī": ['mw'],
    "somī": ['mw'],
    "somīkṛ": ['mw'],
    "somīkṛta": ['ddsa'],
    "somīya": ['mw'],
    "sona": ['bhs'],
    "sonaha": ['mw'],
    "sonahaḥ": ['ap90'],
    "soni": ['mw'],
    "sonmāda": ['ap90', 'cae', 'mw'],
    "sonodevī": ['mw'],
    "sopabarhaṇa": ['mw'],
    "sopacaya": ['mw'],
    "sopacāra": ['ap90', 'cae', 'mw'],
    "sopacārakam": ['mw'],
    "sopacāram": ['mw'],
    "sopadha": ['ap90', 'mw'],
    "sopadham": ['mw'],
    "sopadhi": ['ap90', 'mw'],
    "sopadhiśeṣa": ['bhs', 'mw'],
    "sopadhāna": ['mw'],
    "sopadrava": ['ap90', 'mw'],
    "sopagraham": ['mw'],
    "sopahava": ['mw'],
    "sopahāsa": ['ap90', 'cae', 'mw'],
    "sopahāsam": ['mw'],
    "sopahāsotprāsa": ['mw'],
    "sopakaraṇa": ['ap90', 'cae', 'mw'],
    "sopakrama": ['mw'],
    "sopakāra": ['ap90', 'cae', 'mw'],
    "sopakāraka": ['ddsa', 'mw'],
    "sopama": ['mw'],
    "sopaniṣatka": ['mw'],
    "sopanyāsa": ['mw'],
    "sopapada": ['mw'],
    "sopapattika": ['mw'],
    "sopaplava": ['ap90', 'mw'],
    "sopara": ['mw'],
    "soparodha": ['ap90', 'mw'],
    "soparodham": ['mw'],
    "sopasarga": ['ap90', 'mw'],
    "sopasveda": ['cae', 'mw'],
    "sopavāsa": ['mw'],
    "sopavāsika": ['bhs', 'mw'],
    "sopita": ['bhs'],
    "soppa": ['cped'],
    "sopādhi": ['ap90', 'ddsa', 'mw'],
    "sopādhika": ['mw'],
    "sopādhikatva": ['mw'],
    "sopādhyāyagaṇa": ['mw'],
    "sopādāna": ['bhs', 'cped', 'mw'],
    "sopāka": ['cae', 'cped', 'ddsa', 'mw'],
    "sopākaḥ": ['ap90'],
    "sopākhya": ['mw'],
    "sopālambha": ['mw'],
    "sopālambham": ['mw'],
    "sopāna": ['cae', 'cped', 'ddsa', 'mw'],
    "sopānabhūta": ['mw'],
    "sopānah": ['cae', 'mw'],
    "sopānaka": ['mw'],
    "sopānakaparamparā": ['mw'],
    "sopānakūpa": ['mw'],
    "sopānamālā": ['bhs', 'mw'],
    "sopānamārga": ['mw'],
    "sopānapaddhati": ['mw'],
    "sopānapanti": ['cped'],
    "sopānaparamparā": ['mw'],
    "sopānapatha": ['mw'],
    "sopānapañcaka": ['mw'],
    "sopānapañcaratna": ['mw'],
    "sopānapaṅkti": ['mw'],
    "sopānaphalaka": ['cped'],
    "sopānapāda": ['cped'],
    "sopānaracanā": ['mw'],
    "sopānasīsa": ['cped'],
    "sopānatka": ['cae', 'ddsa', 'mw'],
    "sopānatva": ['mw'],
    "sopānaṃ": ['ap90'],
    "sopānālī": ['mw'],
    "sopānīya": ['bhs'],
    "sopāraka": ['bhs'],
    "sopārakapattana": ['mw'],
    "sopāsana": ['mw'],
    "sopāya": ['mw'],
    "sopāyāsa": ['bhs'],
    "sopāśraya": ['mw'],
    "sopāśrayaniṣadana": ['mw'],
    "sopāṃśuyāja": ['mw'],
    "sora": ['bhs', 'mw'],
    "soracca": ['cped'],
    "soratya": ['bhs'],
    "soraṇa": ['mw'],
    "sormi": ['ddsa', 'mw'],
    "sormika": ['bhs', 'mw'],
    "sorāvāsa": ['mw'],
    "sorāṣṭrika": ['mw'],
    "sorṇabhrū": ['mw'],
    "sosa": ['cped'],
    "sosana": ['cped'],
    "sosenta": ['cped'],
    "sosesi": ['cped'],
    "soseti": ['cped'],
    "sosetvā": ['cped'],
    "sosita": ['cped'],
    "sossati": ['cped'],
    "sostika": ['bhs'],
    "sosānika": ['cped'],
    "sosārita": ['cped'],
    "sota": ['cped'],
    "sotabba": ['cped'],
    "sotabila": ['cped'],
    "sotadvāra": ['cped'],
    "sotar": ['cped'],
    "sotavant": ['cped'],
    "sotaviññeya": ['cped'],
    "sotaviññāṇa": ['cped'],
    "sotindriya": ['cped'],
    "sotka": ['ap90', 'cae', 'ddsa', 'mw'],
    "sotkampa": ['mw'],
    "sotkarṣa": ['mw'],
    "sotkaṇṭha": ['cae', 'mw'],
    "sotkaṇṭham": ['mw'],
    "sotkṛṣṭahasitasvara": ['mw'],
    "sotpala": ['mw'],
    "sotpattika": ['bhs'],
    "sotprekṣam": ['mw'],
    "sotprāsa": ['ap90', 'cae', 'mw'],
    "sotprāsahasita": ['mw'],
    "sotprāsam": ['mw'],
    "sotpāta": ['mw'],
    "sotpīḍa": ['mw'],
    "sotsava": ['ap90', 'cae', 'mw'],
    "sotsaṅga": ['mw'],
    "sotsedha": ['ap90', 'cae', 'mw'],
    "sotsedham": ['mw'],
    "sotseka": ['cae', 'mw'],
    "sotsuka": ['ap90', 'cae', 'mw'],
    "sotsāha": ['ap90', 'cae', 'mw'],
    "sotsāham": ['mw'],
    "sotsāhatā": ['mw'],
    "sottara": ['bhs', 'mw'],
    "sottarapaṇa": ['mw'],
    "sotthi": ['cped'],
    "sotthibhāva": ['cped'],
    "sotthikamma": ['cped'],
    "sotthisālā": ['cped'],
    "sotu": ['cae', 'ddsa', 'gra', 'mw'],
    "sotukāma": ['cped'],
    "sotuṁ": ['cped'],
    "sotva": ['cae', 'mw'],
    "sotāpanna": ['cped'],
    "sotāpatti": ['cped'],
    "sotāpattiphala": ['cped'],
    "sotāyatana": ['cped'],
    "sotṛ": ['cae', 'gra', 'mw'],
    "sovacassatā": ['cped'],
    "sovaggika": ['cped'],
    "sovatthika": ['bhs', 'cped'],
    "sovaṇṇa": ['cped'],
    "sovaṇṇamaya": ['cped'],
    "sovaṇṇaya": ['cped'],
    "sovāka": ['mw'],
    "sovāla": ['mw'],
    "sovīraka": ['cped'],
    "sośīra": ['mw'],
    "soḍha": ['ap90', 'ddsa', 'mw'],
    "soḍhagovinda": ['mw'],
    "soḍhala": ['mw'],
    "soḍhaukikā": ['bhs'],
    "soḍhavat": ['mw'],
    "soḍhavya": ['cae', 'ddsa', 'mw'],
    "soḍhin": ['mw'],
    "soḍhāmitra": ['mw'],
    "soḍhāya": ['mw'],
    "soḍhṛ": ['ap90', 'cae', 'mw'],
    "soḷasī": ['cped'],
    "soṇa": ['cped'],
    "soṇita": ['cped'],
    "soṇī": ['cped'],
    "soṇḍa": ['bhs', 'cped'],
    "soṇḍaka": ['cped'],
    "soṇḍikā": ['cped'],
    "soṇḍā": ['cped'],
    "soṇḍī": ['cped'],
    "soṇṇa": ['cped'],
    "soṇṇamaya": ['cped'],
    "soṇṇamālā": ['cped'],
    "soṇṇavālukā": ['cped'],
    "soṣa": ['cae', 'mw'],
    "soṣma": ['mw'],
    "soṣman": ['ap90', 'cae', 'mw'],
    "soṣmasnānagṛha": ['mw'],
    "soṣmatā": ['cae', 'mw'],
    "soṣmavat": ['mw'],
    "soṣyantī": ['mw'],
    "soṣyantīhoma": ['mw'],
    "soṣyantīkarman": ['mw'],
    "soṣyantīsavana": ['mw'],
    "soṣṇīṣa": ['cae', 'mw'],
    "soṣṭrika": ['mw'],
    "soṭā": ['mw'],
    "soṭāya": ['mw'],
    "spand": ['cae', 'ddsa', 'gra', 'mw'],
    "spanda": ['cae', 'ddsa', 'mw'],
    "spandacaritra": ['mw'],
    "spandakārikā": ['mw'],
    "spandana": ['bhs', 'cae', 'mw'],
    "spandanilaya": ['mw'],
    "spandanirṇaya": ['mw'],
    "spandapradīpa": ['mw'],
    "spandapradīpikā": ['mw'],
    "spandasarvasva": ['mw'],
    "spandasaṃdoha": ['mw'],
    "spandasūtra": ['mw'],
    "spandasūtravimarśinī": ['mw'],
    "spandavivaraṇa": ['mw'],
    "spandavivṛti": ['mw'],
    "spandaśāstra": ['mw'],
    "spandin": ['cae', 'mw'],
    "spandita": ['bhs', 'cae', 'mw'],
    "spandolikā": ['mw'],
    "spandyā": ['cae'],
    "spandārthasūtrāvalī": ['mw'],
    "spara": ['mw'],
    "sparase": ['mw'],
    "sparatva": ['mw'],
    "sparaṇa": ['cae', 'ddsa', 'mw'],
    "spardh": ['ap90', 'mw'],
    "spardha": ['ap90', 'mw'],
    "spardhana": ['mw'],
    "spardhanaṃ": ['ap90'],
    "spardhanīya": ['mw'],
    "spardhas": ['mw'],
    "spardhatā": ['mw'],
    "spardhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "spardhita": ['mw'],
    "spardhya": ['cae', 'mw'],
    "spardhyāstaraṇavat": ['mw'],
    "spardhā": ['ap90', 'cae', 'ddsa', 'mw'],
    "spardhākara": ['mw'],
    "spardhāvant": ['cae'],
    "spardhāvat": ['mw'],
    "sparitṛ": ['mw'],
    "spariśa": ['bhs', 'mw'],
    "spartṛ": ['mw'],
    "sparś": ['ap90', 'mw'],
    "sparśa": ['cae', 'ddsa', 'mw'],
    "sparśadveṣa": ['mw'],
    "sparśaguṇa": ['cae', 'mw'],
    "sparśahāni": ['mw'],
    "sparśaja": ['mw'],
    "sparśaka": ['mw'],
    "sparśakliṣṭa": ['mw'],
    "sparśakāya": ['bhs'],
    "sparśakṣama": ['cae', 'mw'],
    "sparśalajjā": ['mw'],
    "sparśamaṇi": ['mw'],
    "sparśamaṇiprabhava": ['mw'],
    "sparśana": ['ap90', 'cae', 'ddsa', 'mw'],
    "sparśanaka": ['mw'],
    "sparśanakaṃ": ['ap90'],
    "sparśanavant": ['bhs'],
    "sparśanendriya": ['mw'],
    "sparśanīya": ['cae', 'mw'],
    "sparśarasika": ['ddsa', 'mw'],
    "sparśarephasaṃdhi": ['mw'],
    "sparśarūpavat": ['mw'],
    "sparśasaṃcārin": ['mw'],
    "sparśasaṃkocin": ['mw'],
    "sparśasnāna": ['mw'],
    "sparśaspanda": ['mw'],
    "sparśasukha": ['mw'],
    "sparśatanmātra": ['mw'],
    "sparśatas": ['mw'],
    "sparśatva": ['mw'],
    "sparśatvajātipramāṇa": ['mw'],
    "sparśatā": ['mw'],
    "sparśavant": ['cae'],
    "sparśavarga": ['mw'],
    "sparśavat": ['ap90', 'mw'],
    "sparśavattva": ['mw'],
    "sparśavedya": ['mw'],
    "sparśavihāra": ['mw'],
    "sparśavihāratā": ['bhs'],
    "sparśayajña": ['mw'],
    "sparśayitavya": ['cae', 'mw'],
    "sparśayogaśāstra": ['mw'],
    "sparśaśabdavat": ['mw'],
    "sparśaśuddhā": ['mw'],
    "sparśaḥ": ['ap90'],
    "sparśendriya": ['mw'],
    "sparśika": ['mw'],
    "sparśin": ['cae', 'ddsa', 'mw'],
    "sparśita": ['bhs'],
    "sparśitṛ": ['mw'],
    "sparśopala": ['ddsa', 'mw'],
    "sparśoṣmasaṃdhi": ['mw'],
    "sparśā": ['mw'],
    "sparśāhāra": ['bhs'],
    "sparśājña": ['mw'],
    "sparśājñatā": ['mw'],
    "sparśāna": ['mw'],
    "sparśānandā": ['mw'],
    "sparśānukūla": ['cae', 'mw'],
    "sparśārgaḍa": ['bhs'],
    "sparśāsaha": ['mw'],
    "sparśāsahatva": ['mw'],
    "sparśāsahiṣṇu": ['mw'],
    "sparśāsahiṣṇutva": ['mw'],
    "sparśāśana": ['mw'],
    "sparṣ": ['ap90', 'mw'],
    "sparṣṭavya": ['bhs', 'mw'],
    "sparṣṭṛ": ['ap90', 'mw'],
    "spaś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "spaśa": ['cae', 'ddsa', 'mw'],
    "spaśaḥ": ['ap90'],
    "spaśā": ['mw'],
    "spaṃd": ['ap90'],
    "spaṃdanaṃ": ['ap90'],
    "spaṃdaḥ": ['ap90'],
    "spaṃdita": ['ap90'],
    "spaṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "spaṣṭabhāṣin": ['mw'],
    "spaṣṭagarbhā": ['mw'],
    "spaṣṭam": ['mw'],
    "spaṣṭama": ['bhs'],
    "spaṣṭapratipatti": ['mw'],
    "spaṣṭatara": ['mw'],
    "spaṣṭatā": ['mw'],
    "spaṣṭatāraka": ['mw'],
    "spaṣṭavaktṛ": ['mw'],
    "spaṣṭaya": ['ddsa', 'mw'],
    "spaṣṭayati": ['ap90'],
    "spaṣṭetara": ['mw'],
    "spaṣṭākṣara": ['ddsa', 'mw'],
    "spaṣṭārtha": ['cae', 'mw'],
    "spaṣṭī": ['mw'],
    "spaṣṭībhūta": ['mw'],
    "spaṣṭīkaraṇa": ['mw'],
    "spaṣṭīkṛ": ['cae', 'ddsa', 'mw'],
    "spaṣṭīkṛta": ['mw'],
    "spaṣṭīkṛti": ['mw'],
    "sphaijika": ['mw'],
    "sphaijāyani": ['mw'],
    "sphaiyakṛta": ['mw'],
    "sphal": ['cae', 'ddsa', 'mw'],
    "sphar": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sphara": ['bhs', 'mw'],
    "spharaka": ['mw'],
    "spharati": ['bhs'],
    "spharaṇa": ['bhs', 'mw'],
    "spharaṇaṃ": ['ap90'],
    "spharin": ['bhs'],
    "spharitra": ['bhs', 'mw'],
    "sphauṭāyana": ['mw'],
    "sphavi": ['mw'],
    "sphaṃḍ": ['ap90'],
    "sphaṃṭ": ['ap90'],
    "sphaṇḍ": ['mw'],
    "sphaṇṭ": ['mw'],
    "sphaṭ": ['ap90', 'ddsa', 'mw'],
    "sphaṭa": ['mw'],
    "sphaṭaḥ": ['ap90'],
    "sphaṭika": ['cae', 'ddsa', 'mw'],
    "sphaṭikabhitti": ['mw'],
    "sphaṭikaharmya": ['mw'],
    "sphaṭikakuḍya": ['mw'],
    "sphaṭikamaya": ['cae', 'mw'],
    "sphaṭikamaṇi": ['cae', 'mw'],
    "sphaṭikamaṇigṛha": ['mw'],
    "sphaṭikamaṇivat": ['mw'],
    "sphaṭikamaṇiśilā": ['mw'],
    "sphaṭikaprabha": ['mw'],
    "sphaṭikapātra": ['mw'],
    "sphaṭikaskambha": ['mw'],
    "sphaṭikayaśas": ['mw'],
    "sphaṭikaśikharin": ['mw'],
    "sphaṭikaśilā": ['mw'],
    "sphaṭikaśilāmaṇḍapa": ['mw'],
    "sphaṭikaḥ": ['ap90'],
    "sphaṭikā": ['mw'],
    "sphaṭikābhra": ['mw'],
    "sphaṭikācala": ['mw'],
    "sphaṭikādri": ['mw'],
    "sphaṭikādribhida": ['mw'],
    "sphaṭikākṣamālikā": ['mw'],
    "sphaṭikāri": ['mw'],
    "sphaṭikārikā": ['mw'],
    "sphaṭikāriḥ": ['ap90'],
    "sphaṭikārī": ['mw'],
    "sphaṭikāśman": ['mw'],
    "sphaṭikī": ['ap90'],
    "sphaṭita": ['bhs', 'mw'],
    "sphaṭā": ['ap90', 'bhs', 'mw'],
    "sphaṭī": ['mw'],
    "spheman": ['mw'],
    "spheyas": ['ap90', 'mw'],
    "spheṣṭha": ['ap90', 'mw'],
    "spheṭa": ['mw'],
    "sphic": ['ap90', 'ddsa', 'mw'],
    "sphig": ['mw'],
    "sphigdaghna": ['mw'],
    "sphigghātaka": ['mw'],
    "sphigī": ['cae', 'ddsa', 'gra', 'mw'],
    "sphij": ['cae', 'mw'],
    "sphija": ['bhs'],
    "sphik": ['mw'],
    "sphiksrāva": ['mw'],
    "sphira": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sphivi": ['mw'],
    "sphiñja": ['mw'],
    "sphiṭ": ['ap90', 'mw'],
    "sphiṭṭ": ['ap90', 'mw'],
    "spholana": ['mw'],
    "sphoraṇa": ['mw'],
    "sphoraṇaṃ": ['ap90'],
    "sphoṭa": ['cae', 'ddsa', 'mw'],
    "sphoṭabījaka": ['mw'],
    "sphoṭacakra": ['mw'],
    "sphoṭacandrikā": ['mw'],
    "sphoṭahetuka": ['mw'],
    "sphoṭajīvikā": ['mw'],
    "sphoṭaka": ['cae', 'mw'],
    "sphoṭakam": ['bhs'],
    "sphoṭakara": ['mw'],
    "sphoṭakaḥ": ['ap90'],
    "sphoṭalatā": ['mw'],
    "sphoṭana": ['ap90', 'bhs', 'cae', 'mw'],
    "sphoṭanirūpaṇa": ['mw'],
    "sphoṭanī": ['ap90', 'bhs', 'mw'],
    "sphoṭatattva": ['mw'],
    "sphoṭavāda": ['mw'],
    "sphoṭaḥ": ['ap90'],
    "sphoṭika": ['bhs'],
    "sphoṭikā": ['ap90', 'mw'],
    "sphoṭinī": ['mw'],
    "sphoṭita": ['mw'],
    "sphoṭitanayana": ['mw'],
    "sphoṭitārgala": ['mw'],
    "sphoṭā": ['ap90', 'bhs', 'mw'],
    "sphoṭāyana": ['cae', 'mw'],
    "sphujidhvaja": ['mw'],
    "sphul": ['ap90', 'cae', 'ddsa', 'mw'],
    "sphula": ['mw'],
    "sphulamañjarī": ['mw'],
    "sphulana": ['mw'],
    "sphulanaṃ": ['ap90'],
    "sphulantaśrī": ['bhs'],
    "sphulaṃ": ['ap90'],
    "sphuliṃgaḥ": ['ap90'],
    "sphuliṃginī": ['ap90'],
    "sphuliṅga": ['cae', 'ddsa', 'mw'],
    "sphuliṅgaka": ['cae', 'mw'],
    "sphuliṅgavat": ['mw'],
    "sphuliṅgin": ['mw'],
    "sphuliṅginī": ['mw'],
    "sphuliṅgāya": ['ddsa', 'mw'],
    "sphur": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sphura": ['cae', 'ddsa', 'mw'],
    "sphurad": ['mw'],
    "sphuradadharoṣṭha": ['mw'],
    "sphuradadharoṣṭham": ['mw'],
    "sphuradgandha": ['mw'],
    "sphuradoṣṭha": ['mw'],
    "sphuradoṣṭhaka": ['mw'],
    "sphuradulkā": ['mw'],
    "sphuradulkākṛti": ['mw'],
    "sphuramāṇa": ['mw'],
    "sphuramāṇauṣṭha": ['mw'],
    "sphuran": ['mw'],
    "sphuranmīna": ['mw'],
    "sphurat": ['ap90', 'mw'],
    "sphurati": ['bhs'],
    "sphuratprabhāmaṇḍala": ['mw'],
    "sphurattaraṃgajihva": ['mw'],
    "sphuraḥ": ['ap90'],
    "sphuraṇa": ['cae', 'mw'],
    "sphuraṇaṃ": ['ap90'],
    "sphurcch": ['ap90'],
    "sphurch": ['mw'],
    "sphurita": ['ap90', 'cae', 'mw'],
    "sphuritaśatahrada": ['mw'],
    "sphuritottarādhara": ['mw'],
    "sphuritādhara": ['mw'],
    "sphurj": ['ap90', 'mw'],
    "sphurjathuḥ": ['ap90'],
    "sphut": ['ap90', 'mw'],
    "sphutkara": ['mw'],
    "sphutkāra": ['bhs', 'mw'],
    "sphuḍ": ['ap90', 'mw'],
    "sphuṃḍ": ['ap90'],
    "sphuṃṭ": ['ap90'],
    "sphuṇḍ": ['mw'],
    "sphuṇṭ": ['mw'],
    "sphuṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "sphuṭa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "sphuṭabandhanī": ['mw'],
    "sphuṭabodha": ['mw'],
    "sphuṭabudbuda": ['mw'],
    "sphuṭacandratāraka": ['mw'],
    "sphuṭacandrikā": ['mw'],
    "sphuṭadarpaṇa": ['mw'],
    "sphuṭajyotiṣa": ['mw'],
    "sphuṭakaraṇa": ['mw'],
    "sphuṭam": ['mw'],
    "sphuṭana": ['cae', 'mw'],
    "sphuṭanaṃ": ['ap90'],
    "sphuṭanīya": ['mw'],
    "sphuṭapauruṣa": ['mw'],
    "sphuṭaphala": ['mw'],
    "sphuṭaphenarāji": ['mw'],
    "sphuṭapuṇḍarīka": ['mw'],
    "sphuṭaraṅgiṇī": ['mw'],
    "sphuṭasiddhānta": ['mw'],
    "sphuṭasāra": ['mw'],
    "sphuṭasūryagati": ['mw'],
    "sphuṭatara": ['mw'],
    "sphuṭataram": ['mw'],
    "sphuṭatarākṣara": ['mw'],
    "sphuṭatva": ['mw'],
    "sphuṭatā": ['mw'],
    "sphuṭatāra": ['mw'],
    "sphuṭavaktṛ": ['ddsa', 'mw'],
    "sphuṭavalkalī": ['mw'],
    "sphuṭavikrama": ['bhs'],
    "sphuṭavivaraṇa": ['mw'],
    "sphuṭay": ['cae'],
    "sphuṭaya": ['ddsa'],
    "sphuṭaśabdam": ['mw'],
    "sphuṭi": ['mw'],
    "sphuṭika": ['bhs'],
    "sphuṭikā": ['ap90', 'ddsa', 'mw'],
    "sphuṭita": ['ap90', 'mw'],
    "sphuṭitacaraṇa": ['mw'],
    "sphuṭitaka": ['bhs'],
    "sphuṭiḥ": ['ap90'],
    "sphuṭāgas": ['mw'],
    "sphuṭākṣara": ['cae', 'mw'],
    "sphuṭārtha": ['cae', 'ddsa', 'mw'],
    "sphuṭārthatā": ['mw'],
    "sphuṭī": ['mw'],
    "sphuṭībhāva": ['mw'],
    "sphuṭībhū": ['mw'],
    "sphuṭīkaraṇa": ['ddsa', 'mw'],
    "sphuṭīkṛ": ['cae', 'mw'],
    "sphuṭṭ": ['ap90', 'mw'],
    "sphya": ['cae', 'ddsa', 'mw'],
    "sphyakṛt": ['mw'],
    "sphyakṛta": ['mw'],
    "sphyavartani": ['mw'],
    "sphyaṃ": ['ap90'],
    "sphyāgra": ['mw'],
    "sphā": ['gra'],
    "sphāka": ['mw'],
    "sphāl": ['ap90'],
    "sphāla": ['bhs', 'mw'],
    "sphālana": ['bhs', 'ddsa', 'mw'],
    "sphālanaṃ": ['ap90'],
    "sphālayati": ['bhs'],
    "sphālaḥ": ['ap90'],
    "sphāna": ['gra', 'mw'],
    "sphāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "sphāraphulla": ['cae', 'mw'],
    "sphārasphāra": ['mw'],
    "sphāraṇa": ['mw'],
    "sphāraṇaṃ": ['ap90'],
    "sphārika": ['bhs'],
    "sphārita": ['mw'],
    "sphāritra": ['bhs'],
    "sphārībhū": ['cae', 'mw'],
    "sphārṇi": ['mw'],
    "sphāta": ['ap90'],
    "sphāti": ['cae', 'ddsa', 'gra', 'mw'],
    "sphātihārin": ['mw'],
    "sphātimant": ['cae'],
    "sphātimat": ['mw'],
    "sphātiḥ": ['ap90'],
    "sphātiṃkaraṇa": ['mw'],
    "sphāvaya": ['ddsa'],
    "sphāvayitṛ": ['cae', 'mw'],
    "sphāy": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sphāyana": ['mw'],
    "sphāyat": ['mw'],
    "sphāyatkairava": ['mw'],
    "sphāṇi": ['mw'],
    "sphāṭaka": ['mw'],
    "sphāṭakaḥ": ['ap90'],
    "sphāṭakī": ['mw'],
    "sphāṭi": ['mw'],
    "sphāṭika": ['ap90', 'cae', 'ddsa', 'mw'],
    "sphāṭikasaudha": ['mw'],
    "sphāṭikopala": ['mw'],
    "sphāṭita": ['ap90', 'mw'],
    "sphāṭīka": ['mw'],
    "sphāṭīkaṃ": ['ap90'],
    "sphīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "sphītanitambā": ['mw'],
    "sphītatā": ['mw'],
    "sphīti": ['ddsa', 'mw'],
    "sphītiḥ": ['ap90'],
    "sphītī": ['mw'],
    "sphītīkṛ": ['mw'],
    "sphītīkṛta": ['mw'],
    "sphūrch": ['mw'],
    "sphūrchita": ['mw'],
    "sphūrj": ['cae', 'ddsa', 'gra', 'mw'],
    "sphūrja": ['cae', 'mw'],
    "sphūrjaka": ['cae', 'mw'],
    "sphūrjana": ['mw'],
    "sphūrjanaṃ": ['ap90'],
    "sphūrjathu": ['cae', 'ddsa', 'mw'],
    "sphūrjathuḥ": ['ap90'],
    "sphūrjaḥ": ['ap90'],
    "sphūrji": ['mw'],
    "sphūrjita": ['cae', 'mw'],
    "sphūrjāvat": ['mw'],
    "sphūrta": ['mw'],
    "sphūrti": ['cae', 'ddsa', 'mw'],
    "sphūrtimat": ['ap90', 'mw'],
    "sphūrtiḥ": ['ap90'],
    "sphūrṇa": ['mw'],
    "sphūṭa": ['bhs'],
    "spij": ['gra'],
    "spraṣṭavya": ['bhs', 'ddsa', 'mw'],
    "spraṣṭṛ": ['ap90', 'mw'],
    "spuriti": ['bhs'],
    "spāndana": ['mw'],
    "spārha": ['cae', 'ddsa', 'gra', 'mw'],
    "spārharādhas": ['gra', 'mw'],
    "spārhavīra": ['cae', 'gra', 'mw'],
    "spārśana": ['mw'],
    "spārśanapratyakṣa": ['mw'],
    "spāśana": ['mw'],
    "spāśita": ['mw'],
    "spūrdh": ['cae', 'ddsa', 'gra', 'mw'],
    "spūrdhase": ['mw'],
    "spṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "spṛdh": ['cae', 'ddsa', 'gra', 'mw'],
    "spṛdhya": ['cae', 'mw'],
    "spṛdhāna": ['mw'],
    "spṛh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "spṛhaka": ['bhs'],
    "spṛhayadvarṇa": ['gra', 'mw'],
    "spṛhayitṛ": ['mw'],
    "spṛhayālu": ['ap90', 'cae', 'mw'],
    "spṛhayālutā": ['mw'],
    "spṛhayāyia": ['gra'],
    "spṛhayāyya": ['cae', 'ddsa', 'gra', 'mw'],
    "spṛhaṇa": ['cae', 'mw'],
    "spṛhaṇatā": ['bhs'],
    "spṛhaṇaṃ": ['ap90'],
    "spṛhaṇīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "spṛhaṇīyatva": ['mw'],
    "spṛhaṇīyatā": ['mw'],
    "spṛhaṇīyaśobha": ['mw'],
    "spṛhita": ['mw'],
    "spṛhya": ['ap90', 'mw'],
    "spṛhā": ['ap90', 'cae', 'ddsa', 'mw'],
    "spṛhālu": ['ap90', 'bhs', 'mw'],
    "spṛhāvant": ['cae'],
    "spṛhāvat": ['mw'],
    "spṛkkā": ['mw'],
    "spṛt": ['mw'],
    "spṛta": ['mw'],
    "spṛti": ['mw'],
    "spṛś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "spṛśa": ['ddsa', 'mw'],
    "spṛśana": ['bhs'],
    "spṛśi": ['mw'],
    "spṛśya": ['ap90', 'cae', 'mw'],
    "spṛśyā": ['mw'],
    "spṛśā": ['mw'],
    "spṛśī": ['ap90', 'mw'],
    "spṛṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "spṛṣṭaka": ['mw'],
    "spṛṣṭamaithuna": ['cae', 'mw'],
    "spṛṣṭamātra": ['mw'],
    "spṛṣṭapūrva": ['mw'],
    "spṛṣṭatā": ['mw'],
    "spṛṣṭavya": ['mw'],
    "spṛṣṭi": ['cae', 'ddsa', 'mw'],
    "spṛṣṭika": ['ddsa'],
    "spṛṣṭikā": ['cae', 'mw'],
    "spṛṣṭin": ['cae', 'ddsa', 'mw'],
    "spṛṣṭiḥ": ['ap90'],
    "spṛṣṭāspṛṣṭi": ['ap90', 'mw'],
    "spṝ": ['ap90', 'mw'],
    "srabhiṣṭha": ['mw'],
    "sraddhū": ['ap90', 'mw'],
    "srag": ['mw'],
    "sragaṇu": ['mw'],
    "sragdhara": ['cae', 'mw'],
    "sragdharā": ['bhs', 'mw'],
    "sragdāman": ['cae', 'ddsa', 'mw'],
    "sragmin": ['bhs'],
    "sragvat": ['mw'],
    "sragvin": ['ap90', 'cae', 'mw'],
    "sragviṇī": ['mw'],
    "srai": ['ap90', 'mw'],
    "sraj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sraja": ['mw'],
    "srajamālādhārin": ['bhs'],
    "srajas": ['mw'],
    "srajaya": ['mw'],
    "srajayati": ['ap90'],
    "srajin": ['mw'],
    "srajivat": ['mw'],
    "srajiṣṭha": ['mw'],
    "srajvan": ['mw'],
    "srajvā": ['ap90'],
    "srajīyas": ['mw'],
    "srakti": ['cae', 'ddsa', 'gra', 'mw'],
    "sraktya": ['cae', 'mw'],
    "srakva": ['cae', 'ddsa', 'gra', 'mw'],
    "srambh": ['ddsa', 'mw'],
    "sras": ['ddsa', 'gra', 'mw'],
    "srasta": ['ap90', 'cae', 'mw'],
    "srastagātra": ['mw'],
    "srastahasta": ['mw'],
    "srastakara": ['mw'],
    "srastamukta": ['cae'],
    "srastamuṣka": ['mw'],
    "srastara": ['cae', 'ddsa', 'mw'],
    "srastaraḥ": ['ap90'],
    "srastaskandha": ['mw'],
    "srastatā": ['ddsa', 'mw'],
    "srastaśarīrasaṃdhi": ['mw'],
    "srasti": ['mw'],
    "srastiḥ": ['ap90'],
    "srastottarapaṭa": ['mw'],
    "srastāpāna": ['mw'],
    "srastāṃsa": ['mw'],
    "srastāṃsabāhu": ['mw'],
    "srastāṅga": ['mw'],
    "srastāṅgatā": ['mw'],
    "srauca": ['cae'],
    "sraughna": ['ap90', 'mw'],
    "sraughnī": ['mw'],
    "sraughnībhāryā": ['mw'],
    "sraughnīmāninī": ['mw'],
    "sraughnīpāśā": ['mw'],
    "sraughnīya": ['mw'],
    "sraugmata": ['mw'],
    "srauta": ['mw'],
    "srautika": ['mw'],
    "srautovaha": ['cae', 'ddsa', 'mw'],
    "srauva": ['mw'],
    "srava": ['cae', 'ddsa', 'mw'],
    "sravad": ['mw'],
    "sravadgarbhā": ['mw'],
    "sravadraṅga": ['mw'],
    "sravaka": ['mw'],
    "sravamī": ['mw'],
    "sravanta": ['mw'],
    "sravantī": ['cae', 'mw'],
    "sravas": ['cae', 'mw'],
    "sravat": ['ap90', 'cae', 'gra', 'mw'],
    "sravatha": ['cae', 'gra', 'mw'],
    "sravatpāṇipādā": ['mw'],
    "sravatsvedajala": ['mw'],
    "sravattoyā": ['mw'],
    "sravaḥ": ['ap90'],
    "sravaṃtī": ['ap90'],
    "sravaṇa": ['cae', 'mw'],
    "sravaṇaṃ": ['ap90'],
    "sravitavai": ['cae'],
    "sravitave": ['cae', 'mw'],
    "sravā": ['mw'],
    "sraṃbh": ['ap90'],
    "sraṃh": ['ap90', 'mw'],
    "sraṃs": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sraṃsa": ['cae', 'mw'],
    "sraṃsana": ['ddsa', 'mw'],
    "sraṃsanaṃ": ['ap90'],
    "sraṃsanā": ['bhs'],
    "sraṃsanīya": ['bhs'],
    "sraṃsaḥ": ['ap90'],
    "sraṃsin": ['ap90', 'cae', 'mw'],
    "sraṃsinīphala": ['mw'],
    "sraṃsita": ['mw'],
    "sraṅk": ['mw'],
    "sraṣṭavya": ['mw'],
    "sraṣṭāra": ['mw'],
    "sraṣṭṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "sraṣṭṛtva": ['mw'],
    "sraṣṭṛtā": ['mw'],
    "sreha": ['ddsa'],
    "srek": ['ap90', 'mw'],
    "srekaparṇa": ['ddsa', 'mw'],
    "sreman": ['cae', 'gra'],
    "sribh": ['ap90', 'mw'],
    "sridh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "srima": ['mw'],
    "srimbh": ['mw'],
    "sriv": ['ap90', 'ddsa', 'gra', 'mw'],
    "sriṃbh": ['ap90'],
    "srota": ['cae', 'mw'],
    "srotanadībhava": ['mw'],
    "srotas": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "srotasa": ['mw'],
    "srotastā": ['mw'],
    "srotasvat": ['mw'],
    "srotasvatī": ['ap90', 'mw'],
    "srotasvinī": ['mw'],
    "srotasya": ['cae', 'mw'],
    "srotasyaḥ": ['ap90'],
    "srotaāpanna": ['bhs', 'mw'],
    "srotaāpatti": ['bhs', 'mw'],
    "srotaīśa": ['mw'],
    "srotaṃ": ['ap90'],
    "srotiā": ['gra'],
    "sroto": ['mw'],
    "srotodbhava": ['mw'],
    "srotoja": ['mw'],
    "srotojava": ['mw'],
    "srotonadībhava": ['mw'],
    "srotonugata": ['bhs', 'mw'],
    "srotorandhra": ['ddsa', 'mw'],
    "srotovah": ['cae', 'mw'],
    "srotovahā": ['cae', 'mw'],
    "srotoñjana": ['mw'],
    "srotyā": ['cae', 'ddsa', 'gra', 'mw'],
    "srotā": ['bhs'],
    "srotāpatti": ['bhs', 'mw'],
    "srotāñjana": ['bhs'],
    "sru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sruc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "srucaya": ['mw'],
    "sruciṣṭha": ['mw'],
    "srucya": ['cae', 'mw'],
    "srucāyani": ['mw'],
    "srucīyas": ['mw'],
    "srug": ['mw'],
    "srugbheda": ['mw'],
    "srugbhāṇḍa": ['mw'],
    "srugdaṇḍa": ['cae', 'mw'],
    "srugdāru": ['mw'],
    "srugghnī": ['mw'],
    "srughna": ['ap90', 'cae', 'ddsa', 'mw'],
    "srughnaḥ": ['ap90'],
    "srughnikā": ['mw'],
    "srughnā": ['bhs'],
    "srughnī": ['ap90', 'mw'],
    "srugjihva": ['mw'],
    "srugmat": ['mw'],
    "srugvat": ['mw'],
    "srugvyūha": ['mw'],
    "srugādāna": ['mw'],
    "srugāsādana": ['mw'],
    "sruh": ['gra', 'mw'],
    "sruk": ['mw'],
    "srukka": ['cae', 'mw'],
    "srukkāra": ['mw'],
    "srukpraṇālikā": ['mw'],
    "srukpātra": ['mw'],
    "sruksammārjana": ['mw'],
    "sruksruva": ['mw'],
    "sruksruvalakṣaṇa": ['mw'],
    "srut": ['ap90', 'cae', 'ddsa', 'mw'],
    "sruta": ['ap90', 'ddsa', 'mw'],
    "srutajala": ['cae', 'mw'],
    "sruti": ['cae', 'gra', 'mw'],
    "srutiḥ": ['ap90'],
    "srutya": ['cae', 'mw'],
    "srutā": ['mw'],
    "sruva": ['cae', 'ddsa', 'gra', 'mw'],
    "sruvadaṇḍa": ['mw'],
    "sruvadruma": ['mw'],
    "sruvahasta": ['mw'],
    "sruvahoma": ['mw'],
    "sruvaka": ['bhs'],
    "sruvakarṇa": ['mw'],
    "sruvalakṣaṇa": ['mw'],
    "sruvapragrahaṇa": ['mw'],
    "sruvapūram": ['mw'],
    "sruvataru": ['mw'],
    "sruvaḥ": ['ap90'],
    "sruvā": ['mw'],
    "sruvāhuti": ['mw'],
    "sruvāvṛkṣa": ['mw'],
    "srā": ['ddsa', 'gra'],
    "srāgviṇa": ['mw'],
    "srāk": ['ap90', 'mw'],
    "srāktya": ['mw'],
    "srāma": ['cae', 'ddsa', 'gra', 'mw'],
    "srāmya": ['mw'],
    "srāva": ['cae', 'ddsa', 'mw'],
    "srāvaka": ['ap90', 'mw'],
    "srāvakatva": ['mw'],
    "srāvayitavya": ['mw'],
    "srāvaḥ": ['ap90'],
    "srāvaṇa": ['cae', 'mw'],
    "srāvin": ['cae', 'mw'],
    "srāvita": ['mw'],
    "srāvya": ['mw'],
    "srāṇa": ['mw'],
    "srīv": ['cae', 'mw'],
    "srū": ['ap90', 'ddsa', 'gra', 'mw'],
    "srūta": ['mw'],
    "ssa": ['bhs'],
    "stabaka": ['cae', 'ddsa', 'mw'],
    "stabakakanda": ['mw'],
    "stabakaphala": ['mw'],
    "stabakasaṃnibha": ['mw'],
    "stabakaya": ['ddsa', 'mw'],
    "stabakaḥ": ['ap90'],
    "stabakita": ['mw'],
    "stabakācita": ['mw'],
    "stabdha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "stabdhabāhu": ['mw'],
    "stabdhadṛṣṭi": ['mw'],
    "stabdhagātra": ['mw'],
    "stabdhahanu": ['mw'],
    "stabdhakarṇa": ['cae', 'mw'],
    "stabdhakarṇaśirodhara": ['mw'],
    "stabdhalocana": ['cae', 'mw'],
    "stabdham": ['mw'],
    "stabdhamati": ['mw'],
    "stabdhamedhra": ['mw'],
    "stabdhamedhratā": ['mw'],
    "stabdhanayana": ['mw'],
    "stabdhapāda": ['mw'],
    "stabdhapādatā": ['mw'],
    "stabdhapūrṇakoṣṭha": ['mw'],
    "stabdhapūrṇakoṣṭhatā": ['mw'],
    "stabdharomakūpa": ['mw'],
    "stabdharomakūpatā": ['mw'],
    "stabdharoman": ['mw'],
    "stabdhasakthi": ['mw'],
    "stabdhasakthitā": ['mw'],
    "stabdhasambhāra": ['mw'],
    "stabdhatoya": ['mw'],
    "stabdhatva": ['mw'],
    "stabdhatā": ['ap90', 'mw'],
    "stabdhavapus": ['mw'],
    "stabdhaśrotra": ['mw'],
    "stabdhi": ['mw'],
    "stabdhika": ['bhs'],
    "stabdhiḥ": ['ap90'],
    "stabdhoda": ['mw'],
    "stabdhordhvakarṇa": ['mw'],
    "stabdhākṣa": ['mw'],
    "stabdhī": ['mw'],
    "stabdhībhāva": ['cae', 'mw'],
    "stabdhīkaraṇa": ['mw'],
    "stabdhīkṛ": ['cae', 'ddsa', 'mw'],
    "stabh": ['ap90', 'ddsa', 'gra', 'mw'],
    "stabha": ['mw'],
    "stabhamāna": ['mw'],
    "stabhaḥ": ['ap90'],
    "stabhi": ['mw'],
    "stabhita": ['mw'],
    "stabhu": ['ap90', 'mw'],
    "stabhāy": ['gra'],
    "stabhāya": ['ddsa'],
    "stabhūy": ['gra'],
    "stabhūya": ['mw'],
    "stai": ['ap90', 'mw'],
    "staimitya": ['cae', 'ddsa', 'mw'],
    "staimityaṃ": ['ap90'],
    "staina": ['mw'],
    "stainaṃ": ['ap90'],
    "stainya": ['cae', 'ddsa', 'mw'],
    "stainyaka": ['bhs'],
    "stainyaṃ": ['ap90'],
    "stairṇi": ['mw'],
    "stak": ['ap90', 'mw'],
    "stam": ['ap90', 'mw'],
    "stamba": ['cae', 'ddsa', 'mw'],
    "stambaghana": ['mw'],
    "stambaghna": ['mw'],
    "stambaghāta": ['mw'],
    "stambahanana": ['mw'],
    "stambahananī": ['mw'],
    "stambaja": ['cae', 'mw'],
    "stambaka": ['cae', 'mw'],
    "stambakari": ['mw'],
    "stambakaritā": ['mw'],
    "stambakita": ['mw'],
    "stambakāra": ['mw'],
    "stambakāya": ['mw'],
    "stambamitra": ['cae', 'mw'],
    "stambapur": ['mw'],
    "stambavana": ['mw'],
    "stambavatī": ['mw'],
    "stambayajus": ['mw'],
    "stambaśas": ['cae', 'mw'],
    "stamberama": ['cae', 'ddsa', 'mw'],
    "stamberamāsura": ['mw'],
    "stambh": ['cae', 'ddsa', 'gra', 'mw'],
    "stambha": ['cae', 'ddsa', 'mw'],
    "stambhabhañjaka": ['cae', 'mw'],
    "stambhaka": ['cae', 'mw'],
    "stambhakara": ['mw'],
    "stambhakin": ['mw'],
    "stambhakāraṇa": ['mw'],
    "stambhakī": ['mw'],
    "stambhamitra": ['mw'],
    "stambhana": ['cae', 'ddsa', 'mw'],
    "stambhanaka": ['mw'],
    "stambhanaprakāra": ['mw'],
    "stambhanādividhi": ['mw'],
    "stambhanī": ['bhs', 'mw'],
    "stambhanīya": ['mw'],
    "stambhapūjā": ['mw'],
    "stambhatā": ['mw'],
    "stambhatīrtha": ['mw'],
    "stambhavatī": ['mw'],
    "stambhi": ['mw'],
    "stambhikā": ['mw'],
    "stambhin": ['bhs', 'cae', 'mw'],
    "stambhinī": ['mw'],
    "stambhita": ['bhs', 'mw'],
    "stambhitabāṣpavṛtti": ['mw'],
    "stambhitarambha": ['mw'],
    "stambhitatva": ['mw'],
    "stambhitāśru": ['mw'],
    "stambhotkīrṇa": ['mw'],
    "stambhībhū": ['cae', 'ddsa', 'mw'],
    "stambhīya": ['mw'],
    "stambin": ['cae', 'mw'],
    "stan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "stana": ['cae', 'ddsa', 'gra', 'mw'],
    "stanabhara": ['cae', 'mw'],
    "stanabhava": ['mw'],
    "stanabāla": ['mw'],
    "stanacūcuka": ['mw'],
    "stanadhātrī": ['bhs'],
    "stanadveṣin": ['mw'],
    "stanadātrī": ['mw'],
    "stanagraha": ['cae', 'mw'],
    "stanakalaśa": ['mw'],
    "stanakeśavatī": ['mw'],
    "stanakoraka": ['mw'],
    "stanakoṭi": ['cae', 'mw'],
    "stanakumbha": ['mw'],
    "stanakuḍmala": ['mw'],
    "stanakuṇḍa": ['mw'],
    "stanamadhya": ['cae', 'mw'],
    "stanamaṇḍala": ['mw'],
    "stanamukha": ['mw'],
    "stanamūla": ['mw'],
    "stanana": ['mw'],
    "stananaṃ": ['ap90'],
    "stanandhaya": ['ddsa'],
    "stanapa": ['cae', 'ddsa', 'mw'],
    "stanapatana": ['mw'],
    "stanapoṣika": ['mw'],
    "stanapā": ['mw'],
    "stanapāna": ['cae', 'mw'],
    "stanapātṛ": ['mw'],
    "stanapāyaka": ['mw'],
    "stanapāyika": ['mw'],
    "stanapāyikā": ['mw'],
    "stanapāyin": ['cae', 'mw'],
    "stanaroga": ['mw'],
    "stanarohita": ['mw'],
    "stanasyu": ['mw'],
    "stanataṭa": ['cae', 'mw'],
    "stanatha": ['cae', 'ddsa', 'gra', 'mw'],
    "stanathaḥ": ['ap90'],
    "stanathu": ['cae', 'mw'],
    "stanatyāga": ['mw'],
    "stanavatī": ['mw'],
    "stanavepathu": ['ddsa', 'mw'],
    "stanavṛnta": ['mw'],
    "stanayadama": ['cae', 'ddsa', 'gra', 'mw'],
    "stanayitnu": ['cae', 'ddsa', 'gra', 'mw'],
    "stanayitnughoṣa": ['mw'],
    "stanayitnumat": ['mw'],
    "stanayitnusani": ['mw'],
    "stanayitnuvat": ['mw'],
    "stanayitnuḥ": ['ap90'],
    "stanayodhika": ['mw'],
    "stanayoṣika": ['mw'],
    "stanaśikhā": ['mw'],
    "stanaḥ": ['ap90'],
    "stanaṃdha": ['mw'],
    "stanaṃdhama": ['mw'],
    "stanaṃdhaya": ['ap90', 'cae', 'mw'],
    "stanin": ['mw'],
    "stanita": ['ap90', 'cae', 'ddsa', 'mw'],
    "stanitakumāra": ['mw'],
    "stanitaphala": ['mw'],
    "stanitasamaya": ['mw'],
    "stanitasubhagam": ['mw'],
    "stanitavimukha": ['mw'],
    "stanopapīḍam": ['mw'],
    "stanottarīya": ['cae', 'ddsa', 'mw'],
    "stanutṛ": ['mw'],
    "stanya": ['cae', 'ddsa', 'mw'],
    "stanyabhuj": ['mw'],
    "stanyada": ['mw'],
    "stanyadāna": ['mw'],
    "stanyapa": ['mw'],
    "stanyapāna": ['mw'],
    "stanyapāyin": ['mw'],
    "stanyaroga": ['mw'],
    "stanyatyāga": ['cae', 'mw'],
    "stanyatyāgamātraka": ['mw'],
    "stanyaṃ": ['ap90'],
    "stanyāvataraṇa": ['mw'],
    "stanābhoga": ['cae', 'mw'],
    "stanābhuj": ['gra', 'mw'],
    "stanābhuja": ['mw'],
    "stanāgra": ['mw'],
    "stanāntara": ['cae', 'mw'],
    "stanāvaraṇa": ['cae', 'mw'],
    "stanāvaraṇatā": ['mw'],
    "stanāṃśuka": ['cae', 'ddsa', 'mw'],
    "stanāṅgarāga": ['mw'],
    "star": ['gra'],
    "stara": ['ap90', 'cae', 'mw'],
    "staraṇa": ['cae', 'ddsa', 'mw'],
    "staraṇaṃ": ['ap90'],
    "staraṇīya": ['mw'],
    "stariman": ['ap90', 'mw'],
    "startavai": ['ddsa', 'mw'],
    "startave": ['mw'],
    "staru": ['ddsa', 'mw'],
    "starya": ['cae', 'mw'],
    "starī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "starīkṛ": ['mw'],
    "starīman": ['ap90', 'cae', 'gra', 'mw'],
    "staubha": ['mw'],
    "staubhika": ['mw'],
    "staubhikaṃ": ['ap90'],
    "staulā": ['gra', 'mw'],
    "stauna": ['cae', 'gra', 'mw'],
    "staupika": ['bhs', 'mw'],
    "stauti": ['mw'],
    "stava": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "stavacintāmaṇi": ['mw'],
    "stavadaṇḍaka": ['mw'],
    "stavadhyai": ['mw'],
    "stavaka": ['ap90', 'mw'],
    "stavakarṇika": ['bhs'],
    "stavakarṇikā": ['mw'],
    "stavakarṇin": ['mw'],
    "stavakita": ['ap90'],
    "stavamālā": ['mw'],
    "stavamāna": ['mw'],
    "stavana": ['cae', 'mw'],
    "stavanaṃ": ['ap90'],
    "stavanya": ['mw'],
    "stavanīya": ['mw'],
    "stavaraka": ['ddsa', 'mw'],
    "stavarāja": ['ddsa', 'mw'],
    "stavat": ['gra', 'mw'],
    "stavatha": ['cae', 'gra', 'mw'],
    "stavati": ['bhs'],
    "stavaḥ": ['ap90'],
    "stave": ['ddsa'],
    "staveyya": ['mw'],
    "stavi": ['mw'],
    "stavitavya": ['mw'],
    "stavitṛ": ['cae', 'mw'],
    "stavya": ['cae', 'ddsa', 'mw'],
    "stavāmṛtalaharī": ['mw'],
    "stavān": ['cae'],
    "stavāna": ['mw'],
    "stavārha": ['bhs', 'mw'],
    "stavāvali": ['mw'],
    "staṃbaḥ": ['ap90'],
    "staṃberamaḥ": ['ap90'],
    "staṃbh": ['ap90'],
    "staṃbhakin": ['ap90'],
    "staṃbhanaṃ": ['ap90'],
    "staṃbhaḥ": ['ap90'],
    "staṃbhin": ['ap90'],
    "staṃbhinī": ['ap90'],
    "staṃbhita": ['ap90'],
    "stega": ['gra', 'mw'],
    "stema": ['mw'],
    "stemaḥ": ['ap90'],
    "stemita": ['bhs'],
    "sten": ['ap90', 'mw'],
    "stena": ['cae', 'ddsa', 'gra', 'mw'],
    "stenahṛdaya": ['mw'],
    "stenanigraha": ['mw'],
    "stenay": ['cae'],
    "stenaya": ['ddsa'],
    "stenaḥ": ['ap90'],
    "step": ['ap90', 'mw'],
    "steya": ['cae', 'ddsa', 'gra', 'mw'],
    "steyakṛt": ['cae', 'gra', 'mw'],
    "steyaphala": ['mw'],
    "steyasaṃvāsika": ['bhs', 'mw'],
    "steyaṃ": ['ap90'],
    "steyi": ['mw'],
    "steyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "steyiphala": ['mw'],
    "stha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sthag": ['ap90', 'cae', 'ddsa', 'mw'],
    "sthaga": ['ap90', 'mw'],
    "sthagala": ['mw'],
    "sthagana": ['cae', 'ddsa', 'mw'],
    "sthaganaṃ": ['ap90'],
    "sthagara": ['mw'],
    "sthagaraṃ": ['ap90'],
    "sthagayitavya": ['mw'],
    "sthagaṇā": ['mw'],
    "sthagikā": ['ap90', 'mw'],
    "sthagita": ['ap90', 'mw'],
    "sthagu": ['cae', 'mw'],
    "sthaguḥ": ['ap90'],
    "sthagī": ['ap90', 'mw'],
    "sthairabrahmaṇa": ['mw'],
    "sthairakāyaṇa": ['mw'],
    "sthairya": ['cae', 'ddsa', 'mw'],
    "sthairyakara": ['mw'],
    "sthairyakṛt": ['mw'],
    "sthairyasthāman": ['bhs'],
    "sthairyavat": ['mw'],
    "sthairyavattva": ['mw'],
    "sthairyavicāraṇa": ['mw'],
    "sthairyaṃ": ['ap90'],
    "sthakara": ['mw'],
    "sthakaraṃ": ['ap90'],
    "sthal": ['ap90', 'mw'],
    "sthala": ['cae', 'ddsa', 'mw'],
    "sthalacara": ['cae', 'mw'],
    "sthalacyuta": ['mw'],
    "sthalacārin": ['mw'],
    "sthalacāritā": ['mw'],
    "sthaladevatā": ['mw'],
    "sthalaga": ['cae', 'mw'],
    "sthalagata": ['mw'],
    "sthalagāmin": ['mw'],
    "sthalaja": ['cae', 'mw'],
    "sthalajā": ['mw'],
    "sthalakamala": ['cae', 'mw'],
    "sthalakamalinī": ['mw'],
    "sthalakanda": ['mw'],
    "sthalakumuda": ['mw'],
    "sthalakālī": ['mw'],
    "sthalamañjarī": ['mw'],
    "sthalamārga": ['mw'],
    "sthalanalinī": ['mw'],
    "sthalanīraja": ['mw'],
    "sthalapadma": ['mw'],
    "sthalapadminī": ['mw'],
    "sthalapatha": ['mw'],
    "sthalapathīkṛ": ['mw'],
    "sthalapattana": ['mw'],
    "sthalapiṇḍā": ['mw'],
    "sthalapurāṇa": ['mw'],
    "sthalaruhā": ['mw'],
    "sthalasambhavauṣadhi": ['mw'],
    "sthalastha": ['cae', 'mw'],
    "sthalasīman": ['mw'],
    "sthalatara": ['mw'],
    "sthalatas": ['mw'],
    "sthalatā": ['mw'],
    "sthalaukas": ['mw'],
    "sthalavarman": ['mw'],
    "sthalavartman": ['mw'],
    "sthalavetasa": ['mw'],
    "sthalavigraha": ['mw'],
    "sthalavihaṃga": ['mw'],
    "sthalavihaṃgama": ['mw'],
    "sthalaya": ['mw'],
    "sthalaśuddhi": ['mw'],
    "sthalaśṛṅgāṭa": ['mw'],
    "sthalaśṛṅgāṭaka": ['mw'],
    "sthalaṃ": ['ap90'],
    "sthale": ['mw'],
    "sthalejāta": ['ddsa', 'mw'],
    "sthaleruhā": ['mw'],
    "sthaleyu": ['mw'],
    "sthaleśaya": ['ap90', 'mw'],
    "sthaleśvara": ['mw'],
    "sthalotpalinī": ['ddsa', 'mw'],
    "sthalā": ['ap90', 'ddsa', 'mw'],
    "sthalāntara": ['mw'],
    "sthalāravinda": ['ddsa', 'mw'],
    "sthalārūḍha": ['cae', 'mw'],
    "sthalāya": ['ddsa', 'mw'],
    "sthalī": ['ap90', 'cae', 'ddsa', 'mw'],
    "sthalībhū": ['ddsa', 'mw'],
    "sthalībhūta": ['mw'],
    "sthalīdevatā": ['cae', 'mw'],
    "sthalīy": ['cae'],
    "sthalīya": ['mw'],
    "sthalīśāyin": ['cae', 'ddsa', 'mw'],
    "sthapakarṇika": ['bhs'],
    "sthapanī": ['ddsa', 'mw'],
    "sthapati": ['ap90', 'cae', 'ddsa', 'mw'],
    "sthapayati": ['bhs'],
    "sthapika": ['bhs'],
    "sthapuṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "sthapuṭagata": ['cae', 'mw'],
    "sthapuṭaya": ['mw'],
    "sthapuṭita": ['mw'],
    "sthapuṭī": ['mw'],
    "sthapuṭīkṛ": ['mw'],
    "sthapuṭīkṛta": ['mw'],
    "sthaula": ['mw'],
    "sthaulaka": ['mw'],
    "sthaulalakṣya": ['cae', 'ddsa', 'mw'],
    "sthaulapiṇḍi": ['mw'],
    "sthaulaśīrṣa": ['mw'],
    "sthaulya": ['cae', 'ddsa', 'mw'],
    "sthaulyaṃ": ['ap90'],
    "sthaulāṣṭīvi": ['mw'],
    "sthaura": ['mw'],
    "sthauraṃ": ['ap90'],
    "sthaurin": ['ap90', 'mw'],
    "sthaurya": ['mw'],
    "sthauṇeya": ['mw'],
    "sthauṇeyaka": ['mw'],
    "sthauṇeyaḥ": ['ap90'],
    "sthauṇika": ['mw'],
    "sthauṇābhārika": ['mw'],
    "sthava": ['mw'],
    "sthavi": ['mw'],
    "sthavika": ['bhs'],
    "sthaviman": ['cae', 'ddsa', 'mw'],
    "sthavimat": ['mw'],
    "sthavimatas": ['mw'],
    "sthavira": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "sthaviradyuti": ['mw'],
    "sthaviradāru": ['mw'],
    "sthaviragāthā": ['bhs', 'mw'],
    "sthaviraka": ['bhs'],
    "sthavirasthavira": ['mw'],
    "sthavirā": ['mw'],
    "sthavirāvalīcarita": ['mw'],
    "sthavirāya": ['mw'],
    "sthavirāyus": ['mw'],
    "sthaviḥ": ['ap90'],
    "sthaviṣṭha": ['ap90', 'cae', 'mw'],
    "sthavīyas": ['ap90', 'mw'],
    "sthavīyaṃs": ['cae'],
    "sthaśas": ['cae', 'ddsa', 'gra', 'mw'],
    "sthaḍu": ['cae', 'mw'],
    "sthaṃḍilaṃ": ['ap90'],
    "sthaṇḍila": ['bhs', 'cae', 'ddsa', 'mw'],
    "sthaṇḍilak": ['bhs'],
    "sthaṇḍilaka": ['mw'],
    "sthaṇḍilasaṃveśana": ['mw'],
    "sthaṇḍilasitaka": ['mw'],
    "sthaṇḍilaśa": ['mw'],
    "sthaṇḍilaśayana": ['bhs'],
    "sthaṇḍilaśayyā": ['cae', 'mw'],
    "sthaṇḍilaśāyikā": ['bhs', 'cae', 'mw'],
    "sthaṇḍilaśāyin": ['cae', 'mw'],
    "sthaṇḍile": ['mw'],
    "sthaṇḍileya": ['mw'],
    "sthaṇḍileśaya": ['mw'],
    "sthaṇḍileśayana": ['mw'],
    "sthaṇḍilya": ['bhs', 'mw'],
    "sthema": ['mw'],
    "sthemabhāj": ['mw'],
    "stheman": ['ap90', 'cae', 'ddsa', 'mw'],
    "sthemnā": ['mw'],
    "sthera": ['bhs'],
    "stheya": ['ap90', 'cae', 'ddsa', 'mw'],
    "stheyas": ['ap90', 'ddsa', 'gra', 'mw'],
    "stheyaṃs": ['cae'],
    "stheyīkṛ": ['ddsa'],
    "stheyīkṛta": ['mw'],
    "stheṣṭha": ['ap90', 'mw'],
    "sthihati": ['bhs'],
    "sthika": ['mw'],
    "sthin": ['mw'],
    "sthir": ['mw'],
    "sthira": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sthirabuddhi": ['cae', 'mw'],
    "sthirabuddhika": ['mw'],
    "sthiracakra": ['bhs', 'mw'],
    "sthiracchada": ['mw'],
    "sthiracchāya": ['mw'],
    "sthiracetas": ['mw'],
    "sthiracitta": ['cae', 'mw'],
    "sthiradaṃṣṭra": ['mw'],
    "sthiradeva": ['mw'],
    "sthiradhanvan": ['cae', 'gra', 'mw'],
    "sthiradhāman": ['mw'],
    "sthiradhī": ['mw'],
    "sthiragandha": ['mw'],
    "sthiragandhā": ['mw'],
    "sthiragati": ['mw'],
    "sthirajaṅgama": ['mw'],
    "sthirajihva": ['mw'],
    "sthirajīvin": ['mw'],
    "sthirajīvita": ['mw'],
    "sthirajīvitā": ['mw'],
    "sthiraka": ['mw'],
    "sthirakarman": ['ddsa', 'mw'],
    "sthirakuṭṭaka": ['mw'],
    "sthiraliṅga": ['mw'],
    "sthiraliṅgapratiṣṭhā": ['mw'],
    "sthiralocana": ['mw'],
    "sthiramada": ['mw'],
    "sthiramanas": ['mw'],
    "sthiramati": ['bhs', 'cae', 'mw'],
    "sthiramāyā": ['mw'],
    "sthirapada": ['mw'],
    "sthirapattra": ['mw'],
    "sthiraphalā": ['mw'],
    "sthirapratibandha": ['cae', 'mw'],
    "sthirapratijña": ['mw'],
    "sthirapratijñatva": ['mw'],
    "sthirapratiṣṭhā": ['mw'],
    "sthirapreman": ['mw'],
    "sthirapsnu": ['mw'],
    "sthirapuṣpa": ['mw'],
    "sthirapuṣpin": ['mw'],
    "sthirapālatrilakṣa": ['mw'],
    "sthirapīta": ['cae', 'gra', 'mw'],
    "sthiraraṅgā": ['mw'],
    "sthirarāgā": ['mw'],
    "sthirasattva": ['mw'],
    "sthirasauhṛda": ['cae', 'mw'],
    "sthirasaṃgara": ['mw'],
    "sthirasaṃskāra": ['mw'],
    "sthirasaṃskāratā": ['cae', 'mw'],
    "sthirasthāyin": ['mw'],
    "sthirasādhanaka": ['mw'],
    "sthirasāra": ['mw'],
    "sthiratara": ['ap90', 'mw'],
    "sthirataradṛś": ['mw'],
    "sthiratva": ['mw'],
    "sthiratā": ['ap90', 'cae', 'mw'],
    "sthiravarman": ['mw'],
    "sthiravikrama": ['mw'],
    "sthiravāc": ['mw'],
    "sthiravājin": ['mw'],
    "sthiraya": ['mw'],
    "sthirayauvana": ['cae', 'mw'],
    "sthirayoni": ['mw'],
    "sthiraśaṅkukarṇa": ['mw'],
    "sthiraśrī": ['mw'],
    "sthiritvā": ['mw'],
    "sthirā": ['bhs', 'mw'],
    "sthirāghāta": ['mw'],
    "sthirānurāga": ['mw'],
    "sthirānurāgatva": ['mw'],
    "sthirānurāgin": ['mw'],
    "sthirānurāgitva": ['mw'],
    "sthirāpāya": ['mw'],
    "sthirārambha": ['cae', 'mw'],
    "sthirātman": ['ddsa', 'mw'],
    "sthirāya": ['mw'],
    "sthirāyati": ['mw'],
    "sthirāyus": ['mw'],
    "sthirāṃhripa": ['mw'],
    "sthirāṅghripa": ['mw'],
    "sthirī": ['mw'],
    "sthirībhāva": ['mw'],
    "sthirībhū": ['mw'],
    "sthirīkara": ['mw'],
    "sthirīkaraṇa": ['cae', 'ddsa', 'mw'],
    "sthirīkartavya": ['mw'],
    "sthirīkāra": ['mw'],
    "sthirīkṛ": ['cae', 'mw'],
    "sthita": ['ap90', 'cae', 'ddsa', 'mw'],
    "sthitabuddhidatta": ['bhs', 'mw'],
    "sthitadhī": ['cae', 'ddsa', 'mw'],
    "sthitaka": ['bhs'],
    "sthitalapa": ['bhs'],
    "sthitaliṅga": ['mw'],
    "sthitamati": ['mw'],
    "sthitaniścitta": ['bhs'],
    "sthitaprajña": ['cae', 'mw'],
    "sthitaprakaraṇa": ['mw'],
    "sthitapreman": ['mw'],
    "sthitapāṭhya": ['mw'],
    "sthitasaṃketa": ['mw'],
    "sthitasaṃvid": ['mw'],
    "sthitatā": ['mw'],
    "sthitavant": ['cae'],
    "sthitavat": ['mw'],
    "sthitavatvatī": ['mw'],
    "sthiti": ['cae', 'ddsa', 'mw'],
    "sthitibhid": ['mw'],
    "sthitideśa": ['ddsa', 'mw'],
    "sthitijña": ['mw'],
    "sthitika": ['bhs'],
    "sthitikartṛ": ['mw'],
    "sthitimant": ['cae'],
    "sthitimat": ['ap90', 'mw'],
    "sthitiprada": ['mw'],
    "sthitiprakaraṇa": ['mw'],
    "sthitipālana": ['mw'],
    "sthitisthāpaka": ['mw'],
    "sthititā": ['mw'],
    "sthitivarman": ['mw'],
    "sthitiḥ": ['ap90'],
    "sthitopasthita": ['mw'],
    "sthitvā": ['mw'],
    "sthity": ['mw'],
    "sthityatikrānti": ['mw'],
    "sthitāsana": ['mw'],
    "sthitīmukha": ['bhs'],
    "sthivi": ['ddsa', 'gra', 'mw'],
    "sthivimat": ['gra', 'mw'],
    "sthora": ['bhs'],
    "sthorin": ['mw'],
    "sthorā": ['mw'],
    "sthu": ['mw'],
    "sthula": ['ddsa', 'mw'],
    "sthura": ['mw'],
    "sthurikā": ['mw'],
    "sthurin": ['mw'],
    "sthuḍ": ['ap90', 'mw'],
    "sthā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sthāga": ['mw'],
    "sthāgala": ['mw'],
    "sthāgalika": ['mw'],
    "sthāgara": ['mw'],
    "sthāgha": ['mw'],
    "sthājirāvatī": ['mw'],
    "sthāla": ['bhs', 'cae', 'ddsa', 'mw'],
    "sthālaka": ['bhs', 'mw'],
    "sthālapatha": ['mw'],
    "sthālapathika": ['mw'],
    "sthālarūpa": ['mw'],
    "sthālaṃ": ['ap90'],
    "sthālika": ['mw'],
    "sthālin": ['mw'],
    "sthālī": ['ap90', 'mw'],
    "sthālībila": ['mw'],
    "sthālībilya": ['mw'],
    "sthālībilīya": ['mw'],
    "sthālīdaraṇa": ['mw'],
    "sthālīdruma": ['mw'],
    "sthālīgraha": ['mw'],
    "sthālīpakva": ['mw'],
    "sthālīparṇī": ['mw'],
    "sthālīpulāka": ['mw'],
    "sthālīpulākanyāya": ['mw'],
    "sthālīpurīṣa": ['mw'],
    "sthālīpāka": ['cae', 'mw'],
    "sthālīpākamantra": ['mw'],
    "sthālīpākanirṇaya": ['mw'],
    "sthālīpākaprayoga": ['mw'],
    "sthālīpākīya": ['mw'],
    "sthālīsugandha": ['bhs'],
    "sthālīvṛkṣa": ['mw'],
    "sthāma": ['bhs', 'mw'],
    "sthāman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sthāmavant": ['bhs'],
    "sthāmavat": ['mw'],
    "sthāna": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sthānabhaṅga": ['cae', 'mw'],
    "sthānabhraṃśa": ['cae', 'mw'],
    "sthānabhraṣṭa": ['cae', 'mw'],
    "sthānabhūmi": ['mw'],
    "sthānacaturvidhaśloka": ['mw'],
    "sthānacañcalā": ['mw'],
    "sthānacintaka": ['mw'],
    "sthānacyuta": ['mw'],
    "sthānadātṛ": ['mw'],
    "sthānadīpta": ['mw'],
    "sthānaka": ['cae', 'ddsa', 'mw'],
    "sthānakaṃ": ['ap90'],
    "sthānamāhātmya": ['mw'],
    "sthānamṛga": ['mw'],
    "sthānapata": ['mw'],
    "sthānapati": ['cae', 'mw'],
    "sthānapracyuta": ['mw'],
    "sthānaprāpti": ['mw'],
    "sthānapāla": ['cae', 'mw'],
    "sthānapāta": ['mw'],
    "sthānarakṣaka": ['mw'],
    "sthānastha": ['cae', 'mw'],
    "sthānasthita": ['cae', 'mw'],
    "sthānasthāna": ['mw'],
    "sthānatas": ['ap90', 'mw'],
    "sthānatva": ['mw'],
    "sthānatyāga": ['mw'],
    "sthānatā": ['mw'],
    "sthānavat": ['mw'],
    "sthānavibhāga": ['mw'],
    "sthānavid": ['cae', 'mw'],
    "sthānavīrāsana": ['mw'],
    "sthānayoga": ['cae', 'mw'],
    "sthānayogin": ['mw'],
    "sthānaṃ": ['ap90'],
    "sthāne": ['ap90', 'mw'],
    "sthānepatita": ['mw'],
    "sthānepatitatva": ['mw'],
    "sthāneyoga": ['ddsa', 'mw'],
    "sthāneyogin": ['mw'],
    "sthāneyogitva": ['mw'],
    "sthāneśvara": ['cae', 'ddsa', 'mw'],
    "sthāni": ['mw'],
    "sthānibhūta": ['mw'],
    "sthānika": ['ap90', 'ddsa', 'mw'],
    "sthānin": ['ap90', 'cae', 'mw'],
    "sthānivadbhāva": ['mw'],
    "sthānivat": ['mw'],
    "sthānivatsūtravicāra": ['mw'],
    "sthānivattva": ['mw'],
    "sthāny": ['mw'],
    "sthānyāśraya": ['mw'],
    "sthānābhāva": ['mw'],
    "sthānādhikāra": ['mw'],
    "sthānādhipati": ['mw'],
    "sthānādhyakṣa": ['mw'],
    "sthānānta": ['mw'],
    "sthānāntara": ['cae', 'mw'],
    "sthānāntaragata": ['mw'],
    "sthānāntarābhimukha": ['mw'],
    "sthānānyatva": ['mw'],
    "sthānāpanna": ['mw'],
    "sthānāpatti": ['mw'],
    "sthānāsana": ['cae', 'mw'],
    "sthānāsanavihāravat": ['mw'],
    "sthānāsanika": ['mw'],
    "sthānāsedha": ['cae', 'mw'],
    "sthānāsthānajñānabala": ['mw'],
    "sthānāśraya": ['mw'],
    "sthānāṅga": ['mw'],
    "sthānīya": ['ap90', 'cae', 'mw'],
    "sthāpaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "sthāpana": ['bhs', 'cae', 'ddsa', 'mw'],
    "sthāpanavṛtta": ['mw'],
    "sthāpanaṃ": ['ap90'],
    "sthāpanika": ['mw'],
    "sthāpanā": ['ap90', 'mw'],
    "sthāpanī": ['mw'],
    "sthāpanīya": ['cae', 'mw'],
    "sthāpanīyavyākaraṇa": ['bhs'],
    "sthāpatya": ['cae', 'ddsa', 'mw'],
    "sthāpatyaveda": ['mw'],
    "sthāpatyaḥ": ['ap90'],
    "sthāpayitavya": ['mw'],
    "sthāpayitvā": ['bhs', 'mw'],
    "sthāpayitṛ": ['mw'],
    "sthāpetvā": ['bhs'],
    "sthāpin": ['mw'],
    "sthāpita": ['ap90', 'mw'],
    "sthāpitaka": ['bhs'],
    "sthāpitavat": ['mw'],
    "sthāpya": ['ap90', 'cae', 'mw'],
    "sthāpyāharaṇa": ['mw'],
    "sthāraśman": ['cae', 'gra', 'mw'],
    "sthāsaka": ['cae', 'ddsa', 'mw'],
    "sthāsakaḥ": ['ap90'],
    "sthāsnu": ['ap90', 'cae', 'ddsa', 'mw'],
    "sthāsnutā": ['mw'],
    "sthāsu": ['ap90', 'mw'],
    "sthātavya": ['cae', 'ddsa', 'mw'],
    "sthātra": ['cae', 'gra', 'mw'],
    "sthātṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sthāvan": ['mw'],
    "sthāvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "sthāvaragarala": ['mw'],
    "sthāvarajaṅgama": ['cae', 'mw'],
    "sthāvaraka": ['cae'],
    "sthāvarakalpa": ['mw'],
    "sthāvarakrayāṇaka": ['mw'],
    "sthāvararāja": ['mw'],
    "sthāvararājakanyā": ['mw'],
    "sthāvaratva": ['cae', 'mw'],
    "sthāvaratā": ['ap90', 'cae', 'mw'],
    "sthāvaratīrtha": ['mw'],
    "sthāvarā": ['bhs', 'mw'],
    "sthāvarādi": ['mw'],
    "sthāvarākṛti": ['mw'],
    "sthāvarāsthāvara": ['mw'],
    "sthāvira": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sthāvirya": ['cae'],
    "sthāya": ['ddsa', 'mw'],
    "sthāyam": ['mw'],
    "sthāyi": ['mw'],
    "sthāyibhāva": ['mw'],
    "sthāyika": ['mw'],
    "sthāyikā": ['mw'],
    "sthāyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "sthāyitva": ['mw'],
    "sthāyitā": ['cae', 'ddsa', 'mw'],
    "sthāyuka": ['ap90', 'cae', 'ddsa', 'mw'],
    "sthāyā": ['mw'],
    "sthāyībhū": ['ap90', 'ddsa', 'mw'],
    "sthāṃḍilaḥ": ['ap90'],
    "sthāṇava": ['ddsa', 'mw'],
    "sthāṇavīya": ['cae', 'mw'],
    "sthāṇu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sthāṇubhrama": ['mw'],
    "sthāṇubhūta": ['cae', 'mw'],
    "sthāṇuccheda": ['mw'],
    "sthāṇudiś": ['mw'],
    "sthāṇuka": ['bhs'],
    "sthāṇukarṇī": ['mw'],
    "sthāṇumatī": ['mw'],
    "sthāṇuroga": ['mw'],
    "sthāṇutīrtha": ['mw'],
    "sthāṇuvanaukas": ['mw'],
    "sthāṇuvat": ['mw'],
    "sthāṇuvaṭa": ['mw'],
    "sthāṇv": ['mw'],
    "sthāṇvāśramamahātmya": ['mw'],
    "sthāṇvīśvara": ['mw'],
    "sthāṇūccheda": ['cae'],
    "sthāṇḍila": ['mw'],
    "sthū": ['ddsa', 'gra', 'mw'],
    "sthūl": ['mw'],
    "sthūla": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "sthūlabhadra": ['mw'],
    "sthūlabhikṣa": ['bhs'],
    "sthūlabhoga": ['cae'],
    "sthūlabhuja": ['mw'],
    "sthūlabhāva": ['mw'],
    "sthūlabhūta": ['cae', 'mw'],
    "sthūlabinduka": ['bhs'],
    "sthūlabuddhi": ['mw'],
    "sthūlabuddhimat": ['mw'],
    "sthūlabāhu": ['mw'],
    "sthūlabāhū": ['mw'],
    "sthūlacañcu": ['mw'],
    "sthūlacāpa": ['mw'],
    "sthūlacūḍa": ['mw'],
    "sthūladalā": ['mw'],
    "sthūladarbha": ['mw'],
    "sthūladatta": ['mw'],
    "sthūladaṇḍa": ['mw'],
    "sthūladeha": ['mw'],
    "sthūladehin": ['mw'],
    "sthūladhī": ['mw'],
    "sthūlagrīva": ['mw'],
    "sthūlahasta": ['cae', 'mw'],
    "sthūlailā": ['mw'],
    "sthūlairaṇḍa": ['mw'],
    "sthūlajaṅghā": ['mw'],
    "sthūlajihva": ['mw'],
    "sthūlajīraka": ['mw'],
    "sthūlaka": ['ap90', 'mw'],
    "sthūlakambala": ['bhs'],
    "sthūlakanda": ['mw'],
    "sthūlakandaka": ['mw'],
    "sthūlakarṇa": ['mw'],
    "sthūlakaṅgu": ['mw'],
    "sthūlakaṇā": ['mw'],
    "sthūlakaṇṭaka": ['mw'],
    "sthūlakaṇṭakikā": ['mw'],
    "sthūlakaṇṭā": ['mw'],
    "sthūlakeśa": ['cae', 'mw'],
    "sthūlakoṣṭhaka": ['bhs'],
    "sthūlakoṣṭhakīya": ['bhs'],
    "sthūlakāya": ['mw'],
    "sthūlakāṣṭhadah": ['mw'],
    "sthūlakāṣṭhāgni": ['mw'],
    "sthūlakṣeḍa": ['mw'],
    "sthūlakṣveḍa": ['mw'],
    "sthūlalakṣa": ['cae', 'mw'],
    "sthūlalakṣatva": ['mw'],
    "sthūlalakṣitā": ['mw'],
    "sthūlalakṣya": ['cae', 'mw'],
    "sthūlalakṣyatva": ['mw'],
    "sthūlamadhya": ['cae', 'mw'],
    "sthūlamarica": ['mw'],
    "sthūlamati": ['mw'],
    "sthūlamaya": ['mw'],
    "sthūlambhaviṣṇu": ['mw'],
    "sthūlambhāvuka": ['mw'],
    "sthūlamukha": ['mw'],
    "sthūlamāna": ['mw'],
    "sthūlamūla": ['mw'],
    "sthūlanandā": ['bhs'],
    "sthūlanāla": ['mw'],
    "sthūlanāsa": ['mw'],
    "sthūlanāsika": ['mw'],
    "sthūlanīla": ['mw'],
    "sthūlapaṭa": ['mw'],
    "sthūlapaṭṭa": ['mw'],
    "sthūlapaṭṭāka": ['mw'],
    "sthūlaphala": ['mw'],
    "sthūlaphalā": ['mw'],
    "sthūlapiṇḍa": ['mw'],
    "sthūlaprakaraṇa": ['mw'],
    "sthūlaprapañca": ['cae', 'mw'],
    "sthūlapuṣpa": ['mw'],
    "sthūlapuṣpā": ['mw'],
    "sthūlapuṣpī": ['mw'],
    "sthūlapāda": ['mw'],
    "sthūlapūlāsa": ['mw'],
    "sthūlapṛṣata": ['mw'],
    "sthūlaroma": ['mw'],
    "sthūlasikta": ['mw'],
    "sthūlaskandha": ['mw'],
    "sthūlasthūla": ['mw'],
    "sthūlasāyaka": ['mw'],
    "sthūlasūkṣma": ['cae', 'mw'],
    "sthūlasūkṣmaprakaraṇa": ['mw'],
    "sthūlasūkṣmaprapañca": ['cae', 'mw'],
    "sthūlasūkṣmaśarīra": ['cae', 'mw'],
    "sthūlasūraṇa": ['mw'],
    "sthūlatara": ['mw'],
    "sthūlataṇḍula": ['mw'],
    "sthūlatomarin": ['mw'],
    "sthūlatva": ['mw'],
    "sthūlatvacā": ['mw'],
    "sthūlatā": ['ap90', 'cae', 'mw'],
    "sthūlatāla": ['mw'],
    "sthūlavaidehī": ['mw'],
    "sthūlavalkala": ['mw'],
    "sthūlavartmakṛt": ['mw'],
    "sthūlaviṣaya": ['cae', 'mw'],
    "sthūlavālukā": ['mw'],
    "sthūlavṛkṣaphala": ['mw'],
    "sthūlayati": ['ap90'],
    "sthūlaśalka": ['mw'],
    "sthūlaśara": ['mw'],
    "sthūlaśarīra": ['cae', 'mw'],
    "sthūlaśaṅkhā": ['mw'],
    "sthūlaśimbī": ['mw'],
    "sthūlaśiras": ['cae', 'mw'],
    "sthūlaśopha": ['mw'],
    "sthūlaśophatva": ['mw'],
    "sthūlaśākinī": ['mw'],
    "sthūlaśāli": ['mw'],
    "sthūlaśāṭa": ['cae', 'mw'],
    "sthūlaśāṭaka": ['cae', 'mw'],
    "sthūlaśāṭikā": ['mw'],
    "sthūlaśāṭī": ['mw'],
    "sthūlaśīrṣa": ['mw'],
    "sthūlaśīrṣikā": ['mw'],
    "sthūlaśūraṇa": ['mw'],
    "sthūlaṃkaraṇa": ['mw'],
    "sthūlaṣaṭpada": ['mw'],
    "sthūleccha": ['ddsa', 'mw'],
    "sthūlin": ['ap90', 'mw'],
    "sthūloccaya": ['mw'],
    "sthūlodara": ['mw'],
    "sthūlā": ['mw'],
    "sthūlācārya": ['mw'],
    "sthūlākarṇa": ['mw'],
    "sthūlākṣa": ['mw'],
    "sthūlākṣā": ['mw'],
    "sthūlāmra": ['mw'],
    "sthūlāntra": ['cae', 'ddsa', 'mw'],
    "sthūlārma": ['mw'],
    "sthūlāsthūla": ['mw'],
    "sthūlāsya": ['mw'],
    "sthūlāṃśā": ['mw'],
    "sthūlāṅga": ['mw'],
    "sthūlāṣṭīva": ['mw'],
    "sthūlī": ['mw'],
    "sthūlībhūta": ['mw'],
    "sthūlīkaraṇa": ['mw'],
    "sthūlīkṛta": ['mw'],
    "sthūma": ['mw'],
    "sthūmaḥ": ['ap90'],
    "sthūra": ['cae', 'ddsa', 'gra', 'mw'],
    "sthūragudā": ['mw'],
    "sthūragūpa": ['gra'],
    "sthūravāku": ['mw'],
    "sthūrayūpa": ['mw'],
    "sthūrayūpavat": ['mw'],
    "sthūraḥ": ['ap90'],
    "sthūri": ['cae', 'ddsa', 'gra', 'mw'],
    "sthūrikā": ['ddsa', 'mw'],
    "sthūrin": ['ap90', 'mw'],
    "sthūrā": ['mw'],
    "sthūrīpṛṣṭha": ['mw'],
    "sthūṇa": ['bhs', 'cae', 'mw'],
    "sthūṇakarṇa": ['mw'],
    "sthūṇopasthūṇaka": ['mw'],
    "sthūṇya": ['mw'],
    "sthūṇā": ['ap90', 'ddsa', 'gra', 'mw'],
    "sthūṇābhāra": ['mw'],
    "sthūṇāgarta": ['mw'],
    "sthūṇākarṇa": ['mw'],
    "sthūṇāmayūkha": ['mw'],
    "sthūṇānikhanananyāya": ['mw'],
    "sthūṇāpadī": ['mw'],
    "sthūṇāpakṣa": ['mw'],
    "sthūṇārāja": ['mw'],
    "sthūṇāvaśeṣa": ['mw'],
    "sthūṇāvirohaṇa": ['mw'],
    "sthūṇāśīrṣa": ['mw'],
    "sthūṇī": ['mw'],
    "sthūṇīya": ['mw'],
    "sthṛ": ['mw'],
    "sti": ['cae', 'ddsa', 'gra', 'mw'],
    "stibhi": ['ddsa', 'mw'],
    "stibhinī": ['mw'],
    "stibhivat": ['mw'],
    "stibhiḥ": ['ap90'],
    "stigh": ['ap90', 'cae', 'ddsa', 'mw'],
    "stim": ['ap90', 'cae', 'ddsa', 'mw'],
    "stimbhi": ['mw'],
    "stimita": ['ap90', 'mw'],
    "stimitajava": ['mw'],
    "stimitam": ['mw'],
    "stimitanayana": ['mw'],
    "stimitapravāha": ['mw'],
    "stimitarājan": ['bhs'],
    "stimitasamādhiśuci": ['mw'],
    "stimitasthita": ['mw'],
    "stimitatva": ['mw'],
    "stimitatvaṃ": ['ap90'],
    "stimitatā": ['mw'],
    "stimitavāyu": ['mw'],
    "stimitaya": ['mw'],
    "stimitāyatākṣa": ['mw'],
    "stip": ['ap90', 'mw'],
    "stipā": ['cae', 'ddsa', 'gra', 'mw'],
    "stir": ['gra'],
    "stire": ['mw'],
    "stiyā": ['cae', 'ddsa', 'gra', 'mw'],
    "sto": ['mw'],
    "stobdhavya": ['mw'],
    "stobha": ['cae', 'ddsa', 'mw'],
    "stobhacchalā": ['mw'],
    "stobhana": ['mw'],
    "stobhanasaṃhāra": ['mw'],
    "stobhapada": ['mw'],
    "stobhaprakṛti": ['mw'],
    "stobhavat": ['mw'],
    "stobhaḥ": ['ap90'],
    "stobhita": ['mw'],
    "stobhānusaṃhāra": ['mw'],
    "stoka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "stokaka": ['cae', 'ddsa', 'mw'],
    "stokakaḥ": ['ap90'],
    "stokakāya": ['mw'],
    "stokam": ['mw'],
    "stokanamra": ['mw'],
    "stokapāṇḍura": ['mw'],
    "stokatamas": ['mw'],
    "stokatva": ['mw'],
    "stokatā": ['mw'],
    "stokaśas": ['ap90', 'cae', 'mw'],
    "stokonmiṣat": ['mw'],
    "stokya": ['cae', 'mw'],
    "stokāvaśeṣaprāṇa": ['mw'],
    "stokāyus": ['mw'],
    "stokīya": ['cae', 'ddsa', 'mw'],
    "stom": ['mw'],
    "stoma": ['cae', 'ddsa', 'gra', 'mw'],
    "stomabhāga": ['mw'],
    "stomabhāgika": ['mw'],
    "stomabhāgā": ['mw'],
    "stomaciti": ['mw'],
    "stomakṣāra": ['mw'],
    "stomamaya": ['cae', 'mw'],
    "stomapurogava": ['mw'],
    "stomapṛṣṭha": ['mw'],
    "stomataṣṭa": ['gra', 'mw'],
    "stomavardhana": ['cae', 'gra', 'mw'],
    "stomavāhas": ['cae', 'gra', 'mw'],
    "stomavṛddhi": ['mw'],
    "stomaya": ['mw'],
    "stomayati": ['ap90'],
    "stomayoga": ['mw'],
    "stomaḥ": ['ap90'],
    "stomia": ['gra'],
    "stomita": ['bhs'],
    "stomya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "stomāyana": ['mw'],
    "stomīya": ['mw'],
    "stotavya": ['ap90', 'cae', 'ddsa', 'mw'],
    "stotra": ['cae', 'gra', 'mw'],
    "stotrabhāṣya": ['mw'],
    "stotrajāla": ['mw'],
    "stotrakārin": ['mw'],
    "stotraprakaraṇa": ['mw'],
    "stotrapāṭha": ['mw'],
    "stotraratna": ['mw'],
    "stotrarāja": ['mw'],
    "stotrasamīṣantī": ['mw'],
    "stotravarga": ['mw'],
    "stotravat": ['mw'],
    "stotravyākhyā": ['mw'],
    "stotraya": ['mw'],
    "stotraṃ": ['ap90'],
    "stotriya": ['cae', 'ddsa', 'mw'],
    "stotriyaḥ": ['ap90'],
    "stotriyā": ['mw'],
    "stotrādipāṭha": ['mw'],
    "stotrārha": ['mw'],
    "stotrāvalī": ['mw'],
    "stotrīya": ['cae', 'mw'],
    "stotrīyā": ['mw'],
    "stotṛ": ['ap90', 'cae', 'gra', 'mw'],
    "strairājaka": ['mw'],
    "straiṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "straiṇagarbha": ['cae'],
    "straiṇatva": ['mw'],
    "straiṇatā": ['ap90', 'mw'],
    "straiṣūya": ['cae', 'mw'],
    "stri": ['mw'],
    "stritamā": ['mw'],
    "striyammanya": ['mw'],
    "striyā": ['bhs'],
    "striyāgāra": ['bhs'],
    "stry": ['mw'],
    "stryabhigamana": ['ddsa', 'mw'],
    "stryadhyakṣa": ['mw'],
    "stryagāra": ['mw'],
    "stryanuja": ['mw'],
    "stryādivyatyāsam": ['mw'],
    "stryāgāra": ['bhs'],
    "stryājīva": ['cae', 'mw'],
    "stryākhyā": ['mw'],
    "strāṭa": ['mw'],
    "strī": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "strībandha": ['mw'],
    "strībhaga": ['mw'],
    "strībhava": ['cae', 'mw'],
    "strībhoga": ['mw'],
    "strībhāga": ['mw'],
    "strībhāva": ['cae', 'mw'],
    "strībhūṣaṇa": ['mw'],
    "strībhṛtya": ['mw'],
    "strībuddhi": ['mw'],
    "strībādhya": ['mw'],
    "strībālaghātin": ['cae', 'mw'],
    "strīcaritra": ['mw'],
    "strīcaura": ['mw'],
    "strīcañcala": ['mw'],
    "strīcihna": ['mw'],
    "strīcittahārin": ['mw'],
    "strīdehārdha": ['mw'],
    "strīdevata": ['mw'],
    "strīdhana": ['cae', 'mw'],
    "strīdhanalolupa": ['mw'],
    "strīdhananirṇaya": ['mw'],
    "strīdhanaprakaraṇa": ['mw'],
    "strīdharma": ['cae', 'mw'],
    "strīdharmapaddhati": ['mw'],
    "strīdharmayoga": ['mw'],
    "strīdharmiṇī": ['mw'],
    "strīdhava": ['mw'],
    "strīdhvaja": ['mw'],
    "strīdhūrta": ['mw'],
    "strīdhūrtaka": ['mw'],
    "strīdveṣin": ['cae', 'mw'],
    "strīdviṣ": ['cae', 'mw'],
    "strīga": ['mw'],
    "strīgamana": ['cae', 'mw'],
    "strīgamanīya": ['mw'],
    "strīgavī": ['mw'],
    "strīghna": ['cae', 'mw'],
    "strīghoṣa": ['mw'],
    "strīghātaka": ['cae', 'mw'],
    "strīgraha": ['mw'],
    "strīgrāhin": ['mw'],
    "strīguru": ['mw'],
    "strīhantṛ": ['cae', 'mw'],
    "strīharaṇa": ['mw'],
    "strīhatyā": ['cae', 'mw'],
    "strīhuta": ['cae', 'mw'],
    "strīhārin": ['mw'],
    "strījana": ['cae', 'mw'],
    "strījananī": ['cae', 'mw'],
    "strījanman": ['mw'],
    "strījanmapattravicāra": ['mw'],
    "strījanmapattrībhāvādhyāya": ['mw'],
    "strījita": ['cae', 'mw'],
    "strījātaka": ['mw'],
    "strījātakapaddhati": ['mw'],
    "strījātakaṭīkā": ['mw'],
    "strījāti": ['mw'],
    "strīka": ['cae', 'mw'],
    "strīkaraṇa": ['mw'],
    "strīkarman": ['mw'],
    "strīkaṭi": ['cae', 'mw'],
    "strīkaṭī": ['cae', 'mw'],
    "strīkitava": ['mw'],
    "strīkośa": ['mw'],
    "strīkumāra": ['mw'],
    "strīkāgāra": ['bhs'],
    "strīkāma": ['cae', 'mw'],
    "strīkārya": ['cae', 'mw'],
    "strīkṛta": ['mw'],
    "strīkṣetra": ['mw'],
    "strīkṣīra": ['cae', 'mw'],
    "strīlakṣaṇa": ['mw'],
    "strīlakṣaṇavid": ['mw'],
    "strīlampaṭa": ['mw'],
    "strīlaulya": ['mw'],
    "strīliṅga": ['cae', 'mw'],
    "strīliṅgatva": ['mw'],
    "strīliṅgavartin": ['mw'],
    "strīloka": ['mw'],
    "strīlola": ['mw'],
    "strīmadhya": ['mw'],
    "strīmantra": ['mw'],
    "strīmat": ['mw'],
    "strīmaya": ['bhs', 'cae', 'mw'],
    "strīmmanya": ['mw'],
    "strīmukha": ['mw'],
    "strīmukhamadhu": ['mw'],
    "strīmukhamadhudohada": ['mw'],
    "strīmukhamadhudohala": ['mw'],
    "strīmukhapa": ['mw'],
    "strīmānin": ['mw'],
    "strīmāyā": ['mw'],
    "strīndriya": ['mw'],
    "strīnibandhana": ['mw'],
    "strīnirjita": ['mw'],
    "strīnāman": ['mw'],
    "strīnātha": ['mw'],
    "strīpara": ['mw'],
    "strīparvan": ['mw'],
    "strīparvatadeśa": ['mw'],
    "strīpaṇyopajīvin": ['mw'],
    "strīpiśācī": ['mw'],
    "strīpoṣaka": ['bhs'],
    "strīpradhāna": ['mw'],
    "strīprajñā": ['mw'],
    "strīpramāṇa": ['mw'],
    "strīprasaṅga": ['mw'],
    "strīprasū": ['cae', 'mw'],
    "strīpratyaya": ['cae', 'mw'],
    "strīpratyayaprakaraṇa": ['mw'],
    "strīpriya": ['mw'],
    "strīprāya": ['mw'],
    "strīpumaṃs": ['cae'],
    "strīpura": ['mw'],
    "strīpuruṣa": ['mw'],
    "strīpuṃdharma": ['cae', 'mw'],
    "strīpuṃnapuṃsaka": ['mw'],
    "strīpuṃs": ['mw'],
    "strīpuṃsa": ['mw'],
    "strīpuṃsalakṣaṇā": ['mw'],
    "strīpuṃsaliṅgin": ['mw'],
    "strīpuṃyoga": ['mw'],
    "strīpuṣpa": ['mw'],
    "strīpūruṣa": ['mw'],
    "strīpūrva": ['cae', 'mw'],
    "strīpūrvaka": ['cae', 'mw'],
    "strīpūrvin": ['mw'],
    "strīrahaskāma": ['mw'],
    "strīrajas": ['mw'],
    "strīratna": ['cae', 'mw'],
    "strīratnakūṭā": ['mw'],
    "strīrañjana": ['mw'],
    "strīroga": ['mw'],
    "strīrājya": ['mw'],
    "strīrāśi": ['mw'],
    "strīrūpa": ['mw'],
    "strīsabha": ['mw'],
    "strīsakha": ['mw'],
    "strīsamasthāna": ['mw'],
    "strīsambhoga": ['mw'],
    "strīsarūpin": ['mw'],
    "strīsaubhāgyakavala": ['mw'],
    "strīsaṃbandha": ['cae', 'mw'],
    "strīsaṃbhoga": ['cae'],
    "strīsaṃgrahaṇa": ['cae', 'mw'],
    "strīsaṃjña": ['mw'],
    "strīsaṃsarga": ['mw'],
    "strīsaṅga": ['cae', 'mw'],
    "strīsevā": ['mw'],
    "strīsukha": ['mw'],
    "strīsvabhāva": ['mw'],
    "strīsvarūpa": ['mw'],
    "strīsvarūpavat": ['mw'],
    "strīsvarūpin": ['mw'],
    "strītamā": ['ap90', 'mw'],
    "strītarā": ['mw'],
    "strītva": ['cae', 'mw'],
    "strītā": ['ap90', 'mw'],
    "strītānukaroga": ['mw'],
    "strīvadha": ['mw'],
    "strīvaśa": ['cae', 'mw'],
    "strīvaśya": ['cae', 'mw'],
    "strīvaśyatā": ['mw'],
    "strīveṣadhāraka": ['mw'],
    "strīveṣadhārin": ['mw'],
    "strīvidheya": ['mw'],
    "strīvijita": ['mw'],
    "strīvitta": ['mw'],
    "strīvivāha": ['cae', 'mw'],
    "strīviyoga": ['mw'],
    "strīviṣaya": ['cae', 'mw'],
    "strīvraṇa": ['mw'],
    "strīvyañjana": ['mw'],
    "strīvyañjanakṛtā": ['mw'],
    "strīvāhya": ['mw'],
    "strīvākyāṅkuśaprakṣuṇṇa": ['mw'],
    "strīvāsa": ['mw'],
    "strīvāsas": ['mw'],
    "strīvṛta": ['mw'],
    "strīy": ['cae'],
    "strīya": ['ddsa', 'mw'],
    "strīyantra": ['ddsa', 'mw'],
    "strīyā": ['bhs'],
    "strīyācitaputra": ['mw'],
    "strīśauṇḍa": ['mw'],
    "strīśeṣa": ['mw'],
    "strīśroṇi": ['mw'],
    "strīśūdrādidinacaryākrama": ['mw'],
    "strīśūdrādīnāṃdevārcanavicāra": ['mw'],
    "strīṣakha": ['cae', 'mw'],
    "strīṣaṃsāda": ['mw'],
    "strīṣū": ['cae', 'mw'],
    "strīṣūya": ['mw'],
    "stu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "stubdha": ['mw'],
    "stubh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "stubha": ['mw'],
    "stubhaḥ": ['ap90'],
    "stubhvan": ['cae', 'gra', 'mw'],
    "stuc": ['ap90', 'mw'],
    "stuka": ['cae', 'ddsa', 'mw'],
    "stukaḥ": ['ap90'],
    "stukā": ['ap90', 'ddsa', 'gra', 'mw'],
    "stukāsargam": ['mw'],
    "stukāvin": ['gra', 'mw'],
    "stukī": ['mw'],
    "stumbh": ['mw'],
    "stump": ['mw'],
    "stunaka": ['mw'],
    "stunakaḥ": ['ap90'],
    "stupa": ['cae', 'ddsa', 'mw'],
    "stut": ['cae', 'ddsa', 'gra', 'mw'],
    "stuta": ['ap90', 'cae', 'ddsa', 'mw'],
    "stutastoma": ['mw'],
    "stutasvāmikṣetra": ['mw'],
    "stutavat": ['mw'],
    "stutaśastra": ['mw'],
    "stutaśastravat": ['mw'],
    "stuti": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "stutibhāga": ['mw'],
    "stutibrāhmaṇa": ['mw'],
    "stuticandrikā": ['mw'],
    "stutigītaka": ['cae', 'mw'],
    "stutikusumāñjali": ['mw'],
    "stutimantra": ['mw'],
    "stutimat": ['mw'],
    "stutimaṅgala": ['mw'],
    "stutipada": ['mw'],
    "stutipriya": ['mw'],
    "stutipāṭhaka": ['mw'],
    "stutisāra": ['mw'],
    "stutisūktimālā": ['mw'],
    "stutivacana": ['mw'],
    "stutivacas": ['mw'],
    "stutivrata": ['mw'],
    "stutivāda": ['mw'],
    "stutiśabda": ['mw'],
    "stutiśastra": ['mw'],
    "stutiśīla": ['mw'],
    "stutiṭīkā": ['mw'],
    "stutya": ['ap90', 'cae', 'ddsa', 'mw'],
    "stutyatva": ['mw'],
    "stutyavrata": ['mw'],
    "stutyā": ['mw'],
    "stuva": ['mw'],
    "stuvat": ['mw'],
    "stuvati": ['bhs'],
    "stuveya": ['mw'],
    "stuvi": ['mw'],
    "stuvāna": ['mw'],
    "stuṃbh": ['ap90'],
    "stuṣeyia": ['gra'],
    "stuṣeyya": ['gra', 'mw'],
    "styai": ['ap90', 'mw'],
    "styaina": ['mw'],
    "styayāntataḥ": ['bhs'],
    "styena": ['mw'],
    "styenaḥ": ['ap90'],
    "styā": ['cae', 'ddsa'],
    "styāna": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "styānamiddha": ['bhs'],
    "styāya": ['mw'],
    "styāyana": ['ddsa', 'mw'],
    "styāyanaṃ": ['ap90'],
    "stā": ['ddsa', 'gra'],
    "stāgha": ['mw'],
    "stāman": ['mw'],
    "stāmbhin": ['mw'],
    "stāmbhāyana": ['mw'],
    "stāmu": ['gra', 'mw'],
    "stāra": ['bhs'],
    "stāva": ['cae', 'ddsa', 'mw'],
    "stāvaka": ['mw'],
    "stāvakatva": ['mw'],
    "stāvakaḥ": ['ap90'],
    "stāvaḥ": ['ap90'],
    "stāvya": ['mw'],
    "stāvā": ['mw'],
    "stāyat": ['mw'],
    "stāyu": ['cae', 'ddsa', 'gra', 'mw'],
    "stīm": ['mw'],
    "stīma": ['cae', 'mw'],
    "stīmita": ['mw'],
    "stīna": ['bhs'],
    "stīrvi": ['mw'],
    "stīrviḥ": ['ap90'],
    "stīrṇa": ['cae', 'ddsa', 'mw'],
    "stīrṇabarhis": ['cae', 'gra', 'mw'],
    "stīrṇi": ['mw'],
    "stū": ['mw'],
    "stūp": ['ap90', 'mw'],
    "stūpa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "stūpabhedaka": ['mw'],
    "stūpabhedana": ['mw'],
    "stūpabimba": ['mw'],
    "stūpaka": ['bhs'],
    "stūpamaṇḍala": ['mw'],
    "stūpapṛṣṭha": ['mw'],
    "stūpaḥ": ['ap90'],
    "stūpeśāṇa": ['mw'],
    "stūpikā": ['bhs'],
    "stūṇākarṇa": ['mw'],
    "stṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "stṛh": ['ap90', 'cae', 'mw'],
    "stṛkṣ": ['ap90', 'mw'],
    "stṛta": ['mw'],
    "stṛti": ['cae', 'ddsa', 'mw'],
    "stṛtiḥ": ['ap90'],
    "stṛtya": ['cae', 'ddsa', 'mw'],
    "stṛṇa": ['ddsa', 'mw'],
    "stṛṇīṣaṇi": ['mw'],
    "stṝ": ['ap90', 'mw'],
    "stṝh": ['mw'],
    "su": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "su-osārita": ['cped'],
    "su-uddiṭṭha": ['cped'],
    "sua": ['gra'],
    "suabhiṣṭi": ['gra'],
    "suabhiṣṭisumna": ['gra'],
    "suabhīśu": ['gra'],
    "suac": ['gra'],
    "suad": ['gra'],
    "suadhvara": ['gra'],
    "suagni": ['gra'],
    "suanīka": ['gra'],
    "suapas": ['gra'],
    "suapasy": ['gra'],
    "suapasyā": ['gra'],
    "suapatya": ['gra'],
    "suapivāta": ['gra'],
    "suapnas": ['gra'],
    "suapāka": ['gra'],
    "suar": ['gra'],
    "suaraṃkṛta": ['gra'],
    "suaraṇa": ['gra'],
    "suarbhānu": ['gra'],
    "suarcakṣas": ['gra'],
    "suarcanas": ['gra'],
    "suarci": ['gra'],
    "suardṛś": ['gra'],
    "suarga": ['gra'],
    "suaritra": ['gra'],
    "suarjeṣa": ['gra'],
    "suarjit": ['gra'],
    "suarka": ['gra'],
    "suarmīḍha": ['gra'],
    "suarpati": ['gra'],
    "suartha": ['gra'],
    "suarvat": ['gra'],
    "suarvid": ['gra'],
    "suaryu": ['gra'],
    "suarṇara": ['gra'],
    "suarṇṛ": ['gra'],
    "suarṣā": ['gra'],
    "suarṣāti": ['gra'],
    "suasti": ['gra'],
    "suastidā": ['gra'],
    "suastigā": ['gra'],
    "suastimat": ['gra'],
    "suastivah": ['gra'],
    "suastivāh": ['gra'],
    "suavas": ['gra'],
    "suañc": ['gra'],
    "suañcas": ['gra'],
    "suaśva": ['gra'],
    "suaśvayu": ['gra'],
    "suaśvia": ['gra'],
    "suaṅga": ['gra'],
    "suaṅguri": ['gra'],
    "suaṣṭra": ['gra'],
    "sub": ['mw'],
    "subabhru": ['mw'],
    "subaddha": ['ddsa', 'gra', 'mw'],
    "subaddhakakṣā": ['bhs'],
    "subahu": ['cae', 'cped', 'mw'],
    "subahudhā": ['mw'],
    "subahuśas": ['mw'],
    "subahuśruta": ['mw'],
    "subala": ['cae', 'mw'],
    "subalacandra": ['mw'],
    "subalaputra": ['mw'],
    "subalavat": ['mw'],
    "subandha": ['mw'],
    "subandhanavimocana": ['mw'],
    "subandhu": ['bhs', 'cae', 'gra', 'mw'],
    "subanta": ['mw'],
    "subantaprakriyāsarvasva": ['mw'],
    "subantaprakāśa": ['mw'],
    "subantarūpāvalī": ['mw'],
    "subantasaṃgraha": ['mw'],
    "subantavyākhyāna": ['mw'],
    "subantavāda": ['mw'],
    "subantaśiromaṇi": ['mw'],
    "subarhis": ['gra', 'mw'],
    "subartha": ['mw'],
    "subarthanirṇaya": ['mw'],
    "subarthasaṃgraha": ['mw'],
    "subarthatattvāvaloka": ['mw'],
    "subaṃdhu": ['ap90'],
    "subbaca": ['cped'],
    "subbata": ['cped'],
    "subbaṭṭita": ['cped'],
    "subbuṭṭhi": ['cped'],
    "subdha": ['mw'],
    "subh": ['ddsa', 'mw'],
    "subha": ['cped', 'mw'],
    "subhabodhārthamālāpaddhati": ['mw'],
    "subhadra": ['bhs', 'cae', 'gra', 'mw'],
    "subhadraharaṇa": ['mw'],
    "subhadraka": ['mw'],
    "subhadrakā": ['mw'],
    "subhadrapūrvaja": ['mw'],
    "subhadravijaya": ['mw'],
    "subhadreśa": ['mw'],
    "subhadrā": ['bhs', 'mw'],
    "subhadrādhanaṃjaya": ['mw'],
    "subhadrāpariṇaya": ['mw'],
    "subhadrāṇī": ['mw'],
    "subhaga": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "subhagam": ['mw'],
    "subhagambhaviṣṇu": ['mw'],
    "subhagambhāvuka": ['mw'],
    "subhagammanya": ['mw'],
    "subhagammanyabhāva": ['mw'],
    "subhagamānin": ['mw'],
    "subhagasaṃdeśa": ['mw'],
    "subhagatva": ['gra', 'mw'],
    "subhagatā": ['mw'],
    "subhagaya": ['mw'],
    "subhagaṃkaraṇa": ['mw'],
    "subhagaṃmanya": ['cae'],
    "subhagodaya": ['mw'],
    "subhagodayadarpaṇa": ['mw'],
    "subhagā": ['bhs', 'mw'],
    "subhagākheṭabhūmi": ['mw'],
    "subhagākheṭabhūmitva": ['mw'],
    "subhagānanda": ['mw'],
    "subhagānandanātha": ['mw'],
    "subhagārcanacandrikā": ['mw'],
    "subhagārcāratna": ['mw'],
    "subhagāsuta": ['mw'],
    "subhagātanaya": ['mw'],
    "subhaikṣa": ['mw'],
    "subhairava": ['mw'],
    "subhakiṇṇa": ['cped'],
    "subhakti": ['mw'],
    "subhakṣya": ['ddsa', 'mw'],
    "subhanimitta": ['cped'],
    "subhara": ['bhs', 'cae', 'cped', 'gra', 'mw'],
    "subharatā": ['mw'],
    "subharva": ['ddsa'],
    "subhasad": ['gra', 'mw'],
    "subhaspati": ['gra'],
    "subhati": ['bhs'],
    "subhava": ['mw'],
    "subhavas": ['mw'],
    "subhavya": ['mw'],
    "subhayaṃkara": ['mw'],
    "subhayānaka": ['mw'],
    "subhañjana": ['mw'],
    "subhaṃsas": ['mw'],
    "subhaṅga": ['mw'],
    "subhaṇita": ['cae', 'mw'],
    "subhaṭa": ['cae', 'ddsa', 'mw'],
    "subhaṭadatta": ['mw'],
    "subhaṭavarman": ['mw'],
    "subhaṭā": ['mw'],
    "subhaṭṭa": ['mw'],
    "subheṣaja": ['mw'],
    "subhikkha": ['cped'],
    "subhikṣa": ['cae', 'mw'],
    "subhikṣakara": ['mw'],
    "subhikṣakārin": ['mw'],
    "subhikṣakṛt": ['mw'],
    "subhikṣarāja": ['bhs'],
    "subhikṣā": ['mw'],
    "subhikṣākānta": ['bhs'],
    "subhikṣāvaha": ['mw'],
    "subhiṣaj": ['mw'],
    "subhogya": ['mw'],
    "subhogā": ['mw'],
    "subhogīna": ['mw'],
    "subhoja": ['mw'],
    "subhojana": ['mw'],
    "subhojas": ['gra', 'mw'],
    "subhru": ['cae', 'mw'],
    "subhrunāsākṣikeśānta": ['mw'],
    "subhrāj": ['mw'],
    "subhrāja": ['mw'],
    "subhrātṛ": ['mw'],
    "subhrū": ['cae', 'mw'],
    "subhrūnāsākṣikeśānta": ['mw'],
    "subhuja": ['bhs', 'cae', 'mw'],
    "subhujā": ['mw'],
    "subhukta": ['mw'],
    "subhvan": ['mw'],
    "subhāga": ['cae', 'gra', 'mw'],
    "subhāgya": ['mw'],
    "subhāgā": ['mw'],
    "subhājana": ['mw'],
    "subhānu": ['mw'],
    "subhās": ['gra', 'mw'],
    "subhāsa": ['mw'],
    "subhāsvara": ['mw'],
    "subhāvita": ['mw'],
    "subhāvitva": ['mw'],
    "subhāñjana": ['mw'],
    "subhāṣaṇa": ['mw'],
    "subhāṣin": ['mw'],
    "subhāṣita": ['cae', 'mw'],
    "subhāṣitacandrikā": ['mw'],
    "subhāṣitagaveṣin": ['bhs', 'mw'],
    "subhāṣitahārāvali": ['mw'],
    "subhāṣitakaustubha": ['mw'],
    "subhāṣitakāvya": ['mw'],
    "subhāṣitamaya": ['mw'],
    "subhāṣitamañjarī": ['mw'],
    "subhāṣitamuktāvali": ['mw'],
    "subhāṣitanīvī": ['mw'],
    "subhāṣitaprabandha": ['mw'],
    "subhāṣitarasāsvādajātaromāñcakañcuka": ['mw'],
    "subhāṣitaratnakośa": ['mw'],
    "subhāṣitaratnasaṃdoha": ['mw'],
    "subhāṣitaratnākara": ['mw'],
    "subhāṣitasamuccaya": ['mw'],
    "subhāṣitasaṃgraha": ['mw'],
    "subhāṣitasudhā": ['mw'],
    "subhāṣitasudhānandalaharī": ['mw'],
    "subhāṣitasuradruma": ['mw'],
    "subhāṣitaśloka": ['mw'],
    "subhāṣitārṇava": ['mw'],
    "subhāṣitāvali": ['mw'],
    "subhīma": ['mw'],
    "subhīmā": ['mw'],
    "subhīraka": ['mw'],
    "subhīrava": ['mw'],
    "subhīruka": ['mw'],
    "subhīta": ['mw'],
    "subhū": ['cae', 'gra', 'mw'],
    "subhūma": ['bhs', 'mw'],
    "subhūmi": ['bhs', 'mw'],
    "subhūmika": ['mw'],
    "subhūmipa": ['mw'],
    "subhūta": ['cae', 'mw'],
    "subhūtakṛt": ['mw'],
    "subhūti": ['bhs', 'cae', 'mw'],
    "subhūtika": ['mw'],
    "subhūtipāla": ['mw'],
    "subhūtā": ['mw'],
    "subhūyas": ['mw'],
    "subhūṣaṇa": ['mw'],
    "subhūṣaṇabhūṣitā": ['bhs', 'mw'],
    "subhūṣaṇā": ['bhs', 'mw'],
    "subhūṣitakhaṇḍa": ['bhs'],
    "subhṛta": ['cae', 'gra', 'mw'],
    "subhṛśa": ['cae', 'mw'],
    "subhṛśam": ['mw'],
    "subodha": ['cae', 'mw'],
    "subodhajātaka": ['mw'],
    "subodhakāra": ['mw'],
    "subodham": ['mw'],
    "subodhamañjarī": ['mw'],
    "subodhana": ['cae'],
    "subodhanā": ['mw'],
    "subodhanī": ['mw'],
    "subodhapañcikā": ['mw'],
    "subodhikā": ['mw'],
    "subodhinī": ['mw'],
    "subodhinīkāra": ['mw'],
    "subodhā": ['mw'],
    "subrahma": ['bhs'],
    "subrahmabandhūka": ['mw'],
    "subrahman": ['cae', 'gra', 'mw'],
    "subrahmavāsudeva": ['mw'],
    "subrahmaṇya": ['cae', 'gra', 'mw'],
    "subrahmaṇyakṣetramāhātmya": ['mw'],
    "subrahmaṇyamāhātmya": ['mw'],
    "subrahmaṇyapaddhati": ['mw'],
    "subrahmaṇyapañcaratna": ['mw'],
    "subrahmaṇyaprayoga": ['mw'],
    "subrahmaṇyapūjāvidhi": ['mw'],
    "subrahmaṇyasahasranāman": ['mw'],
    "subrahmaṇyastotra": ['mw'],
    "subrahmaṇyā": ['mw'],
    "subrahmaṇyāṣṭaka": ['mw'],
    "subrahmaṇīya": ['mw'],
    "subrāhmaṇa": ['mw'],
    "subuddhi": ['bhs', 'cae', 'mw'],
    "subuddhicandra": ['mw'],
    "subuddhimat": ['mw'],
    "subuddhimiśra": ['mw'],
    "subuddhimiśramaheśvara": ['mw'],
    "subuddhivant": ['bhs'],
    "subudha": ['mw'],
    "subvibhaktyarthaviveka": ['mw'],
    "subāhu": ['bhs', 'cae', 'gra', 'mw'],
    "subāhuka": ['mw'],
    "subāhuparipṛcchā": ['bhs', 'mw'],
    "subāhuyukta": ['bhs', 'mw'],
    "subāhuśatru": ['mw'],
    "subāla": ['cae', 'mw'],
    "subāladhi": ['mw'],
    "subālaka": ['mw'],
    "subāliśa": ['mw'],
    "subālāgrāma": ['mw'],
    "subāndhava": ['mw'],
    "subībhatsa": ['mw'],
    "subīja": ['cae', 'mw'],
    "sucakra": ['cae', 'ddsa', 'gra', 'mw'],
    "sucakropaskara": ['mw'],
    "sucakṣas": ['cae', 'gra', 'mw'],
    "sucakṣu": ['mw'],
    "sucakṣus": ['cae', 'mw'],
    "sucalā": ['bhs'],
    "sucandana": ['cae', 'mw'],
    "sucandra": ['bhs', 'mw'],
    "sucandradṛṣṭi": ['bhs'],
    "sucandrima": ['bhs'],
    "sucarita": ['cae', 'cped', 'mw'],
    "sucaritacarita": ['cae', 'mw'],
    "sucaritavrata": ['mw'],
    "sucaritin": ['mw'],
    "sucaritra": ['mw'],
    "sucaritrā": ['mw'],
    "sucaritā": ['mw'],
    "sucaritārthapada": ['mw'],
    "sucarman": ['mw'],
    "sucarā": ['mw'],
    "sucatura": ['mw'],
    "sucañcukā": ['mw'],
    "succhada": ['cae', 'mw'],
    "succhanna": ['cped'],
    "succhardis": ['cae', 'mw'],
    "succhattra": ['mw'],
    "succhattrā": ['mw'],
    "succhattrī": ['mw'],
    "succhāya": ['cae', 'mw'],
    "succhāyā": ['mw'],
    "sucela": ['cae', 'mw'],
    "sucelaka": ['cae', 'mw'],
    "sucetana": ['cae', 'mw'],
    "sucetas": ['cae', 'gra', 'mw'],
    "sucetu": ['cae', 'gra'],
    "sucetuna": ['gra', 'mw'],
    "sucetunā": ['mw'],
    "sucetīkṛta": ['mw'],
    "suceṣṭarūpa": ['bhs', 'mw'],
    "suchardis": ['gra'],
    "suci": ['cped'],
    "sucigandha": ['cped'],
    "sucigavesī": ['cped'],
    "sucihnita": ['mw'],
    "sucijātika": ['cped'],
    "sucikamma": ['cped'],
    "sucintana": ['mw'],
    "sucintin": ['bhs'],
    "sucintita": ['mw'],
    "sucintitacintin": ['mw'],
    "sucintitārtha": ['bhs', 'mw'],
    "sucintya": ['mw'],
    "sucintā": ['mw'],
    "sucira": ['cae', 'mw'],
    "suciraśrama": ['mw'],
    "sucirotsuka": ['mw'],
    "suciroṣita": ['mw'],
    "sucirārpita": ['mw'],
    "sucirāyus": ['mw'],
    "sucitra": ['bhs', 'cae', 'mw'],
    "sucitrabījā": ['mw'],
    "sucitraka": ['mw'],
    "sucitrarājika": ['bhs'],
    "sucitrā": ['mw'],
    "sucitta": ['cae', 'cped', 'mw'],
    "sucittita": ['cped'],
    "sucivasana": ['cped'],
    "sucukrikā": ['mw'],
    "sucuṭī": ['mw'],
    "sucāru": ['cae', 'cped', 'mw'],
    "sucārudaśanā": ['mw'],
    "sucārurūpa": ['cped', 'mw'],
    "sucārusvana": ['mw'],
    "sucārutā": ['mw'],
    "sucārvaṅgī": ['mw'],
    "sucārā": ['mw'],
    "sucīrā": ['mw'],
    "sucīrṇadhvaja": ['bhs', 'mw'],
    "sud": ['gra'],
    "suda": ['bhs'],
    "sudaas": ['gra'],
    "sudagdhikā": ['mw'],
    "sudakṣa": ['cae', 'gra', 'mw'],
    "sudakṣiṇa": ['cae', 'gra', 'mw'],
    "sudakṣiṇā": ['mw'],
    "sudala": ['mw'],
    "sudalā": ['mw'],
    "sudama": ['mw'],
    "sudambha": ['mw'],
    "sudant": ['cae'],
    "sudanta": ['bhs', 'cae', 'cped', 'mw'],
    "sudantā": ['mw'],
    "sudantī": ['mw'],
    "sudarbha": ['mw'],
    "sudarbhā": ['mw'],
    "sudaridra": ['mw'],
    "sudarpaṇa": ['mw'],
    "sudarśa": ['bhs', 'cae', 'gra', 'mw'],
    "sudarśaka": ['mw'],
    "sudarśana": ['bhs', 'cae', 'mw'],
    "sudarśanabhāṣya": ['mw'],
    "sudarśanacakra": ['mw'],
    "sudarśanacūrṇa": ['mw'],
    "sudarśanadvīpa": ['mw'],
    "sudarśanajvālamantra": ['mw'],
    "sudarśanakavaca": ['mw'],
    "sudarśanakālaprabhā": ['mw'],
    "sudarśanamahāmantra": ['mw'],
    "sudarśanamantra": ['mw'],
    "sudarśanamāhātmya": ['mw'],
    "sudarśanamīmāṃsā": ['mw'],
    "sudarśananṛsiṃhārādhana": ['mw'],
    "sudarśanapañjaropaniṣad": ['mw'],
    "sudarśanaprītikara": ['bhs', 'mw'],
    "sudarśanapāñcajanyapratiṣṭhā": ['mw'],
    "sudarśanasahasranāman": ['mw'],
    "sudarśanasampāta": ['mw'],
    "sudarśanasaṃhitā": ['mw'],
    "sudarśanastava": ['mw'],
    "sudarśanastotra": ['mw'],
    "sudarśanasukarṇakacarita": ['mw'],
    "sudarśanavijaya": ['mw'],
    "sudarśanaśataka": ['mw'],
    "sudarśanaṣaḍakṣara": ['mw'],
    "sudarśanopaniṣad": ['mw'],
    "sudarśanā": ['bhs', 'mw'],
    "sudarśanādiyantravidhi": ['mw'],
    "sudarśanārādhana": ['mw'],
    "sudarśanārādhanakrama": ['mw'],
    "sudarśanāṣṭaka": ['mw'],
    "sudarśanī": ['mw'],
    "sudarśanīya": ['mw'],
    "sudarśatā": ['mw'],
    "sudarśinī": ['mw'],
    "sudassa": ['cped'],
    "sudassana": ['cped'],
    "sudat": ['mw'],
    "sudatra": ['cae', 'gra', 'mw'],
    "sudatta": ['bhs', 'mw'],
    "sudattā": ['bhs', 'mw'],
    "sudatī": ['mw'],
    "sudaya": ['bhs'],
    "sudayita": ['mw'],
    "sudaśana": ['mw'],
    "sudaśārhakula": ['mw'],
    "sudaṁ": ['cped'],
    "sudaṃsas": ['cae', 'ddsa', 'gra', 'mw'],
    "sudaṃśita": ['mw'],
    "sudaṃṣṭra": ['bhs', 'mw'],
    "sudaṃṣṭrā": ['bhs', 'mw'],
    "sudaṇḍa": ['mw'],
    "sudaṇḍikā": ['mw'],
    "sudda": ['cped'],
    "suddha": ['cped'],
    "suddhatta": ['cped'],
    "suddhatā": ['cped'],
    "suddhi": ['cped'],
    "suddhimagga": ['cped'],
    "suddhyupāsya": ['mw'],
    "suddhājīva": ['cped'],
    "suddhāvāsa": ['cped'],
    "suddhāvāsika": ['cped'],
    "suddiṭṭha": ['cped'],
    "sudeha": ['cae', 'mw'],
    "sudella": ['mw'],
    "sudesita": ['cped'],
    "sudeva": ['bhs', 'cae', 'gra', 'mw'],
    "sudevana": ['mw'],
    "sudevi": ['mw'],
    "sudevia": ['gra'],
    "sudevikā": ['mw'],
    "sudevya": ['cae', 'gra', 'mw'],
    "sudevā": ['mw'],
    "sudeśa": ['cae', 'mw'],
    "sudeśika": ['mw'],
    "sudeṣṇa": ['mw'],
    "sudeṣṇu": ['mw'],
    "sudeṣṇā": ['mw'],
    "sudhammatā": ['cped'],
    "sudhana": ['bhs', 'cae', 'gra', 'mw'],
    "sudhanta": ['cped'],
    "sudhanu": ['bhs'],
    "sudhanus": ['mw'],
    "sudhanva": ['mw'],
    "sudhanvamāhātmya": ['mw'],
    "sudhanvan": ['cae', 'gra', 'mw'],
    "sudhanvācārya": ['mw'],
    "sudhanvācāryaḥ": ['ap90'],
    "sudhara": ['mw'],
    "sudharma": ['bhs', 'cae', 'mw'],
    "sudharman": ['cae', 'mw'],
    "sudharmatīrtha": ['bhs'],
    "sudharmin": ['mw'],
    "sudharmitā": ['mw'],
    "sudharmiṣṭha": ['mw'],
    "sudharmā": ['mw'],
    "sudharṣa": ['mw'],
    "sudharṣaṇa": ['mw'],
    "sudhauta": ['cae', 'mw'],
    "sudhaya": ['mw'],
    "sudhendra": ['mw'],
    "sudheṣa": ['mw'],
    "sudhi": ['mw'],
    "sudhita": ['cae', 'ddsa', 'gra', 'mw'],
    "sudhiti": ['mw'],
    "sudhitiḥ": ['ap90'],
    "sudhodaya": ['mw'],
    "sudhodbhava": ['mw'],
    "sudhodbhavā": ['mw'],
    "sudhodgāra": ['ddsa', 'mw'],
    "sudhodgāramaya": ['mw'],
    "sudhota": ['cped'],
    "sudhur": ['cae', 'gra', 'mw'],
    "sudhura": ['cae', 'gra', 'mw'],
    "sudhyupāsya": ['mw'],
    "sudhā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sudhābhavana": ['mw'],
    "sudhābhitti": ['mw'],
    "sudhābhojin": ['mw'],
    "sudhābhuj": ['mw'],
    "sudhābhṛti": ['mw'],
    "sudhādhauta": ['cae', 'mw'],
    "sudhādhavala": ['cae', 'mw'],
    "sudhādhavalita": ['mw'],
    "sudhādhāman": ['mw'],
    "sudhādhāra": ['mw'],
    "sudhādhārā": ['cae', 'mw'],
    "sudhādhārākvathastotra": ['mw'],
    "sudhādrava": ['cae', 'mw'],
    "sudhādīdhiti": ['mw'],
    "sudhāhara": ['mw'],
    "sudhāhartṛ": ['mw'],
    "sudhāhrada": ['mw'],
    "sudhāhṛt": ['mw'],
    "sudhājīvin": ['mw'],
    "sudhākalaśa": ['mw'],
    "sudhākamma": ['cped'],
    "sudhākara": ['cae', 'cped', 'mw'],
    "sudhākaratā": ['mw'],
    "sudhākaṇṭha": ['mw'],
    "sudhākir": ['mw'],
    "sudhākāra": ['cae', 'mw'],
    "sudhākṣālita": ['mw'],
    "sudhālaharī": ['mw'],
    "sudhāma": ['bhs', 'mw'],
    "sudhāman": ['mw'],
    "sudhāmaya": ['cae', 'mw'],
    "sudhāmayūkha": ['mw'],
    "sudhāmitra": ['mw'],
    "sudhāmodaka": ['mw'],
    "sudhāmodakaja": ['mw'],
    "sudhāmukhī": ['mw'],
    "sudhāmṛta": ['cae', 'mw'],
    "sudhāmṛtamaya": ['mw'],
    "sudhānandalaharī": ['mw'],
    "sudhānandasūri": ['mw'],
    "sudhāndhas": ['mw'],
    "sudhānidhi": ['mw'],
    "sudhāpāṇi": ['mw'],
    "sudhāpūra": ['mw'],
    "sudhāra": ['cae', 'gra', 'mw'],
    "sudhārasa": ['cae', 'mw'],
    "sudhārasamaya": ['mw'],
    "sudhārasatva": ['mw'],
    "sudhārañjinī": ['mw'],
    "sudhāraśmi": ['cae', 'mw'],
    "sudhārin": ['mw'],
    "sudhāsava": ['mw'],
    "sudhāsaṃgraha": ['mw'],
    "sudhāseka": ['mw'],
    "sudhāsindhu": ['mw'],
    "sudhāsita": ['cae', 'mw'],
    "sudhāsitatā": ['mw'],
    "sudhāspardhin": ['mw'],
    "sudhāsravā": ['mw'],
    "sudhāsyanda": ['mw'],
    "sudhāsyandin": ['mw'],
    "sudhāsāgara": ['mw'],
    "sudhāsāra": ['mw'],
    "sudhāsū": ['mw'],
    "sudhāsūka": ['mw'],
    "sudhāsūti": ['mw'],
    "sudhāta": ['cae', 'mw'],
    "sudhātu": ['cae', 'gra', 'mw'],
    "sudhātudakṣiṇa": ['mw'],
    "sudhātṛ": ['mw'],
    "sudhāvadāta": ['bhs', 'mw'],
    "sudhāvalita": ['cae'],
    "sudhāvarti": ['mw'],
    "sudhāvarṣa": ['cae', 'mw'],
    "sudhāvarṣin": ['mw'],
    "sudhāvat": ['mw'],
    "sudhāvāsa": ['mw'],
    "sudhāvāsā": ['mw'],
    "sudhāvṛṣṭi": ['mw'],
    "sudhāya": ['mw'],
    "sudhāyoni": ['mw'],
    "sudhāyuka": ['mw'],
    "sudhāśaśāṅkadhavala": ['mw'],
    "sudhāśravā": ['mw'],
    "sudhāśubhra": ['mw'],
    "sudhāṃśu": ['cae', 'mw'],
    "sudhāṃśubha": ['mw'],
    "sudhāṃśuratna": ['mw'],
    "sudhāṃśutaila": ['mw'],
    "sudhāṅga": ['mw'],
    "sudhāṭippaṇī": ['mw'],
    "sudhī": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sudhīcandrikā": ['mw'],
    "sudhīkṛ": ['ddsa', 'mw'],
    "sudhīmayūkha": ['mw'],
    "sudhīndrayati": ['mw'],
    "sudhīra": ['cae', 'ddsa', 'mw'],
    "sudhīvan": ['mw'],
    "sudhīvilocana": ['mw'],
    "sudhīvilocanasāra": ['mw'],
    "sudhīvāda": ['mw'],
    "sudhīśṛṅgāra": ['mw'],
    "sudhūmravarṇā": ['mw'],
    "sudhūmya": ['mw'],
    "sudhūpaka": ['mw'],
    "sudhūpya": ['mw'],
    "sudhṛt": ['mw'],
    "sudhṛta": ['cae', 'mw'],
    "sudhṛti": ['cae', 'mw'],
    "sudhṛṣ": ['gra'],
    "sudhṛṣṭama": ['cae', 'mw'],
    "sudi": ['ap90', 'ddsa', 'mw'],
    "sudih": ['cae', 'mw'],
    "sudina": ['cae', 'ddsa', 'gra', 'mw'],
    "sudinatva": ['gra', 'mw'],
    "sudinatā": ['mw'],
    "sudinna": ['cped'],
    "sudināha": ['mw'],
    "sudināya": ['mw'],
    "suditi": ['mw'],
    "sudiv": ['cae', 'gra', 'mw'],
    "sudiva": ['cae', 'mw'],
    "sudivasa": ['cae', 'mw'],
    "sudivā": ['mw'],
    "sudivātaṇḍi": ['mw'],
    "sudiṭṭha": ['cped'],
    "sudogdhrī": ['mw'],
    "sudogha": ['cae', 'gra', 'mw'],
    "sudoha": ['cae', 'mw'],
    "sudohana": ['cae', 'mw'],
    "sudraviṇas": ['cae', 'gra', 'mw'],
    "sudraṣṭṛ": ['mw'],
    "sudru": ['cae', 'gra', 'mw'],
    "sudubbala": ['cped'],
    "sududdasa": ['cped'],
    "sudugha": ['cae', 'gra', 'mw'],
    "sudughā": ['mw'],
    "suduha": ['mw'],
    "sudukkara": ['cped'],
    "sudukūla": ['mw'],
    "sudullabha": ['cped'],
    "sudurbala": ['cae', 'mw'],
    "sudurbhaga": ['mw'],
    "sudurbhida": ['mw'],
    "sudurbuddhi": ['cae', 'mw'],
    "sudurdarśa": ['cae', 'mw'],
    "sudurdharṣa": ['mw'],
    "sudurdhaṣa": ['cae'],
    "sudurdṛśa": ['cae', 'mw'],
    "sudurgama": ['cae', 'mw'],
    "sudurgamya": ['cae', 'mw'],
    "sudurjara": ['mw'],
    "sudurjaya": ['cae', 'mw'],
    "sudurjayā": ['bhs', 'mw'],
    "sudurjñeya": ['cae', 'mw'],
    "sudurlabha": ['cae', 'mw'],
    "sudurmanas": ['cae', 'mw'],
    "sudurmarṣa": ['mw'],
    "sudurmati": ['mw'],
    "sudurnirīkṣaṇa": ['mw'],
    "sudurukti": ['mw'],
    "sudurvaca": ['mw'],
    "sudurvacas": ['mw'],
    "sudurvaha": ['mw'],
    "sudurveda": ['cae', 'mw'],
    "sudurvida": ['cae', 'mw'],
    "sudurācāra": ['cae', 'mw'],
    "sudurādharṣa": ['cae', 'mw'],
    "sudurāruha": ['mw'],
    "sudurāsada": ['mw'],
    "sudurāvarta": ['mw'],
    "sudustara": ['cae', 'mw'],
    "sudustyaja": ['mw'],
    "sudustāra": ['cae', 'mw'],
    "suduttara": ['cped'],
    "suduścara": ['cae', 'mw'],
    "suduścikitsa": ['mw'],
    "suduḥkha": ['cae', 'mw'],
    "suduḥkham": ['mw'],
    "suduḥkhita": ['cae', 'mw'],
    "suduḥkhārohaṇa": ['mw'],
    "suduḥsaha": ['cae', 'mw'],
    "suduḥsparśa": ['mw'],
    "suduḥśrava": ['mw'],
    "suduṣkara": ['cae', 'mw'],
    "suduṣkha": ['mw'],
    "suduṣkhita": ['mw'],
    "suduṣkula": ['mw'],
    "suduṣkṛta": ['mw'],
    "suduṣprabha": ['mw'],
    "suduṣprasādhya": ['mw'],
    "suduṣprekṣya": ['mw'],
    "suduṣprāpa": ['cae', 'mw'],
    "suduṣpāra": ['cae', 'mw'],
    "suduṣṭa": ['cae', 'mw'],
    "sudvija": ['cae', 'mw'],
    "sudvijānana": ['mw'],
    "sudyotman": ['cae', 'gra', 'mw'],
    "sudyu": ['mw'],
    "sudyumna": ['cae', 'gra', 'mw'],
    "sudyut": ['cae', 'gra', 'mw'],
    "sudā": ['cae', 'mw'],
    "sudāma": ['mw'],
    "sudāman": ['cae', 'gra', 'mw'],
    "sudāmana": ['mw'],
    "sudāminī": ['mw'],
    "sudāmā": ['mw'],
    "sudāna": ['cae', 'mw'],
    "sudānta": ['bhs', 'mw'],
    "sudāntasena": ['mw'],
    "sudānu": ['cae', 'gra', 'mw'],
    "sudāru": ['cae', 'mw'],
    "sudārumūla": ['mw'],
    "sudāruṇa": ['cae', 'mw'],
    "sudās": ['cae', 'gra', 'mw'],
    "sudāsa": ['bhs', 'cae', 'mw'],
    "sudātu": ['gra', 'mw'],
    "sudātṛ": ['mw'],
    "sudāvan": ['cae', 'gra', 'mw'],
    "sudāya": ['mw'],
    "sudīditi": ['gra', 'mw'],
    "sudīdīti": ['cae'],
    "sudīkṣā": ['mw'],
    "sudīpta": ['cae', 'mw'],
    "sudīpā": ['bhs'],
    "sudīrgha": ['cae', 'mw'],
    "sudīrghagharmā": ['mw'],
    "sudīrghajīvaphalā": ['mw'],
    "sudīrghaphalakā": ['mw'],
    "sudīrghā": ['mw'],
    "sudīti": ['cae', 'gra', 'mw'],
    "sudūra": ['cae', 'mw'],
    "sudūram": ['mw'],
    "sudṛpta": ['cae', 'mw'],
    "sudṛś": ['cae', 'gra', 'mw'],
    "sudṛśa": ['bhs'],
    "sudṛśya": ['cae', 'mw'],
    "sudṛśīka": ['cae', 'gra', 'mw'],
    "sudṛśīkarūpa": ['gra', 'mw'],
    "sudṛśīkasaṃdṛś": ['gra', 'mw'],
    "sudṛḍha": ['cae', 'mw'],
    "sudṛḍhaharmyavat": ['mw'],
    "sudṛḍhajñānaraśmijālabimbaskandha": ['bhs'],
    "sudṛḍham": ['mw'],
    "sudṛḍhatvacā": ['mw'],
    "sudṛḍhatā": ['mw'],
    "sudṛḍhavrata": ['mw'],
    "sudṛṣṭa": ['cae', 'mw'],
    "sudṛṣṭi": ['mw'],
    "suga": ['cae', 'ddsa', 'gra', 'mw'],
    "sugabhasti": ['cae', 'gra', 'mw'],
    "sugahana": ['cped', 'mw'],
    "sugahanā": ['mw'],
    "sugahanāvṛti": ['mw'],
    "sugalā": ['mw'],
    "sugama": ['cae', 'ddsa', 'mw'],
    "sugamana": ['mw'],
    "sugambhīra": ['cae', 'mw'],
    "sugamya": ['cae', 'mw'],
    "sugamānvayā": ['mw'],
    "sugandha": ['cae', 'cped', 'mw'],
    "sugandhabhūtṛṇa": ['mw'],
    "sugandhaka": ['mw'],
    "sugandhakāya": ['bhs'],
    "sugandhamukha": ['bhs', 'mw'],
    "sugandhamūlā": ['mw'],
    "sugandhapattrā": ['mw'],
    "sugandharāyaṇa": ['bhs'],
    "sugandhatailaniryāsa": ['mw'],
    "sugandhatā": ['mw'],
    "sugandhavanamāhātmya": ['mw'],
    "sugandhavat": ['mw'],
    "sugandhaya": ['ddsa', 'mw'],
    "sugandhayukti": ['ddsa', 'mw'],
    "sugandheśa": ['ddsa', 'mw'],
    "sugandhi": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sugandhika": ['cae', 'cped', 'mw'],
    "sugandhikusuma": ['mw'],
    "sugandhikusumā": ['mw'],
    "sugandhikā": ['mw'],
    "sugandhimustaka": ['mw'],
    "sugandhimūla": ['mw'],
    "sugandhimūlā": ['mw'],
    "sugandhimūtrapatana": ['mw'],
    "sugandhimūṣikā": ['mw'],
    "sugandhin": ['cae', 'ddsa', 'gra', 'mw'],
    "sugandhinī": ['mw'],
    "sugandhisīha": ['ddsa', 'mw'],
    "sugandhita": ['bhs'],
    "sugandhitejana": ['cae', 'mw'],
    "sugandhitriphalā": ['mw'],
    "sugandhitā": ['mw'],
    "sugandhivastra": ['bhs'],
    "sugandhā": ['mw'],
    "sugandhāditya": ['mw'],
    "sugandhāmalaka": ['mw'],
    "sugandhāra": ['mw'],
    "sugandhāḍhya": ['mw'],
    "sugandhāḍhyā": ['mw'],
    "sugandhī": ['cped', 'mw'],
    "suganman": ['mw'],
    "sugantva": ['mw'],
    "sugara": ['mw'],
    "sugarhita": ['mw'],
    "sugata": ['bhs', 'cae', 'cped', 'mw'],
    "sugatacetanā": ['bhs', 'mw'],
    "sugatamitra": ['mw'],
    "sugatatva": ['mw'],
    "sugataśāsana": ['mw'],
    "sugati": ['cae', 'cped', 'mw'],
    "sugatisaṃdarśanalokeśvara": ['bhs'],
    "sugatisopāna": ['mw'],
    "sugatālaya": ['cped', 'mw'],
    "sugatāvadāna": ['mw'],
    "sugatāyatana": ['mw'],
    "sugatī": ['cped'],
    "sugaurava": ['mw'],
    "sugautama": ['mw'],
    "sugava": ['cae', 'gra', 'mw'],
    "sugavi": ['mw'],
    "sugavia": ['gra'],
    "sugavya": ['cae', 'gra', 'mw'],
    "sugaṇ": ['mw'],
    "sugaṇa": ['mw'],
    "sugaṇaka": ['mw'],
    "sugaṇita": ['mw'],
    "sugaṇokti": ['mw'],
    "sugaṇā": ['mw'],
    "sugehinī": ['cae', 'mw'],
    "sugevṛdh": ['gra', 'mw'],
    "sugeṣṇā": ['mw'],
    "suggahita": ['cped'],
    "sughana": ['cae', 'mw'],
    "sugharikāgṛhaka": ['mw'],
    "sugharṣa": ['mw'],
    "sughaṭa": ['mw'],
    "sughaṭatva": ['mw'],
    "sughaṭita": ['mw'],
    "sughaṭitaghaṭita": ['mw'],
    "sughaṭṭita": ['mw'],
    "sughna": ['cae', 'gra', 'mw'],
    "sughora": ['bhs', 'cae', 'mw'],
    "sughoṣa": ['bhs', 'cae', 'mw'],
    "sughoṣaghoṣa": ['mw'],
    "sughoṣagrāma": ['mw'],
    "sughoṣaka": ['bhs', 'mw'],
    "sughoṣasamabuddhi": ['bhs'],
    "sughoṣavat": ['mw'],
    "sughoṣita": ['mw'],
    "sugla": ['mw'],
    "sugmia": ['gra'],
    "sugmya": ['cae', 'gra', 'mw'],
    "sugo": ['mw'],
    "sugocara": ['mw'],
    "sugopita": ['cped'],
    "sugopya": ['mw'],
    "sugopā": ['cae', 'gra', 'mw'],
    "sugraha": ['cae', 'mw'],
    "sugrahaṇa": ['mw'],
    "sugranthi": ['mw'],
    "sugrathita": ['gra', 'mw'],
    "sugrāhya": ['mw'],
    "sugrāma": ['mw'],
    "sugrāsa": ['mw'],
    "sugrīva": ['bhs', 'cae', 'mw'],
    "sugrīveśa": ['mw'],
    "sugrīvāgraja": ['mw'],
    "sugrīvī": ['mw'],
    "sugrīṣma": ['cae', 'mw'],
    "sugu": ['cae', 'gra', 'mw'],
    "sugulpha": ['mw'],
    "sugupta": ['cae', 'mw'],
    "suguptabhāṇḍa": ['mw'],
    "suguptabhāṇḍatā": ['mw'],
    "suguptalekha": ['mw'],
    "suguptam": ['mw'],
    "suguptatara": ['mw'],
    "sugupti": ['bhs', 'cae', 'mw'],
    "suguptā": ['bhs', 'mw'],
    "suguptīkṛ": ['cae', 'mw'],
    "suguru": ['cae', 'mw'],
    "sugutta": ['cped'],
    "suguṇa": ['cae', 'mw'],
    "suguṇin": ['cae', 'mw'],
    "sugādha": ['cae', 'gra', 'mw'],
    "sugārhapatya": ['gra', 'mw'],
    "sugārhaspatya": ['cae'],
    "sugātra": ['cae', 'mw'],
    "sugātriyā": ['mw'],
    "sugātrā": ['bhs'],
    "sugātrī": ['mw'],
    "sugātu": ['cae', 'gra', 'mw'],
    "sugātuyā": ['cae', 'gra', 'mw'],
    "sugāṅga": ['mw'],
    "sugīta": ['cae', 'mw'],
    "sugītha": ['mw'],
    "sugīti": ['cae', 'mw'],
    "sugūḍha": ['cae', 'mw'],
    "sugūḍham": ['mw'],
    "sugṛddha": ['mw'],
    "sugṛha": ['cae', 'mw'],
    "sugṛhapati": ['cae', 'mw'],
    "sugṛhin": ['mw'],
    "sugṛhī": ['mw'],
    "sugṛhīta": ['cae', 'mw'],
    "sugṛhītanāmadheya": ['cae'],
    "sugṛhītanāman": ['mw'],
    "sugṛhītābhidha": ['mw'],
    "suh": ['mw'],
    "suhada": ['cped'],
    "suhajja": ['cped'],
    "suhala": ['mw'],
    "suhalana": ['mw'],
    "suhana": ['cae', 'gra', 'mw'],
    "suhantu": ['gra', 'mw'],
    "suhanu": ['mw'],
    "suhara": ['mw'],
    "suharṣitaprabheśvarā": ['bhs'],
    "suhasta": ['cae', 'gra', 'mw'],
    "suhastia": ['gra'],
    "suhastin": ['mw'],
    "suhastya": ['cae', 'gra', 'mw'],
    "suhastī": ['gra'],
    "suhasānana": ['mw'],
    "suhata": ['ddsa', 'mw'],
    "suhava": ['cae', 'gra', 'mw'],
    "suhavis": ['gra', 'mw'],
    "suhavya": ['cae', 'gra', 'mw'],
    "suhavītu": ['gra'],
    "suhavītunāman": ['gra', 'mw'],
    "suhaya": ['mw'],
    "suhaṇamukha": ['mw'],
    "suhemanta": ['mw'],
    "suhiraṇya": ['gra', 'mw'],
    "suhiraṇyavat": ['mw'],
    "suhita": ['cae', 'cped', 'mw'],
    "suhitā": ['mw'],
    "suhiṃs": ['mw'],
    "suhma": ['cae', 'ddsa', 'mw'],
    "suhmaka": ['mw'],
    "suhmanagara": ['mw'],
    "suhmāḥ": ['ap90'],
    "suhotra": ['cae', 'mw'],
    "suhotṛ": ['cae', 'gra', 'mw'],
    "suhuta": ['cae', 'gra', 'mw'],
    "suhutahut": ['mw'],
    "suhutakṛt": ['mw'],
    "suhutād": ['gra', 'mw'],
    "suhvāna": ['mw'],
    "suhārd": ['mw'],
    "suhārda": ['gra'],
    "suhāsa": ['mw'],
    "suhāsin": ['mw'],
    "suhū": ['mw'],
    "suhūti": ['mw'],
    "suhṛc": ['mw'],
    "suhṛcchokavivardhana": ['mw'],
    "suhṛd": ['cae', 'mw'],
    "suhṛda": ['mw'],
    "suhṛdadruh": ['mw'],
    "suhṛdaya": ['cae', 'mw'],
    "suhṛdbala": ['mw'],
    "suhṛdbheda": ['mw'],
    "suhṛdvadha": ['cae', 'mw'],
    "suhṛdvākya": ['mw'],
    "suhṛdāgama": ['mw'],
    "suhṛj": ['mw'],
    "suhṛjjana": ['cae', 'mw'],
    "suhṛl": ['mw'],
    "suhṛlliṅgadhara": ['mw'],
    "suhṛn": ['mw'],
    "suhṛnmitra": ['mw'],
    "suhṛnmukha": ['mw'],
    "suhṛnnārī": ['mw'],
    "suhṛt": ['mw'],
    "suhṛtprakāśākhyastava": ['mw'],
    "suhṛtprāpti": ['mw'],
    "suhṛttama": ['mw'],
    "suhṛttva": ['mw'],
    "suhṛttyāga": ['mw'],
    "suhṛttā": ['cae', 'mw'],
    "suidhma": ['gra'],
    "suiṣu": ['gra'],
    "suiṣṭa": ['gra'],
    "sujaghana": ['mw'],
    "sujala": ['cae', 'mw'],
    "sujalpa": ['mw'],
    "sujambha": ['cae', 'gra', 'mw'],
    "sujambhan": ['mw'],
    "sujana": ['cae', 'cped', 'mw'],
    "sujanabhadra": ['bhs'],
    "sujanaparisevitā": ['bhs', 'mw'],
    "sujanaparivārā": ['bhs', 'mw'],
    "sujanatva": ['mw'],
    "sujanatā": ['cae', 'mw'],
    "sujanaya": ['mw'],
    "sujanetaramaitrī": ['mw'],
    "sujaniman": ['gra', 'mw'],
    "sujanman": ['cae', 'gra', 'mw'],
    "sujanmādivrata": ['mw'],
    "sujantu": ['mw'],
    "sujanākara": ['mw'],
    "sujatru": ['mw'],
    "sujavas": ['mw'],
    "sujaya": ['cae', 'mw'],
    "sujaṅgha": ['mw'],
    "sujihva": ['cae', 'gra', 'mw'],
    "sujita": ['cae', 'mw'],
    "sujitaśrama": ['mw'],
    "sujjaka": ['cae', 'ddsa', 'mw'],
    "sujjhamāna": ['cped'],
    "sujjhati": ['cped'],
    "sujjhi": ['cped'],
    "sujjhitvā": ['cped'],
    "sujji": ['cae', 'mw'],
    "sujuṣṭa": ['cae', 'gra', 'mw'],
    "sujyaiṣṭhya": ['mw'],
    "sujyeṣṭha": ['bhs', 'mw'],
    "sujyotis": ['cae', 'gra', 'mw'],
    "sujña": ['cae', 'ddsa', 'mw'],
    "sujñāna": ['cae', 'mw'],
    "sujñānadurgodaya": ['mw'],
    "sujñānaviṃśati": ['mw'],
    "sujā": ['cped'],
    "sujāmi": ['cae', 'mw'],
    "sujāta": ['bhs', 'cae', 'cped', 'gra', 'mw'],
    "sujātabuddhi": ['bhs'],
    "sujātajāta": ['bhs'],
    "sujātaka": ['mw'],
    "sujātatā": ['gra', 'mw'],
    "sujātavaktra": ['mw'],
    "sujāti": ['mw'],
    "sujātā": ['bhs', 'mw'],
    "sujātāṅga": ['mw'],
    "sujātīya": ['mw'],
    "sujīrṇa": ['cae', 'mw'],
    "sujīrṇaśatakhaṇḍamaya": ['mw'],
    "sujīva": ['cae', 'mw'],
    "sujīvantī": ['mw'],
    "sujīvita": ['cae', 'mw'],
    "sujūrṇi": ['cae', 'gra', 'mw'],
    "suka": ['cae', 'cped', 'mw'],
    "sukakṣa": ['mw'],
    "sukala": ['mw'],
    "sukalatra": ['cae', 'mw'],
    "sukalila": ['mw'],
    "sukalita": ['mw'],
    "sukallarūpa": ['cped'],
    "sukalpa": ['cae', 'mw'],
    "sukalpita": ['mw'],
    "sukalya": ['mw'],
    "sukamala": ['mw'],
    "sukambala": ['mw'],
    "sukanda": ['mw'],
    "sukandaja": ['mw'],
    "sukandaka": ['mw'],
    "sukandin": ['mw'],
    "sukaniṣṭha": ['bhs'],
    "sukanyaka": ['mw'],
    "sukanyā": ['cae', 'mw'],
    "sukanyāka": ['mw'],
    "sukaparda": ['mw'],
    "sukapola": ['mw'],
    "sukapolāsya": ['mw'],
    "sukara": ['cae', 'cped', 'gra', 'mw'],
    "sukarasaṃdhi": ['mw'],
    "sukarataraka": ['mw'],
    "sukaratva": ['mw'],
    "sukaraṇīya": ['cped'],
    "sukarma": ['mw'],
    "sukarman": ['cae', 'gra', 'mw'],
    "sukarā": ['mw'],
    "sukarīra": ['mw'],
    "sukarṇa": ['mw'],
    "sukarṇaka": ['mw'],
    "sukarṇika": ['mw'],
    "sukarṇikā": ['mw'],
    "sukarṇī": ['mw'],
    "sukata": ['cped'],
    "sukathā": ['cae', 'cped', 'mw'],
    "sukatī": ['cped'],
    "sukavi": ['cae', 'mw'],
    "sukavihṛdayānandinī": ['mw'],
    "sukavitā": ['cae', 'mw'],
    "sukaṅkavat": ['mw'],
    "sukaṇḍu": ['mw'],
    "sukaṇṭakā": ['mw'],
    "sukaṇṭha": ['cae', 'ddsa', 'mw'],
    "sukaṇṭhī": ['mw'],
    "sukaṣṭa": ['mw'],
    "sukaṭa": ['cped'],
    "sukaṭadukkaṭa": ['cped'],
    "sukaṭaṃkara": ['mw'],
    "sukaṭṭha": ['cped'],
    "sukesara": ['mw'],
    "suketa": ['cae', 'mw'],
    "suketana": ['mw'],
    "suketu": ['bhs', 'cae', 'gra', 'mw'],
    "suketusutā": ['mw'],
    "suketṛ": ['mw'],
    "sukeśa": ['bhs', 'cae', 'mw'],
    "sukeśan": ['mw'],
    "sukeśi": ['mw'],
    "sukeśin": ['mw'],
    "sukeśinī": ['mw'],
    "sukeśānta": ['mw'],
    "sukeśī": ['mw'],
    "sukeśībhārya": ['mw'],
    "sukh": ['ap90', 'mw'],
    "sukha": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sukhabaddha": ['mw'],
    "sukhabandhana": ['mw'],
    "sukhabhakṣikākāra": ['mw'],
    "sukhabhañja": ['mw'],
    "sukhabhedya": ['mw'],
    "sukhabhoga": ['mw'],
    "sukhabhogin": ['mw'],
    "sukhabhogya": ['mw'],
    "sukhabhojana": ['mw'],
    "sukhabhuj": ['mw'],
    "sukhabhāga": ['mw'],
    "sukhabhāgin": ['mw'],
    "sukhabhāgiya": ['cped'],
    "sukhabhāj": ['mw'],
    "sukhabhū": ['mw'],
    "sukhabodha": ['mw'],
    "sukhabodhakṛt": ['mw'],
    "sukhabodhana": ['mw'],
    "sukhabodhanadīpikā": ['mw'],
    "sukhabodharūpa": ['mw'],
    "sukhabodhikā": ['mw'],
    "sukhabodhinī": ['mw'],
    "sukhabuddhi": ['mw'],
    "sukhacara": ['mw'],
    "sukhacchedya": ['mw'],
    "sukhacchāya": ['mw'],
    "sukhacitta": ['mw'],
    "sukhacittabhāj": ['mw'],
    "sukhacāra": ['mw'],
    "sukhada": ['cae', 'cped', 'mw'],
    "sukhadeva": ['mw'],
    "sukhadhana": ['mw'],
    "sukhadivasa": ['bhs'],
    "sukhadohyā": ['mw'],
    "sukhadohā": ['mw'],
    "sukhaduḥkha": ['cae', 'mw'],
    "sukhaduḥkhamaya": ['mw'],
    "sukhaduḥkhasamanvita": ['mw'],
    "sukhaduḥkhasuhṛd": ['cae', 'mw'],
    "sukhaduḥkhin": ['mw'],
    "sukhaduḥkhādi": ['mw'],
    "sukhaduḥkhātmaka": ['mw'],
    "sukhadā": ['mw'],
    "sukhadāyaka": ['mw'],
    "sukhadṛśya": ['mw'],
    "sukhaga": ['mw'],
    "sukhagama": ['mw'],
    "sukhagamya": ['mw'],
    "sukhagandha": ['mw'],
    "sukhaghātya": ['cae', 'mw'],
    "sukhagrāhya": ['cae', 'mw'],
    "sukhagrāhyanibandhana": ['mw'],
    "sukhahasta": ['mw'],
    "sukhaidhita": ['mw'],
    "sukhaikāyatana": ['mw'],
    "sukhaiṣin": ['mw'],
    "sukhajāta": ['mw'],
    "sukhakara": ['mw'],
    "sukhakarī": ['mw'],
    "sukhakaumudī": ['mw'],
    "sukhakriyā": ['mw'],
    "sukhakāma": ['cped'],
    "sukhakāra": ['mw'],
    "sukhakārin": ['mw'],
    "sukhakṛt": ['mw'],
    "sukhalakṣya": ['mw'],
    "sukhalava": ['mw'],
    "sukhalekhana": ['mw'],
    "sukhaleśa": ['mw'],
    "sukhalipsā": ['mw'],
    "sukhallikā": ['bhs', 'mw'],
    "sukham": ['mw'],
    "sukhama": ['bhs'],
    "sukhamada": ['mw'],
    "sukhamaya": ['mw'],
    "sukhambiya": ['cped'],
    "sukhamedhas": ['mw'],
    "sukhamodā": ['mw'],
    "sukhamukha": ['mw'],
    "sukhamālika": ['mw'],
    "sukhamānin": ['mw'],
    "sukhamārjana": ['cae', 'mw'],
    "sukhana": ['mw'],
    "sukhanisinna": ['cped'],
    "sukhaniviṣṭa": ['mw'],
    "sukhanātha": ['mw'],
    "sukhanīya": ['mw'],
    "sukhapara": ['mw'],
    "sukhaparihīna": ['mw'],
    "sukhapaṭisaṁvedī": ['cped'],
    "sukhapeya": ['mw'],
    "sukhaplava": ['mw'],
    "sukhappatta": ['cped'],
    "sukhaprabha": ['bhs'],
    "sukhaprabodhaka": ['mw'],
    "sukhaprada": ['mw'],
    "sukhaprakāśa": ['mw'],
    "sukhaprasava": ['cae', 'mw'],
    "sukhaprasavana": ['mw'],
    "sukhaprasupta": ['mw'],
    "sukhapratibandhin": ['mw'],
    "sukhapratibandhitā": ['cae', 'mw'],
    "sukhapratyarthin": ['mw'],
    "sukhapratyarthitā": ['cae', 'mw'],
    "sukhapratīkṣa": ['mw'],
    "sukhapravepa": ['mw'],
    "sukhapravicāra": ['mw'],
    "sukhapraśna": ['mw'],
    "sukhapraṇāda": ['mw'],
    "sukhaprekṣya": ['mw'],
    "sukhaprāpta": ['mw'],
    "sukhaprāptadhana": ['mw'],
    "sukhaprāpya": ['mw'],
    "sukhapuṇyāhaghoṣa": ['mw'],
    "sukharatha": ['gra', 'mw'],
    "sukharāja": ['mw'],
    "sukharātri": ['bhs', 'mw'],
    "sukharātrikā": ['mw'],
    "sukharūpa": ['mw'],
    "sukhasalila": ['mw'],
    "sukhasalilaniṣeka": ['mw'],
    "sukhasambandhi": ['mw'],
    "sukhasambodhya": ['mw'],
    "sukhasammata": ['cped'],
    "sukhasamphassa": ['cped'],
    "sukhasamāja": ['mw'],
    "sukhasaṁvāsa": ['cped'],
    "sukhasaṃcāra": ['mw'],
    "sukhasaṃcāratva": ['mw'],
    "sukhasaṃcāratā": ['mw'],
    "sukhasaṃcārin": ['mw'],
    "sukhasaṃdohyā": ['mw'],
    "sukhasaṃduhyā": ['mw'],
    "sukhasaṃga": ['cae'],
    "sukhasaṃjñā": ['mw'],
    "sukhasaṃsevya": ['mw'],
    "sukhasaṃsparśa": ['bhs', 'mw'],
    "sukhasaṃstha": ['cae', 'mw'],
    "sukhasaṃsthita": ['cae', 'mw'],
    "sukhasaṃsupta": ['mw'],
    "sukhasaṃveśa": ['mw'],
    "sukhasaṃvitti": ['mw'],
    "sukhasaṃvāhya": ['mw'],
    "sukhasaṃvāsa": ['bhs'],
    "sukhasaṃvṛddha": ['mw'],
    "sukhasaṃyoga": ['cae', 'mw'],
    "sukhasaṃyāna": ['mw'],
    "sukhasaṅga": ['mw'],
    "sukhasaṅgin": ['mw'],
    "sukhasecaka": ['mw'],
    "sukhasevya": ['mw'],
    "sukhasevyatva": ['mw'],
    "sukhasparśa": ['bhs', 'cae', 'mw'],
    "sukhasparśavihāratā": ['mw'],
    "sukhasparśavihāritā": ['mw'],
    "sukhastha": ['cae', 'mw'],
    "sukhasukhena": ['mw'],
    "sukhasupta": ['cae', 'mw'],
    "sukhasupti": ['cae', 'mw'],
    "sukhasuptikā": ['cae', 'mw'],
    "sukhasuptikāpraśna": ['mw'],
    "sukhasuptiprabodhita": ['mw'],
    "sukhasvāpa": ['mw'],
    "sukhasādhana": ['mw'],
    "sukhasādhya": ['cae', 'mw'],
    "sukhasāgara": ['mw'],
    "sukhatama": ['mw'],
    "sukhatara": ['mw'],
    "sukhatas": ['mw'],
    "sukhatthika": ['cped'],
    "sukhatthī": ['cped'],
    "sukhatva": ['mw'],
    "sukhatā": ['mw'],
    "sukhavaha": ['mw'],
    "sukhavarcaka": ['mw'],
    "sukhavarcas": ['mw'],
    "sukhavarman": ['mw'],
    "sukhavartman": ['mw'],
    "sukhavartā": ['mw'],
    "sukhavat": ['mw'],
    "sukhavattā": ['mw'],
    "sukhavatī": ['mw'],
    "sukhavatīvyūha": ['mw'],
    "sukhavedana": ['mw'],
    "sukhaviharaṇa": ['cped'],
    "sukhavihāra": ['mw'],
    "sukhavipāka": ['cped'],
    "sukhaviṣṇu": ['mw'],
    "sukhavāsa": ['cae', 'mw'],
    "sukhavāsana": ['mw'],
    "sukhavī": ['mw'],
    "sukhavījya": ['mw'],
    "sukhay": ['cae'],
    "sukhaya": ['ddsa', 'mw'],
    "sukhayati": ['ap90'],
    "sukhayaśorthavṛddhikara": ['mw'],
    "sukhayitṛ": ['cae', 'mw'],
    "sukhayoganidrā": ['ddsa', 'mw'],
    "sukhayu": ['mw'],
    "sukhayānaka": ['cped'],
    "sukhaśarman": ['mw'],
    "sukhaśayana": ['mw'],
    "sukhaśayita": ['cae', 'mw'],
    "sukhaśayitapracchaka": ['mw'],
    "sukhaśayyā": ['cae', 'mw'],
    "sukhaśayā": ['mw'],
    "sukhaśobhārtham": ['mw'],
    "sukhaśrava": ['cae', 'mw'],
    "sukhaśravya": ['cae', 'mw'],
    "sukhaśravyatā": ['mw'],
    "sukhaśruti": ['mw'],
    "sukhaśāyin": ['mw'],
    "sukhaśīta": ['mw'],
    "sukhaśītala": ['mw'],
    "sukhaśītoṣṇamāruta": ['mw'],
    "sukhaṁ": ['cped'],
    "sukhaṃghuṇa": ['mw'],
    "sukhaṃghuṇaḥ": ['ap90'],
    "sukhaṃkara": ['ap90', 'mw'],
    "sukhaṃkarī": ['mw'],
    "sukhaṃsuṇa": ['mw'],
    "sukhaṇa": ['cped'],
    "sukhecchā": ['mw'],
    "sukhedhita": ['cped'],
    "sukhendriya": ['bhs'],
    "sukhepsu": ['mw'],
    "sukhesi": ['cped'],
    "sukhesī": ['cped'],
    "sukheta": ['mw'],
    "sukhetara": ['mw'],
    "sukheti": ['cped'],
    "sukhetta": ['cped'],
    "sukheṣṭha": ['mw'],
    "sukhi": ['mw'],
    "sukhila": ['bhs'],
    "sukhiloma": ['bhs'],
    "sukhin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "sukhisvabhāva": ['mw'],
    "sukhita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sukhitam": ['mw'],
    "sukhitva": ['mw'],
    "sukhitā": ['cae', 'ddsa', 'mw'],
    "sukhocchedya": ['mw'],
    "sukhocita": ['cae', 'ddsa', 'mw'],
    "sukhodadhi": ['mw'],
    "sukhodaka": ['mw'],
    "sukhodarka": ['cae', 'mw'],
    "sukhodaya": ['cae', 'mw'],
    "sukhodya": ['cae', 'mw'],
    "sukhopadhāna": ['mw'],
    "sukhopagamya": ['cae', 'mw'],
    "sukhopasarpya": ['mw'],
    "sukhopaviṣṭa": ['cae', 'mw'],
    "sukhopāya": ['mw'],
    "sukhorjika": ['mw'],
    "sukhotsava": ['mw'],
    "sukhoṣita": ['cae', 'mw'],
    "sukhoṣitā": ['mw'],
    "sukhoṣya": ['mw'],
    "sukhoṣṇa": ['mw'],
    "sukhuma": ['bhs', 'cped'],
    "sukhumatara": ['cped'],
    "sukhumatta": ['cped'],
    "sukhumatā": ['cped'],
    "sukhumāla": ['cped'],
    "sukhumālatā": ['cped'],
    "sukhura": ['mw'],
    "sukhya": ['bhs', 'mw'],
    "sukhyāta": ['mw'],
    "sukhyāti": ['mw'],
    "sukhā": ['mw'],
    "sukhābhilāṣa": ['mw'],
    "sukhābhirati": ['bhs'],
    "sukhābhiyojya": ['mw'],
    "sukhābhyudayika": ['cae', 'mw'],
    "sukhādhiṣṭhāna": ['mw'],
    "sukhādhāra": ['mw'],
    "sukhādi": ['cae', 'gra', 'mw'],
    "sukhādita": ['mw'],
    "sukhāgata": ['ddsa', 'mw'],
    "sukhāhara": ['mw'],
    "sukhāhāra": ['mw'],
    "sukhājāta": ['mw'],
    "sukhākara": ['mw'],
    "sukhākarā": ['bhs'],
    "sukhākṛ": ['ap90', 'mw'],
    "sukhāloka": ['cae', 'mw'],
    "sukhāmbu": ['mw'],
    "sukhānanda": ['mw'],
    "sukhānta": ['mw'],
    "sukhānubhava": ['mw'],
    "sukhānvita": ['mw'],
    "sukhāpa": ['mw'],
    "sukhāpana": ['bhs'],
    "sukhāpanna": ['mw'],
    "sukhāpayati": ['bhs'],
    "sukhāpeta": ['mw'],
    "sukhāplava": ['mw'],
    "sukhārha": ['mw'],
    "sukhārohaṇa": ['mw'],
    "sukhārta": ['mw'],
    "sukhārtha": ['cae', 'ddsa', 'mw'],
    "sukhārtham": ['mw'],
    "sukhārthin": ['cae', 'mw'],
    "sukhārthāya": ['mw'],
    "sukhārādhya": ['mw'],
    "sukhāsakta": ['mw'],
    "sukhāsana": ['mw'],
    "sukhāsikā": ['mw'],
    "sukhāsparśa": ['mw'],
    "sukhāsukha": ['cae', 'mw'],
    "sukhāsvāda": ['mw'],
    "sukhāsīna": ['cae', 'mw'],
    "sukhātmaka": ['mw'],
    "sukhāvabodha": ['mw'],
    "sukhāvaddeva": ['mw'],
    "sukhāvadvyūha": ['mw'],
    "sukhāvagama": ['mw'],
    "sukhāvagāha": ['mw'],
    "sukhāvaha": ['bhs', 'cae', 'cped', 'mw'],
    "sukhāvahā": ['bhs'],
    "sukhāvala": ['mw'],
    "sukhāvat": ['mw'],
    "sukhāvatī": ['bhs', 'mw'],
    "sukhāvatīvyūha": ['bhs'],
    "sukhāvatīśvara": ['mw'],
    "sukhāvṛta": ['mw'],
    "sukhāy": ['cae'],
    "sukhāya": ['ddsa', 'mw'],
    "sukhāyana": ['mw'],
    "sukhāyata": ['mw'],
    "sukhāyate": ['ap90'],
    "sukhāyati": ['cped'],
    "sukhāśa": ['mw'],
    "sukhāśaya": ['mw'],
    "sukhāśraya": ['mw'],
    "sukhāśā": ['mw'],
    "sukhī": ['cped', 'mw'],
    "sukhīlalitā": ['mw'],
    "sukhīnala": ['mw'],
    "sukhīvala": ['mw'],
    "sukittita": ['cped'],
    "sukiṃśuka": ['gra', 'mw'],
    "sukka": ['cped'],
    "sukkapakkha": ['cped'],
    "sukkaḍi": ['mw'],
    "sukkha": ['cped'],
    "sukkhamāna": ['cped'],
    "sukkhana": ['cped'],
    "sukkhati": ['cped'],
    "sukkhetta": ['cped'],
    "sukkhi": ['cped'],
    "sukkhitvā": ['cped'],
    "sukkhāpana": ['cped'],
    "sukkhāpesi": ['cped'],
    "sukkhāpeti": ['cped'],
    "sukkhāpetvā": ['cped'],
    "sukkhāpita": ['cped'],
    "sukleśa": ['mw'],
    "sukolī": ['mw'],
    "sukomala": ['cae', 'mw'],
    "sukosalā": ['mw'],
    "sukośaka": ['mw'],
    "sukośā": ['mw'],
    "sukraddha": ['cae'],
    "sukratu": ['cae', 'gra', 'mw'],
    "sukratūy": ['cae', 'gra'],
    "sukratūya": ['mw'],
    "sukratūyā": ['cae', 'gra', 'mw'],
    "sukraya": ['mw'],
    "sukriyā": ['mw'],
    "sukruddha": ['mw'],
    "sukrīḍā": ['bhs', 'mw'],
    "sukrūra": ['mw'],
    "sukti": ['mw'],
    "sukucā": ['cae', 'mw'],
    "sukukṣi": ['bhs', 'mw'],
    "sukula": ['cae', 'mw'],
    "sukulaja": ['mw'],
    "sukulajanman": ['mw'],
    "sukulastrī": ['mw'],
    "sukulatā": ['mw'],
    "sukulīna": ['mw'],
    "sukumala": ['mw'],
    "sukumāla": ['mw'],
    "sukumāra": ['cae', 'cped', 'mw'],
    "sukumāraka": ['mw'],
    "sukumāranakhatvac": ['mw'],
    "sukumāratanutvac": ['mw'],
    "sukumāratara": ['mw'],
    "sukumāratva": ['mw'],
    "sukumāratā": ['cped', 'mw'],
    "sukumāravana": ['mw'],
    "sukumārā": ['mw'],
    "sukumārāṅga": ['mw'],
    "sukumārī": ['mw'],
    "sukumārīka": ['mw'],
    "sukundaka": ['mw'],
    "sukundana": ['mw'],
    "sukurkura": ['mw'],
    "sukurīra": ['mw'],
    "sukusala": ['cped'],
    "sukusalasampahaṭṭha": ['cped'],
    "sukusumā": ['mw'],
    "sukuṇḍala": ['bhs', 'mw'],
    "sukuṭya": ['mw'],
    "sukuṭṭa": ['mw'],
    "sukvaṇa": ['mw'],
    "sukāla": ['cae', 'mw'],
    "sukālin": ['cae', 'mw'],
    "sukālukā": ['mw'],
    "sukāma": ['mw'],
    "sukāmada": ['mw'],
    "sukāmavrata": ['mw'],
    "sukāmā": ['mw'],
    "sukānta": ['cae', 'mw'],
    "sukānti": ['mw'],
    "sukāśana": ['mw'],
    "sukāṇḍa": ['mw'],
    "sukāṇḍikā": ['mw'],
    "sukāṇḍin": ['mw'],
    "sukāṣṭha": ['mw'],
    "sukāṣṭhaka": ['mw'],
    "sukāṣṭhā": ['mw'],
    "sukīrti": ['bhs', 'cae', 'gra', 'mw'],
    "sukūrkura": ['mw'],
    "sukṛt": ['cae', 'gra', 'mw'],
    "sukṛta": ['cae', 'gra', 'mw'],
    "sukṛtabhāj": ['mw'],
    "sukṛtadvādaśī": ['mw'],
    "sukṛtadvādaśīvrata": ['mw'],
    "sukṛtakarmakārin": ['mw'],
    "sukṛtakarman": ['cae', 'mw'],
    "sukṛtakṛt": ['cae', 'mw'],
    "sukṛtarasa": ['mw'],
    "sukṛtatas": ['mw'],
    "sukṛtavrata": ['mw'],
    "sukṛti": ['cae', 'mw'],
    "sukṛtin": ['cae', 'mw'],
    "sukṛtitva": ['mw'],
    "sukṛtocchraya": ['mw'],
    "sukṛtodīraṇa": ['mw'],
    "sukṛtvan": ['cae', 'gra', 'mw'],
    "sukṛtya": ['cae', 'mw'],
    "sukṛtyaprakāśa": ['mw'],
    "sukṛtyā": ['cae', 'gra', 'mw'],
    "sukṛtā": ['mw'],
    "sukṛtārtha": ['mw'],
    "sukṛtātman": ['mw'],
    "sukṛtāvāsa": ['mw'],
    "sukṛtāśā": ['mw'],
    "sukṛṣṇa": ['mw'],
    "sukṛṣṭa": ['mw'],
    "sukṣata": ['mw'],
    "sukṣatra": ['cae', 'gra', 'mw'],
    "sukṣatriya": ['mw'],
    "sukṣaya": ['gra', 'mw'],
    "sukṣema": ['cae', 'mw'],
    "sukṣemakṛt": ['mw'],
    "sukṣeman": ['mw'],
    "sukṣetra": ['cae', 'gra', 'mw'],
    "sukṣetratā": ['mw'],
    "sukṣetriyā": ['gra', 'mw'],
    "sukṣiti": ['cae', 'gra', 'mw'],
    "sukṣma": ['mw'],
    "sukṣobhya": ['mw'],
    "sukṣubdha": ['mw'],
    "sul": ['mw'],
    "sula": ['mw'],
    "sulabha": ['bhs', 'cae', 'cped', 'mw'],
    "sulabhakopa": ['cae', 'mw'],
    "sulabhatva": ['mw'],
    "sulabhetara": ['cae', 'mw'],
    "sulabhya": ['mw'],
    "sulabhā": ['mw'],
    "sulabhāvakāśa": ['cae', 'mw'],
    "sulabhībhāva": ['mw'],
    "suladdha": ['cped'],
    "sulagna": ['mw'],
    "sulakkana": ['ddsa'],
    "sulakkaṇa": ['mw'],
    "sulakṣa": ['mw'],
    "sulakṣaṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "sulakṣaṇasāra": ['mw'],
    "sulakṣaṇatva": ['mw'],
    "sulakṣaṇaśūnyatā": ['mw'],
    "sulakṣaṇā": ['mw'],
    "sulakṣita": ['cae', 'mw'],
    "sulalika": ['mw'],
    "sulalita": ['cae', 'mw'],
    "sulalitalatāpallavamaya": ['mw'],
    "sulalitam": ['mw'],
    "sulalitavistara": ['mw'],
    "sulalāṭa": ['mw'],
    "sulasa": ['mw'],
    "sulatāna": ['mw'],
    "sulavat": ['mw'],
    "sulavaṇa": ['mw'],
    "sulavaṇā": ['mw'],
    "sulaṃkṛtikā": ['bhs'],
    "sulaṅghita": ['mw'],
    "suleka": ['mw'],
    "sulekha": ['mw'],
    "sulharī": ['ddsa', 'mw'],
    "sulhaṇa": ['mw'],
    "sulikhita": ['mw'],
    "sulin": ['mw'],
    "sullaṇa": ['mw'],
    "sullāvihāra": ['ddsa', 'mw'],
    "sulocana": ['bhs', 'cae', 'mw'],
    "sulocanā": ['bhs', 'mw'],
    "suloha": ['mw'],
    "sulohaka": ['mw'],
    "sulohin": ['mw'],
    "sulohita": ['mw'],
    "sulohitā": ['mw'],
    "sulola": ['mw'],
    "suloma": ['mw'],
    "sulomadhi": ['mw'],
    "suloman": ['mw'],
    "sulomaśa": ['mw'],
    "sulomaśā": ['mw'],
    "sulomā": ['mw'],
    "suluka": ['bhs'],
    "sululita": ['mw'],
    "sulābha": ['mw'],
    "sulābhika": ['gra'],
    "sulābhikā": ['mw'],
    "sulābhin": ['mw'],
    "sulū": ['mw'],
    "suma": ['ddsa', 'mw'],
    "sumad": ['gra', 'mw'],
    "sumada": ['mw'],
    "sumadana": ['mw'],
    "sumadaṃśu": ['gra', 'mw'],
    "sumadga": ['mw'],
    "sumadgaṇa": ['gra', 'mw'],
    "sumadhura": ['cae', 'mw'],
    "sumadhuram": ['mw'],
    "sumadhya": ['cae', 'mw'],
    "sumadhyama": ['cae', 'mw'],
    "sumadhyamā": ['mw'],
    "sumadra": ['mw'],
    "sumadram": ['mw'],
    "sumadratha": ['gra'],
    "sumadā": ['mw'],
    "sumadātmajā": ['mw'],
    "sumagadha": ['mw'],
    "sumagadham": ['mw'],
    "sumagadhā": ['mw'],
    "sumagadhī": ['mw'],
    "sumahant": ['cae'],
    "sumahas": ['cae', 'gra', 'mw'],
    "sumahat": ['gra', 'mw'],
    "sumahaujas": ['mw'],
    "sumahauṣadha": ['mw'],
    "sumahā": ['mw'],
    "sumahābala": ['cae', 'mw'],
    "sumahābhāga": ['mw'],
    "sumahābāhu": ['mw'],
    "sumahākakṣa": ['cae', 'mw'],
    "sumahākapi": ['mw'],
    "sumahāmanas": ['mw'],
    "sumahāmuni": ['cae'],
    "sumahāprāṇa": ['mw'],
    "sumahāratha": ['mw'],
    "sumahārha": ['mw'],
    "sumahāsattva": ['mw'],
    "sumahāsvana": ['mw'],
    "sumahātapas": ['cae', 'mw'],
    "sumahātejas": ['cae', 'mw'],
    "sumahātman": ['cae', 'mw'],
    "sumahātmanas": ['cae'],
    "sumahātyaya": ['mw'],
    "sumahāvega": ['mw'],
    "sumahāvrata": ['mw'],
    "sumaj": ['mw'],
    "sumajjana": ['cae'],
    "sumajjani": ['mw'],
    "sumajjāni": ['gra'],
    "sumakha": ['cae', 'ddsa', 'gra', 'mw'],
    "sumakhasya": ['mw'],
    "sumakuṭa": ['bhs'],
    "sumalakā": ['mw'],
    "sumalina": ['mw'],
    "sumallika": ['mw'],
    "sumana": ['bhs', 'cped', 'mw'],
    "sumanaka": ['mw'],
    "sumanamakula": ['cped'],
    "sumanamālā": ['cped'],
    "sumanapuppha": ['cped'],
    "sumanas": ['cae', 'gra', 'mw'],
    "sumanaska": ['bhs', 'mw'],
    "sumanasoru": ['bhs'],
    "sumanasy": ['cae', 'gra'],
    "sumanasya": ['ddsa', 'mw'],
    "sumanaḥ": ['mw'],
    "sumanaḥpattra": ['mw'],
    "sumanaḥpattrikā": ['mw'],
    "sumanaḥphala": ['mw'],
    "sumanda": ['mw'],
    "sumandabhāj": ['mw'],
    "sumandabuddhi": ['mw'],
    "sumandā": ['mw'],
    "sumanman": ['cae', 'gra', 'mw'],
    "sumano": ['mw'],
    "sumanobhara": ['mw'],
    "sumanobhirāma": ['mw'],
    "sumanodāman": ['cae', 'mw'],
    "sumanohara": ['cped', 'mw'],
    "sumanoharaṇa": ['mw'],
    "sumanoharā": ['mw'],
    "sumanojñaghoṣa": ['bhs', 'mw'],
    "sumanokasa": ['mw'],
    "sumanolatā": ['mw'],
    "sumanomattaka": ['ddsa', 'mw'],
    "sumanomaya": ['mw'],
    "sumanomukha": ['mw'],
    "sumanorajas": ['mw'],
    "sumanorama": ['mw'],
    "sumanoramā": ['mw'],
    "sumanorañjinī": ['mw'],
    "sumanottarā": ['mw'],
    "sumantra": ['cae', 'mw'],
    "sumantrajña": ['mw'],
    "sumantraka": ['mw'],
    "sumantrin": ['mw'],
    "sumantrita": ['cae', 'mw'],
    "sumantu": ['cae', 'gra', 'mw'],
    "sumantunāman": ['gra', 'mw'],
    "sumantusmṛti": ['mw'],
    "sumantusūtra": ['mw'],
    "sumanyu": ['mw'],
    "sumanā": ['cped', 'ddsa', 'mw'],
    "sumanāmukha": ['bhs', 'mw'],
    "sumanāsya": ['mw'],
    "sumanāya": ['mw'],
    "sumanāyana": ['mw'],
    "sumanībhū": ['mw'],
    "sumanīkṛ": ['mw'],
    "sumara": ['mw'],
    "sumardita": ['mw'],
    "sumarmaga": ['mw'],
    "sumarīcikā": ['mw'],
    "sumarṣaṇa": ['mw'],
    "sumat": ['cae', 'ddsa', 'mw'],
    "sumata": ['bhs', 'mw'],
    "sumati": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sumatibhadra": ['bhs', 'mw'],
    "sumatibodha": ['mw'],
    "sumatiharṣa": ['mw'],
    "sumatimerugaṇi": ['mw'],
    "sumatiratnārya": ['mw'],
    "sumatireṇu": ['bhs', 'mw'],
    "sumatisvāmin": ['mw'],
    "sumatitsaru": ['mw'],
    "sumativijaya": ['mw'],
    "sumatiśīla": ['mw'],
    "sumatkṣara": ['mw'],
    "sumatīkṛta": ['mw'],
    "sumatīndrajayaghoṣaṇa": ['mw'],
    "sumatīndrayati": ['mw'],
    "sumatīvṛdh": ['mw'],
    "sumaḥ": ['ap90'],
    "sumaṅgala": ['cae', 'gra', 'mw'],
    "sumaṅgalanāman": ['mw'],
    "sumaṅgalā": ['mw'],
    "sumaṅgalākhyastotra": ['mw'],
    "sumaṅgalī": ['gra', 'mw'],
    "sumaṅgā": ['mw'],
    "sumaṇi": ['mw'],
    "sumaṇḍala": ['mw'],
    "sumbh": ['ddsa', 'mw'],
    "sumbha": ['cae', 'mw'],
    "sumbhaka": ['bhs'],
    "sumbhalikā": ['bhs'],
    "sumbharāja": ['bhs'],
    "sumbhatārā": ['bhs'],
    "sumbhā": ['bhs'],
    "sumedha": ['cae', 'cped', 'gra', 'mw'],
    "sumedhas": ['cae', 'gra', 'mw'],
    "sumedhasa": ['cped'],
    "sumedhya": ['mw'],
    "sumedhā": ['bhs'],
    "sumegha": ['mw'],
    "sumeka": ['cae', 'gra', 'mw'],
    "sumekhala": ['mw'],
    "sumekhalā": ['bhs'],
    "sumeru": ['bhs', 'cae', 'mw'],
    "sumerudhvajāyatanaśāntanetraśrī": ['bhs'],
    "sumerujā": ['mw'],
    "sumerukalpa": ['bhs'],
    "sumerupuṣpa": ['bhs'],
    "sumeruvatsa": ['bhs', 'mw'],
    "sumeruśrī": ['bhs'],
    "sumita": ['cae', 'gra', 'mw'],
    "sumiti": ['gra', 'mw'],
    "sumitra": ['bhs', 'cae', 'gra', 'mw'],
    "sumitrabhū": ['mw'],
    "sumitradhas": ['mw'],
    "sumitrarūpa": ['bhs'],
    "sumitria": ['gra'],
    "sumitrya": ['cae', 'gra', 'mw'],
    "sumitrā": ['bhs', 'mw'],
    "sumitrābhū": ['mw'],
    "sumitrātanaya": ['mw'],
    "sumla": ['mw'],
    "summuni": ['ddsa', 'mw'],
    "sumna": ['cae', 'gra', 'mw'],
    "sumnahū": ['mw'],
    "sumnay": ['cae', 'gra'],
    "sumnaya": ['mw'],
    "sumnayu": ['cae', 'gra', 'mw'],
    "sumnayā": ['gra', 'mw'],
    "sumnaāpi": ['gra', 'mw'],
    "sumnaṃ": ['ap90'],
    "sumnin": ['cae', 'mw'],
    "sumnya": ['cae', 'mw'],
    "sumnāvan": ['gra'],
    "sumnāvarī": ['cae', 'mw'],
    "sumnāy": ['cae', 'gra'],
    "sumnāya": ['mw'],
    "sumnāyu": ['cae', 'gra', 'mw'],
    "sumpaluṇṭha": ['mw'],
    "sumudita": ['mw'],
    "sumuhūrta": ['mw'],
    "sumukha": ['bhs', 'cae', 'cped', 'mw'],
    "sumukhasū": ['mw'],
    "sumukhatā": ['mw'],
    "sumukhā": ['bhs', 'mw'],
    "sumukhī": ['mw'],
    "sumukhīkṛta": ['mw'],
    "sumukhīpañcāṅga": ['mw'],
    "sumukta": ['bhs', 'mw'],
    "sumukā": ['bhs'],
    "sumutta": ['cped'],
    "sumuṇḍīka": ['mw'],
    "sumuṣita": ['mw'],
    "sumuṣṭi": ['mw'],
    "sumuṣṭikā": ['mw'],
    "sumāgadha": ['mw'],
    "sumāgadhaka": ['mw'],
    "sumāgadhā": ['bhs', 'mw'],
    "sumāgadhī": ['mw'],
    "sumāgandhā": ['bhs', 'mw'],
    "sumāla": ['bhs', 'mw'],
    "sumālatī": ['mw'],
    "sumāli": ['mw'],
    "sumālin": ['mw'],
    "sumālinī": ['bhs', 'mw'],
    "sumālya": ['mw'],
    "sumālyaka": ['mw'],
    "sumānasa": ['cped', 'mw'],
    "sumānikā": ['mw'],
    "sumānin": ['mw'],
    "sumāninitā": ['mw'],
    "sumānuṣa": ['bhs'],
    "sumānuṣavid": ['mw'],
    "sumāpita": ['cped'],
    "sumārdava": ['mw'],
    "sumārtsna": ['mw'],
    "sumāruta": ['cae', 'gra', 'mw'],
    "sumātra": ['bhs'],
    "sumātṛ": ['cae', 'gra', 'mw'],
    "sumāvali": ['mw'],
    "sumāya": ['cae', 'gra', 'mw'],
    "sumāyaka": ['mw'],
    "sumāyā": ['mw'],
    "sumāṣa": ['mw'],
    "sumāṣaka": ['mw'],
    "sumīl̤ha": ['mw'],
    "sumīna": ['mw'],
    "sumīḍha": ['gra', 'mw'],
    "sumūla": ['mw'],
    "sumūlaka": ['mw'],
    "sumūlā": ['mw'],
    "sumūrti": ['mw'],
    "sumṛga": ['mw'],
    "sumṛl̤īka": ['cae', 'mw'],
    "sumṛta": ['cae', 'mw'],
    "sumṛtyu": ['mw'],
    "sumṛḍīka": ['cae', 'gra', 'mw'],
    "sumṛṣṭa": ['mw'],
    "sumṛṣṭapuṣpāḍhya": ['mw'],
    "sumṛṣṭaveṣa": ['mw'],
    "sunaha": ['mw'],
    "sunahāta": ['cped'],
    "sunakha": ['bhs', 'cped'],
    "sunakhī": ['cped'],
    "sunakṣatra": ['cae', 'mw'],
    "sunakṣatrā": ['mw'],
    "sunanda": ['bhs', 'cae', 'ddsa', 'mw'],
    "sunandaka": ['mw'],
    "sunandana": ['bhs', 'mw'],
    "sunandanī": ['mw'],
    "sunandinī": ['mw'],
    "sunandā": ['bhs', 'mw'],
    "sunaphā": ['mw'],
    "sunaphāyoga": ['mw'],
    "sunarda": ['mw'],
    "sunasa": ['cae', 'mw'],
    "sunasā": ['mw'],
    "sunat": ['mw'],
    "sunata": ['mw'],
    "sunati": ['mw'],
    "sunau": ['cae', 'mw'],
    "sunaya": ['bhs', 'cae', 'mw'],
    "sunayaka": ['mw'],
    "sunayakaśrī": ['mw'],
    "sunayana": ['cae', 'mw'],
    "sunayanā": ['mw'],
    "sunayaśrī": ['mw'],
    "sunayaśrīmitra": ['mw'],
    "sunayaśālin": ['mw'],
    "sund": ['mw'],
    "sunda": ['cae', 'ddsa', 'mw'],
    "sundara": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sundarabāhustava": ['mw'],
    "sundaradeva": ['mw'],
    "sundaradāsa": ['mw'],
    "sundaragaṇi": ['mw'],
    "sundaragurukāvya": ['mw'],
    "sundarahaci": ['mw'],
    "sundarajāmātṛmuni": ['mw'],
    "sundaraka": ['bhs', 'mw'],
    "sundarakamalīya": ['mw'],
    "sundarakāṇḍa": ['mw'],
    "sundaralaharī": ['mw'],
    "sundaram": ['mw'],
    "sundaramaṇisaṃdarbha": ['mw'],
    "sundaramiśra": ['mw'],
    "sundarammanya": ['mw'],
    "sundarananda": ['bhs', 'mw'],
    "sundarapura": ['mw'],
    "sundarapuramāhātmya": ['mw'],
    "sundarapāṇḍyadeva": ['mw'],
    "sundararāja": ['mw'],
    "sundararājīya": ['mw'],
    "sundarasena": ['mw'],
    "sundarasenabhāṣya": ['mw'],
    "sundarasiddhānta": ['mw'],
    "sundaratara": ['cped', 'mw'],
    "sundarataram": ['mw'],
    "sundaratva": ['mw'],
    "sundaratā": ['mw'],
    "sundaravarṇa": ['bhs', 'mw'],
    "sundaravatī": ['mw'],
    "sundaravaṃśa": ['mw'],
    "sundaravīrapāṇḍya": ['mw'],
    "sundaraśukla": ['mw'],
    "sundaraśṛṅgāra": ['mw'],
    "sundaraṃmanya": ['cae'],
    "sundareśvara": ['mw'],
    "sundareśvarastotra": ['mw'],
    "sundarikā": ['bhs', 'mw'],
    "sundarikāhrada": ['mw'],
    "sundarikātīrtha": ['mw'],
    "sundarā": ['bhs'],
    "sundarānanda": ['mw'],
    "sundarāraṇya": ['mw'],
    "sundarāraṇyamāhātmya": ['mw'],
    "sundarī": ['bhs', 'ddsa', 'mw'],
    "sundarībhavana": ['mw'],
    "sundarīdevī": ['mw'],
    "sundarīkalpa": ['mw'],
    "sundarīkavaca": ['mw'],
    "sundarīmandira": ['mw'],
    "sundarīpūjāpaddhati": ['mw'],
    "sundarīpūjāratna": ['mw'],
    "sundarīsvayaṃvara": ['mw'],
    "sundarītāpanī": ['mw'],
    "sundarītāpinī": ['mw'],
    "sundarīśaktidānastotra": ['mw'],
    "sundhu": ['bhs'],
    "sundopasunda": ['mw'],
    "sundāsuravadhū": ['mw'],
    "sunemi": ['bhs'],
    "sunepathya": ['mw'],
    "sunetra": ['bhs', 'mw'],
    "sunetrā": ['bhs', 'mw'],
    "sunetrādhipati": ['bhs', 'mw'],
    "sunetṛ": ['mw'],
    "sunibhṛtam": ['cae', 'mw'],
    "sunidha": ['gra'],
    "sunidhi": ['mw'],
    "sunidhyāna": ['bhs'],
    "sunidra": ['cae', 'mw'],
    "sunidrā": ['mw'],
    "sunigraha": ['mw'],
    "sunihita": ['mw'],
    "sunika": ['mw'],
    "sunikantaṁ-nikanta": ['cped'],
    "sunikhilam": ['mw'],
    "sunikhāta": ['mw'],
    "sunikṛṣṭa": ['mw'],
    "sunikṣipta": ['cae', 'mw'],
    "sunimaya": ['mw'],
    "suninada": ['mw'],
    "suninadam": ['mw'],
    "suniraja": ['gra', 'mw'],
    "sunirbhakta": ['mw'],
    "sunirgata": ['mw'],
    "sunirghṛṇa": ['mw'],
    "sunirlajja": ['mw'],
    "sunirmala": ['bhs', 'cae', 'mw'],
    "sunirmatha": ['gra', 'mw'],
    "sunirmita": ['bhs', 'mw'],
    "sunirmitadhvajapradīpa": ['bhs'],
    "sunirmitarūpa": ['bhs'],
    "sunirmāṇarati": ['bhs'],
    "sunirviṇṇa": ['mw'],
    "sunirvṛta": ['cae', 'mw'],
    "suniryukta": ['mw'],
    "suniryāsā": ['mw'],
    "sunirūhaṇa": ['mw'],
    "sunirūpita": ['mw'],
    "sunirūḍha": ['mw'],
    "sunirṇikta": ['mw'],
    "sunisita": ['cped'],
    "sunistriṃśa": ['mw'],
    "sunitambinī": ['mw'],
    "suniviṣṭa": ['mw'],
    "suniyat": ['mw'],
    "suniyata": ['cae', 'mw'],
    "suniyukta": ['mw'],
    "suniścala": ['cae', 'mw'],
    "suniścaya": ['cae', 'mw'],
    "suniścita": ['cae', 'mw'],
    "suniścitam": ['mw'],
    "suniścitapura": ['mw'],
    "suniśita": ['mw'],
    "suniḥṣṭhita": ['cae', 'mw'],
    "suniṣaṇṇa": ['mw'],
    "suniṣaṇṇaka": ['mw'],
    "suniṣka": ['cae', 'gra', 'mw'],
    "suniṣkṛta": ['mw'],
    "suniṣphala": ['mw'],
    "suniṣṭapta": ['mw'],
    "suniṣṭhita": ['bhs', 'mw'],
    "suniṣṭhura": ['mw'],
    "sunna": ['ddsa', 'mw'],
    "sunthaṇā": ['bhs'],
    "sunu": ['mw'],
    "sunva": ['gra'],
    "sunvant": ['cae'],
    "sunvat": ['ddsa', 'mw'],
    "sunyasta": ['mw'],
    "sunābha": ['cae', 'mw'],
    "sunābhaka": ['mw'],
    "sunābhi": ['cae', 'mw'],
    "sunābhya": ['mw'],
    "sunāda": ['mw'],
    "sunādaka": ['mw'],
    "sunāga": ['mw'],
    "sunākuta": ['mw'],
    "sunākṛta": ['mw'],
    "sunāla": ['mw'],
    "sunālaka": ['mw'],
    "sunāmadheya": ['mw'],
    "sunāmadvādaśī": ['mw'],
    "sunāman": ['cae', 'mw'],
    "sunāmnī": ['mw'],
    "sunāra": ['mw'],
    "sunāraḥ": ['ap90'],
    "sunāsa": ['cae', 'mw'],
    "sunāsika": ['cae', 'mw'],
    "sunāsikā": ['mw'],
    "sunāsākṣibhruva": ['mw'],
    "sunāsākṣibhruvā": ['mw'],
    "sunāsīra": ['mw'],
    "sunāsīraḥ": ['ap90'],
    "sunātha": ['cae', 'mw'],
    "sunāśīraḥ": ['ap90'],
    "sunāṭya": ['mw'],
    "sunīhāra": ['cae', 'mw'],
    "sunīla": ['mw'],
    "sunīlaka": ['mw'],
    "sunīlā": ['mw'],
    "sunīta": ['cae', 'mw'],
    "sunītha": ['cae', 'gra', 'mw'],
    "sunīthā": ['mw'],
    "sunīti": ['cae', 'gra', 'mw'],
    "sunū": ['mw'],
    "sunṛpa": ['cae', 'mw'],
    "sunṛśaṃsa": ['mw'],
    "sunṛśaṃsakṛt": ['mw'],
    "suojas": ['gra'],
    "sup": ['ap90', 'ddsa', 'mw'],
    "supad": ['cae', 'gra', 'mw'],
    "supada": ['cae', 'mw'],
    "supadma": ['mw'],
    "supadmadhātupāṭha": ['mw'],
    "supadmamakaranda": ['mw'],
    "supadmapariśiṣṭa": ['mw'],
    "supadmasamāsasaṃgraha": ['mw'],
    "supadmaṣaṭkārakavyākhyāna": ['mw'],
    "supadmā": ['mw'],
    "supakka": ['cped'],
    "supakva": ['cae', 'ddsa', 'mw'],
    "supakṣa": ['cae', 'mw'],
    "supakṣman": ['mw'],
    "supalāyita": ['mw'],
    "supalāśa": ['cae', 'gra', 'mw'],
    "supana": ['bhs'],
    "supanta": ['cped'],
    "supanthās": ['mw'],
    "supaptani": ['gra', 'mw'],
    "suparamaturitā": ['mw'],
    "supari": ['mw'],
    "suparibhāṣa": ['mw'],
    "suparibhūta": ['mw'],
    "suparicchanna": ['mw'],
    "suparidatta": ['mw'],
    "suparihara": ['mw'],
    "suparihīna": ['cped'],
    "suparijñāta": ['mw'],
    "suparika": ['mw'],
    "suparikammakata": ['cped'],
    "suparikarṣīkṛtya": ['bhs'],
    "suparikliṣṭa": ['mw'],
    "suparikīrtitanāmadheyaśrī": ['bhs'],
    "suparila": ['mw'],
    "suparipūjita": ['mw'],
    "suparipūrṇa": ['mw'],
    "suparipūrṇajñānamukhavaktra": ['bhs'],
    "suparipūrṇottamāṅgatā": ['mw'],
    "suparirakṣita": ['mw'],
    "suparisruta": ['mw'],
    "supariviṣṭa": ['mw'],
    "suparivrāj": ['mw'],
    "supariya": ['mw'],
    "supariśrānta": ['cae', 'mw'],
    "supariśrāntavāha": ['mw'],
    "supariśuddha": ['mw'],
    "supariṇata": ['mw'],
    "supariṇīta": ['mw'],
    "supariṣkṛta": ['mw'],
    "suparus": ['mw'],
    "suparuṣa": ['mw'],
    "suparvan": ['cae', 'mw'],
    "suparvata": ['mw'],
    "suparvaṇa": ['mw'],
    "suparvā": ['mw'],
    "suparyavadāta": ['mw'],
    "suparyavasita": ['mw'],
    "suparyavasitārtha": ['mw'],
    "suparyāpta": ['cae', 'mw'],
    "suparyāśīrdatta": ['mw'],
    "suparākrama": ['mw'],
    "suparāñc": ['mw'],
    "suparīkṣaṇa": ['mw'],
    "suparīkṣita": ['cae', 'mw'],
    "suparīkṣya": ['mw'],
    "suparītta": ['bhs'],
    "suparṇa": ['cae', 'gra', 'mw'],
    "suparṇacit": ['mw'],
    "suparṇaciti": ['mw'],
    "suparṇacitidīpikā": ['mw'],
    "suparṇacitipaddhati": ['mw'],
    "suparṇacitya": ['mw'],
    "suparṇaka": ['mw'],
    "suparṇakakumāra": ['mw'],
    "suparṇaketu": ['mw'],
    "suparṇarāja": ['mw'],
    "suparṇasad": ['mw'],
    "suparṇasuvana": ['mw'],
    "suparṇavāta": ['mw'],
    "suparṇayātu": ['gra', 'mw'],
    "suparṇeya": ['mw'],
    "suparṇi": ['bhs'],
    "suparṇikā": ['bhs', 'mw'],
    "suparṇin": ['mw'],
    "suparṇā": ['mw'],
    "suparṇādhyāya": ['mw'],
    "suparṇākhya": ['mw'],
    "suparṇākhyāna": ['mw'],
    "suparṇāṇḍa": ['mw'],
    "suparṇī": ['mw'],
    "suparṇītanaya": ['mw'],
    "supatana": ['mw'],
    "supath": ['gra', 'mw'],
    "supatha": ['cae', 'gra', 'mw'],
    "supathin": ['mw'],
    "supathintara": ['mw'],
    "supathya": ['mw'],
    "supathyā": ['mw'],
    "supati": ['cae', 'cped', 'mw'],
    "supatnī": ['cae', 'gra', 'mw'],
    "supattra": ['cae', 'mw'],
    "supattraka": ['mw'],
    "supattrikā": ['mw'],
    "supattrin": ['cae', 'mw'],
    "supattrita": ['cae', 'mw'],
    "supattrā": ['mw'],
    "supattrī": ['mw'],
    "supatīrtha": ['bhs'],
    "supavañcana": ['ddsa'],
    "supavi": ['mw'],
    "supavitra": ['mw'],
    "supayas": ['mw'],
    "supayodharā": ['mw'],
    "supayovin": ['mw'],
    "supaścāt": ['mw'],
    "supaśyin": ['bhs'],
    "supaṅka": ['cae', 'mw'],
    "supaṇṇa": ['cped'],
    "supaṭha": ['mw'],
    "supaṭipanna": ['cped'],
    "supaṭṭaka": ['mw'],
    "supaṭṭhita": ['cped'],
    "supaṭṭhāka": ['cped'],
    "supeti": ['bhs'],
    "supeśa": ['mw'],
    "supeśala": ['mw'],
    "supeśas": ['cae', 'gra', 'mw'],
    "suphala": ['cae', 'gra', 'mw'],
    "suphalā": ['mw'],
    "suphalīkṛ": ['mw'],
    "suphassita": ['cped'],
    "suphena": ['mw'],
    "suphulla": ['mw'],
    "suphāhila": ['mw'],
    "suphāla": ['mw'],
    "suphāliha": ['mw'],
    "suphālīha": ['mw'],
    "supi": ['cped'],
    "supidhāna": ['cae', 'mw'],
    "supihitavat": ['mw'],
    "supina": ['bhs', 'cped'],
    "supinaka": ['cped'],
    "supinanta": ['cped'],
    "supinapāṭhaka": ['cped'],
    "supināntalokamuni": ['bhs'],
    "supippala": ['gra', 'mw'],
    "supis": ['mw'],
    "supiti": ['bhs'],
    "supitria": ['gra'],
    "supitrya": ['gra', 'mw'],
    "supitvā": ['cped'],
    "supiya": ['bhs'],
    "supiś": ['cae', 'gra', 'mw'],
    "supiṅgalā": ['mw'],
    "supiṣṭa": ['mw'],
    "suplan": ['cae', 'mw'],
    "supothita": ['cped'],
    "supoṣa": ['bhs', 'mw'],
    "supoṣatā": ['mw'],
    "supoṭhita": ['cped'],
    "suppa": ['cped'],
    "suppabhāta": ['cped'],
    "suppadhaṁsiya": ['cped'],
    "suppasanna": ['cped'],
    "suppatiṭṭhita": ['cped'],
    "suppatīta": ['cped'],
    "suppavedita": ['cped'],
    "suppaṭividdha": ['cped'],
    "suprabala": ['mw'],
    "suprabha": ['bhs', 'cae', 'mw'],
    "suprabhadeva": ['mw'],
    "suprabhapura": ['mw'],
    "suprabhavadeva": ['mw'],
    "suprabhedapratiṣṭhātantra": ['mw'],
    "suprabhedatantra": ['mw'],
    "suprabhā": ['bhs', 'mw'],
    "suprabhāsa": ['bhs'],
    "suprabhāta": ['cae', 'mw'],
    "suprabhātastotra": ['mw'],
    "suprabhāte": ['mw'],
    "suprabhātā": ['bhs', 'mw'],
    "suprabhāva": ['mw'],
    "suprabhāyakā": ['bhs'],
    "suprabuddha": ['bhs', 'mw'],
    "suprabuddhā": ['bhs'],
    "supracchanna": ['cae', 'mw'],
    "supracetas": ['cae', 'gra', 'mw'],
    "supracāra": ['mw'],
    "supradadi": ['mw'],
    "supradarśa": ['mw'],
    "supradharṣaka": ['bhs'],
    "supradhṛṣya": ['mw'],
    "supradohā": ['mw'],
    "supraetu": ['gra'],
    "supragamana": ['mw'],
    "supragupta": ['mw'],
    "suprahāra": ['mw'],
    "supraitu": ['cae', 'gra', 'mw'],
    "supraja": ['cae', 'mw'],
    "suprajas": ['cae', 'mw'],
    "suprajastva": ['cae', 'mw'],
    "suprajña": ['cae', 'mw'],
    "suprajñāna": ['mw'],
    "suprajā": ['gra'],
    "suprajāpati": ['mw'],
    "suprajāstva": ['cae', 'gra', 'mw'],
    "suprajāta": ['mw'],
    "suprajāvani": ['mw'],
    "suprajāvat": ['gra', 'mw'],
    "supraketa": ['cae', 'gra', 'mw'],
    "suprakhya": ['mw'],
    "suprakāśa": ['cae', 'ddsa', 'mw'],
    "suprakīrṇendriya": ['mw'],
    "suprakṣālita": ['cae', 'mw'],
    "supralambha": ['mw'],
    "supralāpa": ['mw'],
    "supramadhu": ['mw'],
    "supramaya": ['mw'],
    "supramāṇa": ['mw'],
    "supranṛtta": ['mw'],
    "suprapañcahīna": ['mw'],
    "suprapāṇa": ['cae', 'gra', 'mw'],
    "suprasanna": ['cae', 'mw'],
    "suprasannaka": ['mw'],
    "suprasarā": ['mw'],
    "suprasava": ['mw'],
    "suprasiddha": ['mw'],
    "suprasiddhapadamañjarī": ['mw'],
    "suprasāda": ['cae', 'mw'],
    "suprasādaka": ['mw'],
    "suprasādhita": ['mw'],
    "suprasādā": ['mw'],
    "suprasārita": ['mw'],
    "suprasārā": ['mw'],
    "suprasū": ['cae', 'mw'],
    "supratara": ['mw'],
    "supratardana": ['mw'],
    "supratarka": ['mw'],
    "suprathamā": ['bhs'],
    "supratibhā": ['mw'],
    "supraticakṣa": ['gra', 'mw'],
    "supraticchanna": ['mw'],
    "supraticchannam": ['mw'],
    "supraticchinna": ['mw'],
    "supratigṛhīta": ['cae', 'mw'],
    "supratijña": ['mw'],
    "supratikara": ['mw'],
    "supratima": ['mw'],
    "supratipanna": ['mw'],
    "supratipūjita": ['cae', 'mw'],
    "suprativarman": ['mw'],
    "supratividdha": ['bhs', 'mw'],
    "supratiśraya": ['mw'],
    "supratiṣṇāta": ['mw'],
    "supratiṣṇātasūtra": ['mw'],
    "supratiṣṭha": ['cae', 'mw'],
    "supratiṣṭhita": ['bhs', 'cae', 'mw'],
    "supratiṣṭhitabuddhi": ['bhs'],
    "supratiṣṭhitacaraṇa": ['bhs', 'mw'],
    "supratiṣṭhitacāritra": ['bhs', 'mw'],
    "supratiṣṭhitapāṇipādatalatā": ['mw'],
    "supratiṣṭhitayaśas": ['mw'],
    "supratiṣṭhitā": ['mw'],
    "supratiṣṭhitāsana": ['mw'],
    "supratiṣṭhā": ['bhs', 'mw'],
    "supratiṣṭhāna": ['mw'],
    "supratiṣṭhāpita": ['mw'],
    "supratur": ['cae', 'gra', 'mw'],
    "supratyavasita": ['mw'],
    "supratyañc": ['mw'],
    "supratyūḍha": ['mw'],
    "supratāpa": ['bhs'],
    "supratāra": ['mw'],
    "supratīka": ['cae', 'gra', 'mw'],
    "supratīkeśvara": ['mw'],
    "supratīkinī": ['mw'],
    "supratīkānvaya": ['mw'],
    "supratīpa": ['mw'],
    "supratīsa": ['bhs'],
    "supratīta": ['mw'],
    "supratūrti": ['cae', 'gra', 'mw'],
    "suprauḍha": ['mw'],
    "suprauḍhā": ['mw'],
    "supravedita": ['mw'],
    "supravepita": ['mw'],
    "supraveśa": ['mw'],
    "supravrajita": ['mw'],
    "supravācana": ['cae', 'gra', 'mw'],
    "supravādita": ['mw'],
    "supravṛddha": ['mw'],
    "supravṛkti": ['mw'],
    "supravṛkṇa": ['mw'],
    "supravṛtta": ['mw'],
    "suprayas": ['cae', 'gra', 'mw'],
    "suprayoga": ['mw'],
    "suprayogaviśikha": ['mw'],
    "suprayogā": ['mw'],
    "suprayukta": ['mw'],
    "suprayuktaśara": ['mw'],
    "suprayā": ['gra', 'mw'],
    "suprayāvan": ['gra', 'mw'],
    "suprayāṇa": ['bhs'],
    "supraśasta": ['mw'],
    "supraśaṃsita": ['mw'],
    "supraśna": ['mw'],
    "supraṇihita": ['bhs'],
    "supraṇīti": ['cae', 'gra', 'mw'],
    "supremaka": ['bhs'],
    "supriya": ['bhs', 'cae', 'mw'],
    "supriyā": ['bhs', 'mw'],
    "supriyātman": ['mw'],
    "suprokṣita": ['mw'],
    "suprāc": ['gra'],
    "suprākāra": ['mw'],
    "suprākṛta": ['mw'],
    "suprāpa": ['cae', 'mw'],
    "suprāpya": ['cae', 'mw'],
    "suprāta": ['mw'],
    "suprātar": ['mw'],
    "suprātiveśmika": ['mw'],
    "suprāvarga": ['gra', 'mw'],
    "suprāvia": ['gra'],
    "suprāvya": ['gra', 'mw'],
    "suprāvī": ['cae', 'gra', 'mw'],
    "suprāyaṇa": ['cae', 'gra', 'mw'],
    "suprāñc": ['cae', 'ddsa', 'mw'],
    "suprīta": ['cae', 'gra', 'mw'],
    "suprīti": ['mw'],
    "suprītikara": ['mw'],
    "suprītiyukta": ['mw'],
    "suprītyarati": ['bhs'],
    "supsaras": ['gra', 'mw'],
    "supta": ['ap90', 'cae', 'ddsa', 'mw'],
    "suptacyuta": ['mw'],
    "suptaghna": ['mw'],
    "suptaghātaka": ['mw'],
    "suptajana": ['mw'],
    "suptajanaprāya": ['mw'],
    "suptajñāna": ['mw'],
    "suptaka": ['bhs', 'cae', 'mw'],
    "suptamālin": ['mw'],
    "suptamāṃsa": ['mw'],
    "suptamīna": ['mw'],
    "suptaprabuddha": ['cae', 'mw'],
    "suptapralapita": ['mw'],
    "suptapūrva": ['cae', 'mw'],
    "suptastha": ['mw'],
    "suptasthita": ['mw'],
    "suptatva": ['mw'],
    "suptatvac": ['mw'],
    "suptatā": ['mw'],
    "suptavigraha": ['mw'],
    "suptavijñāna": ['mw'],
    "suptavinidraka": ['mw'],
    "suptavākya": ['mw'],
    "supti": ['cae', 'ddsa', 'mw'],
    "suptiḥ": ['ap90'],
    "suptiṅanta": ['mw'],
    "suptiṅantaparibhāṣā": ['mw'],
    "suptiṅantasāgarasamuccaya": ['mw'],
    "suptotthita": ['cae', 'ddsa'],
    "suptottitha": ['mw'],
    "suptāsupta": ['cae', 'mw'],
    "suptāṅga": ['mw'],
    "suptāṅgatā": ['mw'],
    "supu": ['cae', 'mw'],
    "supupphita": ['cped'],
    "supura": ['mw'],
    "supurodhas": ['mw'],
    "supuruhūti": ['mw'],
    "supuruṣa": ['mw'],
    "suputra": ['cae', 'gra', 'mw'],
    "suputrikā": ['mw'],
    "supuṃsī": ['mw'],
    "supuṅkha": ['mw'],
    "supuṇya": ['mw'],
    "supuṇyada": ['mw'],
    "supuṇyagandha": ['mw'],
    "supuṣkala": ['mw'],
    "supuṣkara": ['mw'],
    "supuṣkarā": ['mw'],
    "supuṣpa": ['bhs', 'cae', 'mw'],
    "supuṣpaka": ['mw'],
    "supuṣpikā": ['mw'],
    "supuṣpita": ['cae', 'mw'],
    "supuṣpite": ['mw'],
    "supuṣpā": ['mw'],
    "supuṣpī": ['mw'],
    "supuṣya": ['mw'],
    "supuṣṭa": ['mw'],
    "supuṣṭi": ['mw'],
    "supuṭa": ['mw'],
    "supāda": ['mw'],
    "supākaka": ['mw'],
    "supākinī": ['mw'],
    "supākya": ['mw'],
    "supāli": ['mw'],
    "supāman": ['mw'],
    "supāna": ['mw'],
    "supānānna": ['mw'],
    "supāra": ['cae', 'gra', 'mw'],
    "supāraga": ['bhs', 'mw'],
    "supārakṣatra": ['cae', 'gra', 'mw'],
    "supāraṇa": ['mw'],
    "supārā": ['mw'],
    "supārśva": ['bhs', 'mw'],
    "supārśvaka": ['mw'],
    "supārśvoru": ['mw'],
    "supārśvā": ['bhs'],
    "supātra": ['bhs', 'mw'],
    "supāva": ['mw'],
    "supāñcālaka": ['mw'],
    "supāśa": ['mw'],
    "supāśā": ['mw'],
    "supāṇi": ['cae', 'gra', 'mw'],
    "supāṇḍara": ['mw'],
    "supāṭala": ['mw'],
    "supāṭhaka": ['mw'],
    "supīlu": ['bhs'],
    "supīna": ['mw'],
    "supīta": ['cae', 'mw'],
    "supīvan": ['mw'],
    "supīvas": ['gra', 'mw'],
    "supīḍana": ['mw'],
    "supīḍita": ['mw'],
    "supū": ['cae', 'mw'],
    "supūjita": ['bhs', 'cae', 'mw'],
    "supūra": ['cae', 'mw'],
    "supūraka": ['mw'],
    "supūrvam": ['mw'],
    "supūrvāhṇe": ['cae', 'mw'],
    "supūrṇa": ['bhs', 'cae', 'gra', 'mw'],
    "supūrṇika": ['bhs'],
    "supūta": ['cae', 'gra', 'mw'],
    "supṛkṣ": ['cae', 'gra', 'mw'],
    "sur": ['ap90', 'mw'],
    "sura": ['cae', 'cped', 'ddsa', 'mw'],
    "surabhavana": ['mw'],
    "surabhay": ['cae'],
    "surabhaya": ['ddsa', 'mw'],
    "surabhi": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "surabhibāṇa": ['mw'],
    "surabhicandana": ['bhs'],
    "surabhicchada": ['mw'],
    "surabhicūla": ['mw'],
    "surabhicūrṇa": ['mw'],
    "surabhidattā": ['mw'],
    "surabhidāru": ['mw'],
    "surabhidāruka": ['mw'],
    "surabhigandha": ['cae', 'cped', 'mw'],
    "surabhigandhi": ['cae', 'mw'],
    "surabhigandhin": ['cae', 'mw'],
    "surabhigandhita": ['mw'],
    "surabhigandhā": ['mw'],
    "surabhighṛta": ['mw'],
    "surabhikandara": ['cae', 'mw'],
    "surabhikā": ['ap90', 'mw'],
    "surabhikṣetramāhātmya": ['mw'],
    "surabhimat": ['ap90', 'mw'],
    "surabhimatī": ['mw'],
    "surabhimukha": ['mw'],
    "surabhimāruta": ['mw'],
    "surabhimāsa": ['cae', 'mw'],
    "surabhin": ['cae', 'gra', 'mw'],
    "surabhipattra": ['mw'],
    "surabhipattrā": ['mw'],
    "surabhiputra": ['mw'],
    "surabhis": ['gra'],
    "surabhisamaya": ['cae', 'mw'],
    "surabhisragdhara": ['mw'],
    "surabhisravā": ['mw'],
    "surabhita": ['ap90', 'cae', 'mw'],
    "surabhitanaya": ['mw'],
    "surabhitanayā": ['mw'],
    "surabhitriphalā": ['mw'],
    "surabhitvac": ['mw'],
    "surabhitā": ['mw'],
    "surabhivalkala": ['mw'],
    "surabhivatsa": ['mw'],
    "surabhiṣṭama": ['cae', 'mw'],
    "surabhuvana": ['mw'],
    "surabhy": ['mw'],
    "surabhyāsya": ['mw'],
    "surabhyāsyatva": ['mw'],
    "surabhāva": ['ddsa', 'mw'],
    "surabhī": ['ap90', 'ddsa', 'mw'],
    "surabhīgandha": ['mw'],
    "surabhīgotra": ['mw'],
    "surabhīkṛ": ['cae', 'ddsa', 'mw'],
    "surabhīpattrā": ['mw'],
    "surabhīpaṭṭana": ['mw'],
    "surabhīrasā": ['mw'],
    "surabhīsuta": ['mw'],
    "surabhūruha": ['mw'],
    "surabhūya": ['ddsa', 'mw'],
    "surabhūṣaṇa": ['mw'],
    "suracāpa": ['cae', 'ddsa', 'mw'],
    "suradevatā": ['mw'],
    "suradevin": ['mw'],
    "suradhanurlekhāya": ['mw'],
    "suradhanus": ['cae', 'mw'],
    "suradhunī": ['mw'],
    "suradhvaja": ['mw'],
    "suradhāman": ['mw'],
    "suradhūpa": ['mw'],
    "suradru": ['mw'],
    "suradruma": ['mw'],
    "suradundubhi": ['mw'],
    "suradundubhī": ['mw'],
    "suradvipa": ['cae', 'mw'],
    "suradviṣ": ['cae', 'mw'],
    "suradāru": ['ddsa', 'mw'],
    "suradārumaya": ['mw'],
    "suradīrghikā": ['mw'],
    "suragaja": ['cae', 'ddsa', 'mw'],
    "suragarbha": ['mw'],
    "suragarbhābha": ['mw'],
    "suragati": ['mw'],
    "suragaṇa": ['cae', 'mw'],
    "suragaṇḍa": ['mw'],
    "suragiri": ['mw'],
    "suragrāmaṇī": ['mw'],
    "suraguru": ['mw'],
    "suragurudivasa": ['mw'],
    "suragāyaka": ['mw'],
    "suragāyana": ['mw'],
    "suragṛha": ['cae', 'mw'],
    "surahas": ['mw'],
    "surahaḥsthāna": ['mw'],
    "surai": ['mw'],
    "surajana": ['mw'],
    "surajanī": ['mw'],
    "surajas": ['mw'],
    "surajaḥphala": ['mw'],
    "surajit": ['mw'],
    "surajyeṣṭha": ['mw'],
    "surajā": ['mw'],
    "surajāya": ['mw'],
    "suraka": ['mw'],
    "surakarin": ['mw'],
    "surakarīndradarpāpahā": ['mw'],
    "suraketu": ['mw'],
    "surakhaṇḍanikā": ['mw'],
    "surakta": ['ddsa', 'mw'],
    "suraktaka": ['mw'],
    "surakula": ['cae', 'mw'],
    "surakāminī": ['mw'],
    "surakārmuka": ['cae', 'mw'],
    "surakāru": ['mw'],
    "surakārya": ['mw'],
    "surakāṣṭha": ['mw'],
    "surakṛt": ['mw'],
    "surakṛta": ['mw'],
    "surakṛtā": ['mw'],
    "surakṣa": ['mw'],
    "surakṣaṇa": ['mw'],
    "surakṣin": ['cae', 'mw'],
    "surakṣita": ['cae', 'mw'],
    "surakṣiṇī": ['bhs'],
    "surakṣya": ['mw'],
    "suralatā": ['mw'],
    "suraloka": ['cae', 'mw'],
    "suralokanātha": ['mw'],
    "suralokarājya": ['mw'],
    "suralokasundarī": ['mw'],
    "suralā": ['mw'],
    "suralāsikā": ['mw'],
    "suramandira": ['mw'],
    "suramantrin": ['mw'],
    "suramaṇīya": ['cae'],
    "suramaṇḍalikā": ['mw'],
    "suramedā": ['mw'],
    "suramohinī": ['mw'],
    "suramuni": ['mw'],
    "suramya": ['cae', 'ddsa'],
    "suramūla": ['mw'],
    "suramṛttikā": ['mw'],
    "suranadī": ['cped', 'mw'],
    "suranandā": ['mw'],
    "surandhaka": ['mw'],
    "surandhra": ['mw'],
    "suranemin": ['bhs'],
    "suranilaya": ['mw'],
    "suranimnagā": ['mw'],
    "suranirgandha": ['mw'],
    "suranirjhariṇī": ['mw'],
    "suranāla": ['mw'],
    "suranātha": ['cped'],
    "suranāyaka": ['mw'],
    "suraparvata": ['mw'],
    "suraparṇa": ['mw'],
    "suraparṇika": ['mw'],
    "suraparṇikā": ['mw'],
    "suraparṇī": ['mw'],
    "surapatha": ['cped', 'mw'],
    "surapati": ['cae', 'mw'],
    "surapaticāpa": ['cae', 'mw'],
    "surapatidhanus": ['mw'],
    "surapatiguru": ['mw'],
    "surapatitanaya": ['mw'],
    "surapatitva": ['mw'],
    "surapratiṣṭhā": ['mw'],
    "surapravīra": ['mw'],
    "surapriya": ['mw'],
    "surapriyā": ['mw'],
    "surapura": ['mw'],
    "surapurodhas": ['mw'],
    "surapurī": ['mw'],
    "surapuṃnāga": ['mw'],
    "surapuṣpa": ['mw'],
    "surapuṣpavṛṣṭi": ['mw'],
    "surapādapa": ['mw'],
    "surapāla": ['mw'],
    "surapāṃsulā": ['mw'],
    "surapāṃsulājana": ['mw'],
    "suraripu": ['cped', 'mw'],
    "surarāj": ['cae', 'mw'],
    "surarāja": ['mw'],
    "surarājaguru": ['mw'],
    "surarājamantrin": ['mw'],
    "surarājan": ['cae', 'mw'],
    "surarājatā": ['mw'],
    "surarājavṛkṣa": ['mw'],
    "surarājaśarāsana": ['mw'],
    "surarājya": ['mw'],
    "surarṣabha": ['mw'],
    "surarṣi": ['cae', 'mw'],
    "surasa": ['cae', 'ddsa', 'mw'],
    "surasadana": ['mw'],
    "surasadman": ['mw'],
    "surasakha": ['ddsa', 'mw'],
    "surasakhaṃ": ['cae'],
    "surasama": ['mw'],
    "surasambhavā": ['mw'],
    "surasamiti": ['mw'],
    "surasarit": ['cae', 'mw'],
    "surasaritsuta": ['mw'],
    "surasarṣapaka": ['mw'],
    "surasasaṃgraha": ['mw'],
    "surasattama": ['mw'],
    "surasaṃgha": ['cae', 'mw'],
    "surasindhu": ['mw'],
    "suraskandha": ['mw'],
    "surasravantī": ['mw'],
    "surasrotasvinī": ['mw'],
    "surasthāna": ['mw'],
    "surastrī": ['cae', 'mw'],
    "surastrīśa": ['mw'],
    "surasundara": ['mw'],
    "surasundarasenā": ['mw'],
    "surasundarasenāgaṇapati": ['mw'],
    "surasundarī": ['bhs', 'cae', 'mw'],
    "surasundarījana": ['mw'],
    "surasuta": ['cae', 'mw'],
    "surasutopama": ['mw'],
    "surasutā": ['mw'],
    "surasā": ['mw'],
    "surasācchada": ['mw'],
    "surasāgraja": ['mw'],
    "surasāgraṇī": ['mw'],
    "surasāṣṭa": ['mw'],
    "surasī": ['mw'],
    "surata": ['bhs', 'cae', 'cped', 'mw'],
    "suratabandha": ['mw'],
    "suratabheda": ['mw'],
    "suratagahvarā": ['mw'],
    "surataglāni": ['mw'],
    "suratajanita": ['mw'],
    "suratakeli": ['mw'],
    "suratakrīḍā": ['mw'],
    "suratamañjarī": ['mw'],
    "suratamṛdita": ['mw'],
    "suratanivṛtti": ['mw'],
    "surataprabhā": ['mw'],
    "suratapradīpa": ['mw'],
    "surataprasaṅga": ['mw'],
    "surataprasaṅgin": ['mw'],
    "suratapriya": ['mw'],
    "suratapriyā": ['mw'],
    "surataraṃgiṇī": ['mw'],
    "surataraṅgin": ['ddsa', 'mw'],
    "surataraṅgiṇī": ['ddsa'],
    "surataru": ['mw'],
    "suratasambhoga": ['mw'],
    "suratasaukhya": ['mw'],
    "suratastha": ['mw'],
    "suratatālī": ['mw'],
    "suratavarṇana": ['mw'],
    "suratavidhi": ['mw'],
    "surataviśeṣa": ['mw'],
    "suratavyāpārajātaśrama": ['mw'],
    "suratavārarātri": ['mw'],
    "suratha": ['cae', 'gra', 'mw'],
    "surathadeva": ['mw'],
    "surathavijaya": ['mw'],
    "surathotsava": ['mw'],
    "surathā": ['mw'],
    "surathākāra": ['mw'],
    "surati": ['bhs', 'mw'],
    "suratimiśra": ['mw'],
    "suratna": ['cae', 'ddsa', 'gra', 'mw'],
    "suratopacārakuśala": ['mw'],
    "suratotsava": ['mw'],
    "suratotsuka": ['mw'],
    "suratoṣaka": ['mw'],
    "suratta": ['cped'],
    "suratuṅga": ['mw'],
    "suratā": ['mw'],
    "suraukas": ['ddsa', 'mw'],
    "suravadhū": ['cae', 'mw'],
    "suravairin": ['mw'],
    "suravallabha": ['mw'],
    "suravallabhā": ['mw'],
    "suravallī": ['mw'],
    "suravana": ['mw'],
    "suravanitā": ['cae'],
    "suravara": ['mw'],
    "suravaranagara": ['mw'],
    "suravaravanitā": ['mw'],
    "suravarcas": ['mw'],
    "suravarman": ['mw'],
    "suravartman": ['mw'],
    "suravelā": ['mw'],
    "suraveśman": ['mw'],
    "suravidviṣ": ['mw'],
    "suravilāsinī": ['mw'],
    "suravāhinī": ['mw'],
    "suravīthī": ['mw'],
    "surayoṣit": ['cae', 'mw'],
    "surayuvati": ['cae', 'ddsa', 'mw'],
    "surayāna": ['mw'],
    "surañjana": ['mw'],
    "surañjita": ['ddsa'],
    "suraśatru": ['mw'],
    "suraśatruguru": ['mw'],
    "suraśatruhan": ['mw'],
    "suraśilpin": ['mw'],
    "suraśmi": ['bhs', 'cae', 'gra'],
    "suraśmiketu": ['bhs'],
    "suraśreṣṭha": ['cae', 'mw'],
    "suraśreṣṭhā": ['mw'],
    "suraśvetā": ['mw'],
    "suraśākhin": ['mw'],
    "suraḍā": ['mw'],
    "suraḥ": ['ap90'],
    "suraṃgaḥ": ['ap90'],
    "suraṅga": ['cae', 'ddsa', 'mw'],
    "suraṅgada": ['mw'],
    "suraṅgadhātu": ['mw'],
    "suraṅgadhūlī": ['mw'],
    "suraṅgikā": ['mw'],
    "suraṅgā": ['mw'],
    "suraṅgī": ['mw'],
    "suraṇa": ['cae', 'gra', 'mw'],
    "suraṇā": ['mw'],
    "suraṛṣi": ['mw'],
    "surebha": ['mw'],
    "surejya": ['mw'],
    "surejyā": ['mw'],
    "surekha": ['cae', 'mw'],
    "surekhā": ['mw'],
    "surekṇas": ['gra', 'mw'],
    "surendra": ['cae', 'ddsa', 'mw'],
    "surendracāpa": ['mw'],
    "surendragopa": ['mw'],
    "surendrajit": ['mw'],
    "surendraka": ['mw'],
    "surendrakanda": ['mw'],
    "surendraloka": ['mw'],
    "surendralupta": ['mw'],
    "surendramālā": ['bhs', 'mw'],
    "surendrapūjya": ['mw'],
    "surendrasaṃhitā": ['mw'],
    "surendratā": ['mw'],
    "surendravatī": ['mw'],
    "surendraśiṣya": ['mw'],
    "surendrā": ['bhs', 'mw'],
    "surendrābhā": ['bhs'],
    "suretara": ['mw'],
    "suretas": ['cae', 'gra', 'mw'],
    "suretodhas": ['mw'],
    "sureśa": ['cae', 'ddsa', 'mw'],
    "sureśaloka": ['mw'],
    "sureśvara": ['cae', 'mw'],
    "sureśvaradhanus": ['mw'],
    "sureśvarapaṇḍita": ['mw'],
    "sureśvaraprabha": ['bhs', 'mw'],
    "sureśvarasvāmin": ['mw'],
    "sureśvaravārttika": ['mw'],
    "sureśvaravārttikaṭīkā": ['mw'],
    "sureśvaropādhyāya": ['mw'],
    "sureśvarācārya": ['mw'],
    "sureśvarāśrama": ['mw'],
    "sureśvarī": ['mw'],
    "sureśvarīkṣetra": ['mw'],
    "sureśvarīmāhātmya": ['mw'],
    "sureśī": ['mw'],
    "sureṇu": ['bhs', 'mw'],
    "sureṇupuṣpadhvaja": ['bhs', 'mw'],
    "sureṣṭa": ['mw'],
    "sureṣṭaka": ['mw'],
    "sureṣṭā": ['mw'],
    "suri": ['mw'],
    "surisa": ['mw'],
    "suriya": ['bhs', 'cped'],
    "suriya-uggamana": ['cped'],
    "suriyaggāha": ['cped'],
    "suriyamaṇḍala": ['cped'],
    "suriyarasmi": ['cped'],
    "suriyaraṁsi": ['cped'],
    "suriyatthaṅgama": ['cped'],
    "suriyuggama": ['cped'],
    "surocana": ['mw'],
    "surocanā": ['mw'],
    "surocis": ['mw'],
    "suroda": ['mw'],
    "surodaka": ['mw'],
    "surodha": ['mw'],
    "surodhas": ['mw'],
    "suroha": ['mw'],
    "surohikā": ['mw'],
    "surohitikā": ['mw'],
    "surohiṇī": ['mw'],
    "suroman": ['cae', 'mw'],
    "suropama": ['cae', 'mw'],
    "suropayāma": ['mw'],
    "surottama": ['cae', 'mw'],
    "surottamā": ['mw'],
    "surottamācārya": ['mw'],
    "surottara": ['mw'],
    "suroṣa": ['cae', 'ddsa', 'mw'],
    "suroṣaṇa": ['mw'],
    "suruc": ['cae', 'gra', 'mw'],
    "suruci": ['bhs', 'mw'],
    "surucikā": ['bhs'],
    "surucira": ['cae', 'mw'],
    "surucirā": ['bhs'],
    "suruja": ['mw'],
    "surukma": ['cae', 'gra', 'mw'],
    "surundalā": ['mw'],
    "surusura": ['mw'],
    "surusurukārakaṁ": ['cped'],
    "suruṃgā": ['ap90'],
    "suruṅga": ['mw'],
    "suruṅgayuj": ['mw'],
    "suruṅgā": ['cae', 'cped', 'ddsa', 'mw'],
    "suruṅgāhi": ['mw'],
    "surya": ['mw'],
    "surā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "surābali": ['mw'],
    "surābdhi": ['mw'],
    "surābhakṣī": ['bhs'],
    "surābhāga": ['mw'],
    "surābhājana": ['cae', 'mw'],
    "surābhāṇḍa": ['mw'],
    "surābīja": ['mw'],
    "surāchaṇa": ['cped'],
    "surācārya": ['mw'],
    "surādevī": ['bhs'],
    "surādhama": ['mw'],
    "surādhara": ['mw'],
    "surādhas": ['cae', 'ddsa', 'gra', 'mw'],
    "surādhipa": ['cae', 'ddsa', 'mw'],
    "surādhutta": ['cped'],
    "surādhvaja": ['cae', 'ddsa', 'mw'],
    "surādhyakṣa": ['mw'],
    "surādhāna": ['mw'],
    "surādhīśa": ['mw'],
    "surādri": ['ddsa', 'mw'],
    "surādṛti": ['mw'],
    "surāghaṭa": ['cped', 'mw'],
    "surāgraha": ['mw'],
    "surāgrya": ['mw'],
    "surāgāra": ['mw'],
    "surāgṛha": ['mw'],
    "surāhuti": ['mw'],
    "surāhva": ['mw'],
    "surāhvaya": ['mw'],
    "surāhvā": ['mw'],
    "surājaka": ['mw'],
    "surājambhava": ['mw'],
    "surājan": ['ddsa', 'mw'],
    "surāji": ['mw'],
    "surājikā": ['mw'],
    "surājñī": ['mw'],
    "surājīva": ['mw'],
    "surājīvin": ['cae', 'ddsa', 'mw'],
    "surākara": ['mw'],
    "surākarman": ['mw'],
    "surākumbha": ['mw'],
    "surākāra": ['mw'],
    "surāla": ['mw'],
    "surālaya": ['cae', 'mw'],
    "surāma": ['gra', 'mw'],
    "surāmada": ['cped', 'mw'],
    "surāman": ['mw'],
    "surāmatta": ['cae', 'mw'],
    "surāmaya": ['mw'],
    "surāmaṇḍa": ['mw'],
    "surāmeha": ['mw'],
    "surāmehin": ['mw'],
    "surāmeraya": ['cped'],
    "surāmukha": ['mw'],
    "surāmūlya": ['cae', 'mw'],
    "surānaka": ['mw'],
    "surānanda": ['mw'],
    "surānandā": ['mw'],
    "surāpa": ['cae', 'mw'],
    "surāpagā": ['ddsa', 'mw'],
    "surāpin": ['mw'],
    "surāpriya": ['mw'],
    "surāpāna": ['cped', 'mw'],
    "surāpānaprāyaścitta": ['mw'],
    "surāpātra": ['mw'],
    "surāpāyikā": ['cped'],
    "surāpāṇa": ['cae', 'ddsa', 'mw'],
    "surāpāṇaparikṣīva": ['mw'],
    "surāpāṇaprāyaścitta": ['mw'],
    "surāpīta": ['cped', 'mw'],
    "surāpītha": ['mw'],
    "surāraṇi": ['mw'],
    "surārcana": ['mw'],
    "surārdana": ['mw'],
    "surārha": ['mw'],
    "surārhaka": ['mw'],
    "surāri": ['cae', 'mw'],
    "surārighna": ['mw'],
    "surārihan": ['mw'],
    "surārihantṛ": ['mw'],
    "surārisambhava": ['mw'],
    "surāsamudra": ['mw'],
    "surāsava": ['cae', 'ddsa', 'mw'],
    "surāsaṃdhāna": ['mw'],
    "surāsaṃspṛṣṭa": ['mw'],
    "surāsoma": ['mw'],
    "surāsomavikrayin": ['mw'],
    "surāsoṇḍa": ['cped'],
    "surāspada": ['mw'],
    "surāsura": ['cae', 'ddsa', 'mw'],
    "surāsuraguru": ['mw'],
    "surāsuramaya": ['mw'],
    "surāsuravimarda": ['mw'],
    "surāsurācārya": ['mw'],
    "surāti": ['cae', 'gra', 'mw'],
    "surātri": ['mw'],
    "surāva": ['mw'],
    "surāvalī": ['mw'],
    "surāvani": ['mw'],
    "surāvant": ['cae'],
    "surāvat": ['gra', 'mw'],
    "surāvāri": ['mw'],
    "surāvāsa": ['mw'],
    "surāvṛta": ['mw'],
    "surāyudha": ['ddsa', 'mw'],
    "surāśodhana": ['mw'],
    "surāśraya": ['mw'],
    "surāśū": ['gra', 'mw'],
    "surāḍaka": ['cped'],
    "surāṅganā": ['cae', 'ddsa', 'mw'],
    "surāṇāyanīya": ['mw'],
    "surāṣṭra": ['cae', 'ddsa', 'mw'],
    "surāṣṭrabrahma": ['mw'],
    "surāṣṭraja": ['mw'],
    "surāṣṭrajā": ['mw'],
    "surāṣṭrasauvīraka": ['mw'],
    "surāṣṭraviṣaya": ['mw'],
    "surāṣṭrodbhavā": ['mw'],
    "surāṣṭrā": ['mw'],
    "surāṣṭrādhipati": ['mw'],
    "surāṣṭrāvanti": ['mw'],
    "surī": ['ddsa', 'mw'],
    "surīka": ['mw'],
    "surīya": ['mw'],
    "surūhaka": ['mw'],
    "surūpa": ['bhs', 'cae', 'cped', 'gra', 'mw'],
    "surūpaka": ['mw'],
    "surūpakṛtnu": ['cae', 'gra', 'mw'],
    "surūpatā": ['mw'],
    "surūpavarṣavarṇa": ['mw'],
    "surūpinī": ['cped'],
    "surūpā": ['mw'],
    "surūpī": ['cped'],
    "surūḍha": ['mw'],
    "surūṇḍa": ['mw'],
    "susabheya": ['mw'],
    "susabhājita": ['mw'],
    "susaciva": ['mw'],
    "susadṛś": ['gra'],
    "susadṛśa": ['cae', 'mw'],
    "susaha": ['gra', 'mw'],
    "susahāya": ['cae', 'mw'],
    "susahāyavant": ['cae'],
    "susahāyavat": ['mw'],
    "susaindhavī": ['mw'],
    "susajjīkṛ": ['mw'],
    "susakhi": ['ddsa', 'mw'],
    "susaktha": ['mw'],
    "susakthi": ['mw'],
    "susaktu": ['mw'],
    "susalila": ['mw'],
    "susama": ['mw'],
    "susambaddha": ['mw'],
    "susambandha": ['mw'],
    "susambhava": ['mw'],
    "susambhrama": ['mw'],
    "susambhramat": ['mw'],
    "susambhrānta": ['mw'],
    "susambhāvya": ['mw'],
    "susambhṛt": ['mw'],
    "susambhṛta": ['mw'],
    "susambhṛti": ['mw'],
    "susamiddha": ['cae', 'gra', 'mw'],
    "susamidh": ['mw'],
    "susammata": ['mw'],
    "susammṛṣṭa": ['gra', 'mw'],
    "susampad": ['mw'],
    "susampanna": ['mw'],
    "susampiṣṭa": ['gra', 'mw'],
    "susamprahṛṣṭa": ['mw'],
    "susamprajña": ['mw'],
    "susamprasthita": ['mw'],
    "susampratapta": ['mw'],
    "susamprīta": ['mw'],
    "susampūrṇa": ['mw'],
    "susamubdha": ['gra', 'mw'],
    "susamāhita": ['cae', 'cped', 'mw'],
    "susamākṛta": ['mw'],
    "susamāpta": ['mw'],
    "susamārabdha": ['mw'],
    "susamāraddha": ['cped'],
    "susamāsīna": ['mw'],
    "susamāśrita": ['mw'],
    "susamīhita": ['cae', 'mw'],
    "susamīkṛ": ['mw'],
    "susamīpa": ['mw'],
    "susamṛddha": ['cae', 'mw'],
    "susamṛddhi": ['mw'],
    "susamṛddhārtha": ['mw'],
    "susani": ['mw'],
    "susanitā": ['gra', 'mw'],
    "susanitṛ": ['gra', 'mw'],
    "susanna": ['mw'],
    "susarala": ['mw'],
    "susaraṇa": ['gra', 'mw'],
    "susartu": ['cae', 'gra', 'mw'],
    "susarva": ['cae', 'mw'],
    "susasya": ['mw'],
    "susatkṛta": ['cae', 'mw'],
    "susattra": ['mw'],
    "susattva": ['cae', 'mw'],
    "susatya": ['mw'],
    "susatyā": ['mw'],
    "susaubhaga": ['mw'],
    "susava": ['mw'],
    "susaññata": ['cped'],
    "susaṃbhava": ['bhs'],
    "susaṃbhavavyūha": ['bhs'],
    "susaṃbhrānta": ['cae'],
    "susaṃcita": ['mw'],
    "susaṃcitam": ['mw'],
    "susaṃdha": ['mw'],
    "susaṃdhi": ['mw'],
    "susaṃdhita": ['mw'],
    "susaṃdīpta": ['mw'],
    "susaṃdṛś": ['cae', 'gra', 'mw'],
    "susaṃgama": ['mw'],
    "susaṃgatā": ['cae', 'mw'],
    "susaṃgraha": ['mw'],
    "susaṃgupta": ['mw'],
    "susaṃgṛhīta": ['cae', 'mw'],
    "susaṃgṛhītarāṣṭra": ['mw'],
    "susaṃhata": ['cae', 'mw'],
    "susaṃhati": ['mw'],
    "susaṃhita": ['mw'],
    "susaṃhitapramāṇa": ['mw'],
    "susaṃhṛṣṭa": ['mw'],
    "susaṃkaṭa": ['mw'],
    "susaṃkruddha": ['mw'],
    "susaṃkula": ['mw'],
    "susaṃkāśa": ['gra', 'mw'],
    "susaṃkṣepa": ['mw'],
    "susaṃnata": ['mw'],
    "susaṃnipātita": ['mw'],
    "susaṃpanna": ['cae'],
    "susaṃpiṣṭa": ['cae'],
    "susaṃprasthita": ['bhs'],
    "susaṃrabdha": ['cae', 'gra', 'mw'],
    "susaṃrambha": ['mw'],
    "susaṃsad": ['gra', 'mw'],
    "susaṃskṛta": ['cae', 'gra', 'mw'],
    "susaṃskṛtopaskara": ['mw'],
    "susaṃskṛtopaskaratā": ['mw'],
    "susaṃsthita": ['mw'],
    "susaṃsthā": ['mw'],
    "susaṃsthāna": ['mw'],
    "susaṃsṛṣṭa": ['mw'],
    "susaṃtoṣa": ['mw'],
    "susaṃtrasta": ['mw'],
    "susaṃtuṣṭa": ['mw'],
    "susaṃvigna": ['cae', 'mw'],
    "susaṃvīta": ['cae', 'mw'],
    "susaṃvṛddha": ['mw'],
    "susaṃvṛta": ['cae', 'mw'],
    "susaṃvṛti": ['mw'],
    "susaṃvṛtta": ['mw'],
    "susaṃvṛttaskandhatā": ['mw'],
    "susaṃvṛtti": ['mw'],
    "susaṃyata": ['cae', 'mw'],
    "susaṃyatta": ['mw'],
    "susaṃyukta": ['mw'],
    "susaṃyuta": ['ddsa', 'mw'],
    "susaṃśita": ['cae', 'gra', 'mw'],
    "susaṃśliṣṭa": ['mw'],
    "susaṃśrita": ['mw'],
    "susaṃśās": ['mw'],
    "susaṅga": ['mw'],
    "susaṅkhata": ['cped'],
    "susaṇṭhāna": ['cped'],
    "susena": ['mw'],
    "susevita": ['mw'],
    "susevya": ['mw'],
    "susic": ['mw'],
    "susiddha": ['mw'],
    "susiddhārtha": ['cae', 'mw'],
    "susikatā": ['mw'],
    "susikkhita": ['cped'],
    "susikta": ['mw'],
    "susira": ['cped'],
    "susita": ['cae', 'mw'],
    "suskandana": ['mw'],
    "suskandha": ['mw'],
    "suskandhamāra": ['mw'],
    "susmita": ['mw'],
    "susmūrṣamāṇa": ['mw'],
    "susmūrṣā": ['mw'],
    "susnayu": ['mw'],
    "susnigdha": ['cae', 'mw'],
    "susnigdhagambhīra": ['mw'],
    "susnigdhā": ['mw'],
    "susnuṣa": ['gra', 'mw'],
    "susnā": ['mw'],
    "susnāta": ['mw'],
    "susoma": ['bhs'],
    "susparśa": ['mw'],
    "suspaṣṭa": ['mw'],
    "suspaṣṭam": ['mw'],
    "susphuṭa": ['mw'],
    "susphīta": ['mw'],
    "susragdhara": ['mw'],
    "susraj": ['mw'],
    "susras": ['mw'],
    "susrotas": ['mw'],
    "susroṇi": ['mw'],
    "sussala": ['ddsa', 'mw'],
    "sussamāna": ['cped'],
    "sussaratā": ['cped'],
    "sussati": ['cped'],
    "sussi": ['cped'],
    "sussitvā": ['cped'],
    "sussūsati": ['cped'],
    "sussūsi": ['cped'],
    "sussūsā": ['cped'],
    "sustambha": ['mw'],
    "sustanā": ['mw'],
    "sustanī": ['mw'],
    "sustha": ['cae', 'mw'],
    "susthacitta": ['mw'],
    "susthakalpa": ['cae', 'mw'],
    "susthala": ['mw'],
    "susthamānasa": ['mw'],
    "susthatva": ['mw'],
    "susthatā": ['mw'],
    "susthaya": ['mw'],
    "susthaṇḍila": ['mw'],
    "sustheya": ['mw'],
    "susthira": ['cae', 'mw'],
    "susthirammanya": ['mw'],
    "susthiravarman": ['mw'],
    "susthirayauvana": ['mw'],
    "susthirā": ['mw'],
    "susthita": ['cae', 'mw'],
    "susthitamanas": ['mw'],
    "susthitamati": ['bhs'],
    "susthitammanya": ['mw'],
    "susthitatva": ['mw'],
    "susthiti": ['cae', 'mw'],
    "susthuṣas": ['mw'],
    "susthāna": ['mw'],
    "susthāvatī": ['mw'],
    "sustrī": ['cae', 'mw'],
    "sustuta": ['mw'],
    "susu": ['cped'],
    "susubhikṣa": ['mw'],
    "susuddha": ['cped'],
    "susudhī": ['bhs'],
    "susugandha": ['mw'],
    "susugandhi": ['mw'],
    "susukha": ['cae', 'ddsa', 'mw'],
    "susukhadṛśya": ['mw'],
    "susukham": ['mw'],
    "susukhin": ['cae', 'mw'],
    "susukhodaya": ['mw'],
    "susukka": ['cped'],
    "susukā": ['cped'],
    "susundara": ['mw'],
    "susurapriyā": ['mw'],
    "susutama": ['mw'],
    "susvabhāva": ['mw'],
    "susvadha": ['mw'],
    "susvadhā": ['mw'],
    "susvana": ['mw'],
    "susvanam": ['mw'],
    "susvapna": ['mw'],
    "susvara": ['cae', 'mw'],
    "susvaram": ['mw'],
    "susvaru": ['gra', 'mw'],
    "susvasti": ['bhs'],
    "susveda": ['mw'],
    "susvinna": ['mw'],
    "susvāda": ['mw'],
    "susvādu": ['cae', 'mw'],
    "susvādutoya": ['mw'],
    "susvāgata": ['cae', 'mw'],
    "susvāmin": ['mw'],
    "susvānta": ['mw'],
    "susvāpa": ['mw'],
    "susādhana": ['mw'],
    "susādhanatva": ['mw'],
    "susādhita": ['mw'],
    "susādhu": ['mw'],
    "susādhya": ['mw'],
    "susāman": ['mw'],
    "susāna": ['cped'],
    "susānagopaka": ['cped'],
    "susāntvayamana": ['mw'],
    "susāntvita": ['mw'],
    "susāra": ['bhs', 'mw'],
    "susārathi": ['mw'],
    "susāravat": ['mw'],
    "susārthavāha": ['bhs', 'mw'],
    "susāvitra": ['mw'],
    "susāya": ['cae', 'mw'],
    "susāyam": ['mw'],
    "susīla": ['cped'],
    "susīma": ['bhs', 'cae', 'mw'],
    "susīman": ['mw'],
    "susīmā": ['bhs', 'mw'],
    "susūkṣma": ['mw'],
    "susūkṣmapattrā": ['mw'],
    "susūkṣmeśa": ['mw'],
    "susūtra": ['mw'],
    "sut": ['cae', 'ddsa', 'mw'],
    "suta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sutadhara": ['cped'],
    "sutadā": ['mw'],
    "sutahibukayoga": ['mw'],
    "sutailā": ['mw'],
    "sutajīva": ['bhs'],
    "sutajīvaka": ['mw'],
    "sutakri": ['gra'],
    "sutakīrti": ['mw'],
    "sutala": ['cae', 'mw'],
    "sutalpa": ['mw'],
    "sutambhara": ['gra', 'mw'],
    "sutamisrā": ['mw'],
    "sutamām": ['mw'],
    "sutanaya": ['mw'],
    "sutanirviśeṣam": ['mw'],
    "sutantra": ['mw'],
    "sutantri": ['cae', 'mw'],
    "sutantu": ['mw'],
    "sutanu": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sutanuja": ['mw'],
    "sutanutā": ['mw'],
    "sutapa": ['mw'],
    "sutapas": ['cae', 'mw'],
    "sutapasvin": ['mw'],
    "sutapeya": ['cae', 'gra', 'mw'],
    "sutappaya": ['cped'],
    "sutapta": ['cae', 'ddsa', 'mw'],
    "sutaptā": ['mw'],
    "sutapā": ['cae', 'ddsa', 'gra', 'mw'],
    "sutapādikā": ['mw'],
    "sutapādukā": ['mw'],
    "sutapāvan": ['gra', 'mw'],
    "sutara": ['cae', 'gra', 'mw'],
    "sutaraṇa": ['cae', 'gra', 'mw'],
    "sutardana": ['mw'],
    "sutarkārī": ['mw'],
    "sutarman": ['cae', 'gra', 'mw'],
    "sutarpayat": ['mw'],
    "sutarpita": ['mw'],
    "sutarām": ['cae', 'mw'],
    "sutasoma": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sutasomajātaka": ['mw'],
    "sutasomavat": ['gra', 'mw'],
    "sutasomā": ['mw'],
    "sutasomāvadāna": ['mw'],
    "sutasuta": ['mw'],
    "sutatva": ['mw'],
    "sutavallabha": ['mw'],
    "sutavant": ['cped'],
    "sutavaskarā": ['mw'],
    "sutavat": ['ap90', 'ddsa', 'mw'],
    "sutavatsala": ['mw'],
    "sutaśravas": ['mw'],
    "sutaśreṇī": ['mw'],
    "sutaṃgama": ['mw'],
    "sutaṃgamaḥ": ['ap90'],
    "sutaṃjaya": ['mw'],
    "sutaṃrayiṣṭhīya": ['mw'],
    "sutaṣṭa": ['cae', 'ddsa', 'gra', 'mw'],
    "sute": ['mw'],
    "sutegṛbh": ['gra', 'mw'],
    "suteja": ['bhs'],
    "sutejana": ['mw'],
    "sutejas": ['cae', 'mw'],
    "sutejita": ['cae', 'mw'],
    "sutejomaṇḍalaratiśrī": ['bhs'],
    "sutejā": ['mw'],
    "sutekara": ['cae', 'gra', 'mw'],
    "sutemanas": ['mw'],
    "suteraṇa": ['cae', 'gra', 'mw'],
    "suti": ['cped', 'gra', 'mw'],
    "sutihīna": ['cped'],
    "sutikta": ['mw'],
    "sutiktaka": ['mw'],
    "sutiktā": ['mw'],
    "sutin": ['ap90', 'cae', 'ddsa', 'mw'],
    "sutintiḍā": ['mw'],
    "sutintiḍī": ['mw'],
    "sutinī": ['ap90'],
    "sutiḥ": ['ap90'],
    "sutotpatti": ['mw'],
    "sutoya": ['mw'],
    "sutoṣa": ['cae', 'mw'],
    "sutoṣaṇa": ['cae', 'mw'],
    "sutrāman": ['ap90', 'cae', 'gra', 'mw'],
    "sutrāmā": ['mw'],
    "sutrāta": ['cae', 'mw'],
    "sutrātra": ['cae', 'gra', 'mw'],
    "sutrāvan": ['cae', 'mw'],
    "sutsaru": ['mw'],
    "sutta": ['cped'],
    "suttaguḷa": ['cped'],
    "suttakantana": ['cped'],
    "suttakāra": ['cped'],
    "suttamaya": ['cped'],
    "suttanta": ['cped'],
    "suttantika": ['cped'],
    "suttapiṭaka": ['cped'],
    "suttappabuddha": ['cped'],
    "suttata": ['cped'],
    "sutthāna": ['ddsa'],
    "sutti": ['cped'],
    "sutuka": ['cae', 'ddsa', 'gra', 'mw'],
    "sutukana": ['mw'],
    "sutumula": ['cae', 'mw'],
    "sutus": ['ap90', 'mw'],
    "sutuṅga": ['mw'],
    "sutuṣṭa": ['mw'],
    "sutvac": ['mw'],
    "sutvakka": ['mw'],
    "sutvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sutvā": ['cped'],
    "sutya": ['cae', 'ddsa', 'mw'],
    "sutyaj": ['gra', 'mw'],
    "sutyaja": ['ddsa', 'mw'],
    "sutyā": ['ap90', 'mw'],
    "sutyāha": ['mw'],
    "sutyāhan": ['cae'],
    "sutyākāla": ['mw'],
    "sutyākālīna": ['mw'],
    "sutyākālīnatva": ['mw'],
    "sutyāmāsa": ['mw'],
    "sutā": ['ap90', 'ddsa', 'mw'],
    "sutābhāva": ['mw'],
    "sutādhāra": ['cped'],
    "sutādāna": ['cae', 'mw'],
    "sutāla": ['mw'],
    "sutāmra": ['mw'],
    "sutāmroṣṭha": ['mw'],
    "sutāna": ['mw'],
    "sutāpati": ['mw'],
    "sutāputra": ['mw'],
    "sutāra": ['cae', 'ddsa', 'mw'],
    "sutāraka": ['mw'],
    "sutārakā": ['mw'],
    "sutārthin": ['cae', 'ddsa', 'mw'],
    "sutārā": ['mw'],
    "sutārṇava": ['mw'],
    "sutāsuta": ['mw'],
    "sutāsutin": ['mw'],
    "sutātmaja": ['mw'],
    "sutātmajā": ['mw'],
    "sutāvant": ['cae'],
    "sutāvat": ['ddsa', 'gra', 'mw'],
    "sutāya": ['bhs'],
    "sutī": ['mw'],
    "sutībhū": ['ddsa'],
    "sutībhūta": ['mw'],
    "sutīkṣṇa": ['cae', 'ddsa', 'mw'],
    "sutīkṣṇadaśana": ['mw'],
    "sutīkṣṇaka": ['mw'],
    "sutīkṣṇam": ['mw'],
    "sutīkṣṇāgra": ['mw'],
    "sutīrtha": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sutīrthaka": ['mw'],
    "sutīrtharāj": ['mw'],
    "sutīrthya": ['mw'],
    "sutīy": ['cae'],
    "sutīya": ['mw'],
    "sutīyati": ['ap90'],
    "sutūlikā": ['mw'],
    "sutūlī": ['mw'],
    "sutṛṇa": ['mw'],
    "sutṛṣṇa": ['mw'],
    "suukta": ['gra'],
    "suuktavāc": ['gra'],
    "suurmi": ['gra'],
    "suutthitā": ['bhs'],
    "suva": ['cped'],
    "suvaca": ['cped', 'mw'],
    "suvacana": ['ddsa', 'mw'],
    "suvacanī": ['mw'],
    "suvacas": ['bhs', 'mw'],
    "suvacasyā": ['gra', 'mw'],
    "suvacā": ['mw'],
    "suvadana": ['bhs', 'cae', 'mw'],
    "suvadanā": ['mw'],
    "suvah": ['mw'],
    "suvaha": ['mw'],
    "suvahman": ['gra', 'mw'],
    "suvahni": ['mw'],
    "suvajra": ['cae', 'gra', 'mw'],
    "suvajrin": ['mw'],
    "suvaktra": ['mw'],
    "suvakṣas": ['mw'],
    "suvalg": ['mw'],
    "suvalitaratiprabhāsaśrī": ['bhs'],
    "suvallarī": ['mw'],
    "suvalli": ['mw'],
    "suvallija": ['mw'],
    "suvallikā": ['mw'],
    "suvallī": ['mw'],
    "suvammita": ['cped'],
    "suvana": ['mw'],
    "suvanaḥ": ['ap90'],
    "suvapus": ['mw'],
    "suvar": ['mw'],
    "suvaratra": ['gra', 'mw'],
    "suvarcaka": ['mw'],
    "suvarcala": ['mw'],
    "suvarcalā": ['mw'],
    "suvarcas": ['cae', 'gra', 'mw'],
    "suvarcasa": ['cae', 'mw'],
    "suvarcasin": ['cae', 'mw'],
    "suvarcaska": ['mw'],
    "suvarcikā": ['mw'],
    "suvarcin": ['mw'],
    "suvardhayitṛ": ['mw'],
    "suvardhāman": ['mw'],
    "suvarga": ['mw'],
    "suvargakāma": ['mw'],
    "suvargeya": ['mw'],
    "suvargya": ['mw'],
    "suvarjana": ['mw'],
    "suvarjikā": ['mw'],
    "suvarjit": ['mw'],
    "suvarman": ['cae', 'mw'],
    "suvartita": ['mw'],
    "suvartitoru": ['mw'],
    "suvartman": ['mw'],
    "suvartula": ['mw'],
    "suvarvat": ['mw'],
    "suvarvid": ['mw'],
    "suvarūtha": ['mw'],
    "suvarūthin": ['mw'],
    "suvarṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "suvarṇabalaja": ['mw'],
    "suvarṇabhujendra": ['bhs', 'mw'],
    "suvarṇabhāsa": ['bhs'],
    "suvarṇabhāsottama": ['bhs'],
    "suvarṇabhāṇḍa": ['cae', 'mw'],
    "suvarṇabhāṇḍaka": ['mw'],
    "suvarṇabhāṇḍāgāra": ['cae', 'mw'],
    "suvarṇabhū": ['mw'],
    "suvarṇabhūmi": ['mw'],
    "suvarṇabindu": ['cae', 'mw'],
    "suvarṇacakravartin": ['mw'],
    "suvarṇacampaka": ['mw'],
    "suvarṇacaura": ['cae', 'mw'],
    "suvarṇacaurikā": ['cae', 'mw'],
    "suvarṇacaṣaka": ['mw'],
    "suvarṇacārin": ['bhs'],
    "suvarṇacūla": ['mw'],
    "suvarṇacūḍa": ['mw'],
    "suvarṇadhenu": ['mw'],
    "suvarṇadhenudānavidhi": ['mw'],
    "suvarṇadhovaka": ['bhs'],
    "suvarṇadhvaja": ['bhs'],
    "suvarṇadvīpa": ['mw'],
    "suvarṇadāna": ['mw'],
    "suvarṇagairika": ['mw'],
    "suvarṇagarbha": ['bhs', 'mw'],
    "suvarṇagaṇita": ['mw'],
    "suvarṇagiri": ['mw'],
    "suvarṇagotra": ['mw'],
    "suvarṇagranthi": ['mw'],
    "suvarṇahali": ['mw'],
    "suvarṇajambudhvajakāñcanābha": ['bhs'],
    "suvarṇajyotis": ['mw'],
    "suvarṇajīvika": ['mw'],
    "suvarṇaka": ['mw'],
    "suvarṇakadalī": ['mw'],
    "suvarṇakakṣya": ['mw'],
    "suvarṇakartṛ": ['cae', 'mw'],
    "suvarṇakarṣa": ['mw'],
    "suvarṇakaṃ": ['ap90'],
    "suvarṇakaṅkaṇa": ['mw'],
    "suvarṇakaṇa": ['mw'],
    "suvarṇakaṇaguggulu": ['mw'],
    "suvarṇakaṭaka": ['cae', 'mw'],
    "suvarṇaketakī": ['mw'],
    "suvarṇakeśa": ['bhs', 'mw'],
    "suvarṇakāra": ['cae', 'mw'],
    "suvarṇakāreśvaravarman": ['mw'],
    "suvarṇakārānna": ['cae', 'mw'],
    "suvarṇakṛt": ['mw'],
    "suvarṇakṣīrī": ['mw'],
    "suvarṇalatā": ['mw'],
    "suvarṇalekhā": ['mw'],
    "suvarṇamaya": ['cae', 'mw'],
    "suvarṇamedinī": ['mw'],
    "suvarṇamedinīdāna": ['mw'],
    "suvarṇamekhalā": ['bhs'],
    "suvarṇamekhalī": ['mw'],
    "suvarṇamocā": ['mw'],
    "suvarṇamukharī": ['mw'],
    "suvarṇamukharīmāhātmya": ['mw'],
    "suvarṇamukhīmāhātmya": ['mw'],
    "suvarṇamuktāvivāda": ['mw'],
    "suvarṇamuṣṭi": ['mw'],
    "suvarṇamākṣika": ['mw'],
    "suvarṇamālikā": ['mw'],
    "suvarṇamāṣa": ['mw'],
    "suvarṇamāṣaka": ['mw'],
    "suvarṇanakulī": ['mw'],
    "suvarṇanaṣṭaśānti": ['mw'],
    "suvarṇanābha": ['mw'],
    "suvarṇanābhi": ['mw'],
    "suvarṇapadma": ['mw'],
    "suvarṇapadmadāna": ['mw'],
    "suvarṇapakṣa": ['mw'],
    "suvarṇapattra": ['mw'],
    "suvarṇaphalā": ['mw'],
    "suvarṇapiñjara": ['cae', 'mw'],
    "suvarṇaprabha": ['bhs'],
    "suvarṇaprabhāsa": ['bhs', 'mw'],
    "suvarṇaprabhāsitā": ['bhs'],
    "suvarṇaprabhāsottama": ['bhs'],
    "suvarṇaprabhāsā": ['bhs', 'mw'],
    "suvarṇaprasara": ['mw'],
    "suvarṇaprasava": ['mw'],
    "suvarṇaprastha": ['bhs'],
    "suvarṇapura": ['mw'],
    "suvarṇapuṣpa": ['bhs', 'mw'],
    "suvarṇapuṣpita": ['mw'],
    "suvarṇapuṣpojjvalaraśmiketu": ['bhs'],
    "suvarṇapālikā": ['mw'],
    "suvarṇapārśva": ['bhs', 'mw'],
    "suvarṇapṛthvīdānavidhi": ['mw'],
    "suvarṇapṛṣṭha": ['mw'],
    "suvarṇarajata": ['cae', 'mw'],
    "suvarṇarambhā": ['mw'],
    "suvarṇaratnākaracchattraketu": ['mw'],
    "suvarṇaratnākaracchattrakūṭa": ['mw'],
    "suvarṇaratnākarachattrakūṭa": ['bhs'],
    "suvarṇarekha": ['mw'],
    "suvarṇarekhā": ['mw'],
    "suvarṇaretas": ['mw'],
    "suvarṇaretasa": ['mw'],
    "suvarṇaroman": ['mw'],
    "suvarṇarūpyaka": ['mw'],
    "suvarṇarūpyamaya": ['mw'],
    "suvarṇasa": ['mw'],
    "suvarṇasaṃdhi": ['bhs'],
    "suvarṇasena": ['bhs'],
    "suvarṇasiddha": ['mw'],
    "suvarṇastainya": ['mw'],
    "suvarṇasteya": ['mw'],
    "suvarṇasteyin": ['mw'],
    "suvarṇasthāna": ['mw'],
    "suvarṇasthānamāhātmya": ['mw'],
    "suvarṇasānūra": ['mw'],
    "suvarṇasāra": ['mw'],
    "suvarṇasūtra": ['mw'],
    "suvarṇatantra": ['mw'],
    "suvarṇatāla": ['mw'],
    "suvarṇavarṇa": ['mw'],
    "suvarṇavarṇatā": ['mw'],
    "suvarṇavarṇā": ['mw'],
    "suvarṇavarṣa": ['mw'],
    "suvarṇavastrādi": ['mw'],
    "suvarṇavat": ['ap90', 'mw'],
    "suvarṇavattā": ['mw'],
    "suvarṇavatī": ['mw'],
    "suvarṇavaṇij": ['mw'],
    "suvarṇavijaya": ['mw'],
    "suvarṇaviṣāṇa": ['bhs'],
    "suvarṇavṛṣabha": ['mw'],
    "suvarṇayūthikā": ['cae', 'mw'],
    "suvarṇayūthī": ['mw'],
    "suvarṇaśakaṭikā": ['cae', 'mw'],
    "suvarṇaśataraśmibhāsagarbha": ['bhs'],
    "suvarṇaśekhara": ['mw'],
    "suvarṇaśileśvaratīrtha": ['mw'],
    "suvarṇaśiras": ['mw'],
    "suvarṇaśṛṅga": ['bhs'],
    "suvarṇaṣṭhīvi": ['mw'],
    "suvarṇaṣṭhīvin": ['mw'],
    "suvarṇin": ['bhs', 'mw'],
    "suvarṇya": ['mw'],
    "suvarṇā": ['mw'],
    "suvarṇābha": ['bhs', 'mw'],
    "suvarṇābhiṣeka": ['mw'],
    "suvarṇāhvā": ['mw'],
    "suvarṇākarṣaṇabhairavastotra": ['mw'],
    "suvarṇākhya": ['mw'],
    "suvarṇākṣa": ['mw'],
    "suvarṇālaṃkāravat": ['mw'],
    "suvarṇālu": ['mw'],
    "suvarṇāra": ['mw'],
    "suvarṇāvabhāsa": ['bhs'],
    "suvarṇāvabhāsā": ['bhs', 'mw'],
    "suvarṇī": ['mw'],
    "suvarṇībhū": ['ddsa', 'mw'],
    "suvarṇīya": ['mw'],
    "suvarṣa": ['cae', 'ddsa', 'mw'],
    "suvas": ['mw'],
    "suvasana": ['cae', 'gra', 'mw'],
    "suvasanta": ['cae', 'mw'],
    "suvasantaka": ['mw'],
    "suvastra": ['bhs', 'cae', 'mw'],
    "suvastrā": ['mw'],
    "suvastusampad": ['mw'],
    "suvasu": ['mw'],
    "suvatsā": ['mw'],
    "suvatthi": ['bhs', 'cped'],
    "suvavatthāpita": ['cped'],
    "suvayas": ['mw'],
    "suvaśa": ['mw'],
    "suvaśya": ['mw'],
    "suvaṃśa": ['mw'],
    "suvaṃśaghoṣa": ['mw'],
    "suvaṃśekṣu": ['mw'],
    "suvaṇṇa": ['cped'],
    "suvaṇṇabhiṅkāra": ['cped'],
    "suvaṇṇadaṇḍa": ['cped'],
    "suvaṇṇagabbha": ['cped'],
    "suvaṇṇaguhā": ['cped'],
    "suvaṇṇahaṁsa": ['cped'],
    "suvaṇṇakaṭāha": ['cped'],
    "suvaṇṇakāra": ['cped'],
    "suvaṇṇamaya": ['cped'],
    "suvaṇṇapaṭṭa": ['cped'],
    "suvaṇṇapīṭhaka": ['cped'],
    "suvaṇṇavaṇṇa": ['cped'],
    "suvaṇṇin": ['bhs'],
    "suve": ['bhs', 'cped'],
    "suveda": ['cae', 'gra', 'mw'],
    "suvedana": ['cae', 'gra', 'mw'],
    "suvedas": ['mw'],
    "suvedha": ['bhs'],
    "suvega": ['mw'],
    "suvegin": ['mw'],
    "suvegā": ['mw'],
    "suvela": ['cae', 'mw'],
    "suvema": ['cae', 'mw'],
    "suvena": ['cae', 'gra', 'mw'],
    "suvetanā": ['bhs'],
    "suvetasa": ['mw'],
    "suveśa": ['mw'],
    "suveṇa": ['mw'],
    "suveṇā": ['mw'],
    "suveṣa": ['cae', 'mw'],
    "suveṣadhara": ['mw'],
    "suveṣanilaya": ['cae'],
    "suveṣatā": ['mw'],
    "suveṣavat": ['mw'],
    "suveṣin": ['mw'],
    "suvibhakta": ['bhs', 'cae', 'mw'],
    "suvibhaktagātra": ['mw'],
    "suvibhaktatā": ['mw'],
    "suvibhaktavatī": ['bhs'],
    "suvibhaktānavadyāṅgī": ['mw'],
    "suvibhaktāṅgapratyaṅgatā": ['mw'],
    "suvibhatta": ['cped'],
    "suvibhoka": ['mw'],
    "suvibhu": ['mw'],
    "suvibhāta": ['mw'],
    "suvibhīṣaṇa": ['mw'],
    "suvibhūṣita": ['mw'],
    "suvicakṣaṇa": ['mw'],
    "suvicakṣaṇagātra": ['bhs'],
    "suvicintitārtha": ['bhs'],
    "suvicita": ['mw'],
    "suvicitra": ['bhs'],
    "suvicāra": ['mw'],
    "suvicārita": ['mw'],
    "suvicārya": ['mw'],
    "suvicāryakārin": ['mw'],
    "suvid": ['gra', 'mw'],
    "suvida": ['mw'],
    "suvidagdha": ['cae', 'mw'],
    "suvidalla": ['mw'],
    "suvidallā": ['mw'],
    "suvidarbha": ['mw'],
    "suvidat": ['mw'],
    "suvidatra": ['cae', 'gra', 'mw'],
    "suvidatriya": ['cae', 'gra', 'mw'],
    "suviddha": ['mw'],
    "suvidha": ['cae', 'mw'],
    "suvidham": ['mw'],
    "suvidhi": ['cae', 'mw'],
    "suvidhāna": ['mw'],
    "suvidhānatas": ['mw'],
    "suvidita": ['cae', 'mw'],
    "suvidvas": ['gra', 'mw'],
    "suvidvaṃs": ['cae'],
    "suvidyut": ['mw'],
    "suvidyā": ['cae', 'mw'],
    "suvidīrṇa": ['mw'],
    "suvigraha": ['cae', 'mw'],
    "suviguṇa": ['mw'],
    "suvihita": ['cae', 'mw'],
    "suvihitaprayoga": ['cae'],
    "suvihitaprayogatā": ['mw'],
    "suvihvala": ['mw'],
    "suvijñeya": ['cae', 'mw'],
    "suvijñāna": ['cae', 'gra', 'mw'],
    "suvijñāpaka": ['mw'],
    "suvijāna": ['cped'],
    "suvijātinā": ['bhs'],
    "suvijṛmbhita": ['bhs'],
    "suvikalpāṅga": ['bhs'],
    "suviklava": ['mw'],
    "suvikrama": ['mw'],
    "suvikrāmin": ['bhs'],
    "suvikrānta": ['bhs', 'mw'],
    "suvikrāntavikramaṇaparipṛcchā": ['mw'],
    "suvikrāntavikramin": ['mw'],
    "suvikrāntavikrāmin": ['bhs', 'mw'],
    "suvikrāntaśrī": ['bhs'],
    "suvilaya": ['mw'],
    "suvilitta": ['cped'],
    "suvilokitajñānaketu": ['bhs'],
    "suvilokitanetra": ['bhs'],
    "suvimala": ['mw'],
    "suvimaladatta": ['bhs'],
    "suvimhita": ['cped'],
    "suvimuc": ['mw'],
    "suvimāna": ['bhs'],
    "suvinaya": ['mw'],
    "suvinaṣṭa": ['mw'],
    "suvineya": ['mw'],
    "suvinirmala": ['mw'],
    "suviniścaya": ['mw'],
    "suviniścita": ['mw'],
    "suvinyasta": ['mw'],
    "suvinīta": ['mw'],
    "suvinītā": ['mw'],
    "suvipina": ['mw'],
    "suvipra": ['gra', 'mw'],
    "suvipula": ['cae', 'mw'],
    "suviraja": ['mw'],
    "suvirūḍha": ['cae', 'mw'],
    "suvisada": ['cped'],
    "suvismaya": ['mw'],
    "suvismita": ['mw'],
    "suvispaṣṭa": ['mw'],
    "suvistara": ['cae', 'mw'],
    "suvistaram": ['mw'],
    "suvistīrṇa": ['mw'],
    "suvistīrṇam": ['mw'],
    "suvita": ['cae', 'ddsa', 'gra', 'mw'],
    "suvitala": ['mw'],
    "suvitata": ['mw'],
    "suvitta": ['cae', 'ddsa', 'mw'],
    "suvitti": ['mw'],
    "suvivaktṛ": ['mw'],
    "suvivartita": ['mw'],
    "suvivikta": ['mw'],
    "suvivṛt": ['mw'],
    "suvivṛta": ['gra', 'mw'],
    "suviññāpaya": ['cped'],
    "suviśada": ['mw'],
    "suviśiṣṭa": ['mw'],
    "suviśodhaka": ['bhs', 'mw'],
    "suviśrabdha": ['cae', 'mw'],
    "suviśrabdham": ['mw'],
    "suviśuddha": ['bhs', 'mw'],
    "suviśuddhacandrābhā": ['bhs'],
    "suviśuddhadharmadhātujñāna": ['bhs'],
    "suviśuddhajñānakusumāvabhāsa": ['bhs'],
    "suviśuddhā": ['bhs'],
    "suviśvasta": ['mw'],
    "suviśākha": ['bhs'],
    "suviśāla": ['mw'],
    "suviśālā": ['mw'],
    "suviśālākṣa": ['mw'],
    "suviśārada": ['mw'],
    "suviṣaṇṇa": ['mw'],
    "suviṣāṇa": ['mw'],
    "suviṣṇu": ['mw'],
    "suviṣṭambhin": ['mw'],
    "suviṣṭhita": ['mw'],
    "suvrata": ['bhs', 'cae', 'gra', 'mw'],
    "suvratadatta": ['mw'],
    "suvratasvara": ['mw'],
    "suvratā": ['mw'],
    "suvuṭṭhika": ['cped'],
    "suvyakta": ['cae', 'mw'],
    "suvyaktam": ['mw'],
    "suvyapadeśakṣema": ['bhs'],
    "suvyasta": ['mw'],
    "suvyavasthita": ['mw'],
    "suvyuṣṭa": ['mw'],
    "suvyāhṛta": ['mw'],
    "suvyākhyāta": ['mw'],
    "suvyākṛtā": ['bhs'],
    "suvyūhamukhā": ['bhs', 'mw'],
    "suvyūhā": ['bhs', 'mw'],
    "suvāc": ['cae', 'gra', 'mw'],
    "suvācas": ['cae', 'gra', 'mw'],
    "suvācya": ['mw'],
    "suvāditra": ['mw'],
    "suvāgmin": ['mw'],
    "suvāha": ['mw'],
    "suvāhana": ['mw'],
    "suvājin": ['mw'],
    "suvājivāpu": ['mw'],
    "suvākya": ['mw'],
    "suvāla": ['mw'],
    "suvāladhi": ['mw'],
    "suvāladhikhura": ['mw'],
    "suvālukā": ['mw'],
    "suvāmā": ['mw'],
    "suvānta": ['cae', 'mw'],
    "suvār": ['mw'],
    "suvārttā": ['mw'],
    "suvāsa": ['mw'],
    "suvāsaka": ['mw'],
    "suvāsakumāra": ['mw'],
    "suvāsakumāraka": ['mw'],
    "suvāsana": ['mw'],
    "suvāsarā": ['mw'],
    "suvāsas": ['cae', 'gra', 'mw'],
    "suvāsin": ['mw'],
    "suvāsinī": ['cae', 'mw'],
    "suvāsita": ['mw'],
    "suvāstu": ['cae', 'gra', 'mw'],
    "suvāstuka": ['mw'],
    "suvāsu": ['bhs'],
    "suvātra": ['mw'],
    "suvātā": ['mw'],
    "suvāṇa": ['cped'],
    "suvāṇadoṇi": ['cped'],
    "suvīra": ['cae', 'gra', 'mw'],
    "suvīraja": ['mw'],
    "suvīraka": ['mw'],
    "suvīratā": ['mw'],
    "suvīria": ['gra'],
    "suvīrya": ['cae', 'gra', 'mw'],
    "suvīryā": ['mw'],
    "suvīrā": ['bhs'],
    "suvīrāmla": ['mw'],
    "suvīthīpatha": ['mw'],
    "suvṛddha": ['mw'],
    "suvṛdh": ['cae', 'gra', 'mw'],
    "suvṛdha": ['mw'],
    "suvṛjana": ['gra', 'mw'],
    "suvṛkti": ['cae', 'gra', 'mw'],
    "suvṛkṣa": ['cae', 'mw'],
    "suvṛt": ['cae', 'gra', 'mw'],
    "suvṛtta": ['cae', 'mw'],
    "suvṛttatilaka": ['mw'],
    "suvṛttatā": ['mw'],
    "suvṛtti": ['cae', 'mw'],
    "suvṛttā": ['mw'],
    "suvṛśc": ['mw'],
    "suvṛṣa": ['bhs'],
    "suvṛṣabha": ['mw'],
    "suvṛṣalīka": ['mw'],
    "suvṛṣṭa": ['cae', 'mw'],
    "suvṛṣṭi": ['mw'],
    "suyabhyā": ['mw'],
    "suyaj": ['cae', 'gra', 'mw'],
    "suyajus": ['mw'],
    "suyajña": ['cae', 'ddsa', 'gra', 'mw'],
    "suyajñā": ['mw'],
    "suyakṣa": ['bhs'],
    "suyama": ['cae', 'gra', 'mw'],
    "suyamā": ['mw'],
    "suyantrita": ['cae', 'mw'],
    "suyantritatva": ['mw'],
    "suyantu": ['cae', 'gra', 'mw'],
    "suyata": ['cae', 'gra', 'mw'],
    "suyatātmavat": ['mw'],
    "suyavasa": ['cae', 'mw'],
    "suyavase": ['mw'],
    "suyavasin": ['mw'],
    "suyavasodaka": ['mw'],
    "suyavasu": ['mw'],
    "suyavasyu": ['mw'],
    "suyavasād": ['mw'],
    "suyaśa": ['mw'],
    "suyaśas": ['cae', 'gra', 'mw'],
    "suyaśā": ['mw'],
    "suyaṣṭavya": ['mw'],
    "suyiṭṭha": ['cped'],
    "suyodhana": ['bhs', 'cae', 'mw'],
    "suyoga": ['mw'],
    "suyojita": ['mw'],
    "suyuddha": ['cae', 'mw'],
    "suyuj": ['cae', 'gra', 'mw'],
    "suyuk": ['mw'],
    "suyukta": ['gra', 'mw'],
    "suyukti": ['mw'],
    "suyuta": ['mw'],
    "suyutta": ['bhs', 'cped'],
    "suyya": ['ddsa', 'mw'],
    "suyyati": ['cped'],
    "suyyā": ['mw'],
    "suyyābhidhāna": ['mw'],
    "suyyākuṇḍala": ['mw'],
    "suyyāsetu": ['mw'],
    "suyāma": ['bhs', 'cae', 'gra', 'mw'],
    "suyāman": ['mw'],
    "suyāmuna": ['mw'],
    "suyāti": ['mw'],
    "suyāśu": ['gra', 'mw'],
    "suñña": ['cped'],
    "suññagāma": ['cped'],
    "suññagāra": ['cped'],
    "suññatā": ['cped'],
    "suābhū": ['gra'],
    "suādhī": ['gra'],
    "suāhuta": ['gra'],
    "suāpi": ['gra'],
    "suās": ['gra'],
    "suāsastha": ['gra'],
    "suātata": ['gra'],
    "suāvasu": ['gra'],
    "suāveśa": ['gra'],
    "suāyasa": ['gra'],
    "suāyudha": ['gra'],
    "suāyuj": ['gra'],
    "suāśis": ['gra'],
    "suāśita": ['gra'],
    "suśabda": ['cae', 'mw'],
    "suśabdatā": ['mw'],
    "suśaka": ['gra', 'mw'],
    "suśakta": ['mw'],
    "suśakti": ['gra', 'mw'],
    "suśakuna": ['mw'],
    "suśalya": ['mw'],
    "suśama": ['mw'],
    "suśami": ['cae', 'mw'],
    "suśamī": ['cae', 'gra', 'mw'],
    "suśaphagatimukha": ['mw'],
    "suśara": ['mw'],
    "suśaraṇa": ['cae', 'gra', 'mw'],
    "suśaraṇya": ['mw'],
    "suśarmacandra": ['mw'],
    "suśarman": ['cae', 'gra', 'mw'],
    "suśarmannagara": ['mw'],
    "suśarmanpura": ['mw'],
    "suśarīra": ['mw'],
    "suśasta": ['mw'],
    "suśasti": ['cae', 'gra', 'mw'],
    "suśaurya": ['bhs'],
    "suśavī": ['mw'],
    "suśaṃsa": ['cae', 'gra', 'mw'],
    "suśaṃsin": ['cae', 'mw'],
    "suśaṭha": ['mw'],
    "suścandra": ['cae', 'gra', 'mw'],
    "suśeru": ['mw'],
    "suśeva": ['cae', 'gra', 'mw'],
    "suśevas": ['cae', 'mw'],
    "suśevia": ['gra'],
    "suśevya": ['gra', 'mw'],
    "suśikha": ['mw'],
    "suśikhā": ['mw'],
    "suśikhāsamūha": ['mw'],
    "suśikman": ['mw'],
    "suśikṣita": ['cae', 'mw'],
    "suśila": ['bhs'],
    "suśilpa": ['gra', 'mw'],
    "suśimbikā": ['mw'],
    "suśipra": ['cae', 'gra', 'mw'],
    "suśiprin": ['mw'],
    "suśiras": ['mw'],
    "suśithila": ['mw'],
    "suśithilīkṛta": ['mw'],
    "suśiśvi": ['cae', 'gra', 'mw'],
    "suśiṣya": ['cae', 'mw'],
    "suśiṣṭa": ['mw'],
    "suśiṣṭi": ['cae', 'gra', 'mw'],
    "suślakṣṇa": ['cae', 'mw'],
    "suślakṣṇam": ['mw'],
    "suśleṣa": ['mw'],
    "suśliṣṭa": ['cae', 'mw'],
    "suśliṣṭaguṇa": ['mw'],
    "suśliṣṭaguṇatā": ['mw'],
    "suśliṣṭasaṃdhi": ['mw'],
    "suśliṣṭasaṃdhitā": ['mw'],
    "suśloka": ['cae', 'mw'],
    "suślokya": ['cae', 'mw'],
    "suśobhamāna": ['mw'],
    "suśobhana": ['bhs', 'mw'],
    "suśobhanaka": ['bhs'],
    "suśobhita": ['mw'],
    "suśodhita": ['mw'],
    "suśoka": ['gra', 'mw'],
    "suśopha": ['mw'],
    "suśoṇa": ['mw'],
    "suśoṣita": ['mw'],
    "suśrama": ['mw'],
    "suśrapa": ['mw'],
    "suśrava": ['mw'],
    "suśravas": ['cae', 'gra', 'mw'],
    "suśravasyā": ['gra', 'mw'],
    "suśravomantra": ['mw'],
    "suśravā": ['mw'],
    "suśrotu": ['cae', 'gra', 'mw'],
    "suśroṇi": ['cae', 'mw'],
    "suśroṇā": ['mw'],
    "suśroṇī": ['mw'],
    "suśruk": ['mw'],
    "suśrut": ['cae', 'gra', 'mw'],
    "suśruta": ['cae', 'gra', 'mw'],
    "suśrutapāṭhaśuddhi": ['mw'],
    "suśrutasaṃhitā": ['mw'],
    "suśrutasāra": ['mw'],
    "suśruti": ['cae', 'mw'],
    "suśruṇa": ['gra', 'mw'],
    "suśrānta": ['mw'],
    "suśrāta": ['gra', 'mw'],
    "suśrī": ['cae', 'gra', 'mw'],
    "suśrīka": ['cae', 'mw'],
    "suśrīkā": ['mw'],
    "suśubha": ['mw'],
    "suśuddha": ['mw'],
    "suśukla": ['mw'],
    "suśukvan": ['cae', 'gra', 'mw'],
    "suśukvani": ['cae', 'mw'],
    "suśva": ['mw'],
    "suśāka": ['mw'],
    "suśākaka": ['mw'],
    "suśānta": ['bhs', 'cae', 'mw'],
    "suśānti": ['mw'],
    "suśāntā": ['mw'],
    "suśārada": ['mw'],
    "suśāsana": ['mw'],
    "suśāsita": ['mw'],
    "suśāsya": ['mw'],
    "suśīghra": ['mw'],
    "suśīghraga": ['mw'],
    "suśīghram": ['mw'],
    "suśīla": ['bhs', 'cae', 'mw'],
    "suśīlaguṇavat": ['mw'],
    "suśīlatva": ['mw'],
    "suśīlatā": ['mw'],
    "suśīlavant": ['cae'],
    "suśīlavat": ['mw'],
    "suśīlin": ['cae', 'mw'],
    "suśīlā": ['mw'],
    "suśīlāntaka": ['mw'],
    "suśīma": ['mw'],
    "suśīmakāma": ['mw'],
    "suśīta": ['cae', 'mw'],
    "suśītala": ['cae', 'mw'],
    "suśītā": ['mw'],
    "suśīvikā": ['mw'],
    "suśūlinīdaṇḍaka": ['mw'],
    "suśṛta": ['mw'],
    "suśṛṅga": ['mw'],
    "suśṛṅgāra": ['mw'],
    "suūti": ['cae', 'gra', 'mw'],
    "suḍaśabdanṛtya": ['mw'],
    "suḍīnaka": ['mw'],
    "suṃdara": ['ap90'],
    "suṃdaḥ": ['ap90'],
    "suṅghāta": ['cped'],
    "suṅka": ['cped'],
    "suṅkaṭṭhāna": ['cped'],
    "suṅkika": ['cped'],
    "suṇa": ['cped'],
    "suṇamāna": ['cped'],
    "suṇanta": ['cped'],
    "suṇhā": ['cped'],
    "suṇi": ['cped'],
    "suṇisā": ['cped'],
    "suṇitabba": ['cped'],
    "suṇituṁ": ['cped'],
    "suṇitvā": ['cped'],
    "suṇāti": ['cped'],
    "suṇḍika": ['bhs'],
    "suṣad": ['mw'],
    "suṣada": ['cae', 'gra', 'mw'],
    "suṣadman": ['mw'],
    "suṣaha": ['cae', 'gra', 'mw'],
    "suṣakhi": ['cae', 'gra', 'mw'],
    "suṣama": ['ap90', 'cae', 'mw'],
    "suṣamaduḥṣamā": ['mw'],
    "suṣamiddha": ['mw'],
    "suṣamidh": ['gra', 'mw'],
    "suṣamā": ['mw'],
    "suṣamī": ['mw'],
    "suṣavya": ['gra', 'mw'],
    "suṣavī": ['ap90', 'mw'],
    "suṣaṃdhi": ['mw'],
    "suṣaṃsad": ['ddsa', 'gra', 'mw'],
    "suṣaṇa": ['cae', 'gra', 'mw'],
    "suṣaṇana": ['cae', 'gra', 'mw'],
    "suṣecana": ['gra', 'mw'],
    "suṣedha": ['mw'],
    "suṣeka": ['gra', 'mw'],
    "suṣeṇa": ['bhs', 'cae', 'mw'],
    "suṣeṇaḥ": ['ap90'],
    "suṣeṇikā": ['mw'],
    "suṣeṇā": ['mw'],
    "suṣeṇī": ['mw'],
    "suṣi": ['mw'],
    "suṣika": ['mw'],
    "suṣikta": ['mw'],
    "suṣilīkā": ['mw'],
    "suṣima": ['ap90', 'mw'],
    "suṣinandi": ['mw'],
    "suṣira": ['ap90', 'cae', 'gra', 'mw'],
    "suṣiraccheda": ['mw'],
    "suṣiratva": ['mw'],
    "suṣiratā": ['cae', 'mw'],
    "suṣiravat": ['mw'],
    "suṣiravivara": ['mw'],
    "suṣiravivarin": ['mw'],
    "suṣirā": ['mw'],
    "suṣita": ['mw'],
    "suṣiḥ": ['ap90'],
    "suṣkanta": ['mw'],
    "suṣma": ['mw'],
    "suṣmanta": ['mw'],
    "suṣmaṃ": ['ap90'],
    "suṣoma": ['cae', 'gra', 'mw'],
    "suṣomā": ['mw'],
    "suṣui": ['gra'],
    "suṣumat": ['ddsa', 'gra', 'mw'],
    "suṣumna": ['gra', 'mw'],
    "suṣumnā": ['mw'],
    "suṣumṇa": ['cae', 'ddsa', 'mw'],
    "suṣumṇaḥ": ['ap90'],
    "suṣumṇā": ['mw'],
    "suṣupsu": ['cae', 'mw'],
    "suṣupsā": ['cae', 'ddsa', 'mw'],
    "suṣupta": ['cae', 'mw'],
    "suṣupti": ['cae', 'mw'],
    "suṣuptivat": ['mw'],
    "suṣuptiḥ": ['ap90'],
    "suṣupvas": ['mw'],
    "suṣupāṇa": ['mw'],
    "suṣut": ['mw'],
    "suṣuta": ['cae', 'gra', 'mw'],
    "suṣuti": ['cae', 'gra', 'mw'],
    "suṣuvāṇa": ['mw'],
    "suṣvay": ['cae', 'gra'],
    "suṣvaya": ['ddsa', 'mw'],
    "suṣvi": ['cae', 'ddsa', 'gra', 'mw'],
    "suṣvāṇa": ['mw'],
    "suṣā": ['cae', 'gra', 'mw'],
    "suṣāha": ['gra', 'mw'],
    "suṣāman": ['gra', 'mw'],
    "suṣārathi": ['cae', 'gra', 'mw'],
    "suṣāḍha": ['mw'],
    "suṣāḍhaḥ": ['ap90'],
    "suṣīma": ['ap90', 'mw'],
    "suṣū": ['cae', 'gra', 'mw'],
    "suṣūma": ['gra'],
    "suṣūmā": ['cae', 'mw'],
    "suṣūta": ['gra', 'mw'],
    "suṣūti": ['mw'],
    "suṣūya": ['mw'],
    "suṣṭarīman": ['mw'],
    "suṣṭhita": ['mw'],
    "suṣṭhu": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "suṣṭhudvāra": ['mw'],
    "suṣṭhutaram": ['mw'],
    "suṣṭhutā": ['bhs', 'mw'],
    "suṣṭhuvah": ['gra', 'mw'],
    "suṣṭhuvāh": ['gra', 'mw'],
    "suṣṭhāman": ['gra', 'mw'],
    "suṣṭhāna": ['gra', 'mw'],
    "suṣṭu": ['cae', 'gra', 'mw'],
    "suṣṭubh": ['cae', 'gra', 'mw'],
    "suṣṭuta": ['cae', 'gra', 'mw'],
    "suṣṭuti": ['cae', 'gra', 'mw'],
    "suṭ": ['ap90', 'mw'],
    "suṭaṅka": ['mw'],
    "suṭṭ": ['ap90', 'mw'],
    "suṭṭhu": ['cped'],
    "suṭṭhutā": ['cped'],
    "sva": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "svabalāśraya": ['mw'],
    "svabandhu": ['cae', 'mw'],
    "svabandhupaddhati": ['mw'],
    "svabdin": ['gra', 'mw'],
    "svabhadrā": ['mw'],
    "svabhakṣa": ['mw'],
    "svabhavas": ['mw'],
    "svabhaṭa": ['mw'],
    "svabhigūrta": ['mw'],
    "svabhirāma": ['mw'],
    "svabhiṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "svabhiṣṭisumna": ['gra', 'mw'],
    "svabhyagra": ['mw'],
    "svabhyakta": ['cae', 'mw'],
    "svabhyasa": ['mw'],
    "svabhyasta": ['mw'],
    "svabhājana": ['mw'],
    "svabhānu": ['cae', 'gra', 'mw'],
    "svabhāsībhavati": ['bhs'],
    "svabhāva": ['bhs', 'cae', 'ddsa', 'mw'],
    "svabhāvabhāva": ['mw'],
    "svabhāvadaurjanya": ['mw'],
    "svabhāvadveṣa": ['mw'],
    "svabhāvaja": ['cae', 'mw'],
    "svabhāvajanita": ['mw'],
    "svabhāvaka": ['bhs'],
    "svabhāvakṛpaṇa": ['mw'],
    "svabhāvakṛta": ['mw'],
    "svabhāvaprabhava": ['mw'],
    "svabhāvasiddha": ['mw'],
    "svabhāvatas": ['mw'],
    "svabhāvatva": ['mw'],
    "svabhāvatā": ['mw'],
    "svabhāvavāda": ['mw'],
    "svabhāvavādin": ['mw'],
    "svabhāvaśūra": ['mw'],
    "svabhāvikī": ['mw'],
    "svabhāvokta": ['cae', 'mw'],
    "svabhāvokti": ['mw'],
    "svabhāvonnatabhāva": ['mw'],
    "svabhāvonnatabhāvatva": ['mw'],
    "svabhāvārthadīpikā": ['mw'],
    "svabhāṣita": ['mw'],
    "svabhīśu": ['cae', 'gra', 'mw'],
    "svabhū": ['cae', 'ddsa', 'mw'],
    "svabhūmi": ['cae', 'mw'],
    "svabhūta": ['mw'],
    "svabhūti": ['cae', 'gra', 'mw'],
    "svabhūtiojas": ['gra'],
    "svabhūtyojas": ['gra', 'mw'],
    "svabhūtyāga": ['mw'],
    "svabrāhmaṇyā": ['mw'],
    "svabāhu": ['mw'],
    "svabāhubala": ['mw'],
    "svabāndhava": ['mw'],
    "svabīja": ['mw'],
    "svac": ['gra'],
    "svacakṣus": ['cae', 'mw'],
    "svacara": ['mw'],
    "svacaraṇaparṣad": ['mw'],
    "svacaryā": ['mw'],
    "svaccha": ['ap90', 'cae', 'ddsa', 'mw'],
    "svacchabhāva": ['mw'],
    "svacchadhātuka": ['mw'],
    "svacchadravya": ['mw'],
    "svacchaka": ['mw'],
    "svacchamaṇi": ['mw'],
    "svacchanda": ['cae', 'ddsa', 'mw'],
    "svacchandabhairava": ['mw'],
    "svacchandabhairavarasa": ['mw'],
    "svacchandabhaṭṭārakabṛhatpūjāpattrikāvidhi": ['mw'],
    "svacchandacara": ['mw'],
    "svacchandacāra": ['cae'],
    "svacchandacārin": ['cae', 'mw'],
    "svacchandacāriṇī": ['mw'],
    "svacchandaka": ['mw'],
    "svacchandam": ['mw'],
    "svacchandamaraṇa": ['mw'],
    "svacchandamṛtyuka": ['mw'],
    "svacchandanaya": ['mw'],
    "svacchandanāyaka": ['mw'],
    "svacchandapaddhati": ['mw'],
    "svacchandasaṃgraha": ['mw'],
    "svacchandasārasaṃgraha": ['mw'],
    "svacchandatantra": ['mw'],
    "svacchandatantrarāja": ['mw'],
    "svacchandatas": ['mw'],
    "svacchandatā": ['mw'],
    "svacchandavanajāta": ['cae', 'mw'],
    "svacchandaśāktāgama": ['mw'],
    "svacchandoddyota": ['mw'],
    "svacchapattra": ['mw'],
    "svacchatva": ['mw'],
    "svacchatā": ['mw'],
    "svacchavāluka": ['mw'],
    "svacchikā": ['mw'],
    "svacchā": ['mw'],
    "svacetas": ['cae', 'ddsa', 'mw'],
    "svad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svadana": ['mw'],
    "svadanaṃ": ['ap90'],
    "svadayitṛ": ['mw'],
    "svadehadāna": ['mw'],
    "svadeśa": ['cae', 'ddsa', 'mw'],
    "svadeśabandhu": ['mw'],
    "svadeśaja": ['mw'],
    "svadeśamadhyaparidhi": ['mw'],
    "svadeśaparidhi": ['mw'],
    "svadeśasmārin": ['mw'],
    "svadhainava": ['gra'],
    "svadhana": ['cae'],
    "svadharma": ['cae', 'mw'],
    "svadharmacyuta": ['mw'],
    "svadharman": ['cae', 'gra', 'mw'],
    "svadharmaskhalana": ['mw'],
    "svadharmastha": ['mw'],
    "svadharmatyāga": ['mw'],
    "svadharmavartin": ['mw'],
    "svadharmavartitva": ['mw'],
    "svadharmācaraṇa": ['mw'],
    "svadharmādhvabodha": ['mw'],
    "svadharmānapaga": ['mw'],
    "svadharmārthaviniścaya": ['mw'],
    "svadhaya": ['mw'],
    "svadhenava": ['mw'],
    "svadhicaraṇa": ['mw'],
    "svadhita": ['cae', 'mw'],
    "svadhiti": ['cae', 'ddsa', 'gra', 'mw'],
    "svadhitihetika": ['mw'],
    "svadhitiḥ": ['ap90'],
    "svadhitīvant": ['cae'],
    "svadhitīvat": ['gra', 'mw'],
    "svadhiṣṭhita": ['ddsa', 'mw'],
    "svadhiṣṭhāna": ['mw'],
    "svadhur": ['mw'],
    "svadhvara": ['cae', 'ddsa', 'gra', 'mw'],
    "svadhvaryu": ['mw'],
    "svadhyakṣa": ['mw'],
    "svadhyavasāna": ['mw'],
    "svadhā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svadhābhuj": ['mw'],
    "svadhābhājin": ['mw'],
    "svadhādhipa": ['mw'],
    "svadhākara": ['cae', 'mw'],
    "svadhākāra": ['cae', 'mw'],
    "svadhāmahe": ['mw'],
    "svadhāman": ['mw'],
    "svadhāmaya": ['mw'],
    "svadhāmṛtamaya": ['mw'],
    "svadhāninayana": ['mw'],
    "svadhāninayanīya": ['mw'],
    "svadhāpati": ['gra', 'mw'],
    "svadhāpriya": ['mw'],
    "svadhāprāṇa": ['mw'],
    "svadhāvan": ['cae', 'gra', 'mw'],
    "svadhāvant": ['cae'],
    "svadhāvat": ['ddsa', 'gra', 'mw'],
    "svadhāvin": ['cae', 'mw'],
    "svadhāyin": ['mw'],
    "svadhāśana": ['mw'],
    "svadhīta": ['cae', 'mw'],
    "svadhīti": ['cae', 'mw'],
    "svadhṛti": ['ddsa', 'mw'],
    "svadita": ['ap90', 'cae', 'mw'],
    "svadiṅmukham": ['mw'],
    "svadoṣaja": ['mw'],
    "svaduhitṛ": ['mw'],
    "svadāna": ['mw'],
    "svadāra": ['mw'],
    "svadāragāmin": ['mw'],
    "svadāranirata": ['mw'],
    "svadāvan": ['gra', 'mw'],
    "svadṛś": ['mw'],
    "svadṛṣṭa": ['mw'],
    "svaetu": ['gra'],
    "svaga": ['mw'],
    "svagarbha": ['mw'],
    "svagata": ['cae', 'mw'],
    "svagatam": ['mw'],
    "svagati": ['mw'],
    "svagni": ['cae', 'ddsa', 'gra', 'mw'],
    "svagocara": ['mw'],
    "svagopa": ['gra', 'mw'],
    "svagraha": ['mw'],
    "svagrāma": ['ddsa', 'mw'],
    "svagupta": ['mw'],
    "svaguptā": ['mw'],
    "svaguṇa": ['cae', 'mw'],
    "svaguṇaprakāśaka": ['mw'],
    "svaguṇatas": ['mw'],
    "svaguṇaśākha": ['bhs'],
    "svagā": ['cae', 'mw'],
    "svagākartṛ": ['mw'],
    "svagākāra": ['mw'],
    "svagākṛ": ['mw'],
    "svagākṛta": ['mw'],
    "svagākṛti": ['mw'],
    "svagūrta": ['cae', 'gra', 'mw'],
    "svagṛha": ['cae', 'mw'],
    "svagṛhīta": ['mw'],
    "svahantṛ": ['mw'],
    "svaharaṇa": ['cae', 'ddsa', 'mw'],
    "svahasta": ['cae', 'mw'],
    "svahastagata": ['mw'],
    "svahastasvastikastanī": ['mw'],
    "svahastikā": ['cae', 'mw'],
    "svahastita": ['mw'],
    "svahastollikhita": ['mw'],
    "svahatavāsas": ['mw'],
    "svahetu": ['mw'],
    "svahita": ['cae', 'mw'],
    "svahitaiṣin": ['mw'],
    "svahotṛ": ['mw'],
    "svaira": ['ap90', 'cae', 'ddsa', 'mw'],
    "svairacārin": ['cae', 'mw'],
    "svairagati": ['cae', 'mw'],
    "svairakam": ['cae', 'mw'],
    "svairakathā": ['mw'],
    "svairam": ['mw'],
    "svairastha": ['mw'],
    "svairatha": ['mw'],
    "svairatā": ['ap90', 'mw'],
    "svairavartin": ['cae', 'mw'],
    "svairavihārin": ['mw'],
    "svairavṛtta": ['cae', 'mw'],
    "svairavṛtti": ['mw'],
    "svaireṇa": ['mw'],
    "svaireṣu": ['mw'],
    "svairi": ['mw'],
    "svairikarman": ['mw'],
    "svairin": ['ap90', 'cae', 'ddsa', 'mw'],
    "svairindhrī": ['mw'],
    "svairitā": ['mw'],
    "svairiṃdhrī": ['ap90'],
    "svairiṇī": ['ap90', 'mw'],
    "svairācāra": ['mw'],
    "svairāhāra": ['mw'],
    "svairālāpa": ['mw'],
    "svaitu": ['gra', 'mw'],
    "svaiṣa": ['cae', 'mw'],
    "svaj": ['cae', 'ddsa', 'gra', 'mw'],
    "svaja": ['cae', 'ddsa', 'gra', 'mw'],
    "svajana": ['cae', 'mw'],
    "svajanagandhin": ['mw'],
    "svajanatā": ['mw'],
    "svajanaya": ['mw'],
    "svajanman": ['cae', 'gra', 'mw'],
    "svajanāvṛta": ['mw'],
    "svajanāya": ['mw'],
    "svajenia": ['gra'],
    "svajenya": ['cae', 'gra', 'mw'],
    "svajita": ['cae', 'mw'],
    "svajñāti": ['cae', 'mw'],
    "svajā": ['cae', 'mw'],
    "svajāta": ['cae', 'mw'],
    "svajāti": ['cae', 'mw'],
    "svajātidviṣ": ['mw'],
    "svajātya": ['cae', 'mw'],
    "svajātīya": ['cae', 'mw'],
    "svaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "svakambalā": ['mw'],
    "svakampana": ['mw'],
    "svakaraṇa": ['ddsa', 'mw'],
    "svakarmaja": ['mw'],
    "svakarmakṛt": ['mw'],
    "svakarman": ['cae', 'mw'],
    "svakarmastha": ['cae', 'mw'],
    "svakarmavaśa": ['mw'],
    "svakarmin": ['mw'],
    "svakasvaka": ['mw'],
    "svaketu": ['mw'],
    "svakk": ['mw'],
    "svakta": ['mw'],
    "svakula": ['cae', 'ddsa', 'mw'],
    "svakulaja": ['mw'],
    "svakulakṣaya": ['mw'],
    "svakulya": ['mw'],
    "svakuśalamaya": ['cae', 'mw'],
    "svakuṭumba": ['mw'],
    "svakāla": ['cae', 'mw'],
    "svakāle": ['mw'],
    "svakāmin": ['cae', 'mw'],
    "svakārya": ['mw'],
    "svakāryasaha": ['mw'],
    "svakīrtimaya": ['mw'],
    "svakīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "svakīyā": ['mw'],
    "svakṛt": ['mw'],
    "svakṛta": ['cae', 'mw'],
    "svakṛtārtha": ['mw'],
    "svakṣa": ['cae', 'ddsa', 'mw'],
    "svakṣatra": ['cae', 'ddsa', 'gra', 'mw'],
    "sval": ['ap90'],
    "svaladā": ['mw'],
    "svalajjā": ['cae'],
    "svalakṣaṇa": ['ddsa', 'mw'],
    "svalakṣaṇamaṇḍita": ['bhs'],
    "svalakṣaṇaprakāśa": ['mw'],
    "svalakṣita": ['mw'],
    "svalaṃkṛt": ['mw'],
    "svalaṃkṛta": ['cae', 'mw'],
    "svalaṅkṛta": ['ddsa'],
    "svalikhita": ['mw'],
    "svaliṅga": ['mw'],
    "svalpa": ['ap90', 'cae', 'ddsa', 'mw'],
    "svalpabala": ['mw'],
    "svalpadehā": ['mw'],
    "svalpadrāvaka": ['mw'],
    "svalpaduḥkha": ['mw'],
    "svalpadṛś": ['mw'],
    "svalpajātaka": ['mw'],
    "svalpaka": ['ap90', 'cae', 'mw'],
    "svalpakaṅka": ['mw'],
    "svalpakesarin": ['mw'],
    "svalpakeśin": ['mw'],
    "svalpapattraka": ['mw'],
    "svalpaphalā": ['mw'],
    "svalpasmṛti": ['cae', 'mw'],
    "svalpatantra": ['mw'],
    "svalpatantratva": ['mw'],
    "svalpatara": ['mw'],
    "svalpatas": ['cae', 'mw'],
    "svalpavayas": ['cae', 'mw'],
    "svalpavittavat": ['mw'],
    "svalpaviṣaya": ['mw'],
    "svalpavrīḍa": ['mw'],
    "svalpavyaya": ['mw'],
    "svalpayātrā": ['mw'],
    "svalpaśarīra": ['mw'],
    "svalpaśilā": ['mw'],
    "svalpaśilāya": ['mw'],
    "svalpeccha": ['mw'],
    "svalpecchatā": ['mw'],
    "svalpiṣṭha": ['ap90'],
    "svalpāntara": ['mw'],
    "svalpāpahāra": ['mw'],
    "svalpātivistara": ['mw'],
    "svalpāyu": ['mw'],
    "svalpāyus": ['mw'],
    "svalpāṅguli": ['mw'],
    "svalpībhū": ['cae', 'ddsa', 'mw'],
    "svalpīyas": ['ap90', 'ddsa', 'mw'],
    "svalīna": ['mw'],
    "svam, suvar": ['ddsa'],
    "svamahiman": ['cae'],
    "svamanobodhavākya": ['mw'],
    "svamanīṣikā": ['mw'],
    "svamanīṣā": ['mw'],
    "svamat": ['mw'],
    "svameka": ['mw'],
    "svamekaḥ": ['ap90'],
    "svamārgamarmavivaraṇa": ['mw'],
    "svamātreṇa": ['mw'],
    "svamātṛtas": ['cae'],
    "svamāyā": ['mw'],
    "svamāṃsa": ['cae', 'mw'],
    "svan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svana": ['cae', 'ddsa', 'gra', 'mw'],
    "svanacakra": ['mw'],
    "svanadratha": ['gra', 'mw'],
    "svanagara": ['mw'],
    "svanas": ['cae', 'gra', 'mw'],
    "svanavant": ['cae'],
    "svanavat": ['mw'],
    "svanavekṣaṇīya": ['mw'],
    "svanaya": ['gra', 'mw'],
    "svanaḍuh": ['mw'],
    "svanaḥ": ['ap90'],
    "svani": ['gra', 'mw'],
    "svanika": ['ap90', 'mw'],
    "svanita": ['ap90', 'cae', 'mw'],
    "svanitāhvaya": ['mw'],
    "svaniḥ": ['ap90'],
    "svaniṣṭha": ['mw'],
    "svaniṣṭhatva": ['mw'],
    "svanna": ['mw'],
    "svanotsāha": ['mw'],
    "svanta": ['cae', 'mw'],
    "svanugupta": ['cae', 'mw'],
    "svanujā": ['mw'],
    "svanurakta": ['mw'],
    "svanurūpa": ['mw'],
    "svanuṣṭhita": ['cae', 'mw'],
    "svanābhaka": ['mw'],
    "svanābhya": ['mw'],
    "svanāman": ['ddsa', 'mw'],
    "svanāmāṅka": ['mw'],
    "svanāśa": ['mw'],
    "svanīka": ['cae', 'ddsa', 'gra', 'mw'],
    "svap": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svapada": ['cae', 'ddsa', 'mw'],
    "svapakṣa": ['cae', 'ddsa', 'mw'],
    "svapakṣīya": ['mw'],
    "svapana": ['cae', 'ddsa', 'mw'],
    "svapanaṃ": ['ap90'],
    "svapanīya": ['mw'],
    "svaparamaṇḍala": ['mw'],
    "svaparapratāraka": ['ddsa', 'mw'],
    "svaparāddha": ['mw'],
    "svaparāhle": ['ddsa'],
    "svaparāhṇe": ['cae'],
    "svapas": ['cae', 'ddsa', 'gra', 'mw'],
    "svapasy": ['cae', 'gra'],
    "svapasya": ['cae', 'ddsa', 'mw'],
    "svapasyā": ['cae', 'ddsa', 'gra', 'mw'],
    "svapati": ['gra', 'mw'],
    "svapatibhrāntimatī": ['mw'],
    "svapatita": ['mw'],
    "svapatya": ['cae', 'ddsa', 'gra', 'mw'],
    "svapatīkṛ": ['mw'],
    "svapañcaka": ['mw'],
    "svapaṇa": ['mw'],
    "svapitṛ": ['ddsa', 'mw'],
    "svapivāta": ['cae', 'ddsa', 'gra', 'mw'],
    "svapiś": ['mw'],
    "svapiṇḍā": ['mw'],
    "svapna": ['cae', 'ddsa', 'gra', 'mw'],
    "svapnabhāj": ['cae', 'mw'],
    "svapnacintāmaṇi": ['mw'],
    "svapnadarśana": ['mw'],
    "svapnadhīgamya": ['cae', 'mw'],
    "svapnadoṣa": ['mw'],
    "svapnadṛś": ['mw'],
    "svapnagata": ['mw'],
    "svapnagiri": ['mw'],
    "svapnagṛha": ['mw'],
    "svapnaj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svapnaja": ['cae', 'ddsa', 'mw'],
    "svapnajñāna": ['mw'],
    "svapnakalpa": ['mw'],
    "svapnakāma": ['mw'],
    "svapnakṛt": ['mw'],
    "svapnalabdha": ['cae', 'mw'],
    "svapnamantrapaṭala": ['mw'],
    "svapnamukhā": ['mw'],
    "svapnamāṇava": ['mw'],
    "svapnamāṇavaka": ['mw'],
    "svapnanaṃśana": ['gra', 'mw'],
    "svapnanidarśana": ['mw'],
    "svapnanidarśanīya": ['mw'],
    "svapnaniketana": ['mw'],
    "svapnaparyantam": ['mw'],
    "svapnaparīkṣā": ['mw'],
    "svapnaphalādhyāya": ['mw'],
    "svapnaphalāphala": ['mw'],
    "svapnaprakaraṇa": ['mw'],
    "svapnaprapañca": ['mw'],
    "svapnas": ['cae', 'ddsa', 'gra', 'mw'],
    "svapnasaṃdarśana": ['cae', 'mw'],
    "svapnasthāna": ['ddsa', 'mw'],
    "svapnasṛṣṭi": ['mw'],
    "svapnatandritā": ['mw'],
    "svapnavat": ['mw'],
    "svapnavicārin": ['mw'],
    "svapnavidhi": ['mw'],
    "svapnavikāra": ['mw'],
    "svapnavinaśvara": ['mw'],
    "svapnaviparyaya": ['mw'],
    "svapnavārāhīkalpa": ['mw'],
    "svapnavāsavadattānāṭaka": ['mw'],
    "svapnavṛtta": ['cae', 'mw'],
    "svapnayā": ['cae', 'mw'],
    "svapnaśīla": ['mw'],
    "svapnaḥ": ['ap90'],
    "svapneduḥṣvapnya": ['mw'],
    "svapneśvara": ['mw'],
    "svapnia": ['gra'],
    "svapnopabhoga": ['mw'],
    "svapnopama": ['mw'],
    "svapnya": ['cae', 'gra', 'mw'],
    "svapnyayā": ['mw'],
    "svapnābhikaraṇa": ['mw'],
    "svapnādeśa": ['mw'],
    "svapnādhyāya": ['bhs', 'ddsa', 'mw'],
    "svapnādhyāyavid": ['mw'],
    "svapnālu": ['mw'],
    "svapnānayanamantra": ['mw'],
    "svapnānta": ['cae', 'mw'],
    "svapnāntalokamuni": ['bhs'],
    "svapnāntara": ['mw'],
    "svapnāntaragata": ['mw'],
    "svapnāntika": ['mw'],
    "svapnāvasthā": ['mw'],
    "svapnāy": ['cae'],
    "svapnāya": ['ddsa', 'mw'],
    "svapoṣam": ['mw'],
    "svaprabhutayā": ['mw'],
    "svaprabhutā": ['mw'],
    "svaprabhā": ['mw'],
    "svapradhāna": ['cae', 'mw'],
    "svapradhānatā": ['mw'],
    "svaprakāśa": ['ddsa', 'mw'],
    "svaprakāśajñānavādārtha": ['mw'],
    "svaprakāśapradīpikā": ['mw'],
    "svaprakāśarahasya": ['mw'],
    "svaprakāśatva": ['mw'],
    "svaprakāśatāvicāra": ['mw'],
    "svaprakāśavādārtha": ['mw'],
    "svapramāṇānurūpa": ['mw'],
    "svaprasāra": ['mw'],
    "svapratikara": ['mw'],
    "svapratinidhi": ['mw'],
    "svapratinidhitvena": ['mw'],
    "svapratiṣṭha": ['mw'],
    "svaprayogāt": ['mw'],
    "svaprayojanavaśa": ['mw'],
    "svaptavya": ['cae', 'mw'],
    "svaptṛ": ['mw'],
    "svapura": ['ddsa', 'mw'],
    "svapuras": ['mw'],
    "svaputravat": ['mw'],
    "svapāka": ['cae', 'gra', 'mw'],
    "svapū": ['cae', 'ddsa', 'gra', 'mw'],
    "svapūrṇa": ['mw'],
    "svar": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svara": ['cae', 'ddsa', 'gra', 'mw'],
    "svarabaddha": ['mw'],
    "svarabhairava": ['mw'],
    "svarabhakti": ['cae', 'ddsa', 'mw'],
    "svarabhaṅga": ['mw'],
    "svarabhaṅgin": ['mw'],
    "svarabheda": ['cae', 'mw'],
    "svarabhedabhaya": ['mw'],
    "svarabhūta": ['mw'],
    "svarabrahman": ['mw'],
    "svaracchidra": ['mw'],
    "svaracintā": ['mw'],
    "svaradhīta": ['mw'],
    "svaradhītasāra": ['mw'],
    "svaradīpta": ['mw'],
    "svaragatādhyāya": ['mw'],
    "svaraghna": ['mw'],
    "svaragrāma": ['mw'],
    "svaragupti": ['bhs', 'mw'],
    "svarahan": ['mw'],
    "svarakampa": ['mw'],
    "svarakara": ['mw'],
    "svarakṣaya": ['mw'],
    "svarakṣu": ['mw'],
    "svaralakṣaṇa": ['mw'],
    "svaralāsikā": ['mw'],
    "svaramantrakāṇḍa": ['mw'],
    "svaramañcanṛtya": ['mw'],
    "svaramañjarī": ['mw'],
    "svaramaṇḍala": ['mw'],
    "svaramaṇḍalikā": ['mw'],
    "svaramelakalānidhi": ['mw'],
    "svaramātrā": ['mw'],
    "svaranirṇaya": ['mw'],
    "svaranābhi": ['mw'],
    "svarapakṣa": ['mw'],
    "svaraparibhāṣā": ['mw'],
    "svaraparivarta": ['cae', 'mw'],
    "svarapattana": ['mw'],
    "svarapañcāśat": ['mw'],
    "svaraprakaraṇa": ['mw'],
    "svaraprakriyā": ['mw'],
    "svaraprastāra": ['mw'],
    "svarapuraṃjaya": ['mw'],
    "svarapṛṣṭha": ['mw'],
    "svararatnabhāṇḍa": ['mw'],
    "svararatnakośa": ['mw'],
    "svaras": ['gra', 'mw'],
    "svarasa": ['ddsa', 'mw'],
    "svarasampad": ['mw'],
    "svarasampanna": ['mw'],
    "svarasamuccaya": ['mw'],
    "svarasaṃdarbha": ['mw'],
    "svarasaṃdehavivāda": ['mw'],
    "svarasaṃdhi": ['mw'],
    "svarasaṃgraha": ['mw'],
    "svarasaṃkrama": ['cae', 'mw'],
    "svarasaṃpad": ['cae'],
    "svarasaṃpanna": ['cae'],
    "svarasaṃsvāravat": ['mw'],
    "svarasaṃyoga": ['cae', 'ddsa', 'mw'],
    "svarasiddhāntacandrikā": ['mw'],
    "svarasiddhāntakaumudī": ['mw'],
    "svarasiddhāntamañjarī": ['mw'],
    "svarasiṃha": ['mw'],
    "svarasubodhinī": ['mw'],
    "svarasvara": ['bhs'],
    "svarasvarūpa": ['mw'],
    "svarasāman": ['mw'],
    "svarasāra": ['mw'],
    "svarasīkṛ": ['mw'],
    "svaratantra": ['mw'],
    "svaratattvacamatkāra": ['mw'],
    "svaratattvodaya": ['mw'],
    "svaratikrama": ['mw'],
    "svaratā": ['mw'],
    "svaravaidika": ['mw'],
    "svaravant": ['cae'],
    "svaravat": ['ap90', 'mw'],
    "svaravibhakti": ['mw'],
    "svaravidhi": ['mw'],
    "svaravivikta": ['bhs'],
    "svaravyākhyā": ['mw'],
    "svarayoga": ['cae', 'mw'],
    "svarayoni": ['mw'],
    "svaraśas": ['mw'],
    "svaraśikṣā": ['mw'],
    "svaraśuddha": ['mw'],
    "svaraśāstra": ['mw'],
    "svaraśūnya": ['mw'],
    "svaraḥ": ['ap90'],
    "svaraṃkṛta": ['cae', 'gra', 'mw'],
    "svaraṅgaśūra": ['bhs'],
    "svaraṅkṛta": ['ddsa'],
    "svaraṇa": ['cae', 'gra', 'mw'],
    "svarbhānava": ['cae', 'mw'],
    "svarbhānavī": ['mw'],
    "svarbhānavīya": ['mw'],
    "svarbhānu": ['cae', 'gra', 'mw'],
    "svarbhānusūdana": ['cae', 'mw'],
    "svarbhānuśatru": ['cae'],
    "svarbhāṇu": ['mw'],
    "svarcakṣas": ['cae', 'gra', 'mw'],
    "svarcana": ['mw'],
    "svarcanas": ['cae', 'gra', 'mw'],
    "svarci": ['cae', 'gra', 'mw'],
    "svarcis": ['mw'],
    "svard": ['ap90', 'mw'],
    "svarda": ['cae', 'mw'],
    "svardantin": ['mw'],
    "svardeva": ['mw'],
    "svardhenu": ['mw'],
    "svardhin": ['cae', 'mw'],
    "svardhunī": ['mw'],
    "svardhāman": ['mw'],
    "svardā": ['cae', 'mw'],
    "svardṛś": ['cae', 'ddsa', 'gra', 'mw'],
    "svareṇu": ['mw'],
    "svarga": ['cae', 'ddsa', 'gra', 'mw'],
    "svargabhartṛ": ['cae', 'mw'],
    "svargacyuta": ['cae', 'mw'],
    "svargada": ['mw'],
    "svargadvāra": ['cae', 'ddsa', 'mw'],
    "svargadvāreṣṭi": ['mw'],
    "svargagamana": ['cae', 'mw'],
    "svargagata": ['mw'],
    "svargagati": ['cae', 'mw'],
    "svargagiri": ['mw'],
    "svargagāmin": ['cae', 'mw'],
    "svargahetau": ['mw'],
    "svargahvāya": ['mw'],
    "svargajit": ['cae', 'mw'],
    "svargajīvin": ['cae', 'mw'],
    "svargakhaṇḍa": ['mw'],
    "svargakāma": ['cae', 'mw'],
    "svargaloka": ['cae', 'mw'],
    "svargalokeśa": ['mw'],
    "svargamana": ['mw'],
    "svargamandākinī": ['mw'],
    "svargamārga": ['cae', 'mw'],
    "svargamārgadidṛkṣu": ['mw'],
    "svarganaraka": ['mw'],
    "svargapada": ['mw'],
    "svargapara": ['mw'],
    "svargaparvan": ['mw'],
    "svargapatha": ['mw'],
    "svargapati": ['cae', 'mw'],
    "svargaprada": ['mw'],
    "svargapradhāna": ['mw'],
    "svargapurī": ['cae', 'mw'],
    "svargarodaḥkuhara": ['mw'],
    "svargarājya": ['cae', 'mw'],
    "svargasad": ['cae', 'mw'],
    "svargasaridvarā": ['mw'],
    "svargasattraprayoga": ['mw'],
    "svargasaṃkrama": ['mw'],
    "svargasaṃpādana": ['mw'],
    "svargastha": ['cae', 'mw'],
    "svargasthita": ['cae', 'mw'],
    "svargastrī": ['cae', 'mw'],
    "svargasukha": ['cae', 'mw'],
    "svargasādhana": ['mw'],
    "svargata": ['cae', 'ddsa', 'mw'],
    "svargataraṃgiṇī": ['cae', 'mw'],
    "svargataraṅgiṇī": ['ddsa'],
    "svargataru": ['cae', 'mw'],
    "svargatarṣa": ['mw'],
    "svargati": ['cae', 'ddsa', 'mw'],
    "svargaukas": ['cae', 'ddsa', 'mw'],
    "svargavadhū": ['mw'],
    "svargavant": ['cae'],
    "svargavat": ['mw'],
    "svargavāsa": ['mw'],
    "svargaya": ['mw'],
    "svargayoni": ['mw'],
    "svargayāṇa": ['cae', 'mw'],
    "svargaśrī": ['mw'],
    "svargaḥ": ['ap90'],
    "svargaṅgā": ['mw'],
    "svargepsu": ['mw'],
    "svargi": ['mw'],
    "svargigiri": ['mw'],
    "svargin": ['ap90', 'cae', 'ddsa', 'mw'],
    "svargiri": ['mw'],
    "svargistrī": ['mw'],
    "svargivadhū": ['mw'],
    "svargopaga": ['mw'],
    "svargya": ['cae', 'ddsa', 'mw'],
    "svargābhikāma": ['mw'],
    "svargāmin": ['cae', 'ddsa'],
    "svargāpagā": ['mw'],
    "svargāpavarga": ['mw'],
    "svargārgala": ['mw'],
    "svargārohaṇa": ['ddsa', 'mw'],
    "svargārohaṇaparvan": ['mw'],
    "svargārohaṇika": ['mw'],
    "svargārtham": ['mw'],
    "svargārūḍha": ['mw'],
    "svargāvāsa": ['mw'],
    "svargāy": ['cae'],
    "svargīya": ['ap90', 'cae', 'mw'],
    "svarhat": ['mw'],
    "svarhaṇa": ['mw'],
    "svari": ['cae', 'gra', 'mw'],
    "svaria": ['gra'],
    "svarita": ['ap90', 'cae', 'ddsa', 'mw'],
    "svaritatva": ['mw'],
    "svaritavat": ['mw'],
    "svaritavākyapaddhati": ['mw'],
    "svaritra": ['cae', 'gra', 'mw'],
    "svaritṛ": ['gra', 'mw'],
    "svariṅgaṇa": ['mw'],
    "svarjeṣa": ['gra', 'mw'],
    "svarji": ['mw'],
    "svarjika": ['mw'],
    "svarjikaḥ": ['ap90'],
    "svarjikā": ['mw'],
    "svarjikākṣāra": ['mw'],
    "svarjikṣāra": ['mw'],
    "svarjin": ['mw'],
    "svarjit": ['cae', 'ddsa', 'gra', 'mw'],
    "svarjyotirnidhana": ['mw'],
    "svarjyotis": ['mw'],
    "svarka": ['cae', 'ddsa', 'gra', 'mw'],
    "svarloka": ['cae', 'mw'],
    "svarlokatā": ['mw'],
    "svarlīna": ['mw'],
    "svarmadhya": ['mw'],
    "svarmaṇi": ['cae', 'mw'],
    "svarmīl̤ha": ['cae', 'mw'],
    "svarmīḍha": ['gra'],
    "svarnadī": ['mw'],
    "svarnagarī": ['cae', 'mw'],
    "svarnagarīkṛta": ['mw'],
    "svarnayana": ['mw'],
    "svarocas": ['mw'],
    "svaroci": ['mw'],
    "svarocis": ['cae', 'gra', 'mw'],
    "svarociṣa": ['mw'],
    "svarodaya": ['mw'],
    "svarodayavicāra": ['mw'],
    "svarodayayuddhanirṇaya": ['mw'],
    "svaropadha": ['mw'],
    "svaropaghāta": ['mw'],
    "svaropaghātin": ['mw'],
    "svarpati": ['cae', 'gra', 'mw'],
    "svart": ['mw'],
    "svartha": ['cae', 'ddsa', 'gra', 'mw'],
    "svaru": ['cae', 'ddsa', 'gra', 'mw'],
    "svaruci": ['cae', 'ddsa', 'mw'],
    "svarucyā": ['mw'],
    "svaruh": ['mw'],
    "svarumocana": ['mw'],
    "svarus": ['ap90', 'mw'],
    "svaruḥ": ['ap90'],
    "svarvadhū": ['cae', 'mw'],
    "svarvaidya": ['mw'],
    "svarvannidhana": ['mw'],
    "svarvant": ['cae'],
    "svarvat": ['ddsa', 'gra', 'mw'],
    "svarveśyā": ['mw'],
    "svarvid": ['cae', 'gra', 'mw'],
    "svarvāhinī": ['mw'],
    "svarvāpī": ['mw'],
    "svarvīthi": ['mw'],
    "svarya": ['cae', 'ddsa', 'gra', 'mw'],
    "svaryas": ['mw'],
    "svaryaśas": ['mw'],
    "svaryoṣit": ['mw'],
    "svaryu": ['cae', 'gra', 'mw'],
    "svaryāna": ['mw'],
    "svaryāta": ['cae', 'ddsa', 'mw'],
    "svaryātṛ": ['mw'],
    "svarā": ['mw'],
    "svarāj": ['cae', 'ddsa', 'gra', 'mw'],
    "svarājan": ['cae', 'mw'],
    "svarājia": ['gra'],
    "svarājya": ['cae', 'gra', 'mw'],
    "svarālu": ['mw'],
    "svarānta": ['mw'],
    "svarāntara": ['mw'],
    "svarāntare": ['mw'],
    "svarāpagā": ['mw'],
    "svarārūḍha": ['mw'],
    "svarārṇava": ['mw'],
    "svarāsvara": ['bhs'],
    "svarāvadhāna": ['mw'],
    "svarāṃśa": ['mw'],
    "svarāṅga": ['bhs'],
    "svarāṅgaghoṣa": ['bhs'],
    "svarāṅka": ['mw'],
    "svarāṅkuśa": ['mw'],
    "svarāṣṭaka": ['mw'],
    "svarāṣṭra": ['cae', 'mw'],
    "svarāṣṭracintā": ['mw'],
    "svarāṣṭrīya": ['mw'],
    "svarāṣṭrīyajana": ['mw'],
    "svarī": ['gra'],
    "svarīyas": ['mw'],
    "svarūpa": ['cae', 'mw'],
    "svarūpabhāva": ['mw'],
    "svarūpadhārin": ['mw'],
    "svarūpagata": ['mw'],
    "svarūpaka": ['mw'],
    "svarūpanirūpaṇa": ['mw'],
    "svarūpanirṇaya": ['mw'],
    "svarūpaprakāśa": ['mw'],
    "svarūpasambandharūpa": ['mw'],
    "svarūpasambodhana": ['mw'],
    "svarūpasambodhanapañcaviṃśativṛtti": ['mw'],
    "svarūpatas": ['mw'],
    "svarūpatva": ['mw'],
    "svarūpatā": ['mw'],
    "svarūpavat": ['mw'],
    "svarūpin": ['mw'],
    "svarūpopaniṣad": ['mw'],
    "svarūpotprekṣā": ['mw'],
    "svarūpā": ['mw'],
    "svarūpācārya": ['mw'],
    "svarūpākhyastotra": ['mw'],
    "svarūpānusaṃdhāna": ['mw'],
    "svarūpānusaṃdhānastotra": ['mw'],
    "svarūpāsiddhi": ['mw'],
    "svarṇa": ['cae', 'ddsa', 'mw'],
    "svarṇabandha": ['mw'],
    "svarṇabandhaka": ['mw'],
    "svarṇabhāj": ['mw'],
    "svarṇabhūmikā": ['mw'],
    "svarṇabhūṣaṇa": ['mw'],
    "svarṇabhṛṅgāra": ['mw'],
    "svarṇabindu": ['mw'],
    "svarṇacūla": ['mw'],
    "svarṇacūḍa": ['mw'],
    "svarṇacūḍaka": ['mw'],
    "svarṇada": ['mw'],
    "svarṇadhātu": ['mw'],
    "svarṇadru": ['mw'],
    "svarṇadugdhā": ['mw'],
    "svarṇadugdhī": ['mw'],
    "svarṇadvīpa": ['ddsa', 'mw'],
    "svarṇadā": ['mw'],
    "svarṇadāmā": ['mw'],
    "svarṇadī": ['cae', 'ddsa', 'mw'],
    "svarṇadīdhiti": ['mw'],
    "svarṇagairika": ['mw'],
    "svarṇagaurīvrata": ['mw'],
    "svarṇagaurīvratapūjā": ['mw'],
    "svarṇagaṇapati": ['mw'],
    "svarṇagharma": ['mw'],
    "svarṇagiri": ['mw'],
    "svarṇagrāma": ['mw'],
    "svarṇagrīva": ['mw'],
    "svarṇagrīvā": ['mw'],
    "svarṇaja": ['mw'],
    "svarṇajātikā": ['mw'],
    "svarṇajātī": ['mw'],
    "svarṇajīrī": ['mw'],
    "svarṇajīvantikā": ['mw'],
    "svarṇajīvā": ['mw'],
    "svarṇaka": ['ap90', 'mw'],
    "svarṇakaṇa": ['mw'],
    "svarṇakaṇikā": ['mw'],
    "svarṇaketakī": ['mw'],
    "svarṇakeśa": ['bhs'],
    "svarṇakhaṇḍāya": ['mw'],
    "svarṇakāra": ['cae', 'mw'],
    "svarṇakāraka": ['mw'],
    "svarṇakāratā": ['mw'],
    "svarṇakāya": ['mw'],
    "svarṇakūṭa": ['mw'],
    "svarṇakṛt": ['cae', 'mw'],
    "svarṇakṣīriṇikā": ['mw'],
    "svarṇakṣīrī": ['mw'],
    "svarṇalatā": ['mw'],
    "svarṇalābha": ['mw'],
    "svarṇalī": ['mw'],
    "svarṇamahā": ['mw'],
    "svarṇamaya": ['mw'],
    "svarṇamukharīmāhātmya": ['mw'],
    "svarṇamākṣika": ['mw'],
    "svarṇamātṛ": ['mw'],
    "svarṇamūla": ['mw'],
    "svarṇamūṣikā": ['mw'],
    "svarṇanibha": ['mw'],
    "svarṇanābha": ['mw'],
    "svarṇapadmā": ['mw'],
    "svarṇapakṣa": ['mw'],
    "svarṇaparṇī": ['mw'],
    "svarṇaphalā": ['mw'],
    "svarṇaprabhāsa": ['bhs'],
    "svarṇaprastha": ['mw'],
    "svarṇapuṅkha": ['mw'],
    "svarṇapuṣpa": ['mw'],
    "svarṇapuṣpikā": ['mw'],
    "svarṇapārevata": ['mw'],
    "svarṇapāṭhaka": ['mw'],
    "svarṇara": ['cae', 'ddsa', 'gra', 'mw'],
    "svarṇarambhā": ['mw'],
    "svarṇarekhā": ['cae', 'ddsa', 'mw'],
    "svarṇaretas": ['mw'],
    "svarṇaroman": ['mw'],
    "svarṇarāga": ['mw'],
    "svarṇarāja": ['mw'],
    "svarṇarīti": ['mw'],
    "svarṇarūpin": ['mw'],
    "svarṇasaṃcayā": ['mw'],
    "svarṇasindūra": ['mw'],
    "svarṇastha": ['mw'],
    "svarṇasū": ['mw'],
    "svarṇatantra": ['mw'],
    "svarṇavajra": ['mw'],
    "svarṇavalkala": ['mw'],
    "svarṇavallī": ['mw'],
    "svarṇavarṇa": ['mw'],
    "svarṇavarṇabhāj": ['mw'],
    "svarṇavarṇābhā": ['mw'],
    "svarṇavaṅga": ['mw'],
    "svarṇavaṇij": ['mw'],
    "svarṇavidyā": ['mw'],
    "svarṇayūthī": ['mw'],
    "svarṇaśaila": ['mw'],
    "svarṇaśephālikā": ['mw'],
    "svarṇaśikha": ['mw'],
    "svarṇaśuktikā": ['mw'],
    "svarṇaśṛṅga": ['mw'],
    "svarṇaśṛṅgin": ['mw'],
    "svarṇaṃ": ['ap90'],
    "svarṇaṣṭhīvin": ['mw'],
    "svarṇetṛ": ['mw'],
    "svarṇidhana": ['mw'],
    "svarṇulī": ['mw'],
    "svarṇādri": ['mw'],
    "svarṇāhvā": ['mw'],
    "svarṇākara": ['mw'],
    "svarṇākarṣaṇa": ['mw'],
    "svarṇākarṣaṇabhairavavidhāna": ['mw'],
    "svarṇāri": ['mw'],
    "svarṇāṅga": ['mw'],
    "svarṇīta": ['mw'],
    "svarṇṛ": ['cae', 'gra', 'mw'],
    "svarṣā": ['cae', 'gra', 'mw'],
    "svarṣāti": ['cae', 'gra', 'mw'],
    "svasadṛśa": ['mw'],
    "svasainya": ['mw'],
    "svasambhava": ['mw'],
    "svasambhūta": ['mw'],
    "svasammukha": ['mw'],
    "svasamuttha": ['mw'],
    "svasamāna": ['mw'],
    "svasara": ['cae', 'gra', 'mw'],
    "svasarva": ['mw'],
    "svasattā": ['mw'],
    "svasaṃhitā": ['mw'],
    "svasaṃsthā": ['mw'],
    "svasaṃvedana": ['mw'],
    "svasaṃvedya": ['ddsa', 'mw'],
    "svasaṃvid": ['mw'],
    "svasaṃvṛta": ['mw'],
    "svasaṃyukta": ['mw'],
    "svasetu": ['ddsa', 'gra', 'mw'],
    "svasic": ['mw'],
    "svasiddha": ['mw'],
    "svasita": ['cae', 'ddsa', 'mw'],
    "svask": ['ap90', 'mw'],
    "svaskanda": ['mw'],
    "svasreya": ['mw'],
    "svasrīya": ['cae', 'ddsa', 'mw'],
    "svasrīyaḥ": ['ap90'],
    "svasrīyā": ['ap90', 'mw'],
    "svastaka": ['mw'],
    "svastamita": ['mw'],
    "svastara": ['cae', 'mw'],
    "svastha": ['cae', 'ddsa', 'mw'],
    "svasthacitta": ['mw'],
    "svastham": ['mw'],
    "svasthamānasa": ['cae'],
    "svasthatā": ['mw'],
    "svasthavṛtta": ['mw'],
    "svasthita": ['mw'],
    "svasthāna": ['cae', 'mw'],
    "svasthānastha": ['mw'],
    "svasthāriṣṭa": ['mw'],
    "svasthībhū": ['ddsa', 'mw'],
    "svasthīkṛ": ['mw'],
    "svasti": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "svastibhāva": ['mw'],
    "svastida": ['cae', 'mw'],
    "svastidevī": ['mw'],
    "svastidā": ['cae', 'gra', 'mw'],
    "svastigavyūti": ['mw'],
    "svastigā": ['cae', 'gra', 'mw'],
    "svastika": ['bhs', 'cae', 'mw'],
    "svastikadāna": ['mw'],
    "svastikakarṇa": ['mw'],
    "svastikara": ['mw'],
    "svastikarman": ['mw'],
    "svastikayantra": ['mw'],
    "svastikaḥ": ['ap90'],
    "svastikaṭaka": ['bhs'],
    "svastikādicakra": ['mw'],
    "svastikāra": ['cae', 'mw'],
    "svastikāsana": ['mw'],
    "svastikāṅka": ['mw'],
    "svastikīkṛta": ['mw'],
    "svastikṛt": ['mw'],
    "svastimant": ['cae'],
    "svastimat": ['ap90', 'gra', 'mw'],
    "svastimatī": ['mw'],
    "svastimukha": ['mw'],
    "svastinā": ['bhs'],
    "svastipura": ['mw'],
    "svastitā": ['cae', 'mw'],
    "svastivacana": ['mw'],
    "svastivah": ['gra', 'mw'],
    "svastivāc": ['cae', 'mw'],
    "svastivācaka": ['mw'],
    "svastivācana": ['cae', 'mw'],
    "svastivācanaka": ['cae', 'mw'],
    "svastivācanakamantra": ['mw'],
    "svastivācanakapaddhati": ['mw'],
    "svastivācanika": ['cae', 'mw'],
    "svastivācya": ['cae', 'mw'],
    "svastivāda": ['mw'],
    "svastivāh": ['mw'],
    "svastivāhana": ['mw'],
    "svasty": ['mw'],
    "svastya": ['ddsa', 'mw'],
    "svastyakṣara": ['mw'],
    "svastyarthacarita": ['mw'],
    "svastyayana": ['cae', 'ddsa', 'mw'],
    "svastyayanagaṇa": ['mw'],
    "svastyayati": ['bhs'],
    "svastyātreya": ['cae', 'mw'],
    "svastī": ['mw'],
    "svasvabhāva": ['cae', 'mw'],
    "svasvadha": ['mw'],
    "svasvakāla": ['ddsa', 'mw'],
    "svasvaprāṇa": ['mw'],
    "svasvaruci": ['mw'],
    "svasvarūpa": ['cae', 'mw'],
    "svasvāmibhāva": ['mw'],
    "svasvāmisambandha": ['mw'],
    "svasā": ['bhs', 'mw'],
    "svasāra": ['mw'],
    "svasū": ['mw'],
    "svasṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svasṛt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svasṛtva": ['ddsa', 'gra', 'mw'],
    "svatantra": ['cae', 'ddsa', 'mw'],
    "svatantralekhana": ['mw'],
    "svatantramukhamardana": ['mw'],
    "svatantrasāra": ['mw'],
    "svatantratantra": ['mw'],
    "svatantratā": ['mw'],
    "svatantravṛtti": ['mw'],
    "svatantray": ['cae'],
    "svatantraya": ['mw'],
    "svatantrika": ['mw'],
    "svatantrin": ['mw'],
    "svatas": ['ap90', 'cae', 'mw'],
    "svatastva": ['mw'],
    "svatavas": ['cae', 'gra', 'mw'],
    "svataḥpramāṇa": ['mw'],
    "svataḥsiddha": ['mw'],
    "svatejadīpta": ['bhs'],
    "svatejas": ['cae', 'mw'],
    "svatejoraśmimālin": ['mw'],
    "svatra": ['mw'],
    "svatulya": ['mw'],
    "svatva": ['mw'],
    "svatvabodhana": ['mw'],
    "svatvahetu": ['mw'],
    "svatvahāni": ['mw'],
    "svatvanivṛtti": ['mw'],
    "svatvarahasya": ['mw'],
    "svatvavat": ['mw'],
    "svatvavicāra": ['mw'],
    "svatvavyabhicārin": ['mw'],
    "svatvavyabhicāritva": ['mw'],
    "svatvavyavasthārṇavasetubandha": ['mw'],
    "svatvavāda": ['mw'],
    "svatvaṃ": ['ap90'],
    "svatvotpatti": ['mw'],
    "svatvābhāva": ['mw'],
    "svatvāspada": ['mw'],
    "svatvāspadībhūta": ['mw'],
    "svatvāvagama": ['mw'],
    "svatā": ['cae', 'mw'],
    "svatṛtīya": ['mw'],
    "svaujas": ['mw'],
    "svaupaśa": ['mw'],
    "svavacchanna": ['mw'],
    "svavagraha": ['ddsa', 'mw'],
    "svavahita": ['mw'],
    "svavairitā": ['mw'],
    "svavaklinna": ['mw'],
    "svavargya": ['mw'],
    "svavargīya": ['mw'],
    "svavas": ['gra', 'mw'],
    "svavasu": ['mw'],
    "svavat": ['cae', 'ddsa', 'mw'],
    "svavattā": ['mw'],
    "svavaśa": ['cae', 'ddsa', 'mw'],
    "svavaśatā": ['mw'],
    "svavaśaṃkṛta": ['mw'],
    "svavaśinī": ['mw'],
    "svavaśya": ['mw'],
    "svavaṃśaja": ['mw'],
    "svavaṃśin": ['mw'],
    "svavaṃśya": ['ddsa', 'mw'],
    "svavekṣa": ['mw'],
    "svavekṣita": ['mw'],
    "svaveśa": ['gra'],
    "svavicchandas": ['mw'],
    "svavidheya": ['mw'],
    "svavidhi": ['mw'],
    "svavidhinā": ['mw'],
    "svavidyut": ['cae', 'gra', 'mw'],
    "svavigraha": ['mw'],
    "svavikatthana": ['mw'],
    "svavināśa": ['mw'],
    "svaviṣaya": ['cae', 'mw'],
    "svavokṣita": ['mw'],
    "svavyāja": ['mw'],
    "svavān": ['cae'],
    "svavāra": ['mw'],
    "svavārtta": ['mw'],
    "svavāsin": ['mw'],
    "svavāsinī": ['ddsa', 'mw'],
    "svavāñchā": ['mw'],
    "svavīkṣita": ['mw'],
    "svavīryatas": ['mw'],
    "svavṛj": ['gra', 'mw'],
    "svavṛkti": ['gra', 'mw'],
    "svavṛti": ['mw'],
    "svavṛtta": ['mw'],
    "svavṛtti": ['cae', 'mw'],
    "svavṛttivāda": ['mw'],
    "svavṛṣṭi": ['gra', 'mw'],
    "svayam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svayamabhigūrta": ['mw'],
    "svayamadhigata": ['mw'],
    "svayamagurutva": ['ddsa', 'mw'],
    "svayamanuṣṭhāna": ['cae', 'mw'],
    "svayamapodita": ['mw'],
    "svayamarjita": ['cae', 'mw'],
    "svayamavadīrṇa": ['mw'],
    "svayamavapanna": ['mw'],
    "svayambhagna": ['mw'],
    "svayambhoja": ['mw'],
    "svayambhrami": ['mw'],
    "svayambhramin": ['mw'],
    "svayambhu": ['mw'],
    "svayambhucaitanya": ['mw'],
    "svayambhuva": ['mw'],
    "svayambhuvā": ['mw'],
    "svayambhū": ['gra', 'mw'],
    "svayambhūkṣetramāhātmya": ['mw'],
    "svayambhūliṅga": ['mw'],
    "svayambhūliṅgasambhūtā": ['mw'],
    "svayambhūmātṛkātantra": ['mw'],
    "svayambhūpurāṇa": ['mw'],
    "svayambhūta": ['mw'],
    "svayambhṛta": ['mw'],
    "svayambodha": ['mw'],
    "svayamindriyamocana": ['mw'],
    "svayammathita": ['mw'],
    "svayammlāna": ['mw'],
    "svayammūrta": ['mw'],
    "svayammṛta": ['mw'],
    "svayampatita": ['ddsa', 'mw'],
    "svayamprabha": ['mw'],
    "svayamprabhu": ['mw'],
    "svayamprabhā": ['mw'],
    "svayampradīrṇa": ['mw'],
    "svayamprajvalita": ['mw'],
    "svayamprakāśa": ['mw'],
    "svayamprakāśamāna": ['mw'],
    "svayamprakāśamānatva": ['mw'],
    "svayamprakāśatīrtha": ['mw'],
    "svayamprakāśendra": ['mw'],
    "svayamprakāśānanda": ['mw'],
    "svayamprakāśātman": ['mw'],
    "svayamprastuta": ['mw'],
    "svayampraśīrṇa": ['mw'],
    "svayamprokta": ['mw'],
    "svayampāpa": ['mw'],
    "svayampāṭha": ['mw'],
    "svayamudghāṭita": ['mw'],
    "svayamudgīrṇa": ['mw'],
    "svayamudita": ['mw'],
    "svayamudyata": ['cae', 'mw'],
    "svayamujjvala": ['mw'],
    "svayamukti": ['mw'],
    "svayamupasthita": ['mw'],
    "svayamupeta": ['mw'],
    "svayamupāgata": ['mw'],
    "svayamācāryaka": ['bhs'],
    "svayamāgata": ['cae', 'mw'],
    "svayamāhṛta": ['cae', 'mw'],
    "svayamāhṛtyabhojin": ['mw'],
    "svayamānīta": ['mw'],
    "svayamāsanaḍhaukana": ['mw'],
    "svayamātṛṇṇa": ['mw'],
    "svayamātṛṇṇavat": ['mw'],
    "svayamātṛṇṇā": ['mw'],
    "svayamīhitalabdha": ['mw'],
    "svayamīśvara": ['mw'],
    "svayata": ['cae', 'gra', 'mw'],
    "svayatna": ['ddsa', 'mw'],
    "svayaśas": ['cae', 'ddsa', 'gra', 'mw'],
    "svayaṃ": ['bhs', 'mw'],
    "svayaṃbhagna": ['cae'],
    "svayaṃbhu": ['cae'],
    "svayaṃbhuva": ['cae'],
    "svayaṃbhū": ['cae'],
    "svayaṃciti": ['mw'],
    "svayaṃdatta": ['cae', 'mw'],
    "svayaṃdhārita": ['cae'],
    "svayaṃdina": ['mw'],
    "svayaṃdāna": ['mw'],
    "svayaṃdṛś": ['mw'],
    "svayaṃgraha": ['cae', 'mw'],
    "svayaṃgrahaṇa": ['mw'],
    "svayaṃgrāha": ['cae', 'mw'],
    "svayaṃgrāham": ['mw'],
    "svayaṃgrāhaniṣaktabāhu": ['mw'],
    "svayaṃgrāhapraṇaya": ['mw'],
    "svayaṃgrāhya": ['mw'],
    "svayaṃguptā": ['mw'],
    "svayaṃgurutva": ['mw'],
    "svayaṃguṇaparityāga": ['mw'],
    "svayaṃhoma": ['mw'],
    "svayaṃhomin": ['mw'],
    "svayaṃhotṛ": ['mw'],
    "svayaṃhārakarī": ['mw'],
    "svayaṃhārikā": ['mw'],
    "svayaṃhārī": ['mw'],
    "svayaṃja": ['cae', 'mw'],
    "svayaṃjyotis": ['cae', 'mw'],
    "svayaṃjā": ['gra'],
    "svayaṃjāta": ['cae', 'mw'],
    "svayaṃkartṛka": ['mw'],
    "svayaṃkhāta": ['cae', 'mw'],
    "svayaṃkrānta": ['mw'],
    "svayaṃkārin": ['bhs'],
    "svayaṃkṛta": ['cae', 'mw'],
    "svayaṃkṛtin": ['mw'],
    "svayaṃkṛṣṭa": ['mw'],
    "svayaṃmṛta": ['cae'],
    "svayaṃnirdiṣṭa": ['cae', 'mw'],
    "svayaṃprabha": ['bhs', 'cae'],
    "svayaṃprakāśa": ['cae'],
    "svayaṃprakāśamāna": ['cae'],
    "svayaṃprastuta": ['cae'],
    "svayaṃpraśīrṇa": ['cae'],
    "svayaṃsambhṛta": ['mw'],
    "svayaṃsaṃviddha": ['mw'],
    "svayaṃsaṃyoga": ['mw'],
    "svayaṃsiddha": ['mw'],
    "svayaṃsras": ['cae', 'mw'],
    "svayaṃsrasta": ['cae', 'mw'],
    "svayaṃtyakta": ['cae', 'mw'],
    "svayaṃvaha": ['mw'],
    "svayaṃvakra": ['mw'],
    "svayaṃvara": ['cae', 'ddsa', 'mw'],
    "svayaṃvarakathā": ['mw'],
    "svayaṃvarakṛtakṣaṇā": ['mw'],
    "svayaṃvarapati": ['mw'],
    "svayaṃvaraprabhā": ['mw'],
    "svayaṃvarasakhī": ['mw'],
    "svayaṃvarastha": ['mw'],
    "svayaṃvarasuhṛd": ['mw'],
    "svayaṃvarasuhṛttva": ['mw'],
    "svayaṃvaravadhū": ['cae', 'mw'],
    "svayaṃvaravāpī": ['mw'],
    "svayaṃvaravṛta": ['mw'],
    "svayaṃvarayitrī": ['mw'],
    "svayaṃvaraṇa": ['mw'],
    "svayaṃvarāgata": ['mw'],
    "svayaṃvaśa": ['mw'],
    "svayaṃvedana": ['mw'],
    "svayaṃvikrīta": ['mw'],
    "svayaṃvilīna": ['mw'],
    "svayaṃviśīrṇa": ['mw'],
    "svayaṃvyaktasthalastotra": ['mw'],
    "svayaṃvāda": ['mw'],
    "svayaṃvānta": ['mw'],
    "svayaṃvṛta": ['cae', 'mw'],
    "svayaṃyāna": ['mw'],
    "svayaṃśreṣṭha": ['cae', 'mw'],
    "svayaṃśīrṇa": ['cae', 'mw'],
    "svayaṃśṛta": ['mw'],
    "svayoni": ['cae', 'mw'],
    "svayoniguṇakṛt": ['mw'],
    "svayu": ['cae', 'gra', 'mw'],
    "svayugvan": ['cae', 'gra', 'mw'],
    "svayuj": ['cae', 'gra', 'mw'],
    "svayukta": ['cae', 'gra', 'mw'],
    "svayukti": ['cae', 'gra', 'mw'],
    "svayuktitas": ['mw'],
    "svayuktyā": ['mw'],
    "svayuti": ['mw'],
    "svayāvan": ['gra', 'mw'],
    "svayūthya": ['mw'],
    "svañc": ['cae', 'ddsa', 'mw'],
    "svañcana": ['mw'],
    "svañcas": ['cae', 'gra', 'mw'],
    "svañj": ['mw'],
    "svañja": ['mw'],
    "svañjana": ['mw'],
    "svaś": ['mw'],
    "svaśa": ['bhs', 'mw'],
    "svaśakti": ['cae', 'mw'],
    "svaśaktyā": ['mw'],
    "svaśarīra": ['mw'],
    "svaśarīraprabha": ['bhs'],
    "svaścandra": ['cae', 'gra', 'mw'],
    "svaścūḍāmaṇi": ['mw'],
    "svaśiras": ['mw'],
    "svaślāghā": ['mw'],
    "svaśocis": ['cae', 'gra', 'mw'],
    "svaśuraḥ": ['ap90'],
    "svaśva": ['cae', 'ddsa', 'gra', 'mw'],
    "svaśvayu": ['gra', 'mw'],
    "svaśvya": ['cae', 'gra', 'mw'],
    "svaḥ": ['mw'],
    "svaḥkāmya": ['mw'],
    "svaḥpatha": ['mw'],
    "svaḥpati": ['mw'],
    "svaḥpāla": ['mw'],
    "svaḥpṛṣṭha": ['mw'],
    "svaḥsad": ['ddsa', 'mw'],
    "svaḥsarit": ['mw'],
    "svaḥsindhu": ['mw'],
    "svaḥsravantī": ['mw'],
    "svaḥstrī": ['cae', 'mw'],
    "svaḥsundarī": ['cae', 'mw'],
    "svaḥsyandana": ['mw'],
    "svaḥsāman": ['mw'],
    "svaḥśiras": ['mw'],
    "svaṃg": ['ap90'],
    "svaṃgaḥ": ['ap90'],
    "svaṃj": ['ap90'],
    "svaṃjanaṃ": ['ap90'],
    "svaṃk": ['ap90'],
    "svaṅg": ['mw'],
    "svaṅga": ['cae', 'ddsa', 'gra', 'mw'],
    "svaṅguri": ['cae', 'gra', 'mw'],
    "svaṅgārin": ['mw'],
    "svaṅk": ['mw'],
    "svaṣṭra": ['gra', 'mw'],
    "svaṭh": ['ap90', 'mw'],
    "sve": ['cped'],
    "sveccha": ['ddsa', 'mw'],
    "sveccham": ['cae', 'mw'],
    "svecchayā": ['mw'],
    "svecchā": ['cae', 'mw'],
    "svecchābhojana": ['cae'],
    "svecchācāra": ['mw'],
    "svecchācārin": ['cae'],
    "svecchādhīna": ['mw'],
    "svecchāhāra": ['mw'],
    "svecchāhāravihāra": ['mw'],
    "svecchāmaya": ['mw'],
    "svecchāmṛtyu": ['mw'],
    "svecchātas": ['mw'],
    "sveda": ['cae', 'ddsa', 'gra', 'mw'],
    "svedabindu": ['cae', 'ddsa', 'mw'],
    "svedacchid": ['mw'],
    "svedacūṣaka": ['mw'],
    "svedaja": ['cae', 'mw'],
    "svedajadūṣita": ['mw'],
    "svedajala": ['cae', 'mw'],
    "svedajalakaṇa": ['mw'],
    "svedajalakaṇikā": ['mw'],
    "svedaleśa": ['cae', 'mw'],
    "svedamalojjhitadeha": ['mw'],
    "svedamātṛ": ['mw'],
    "svedana": ['bhs', 'cae', 'ddsa', 'mw'],
    "svedanatva": ['mw'],
    "svedanayantra": ['mw'],
    "svedanaṃ": ['ap90'],
    "svedanikā": ['ap90', 'mw'],
    "svedanī": ['ap90', 'mw'],
    "svedavipruṣ": ['mw'],
    "svedavāri": ['cae', 'mw'],
    "svedayu": ['cae', 'mw'],
    "svedaḥ": ['ap90'],
    "svedin": ['mw'],
    "svedita": ['mw'],
    "svedoda": ['mw'],
    "svedodaka": ['mw'],
    "svedodgama": ['cae', 'mw'],
    "sveduhavya": ['gra', 'mw'],
    "svedya": ['ddsa', 'mw'],
    "svedāmbhas": ['mw'],
    "svedāmbu": ['cae', 'mw'],
    "svedāyana": ['mw'],
    "svedāñji": ['gra', 'mw'],
    "svek": ['ap90', 'mw'],
    "sveka": ['mw'],
    "svela": ['bhs'],
    "svetavya": ['mw'],
    "sveṣṭa": ['cae', 'ddsa', 'mw'],
    "sveṣṭadaivata": ['mw'],
    "sveṣṭadevatā": ['mw'],
    "svid": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svidam": ['bhs'],
    "svidhma": ['gra', 'mw'],
    "svidita": ['mw'],
    "svikā": ['mw'],
    "svin": ['mw'],
    "svinna": ['ap90', 'cae', 'mw'],
    "svinnāṅguli": ['mw'],
    "svita": ['cae', 'mw'],
    "sviṣu": ['cae', 'gra', 'mw'],
    "sviṣṭa": ['cae', 'ddsa', 'gra', 'mw'],
    "sviṣṭakṛccaturtha": ['mw'],
    "sviṣṭakṛdbhāga": ['mw'],
    "sviṣṭakṛdbhājana": ['mw'],
    "sviṣṭakṛt": ['cae', 'mw'],
    "sviṣṭakṛta": ['mw'],
    "sviṣṭi": ['cae', 'ddsa', 'mw'],
    "svocita": ['ddsa', 'mw'],
    "svodarapūraka": ['mw'],
    "svodarapūraṇa": ['mw'],
    "svodaya": ['mw'],
    "svojas": ['cae', 'ddsa', 'gra', 'mw'],
    "svokta": ['mw'],
    "svopadhi": ['mw'],
    "svopajña": ['mw'],
    "svopajñadhātupāṭhavivaraṇa": ['mw'],
    "svopaśa": ['mw'],
    "svopārjita": ['mw'],
    "svoras": ['ddsa', 'mw'],
    "svorasa": ['mw'],
    "svorasaḥ": ['ap90'],
    "svottha": ['ddsa', 'mw'],
    "svotthita": ['mw'],
    "svovaśvīya": ['mw'],
    "svovaśīyaṃ": ['ap90'],
    "svurcch": ['ap90'],
    "svā": ['mw'],
    "svābhadevī": ['bhs'],
    "svābhicārin": ['mw'],
    "svābhāsa": ['mw'],
    "svābhāva": ['mw'],
    "svābhāvika": ['ap90', 'cae', 'ddsa', 'mw'],
    "svābhāvikatva": ['mw'],
    "svābhāviketara": ['mw'],
    "svābhāvya": ['cae', 'ddsa', 'mw'],
    "svābhāvyaṃ": ['ap90'],
    "svābhīla": ['mw'],
    "svābhīṣṭa": ['mw'],
    "svābhū": ['cae', 'ddsa', 'gra', 'mw'],
    "svācaraṇa": ['cae', 'mw'],
    "svācchandya": ['cae', 'ddsa', 'mw'],
    "svācchaṃdyaṃ": ['ap90'],
    "svācānta": ['cae', 'mw'],
    "svācāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "svācāravat": ['mw'],
    "svād": ['ap90', 'ddsa', 'gra', 'mw'],
    "svāda": ['cae', 'ddsa', 'mw'],
    "svādana": ['cae', 'gra', 'mw'],
    "svādanīya": ['bhs', 'cae', 'mw'],
    "svādara": ['mw'],
    "svādas": ['cae', 'gra', 'mw'],
    "svādava": ['mw'],
    "svādaḥ": ['ap90'],
    "svādharṣaka": ['bhs'],
    "svādhikāra": ['ddsa', 'mw'],
    "svādhipatya": ['mw'],
    "svādhiṣṭhāna": ['mw'],
    "svādhiṭṭhita": ['cped'],
    "svādhvarika": ['mw'],
    "svādhyāya": ['cae', 'ddsa', 'mw'],
    "svādhyāyabrāhmaṇa": ['mw'],
    "svādhyāyadhṛk": ['mw'],
    "svādhyāyana": ['mw'],
    "svādhyāyanikā": ['bhs', 'mw'],
    "svādhyāyati": ['bhs'],
    "svādhyāyavant": ['cae'],
    "svādhyāyavat": ['mw'],
    "svādhyāyin": ['cae', 'mw'],
    "svādhyāyinikā": ['mw'],
    "svādhyāyārthin": ['cae', 'mw'],
    "svādhī": ['cae', 'ddsa', 'gra', 'mw'],
    "svādhīna": ['cae', 'ddsa', 'mw'],
    "svādhīnabhartṛkā": ['mw'],
    "svādhīnakuśala": ['cae', 'mw'],
    "svādhīnapatikā": ['mw'],
    "svādhīnatva": ['mw'],
    "svādhīnatā": ['mw'],
    "svādhīnopāya": ['cae'],
    "svādiman": ['ap90', 'cae', 'mw'],
    "svādin": ['ddsa', 'mw'],
    "svādita": ['ap90', 'mw'],
    "svāditya": ['mw'],
    "svādiṣṭha": ['ap90', 'gra', 'mw'],
    "svādman": ['cae', 'ddsa', 'gra', 'mw'],
    "svādu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svādudhanvan": ['mw'],
    "svādugandha": ['mw'],
    "svādugandhā": ['mw'],
    "svādukanda": ['mw'],
    "svādukandaka": ['mw'],
    "svādukandā": ['mw'],
    "svādukara": ['mw'],
    "svādukaṇṭa": ['mw'],
    "svādukaṇṭaka": ['mw'],
    "svādukhaṇḍa": ['mw'],
    "svādukā": ['mw'],
    "svādukāma": ['mw'],
    "svādukāmatā": ['mw'],
    "svādukāra": ['mw'],
    "svādukṣadman": ['gra', 'mw'],
    "svādulatā": ['mw'],
    "svāduluṅgī": ['mw'],
    "svādumajjan": ['mw'],
    "svāduman": ['cae', 'mw'],
    "svādumustā": ['mw'],
    "svādumāṃsī": ['mw'],
    "svādumūla": ['mw'],
    "svādumṛdu": ['mw'],
    "svāduparṇī": ['mw'],
    "svāduphala": ['mw'],
    "svāduphalā": ['mw'],
    "svādupiṇḍā": ['mw'],
    "svādupuṣpa": ['mw'],
    "svādupuṣpī": ['mw'],
    "svādupāka": ['mw'],
    "svādupākatva": ['mw'],
    "svādupākin": ['mw'],
    "svādupākā": ['mw'],
    "svādurasa": ['mw'],
    "svādurasā": ['mw'],
    "svādurāti": ['gra', 'mw'],
    "svādusammud": ['mw'],
    "svādusvādu": ['mw'],
    "svādutama": ['mw'],
    "svādutara": ['mw'],
    "svādutiktakaṣāya": ['mw'],
    "svādutuṇḍikā": ['mw'],
    "svādutā": ['cae', 'mw'],
    "svāduvivekin": ['mw'],
    "svāduvāri": ['mw'],
    "svāduyogin": ['mw'],
    "svāduyukta": ['cae', 'mw'],
    "svāduśuddha": ['mw'],
    "svāduṃkāram": ['mw'],
    "svāduṣaṃsad": ['gra', 'mw'],
    "svāduṣkilīyā": ['mw'],
    "svādv": ['mw'],
    "svādvamla": ['mw'],
    "svādvamlatiktatubara": ['mw'],
    "svādvanna": ['mw'],
    "svādvī": ['ap90'],
    "svādya": ['cae', 'mw'],
    "svādāna": ['cae', 'ddsa', 'mw'],
    "svādīyas": ['ap90', 'gra', 'mw'],
    "svādīyati": ['bhs'],
    "svādūda": ['mw'],
    "svādūdaka": ['mw'],
    "svādūdakasamudra": ['mw'],
    "svādūkṛ": ['mw'],
    "svāgama": ['mw'],
    "svāgata": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "svāgatapraśna": ['mw'],
    "svāgatavacana": ['mw'],
    "svāgatavant": ['bhs'],
    "svāgataṁ": ['cped'],
    "svāgataṃ": ['ap90'],
    "svāgatika": ['mw'],
    "svāgatā": ['mw'],
    "svāgatīkṛ": ['ddsa', 'mw'],
    "svāgrayaṇa": ['mw'],
    "svāhata": ['ddsa', 'mw'],
    "svāheya": ['mw'],
    "svāhi": ['mw'],
    "svāhuta": ['cae', 'ddsa', 'gra', 'mw'],
    "svāhvāna": ['mw'],
    "svāhya": ['mw'],
    "svāhā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "svāhābhuj": ['mw'],
    "svāhākaraṇa": ['mw'],
    "svāhākāra": ['cae', 'mw'],
    "svāhākāravaṣaṭkāra": ['mw'],
    "svāhākṛ": ['cae'],
    "svāhākṛt": ['mw'],
    "svāhākṛta": ['gra', 'mw'],
    "svāhākṛti": ['cae', 'gra', 'mw'],
    "svāhākṛtī": ['gra', 'mw'],
    "svāhāpati": ['mw'],
    "svāhāpriya": ['mw'],
    "svāhāra": ['mw'],
    "svāhārha": ['mw'],
    "svāhāsudhākara": ['mw'],
    "svāhāvallabha": ['mw'],
    "svāhāvana": ['mw'],
    "svāhāśana": ['mw'],
    "svājanya": ['ddsa', 'mw'],
    "svājñā": ['ddsa', 'mw'],
    "svājīva": ['cae', 'mw'],
    "svājīvya": ['cae', 'ddsa', 'mw'],
    "svākhyāta": ['cped', 'mw'],
    "svākhyātatā": ['mw'],
    "svākhyāśataka": ['mw'],
    "svākkhāta": ['cped'],
    "svākta": ['mw'],
    "svākāra": ['bhs', 'cped', 'ddsa', 'mw'],
    "svākārakara": ['mw'],
    "svākūti": ['mw'],
    "svākṛti": ['cae', 'ddsa', 'mw'],
    "svākṣapāda": ['mw'],
    "svākṣara": ['mw'],
    "svālakṣaṇa": ['mw'],
    "svālakṣaṇya": ['cae', 'ddsa', 'mw'],
    "svālakṣaṇyaṃ": ['ap90'],
    "svālakṣya": ['mw'],
    "svālaṃkṛta": ['bhs'],
    "svālpa": ['ap90', 'mw'],
    "svāmam": ['bhs'],
    "svāmi": ['mw'],
    "svāmibhaṭṭāraka": ['cae', 'mw'],
    "svāmibhāva": ['mw'],
    "svāmidatta": ['mw'],
    "svāmigirimāhātmya": ['mw'],
    "svāmiguṇa": ['mw'],
    "svāmijanaka": ['mw'],
    "svāmijaṅghin": ['mw'],
    "svāmika": ['bhs', 'cae', 'ddsa', 'mw'],
    "svāmikarāja": ['mw'],
    "svāmikumāra": ['mw'],
    "svāmikārttika": ['mw'],
    "svāmikārttikānuprekṣā": ['mw'],
    "svāmikārya": ['mw'],
    "svāmikāryārthin": ['mw'],
    "svāmimūla": ['mw'],
    "svāmin": ['ap90', 'cae', 'ddsa', 'mw'],
    "svāminy": ['mw'],
    "svāminyaṣṭaka": ['mw'],
    "svāminī": ['ap90', 'mw'],
    "svāminīstotra": ['mw'],
    "svāmiprasāda": ['mw'],
    "svāmiprasādāt": ['mw'],
    "svāmipāla": ['cae', 'mw'],
    "svāmipālavivāda": ['mw'],
    "svāmipālavivādataraṃga": ['mw'],
    "svāmisadbhāva": ['mw'],
    "svāmisevā": ['cae', 'mw'],
    "svāmitva": ['mw'],
    "svāmitā": ['ap90', 'cae', 'mw'],
    "svāmivaśīkarastotra": ['mw'],
    "svāmivātsalya": ['mw'],
    "svāmiśailamāhātmya": ['mw'],
    "svāmiśāstrin": ['mw'],
    "svāmnāya": ['mw'],
    "svāmy": ['mw'],
    "svāmya": ['cae', 'ddsa', 'mw'],
    "svāmyakāraṇa": ['mw'],
    "svāmyartham": ['mw'],
    "svāmyasammata": ['mw'],
    "svāmyaṃ": ['ap90'],
    "svāmyupakāraka": ['mw'],
    "svāna": ['cae', 'ddsa', 'gra', 'mw'],
    "svānama": ['ddsa', 'mw'],
    "svānanda": ['mw'],
    "svānandacandrikā": ['mw'],
    "svānandapūrṇa": ['mw'],
    "svānaḥ": ['ap90'],
    "svāni": ['mw'],
    "svānin": ['cae', 'gra', 'mw'],
    "svānta": ['cae', 'mw'],
    "svāntaja": ['mw'],
    "svāntastha": ['mw'],
    "svāntavat": ['mw'],
    "svānubhava": ['mw'],
    "svānubhavādarśa": ['mw'],
    "svānubhāva": ['ddsa', 'mw'],
    "svānubhūti": ['mw'],
    "svānubhūtiprakāśa": ['mw'],
    "svānubhūtiprakāśavivṛti": ['mw'],
    "svānubhūtivākya": ['mw'],
    "svānubhūtyabhidhanāṭaka": ['mw'],
    "svānubhūtyekasāra": ['mw'],
    "svānurūpa": ['mw'],
    "svānusāra": ['mw'],
    "svānyadīyatva": ['mw'],
    "svānyadīyatvasaṃdeha": ['mw'],
    "svāpa": ['cae', 'ddsa', 'gra', 'mw'],
    "svāpada": ['mw'],
    "svāpadaḥ": ['ap90'],
    "svāpaka": ['mw'],
    "svāpakīya": ['mw'],
    "svāpana": ['cae', 'ddsa', 'mw'],
    "svāparādha": ['mw'],
    "svāparṇa": ['bhs'],
    "svāpateya": ['cae', 'ddsa', 'mw'],
    "svāpateyaṃ": ['ap90'],
    "svāpavyasana": ['ddsa', 'mw'],
    "svāpaya": ['mw'],
    "svāpaḥ": ['ap90'],
    "svāpi": ['cae', 'ddsa', 'gra', 'mw'],
    "svāpika": ['ddsa', 'mw'],
    "svāpimat": ['mw'],
    "svāpin": ['mw'],
    "svāpiśi": ['mw'],
    "svāpiśīya": ['mw'],
    "svāpna": ['mw'],
    "svāpta": ['ddsa', 'mw'],
    "svāptavacana": ['mw'],
    "svāpyaya": ['ddsa', 'mw'],
    "svāra": ['cae', 'ddsa', 'gra', 'mw'],
    "svārabdha": ['mw'],
    "svārakṣya": ['cae', 'mw'],
    "svārambhaka": ['mw'],
    "svārasika": ['ap90', 'ddsa', 'mw'],
    "svārasya": ['mw'],
    "svārasyaṃ": ['ap90'],
    "svārasāmika": ['mw'],
    "svārdra": ['ddsa', 'mw'],
    "svārjita": ['cae', 'ddsa', 'mw'],
    "svārocis": ['mw'],
    "svārociṣa": ['cae', 'ddsa', 'mw'],
    "svārociṣaḥ": ['ap90'],
    "svārtha": ['cae', 'ddsa', 'mw'],
    "svārthabhraṃśin": ['mw'],
    "svārthabhāj": ['mw'],
    "svārthalipsu": ['mw'],
    "svārtham": ['mw'],
    "svārthapara": ['mw'],
    "svārthaparatā": ['mw'],
    "svārthaparāyaṇa": ['mw'],
    "svārthapaṇḍita": ['mw'],
    "svārthaprayatna": ['mw'],
    "svārthasiddhi": ['mw'],
    "svārthasādhaka": ['mw'],
    "svārthasādhana": ['cae', 'mw'],
    "svārthasādhanatatpara": ['mw'],
    "svārthatā": ['mw'],
    "svārthavighāta": ['mw'],
    "svārthe": ['mw'],
    "svārthet": ['mw'],
    "svārthika": ['ddsa', 'mw'],
    "svārthin": ['mw'],
    "svārthopapatti": ['mw'],
    "svārthānumāna": ['mw'],
    "svāruh": ['cae', 'mw'],
    "svārādhita": ['ddsa', 'mw'],
    "svārāj": ['ap90', 'mw'],
    "svārājya": ['cae', 'ddsa', 'mw'],
    "svārājyakāma": ['mw'],
    "svārājyasiddhi": ['mw'],
    "svārājyaṃ": ['ap90'],
    "svārāma": ['mw'],
    "svārāyaṇa": ['mw'],
    "svārūpā": ['mw'],
    "svārūḍha": ['mw'],
    "svās": ['cae', 'ddsa', 'gra', 'mw'],
    "svāsad": ['mw'],
    "svāsada": ['mw'],
    "svāsana": ['cae', 'mw'],
    "svāsanaka": ['bhs'],
    "svāsastha": ['cae', 'gra', 'mw'],
    "svāsrīya": ['mw'],
    "svāsrīyi": ['mw'],
    "svāstara": ['mw'],
    "svāstaraṇa": ['mw'],
    "svāsthya": ['cae', 'ddsa', 'mw'],
    "svāsthyaṃ": ['ap90'],
    "svāstīrṇa": ['cae', 'mw'],
    "svāsīna": ['cae', 'mw'],
    "svāsṛka": ['mw'],
    "svātana": ['cped'],
    "svātantrya": ['cae', 'ddsa', 'mw'],
    "svātanāya": ['cped'],
    "svātata": ['gra', 'mw'],
    "svātaṃtryaṃ": ['ap90'],
    "svāti": ['bhs', 'cae', 'ddsa', 'mw'],
    "svātigiri": ['bhs', 'mw'],
    "svātikarṇa": ['mw'],
    "svātikā": ['bhs'],
    "svātikārī": ['mw'],
    "svātimukha": ['bhs', 'mw'],
    "svātimukhā": ['bhs', 'mw'],
    "svātiyoga": ['mw'],
    "svātiḥ": ['ap90'],
    "svātiṣeṇa": ['mw'],
    "svātman": ['cae', 'ddsa', 'mw'],
    "svātmanirūpaṇa": ['mw'],
    "svātmanirūpaṇaprakaraṇa": ['mw'],
    "svātmaprabodha": ['mw'],
    "svātmaprakāśikā": ['mw'],
    "svātmaprayogapradīpikā": ['mw'],
    "svātmapūjā": ['mw'],
    "svātmasaṃvidupadeśa": ['mw'],
    "svātmasaṃvittyupadeśa": ['mw'],
    "svātmatā": ['mw'],
    "svātmavadha": ['cae', 'mw'],
    "svātmayogapradīpa": ['mw'],
    "svātmopadeśa": ['mw'],
    "svātmānandaprakaraṇa": ['mw'],
    "svātmānandaprakāśa": ['mw'],
    "svātmānandastotra": ['mw'],
    "svātmānandavivardhinī": ['mw'],
    "svātmānandopadeśa": ['mw'],
    "svātmānubhava": ['mw'],
    "svātmānubodha": ['mw'],
    "svātmānurūpaṇa": ['mw'],
    "svātmārāma": ['mw'],
    "svātmāvabodha": ['mw'],
    "svātmībhāva": ['mw'],
    "svātta": ['cae', 'ddsa', 'mw'],
    "svātī": ['cae'],
    "svāvamānana": ['mw'],
    "svāvamānanā": ['mw'],
    "svāvasu": ['gra', 'mw'],
    "svāvaśya": ['ddsa', 'mw'],
    "svāveśa": ['cae', 'gra', 'mw'],
    "svāvṛj": ['ddsa', 'gra', 'mw'],
    "svāvṛt": ['mw'],
    "svāya": ['mw'],
    "svāyambhuva": ['ddsa', 'mw'],
    "svāyambhuvamanupitṛ": ['mw'],
    "svāyambhuvī": ['mw'],
    "svāyambhū": ['mw'],
    "svāyambhūkṣetramāhātmya": ['mw'],
    "svāyasa": ['ddsa', 'gra', 'mw'],
    "svāyatta": ['cae', 'ddsa', 'mw'],
    "svāyattatva": ['mw'],
    "svāyattīkṛ": ['mw'],
    "svāyava": ['mw'],
    "svāyaṃbhuva": ['ap90', 'cae'],
    "svāyoga": ['mw'],
    "svāyu": ['mw'],
    "svāyudha": ['cae', 'gra', 'mw'],
    "svāyuj": ['ddsa', 'gra', 'mw'],
    "svāyus": ['mw'],
    "svāñjalyaka": ['mw'],
    "svāśir": ['mw'],
    "svāśis": ['gra', 'mw'],
    "svāśita": ['gra', 'mw'],
    "svāśiṣa": ['bhs'],
    "svāśiṣātman": ['ddsa', 'mw'],
    "svāśliṣ": ['mw'],
    "svāśraya": ['mw'],
    "svāśrita": ['mw'],
    "svāśu": ['cae', 'mw'],
    "svāḍhyambhava": ['mw'],
    "svāḍhyaṃkara": ['mw'],
    "svāḍhyaṃkaraṇa": ['mw'],
    "svāṃkikaḥ": ['ap90'],
    "svāṃkṛta": ['mw'],
    "svāṃśatas": ['cae'],
    "svāṅga": ['cae', 'ddsa', 'mw'],
    "svāṅgabhaṅga": ['mw'],
    "svāṅgaśīta": ['mw'],
    "svāṅka": ['cae'],
    "svāṅkika": ['mw'],
    "svī": ['mw'],
    "svīkaraṇa": ['cae', 'ddsa', 'mw'],
    "svīkaraṇakarman": ['mw'],
    "svīkaraṇaṃ": ['ap90'],
    "svīkaraṇīya": ['mw'],
    "svīkartavya": ['mw'],
    "svīkartṛ": ['mw'],
    "svīkāra": ['cae', 'mw'],
    "svīkāragraha": ['mw'],
    "svīkārapattra": ['mw'],
    "svīkārarahita": ['mw'],
    "svīkārya": ['mw'],
    "svīkārānta": ['mw'],
    "svīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "svīkṛta": ['mw'],
    "svīkṛti": ['mw'],
    "svīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "svīyā": ['mw'],
    "svīyākṣara": ['mw'],
    "svūrch": ['mw'],
    "svṛ": ['ap90', 'mw'],
    "svṛddha": ['mw'],
    "svṛkṣa": ['mw'],
    "svṛta": ['mw'],
    "svṛtīka": ['mw'],
    "svṝ": ['ap90', 'mw'],
    "sya": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "syad": ['cae', 'ddsa', 'gra', 'mw'],
    "syada": ['cae', 'mw'],
    "syadaḥ": ['ap90'],
    "syagavi": ['mw'],
    "syam": ['ap90', 'mw'],
    "syama": ['bhs'],
    "syamana": ['mw'],
    "syamantaka": ['ddsa', 'mw'],
    "syamantakamaṇiharaṇa": ['mw'],
    "syamantakaprabandha": ['mw'],
    "syamantakopākhyāna": ['mw'],
    "syamaṃtakaḥ": ['ap90'],
    "syamika": ['mw'],
    "syamikaḥ": ['ap90'],
    "syamikā": ['ap90'],
    "syamīka": ['mw'],
    "syamīkaḥ": ['ap90'],
    "syamīkā": ['mw'],
    "syand": ['ddsa', 'gra', 'mw'],
    "syanda": ['bhs', 'cae', 'ddsa', 'mw'],
    "syandaka": ['mw'],
    "syandamānikā": ['bhs'],
    "syandana": ['bhs', 'cae', 'gra', 'mw'],
    "syandanadhvani": ['mw'],
    "syandanadruma": ['mw'],
    "syandani": ['mw'],
    "syandanikā": ['bhs', 'mw'],
    "syandanālokabhīta": ['mw'],
    "syandanāroha": ['mw'],
    "syandanārūḍha": ['mw'],
    "syandanī": ['mw'],
    "syandanīya": ['mw'],
    "syandaraka": ['bhs'],
    "syandayadhyai": ['mw'],
    "syandikā": ['mw'],
    "syandin": ['cae', 'mw'],
    "syandinikā": ['bhs'],
    "syandinī": ['mw'],
    "syandita": ['bhs'],
    "syanditāśva": ['mw'],
    "syanditṛ": ['mw'],
    "syandolikā": ['mw'],
    "syandra": ['cae', 'gra', 'mw'],
    "syandyā": ['cae', 'mw'],
    "syanna": ['ap90', 'ddsa', 'mw'],
    "syanttavya": ['mw'],
    "syanttṛ": ['cae', 'ddsa', 'mw'],
    "syapeṭārikā": ['bhs', 'mw'],
    "syaukāmi": ['mw'],
    "syaumaraśma": ['mw'],
    "syaṃd": ['ap90'],
    "syaṃdana": ['ap90'],
    "syaṃdanikā": ['ap90'],
    "syaṃdaḥ": ['ap90'],
    "syaṃdin": ['ap90'],
    "syaṃdinī": ['ap90'],
    "syedu": ['cae', 'mw'],
    "syona": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "syonakṛt": ['cae', 'gra', 'mw'],
    "syonaśī": ['cae', 'gra', 'mw'],
    "syonāka": ['mw'],
    "syota": ['mw'],
    "syotaḥ": ['ap90'],
    "syumna": ['mw'],
    "syutna": ['mw'],
    "syuvaka": ['mw'],
    "syād": ['mw'],
    "syādvāda": ['ddsa', 'mw'],
    "syādvādamañjarī": ['mw'],
    "syādvādaratnākara": ['mw'],
    "syādvādavādin": ['mw'],
    "syādvādika": ['mw'],
    "syādvādin": ['mw'],
    "syāla": ['cae', 'ddsa', 'gra', 'mw'],
    "syālaka": ['mw'],
    "syālaḥ": ['ap90'],
    "syālikā": ['mw'],
    "syālī": ['mw'],
    "syāma": ['bhs'],
    "syāmahe": ['ddsa'],
    "syāmantopākhyāna": ['mw'],
    "syāmūla": ['mw'],
    "syāt": ['ap90', 'bhs', 'ddsa', 'mw'],
    "syū": ['cae', 'gra', 'mw'],
    "syūma": ['mw'],
    "syūmagabhasti": ['gra', 'mw'],
    "syūmagṛbh": ['gra', 'mw'],
    "syūmaka": ['mw'],
    "syūman": ['cae', 'ddsa', 'gra', 'mw'],
    "syūmanyu": ['mw'],
    "syūmaraśmi": ['gra', 'mw'],
    "syūmaḥ": ['ap90'],
    "syūna": ['mw'],
    "syūnaḥ": ['ap90'],
    "syūnā": ['mw'],
    "syūta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "syūti": ['mw'],
    "syūtiḥ": ['ap90'],
    "sā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sābarṇika": ['mw'],
    "sābdī": ['ap90', 'mw'],
    "sābhayadakṣiṇam": ['mw'],
    "sābhicaraṇika": ['mw'],
    "sābhijñāna": ['cae', 'mw'],
    "sābhijñānam": ['mw'],
    "sābhijñānayuta": ['mw'],
    "sābhikāma": ['cae', 'ddsa', 'mw'],
    "sābhilāṣa": ['cae', 'mw'],
    "sābhilāṣam": ['mw'],
    "sābhimāna": ['cae', 'mw'],
    "sābhimānam": ['mw'],
    "sābhinayam": ['mw'],
    "sābhiniveśa": ['mw'],
    "sābhiprāya": ['cae', 'mw'],
    "sābhisara": ['mw'],
    "sābhisaṃskāra": ['bhs'],
    "sābhisaṃskāraparinirvāyin": ['mw'],
    "sābhitāpa": ['mw'],
    "sābhiśaṅka": ['mw'],
    "sābhoga": ['bhs'],
    "sābhra": ['cae', 'mw'],
    "sābhramatī": ['mw'],
    "sābhramatīmāhātmya": ['mw'],
    "sābhravatī": ['mw'],
    "sābhraṅgikā": ['mw'],
    "sābhri": ['mw'],
    "sābhyarthana": ['ddsa', 'mw'],
    "sābhyasūya": ['ap90', 'mw'],
    "sābhyasūyam": ['mw'],
    "sābhyāsa": ['mw'],
    "sābhāpata": ['mw'],
    "sābhāsaṃnayana": ['mw'],
    "sābhāvya": ['ddsa', 'mw'],
    "sābhīyati": ['bhs'],
    "sābrahmacāra": ['mw'],
    "sābādha": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāc": ['ddsa', 'mw'],
    "sācariyaka": ['cped'],
    "sācaya": ['mw'],
    "sāceya": ['mw'],
    "sāci": ['ap90', 'cae', 'ddsa', 'mw'],
    "sācia": ['gra'],
    "sācikāṇḍa": ['mw'],
    "sācin": ['gra', 'mw'],
    "sācismita": ['mw'],
    "sācisthita": ['mw'],
    "sācivilokita": ['mw'],
    "sācivya": ['cae', 'ddsa', 'mw'],
    "sācivyaṃ": ['ap90'],
    "sācivyākṣepa": ['mw'],
    "sācivāṭikā": ['mw'],
    "sācya": ['cae', 'gra', 'mw'],
    "sācāra": ['ddsa', 'mw'],
    "sācī": ['mw'],
    "sācīguṇa": ['ddsa', 'mw'],
    "sācīkṛ": ['cae', 'ddsa', 'mw'],
    "sācīkṛta": ['mw'],
    "sācīkṛtadṛś": ['mw'],
    "sācīkṛtam": ['mw'],
    "sācīkṛtānana": ['mw'],
    "sācīna": ['mw'],
    "sācīsūtra": ['mw'],
    "sācīvit": ['mw'],
    "sāda": ['cae', 'ddsa', 'gra', 'mw'],
    "sādada": ['mw'],
    "sādadyoni": ['gra', 'mw'],
    "sādaka": ['mw'],
    "sādamaya": ['mw'],
    "sādana": ['cae', 'ddsa', 'gra', 'mw'],
    "sādanaspṛś": ['gra', 'mw'],
    "sādanaṃ": ['ap90'],
    "sādania": ['gra'],
    "sādanya": ['cae', 'gra', 'mw'],
    "sādanī": ['mw'],
    "sādara": ['cae', 'cped', 'ddsa', 'mw'],
    "sādaram": ['mw'],
    "sādarapūrvakam": ['mw'],
    "sādaraṁ": ['cped'],
    "sādasa": ['mw'],
    "sādasata": ['mw'],
    "sādayitavya": ['cae', 'mw'],
    "sādaḥ": ['ap90'],
    "sādbhuta": ['cae', 'ddsa', 'mw'],
    "sāddāla": ['mw'],
    "sādeyya": ['mw'],
    "sādguṇya": ['ddsa', 'mw'],
    "sādh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sādha": ['cae', 'gra', 'mw'],
    "sādhadiṣṭi": ['cae', 'gra', 'mw'],
    "sādhaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sādhakasarvasva": ['mw'],
    "sādhakatama": ['mw'],
    "sādhakatamatva": ['mw'],
    "sādhakatva": ['mw'],
    "sādhakatā": ['mw'],
    "sādhakavarti": ['mw'],
    "sādhakā": ['mw'],
    "sādhamitrika": ['mw'],
    "sādhana": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sādhanabhāga": ['mw'],
    "sādhanacatuṣṭaya": ['mw'],
    "sādhanadīpikā": ['mw'],
    "sādhanaka": ['mw'],
    "sādhanakriyā": ['mw'],
    "sādhanakṣama": ['cae', 'mw'],
    "sādhanamuktāvalī": ['mw'],
    "sādhanamālātantra": ['mw'],
    "sādhananirdeśa": ['mw'],
    "sādhanapaddhati": ['mw'],
    "sādhanapattra": ['mw'],
    "sādhanapañcaka": ['mw'],
    "sādhanarūpin": ['mw'],
    "sādhanasubodhinī": ['mw'],
    "sādhanasāgara": ['mw'],
    "sādhanatva": ['mw'],
    "sādhanatā": ['ap90', 'mw'],
    "sādhanavat": ['mw'],
    "sādhanta": ['mw'],
    "sādhanā": ['ap90', 'ddsa', 'mw'],
    "sādhanādhyakṣa": ['cae', 'mw'],
    "sādhanārha": ['mw'],
    "sādhanāvyāpaka": ['mw'],
    "sādhanāvyāpakatva": ['mw'],
    "sādhanāvyāpakatā": ['mw'],
    "sādhanī": ['mw'],
    "sādhanībhūta": ['mw'],
    "sādhanīdvādaśī": ['mw'],
    "sādhanīkṛ": ['mw'],
    "sādhanīya": ['cae', 'mw'],
    "sādhanīyatva": ['mw'],
    "sādharma": ['bhs'],
    "sādharmika": ['mw'],
    "sādharmya": ['cae', 'ddsa', 'mw'],
    "sādharmyasama": ['mw'],
    "sādharmyaṃ": ['ap90'],
    "sādhase": ['mw'],
    "sādhava": ['mw'],
    "sādhaya": ['mw'],
    "sādhayitavya": ['mw'],
    "sādhayitṛ": ['mw'],
    "sādhaṃtaḥ": ['ap90'],
    "sādhenta": ['cped'],
    "sādhesi": ['cped'],
    "sādheti": ['cped'],
    "sādhetvā": ['cped'],
    "sādhia": ['gra'],
    "sādhibhūta": ['mw'],
    "sādhibhūtādhidaiva": ['mw'],
    "sādhidaiva": ['mw'],
    "sādhidaivata": ['cae', 'ddsa', 'mw'],
    "sādhika": ['cae', 'cped', 'mw'],
    "sādhikaporisa": ['cped'],
    "sādhikā": ['ap90', 'mw'],
    "sādhikṣepa": ['mw'],
    "sādhiman": ['ap90', 'mw'],
    "sādhimāna": ['mw'],
    "sādhin": ['cae', 'mw'],
    "sādhita": ['ap90', 'cped', 'ddsa', 'mw'],
    "sādhivāsa": ['mw'],
    "sādhiya": ['cped'],
    "sādhiyajña": ['mw'],
    "sādhiṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sādhiṣṭhāna": ['mw'],
    "sādhra": ['mw'],
    "sādhu": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sādhuarya": ['gra'],
    "sādhubhāva": ['mw'],
    "sādhucaraṇa": ['mw'],
    "sādhucaritra": ['mw'],
    "sādhucitta": ['cped'],
    "sādhudarśin": ['mw'],
    "sādhudatta": ['mw'],
    "sādhudevin": ['mw'],
    "sādhudevī": ['mw'],
    "sādhudhvani": ['mw'],
    "sādhudhī": ['mw'],
    "sādhudvitīya": ['mw'],
    "sādhudāyin": ['mw'],
    "sādhugata": ['mw'],
    "sādhuja": ['mw'],
    "sādhujana": ['cae', 'mw'],
    "sādhujāta": ['mw'],
    "sādhuka": ['mw'],
    "sādhukam": ['bhs'],
    "sādhukamyatā": ['cped'],
    "sādhukarman": ['cae', 'gra', 'mw'],
    "sādhukaṁ": ['cped'],
    "sādhukāra": ['cped', 'mw'],
    "sādhukārin": ['cae', 'ddsa', 'mw'],
    "sādhukīrti": ['mw'],
    "sādhukīḷana": ['cped'],
    "sādhukṛt": ['cae', 'mw'],
    "sādhukṛta": ['mw'],
    "sādhukṛtya": ['cae', 'mw'],
    "sādhukṛtyā": ['mw'],
    "sādhumantra": ['mw'],
    "sādhumat": ['mw'],
    "sādhumata": ['mw'],
    "sādhumatī": ['bhs', 'mw'],
    "sādhummanya": ['mw'],
    "sādhumātrā": ['mw'],
    "sādhunigraha": ['mw'],
    "sādhunigūhin": ['mw'],
    "sādhupadavī": ['mw'],
    "sādhuphala": ['mw'],
    "sādhuprabha": ['bhs'],
    "sādhupratikramaṇasūtra": ['mw'],
    "sādhuputra": ['mw'],
    "sādhupuṣpa": ['mw'],
    "sādhurandhin": ['mw'],
    "sādhuratnasūri": ['mw'],
    "sādhurūpa": ['bhs', 'cped'],
    "sādhusamakṣarūpa": ['mw'],
    "sādhusammata": ['cped', 'mw'],
    "sādhusamācāra": ['mw'],
    "sādhusaṃsarga": ['mw'],
    "sādhusaṃskṛta": ['cae', 'mw'],
    "sādhusiddha": ['mw'],
    "sādhutama": ['mw'],
    "sādhutara": ['mw'],
    "sādhutas": ['cae', 'mw'],
    "sādhutva": ['mw'],
    "sādhutā": ['ap90', 'cae', 'mw'],
    "sādhuvandana": ['mw'],
    "sādhuvat": ['mw'],
    "sādhuveṣa": ['mw'],
    "sādhuvigarhita": ['mw'],
    "sādhuvācaka": ['mw'],
    "sādhuvāda": ['cae', 'ddsa', 'mw'],
    "sādhuvādin": ['cae', 'mw'],
    "sādhuvāha": ['mw'],
    "sādhuvāhin": ['cae', 'mw'],
    "sādhuvṛkṣa": ['mw'],
    "sādhuvṛtta": ['cae', 'mw'],
    "sādhuvṛttatā": ['mw'],
    "sādhuvṛtti": ['mw'],
    "sādhuvṛttitā": ['mw'],
    "sādhuyā": ['cae', 'ddsa', 'mw'],
    "sādhuśabda": ['cae', 'mw'],
    "sādhuśukla": ['mw'],
    "sādhuśīla": ['cae', 'mw'],
    "sādhuśīlatva": ['mw'],
    "sādhuṣṭhāna": ['mw'],
    "sādhv": ['mw'],
    "sādhvalaṃkṛta": ['mw'],
    "sādhvanindita": ['mw'],
    "sādhvapāsanavidhi": ['mw'],
    "sādhvarya": ['cae', 'gra', 'mw'],
    "sādhvasa": ['cae', 'ddsa', 'mw'],
    "sādhvasavipluta": ['mw'],
    "sādhvasaṃ": ['ap90'],
    "sādhvasādhu": ['cae', 'ddsa', 'mw'],
    "sādhvasādhutva": ['mw'],
    "sādhvasārādhana": ['cae'],
    "sādhvācāra": ['cae', 'mw'],
    "sādhvī": ['ap90', 'ddsa', 'mw'],
    "sādhvīka": ['cae', 'mw'],
    "sādhya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sādhyakośa": ['mw'],
    "sādhyapakṣa": ['mw'],
    "sādhyapramāṇasaṃkhyāvat": ['mw'],
    "sādhyarṣi": ['mw'],
    "sādhyasama": ['mw'],
    "sādhyasamatva": ['mw'],
    "sādhyasiddha": ['mw'],
    "sādhyasiddhi": ['mw'],
    "sādhyasiddhipāda": ['mw'],
    "sādhyasādhana": ['mw'],
    "sādhyasādhanakaumudī": ['mw'],
    "sādhyasādhanakhaṇḍa": ['mw'],
    "sādhyatva": ['mw'],
    "sādhyatā": ['ap90', 'mw'],
    "sādhyatāvacchedaka": ['mw'],
    "sādhyavant": ['cae'],
    "sādhyavasānikā": ['cae', 'mw'],
    "sādhyavasānā": ['cae', 'mw'],
    "sādhyavasāya": ['mw'],
    "sādhyavat": ['ap90', 'mw'],
    "sādhyavyāpaka": ['mw'],
    "sādhyavyāpakatā": ['mw'],
    "sādhyā": ['cae', 'mw'],
    "sādhyābhāva": ['mw'],
    "sādhyāhāra": ['mw'],
    "sādhyāsa": ['mw'],
    "sādhāna": ['cae', 'mw'],
    "sādhāra": ['cped', 'ddsa', 'mw'],
    "sādhāraṇa": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sādhāraṇadeva": ['mw'],
    "sādhāraṇadeśa": ['mw'],
    "sādhāraṇadhana": ['mw'],
    "sādhāraṇadharma": ['mw'],
    "sādhāraṇagrantha": ['mw'],
    "sādhāraṇakroḍa": ['mw'],
    "sādhāraṇam": ['mw'],
    "sādhāraṇanyāsa": ['mw'],
    "sādhāraṇapakṣa": ['mw'],
    "sādhāraṇaprāyaścittasaṃgraha": ['mw'],
    "sādhāraṇapūrvapakṣarahasya": ['mw'],
    "sādhāraṇarahasya": ['mw'],
    "sādhāraṇastrī": ['mw'],
    "sādhāraṇatva": ['mw'],
    "sādhāraṇatā": ['ap90', 'mw'],
    "sādhāraṇavratapratiṣṭhāprayoga": ['mw'],
    "sādhāraṇavāda": ['mw'],
    "sādhāraṇya": ['cae', 'ddsa', 'mw'],
    "sādhāraṇyaṃ": ['ap90'],
    "sādhāraṇyā": ['mw'],
    "sādhāraṇāsādhāraṇānupasaṃhārivirodhagrantha": ['mw'],
    "sādhāraṇāsādhāraṇānupasaṃhārivirodhin": ['mw'],
    "sādhāraṇī": ['ap90', 'mw'],
    "sādhāraṇībhū": ['mw'],
    "sādhāraṇīkṛ": ['ap90', 'ddsa', 'mw'],
    "sādhārita": ['mw'],
    "sādhīyas": ['ap90', 'mw'],
    "sādhīyaṃs": ['cae'],
    "sādhūkta": ['mw'],
    "sādhṛta": ['mw'],
    "sādhṛtaṃ": ['ap90'],
    "sādi": ['cae', 'mw'],
    "sādin": ['ap90', 'cae', 'ddsa', 'mw'],
    "sādisa": ['cped'],
    "sādita": ['ap90', 'cped', 'mw'],
    "sāditva": ['mw'],
    "sādiyamāna": ['cped'],
    "sādiyana": ['cped'],
    "sādiyanta": ['cped'],
    "sādiyanā": ['cped'],
    "sādiyati": ['cped'],
    "sādiyi": ['cped'],
    "sādiyitvā": ['cped'],
    "sādiḥ": ['ap90'],
    "sādu": ['cped'],
    "sādurasa": ['cped'],
    "sādutara": ['cped'],
    "sādya": ['bhs', 'cae', 'mw'],
    "sādyanta": ['mw'],
    "sādyantam": ['mw'],
    "sādyaska": ['ap90', 'ddsa', 'mw'],
    "sādyaskra": ['mw'],
    "sādyaskraprayoga": ['mw'],
    "sādyaḥkra": ['mw'],
    "sādyaṃta": ['ap90'],
    "sādyoja": ['mw'],
    "sādāna": ['cped'],
    "sādāśiva": ['mw'],
    "sādīnava": ['mw'],
    "sādīyati": ['bhs'],
    "sādṛśa": ['bhs', 'mw'],
    "sādṛśaka": ['bhs'],
    "sādṛśya": ['cae', 'mw'],
    "sādṛśyavāda": ['mw'],
    "sādṛśyaṃ": ['ap90'],
    "sādṛśī": ['ddsa', 'mw'],
    "sādṛśīya": ['mw'],
    "sāgama": ['mw'],
    "sāgamaka": ['mw'],
    "sāgara": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sāgarabuddhi": ['bhs'],
    "sāgarabuddhidhārin": ['bhs'],
    "sāgarabuddhidhāryabhijñagupta": ['mw'],
    "sāgaracandra": ['mw'],
    "sāgaradatta": ['cae', 'mw'],
    "sāgaradeva": ['mw'],
    "sāgaradhara": ['mw'],
    "sāgaradharapuruṣa": ['bhs'],
    "sāgaradhvaja": ['bhs'],
    "sāgaradhīracetas": ['mw'],
    "sāgaraga": ['cae', 'mw'],
    "sāgaragama": ['mw'],
    "sāgaragambhīra": ['mw'],
    "sāgaragambhīrā": ['bhs', 'mw'],
    "sāgaragarbha": ['bhs'],
    "sāgaraghoṣa": ['bhs'],
    "sāgaragā": ['mw'],
    "sāgaragāmin": ['cae', 'mw'],
    "sāgaragāminī": ['mw'],
    "sāgaragāsuta": ['mw'],
    "sāgaraka": ['cae', 'mw'],
    "sāgarakukṣi": ['bhs', 'mw'],
    "sāgaralipi": ['bhs', 'mw'],
    "sāgaramati": ['bhs', 'mw'],
    "sāgaramatisūtra": ['bhs'],
    "sāgaramegha": ['bhs', 'mw'],
    "sāgaramekhala": ['cae', 'mw'],
    "sāgaramekhalā": ['mw'],
    "sāgaramerucandra": ['bhs'],
    "sāgaramudrā": ['bhs', 'mw'],
    "sāgaramukha": ['bhs'],
    "sāgaranandin": ['mw'],
    "sāgaranemi": ['mw'],
    "sāgaranemī": ['mw'],
    "sāgaranigarjitasvara": ['bhs'],
    "sāgaranāgarājaparipṛcchā": ['bhs', 'mw'],
    "sāgaraparipṛcchā": ['mw'],
    "sāgaraparyanta": ['cae', 'mw'],
    "sāgaraplavana": ['mw'],
    "sāgarapura": ['mw'],
    "sāgaraputra": ['bhs'],
    "sāgarapāla": ['mw'],
    "sāgararāja": ['bhs'],
    "sāgarasamṛddhi": ['bhs'],
    "sāgarasaṃhitā": ['mw'],
    "sāgarasūnu": ['mw'],
    "sāgaratva": ['mw'],
    "sāgaratīra": ['bhs'],
    "sāgaravarabuddhivikrīḍitābhijña": ['bhs'],
    "sāgaravaradhara": ['mw'],
    "sāgaravaradharabuddhivikrīḍitābhijña": ['bhs', 'mw'],
    "sāgaravarman": ['mw'],
    "sāgaravat": ['mw'],
    "sāgaravati": ['bhs'],
    "sāgaravyūhagarbha": ['bhs', 'mw'],
    "sāgaravāsin": ['cae', 'mw'],
    "sāgaravīra": ['mw'],
    "sāgaraśaya": ['mw'],
    "sāgaraśiri": ['bhs'],
    "sāgaraśukti": ['cae', 'mw'],
    "sāgaraḥ": ['ap90'],
    "sāgaraṃgama": ['mw'],
    "sāgareśvaratīrtha": ['mw'],
    "sāgarika": ['mw'],
    "sāgarikā": ['ddsa', 'mw'],
    "sāgarikāmaya": ['cae', 'mw'],
    "sāgarodaka": ['mw'],
    "sāgaroddhūtaniḥsvana": ['mw'],
    "sāgarodgāra": ['mw'],
    "sāgaropama": ['mw'],
    "sāgarottha": ['mw'],
    "sāgarālaya": ['mw'],
    "sāgarāmbara": ['cae', 'mw'],
    "sāgarāmbarā": ['mw'],
    "sāgarāmbuda": ['bhs'],
    "sāgarāmburaśana": ['mw'],
    "sāgarānta": ['cae', 'mw'],
    "sāgarāntargata": ['mw'],
    "sāgarānukūla": ['mw'],
    "sāgarānūpaka": ['mw'],
    "sāgarāpāṅga": ['mw'],
    "sāgarāvarta": ['mw'],
    "sāgarāya": ['mw'],
    "sāgas": ['cae', 'ddsa', 'mw'],
    "sāgata": ['cped'],
    "sāgataṁ": ['cped'],
    "sāgni": ['ap90', 'cae', 'mw'],
    "sāgnicitya": ['mw'],
    "sāgnidhūma": ['mw'],
    "sāgnika": ['ap90', 'cae', 'mw'],
    "sāgnikavidhi": ['mw'],
    "sāgnipurogama": ['mw'],
    "sāgniratnākara": ['mw'],
    "sāgra": ['ap90', 'cae', 'mw'],
    "sāgraha": ['mw'],
    "sāgraham": ['mw'],
    "sāgram": ['mw'],
    "sāgrayaṇāgnyādhānaprayoga": ['mw'],
    "sāguṇya": ['mw'],
    "sāgāra": ['cped'],
    "sāh": ['cae', 'ddsa', 'mw'],
    "sāha": ['cae', 'ddsa', 'gra', 'mw'],
    "sāhacara": ['mw'],
    "sāhacarya": ['cae', 'ddsa', 'mw'],
    "sāhacaryaṃ": ['ap90'],
    "sāhadeva": ['mw'],
    "sāhadevaka": ['mw'],
    "sāhadevi": ['ddsa', 'mw'],
    "sāhadevia": ['gra'],
    "sāhadevya": ['gra', 'mw'],
    "sāhajika": ['ddsa', 'mw'],
    "sāhajit": ['mw'],
    "sāhakāyana": ['mw'],
    "sāhana": ['mw'],
    "sāhanaṃ": ['ap90'],
    "sāhantya": ['cae', 'mw'],
    "sāhapadīna": ['mw'],
    "sāhartavya": ['bhs'],
    "sāhasa": ['cae', 'cped', 'ddsa', 'mw'],
    "sāhasaikarasika": ['mw'],
    "sāhasaikāntarasānuvartin": ['mw'],
    "sāhasakaraṇa": ['cae', 'mw'],
    "sāhasakarmatā": ['cae', 'mw'],
    "sāhasakārin": ['cae', 'mw'],
    "sāhasalāñchana": ['mw'],
    "sāhasasika": ['cped'],
    "sāhasavat": ['mw'],
    "sāhasaṃ": ['ap90'],
    "sāhasika": ['cae', 'ddsa', 'mw'],
    "sāhasikatā": ['mw'],
    "sāhasikaḥ": ['ap90'],
    "sāhasikya": ['mw'],
    "sāhasin": ['ap90', 'mw'],
    "sāhasopanyāsin": ['cae', 'mw'],
    "sāhasra": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "sāhasracūḍika": ['bhs', 'mw'],
    "sāhasraka": ['cae', 'mw'],
    "sāhasrapramardanī": ['bhs'],
    "sāhasravant": ['cae'],
    "sāhasravat": ['mw'],
    "sāhasravedhin": ['mw'],
    "sāhasraśas": ['cae', 'mw'],
    "sāhasri": ['ddsa', 'mw'],
    "sāhasrika": ['bhs', 'cae', 'mw'],
    "sāhasrādya": ['mw'],
    "sāhasrāntya": ['mw'],
    "sāhasrānīka": ['mw'],
    "sāhasrī": ['bhs'],
    "sāhasādhyavasāyin": ['mw'],
    "sāhasāṅka": ['mw'],
    "sāhasāṅkacarita": ['mw'],
    "sāhasāṅkīya": ['mw'],
    "sāhatthika": ['cped'],
    "sāhavadīna": ['mw'],
    "sāhaya": ['mw'],
    "sāhañja": ['mw'],
    "sāhañjanī": ['mw'],
    "sāhañji": ['mw'],
    "sāhaṃjanī": ['bhs'],
    "sāhaṃkāra": ['cae', 'mw'],
    "sāhaṃkāratā": ['mw'],
    "sāhaṃkṛta": ['mw'],
    "sāhaṅkāra": ['ddsa'],
    "sāhebrām": ['mw'],
    "sāhi": ['mw'],
    "sāhia": ['gra'],
    "sāhideva": ['mw'],
    "sāhika": ['bhs'],
    "sāhila": ['mw'],
    "sāhisujā": ['mw'],
    "sāhitya": ['cae', 'ddsa', 'mw'],
    "sāhityabodha": ['mw'],
    "sāhityacandrikā": ['mw'],
    "sāhityacintāmaṇi": ['mw'],
    "sāhityacūḍāmaṇi": ['mw'],
    "sāhityadarpaṇa": ['cae', 'mw'],
    "sāhityadīpikā": ['mw'],
    "sāhityahṛdayadarpaṇa": ['mw'],
    "sāhityakalpadruma": ['mw'],
    "sāhityakalpapallavī": ['mw'],
    "sāhityakaumudī": ['mw'],
    "sāhityakautūhala": ['mw'],
    "sāhityakaṇṭhoddhāra": ['mw'],
    "sāhityamuktāmaṇi": ['mw'],
    "sāhityamīmāṃsā": ['mw'],
    "sāhityaratnamālā": ['mw'],
    "sāhityaratnākara": ['mw'],
    "sāhityasaraṇīvyākhyā": ['mw'],
    "sāhityasarvasva": ['mw'],
    "sāhityasaṃgraha": ['mw'],
    "sāhityasudhā": ['mw'],
    "sāhityasudhāsamudra": ['mw'],
    "sāhityasāmrājya": ['mw'],
    "sāhityasāra": ['mw'],
    "sāhityasūcī": ['mw'],
    "sāhityasūkṣmasaraṇi": ['mw'],
    "sāhityataraṃgiṇī": ['mw'],
    "sāhityavicāra": ['mw'],
    "sāhityavidhyādhara": ['mw'],
    "sāhityaśārṅgadhara": ['mw'],
    "sāhityaśāstra": ['mw'],
    "sāhityaṃ": ['ap90'],
    "sāhityena": ['mw'],
    "sāhitī": ['mw'],
    "sāhivīci": ['mw'],
    "sāhlāda": ['cae', 'mw'],
    "sāhlādam": ['mw'],
    "sāhna": ['cae', 'ddsa', 'mw'],
    "sāhnoka": ['mw'],
    "sāhnātirātra": ['mw'],
    "sāhoḍha": ['bhs'],
    "sāhu": ['cped'],
    "sāhula": ['mw'],
    "sāhuḍiyāna": ['mw'],
    "sāhuḍīpāla": ['mw'],
    "sāhva": ['cae', 'mw'],
    "sāhvan": ['mw'],
    "sāhvas": ['gra', 'mw'],
    "sāhvaya": ['mw'],
    "sāhvayaḥ": ['ap90'],
    "sāhvya": ['mw'],
    "sāhya": ['cae', 'ddsa', 'gra', 'mw'],
    "sāhyakara": ['mw'],
    "sāhyakṛt": ['mw'],
    "sāhyaṃ": ['ap90'],
    "sāhānusāhi": ['mw'],
    "sāhāra": ['cped'],
    "sāhāya": ['mw'],
    "sāhāyaka": ['cae', 'ddsa', 'mw'],
    "sāhāyakaṃ": ['ap90'],
    "sāhāyya": ['cae', 'ddsa', 'mw'],
    "sāhāyyadāna": ['mw'],
    "sāhāyyaka": ['cae', 'mw'],
    "sāhāyyakara": ['mw'],
    "sāhāyyaṃ": ['ap90'],
    "sāja": ['mw'],
    "sājoka": ['mw'],
    "sājya": ['mw'],
    "sājātya": ['cae', 'ddsa', 'mw'],
    "sājātyalakṣaṇaprakāśa": ['mw'],
    "sājātyaṃ": ['ap90'],
    "sāka": ['cped', 'mw'],
    "sākac": ['mw'],
    "sākacchā": ['cped'],
    "sākala": ['mw'],
    "sākali": ['bhs', 'mw'],
    "sākalikā": ['mw'],
    "sākalya": ['cae', 'cped', 'ddsa', 'mw'],
    "sākalyaka": ['mw'],
    "sākalyavacana": ['mw'],
    "sākalyaṃ": ['ap90'],
    "sākalyena": ['mw'],
    "sākalāyana": ['mw'],
    "sākam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sākamaśva": ['ddsa', 'mw'],
    "sākamaśvatva": ['mw'],
    "sākamedha": ['mw'],
    "sākamprasthāyya": ['mw'],
    "sākamprasthāyīya": ['mw'],
    "sākamukṣ": ['cae', 'gra', 'mw'],
    "sākapaṇṇa": ['cped'],
    "sākaruṇḍa": ['mw'],
    "sākarṇakya": ['mw'],
    "sākarṇakāyana": ['mw'],
    "sākaṃ": ['ap90', 'mw'],
    "sākaṃgarbha": ['mw'],
    "sākaṃja": ['cae', 'gra', 'mw'],
    "sākaṃvṛdh": ['cae', 'gra', 'mw'],
    "sākaṃvṛt": ['cae', 'mw'],
    "sākaṃyuj": ['cae', 'gra', 'mw'],
    "sākaṭika": ['cped'],
    "sāketa": ['cae', 'ddsa', 'mw'],
    "sāketaka": ['mw'],
    "sāketakaḥ": ['ap90'],
    "sāketamāhātmya": ['mw'],
    "sāketana": ['mw'],
    "sāketapurāṇa": ['mw'],
    "sāketaṃ": ['ap90'],
    "sāketu": ['mw'],
    "sāketā": ['bhs'],
    "sākheya": ['ap90', 'mw'],
    "sākhi": ['mw'],
    "sākhia": ['gra'],
    "sākhidatteya": ['mw'],
    "sākhilya": ['bhs', 'mw'],
    "sākhilyaka": ['bhs'],
    "sākhya": ['cae', 'ddsa', 'gra', 'mw'],
    "sākhyaṃ": ['ap90'],
    "sākhā": ['cped'],
    "sākhābhaṅga": ['cped'],
    "sākhāmiga": ['cped'],
    "sākhānagara": ['cped'],
    "sākhāpalāsa": ['cped'],
    "sākhī": ['cped'],
    "sākiya": ['cped'],
    "sākiyānī": ['cped'],
    "sākoka": ['mw'],
    "sākoṭaka": ['mw'],
    "sāktava": ['mw'],
    "sāktuka": ['mw'],
    "sāktukaṃ": ['ap90'],
    "sāktusaindhava": ['mw'],
    "sākula": ['mw'],
    "sākuntika": ['cped'],
    "sākuruṇḍa": ['mw'],
    "sākuṇika": ['cped'],
    "sākāmprāttāyana": ['mw'],
    "sākāra": ['mw'],
    "sākārajñānavāda": ['mw'],
    "sākāram": ['mw'],
    "sākārasiddhi": ['mw'],
    "sākāśa": ['mw'],
    "sākāṃkṣa": ['ap90'],
    "sākāṅkṣa": ['cae', 'ddsa', 'mw'],
    "sākāṅkṣam": ['mw'],
    "sākāṅkṣatva": ['mw'],
    "sākāṅkṣatā": ['mw'],
    "sākūta": ['ap90', 'cae', 'mw'],
    "sākūtahasita": ['mw'],
    "sākūtam": ['mw'],
    "sākūtasmita": ['mw'],
    "sākṣ": ['mw'],
    "sākṣa": ['mw'],
    "sākṣara": ['cae', 'mw'],
    "sākṣaratā": ['mw'],
    "sākṣata": ['cae', 'ddsa', 'mw'],
    "sākṣatam": ['mw'],
    "sākṣatapātrahasta": ['mw'],
    "sākṣepa": ['ap90', 'cae', 'ddsa', 'mw'],
    "sākṣepam": ['mw'],
    "sākṣi": ['mw'],
    "sākṣibhāvita": ['mw'],
    "sākṣibhūta": ['ddsa', 'mw'],
    "sākṣidvaidha": ['mw'],
    "sākṣika": ['cae', 'ddsa', 'mw'],
    "sākṣilakṣaṇa": ['mw'],
    "sākṣimant": ['cae'],
    "sākṣimat": ['mw'],
    "sākṣimātra": ['mw'],
    "sākṣimātrākṛ": ['mw'],
    "sākṣin": ['ap90', 'cae', 'ddsa', 'mw'],
    "sākṣiparīkṣaṇa": ['mw'],
    "sākṣiparīkṣā": ['mw'],
    "sākṣipratyaya": ['mw'],
    "sākṣipraśna": ['cae', 'mw'],
    "sākṣipraśnavidhāna": ['mw'],
    "sākṣiptam": ['mw'],
    "sākṣitva": ['mw'],
    "sākṣitā": ['cae', 'mw'],
    "sākṣivat": ['mw'],
    "sākṣya": ['cae', 'ddsa', 'mw'],
    "sākṣyaṃ": ['ap90'],
    "sākṣād": ['mw'],
    "sākṣādbhū": ['mw'],
    "sākṣāddharma": ['mw'],
    "sākṣāddṛṣṭa": ['mw'],
    "sākṣāddṛṣṭi": ['mw'],
    "sākṣākaroti": ['bhs'],
    "sākṣāt": ['ap90', 'cae', 'ddsa', 'mw'],
    "sākṣātkara": ['mw'],
    "sākṣātkaraṇa": ['mw'],
    "sākṣātkartavya": ['mw'],
    "sākṣātkartṛ": ['mw'],
    "sākṣātkriyā": ['bhs', 'cae', 'mw'],
    "sākṣātkāra": ['cae', 'mw'],
    "sākṣātkāratā": ['mw'],
    "sākṣātkāravat": ['mw'],
    "sākṣātkārin": ['mw'],
    "sākṣātkṛ": ['mw'],
    "sākṣātkṛta": ['mw'],
    "sākṣātkṛtadharman": ['mw'],
    "sākṣātkṛti": ['cae', 'mw'],
    "sākṣātpuruṣottamavākya": ['mw'],
    "sākṣī": ['mw'],
    "sākṣībhū": ['mw'],
    "sākṣīka": ['mw'],
    "sākṣīkaroti": ['bhs'],
    "sākṣīkriyā": ['bhs'],
    "sākṣīkṛ": ['cae', 'mw'],
    "sāla": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sālabala": ['mw'],
    "sālabalā": ['bhs'],
    "sālabhañjaka": ['bhs'],
    "sālacandra": ['mw'],
    "sālaga": ['mw'],
    "sālagasūḍaka": ['mw'],
    "sālagasūḍanṛtya": ['mw'],
    "sālagrāma": ['mw'],
    "sālaka": ['cae', 'ddsa', 'mw'],
    "sālaki": ['mw'],
    "sālaktaka": ['cae', 'mw'],
    "sālakānana": ['cae'],
    "sālakṣaṇya": ['mw'],
    "sālalaṭṭhi": ['cped'],
    "sālamba": ['mw'],
    "sālambana": ['mw'],
    "sālambha": ['bhs'],
    "sālana": ['mw'],
    "sālanaḥ": ['ap90'],
    "sālaniryāsa": ['mw'],
    "sālarukkha": ['cped'],
    "sālarāja": ['bhs'],
    "sālasa": ['cae', 'mw'],
    "sālavana": ['cped', 'mw'],
    "sālavāhana": ['mw'],
    "sālaya": ['cped'],
    "sālaḥ": ['ap90'],
    "sālaṃkāra": ['mw'],
    "sālekhika": ['bhs'],
    "sālendradhvajāgravatī": ['bhs'],
    "sālendrarāja": ['bhs', 'mw'],
    "sālendrarājaśrigarbha": ['bhs'],
    "sāleyaṃ": ['ap90'],
    "sāleyikā": ['mw'],
    "sāleyī": ['mw'],
    "sālha": ['mw'],
    "sālhaṇa": ['ddsa', 'mw'],
    "sālhaṇi": ['mw'],
    "sālhāda": ['ddsa'],
    "sāli": ['cped'],
    "sālibalā": ['bhs'],
    "sālibhatta": ['cped'],
    "sāligabbha": ['cped'],
    "sālikkhetta": ['cped'],
    "sālikā": ['cped', 'mw'],
    "sālimañjari": ['mw'],
    "sālinda": ['cped'],
    "sālittakasippa": ['cped'],
    "sālivāhana": ['mw'],
    "sāliṅgya": ['mw'],
    "sālohita": ['bhs', 'cped', 'mw'],
    "sāloke": ['cped'],
    "sālokya": ['cae', 'ddsa', 'mw'],
    "sālokyatā": ['mw'],
    "sālokyaṃ": ['ap90'],
    "sālokyādicatuṣṭaya": ['mw'],
    "sālopa": ['mw'],
    "sāluka": ['cped'],
    "sālva": ['mw'],
    "sālvaḥ": ['ap90'],
    "sālvikaḥ": ['ap90'],
    "sālā": ['ap90', 'cped', 'mw'],
    "sālākarī": ['mw'],
    "sālākiya": ['cped'],
    "sālāraṃ": ['ap90'],
    "sālāturīya": ['mw'],
    "sālāvṛka": ['cae', 'ddsa', 'gra', 'mw'],
    "sālāvṛkeya": ['mw'],
    "sālāvṛkīya": ['mw'],
    "sālūra": ['mw'],
    "sālūraḥ": ['ap90'],
    "sāl̤hṛ": ['mw'],
    "sām": ['ap90', 'mw'],
    "sāma": ['bhs', 'cae', 'cped', 'mw'],
    "sāmabhilaṣati": ['bhs'],
    "sāmabhṛt": ['gra', 'mw'],
    "sāmabrāhmaṇa": ['mw'],
    "sāmacca": ['cped'],
    "sāmacodanā": ['mw'],
    "sāmadarpaṇa": ['mw'],
    "sāmadaṇḍa": ['cae'],
    "sāmadharmārthanītimat": ['mw'],
    "sāmadhvani": ['cae', 'mw'],
    "sāmaga": ['cae', 'ddsa', 'mw'],
    "sāmagaprayoga": ['mw'],
    "sāmagapūrvāpara": ['mw'],
    "sāmagarbha": ['mw'],
    "sāmagavṛṣotsarga": ['mw'],
    "sāmagaṇa": ['mw'],
    "sāmaggi": ['cped'],
    "sāmaggiya": ['cped'],
    "sāmagir": ['mw'],
    "sāmagrya": ['mw'],
    "sāmagryaṃ": ['ap90'],
    "sāmagrī": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "sāmagrīpratibadhyatā": ['mw'],
    "sāmagrīpratibandhakatāvāda": ['mw'],
    "sāmagrīsahacāra": ['mw'],
    "sāmagrīvicāra": ['mw'],
    "sāmagrīvyāpti": ['mw'],
    "sāmagrīvyāptivicāra": ['mw'],
    "sāmagrīvāda": ['mw'],
    "sāmagrīvādārtha": ['mw'],
    "sāmagā": ['cae', 'gra', 'mw'],
    "sāmagāhnika": ['mw'],
    "sāmagāna": ['cae', 'mw'],
    "sāmagānapriya": ['mw'],
    "sāmagānāṃchandas": ['mw'],
    "sāmagāya": ['cae', 'mw'],
    "sāmagāyaka": ['mw'],
    "sāmagāyin": ['mw'],
    "sāmagī": ['mw'],
    "sāmagīta": ['mw'],
    "sāmaja": ['ddsa', 'mw'],
    "sāmajāta": ['mw'],
    "sāmajātaka": ['mw'],
    "sāmaka": ['ap90', 'cae', 'mw'],
    "sāmakalam": ['mw'],
    "sāmakaṃ": ['ap90'],
    "sāmakārikā": ['mw'],
    "sāmakārin": ['mw'],
    "sāmakṣa": ['mw'],
    "sāmakṣya": ['mw'],
    "sāmalakṣaṇa": ['mw'],
    "sāmam": ['bhs'],
    "sāmamaya": ['cae', 'mw'],
    "sāman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sāmana": ['ap90', 'ddsa', 'gra', 'mw'],
    "sāmanaka": ['bhs'],
    "sāmanasī": ['mw'],
    "sāmania": ['gra'],
    "sāmanidhana": ['mw'],
    "sāmanta": ['cae', 'cped', 'ddsa', 'mw'],
    "sāmantacakra": ['mw'],
    "sāmantaja": ['mw'],
    "sāmantaka": ['bhs'],
    "sāmantakena": ['mw'],
    "sāmantapratyaya": ['mw'],
    "sāmantapāla": ['mw'],
    "sāmantarāja": ['mw'],
    "sāmantavāsin": ['cae', 'mw'],
    "sāmanteya": ['mw'],
    "sāmanvat": ['mw'],
    "sāmanvin": ['mw'],
    "sāmanya": ['gra', 'mw'],
    "sāmanyaḥ": ['ap90'],
    "sāmanī": ['ap90', 'mw'],
    "sāmapariśiṣṭa": ['mw'],
    "sāmapatha": ['mw'],
    "sāmapavitra": ['mw'],
    "sāmapradhāna": ['mw'],
    "sāmapragātha": ['ddsa', 'mw'],
    "sāmaprakāśana": ['mw'],
    "sāmaprastotṛtva": ['mw'],
    "sāmaprayoga": ['mw'],
    "sāmapuṣpi": ['mw'],
    "sāmapūrva": ['mw'],
    "sāmapūrvam": ['mw'],
    "sāmara": ['mw'],
    "sāmarathaṃtara": ['mw'],
    "sāmareya": ['mw'],
    "sāmarghya": ['mw'],
    "sāmarika": ['mw'],
    "sāmarthya": ['cae', 'ddsa', 'mw'],
    "sāmarthyabandhana": ['mw'],
    "sāmarthyahīna": ['cae', 'mw'],
    "sāmarthyavant": ['cae'],
    "sāmarthyavat": ['mw'],
    "sāmarthyayoga": ['mw'],
    "sāmarthyaṃ": ['ap90'],
    "sāmarādhipa": ['mw'],
    "sāmarāga": ['mw'],
    "sāmarāja": ['mw'],
    "sāmarājan": ['mw'],
    "sāmarṣa": ['cae', 'ddsa', 'mw'],
    "sāmarṣahāsam": ['mw'],
    "sāmarṣam": ['mw'],
    "sāmarṣatā": ['mw'],
    "sāmarṣaṇa": ['mw'],
    "sāmasaras": ['mw'],
    "sāmasarasa": ['mw'],
    "sāmasaṃgāyaka": ['mw'],
    "sāmasaṃhitā": ['mw'],
    "sāmasaṃkhyā": ['mw'],
    "sāmasaṃkṣepa": ['mw'],
    "sāmasiddha": ['mw'],
    "sāmasiddhi": ['mw'],
    "sāmasta": ['mw'],
    "sāmastambi": ['mw'],
    "sāmasthya": ['mw'],
    "sāmastika": ['mw'],
    "sāmastya": ['mw'],
    "sāmasurasa": ['mw'],
    "sāmasādhya": ['mw'],
    "sāmasāvitrī": ['mw'],
    "sāmasūkta": ['mw'],
    "sāmasūtra": ['mw'],
    "sāmasūtravyākhyā": ['mw'],
    "sāmatantra": ['mw'],
    "sāmatas": ['cae', 'mw'],
    "sāmatejas": ['mw'],
    "sāmato": ['bhs'],
    "sāmatthiya": ['cped'],
    "sāmatva": ['ddsa', 'mw'],
    "sāmavaidika": ['mw'],
    "sāmavairya": ['mw'],
    "sāmavat": ['mw'],
    "sāmavaśa": ['mw'],
    "sāmaveda": ['cae', 'mw'],
    "sāmavedacchala": ['mw'],
    "sāmavedapariśiṣṭa": ['mw'],
    "sāmavedarahasya": ['mw'],
    "sāmavedarahasyopaniṣad": ['mw'],
    "sāmavedarāj": ['mw'],
    "sāmavedasāra": ['mw'],
    "sāmavedavid": ['mw'],
    "sāmavedaśikṣā": ['mw'],
    "sāmavedopaniṣad": ['mw'],
    "sāmavedāntaga": ['mw'],
    "sāmavedārtha": ['mw'],
    "sāmavedārthaprakāśa": ['mw'],
    "sāmavedīyaraudravidhi": ['mw'],
    "sāmavedīyarudrī": ['mw'],
    "sāmavid": ['cae', 'ddsa', 'mw'],
    "sāmavidhāna": ['mw'],
    "sāmavidhānabrāhmaṇa": ['mw'],
    "sāmavipra": ['cae', 'gra', 'mw'],
    "sāmavāda": ['cae', 'ddsa', 'mw'],
    "sāmavāyika": ['ap90', 'ddsa', 'mw'],
    "sāmaya": ['ddsa', 'mw'],
    "sāmayika": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sāmayikatva": ['mw'],
    "sāmayikābhāva": ['mw'],
    "sāmayoni": ['ddsa', 'mw'],
    "sāmayugīna": ['mw'],
    "sāmayācārika": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāmayācārikasūtra": ['mw'],
    "sāmañjasya": ['ddsa', 'mw'],
    "sāmañña": ['cped'],
    "sāmaññaphala": ['cped'],
    "sāmaññatā": ['cped'],
    "sāmaśabda": ['mw'],
    "sāmaśiras": ['mw'],
    "sāmaśrautasūtra": ['mw'],
    "sāmaśravas": ['cae', 'mw'],
    "sāmaśravasa": ['mw'],
    "sāmaśrāddha": ['mw'],
    "sāmaṁ": ['cped'],
    "sāmaṃjasyaṃ": ['ap90'],
    "sāmaṃta": ['ap90'],
    "sāmaṇaka": ['cped'],
    "sāmaṇera": ['cped'],
    "sāmaṇerī": ['cped'],
    "sāmb": ['mw'],
    "sāmba": ['cae', 'ddsa', 'mw'],
    "sāmbacarita": ['mw'],
    "sāmbamuktāvalīstotra": ['mw'],
    "sāmbamūrti": ['mw'],
    "sāmbandhika": ['mw'],
    "sāmbapañcāśikā": ['mw'],
    "sāmbapradyumnaprabandha": ['mw'],
    "sāmbapura": ['mw'],
    "sāmbapurāṇa": ['mw'],
    "sāmbapurī": ['mw'],
    "sāmbara": ['mw'],
    "sāmbarya": ['mw'],
    "sāmbavatī": ['mw'],
    "sāmbavijaya": ['mw'],
    "sāmbaśiva": ['mw'],
    "sāmbeśvara": ['ddsa', 'mw'],
    "sāmbhala": ['mw'],
    "sāmbhara": ['mw'],
    "sāmbhas": ['mw'],
    "sāmbhavī": ['mw'],
    "sāmbhāṣya": ['mw'],
    "sāmbhūyi": ['mw'],
    "sāmbi": ['mw'],
    "sāmbopapurāṇa": ['mw'],
    "sāmbuvāsara": ['ddsa', 'mw'],
    "sāmbādhika": ['mw'],
    "sāmbāditya": ['mw'],
    "sāmeśvaramāhātmya": ['mw'],
    "sāmi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sāmibhukta": ['mw'],
    "sāmicita": ['mw'],
    "sāmidhena": ['cae', 'ddsa', 'mw'],
    "sāmidheni": ['mw'],
    "sāmidhenya": ['mw'],
    "sāmidhenī": ['ap90', 'mw'],
    "sāmidhenīka": ['mw'],
    "sāmigandharva": ['mw'],
    "sāmika": ['cped', 'mw'],
    "sāmikṛta": ['mw'],
    "sāmin": ['mw'],
    "sāminī": ['cped'],
    "sāmipīta": ['mw'],
    "sāmisa": ['cped'],
    "sāmisaṃsthita": ['mw'],
    "sāmita": ['mw'],
    "sāmitya": ['mw'],
    "sāmivacana": ['cped'],
    "sāmiṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "sāmmada": ['mw'],
    "sāmmanasya": ['ddsa', 'mw'],
    "sāmmatya": ['mw'],
    "sāmmeghya": ['mw'],
    "sāmmitikāyani": ['mw'],
    "sāmmodanika": ['mw'],
    "sāmmukhya": ['ddsa', 'mw'],
    "sāmmukhī": ['mw'],
    "sāmmārjina": ['mw'],
    "sāmmātra": ['mw'],
    "sāmmātura": ['mw'],
    "sāmna": ['mw'],
    "sāmnī": ['mw'],
    "sāmoda": ['mw'],
    "sāmodbhava": ['mw'],
    "sāmonmukha": ['mw'],
    "sāmopacāra": ['mw'],
    "sāmopāya": ['mw'],
    "sāmoḍha": ['mw'],
    "sāmpa": ['bhs'],
    "sāmpada": ['mw'],
    "sāmpannika": ['mw'],
    "sāmparāya": ['ddsa', 'mw'],
    "sāmparāyaṇa": ['mw'],
    "sāmparāyaṇaka": ['mw'],
    "sāmparāyika": ['mw'],
    "sāmparāyikakalpa": ['mw'],
    "sāmpradānika": ['mw'],
    "sāmpradāyika": ['ddsa', 'mw'],
    "sāmprata": ['ddsa', 'mw'],
    "sāmpratakāla": ['mw'],
    "sāmpratam": ['mw'],
    "sāmpratika": ['mw'],
    "sāmpratādhipa": ['mw'],
    "sāmprayogika": ['mw'],
    "sāmprayogikādhikaraṇa": ['mw'],
    "sāmpraśnika": ['mw'],
    "sāmpriyaka": ['mw'],
    "sāmpādika": ['ddsa', 'mw'],
    "sāmpātika": ['mw'],
    "sāmpīka": ['mw'],
    "sāmrājya": ['cae', 'ddsa', 'gra', 'mw'],
    "sāmrājyadīkṣita": ['mw'],
    "sāmrājyakṛt": ['mw'],
    "sāmrājyalakṣmīpīṭhikā": ['mw'],
    "sāmrājyalakṣmīpūjā": ['mw'],
    "sāmrājyasiddhi": ['mw'],
    "sāmrājyasiddhidā": ['mw'],
    "sāmrājyaṃ": ['ap90'],
    "sāmrāṇija": ['mw'],
    "sāmrāṇikardama": ['mw'],
    "sāmudayika": ['mw'],
    "sāmuddika": ['cped'],
    "sāmudga": ['mw'],
    "sāmudra": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "sāmudrabandhu": ['mw'],
    "sāmudraka": ['cae', 'mw'],
    "sāmudrakalekhaka": ['bhs'],
    "sāmudrakavidyā": ['mw'],
    "sāmudrakaṃ": ['ap90'],
    "sāmudraniṣkuṭa": ['mw'],
    "sāmudrasthalaka": ['mw'],
    "sāmudratilaka": ['mw'],
    "sāmudravid": ['mw'],
    "sāmudri": ['mw'],
    "sāmudrika": ['ap90', 'cae', 'mw'],
    "sāmudrikacintāmaṇi": ['mw'],
    "sāmudrikajña": ['mw'],
    "sāmudrikakaṇṭhābharaṇa": ['mw'],
    "sāmudrikalakṣaṇa": ['mw'],
    "sāmudrikasāra": ['mw'],
    "sāmudrikaśāstra": ['mw'],
    "sāmudrikā": ['mw'],
    "sāmudrikācārya": ['mw'],
    "sāmudrī": ['mw'],
    "sāmudānika": ['mw'],
    "sāmudāyika": ['mw'],
    "sāmutkarṣika": ['bhs', 'mw'],
    "sāmvṛttika": ['mw'],
    "sāmya": ['cae', 'ddsa', 'mw'],
    "sāmyabodhaka": ['mw'],
    "sāmyagrāha": ['mw'],
    "sāmyaka": ['bhs'],
    "sāmyakṣa": ['mw'],
    "sāmyatva": ['mw'],
    "sāmyatā": ['cae', 'mw'],
    "sāmyatālaviśārada": ['mw'],
    "sāmyaṃ": ['ap90'],
    "sāmyekṣa": ['mw'],
    "sāmyekṣya": ['mw'],
    "sāmyāvasthā": ['mw'],
    "sāmyāvasthāna": ['mw'],
    "sāmā": ['cped'],
    "sāmācārika": ['mw'],
    "sāmācārī": ['mw'],
    "sāmājika": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sāmāna": ['mw'],
    "sāmānadeśika": ['mw'],
    "sāmānagrāmika": ['mw'],
    "sāmānika": ['mw'],
    "sāmānta": ['mw'],
    "sāmāntarukthya": ['mw'],
    "sāmānya": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāmānyabhāva": ['mw'],
    "sāmānyabhāvagrantha": ['mw'],
    "sāmānyabhāvavyavasthāpana": ['mw'],
    "sāmānyabhāvaṭippaṇī": ['mw'],
    "sāmānyacandrikā": ['mw'],
    "sāmānyacchala": ['mw'],
    "sāmānyadeśavat": ['mw'],
    "sāmānyadhātrī": ['mw'],
    "sāmānyaghaṭa": ['mw'],
    "sāmānyahomapaddhati": ['mw'],
    "sāmānyajñāna": ['mw'],
    "sāmānyakavipraśaṃsā": ['mw'],
    "sāmānyakramavṛtti": ['mw'],
    "sāmānyalakṣaṇa": ['mw'],
    "sāmānyalakṣaṇadīdhitiṭippaṇī": ['mw'],
    "sāmānyalakṣaṇadīdhitiṭīkā": ['mw'],
    "sāmānyalakṣaṇagrantha": ['mw'],
    "sāmānyalakṣaṇakāryakāraṇabhāva": ['mw'],
    "sāmānyalakṣaṇaprakāśa": ['mw'],
    "sāmānyalakṣaṇapūrvapakṣaprakāśa": ['mw'],
    "sāmānyalakṣaṇarahasya": ['mw'],
    "sāmānyalakṣaṇavicāra": ['mw'],
    "sāmānyalakṣaṇavivecana": ['mw'],
    "sāmānyalakṣaṇavyabhicāra": ['mw'],
    "sāmānyalakṣaṇaṭippaṇī": ['mw'],
    "sāmānyalakṣaṇā": ['mw'],
    "sāmānyalakṣaṇī": ['mw'],
    "sāmānyam": ['mw'],
    "sāmānyanirukti": ['mw'],
    "sāmānyaniruktidvitīyatakṣaṇa": ['mw'],
    "sāmānyaniruktidīdhitiṭīkā": ['mw'],
    "sāmānyaniruktigrantharahasya": ['mw'],
    "sāmānyaniruktigranthārtha": ['mw'],
    "sāmānyaniruktikroḍa": ['mw'],
    "sāmānyaniruktilakṣaṇa": ['mw'],
    "sāmānyaniruktipattra": ['mw'],
    "sāmānyaniruktiprathamalakṣaṇa": ['mw'],
    "sāmānyaniruktivivecana": ['mw'],
    "sāmānyaniruktivyākhyā": ['mw'],
    "sāmānyaniruktiṭīkā": ['mw'],
    "sāmānyaniruktyabhinavavyākhyā": ['mw'],
    "sāmānyaniruktyanugama": ['mw'],
    "sāmānyanāyikā": ['mw'],
    "sāmānyapadārtha": ['mw'],
    "sāmānyapakṣa": ['mw'],
    "sāmānyapraghaṭṭaka": ['mw'],
    "sāmānyapratipattipūrvam": ['mw'],
    "sāmānyapūrvam": ['mw'],
    "sāmānyasūtra": ['mw'],
    "sāmānyatama": ['mw'],
    "sāmānyatara": ['mw'],
    "sāmānyatas": ['mw'],
    "sāmānyataḥ": ['ap90'],
    "sāmānyatodṛṣṭa": ['mw'],
    "sāmānyatva": ['mw'],
    "sāmānyavacana": ['mw'],
    "sāmānyavanitā": ['mw'],
    "sāmānyavat": ['mw'],
    "sāmānyavattva": ['mw'],
    "sāmānyavihitadravyavicāra": ['mw'],
    "sāmānyavāda": ['mw'],
    "sāmānyaśabda": ['mw'],
    "sāmānyaśabdaka": ['mw'],
    "sāmānyaśrāddhavidhi": ['mw'],
    "sāmānyaśāsana": ['mw'],
    "sāmānyaśāstra": ['mw'],
    "sāmānyā": ['mw'],
    "sāmānyābhāva": ['mw'],
    "sāmānyābhāvagrantha": ['mw'],
    "sāmānyābhāvaprakāśa": ['mw'],
    "sāmānyābhāvarahasya": ['mw'],
    "sāmānyābhāvasādhana": ['mw'],
    "sāmānyābhāvaṭippanī": ['mw'],
    "sāmānyābhāvāloka": ['mw'],
    "sāmānyādhikaraṇya": ['mw'],
    "sāmānādhikaraṇya": ['ddsa', 'mw'],
    "sāmānādhikaraṇyaṃ": ['ap90'],
    "sāmānādhikariṇya": ['cae'],
    "sāmāsika": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāmātaṭa": ['bhs'],
    "sāmātsāmya": ['mw'],
    "sāmātya": ['cae', 'ddsa', 'mw'],
    "sāmātyaka": ['mw'],
    "sāmātyapramukha": ['mw'],
    "sāmātāna": ['mw'],
    "sāmāyi": ['bhs'],
    "sāmāyika": ['mw'],
    "sāmāṅga": ['mw'],
    "sāmī": ['cped'],
    "sāmīci": ['cped'],
    "sāmīcikamma": ['cped'],
    "sāmīcipaṭipanna": ['cped'],
    "sāmīcī": ['ap90', 'bhs', 'mw'],
    "sāmīcīkaraṇīya": ['mw'],
    "sāmīcīnya": ['mw'],
    "sāmīpya": ['cae', 'ddsa', 'mw'],
    "sāmīpyaṃ": ['ap90'],
    "sāmīraṇa": ['ddsa', 'mw'],
    "sāmīrya": ['mw'],
    "sāmītī": ['bhs'],
    "sāmūhika": ['ddsa', 'mw'],
    "sāmūnā": ['mw'],
    "sāmṛddhya": ['cae', 'mw'],
    "sāmṛta": ['ddsa', 'mw'],
    "sānaga": ['cae', 'mw'],
    "sānala": ['mw'],
    "sānalaḥ": ['ap90'],
    "sānanda": ['cae', 'ddsa', 'mw'],
    "sānandagadgadapadam": ['mw'],
    "sānandagovinda": ['mw'],
    "sānandam": ['mw'],
    "sānandanī": ['mw'],
    "sānandā": ['mw'],
    "sānandāśru": ['mw'],
    "sānandūra": ['mw'],
    "sānandūramāhātmya": ['mw'],
    "sānasi": ['cae', 'ddsa', 'gra', 'mw'],
    "sānasiḥ": ['ap90'],
    "sānatkumāra": ['mw'],
    "sānatsujāta": ['mw'],
    "sānaṃda": ['ap90'],
    "sāndhakāra": ['ddsa'],
    "sāndhivigrahika": ['ddsa'],
    "sāndhya": ['ddsa'],
    "sāndilya": ['mw'],
    "sāndra": ['cae', 'ddsa', 'mw'],
    "sāndrakutūhala": ['mw'],
    "sāndramaṇi": ['mw'],
    "sāndrameha": ['mw'],
    "sāndramehin": ['mw'],
    "sāndramūtra": ['mw'],
    "sāndrapada": ['mw'],
    "sāndraprasādameha": ['mw'],
    "sāndrapuṣpa": ['mw'],
    "sāndrasnigdha": ['mw'],
    "sāndrasparśa": ['cae', 'mw'],
    "sāndratama": ['mw'],
    "sāndratara": ['mw'],
    "sāndrataram": ['mw'],
    "sāndratva": ['mw'],
    "sāndratvakka": ['mw'],
    "sāndratā": ['mw'],
    "sāndrī": ['mw'],
    "sāndrībhū": ['mw'],
    "sāndrīkṛ": ['ddsa'],
    "sāndrīkṛta": ['mw'],
    "sāndīpani": ['ddsa'],
    "sāneyikā": ['mw'],
    "sāneyī": ['mw'],
    "sānibāpa": ['mw'],
    "sānikā": ['ap90', 'mw'],
    "sānin": ['mw'],
    "sānmātura": ['mw'],
    "sānna": ['mw'],
    "sānnahanika": ['ddsa'],
    "sānntānika": ['ddsa'],
    "sānta": ['mw'],
    "sāntaka": ['mw'],
    "sāntapana": ['ddsa'],
    "sāntara": ['bhs', 'ddsa', 'mw'],
    "sāntarapluta": ['mw'],
    "sāntarbahi": ['bhs'],
    "sāntardeśa": ['mw'],
    "sāntardīpa": ['cae', 'mw'],
    "sāntarhāsa": ['cae', 'mw'],
    "sāntarhāsam": ['mw'],
    "sāntarnidāghajvaram": ['mw'],
    "sāntarottara": ['bhs', 'mw'],
    "sāntarāla": ['cae', 'mw'],
    "sāntarāya": ['mw'],
    "sāntarāyatā": ['mw'],
    "sāntaḥstha": ['mw'],
    "sāntevāsika": ['cped'],
    "sāntika": ['bhs'],
    "sāntv": ['mw'],
    "sāntva": ['cae', 'ddsa', 'mw'],
    "sāntvada": ['mw'],
    "sāntvana": ['cae', 'ddsa', 'mw'],
    "sāntvanā": ['mw'],
    "sāntvanīya": ['mw'],
    "sāntvapūrva": ['cae', 'mw'],
    "sāntvapūrvam": ['mw'],
    "sāntvatas": ['mw'],
    "sāntvavāda": ['ddsa', 'mw'],
    "sāntvay": ['cae'],
    "sāntvaya": ['ddsa'],
    "sāntvayitṛ": ['ddsa', 'mw'],
    "sāntvayā": ['mw'],
    "sāntvita": ['mw'],
    "sānu": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sānubandha": ['cae', 'mw'],
    "sānubandhaka": ['mw'],
    "sānubaṃdha": ['ap90'],
    "sānucara": ['cae', 'cped', 'mw'],
    "sānuga": ['cae', 'mw'],
    "sānuja": ['mw'],
    "sānuka": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sānukampa": ['cae', 'ddsa', 'mw'],
    "sānukampam": ['mw'],
    "sānukaṃpa": ['ap90'],
    "sānukrośa": ['ap90', 'cae', 'mw'],
    "sānukrośam": ['mw'],
    "sānukrośatā": ['mw'],
    "sānukālam": ['bhs'],
    "sānukūla": ['mw'],
    "sānukūlya": ['cae', 'mw'],
    "sānumant": ['cae'],
    "sānumat": ['ap90', 'ddsa', 'mw'],
    "sānumatī": ['mw'],
    "sānumāna": ['mw'],
    "sānunaya": ['ap90', 'cae', 'mw'],
    "sānunayam": ['mw'],
    "sānunāsika": ['mw'],
    "sānunāsikavākya": ['mw'],
    "sānunāsikavākyatva": ['mw'],
    "sānunāsikya": ['mw'],
    "sānunāsyam": ['mw'],
    "sānuplava": ['mw'],
    "sānuprastha": ['mw'],
    "sānuprāsa": ['cae', 'mw'],
    "sānuruha": ['mw'],
    "sānurāga": ['ap90', 'cae', 'mw'],
    "sānusvarita": ['mw'],
    "sānusvāra": ['mw'],
    "sānusāra": ['mw'],
    "sānutarṣam": ['mw'],
    "sānutāpa": ['cae', 'mw'],
    "sānuvajja": ['cped'],
    "sānuvakraga": ['mw'],
    "sānuvaṣaṭkāra": ['mw'],
    "sānuvāda": ['cped'],
    "sānuyātra": ['cae', 'mw'],
    "sānuśaya": ['cae', 'mw'],
    "sānuśayam": ['mw'],
    "sānuśayavighaṭita": ['cae'],
    "sānuṣak": ['gra', 'mw'],
    "sānuṣaṅga": ['mw'],
    "sānuṣṭi": ['mw'],
    "sānvaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "sānvārambhaṇīya": ['mw'],
    "sānyaputra": ['mw'],
    "sānāthya": ['cae', 'ddsa', 'mw'],
    "sānūkāśa": ['mw'],
    "sānūpa": ['mw'],
    "sāp": ['mw'],
    "sāpa": ['cped'],
    "sāpad": ['mw'],
    "sāpadesa": ['cped'],
    "sāpadeśam": ['mw'],
    "sāpagama": ['mw'],
    "sāpahnava": ['mw'],
    "sāpamāna": ['mw'],
    "sāpamānam": ['mw'],
    "sāpara": ['mw'],
    "sāparādha": ['ap90', 'cae', 'mw'],
    "sāparādhika": ['bhs'],
    "sāparānta": ['mw'],
    "sāpateya": ['bhs'],
    "sāpateyya": ['cped'],
    "sāpatna": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāpatnaka": ['bhs', 'cae', 'mw'],
    "sāpatneya": ['ddsa', 'mw'],
    "sāpatnya": ['cae', 'mw'],
    "sāpatnyaka": ['mw'],
    "sāpatnyaṃ": ['ap90'],
    "sāpatrapa": ['mw'],
    "sāpattika": ['bhs', 'cped'],
    "sāpatya": ['ddsa', 'mw'],
    "sāpavāda": ['ap90', 'cae'],
    "sāpavādaka": ['mw'],
    "sāpavādam": ['mw'],
    "sāpekha": ['cped'],
    "sāpekkha": ['cped'],
    "sāpekṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāpekṣatva": ['mw'],
    "sāpekṣatā": ['mw'],
    "sāphalya": ['cae', 'ddsa', 'mw'],
    "sāphalyaṃ": ['ap90'],
    "sāpia": ['gra'],
    "sāpiṃḍyaṃ": ['ap90'],
    "sāpiṇḍa": ['mw'],
    "sāpiṇḍi": ['mw'],
    "sāpiṇḍibhakta": ['mw'],
    "sāpiṇḍya": ['cae', 'ddsa', 'mw'],
    "sāpiṇḍyadīpikā": ['mw'],
    "sāpiṇḍyakalpalatikā": ['mw'],
    "sāpiṇḍyakalpalatā": ['mw'],
    "sāpiṇḍyamīmāṃsā": ['mw'],
    "sāpiṇḍyanirṇaya": ['mw'],
    "sāpiṇḍyaviṣaya": ['mw'],
    "sāpiṇḍīmañjarī": ['mw'],
    "sāprāyya": ['mw'],
    "sāpsarogaṇa": ['mw'],
    "sāpta": ['cae', 'gra', 'mw'],
    "sāptadaśya": ['mw'],
    "sāptaleya": ['mw'],
    "sāptalāyana": ['mw'],
    "sāptamika": ['mw'],
    "sāptapada": ['ap90', 'cae', 'mw'],
    "sāptapadīna": ['cae', 'mw'],
    "sāptapauruṣa": ['ap90', 'cae', 'mw'],
    "sāptapuruṣa": ['cae', 'mw'],
    "sāptarathavāhani": ['mw'],
    "sāptarātrika": ['mw'],
    "sāptatantava": ['ddsa', 'mw'],
    "sāptatika": ['mw'],
    "sāpti": ['mw'],
    "sāptāhika": ['bhs'],
    "sāpya": ['gra', 'mw'],
    "sāpāya": ['mw'],
    "sāpāśraya": ['mw'],
    "sāpīḍa": ['mw'],
    "sār": ['mw'],
    "sāra": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sārabhaṅga": ['mw'],
    "sārabhaṭa": ['mw'],
    "sārabhaṭṭāraka": ['mw'],
    "sārabhoga": ['mw'],
    "sārabhuj": ['mw'],
    "sārabhāṇḍa": ['cae', 'mw'],
    "sārabhāṇḍagṛhaka": ['cae', 'mw'],
    "sārabhūta": ['cae', 'mw'],
    "sārabhṛt": ['mw'],
    "sārabodhinī": ['mw'],
    "sāracandrikā": ['mw'],
    "sāracaturviṃśatikā": ['mw'],
    "sāracintāmaṇi": ['mw'],
    "sārada": ['cped'],
    "sāradarśin": ['mw'],
    "sāraddha": ['cped'],
    "sāradhvaja": ['bhs'],
    "sāradhvaji": ['mw'],
    "sāradhānya": ['mw'],
    "sāradhātṛ": ['mw'],
    "sāradika": ['cped'],
    "sāradruma": ['mw'],
    "sāradā": ['mw'],
    "sāradāru": ['mw'],
    "sāradārumaya": ['mw'],
    "sāradīpikā": ['mw'],
    "sāraga": ['mw'],
    "sāragandha": ['cped', 'mw'],
    "sāragavesī": ['cped'],
    "sāragha": ['cae', 'ddsa', 'gra', 'mw'],
    "sāraghaṃ": ['ap90'],
    "sāragrahamañjarī": ['mw'],
    "sāragrāha": ['mw'],
    "sāragrāhin": ['mw'],
    "sāragrīva": ['mw'],
    "sāraguru": ['mw'],
    "sāraguṇa": ['mw'],
    "sāragātra": ['mw'],
    "sāragītā": ['mw'],
    "sāraja": ['mw'],
    "sārajjanā": ['cped'],
    "sārajjati": ['cped'],
    "sārajji": ['cped'],
    "sārajjitvā": ['cped'],
    "sārajyati": ['bhs'],
    "sāraka": ['ap90', 'bhs', 'mw'],
    "sārakalikā": ['mw'],
    "sārakalpa": ['bhs'],
    "sārakaumudī": ['mw'],
    "sārakeya": ['mw'],
    "sārakhadira": ['mw'],
    "sārakkha": ['cped'],
    "sārakya": ['mw'],
    "sārakāyaṇa": ['mw'],
    "sārakṣetramāhātmya": ['mw'],
    "sārakṣetramāhātmyasāroddhāra": ['mw'],
    "sāralaharī": ['mw'],
    "sāraloha": ['mw'],
    "sāralya": ['cae', 'ddsa', 'mw'],
    "sāralyaṃ": ['ap90'],
    "sāramahat": ['mw'],
    "sāramaya": ['cped', 'mw'],
    "sāramañjarī": ['mw'],
    "sārambha": ['bhs', 'cped', 'mw'],
    "sārameya": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sārameyacikitsā": ['mw'],
    "sārameyagaṇādhipa": ['mw'],
    "sārameyatā": ['mw'],
    "sārameyavākya": ['mw'],
    "sārameyaḥ": ['ap90'],
    "sārameyādana": ['mw'],
    "sārameyī": ['mw'],
    "sāramiti": ['mw'],
    "sāramārgaṇa": ['mw'],
    "sāramūṣikā": ['mw'],
    "sārapada": ['mw'],
    "sārapadyāvalī": ['mw'],
    "sāraparṇī": ['mw'],
    "sārapattra": ['mw'],
    "sārapattraka": ['mw'],
    "sāraphalgu": ['cae', 'mw'],
    "sāraphalgutva": ['ddsa', 'mw'],
    "sāraphalgutā": ['mw'],
    "sārapradīpikā": ['mw'],
    "sāraprakāśikā": ['mw'],
    "sārapura": ['bhs'],
    "sārapādapa": ['mw'],
    "sārapāka": ['mw'],
    "sārarāja": ['bhs'],
    "sārarūpa": ['mw'],
    "sārarūpatā": ['mw'],
    "sāras": ['mw'],
    "sārasa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sārasadvitīya": ['mw'],
    "sārasagṛdhra": ['mw'],
    "sārasambandhapaddhati": ['mw'],
    "sārasamuccaya": ['mw'],
    "sārasana": ['cae', 'ddsa', 'mw'],
    "sārasanaṃ": ['ap90'],
    "sārasapriyā": ['mw'],
    "sārasaṃgraha": ['mw'],
    "sārasaṃgrahajñānabhūṣaṇabhāṣya": ['mw'],
    "sārasaṃgrahanighaṇṭu": ['mw'],
    "sārasaṃgrahasaṃgraha": ['mw'],
    "sārasaṃhitā": ['mw'],
    "sāraseya": ['mw'],
    "sārasi": ['bhs'],
    "sārasiddhāntakaumudī": ['mw'],
    "sārasikā": ['ddsa', 'mw'],
    "sārasindhu": ['mw'],
    "sārasundarī": ['mw'],
    "sārasvata": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sārasvatakalpa": ['mw'],
    "sārasvatakośa": ['mw'],
    "sārasvatamaṇḍana": ['mw'],
    "sārasvatamāhātmya": ['mw'],
    "sārasvataprakriyā": ['mw'],
    "sārasvataprasādaṭīkā": ['mw'],
    "sārasvatapura": ['mw'],
    "sārasvatasāra": ['mw'],
    "sārasvatasārasaṃgraha": ['mw'],
    "sārasvatasūtra": ['mw'],
    "sārasvatatantra": ['mw'],
    "sārasvatatīrtha": ['mw'],
    "sārasvatauṣadhībhū": ['mw'],
    "sārasvatavilāsa": ['mw'],
    "sārasvatavrata": ['mw'],
    "sārasvatavyākaraṇa": ['mw'],
    "sārasvatotsava": ['mw'],
    "sārasvatya": ['mw'],
    "sārasvatābhidhāna": ['mw'],
    "sārasvatādarśa": ['mw'],
    "sārasvatālaṃkāra": ['mw'],
    "sārasvatī": ['mw'],
    "sārasvatīya": ['mw'],
    "sārasvatīyaśilpaśāstra": ['mw'],
    "sārasya": ['mw'],
    "sārasyāyana": ['mw'],
    "sārasāgara": ['mw'],
    "sārasākṣa": ['mw'],
    "sārasākṣī": ['ddsa', 'mw'],
    "sārasārin": ['mw'],
    "sārasāyana": ['mw'],
    "sārasāyanabhakta": ['mw'],
    "sārasī": ['mw'],
    "sārasūci": ['cped'],
    "sāratama": ['mw'],
    "sāratamatva": ['mw'],
    "sāratara": ['ddsa', 'mw'],
    "sārataratā": ['mw'],
    "sārataru": ['mw'],
    "sāratas": ['ap90', 'cae', 'mw'],
    "sārataṇḍula": ['mw'],
    "sārathi": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sārathidvitīya": ['cae'],
    "sārathika": ['bhs'],
    "sārathipura": ['bhs'],
    "sārathipuri": ['mw'],
    "sārathitva": ['mw'],
    "sārathiḥ": ['ap90'],
    "sārathya": ['cae', 'mw'],
    "sārathyaṃ": ['ap90'],
    "sārathī": ['cped'],
    "sāratrayaculuka": ['mw'],
    "sāratta": ['cped'],
    "sāratva": ['mw'],
    "sāratā": ['cae', 'mw'],
    "sārava": ['mw'],
    "sāravant": ['cae', 'cped'],
    "sāravarjita": ['mw'],
    "sāravastu": ['mw'],
    "sāravat": ['ap90', 'ddsa', 'mw'],
    "sāravattā": ['cae', 'mw'],
    "sāravatī": ['bhs', 'mw'],
    "sāravid": ['mw'],
    "sāraya": ['mw'],
    "sārayodha": ['mw'],
    "sārayoga": ['mw'],
    "sāraśana": ['mw'],
    "sāraśanaṃ": ['ap90'],
    "sāraśūnya": ['mw'],
    "sāraṃga": ['ap90'],
    "sāraṃgikaḥ": ['ap90'],
    "sāraṃgī": ['ap90'],
    "sāraṃḍaḥ": ['ap90'],
    "sāraṅga": ['bhs', 'cae', 'ddsa', 'mw'],
    "sāraṅgadeva": ['mw'],
    "sāraṅgahāra": ['mw'],
    "sāraṅgaja": ['mw'],
    "sāraṅgajadṛś": ['mw'],
    "sāraṅgalocanā": ['cae', 'mw'],
    "sāraṅgapāṇi": ['mw'],
    "sāraṅgaraṅgadā": ['mw'],
    "sāraṅgasamuccaya": ['mw'],
    "sāraṅgasāra": ['mw'],
    "sāraṅgaśabala": ['mw'],
    "sāraṅgika": ['mw'],
    "sāraṅgākṣā": ['mw'],
    "sāraṅgākṣī": ['cae'],
    "sāraṅgī": ['cae', 'mw'],
    "sāraṅgīsārasamuccaya": ['mw'],
    "sāraṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāraṇasundara": ['mw'],
    "sāraṇeśa": ['mw'],
    "sāraṇi": ['cae', 'mw'],
    "sāraṇika": ['ap90', 'cae', 'mw'],
    "sāraṇikaghna": ['mw'],
    "sāraṇikā": ['mw'],
    "sāraṇiḥ": ['ap90'],
    "sāraṇyaka": ['mw'],
    "sāraṇā": ['ap90', 'mw'],
    "sāraṇātraya": ['mw'],
    "sāraṇī": ['mw'],
    "sāraṇīkoṣṭaka": ['mw'],
    "sāraṇīrāja": ['mw'],
    "sāraṇḍa": ['mw'],
    "sārci": ['cae', 'mw'],
    "sārcimālin": ['mw'],
    "sārcis": ['cae', 'mw'],
    "sārdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "sārdhacandra": ['mw'],
    "sārdham": ['ap90', 'mw'],
    "sārdhamātra": ['mw'],
    "sārdhasaptan": ['mw'],
    "sārdhasaṃvatsara": ['mw'],
    "sārdhavārṣika": ['mw'],
    "sārdhaśata": ['mw'],
    "sārdhaṃcara": ['bhs'],
    "sārdhaṃvihārika": ['bhs'],
    "sārdhaṃvihārin": ['mw'],
    "sārdra": ['ap90', 'cae', 'mw'],
    "sārdāgava": ['mw'],
    "sāresi": ['cped'],
    "sāretabba": ['cped'],
    "sāreti": ['cped'],
    "sāretvā": ['cped'],
    "sāreśvara": ['mw'],
    "sārgala": ['ap90', 'mw'],
    "sārgaḍa": ['mw'],
    "sārgika": ['mw'],
    "sārgāla": ['mw'],
    "sāri": ['mw'],
    "sāribā": ['cped'],
    "sārika": ['cae', 'mw'],
    "sārikā": ['ap90', 'ddsa', 'mw'],
    "sārikāmukha": ['mw'],
    "sārikāmāhātmya": ['mw'],
    "sārikāvaṇa": ['mw'],
    "sārimejaya": ['mw'],
    "sārin": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāriphala": ['mw'],
    "sāriphalaka": ['mw'],
    "sāristhākhā": ['mw'],
    "sārisṛkka": ['cae', 'mw'],
    "sārisṛkkva": ['mw'],
    "sārisṛkta": ['cae', 'mw'],
    "sārisṛkva": ['cae'],
    "sārita": ['cped'],
    "sāriva": ['ddsa', 'mw'],
    "sārivā": ['mw'],
    "sāriḥ": ['ap90'],
    "sāriṇī": ['mw'],
    "sāriṣṭa": ['ddsa', 'mw'],
    "sāriṣṭha": ['ddsa', 'mw'],
    "sāriṣṭhatva": ['mw'],
    "sārja": ['mw'],
    "sārjana": ['mw'],
    "sārjanākṣi": ['mw'],
    "sārka": ['ddsa', 'mw'],
    "sārkaṇḍeya": ['mw'],
    "sārocaya": ['bhs'],
    "sāroddhāra": ['mw'],
    "sāroddhārapaddhati": ['mw'],
    "sāroddhārasaṃgraha": ['mw'],
    "sāroddhāraśakunaparīkṣā": ['mw'],
    "sāroha": ['mw'],
    "sāropa": ['mw'],
    "sāropya": ['bhs'],
    "sāropā": ['mw'],
    "sāroṣṭika": ['mw'],
    "sāroṣṭrika": ['mw'],
    "sāroṣṭrikaḥ": ['ap90'],
    "sārpa": ['cae', 'ddsa', 'mw'],
    "sārparāja": ['mw'],
    "sārparājña": ['mw'],
    "sārparājñī": ['mw'],
    "sārpavidyika": ['mw'],
    "sārpaḥ": ['ap90'],
    "sārpiṇikā": ['mw'],
    "sārpiṣa": ['ap90', 'mw'],
    "sārpiṣka": ['mw'],
    "sārpyaḥ": ['ap90'],
    "sārpākava": ['mw'],
    "sārpākavāyaṇa": ['mw'],
    "sārtarava": ['mw'],
    "sārtha": ['ap90', 'cae', 'ddsa', 'mw'],
    "sārthabhraṃśasamudbhava": ['mw'],
    "sārthabhṛt": ['mw'],
    "sārthadhara": ['mw'],
    "sārthaghnī": ['mw'],
    "sārthahan": ['mw'],
    "sārthahīna": ['mw'],
    "sārthaja": ['cae', 'mw'],
    "sārthaka": ['ap90', 'bhs', 'cae', 'mw'],
    "sārthakatva": ['mw'],
    "sārthakatā": ['mw'],
    "sārthamaṇḍala": ['mw'],
    "sārthapati": ['cae', 'mw'],
    "sārthapāla": ['cae', 'mw'],
    "sārthasaṃcaya": ['mw'],
    "sārthavat": ['ap90', 'mw'],
    "sārthavāha": ['bhs', 'cae', 'mw'],
    "sārthavāhaka": ['bhs'],
    "sārthavāhana": ['mw'],
    "sārthavāhavacas": ['mw'],
    "sārthaya": ['mw'],
    "sārtheśa": ['mw'],
    "sārthika": ['cae', 'ddsa', 'mw'],
    "sārthikaḥ": ['ap90'],
    "sārthīkṛ": ['mw'],
    "sārti": ['mw'],
    "sārtra": ['mw'],
    "sāru": ['mw'],
    "sārundhatīka": ['ddsa', 'mw'],
    "sāruppa": ['cped'],
    "sārva": ['ap90', 'cae', 'ddsa', 'mw'],
    "sārvabhauma": ['ap90', 'cae', 'mw'],
    "sārvabhaumabhavana": ['mw'],
    "sārvabhaumagṛha": ['mw'],
    "sārvabhaumasarvasverāmasūkta": ['mw'],
    "sārvabhaumasiddhānta": ['mw'],
    "sārvabhaumavrata": ['mw'],
    "sārvabhaumika": ['mw'],
    "sārvabhautika": ['ap90', 'cae', 'mw'],
    "sārvabhaṭṭabhaumācārya": ['mw'],
    "sārvacarmīṇa": ['mw'],
    "sārvadhātuka": ['ap90', 'cae', 'ddsa', 'mw'],
    "sārvagaṇa": ['mw'],
    "sārvaguṇika": ['mw'],
    "sārvagāmin": ['mw'],
    "sārvajanika": ['ap90', 'mw'],
    "sārvajanya": ['mw'],
    "sārvajanīna": ['mw'],
    "sārvajña": ['mw'],
    "sārvajñaṃ": ['ap90'],
    "sārvajñya": ['mw'],
    "sārvakarmika": ['mw'],
    "sārvakeśya": ['mw'],
    "sārvakratuka": ['mw'],
    "sārvakāla": ['cae', 'mw'],
    "sārvakālika": ['ap90', 'bhs', 'cae', 'mw'],
    "sārvakālya": ['mw'],
    "sārvakāma": ['mw'],
    "sārvakāmasamṛddha": ['mw'],
    "sārvakāmika": ['ap90', 'cae', 'mw'],
    "sārvakāmya": ['mw'],
    "sārvakārmika": ['mw'],
    "sārvalaukika": ['ap90', 'cae', 'mw'],
    "sārvamedhika": ['mw'],
    "sārvanāmika": ['mw'],
    "sārvanāmnya": ['mw'],
    "sārvaraugika": ['mw'],
    "sārvarogika": ['mw'],
    "sārvarātrika": ['mw'],
    "sārvasaha": ['mw'],
    "sārvasaṃsargalavaṇa": ['mw'],
    "sārvasena": ['mw'],
    "sārvasenayajña": ['mw'],
    "sārvaseni": ['mw'],
    "sārvaseniyajña": ['mw'],
    "sārvasenya": ['mw'],
    "sārvasenī": ['mw'],
    "sārvasenīya": ['mw'],
    "sārvasurabhi": ['mw'],
    "sārvasūtra": ['mw'],
    "sārvatrika": ['ap90', 'ddsa'],
    "sārvavaidika": ['mw'],
    "sārvavaidyaḥ": ['ap90'],
    "sārvavarmika": ['mw'],
    "sārvavarṇika": ['ap90', 'cae', 'mw'],
    "sārvavedasa": ['cae', 'mw'],
    "sārvavedasadakṣiṇa": ['mw'],
    "sārvavedasaḥ": ['ap90'],
    "sārvavedya": ['mw'],
    "sārvavibhaktika": ['ap90', 'mw'],
    "sārvavidya": ['mw'],
    "sārvayajñika": ['mw'],
    "sārvayaugika": ['mw'],
    "sārvayānika": ['bhs'],
    "sārvaṃsaha": ['mw'],
    "sārvātmya": ['mw'],
    "sārvāyuṣa": ['mw'],
    "sārya": ['mw'],
    "sārñjaya": ['ddsa', 'gra', 'mw'],
    "sārā": ['mw'],
    "sārādāna": ['mw'],
    "sārāgavastra": ['mw'],
    "sārāghya": ['mw'],
    "sārāji": ['ddsa'],
    "sārāla": ['mw'],
    "sārālaḥ": ['ap90'],
    "sārāmbhas": ['mw'],
    "sārāmukha": ['mw'],
    "sārāmṛta": ['mw'],
    "sārānīya": ['cped'],
    "sārāpahāra": ['mw'],
    "sārāparādha": ['mw'],
    "sārāparādhatas": ['mw'],
    "sārārthasaṃgraha": ['mw'],
    "sārārthin": ['mw'],
    "sārāsvādinī": ['mw'],
    "sārāsāra": ['cae', 'ddsa', 'mw'],
    "sārāsāratā": ['mw'],
    "sārāsāravicāra": ['mw'],
    "sārāsāraviveka": ['mw'],
    "sārāt": ['mw'],
    "sārātsārasusaṃgraha": ['mw'],
    "sārātsāratattva": ['mw'],
    "sārātsāratattvasaṃgraha": ['mw'],
    "sārāva": ['ddsa', 'mw'],
    "sārāvalī": ['mw'],
    "sārāvalījātaka": ['mw'],
    "sārāyaṇī": ['bhs'],
    "sārāyaṇīya": ['bhs', 'mw'],
    "sārāśīti": ['mw'],
    "sārī": ['cped', 'mw'],
    "sārīkrīḍā": ['mw'],
    "sārīrika": ['cped'],
    "sārūpavatsa": ['mw'],
    "sārūpya": ['bhs', 'cae', 'ddsa', 'mw'],
    "sārūpyaka": ['bhs'],
    "sārūpyatas": ['mw'],
    "sārūpyatā": ['mw'],
    "sārūpyavatī": ['bhs'],
    "sārūpyaṃ": ['ap90'],
    "sārūḍha": ['mw'],
    "sārṅgī": ['mw'],
    "sārṣapa": ['ap90', 'ddsa', 'mw'],
    "sārṣṭa": ['cae', 'mw'],
    "sārṣṭi": ['ap90', 'cae', 'ddsa', 'mw'],
    "sārṣṭitā": ['ap90', 'mw'],
    "sārṣṭya": ['mw'],
    "sārṣṭyaṃ": ['ap90'],
    "sāsa": ['ap90', 'ddsa', 'mw'],
    "sāsadyamāna": ['mw'],
    "sāsahi": ['cae', 'ddsa', 'gra', 'mw'],
    "sāsahvas": ['mw'],
    "sāsahāna": ['mw'],
    "sāsakarṇi": ['mw'],
    "sāsana": ['cped'],
    "sāsanahara": ['cped'],
    "sāsanakara": ['cped'],
    "sāsanakāraka": ['cped'],
    "sāsanakārī": ['cped'],
    "sāsandīka": ['mw'],
    "sāsanika": ['cped'],
    "sāsanāntaradhāna": ['cped'],
    "sāsanāvacara": ['cped'],
    "sāsapa": ['cped'],
    "sāsati": ['cped'],
    "sāsava": ['cped', 'mw'],
    "sāsaṅka": ['cped'],
    "sāsi": ['cped', 'mw'],
    "sāsihasta": ['mw'],
    "sāsipāṇi": ['mw'],
    "sāsita": ['cped'],
    "sāsnā": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāsnādimat": ['mw'],
    "sāsnālāṅgūlakakudakhuraviṣāṇin": ['mw'],
    "sāsnāvat": ['mw'],
    "sāsra": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāsram": ['mw'],
    "sāsrava": ['mw'],
    "sāstaraṇa": ['mw'],
    "sāsthi": ['mw'],
    "sāsthisvānam": ['mw'],
    "sāsthitāmrārdha": ['mw'],
    "sāsthivadha": ['mw'],
    "sāsu": ['cae', 'mw'],
    "sāsusū": ['ap90', 'mw'],
    "sāsvādana": ['mw'],
    "sāsāra": ['ddsa', 'mw'],
    "sāsūya": ['ap90', 'cae', 'mw'],
    "sāt": ['ap90', 'mw'],
    "sāta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sātacca": ['cped'],
    "sātaccakiriyā": ['cped'],
    "sātaccakārī": ['cped'],
    "sātagiri": ['bhs'],
    "sātakumbha": ['cped'],
    "sātala": ['mw'],
    "sātalā": ['mw'],
    "sātantya": ['bhs'],
    "sātasaikā": ['mw'],
    "sātatika": ['bhs', 'cped'],
    "sātatya": ['bhs', 'cae', 'ddsa', 'mw'],
    "sātatyacatuṣkaṭīkā": ['mw'],
    "sātatyaṃ": ['ap90'],
    "sātavāha": ['cae', 'ddsa', 'mw'],
    "sātavāhana": ['cae', 'mw'],
    "sātavāhanaḥ": ['ap90'],
    "sātaya": ['mw'],
    "sāthalika": ['cped'],
    "sāti": ['cae', 'ddsa', 'gra', 'mw'],
    "sātilaka": ['mw'],
    "sātireka": ['cae', 'cped', 'ddsa', 'mw'],
    "sātirikta": ['mw'],
    "sātirātra": ['mw'],
    "sātisāra": ['bhs', 'cped', 'mw'],
    "sātiśaya": ['cae', 'mw'],
    "sātiḥ": ['ap90'],
    "sātkarya": ['mw'],
    "sātma": ['mw'],
    "sātman": ['bhs', 'cae', 'mw'],
    "sātmatva": ['cae', 'mw'],
    "sātmatā": ['cae', 'mw'],
    "sātmya": ['cae', 'mw'],
    "sātmyatas": ['mw'],
    "sātmārpaṇa": ['ddsa', 'mw'],
    "sātmī": ['mw'],
    "sātmībhāva": ['mw'],
    "sātmībhū": ['mw'],
    "sātmīkṛta": ['mw'],
    "sātobārhata": ['mw'],
    "sātpauruṣya": ['bhs'],
    "sātpuḍā": ['mw'],
    "sātrājita": ['ddsa', 'mw'],
    "sātrājitī": ['mw'],
    "sātrāsāha": ['mw'],
    "sātrāsāhaka": ['mw'],
    "sāttha": ['cped'],
    "sātthaka": ['cped'],
    "sāttra": ['mw'],
    "sāttrika": ['mw'],
    "sāttva": ['mw'],
    "sāttvaki": ['mw'],
    "sāttvika": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāttvikabrahmavidyāvilāsa": ['mw'],
    "sāttvikapurāṇavibhāga": ['mw'],
    "sāttvikī": ['mw'],
    "sātu": ['cae', 'gra', 'mw'],
    "sātvat": ['ap90', 'ddsa', 'mw'],
    "sātvata": ['cae', 'ddsa', 'mw'],
    "sātvatasaṃhitā": ['mw'],
    "sātvatasaṃhitāprayoga": ['mw'],
    "sātvatasiddhāntaśataka": ['mw'],
    "sātvataḥ": ['ap90'],
    "sātvatācāravādārtha": ['mw'],
    "sātvatī": ['ap90', 'mw'],
    "sātvatīsūnu": ['mw'],
    "sātvatīya": ['mw'],
    "sātvika": ['mw'],
    "sātya": ['cae', 'mw'],
    "sātyadūta": ['mw'],
    "sātyahavya": ['ddsa', 'mw'],
    "sātyaka": ['mw'],
    "sātyaki": ['cae', 'ddsa', 'mw'],
    "sātyakin": ['mw'],
    "sātyakiḥ": ['ap90'],
    "sātyakāmi": ['mw'],
    "sātyakāyana": ['mw'],
    "sātyamugra": ['mw'],
    "sātyamugri": ['mw'],
    "sātyamugrya": ['mw'],
    "sātyamuni": ['mw'],
    "sātyarathi": ['mw'],
    "sātyavata": ['mw'],
    "sātyavataḥ": ['ap90'],
    "sātyavateya": ['mw'],
    "sātyayajña": ['mw'],
    "sātyayajñi": ['mw'],
    "sātyaṃkārya": ['mw'],
    "sātyādhivāka": ['mw'],
    "sātāgiri": ['bhs', 'mw'],
    "sātīkāśa": ['mw'],
    "sātīlaka": ['mw'],
    "sātīna": ['mw'],
    "sātīnaḥ": ['ap90'],
    "sātīyati": ['bhs'],
    "sāva": ['cae', 'ddsa', 'gra', 'mw'],
    "sāvacāraṇa": ['cae', 'mw'],
    "sāvadhi": ['ap90', 'cae', 'mw'],
    "sāvadhāna": ['ap90', 'cae', 'mw'],
    "sāvadhānam": ['mw'],
    "sāvadhānasāhitya": ['mw'],
    "sāvadhānatā": ['mw'],
    "sāvadhānaya": ['mw'],
    "sāvadhānī": ['mw'],
    "sāvadhānībhū": ['mw'],
    "sāvadhānīkṛ": ['mw'],
    "sāvadhānīkṛta": ['mw'],
    "sāvadhāraṇa": ['mw'],
    "sāvadya": ['bhs', 'cae', 'mw'],
    "sāvadyaṃ": ['ap90'],
    "sāvadāna": ['bhs'],
    "sāvadānam": ['mw'],
    "sāvagraha": ['ap90', 'mw'],
    "sāvahela": ['ap90', 'mw'],
    "sāvahelam": ['mw'],
    "sāvahita": ['mw'],
    "sāvairisole": ['mw'],
    "sāvajja": ['cped'],
    "sāvajjatā": ['cped'],
    "sāvajña": ['ap90', 'cae', 'mw'],
    "sāvajñam": ['mw'],
    "sāvaka": ['ap90', 'cped', 'ddsa', 'mw'],
    "sāvakasaṅgha": ['cped'],
    "sāvakatta": ['cped'],
    "sāvakāśa": ['ap90', 'ddsa', 'mw'],
    "sāvakāśam": ['mw'],
    "sāvakāśatva": ['mw'],
    "sāvalamba": ['ddsa', 'mw'],
    "sāvalepa": ['ap90', 'cae', 'mw'],
    "sāvalepam": ['mw'],
    "sāvamarda": ['ddsa', 'mw'],
    "sāvamāna": ['cae', 'mw'],
    "sāvana": ['ap90', 'ddsa', 'mw'],
    "sāvantamiśra": ['mw'],
    "sāvara": ['mw'],
    "sāvaraḥ": ['ap90'],
    "sāvaraṇa": ['ap90', 'cae', 'mw'],
    "sāvaraṇasadāśivapūjāvidhi": ['mw'],
    "sāvaroha": ['mw'],
    "sāvarṇa": ['ap90', 'ddsa', 'mw'],
    "sāvarṇaka": ['mw'],
    "sāvarṇalakṣya": ['mw'],
    "sāvarṇi": ['ddsa', 'gra', 'mw'],
    "sāvarṇia": ['gra'],
    "sāvarṇika": ['mw'],
    "sāvarṇikā": ['mw'],
    "sāvarṇiḥ": ['ap90'],
    "sāvarṇya": ['gra', 'mw'],
    "sāvarṇyaṃ": ['ap90'],
    "sāvasa": ['mw'],
    "sāvasesa": ['cped'],
    "sāvatthī": ['cped'],
    "sāvayamāna": ['cped'],
    "sāvayasa": ['mw'],
    "sāvayava": ['ap90', 'cae', 'mw'],
    "sāvayavatva": ['mw'],
    "sāvayavīkṛ": ['mw'],
    "sāvaśeṣa": ['ap90', 'bhs', 'cae', 'mw'],
    "sāvaśeṣabandhana": ['mw'],
    "sāvaśeṣajīvita": ['mw'],
    "sāvaḥ": ['ap90'],
    "sāvaṇa": ['cped'],
    "sāvaṣṭambha": ['cae', 'mw'],
    "sāvaṣṭambham": ['mw'],
    "sāvaṣṭaṃbha": ['ap90'],
    "sāvaṭṭa": ['cped'],
    "sāvegam": ['cae', 'ddsa', 'mw'],
    "sāventa": ['cped'],
    "sāverī": ['mw'],
    "sāvesi": ['cped'],
    "sāvetabba": ['cped'],
    "sāvetar": ['cped'],
    "sāvetasa": ['mw'],
    "sāveti": ['cped'],
    "sāvetvā": ['cped'],
    "sāveśya": ['cae'],
    "sāvika": ['cae', 'mw'],
    "sāvikā": ['ap90', 'cped', 'mw'],
    "sāvin": ['cae', 'gra', 'mw'],
    "sāvinī": ['ddsa', 'mw'],
    "sāvita": ['cped'],
    "sāvitra": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāvitracayana": ['mw'],
    "sāvitracayanapaddhati": ['mw'],
    "sāvitracayanaprayoga": ['mw'],
    "sāvitraciti": ['mw'],
    "sāvitragrahahoma": ['mw'],
    "sāvitravat": ['mw'],
    "sāvitreya": ['mw'],
    "sāvitri": ['mw'],
    "sāvitrikā": ['mw'],
    "sāvitry": ['mw'],
    "sāvitryavarajā": ['mw'],
    "sāvitryupaniṣad": ['mw'],
    "sāvitryupākhyāna": ['mw'],
    "sāvitrādikāṭhakacayana": ['mw'],
    "sāvitrādiprayogavṛtti": ['mw'],
    "sāvitrāgniprayoga": ['mw'],
    "sāvitrī": ['ap90', 'mw'],
    "sāvitrībhāṣya": ['mw'],
    "sāvitrīka": ['mw'],
    "sāvitrīmahānāmya": ['mw'],
    "sāvitrīparibhraṣṭa": ['cae', 'mw'],
    "sāvitrīpariṇaya": ['mw'],
    "sāvitrīpatita": ['cae', 'mw'],
    "sāvitrīpañjara": ['mw'],
    "sāvitrīputra": ['mw'],
    "sāvitrīputrīya": ['mw'],
    "sāvitrīsūtra": ['mw'],
    "sāvitrītīrtha": ['mw'],
    "sāvitrīvrata": ['mw'],
    "sāvitrīvrataka": ['mw'],
    "sāvitrīvratakathānaka": ['mw'],
    "sāvitrīvratapūjākathā": ['mw'],
    "sāvitrīvratodyāpana": ['mw'],
    "sāviṣkāra": ['ap90', 'mw'],
    "sāvya": ['mw'],
    "sāvāsana": ['bhs'],
    "sāya": ['cae', 'ddsa', 'gra', 'mw'],
    "sāyadhūrta": ['mw'],
    "sāyaka": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sāyakamaya": ['mw'],
    "sāyakapraṇutta": ['mw'],
    "sāyakapuṅkha": ['mw'],
    "sāyakapuṅkhā": ['mw'],
    "sāyakaḥ": ['ap90'],
    "sāyakāya": ['ddsa', 'mw'],
    "sāyakāyana": ['mw'],
    "sāyakāyanin": ['mw'],
    "sāyam": ['ap90', 'ddsa', 'mw'],
    "sāyamadhivāsa": ['mw'],
    "sāyamaupāsanaprayoga": ['mw'],
    "sāyamaśana": ['cae', 'mw'],
    "sāyamaṇḍana": ['mw'],
    "sāyambhava": ['mw'],
    "sāyambhojana": ['mw'],
    "sāyammantra": ['mw'],
    "sāyampoṣa": ['mw'],
    "sāyamprātar": ['ddsa', 'mw'],
    "sāyamprātaragnihotrahoma": ['mw'],
    "sāyamprātaragnihotraprayoga": ['mw'],
    "sāyamprātaraupāsanavidhi": ['mw'],
    "sāyamprātardoha": ['mw'],
    "sāyamprātarhoma": ['mw'],
    "sāyamprātarmaya": ['mw'],
    "sāyamprātarāhuti": ['mw'],
    "sāyamprātarāśin": ['mw'],
    "sāyamprātika": ['mw'],
    "sāyamupāsanavidhi": ['mw'],
    "sāyamāhuti": ['cae', 'mw'],
    "sāyamāsa": ['cped'],
    "sāyamāśa": ['mw'],
    "sāyamāśaprātarāśa": ['mw'],
    "sāyana": ['cped', 'mw'],
    "sāyanaṃ": ['ap90'],
    "sāyandugdha": ['ddsa'],
    "sāyanta": ['cped'],
    "sāyantana": ['cae', 'ddsa', 'mw'],
    "sāyantanamallikā": ['mw'],
    "sāyantanasamaya": ['mw'],
    "sāyanīya": ['cped'],
    "sāyatana": ['mw'],
    "sāyatare": ['mw'],
    "sāyati": ['cped'],
    "sāyavasa": ['mw'],
    "sāyaḥ": ['ap90'],
    "sāyaṃ": ['mw'],
    "sāyaṃdhṛti": ['mw'],
    "sāyaṃdoha": ['cae', 'mw'],
    "sāyaṃdohavat": ['mw'],
    "sāyaṃdugdha": ['cae', 'mw'],
    "sāyaṃgavendra": ['bhs'],
    "sāyaṃgoṣṭha": ['mw'],
    "sāyaṃgṛha": ['mw'],
    "sāyaṃhoma": ['mw'],
    "sāyaṃkāla": ['cae', 'mw'],
    "sāyaṃkālika": ['cae', 'mw'],
    "sāyaṃkālīna": ['cae', 'mw'],
    "sāyaṃnivāsa": ['mw'],
    "sāyaṃprātar": ['cae'],
    "sāyaṃprātarhoma": ['cae'],
    "sāyaṃprātika": ['bhs'],
    "sāyaṃsaṃdhyā": ['mw'],
    "sāyaṃsaṃdhyādevatā": ['mw'],
    "sāyaṃsaṃdhyāprayoga": ['mw'],
    "sāyaṃsūrya": ['ddsa', 'mw'],
    "sāyaṃsūryoḍha": ['mw'],
    "sāyaṃtana": ['ap90'],
    "sāyaṃtūrya": ['mw'],
    "sāyaṃyāvan": ['mw'],
    "sāyaṅkāla": ['ddsa'],
    "sāyaṇa": ['cae', 'ddsa', 'mw'],
    "sāyaṇamādhava": ['cae'],
    "sāyaṇamādhavīya": ['mw'],
    "sāyaṇaḥ": ['ap90'],
    "sāyaṇha": ['cped'],
    "sāyaṇhakāla": ['cped'],
    "sāyaṇhasamaya": ['cped'],
    "sāyaṇācārya": ['cae'],
    "sāyaṇīya": ['mw'],
    "sāyi": ['cped'],
    "sāyia": ['gra'],
    "sāyikā": ['mw'],
    "sāyin": ['ap90', 'mw'],
    "sāyita": ['cped'],
    "sāyitvā": ['cped'],
    "sāyodbhidura": ['mw'],
    "sāyojya": ['mw'],
    "sāyudha": ['cae', 'mw'],
    "sāyudhapragraha": ['mw'],
    "sāyujya": ['cae', 'ddsa', 'mw'],
    "sāyujyamukti": ['mw'],
    "sāyujyatva": ['mw'],
    "sāyujyatā": ['mw'],
    "sāyujyaṃ": ['ap90'],
    "sāyya": ['gra', 'mw'],
    "sāyāhan": ['cae', 'ddsa', 'mw'],
    "sāyāhna": ['mw'],
    "sāyāhnasamaye": ['mw'],
    "sāyārambha": ['mw'],
    "sāyāsa": ['cae', 'ddsa', 'mw'],
    "sāyāśana": ['mw'],
    "sāñcādhara": ['mw'],
    "sāñja": ['mw'],
    "sāñjali": ['cae', 'mw'],
    "sāñjana": ['mw'],
    "sāñjhanandin": ['mw'],
    "sāśana": ['mw'],
    "sāśanānaśana": ['gra', 'mw'],
    "sāśanāra": ['mw'],
    "sāśayandaka": ['mw'],
    "sāśayaṃdakaḥ": ['ap90'],
    "sāśaṃka": ['ap90'],
    "sāśaṃsa": ['ap90', 'mw'],
    "sāśaṃsam": ['cae', 'mw'],
    "sāśaṅka": ['cae', 'mw'],
    "sāśaṅkam": ['mw'],
    "sāśaṅkatā": ['mw'],
    "sāścarya": ['ap90', 'cae', 'mw'],
    "sāścaryacarya": ['mw'],
    "sāścaryakautuka": ['mw'],
    "sāścaryam": ['mw'],
    "sāścaryamaya": ['mw'],
    "sāśikya": ['ddsa', 'mw'],
    "sāśira": ['mw'],
    "sāśmavarṣin": ['mw'],
    "sāśra": ['ap90', 'mw'],
    "sāśrava": ['bhs'],
    "sāśru": ['ap90', 'cae', 'mw'],
    "sāśrudhī": ['ap90', 'mw'],
    "sāśrulocana": ['cae', 'mw'],
    "sāśrunayana": ['mw'],
    "sāśva": ['mw'],
    "sāśvamedha": ['mw'],
    "sāśīrka": ['mw'],
    "sāśīti": ['ddsa', 'mw'],
    "sāśūka": ['mw'],
    "sāśūkaḥ": ['ap90'],
    "sāḍa": ['mw'],
    "sāḍakhāna": ['mw'],
    "sāḍbhūta": ['mw'],
    "sāḍha": ['ddsa', 'mw'],
    "sāḍhyai": ['mw'],
    "sāḍhṛ": ['cae', 'ddsa', 'mw'],
    "sāḍi": ['mw'],
    "sāḷava": ['cped'],
    "sāṃbali": ['bhs'],
    "sāṃbandhaka": ['bhs'],
    "sāṃbandhika": ['cae'],
    "sāṃbaraṃ": ['ap90'],
    "sāṃbarī": ['ap90'],
    "sāṃbaḥ": ['ap90'],
    "sāṃbaṃdhika": ['ap90'],
    "sāṃbhavī": ['ap90'],
    "sāṃcaritra": ['bhs'],
    "sāṃcetanika": ['bhs'],
    "sāṃcārika": ['mw'],
    "sāṃdha": ['mw'],
    "sāṃdhika": ['mw'],
    "sāṃdhikaḥ": ['ap90'],
    "sāṃdhivela": ['mw'],
    "sāṃdhivelī": ['mw'],
    "sāṃdhivigrahika": ['mw'],
    "sāṃdhivigrahikaḥ": ['ap90'],
    "sāṃdhya": ['ap90', 'cae', 'mw'],
    "sāṃdhyabhojana": ['mw'],
    "sāṃdhyakusumā": ['mw'],
    "sāṃdra": ['ap90'],
    "sāṃdrāviṇa": ['mw'],
    "sāṃdīpani": ['mw'],
    "sāṃdīpaniḥ": ['ap90'],
    "sāṃdṛṣṭika": ['ap90', 'bhs', 'mw'],
    "sāṃga": ['ap90'],
    "sāṃgama": ['mw'],
    "sāṃgamana": ['mw'],
    "sāṃgamaḥ": ['ap90'],
    "sāṃgamiṣṇu": ['mw'],
    "sāṃgatika": ['ap90', 'cae', 'mw'],
    "sāṃgatya": ['mw'],
    "sāṃghaṭika": ['mw'],
    "sāṃghaṭṭika": ['mw'],
    "sāṃghika": ['bhs', 'mw'],
    "sāṃghāta": ['bhs', 'mw'],
    "sāṃghātika": ['ap90', 'mw'],
    "sāṃghātya": ['mw'],
    "sāṃghāṭi": ['bhs'],
    "sāṃghāṭikā": ['mw'],
    "sāṃgrahasūtrika": ['mw'],
    "sāṃgrahaṇa": ['mw'],
    "sāṃgrahaṇeṣṭi": ['mw'],
    "sāṃgrahika": ['mw'],
    "sāṃgrāhika": ['mw'],
    "sāṃgrāma": ['mw'],
    "sāṃgrāmajitya": ['cae', 'mw'],
    "sāṃgrāmika": ['ap90', 'cae', 'mw'],
    "sāṃgrāmikaguṇa": ['mw'],
    "sāṃgrāmikaparicchada": ['mw'],
    "sāṃgrāmikatva": ['mw'],
    "sāṃgrāmikavidhijña": ['mw'],
    "sāṃhananika": ['ap90', 'mw'],
    "sāṃhatya": ['cae', 'mw'],
    "sāṃhita": ['mw'],
    "sāṃhitika": ['mw'],
    "sāṃhitopaniṣadbhāṣya": ['mw'],
    "sāṃhāra": ['mw'],
    "sāṃhātika": ['mw'],
    "sāṃjanaḥ": ['ap90'],
    "sāṃjñāyani": ['mw'],
    "sāṃjīvīputra": ['cae', 'mw'],
    "sāṃkala": ['ap90', 'mw'],
    "sāṃkalpika": ['mw'],
    "sāṃkarika": ['mw'],
    "sāṃkarya": ['mw'],
    "sāṃkaryakhaṇḍana": ['mw'],
    "sāṃkaryavāda": ['mw'],
    "sāṃkaryaṃ": ['ap90'],
    "sāṃkathika": ['mw'],
    "sāṃkathya": ['bhs', 'mw'],
    "sāṃketika": ['ap90', 'mw'],
    "sāṃketya": ['mw'],
    "sāṃkhya": ['ap90', 'cae', 'mw'],
    "sāṃkhyabhikṣu": ['mw'],
    "sāṃkhyacandrikā": ['mw'],
    "sāṃkhyadarśana": ['mw'],
    "sāṃkhyajñāna": ['mw'],
    "sāṃkhyakaumudī": ['mw'],
    "sāṃkhyakramadīpikā": ['mw'],
    "sāṃkhyakārikā": ['cae', 'mw'],
    "sāṃkhyakārikābhāṣya": ['mw'],
    "sāṃkhyamata": ['mw'],
    "sāṃkhyamaya": ['mw'],
    "sāṃkhyamukhya": ['mw'],
    "sāṃkhyamīmāṃsā": ['mw'],
    "sāṃkhyapadārthagāthā": ['mw'],
    "sāṃkhyapravacana": ['mw'],
    "sāṃkhyapravacanabhāṣya": ['mw'],
    "sāṃkhyapuruṣa": ['mw'],
    "sāṃkhyasaptati": ['mw'],
    "sāṃkhyasāra": ['mw'],
    "sāṃkhyasāraviveka": ['mw'],
    "sāṃkhyasūtra": ['mw'],
    "sāṃkhyasūtraprakṣepikā": ['mw'],
    "sāṃkhyasūtravivaraṇa": ['mw'],
    "sāṃkhyasūtravṛtti": ['mw'],
    "sāṃkhyasūtravṛttisāra": ['mw'],
    "sāṃkhyataraṃga": ['mw'],
    "sāṃkhyatattvacandrikā": ['mw'],
    "sāṃkhyatattvakaumudī": ['mw'],
    "sāṃkhyatattvapradīpa": ['mw'],
    "sāṃkhyatattvapradīpikā": ['mw'],
    "sāṃkhyatattvavilāsa": ['mw'],
    "sāṃkhyavṛtti": ['mw'],
    "sāṃkhyavṛttiprakāśa": ['mw'],
    "sāṃkhyavṛttisāra": ['mw'],
    "sāṃkhyayoga": ['cae', 'mw'],
    "sāṃkhyayogadīpikā": ['mw'],
    "sāṃkhyayogapravartin": ['mw'],
    "sāṃkhyayogavadin": ['mw'],
    "sāṃkhyayogavat": ['mw'],
    "sāṃkhyaśāstra": ['mw'],
    "sāṃkhyācārya": ['cae', 'mw'],
    "sāṃkhyālaṃkāra": ['mw'],
    "sāṃkhyārtha": ['mw'],
    "sāṃkhyārthasaṃkhyāyika": ['mw'],
    "sāṃkhyārthatattvapradīpikā": ['mw'],
    "sāṃkhyāyana": ['cae', 'mw'],
    "sāṃkhyāyanabrāhmaṇa": ['mw'],
    "sāṃkhyāyanagṛhya": ['mw'],
    "sāṃkhyāyanasūtra": ['mw'],
    "sāṃkhyāyanatantra": ['mw'],
    "sāṃkleśika": ['bhs'],
    "sāṃkrandani": ['mw'],
    "sāṃkrāmika": ['mw'],
    "sāṃkuci": ['mw'],
    "sāṃkucita": ['mw'],
    "sāṃkārikā": ['mw'],
    "sāṃkāśina": ['mw'],
    "sāṃkāśya": ['bhs', 'cae', 'mw'],
    "sāṃkāśyanātha": ['mw'],
    "sāṃkāśyaṃ": ['ap90'],
    "sāṃkūṭina": ['mw'],
    "sāṃkṛta": ['mw'],
    "sāṃkṛti": ['mw'],
    "sāṃkṛtya": ['cae', 'mw'],
    "sāṃkṛtyāyana": ['mw'],
    "sāṃkṛtyāyanī": ['mw'],
    "sāṃkṛtī": ['mw'],
    "sāṃkṛtīputra": ['mw'],
    "sāṃkṣepika": ['ap90', 'mw'],
    "sāṃlekhika": ['bhs'],
    "sāṃmanasya": ['cae'],
    "sāṃmeghya": ['cae'],
    "sāṃmitīya": ['bhs'],
    "sāṃmukhya": ['cae'],
    "sāṃmukhyaṃ": ['ap90'],
    "sāṃnahanika": ['ap90', 'mw'],
    "sāṃnata": ['mw'],
    "sāṃnatya": ['mw'],
    "sāṃnidhya": ['cae', 'mw'],
    "sāṃnidhyatas": ['mw'],
    "sāṃnidhyatā": ['mw'],
    "sāṃnidhyaṃ": ['ap90'],
    "sāṃnihitya": ['mw'],
    "sāṃnipātika": ['ap90', 'mw'],
    "sāṃnipātikakarman": ['mw'],
    "sāṃnipātin": ['mw'],
    "sāṃnipātitva": ['mw'],
    "sāṃnipātya": ['mw'],
    "sāṃniveśika": ['mw'],
    "sāṃnyāsika": ['mw'],
    "sāṃnyāsikaḥ": ['ap90'],
    "sāṃnāhika": ['cae', 'mw'],
    "sāṃnāhuka": ['cae', 'mw'],
    "sāṃnāyya": ['cae', 'mw'],
    "sāṃnāyyabhājana": ['mw'],
    "sāṃnāyyakumbhī": ['mw'],
    "sāṃnāyyapātra": ['mw'],
    "sāṃnāyyatva": ['mw'],
    "sāṃnāyyavat": ['mw'],
    "sāṃnāyyaḥ": ['ap90'],
    "sāṃnāyyokhā": ['mw'],
    "sāṃnāyyāpidhānī": ['mw'],
    "sāṃparāya": ['ap90', 'bhs', 'cae'],
    "sāṃparāyika": ['ap90', 'bhs', 'cae'],
    "sāṃpradāyika": ['ap90', 'cae'],
    "sāṃprata": ['ap90', 'cae'],
    "sāṃpratika": ['ap90'],
    "sāṃpreya": ['bhs'],
    "sāṃpreyaka": ['bhs'],
    "sāṃrakṣya": ['mw'],
    "sāṃrāviṇa": ['cae', 'mw'],
    "sāṃrāviṇaṃ": ['ap90'],
    "sāṃsargavidya": ['mw'],
    "sāṃsargika": ['mw'],
    "sāṃsiddhika": ['ap90', 'mw'],
    "sāṃsiddhikadrava": ['mw'],
    "sāṃsiddhya": ['mw'],
    "sāṃskārika": ['mw'],
    "sāṃsparśaka": ['cae', 'mw'],
    "sāṃsphīyaka": ['mw'],
    "sāṃsraviṇa": ['mw'],
    "sāṃsrāviṇaṃ": ['ap90'],
    "sāṃsthānika": ['mw'],
    "sāṃsthānikaḥ": ['ap90'],
    "sāṃsārika": ['ap90', 'cae', 'mw'],
    "sāṃsṛṣṭika": ['mw'],
    "sāṃtapana": ['cae', 'gra', 'mw'],
    "sāṃtapanaṃ": ['ap90'],
    "sāṃtapanāyana": ['mw'],
    "sāṃtapanīya": ['mw'],
    "sāṃtapanīyā": ['mw'],
    "sāṃtara": ['ap90'],
    "sāṃtatika": ['mw'],
    "sāṃtatya": ['bhs'],
    "sāṃtv": ['ap90'],
    "sāṃtvaḥ": ['ap90'],
    "sāṃtāna": ['mw'],
    "sāṃtānika": ['ap90', 'bhs', 'cae', 'mw'],
    "sāṃtāpika": ['mw'],
    "sāṃvahitra": ['mw'],
    "sāṃvaidya": ['mw'],
    "sāṃvaraṇa": ['mw'],
    "sāṃvaraṇi": ['gra', 'mw'],
    "sāṃvarga": ['mw'],
    "sāṃvargajita": ['mw'],
    "sāṃvarika": ['bhs'],
    "sāṃvarta": ['mw'],
    "sāṃvartaka": ['mw'],
    "sāṃvartasmṛti": ['mw'],
    "sāṃvatsara": ['ap90', 'cae', 'mw'],
    "sāṃvatsaraka": ['mw'],
    "sāṃvatsararatha": ['mw'],
    "sāṃvatsarasūtra": ['mw'],
    "sāṃvatsarika": ['mw'],
    "sāṃvatsarikaikoddiṣṭaśrāddhaprayoga": ['mw'],
    "sāṃvatsarikaśrāddha": ['mw'],
    "sāṃvatsarī": ['mw'],
    "sāṃvatsarīya": ['mw'],
    "sāṃvatsarīyā": ['mw'],
    "sāṃveśanika": ['mw'],
    "sāṃveśya": ['mw'],
    "sāṃveṣika": ['mw'],
    "sāṃvidya": ['cae', 'mw'],
    "sāṃvittika": ['mw'],
    "sāṃvyavahārika": ['mw'],
    "sāṃvādika": ['ap90', 'mw'],
    "sāṃvādya": ['mw'],
    "sāṃvāhika": ['mw'],
    "sāṃvāsika": ['mw'],
    "sāṃvāsyaka": ['mw'],
    "sāṃvāśina": ['mw'],
    "sāṃvṛta": ['bhs'],
    "sāṃvṛtti": ['mw'],
    "sāṃvṛttika": ['ap90'],
    "sāṃyamana": ['mw'],
    "sāṃyamani": ['mw'],
    "sāṃyamanika": ['bhs', 'mw'],
    "sāṃyaugika": ['mw'],
    "sāṃyogika": ['bhs', 'mw'],
    "sāṃyuga": ['cae', 'mw'],
    "sāṃyugīna": ['ap90', 'cae', 'mw'],
    "sāṃyāti": ['mw'],
    "sāṃyātika": ['mw'],
    "sāṃyātrika": ['ddsa', 'mw'],
    "sāṃyātrikaḥ": ['ap90'],
    "sāṃśa": ['mw'],
    "sāṃśayika": ['ap90', 'cae', 'mw'],
    "sāṃśayikatva": ['mw'],
    "sāṃśaṃsika": ['cae', 'mw'],
    "sāṃśitya": ['mw'],
    "sāṅga": ['cae', 'ddsa', 'mw'],
    "sāṅgada": ['mw'],
    "sāṅgaglāni": ['mw'],
    "sāṅgaja": ['mw'],
    "sāṅgana": ['bhs'],
    "sāṅgarāga": ['mw'],
    "sāṅgasena": ['mw'],
    "sāṅgatika": ['ddsa'],
    "sāṅgaṇa": ['cped'],
    "sāṅgopāṅga": ['mw'],
    "sāṅgopāṅgopaniṣad": ['mw'],
    "sāṅgrāmika": ['ddsa'],
    "sāṅguṣṭha": ['cae', 'ddsa', 'mw'],
    "sāṅguṣṭham": ['mw'],
    "sāṅguṣṭhā": ['mw'],
    "sāṅgāraka": ['mw'],
    "sāṅkarya": ['ddsa'],
    "sāṅkhya": ['ddsa'],
    "sāṅkhyāyana": ['ddsa'],
    "sāṅkura": ['mw'],
    "sāṅmukhī": ['mw'],
    "sāṇa": ['cped'],
    "sāṇi": ['cped'],
    "sāṇipasibbaka": ['cped'],
    "sāṇipākāra": ['cped'],
    "sāṇḍa": ['cae', 'mw'],
    "sāṣīrājan": ['mw'],
    "sāṣṭa": ['mw'],
    "sāṣṭhī": ['mw'],
    "sāṣṭrika": ['mw'],
    "sāṣṭāṃgam": ['ap90'],
    "sāṣṭāṅga": ['cae', 'mw'],
    "sāṣṭāṅgam": ['mw'],
    "sāṣṭāṅgapātam": ['mw'],
    "sāṭ": ['ap90', 'mw'],
    "sāṭaka": ['cped'],
    "sāṭakayuga": ['cped'],
    "sāṭhala": ['mw'],
    "sāṭheyya": ['cped'],
    "sāṭhoka": ['mw'],
    "sāṭikā": ['cped'],
    "sāṭopa": ['ap90', 'cae', 'ddsa', 'mw'],
    "sāṭopam": ['mw'],
    "sāṭṭahāsa": ['mw'],
    "sāṭṭahāsam": ['mw'],
    "sāṭṭāla": ['mw'],
    "sī": ['bhs', 'ddsa', 'gra', 'mw'],
    "sībalā": ['mw'],
    "sīd": ['mw'],
    "sīda": ['ddsa', 'mw'],
    "sīdamāna": ['cped'],
    "sīdana": ['cped'],
    "sīdantīya": ['mw'],
    "sīdati": ['cped'],
    "sīdhra": ['mw'],
    "sīdhraṃ": ['ap90'],
    "sīdhu": ['ap90', 'cae', 'ddsa', 'mw'],
    "sīdhugandha": ['mw'],
    "sīdhupa": ['mw'],
    "sīdhupuṣpa": ['mw'],
    "sīdhupuṣpī": ['mw'],
    "sīdhupāna": ['cae', 'mw'],
    "sīdhurasa": ['mw'],
    "sīdhusaṃjña": ['mw'],
    "sīdi": ['cped'],
    "sīditvā": ['cped'],
    "sīdya": ['mw'],
    "sīdyaṃ": ['ap90'],
    "sīgha": ['cped'],
    "sīghagāmī": ['cped'],
    "sīghasota": ['cped'],
    "sīghasīghaṁ": ['cped'],
    "sīghataraṁ": ['cped'],
    "sīghaṁ": ['cped'],
    "sīha": ['bhs', 'cped', 'mw'],
    "sīhacamma": ['cped'],
    "sīhaniṣadya": ['bhs'],
    "sīhanu": ['cped'],
    "sīhanāda": ['cped'],
    "sīhanādika": ['cped'],
    "sīhapañjara": ['cped'],
    "sīhapotaka": ['cped'],
    "sīhara": ['mw'],
    "sīhaseyyā": ['cped'],
    "sīhassara": ['cped'],
    "sīhavikkīḷita": ['cped'],
    "sīhaḷa": ['cped'],
    "sīhaḷabhāsā": ['cped'],
    "sīhaḷadīpa": ['cped'],
    "sīhuṃḍaḥ": ['ap90'],
    "sīhuṇḍa": ['mw'],
    "sīk": ['ap90', 'mw'],
    "sīkara": ['cae'],
    "sīkaraḥ": ['ap90'],
    "sīkarin": ['cae'],
    "sīkhā": ['mw'],
    "sīkṣ": ['ddsa', 'gra', 'mw'],
    "sīkṣat": ['mw'],
    "sīla": ['cped', 'mw'],
    "sīlabbata": ['cped'],
    "sīlabheda": ['cped'],
    "sīlagandha": ['cped'],
    "sīlakathā": ['cped'],
    "sīlakkhandha": ['cped'],
    "sīlamaya": ['cped'],
    "sīlamāvat": ['gra'],
    "sīlamāvatī": ['mw'],
    "sīlana": ['cped'],
    "sīlandha": ['mw'],
    "sīlandhra": ['mw'],
    "sīlasampanna": ['cped'],
    "sīlasampatti": ['cped'],
    "sīlavant": ['cped'],
    "sīlavata": ['cped'],
    "sīlavatta": ['cped'],
    "sīlavipanna": ['cped'],
    "sīlavipatti": ['cped'],
    "sīlika": ['cped'],
    "sīllana": ['mw'],
    "sīlāra": ['mw'],
    "sīlī": ['cped'],
    "sīm": ['cae', 'ddsa', 'gra', 'mw'],
    "sīma": ['bhs', 'mw'],
    "sīmadharasvāmin": ['mw'],
    "sīmaka": ['mw'],
    "sīmaliṅga": ['cae', 'ddsa', 'mw'],
    "sīman": ['ap90', 'cae', 'ddsa', 'mw'],
    "sīmanta": ['ddsa', 'mw'],
    "sīmantadṛśvan": ['mw'],
    "sīmantaka": ['cae', 'mw'],
    "sīmantakaraṇa": ['mw'],
    "sīmantakarmapaddhati": ['mw'],
    "sīmantamaṇi": ['mw'],
    "sīmantavat": ['ddsa', 'mw'],
    "sīmantavidhi": ['mw'],
    "sīmantay": ['cae'],
    "sīmantaya": ['ddsa', 'mw'],
    "sīmantin": ['cae', 'ddsa', 'mw'],
    "sīmantinī": ['cped', 'mw'],
    "sīmantita": ['mw'],
    "sīmantonnayana": ['cae', 'ddsa', 'mw'],
    "sīmantonnayanamantra": ['mw'],
    "sīmantonnayanaprayoga": ['mw'],
    "sīmatas": ['mw'],
    "sīmaṃtakaḥ": ['ap90'],
    "sīmaṃtayati": ['ap90'],
    "sīmaṃtaḥ": ['ap90'],
    "sīmaṃtinī": ['ap90'],
    "sīmaṃtita": ['ap90'],
    "sīmaṭṭha": ['cped'],
    "sīmika": ['mw'],
    "sīmikaḥ": ['ap90'],
    "sīmikā": ['mw'],
    "sīmollaṅghana": ['mw'],
    "sīmā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sīmābandha": ['bhs', 'mw'],
    "sīmādhipa": ['cae', 'mw'],
    "sīmāgiri": ['mw'],
    "sīmājñāna": ['cae', 'mw'],
    "sīmākata": ['cped'],
    "sīmākṛṣāṇa": ['mw'],
    "sīmāliṅga": ['cae', 'mw'],
    "sīmāniścaya": ['mw'],
    "sīmānta": ['cae', 'mw'],
    "sīmāntabhūpāla": ['mw'],
    "sīmāntalekhā": ['mw'],
    "sīmāntapūjana": ['mw'],
    "sīmāntara": ['mw'],
    "sīmāpahārin": ['mw'],
    "sīmāpāla": ['cae', 'mw'],
    "sīmāsammuti": ['cped'],
    "sīmāsamugghāta": ['cped'],
    "sīmāsaṃdhi": ['cae', 'mw'],
    "sīmāsetu": ['mw'],
    "sīmāsetuvinirṇaya": ['mw'],
    "sīmātiga": ['cped'],
    "sīmātikramaṇotsava": ['mw'],
    "sīmātikrāntika": ['bhs'],
    "sīmāvati": ['bhs'],
    "sīmāvinirṇaya": ['mw'],
    "sīmāvivāda": ['cae', 'mw'],
    "sīmāvivādadharma": ['mw'],
    "sīmāvāda": ['cae', 'mw'],
    "sīmāvṛkṣa": ['cae', 'mw'],
    "sīmīka": ['mw'],
    "sīna": ['cped'],
    "sīpa": ['mw'],
    "sīpada": ['cped'],
    "sīpaḥ": ['ap90'],
    "sīphalā": ['bhs'],
    "sīpāla": ['mw'],
    "sīra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sīrabhṛt": ['mw'],
    "sīradeva": ['mw'],
    "sīradhvaja": ['mw'],
    "sīraja": ['mw'],
    "sīraka": ['mw'],
    "sīrakaḥ": ['ap90'],
    "sīrapati": ['mw'],
    "sīrapāṇi": ['mw'],
    "sīravāha": ['cae', 'mw'],
    "sīravāhaka": ['mw'],
    "sīrayoga": ['mw'],
    "sīraḥ": ['ap90'],
    "sīrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "sīrotkaṣaṇa": ['mw'],
    "sīrya": ['mw'],
    "sīrā": ['cae', 'ddsa', 'gra'],
    "sīrāyudha": ['ddsa', 'mw'],
    "sīrṇa": ['mw'],
    "sīrṇi": ['mw'],
    "sīsa": ['cae', 'cped', 'ddsa', 'mw'],
    "sīsacchadana": ['cped'],
    "sīsacchavi": ['cped'],
    "sīsacchejja": ['cped'],
    "sīsaja": ['mw'],
    "sīsaka": ['cae', 'mw'],
    "sīsakapāla": ['cped'],
    "sīsakaṭāha": ['cped'],
    "sīsaparamparā": ['cped'],
    "sīsapattra": ['mw'],
    "sīsapattraka": ['mw'],
    "sīsappaccālana": ['cped'],
    "sīsara": ['ddsa', 'mw'],
    "sīsarama": ['mw'],
    "sīsatāṇa": ['mw'],
    "sīsaveṭhana": ['cped'],
    "sīsaṃ": ['ap90'],
    "sīsābādha": ['cped'],
    "sīt": ['mw'],
    "sīta": ['cped'],
    "sītabhīruka": ['cped'],
    "sītala": ['cped'],
    "sītavana": ['mw'],
    "sītibhāva": ['cped'],
    "sītibhūta": ['cped'],
    "sītkāra": ['ddsa', 'mw'],
    "sītkāraḥ": ['ap90'],
    "sītodaka": ['cped'],
    "sītopaniṣad": ['mw'],
    "sītormile": ['mw'],
    "sītya": ['ap90', 'mw'],
    "sītā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sītācaraṇacāmara": ['mw'],
    "sītādivyacaritra": ['mw'],
    "sītādravya": ['cae', 'mw'],
    "sītāgaurīvrata": ['mw'],
    "sītāgoptṛ": ['mw'],
    "sītāharaṇa": ['mw'],
    "sītāhāra": ['mw'],
    "sītājāni": ['mw'],
    "sītākalyāṇa": ['mw'],
    "sītākuṇḍa": ['mw'],
    "sītāloṣṭa": ['mw'],
    "sītāloṣṭha": ['mw'],
    "sītānadī": ['mw'],
    "sītānakaḥ": ['ap90'],
    "sītānanda": ['mw'],
    "sītānavamīvratamāhātmya": ['mw'],
    "sītānāgarāja": ['bhs'],
    "sītāpati": ['mw'],
    "sītāphala": ['mw'],
    "sītārāghavanāṭaka": ['mw'],
    "sītārāma": ['mw'],
    "sītārāmacandra": ['mw'],
    "sītārāmapaddhati": ['mw'],
    "sītārāmaparalīkara": ['mw'],
    "sītārāmasaṃkīrtana": ['mw'],
    "sītārāmastotra": ['mw'],
    "sītārāmasūri": ['mw'],
    "sītārāmatattvaprakāśa": ['mw'],
    "sītārāmavihāra": ['mw'],
    "sītārāmavihārakāvya": ['mw'],
    "sītārāmayantroddhāra": ['mw'],
    "sītārāmaśāstrin": ['mw'],
    "sītārāmānujīya": ['mw'],
    "sītārāmāṣṭaka": ['mw'],
    "sītārāmāṣṭottaraśatanāman": ['mw'],
    "sītāsahasranāman": ['mw'],
    "sītāsahasranāmastotra": ['mw'],
    "sītāstava": ['mw'],
    "sītāstotra": ['mw'],
    "sītāstuti": ['mw'],
    "sītāsvayaṃvara": ['mw'],
    "sītātīrthamāhātmya": ['mw'],
    "sītāvallabha": ['mw'],
    "sītāvana": ['mw'],
    "sītāvijayacampū": ['mw'],
    "sītāvivāha": ['mw'],
    "sītāyajña": ['cae', 'mw'],
    "sītāśruti": ['mw'],
    "sītāṣṭottaraśatanāmāvali": ['mw'],
    "sītīlaka": ['mw'],
    "sītīnaka": ['mw'],
    "sīv": ['ap90', 'ddsa'],
    "sīvaka": ['bhs', 'mw'],
    "sīvana": ['cae', 'ddsa', 'mw'],
    "sīvanaṃ": ['ap90'],
    "sīvanī": ['ap90', 'mw'],
    "sīvathikā": ['cped'],
    "sīvya": ['mw'],
    "sīyaka": ['mw'],
    "sīṃhaka": ['bhs'],
    "sū": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sūbharva": ['cae', 'gra', 'mw'],
    "sūc": ['ap90', 'mw'],
    "sūca": ['mw'],
    "sūcaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sūcana": ['cae', 'cped', 'mw'],
    "sūcanaka": ['bhs'],
    "sūcanaṃ": ['ap90'],
    "sūcanā": ['mw'],
    "sūcanī": ['mw'],
    "sūcanīya": ['cae', 'mw'],
    "sūcay": ['cae'],
    "sūcaya": ['ddsa'],
    "sūcayitavya": ['cae', 'ddsa', 'mw'],
    "sūcaḥ": ['ap90'],
    "sūccais": ['cae', 'mw'],
    "sūcchrita": ['mw'],
    "sūci": ['cae', 'cped', 'ddsa', 'mw'],
    "sūcibhedya": ['cae', 'mw'],
    "sūcibhinna": ['mw'],
    "sūcighara": ['bhs', 'cped'],
    "sūcighaṭikā": ['cped'],
    "sūcigṛha": ['bhs'],
    "sūcigṛhaka": ['mw'],
    "sūcika": ['bhs', 'mw'],
    "sūcikaḥ": ['ap90'],
    "sūcikhāta": ['mw'],
    "sūcikulāya": ['mw'],
    "sūcikā": ['ap90', 'bhs', 'cped', 'mw'],
    "sūcikābharaṇa": ['mw'],
    "sūcikādhara": ['mw'],
    "sūcikāmukha": ['mw'],
    "sūcikāra": ['cped'],
    "sūciloma": ['cped'],
    "sūcimallikā": ['mw'],
    "sūcimukha": ['cped'],
    "sūcin": ['ap90', 'cae', 'mw'],
    "sūcinī": ['ap90', 'mw'],
    "sūcipattra": ['mw'],
    "sūcipattraka": ['mw'],
    "sūcipattrika": ['mw'],
    "sūcipat‍tra": ['ddsa'],
    "sūcipuṣpa": ['mw'],
    "sūciradana": ['mw'],
    "sūciroma": ['bhs'],
    "sūciroman": ['mw'],
    "sūcisūtra": ['mw'],
    "sūcita": ['ap90', 'ddsa', 'mw'],
    "sūcitavya": ['mw'],
    "sūcitā": ['mw'],
    "sūcivadana": ['mw'],
    "sūcivat": ['ap90', 'mw'],
    "sūcivijjhana": ['cped'],
    "sūciśikhā": ['mw'],
    "sūciśāli": ['mw'],
    "sūciḥ": ['ap90'],
    "sūcy": ['mw'],
    "sūcya": ['ap90', 'cae', 'mw'],
    "sūcyagra": ['cae', 'ddsa', 'mw'],
    "sūcyagrasthūlaka": ['mw'],
    "sūcyagraviddha": ['mw'],
    "sūcyāhva": ['mw'],
    "sūcyāsya": ['mw'],
    "sūcā": ['ap90', 'bhs', 'mw'],
    "sūcī": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sūcībhedya": ['cae', 'mw'],
    "sūcīdala": ['mw'],
    "sūcīgṛha": ['bhs'],
    "sūcīka": ['cae', 'gra', 'mw'],
    "sūcīkapiśa": ['mw'],
    "sūcīkarman": ['mw'],
    "sūcīkaṭāhanyāya": ['mw'],
    "sūcīkhāta": ['mw'],
    "sūcīmukha": ['cae', 'mw'],
    "sūcīmukhāgrasambhedya": ['mw'],
    "sūcīmukhī": ['mw'],
    "sūcīpadaka": ['bhs'],
    "sūcīpadma": ['mw'],
    "sūcīpadī": ['mw'],
    "sūcīpattra": ['mw'],
    "sūcīpattrā": ['mw'],
    "sūcīprota": ['mw'],
    "sūcīpuṣpa": ['mw'],
    "sūcīpāśa": ['mw'],
    "sūcīroman": ['mw'],
    "sūcīsūtra": ['mw'],
    "sūcītuṇḍa": ['mw'],
    "sūcīvaktra": ['mw'],
    "sūcīvānakarman": ['mw'],
    "sūd": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sūda": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sūdadohas": ['gra', 'mw'],
    "sūdaka": ['cped', 'mw'],
    "sūdakarman": ['cae', 'mw'],
    "sūdana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sūdanā": ['bhs'],
    "sūdara": ['mw'],
    "sūdatva": ['mw'],
    "sūdatā": ['mw'],
    "sūdavat": ['mw'],
    "sūdayitnu": ['cae', 'gra', 'mw'],
    "sūdayā": ['bhs', 'mw'],
    "sūdaśālā": ['cae', 'ddsa', 'mw'],
    "sūdaśāstra": ['mw'],
    "sūdaḥ": ['ap90'],
    "sūdgātṛ": ['mw'],
    "sūdhana": ['bhs'],
    "sūdi": ['mw'],
    "sūdin": ['cae', 'mw'],
    "sūdita": ['mw'],
    "sūditṛ": ['mw'],
    "sūdya": ['cae', 'mw'],
    "sūdādhyakṣa": ['mw'],
    "sūdāvatsa": ['mw'],
    "sūdī": ['mw'],
    "sūju": ['cped'],
    "sūka": ['bhs', 'cped', 'mw'],
    "sūkara": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sūkaradaṃṣṭra": ['mw'],
    "sūkaradaṃṣṭraka": ['mw'],
    "sūkaragṛha": ['mw'],
    "sūkaraka": ['mw'],
    "sūkarakanda": ['mw'],
    "sūkarakṣetra": ['mw'],
    "sūkaramaṁsa": ['cped'],
    "sūkaramukha": ['mw'],
    "sūkaranayana": ['mw'],
    "sūkarapadī": ['mw'],
    "sūkarapotaka": ['cped'],
    "sūkarapreyasī": ['mw'],
    "sūkarapādikā": ['mw'],
    "sūkarapādī": ['mw'],
    "sūkarasadman": ['mw'],
    "sūkaratā": ['mw'],
    "sūkaraḥ": ['ap90'],
    "sūkareṣṭa": ['mw'],
    "sūkarika": ['cped', 'mw'],
    "sūkarikā": ['bhs', 'mw'],
    "sūkarikāvadāna": ['bhs'],
    "sūkarākrāntā": ['mw'],
    "sūkarākṣitā": ['mw'],
    "sūkarāsyā": ['mw'],
    "sūkarī": ['mw'],
    "sūkaḥ": ['ap90'],
    "sūkhara": ['mw'],
    "sūkta": ['cae', 'ddsa', 'gra', 'mw'],
    "sūktabhāj": ['mw'],
    "sūktacārin": ['mw'],
    "sūktadarśin": ['mw'],
    "sūktadarśitva": ['mw'],
    "sūktadraṣṭṛ": ['mw'],
    "sūktamukhīya": ['mw'],
    "sūktapañcaka": ['mw'],
    "sūktaratnākara": ['mw'],
    "sūktavāc": ['cae', 'gra', 'mw'],
    "sūktavāka": ['cae', 'gra', 'mw'],
    "sūktavākya": ['mw'],
    "sūkti": ['cae', 'mw'],
    "sūktika": ['mw'],
    "sūktimañjarīprakāśa": ['mw'],
    "sūktimuktā": ['mw'],
    "sūktimuktāvali": ['mw'],
    "sūktimuktāvalī": ['mw'],
    "sūktimālikā": ['mw'],
    "sūktiratnākara": ['mw'],
    "sūktisahasra": ['mw'],
    "sūktisaṃgraha": ['mw'],
    "sūktisādhutvamālikā": ['mw'],
    "sūktocya": ['mw'],
    "sūktokti": ['mw'],
    "sūkty": ['mw'],
    "sūktyādarśa": ['mw'],
    "sūktā": ['mw'],
    "sūktāmṛtapunaruktopadaṃśanadaśana": ['mw'],
    "sūktānukramaṇī": ['mw'],
    "sūktāsi": ['mw'],
    "sūktāvali": ['mw'],
    "sūkṣma": ['ap90', 'cae', 'ddsa', 'mw'],
    "sūkṣmabadarī": ['mw'],
    "sūkṣmabhūta": ['cae', 'mw'],
    "sūkṣmabīja": ['mw'],
    "sūkṣmacakra": ['mw'],
    "sūkṣmadala": ['mw'],
    "sūkṣmadalā": ['mw'],
    "sūkṣmadarśin": ['cae', 'mw'],
    "sūkṣmadarśitā": ['cae', 'mw'],
    "sūkṣmadeha": ['mw'],
    "sūkṣmadharma": ['mw'],
    "sūkṣmadāru": ['mw'],
    "sūkṣmadṛṣṭi": ['cae', 'mw'],
    "sūkṣmaghaṇṭikā": ['mw'],
    "sūkṣmailā": ['mw'],
    "sūkṣmajātaka": ['mw'],
    "sūkṣmakṛśaphalā": ['mw'],
    "sūkṣmakṛṣṇaphalā": ['mw'],
    "sūkṣmalobhaka": ['mw'],
    "sūkṣmam": ['mw'],
    "sūkṣmamakṣika": ['mw'],
    "sūkṣmamant": ['cae'],
    "sūkṣmamati": ['cae', 'mw'],
    "sūkṣmamatimat": ['mw'],
    "sūkṣmamāna": ['mw'],
    "sūkṣmamūlā": ['mw'],
    "sūkṣmanābha": ['mw'],
    "sūkṣmaparṇā": ['mw'],
    "sūkṣmaparṇī": ['mw'],
    "sūkṣmapattra": ['mw'],
    "sūkṣmapattraka": ['mw'],
    "sūkṣmapattrikā": ['mw'],
    "sūkṣmapattrā": ['mw'],
    "sūkṣmapattrī": ['mw'],
    "sūkṣmaphala": ['mw'],
    "sūkṣmaphalā": ['mw'],
    "sūkṣmapippalī": ['mw'],
    "sūkṣmapuṣpī": ['mw'],
    "sūkṣmapāda": ['cae', 'mw'],
    "sūkṣmapādatva": ['mw'],
    "sūkṣmasphoṭa": ['mw'],
    "sūkṣmatama": ['mw'],
    "sūkṣmatantra": ['mw'],
    "sūkṣmatara": ['mw'],
    "sūkṣmataṇḍula": ['mw'],
    "sūkṣmataṇḍulā": ['mw'],
    "sūkṣmatuṇḍa": ['mw'],
    "sūkṣmatva": ['mw'],
    "sūkṣmatvac": ['bhs'],
    "sūkṣmatā": ['mw'],
    "sūkṣmavallī": ['mw'],
    "sūkṣmavastra": ['bhs'],
    "sūkṣmaviṣaya": ['cae'],
    "sūkṣmavāluka": ['mw'],
    "sūkṣmaśarkarā": ['mw'],
    "sūkṣmaśarīra": ['cae', 'mw'],
    "sūkṣmaśiraska": ['mw'],
    "sūkṣmaśāka": ['mw'],
    "sūkṣmaśākha": ['mw'],
    "sūkṣmaśāli": ['mw'],
    "sūkṣmaṣaṭcaraṇa": ['mw'],
    "sūkṣmaṭikka": ['mw'],
    "sūkṣmekṣikā": ['mw'],
    "sūkṣmya": ['mw'],
    "sūkṣmā": ['mw'],
    "sūkṣmākṣa": ['mw'],
    "sūkṣmākṣatā": ['mw'],
    "sūkṣmātman": ['mw'],
    "sūkṣmī": ['mw'],
    "sūkṣmībhūta": ['mw'],
    "sūkṣmīkṛ": ['mw'],
    "sūkṣmīkṛta": ['mw'],
    "sūla": ['cped'],
    "sūlāropaṇa": ['cped'],
    "sūlīka": ['mw'],
    "sūma": ['gra', 'mw'],
    "sūmati": ['bhs'],
    "sūmaya": ['gra', 'mw'],
    "sūmaḥ": ['ap90'],
    "sūna": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sūnara": ['cae', 'ddsa', 'gra', 'mw'],
    "sūnarī": ['ap90'],
    "sūnavat": ['mw'],
    "sūnaśara": ['mw'],
    "sūnika": ['cae', 'ddsa', 'mw'],
    "sūnin": ['ap90', 'cae', 'mw'],
    "sūnmada": ['mw'],
    "sūnmāda": ['mw'],
    "sūnnīya": ['mw'],
    "sūnu": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sūnumat": ['gra', 'mw'],
    "sūnurūpa": ['mw'],
    "sūnutā": ['mw'],
    "sūnuḥ": ['ap90'],
    "sūnā": ['ap90', 'cped', 'ddsa', 'gra', 'mw'],
    "sūnācakradhvajavant": ['cae'],
    "sūnācakradhvajavat": ['mw'],
    "sūnādoṣa": ['cae', 'mw'],
    "sūnāghara": ['cped'],
    "sūnāparicara": ['cae', 'mw'],
    "sūnāstha": ['cae', 'mw'],
    "sūnātaṭi": ['mw'],
    "sūnū": ['ap90'],
    "sūnṛta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sūnṛtavāc": ['mw'],
    "sūnṛtā": ['mw'],
    "sūnṛtānṛta": ['mw'],
    "sūnṛtāvan": ['cae', 'gra'],
    "sūnṛtāvant": ['cae'],
    "sūnṛtāvarī": ['mw'],
    "sūnṛtāvat": ['gra', 'mw'],
    "sūpa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "sūpacara": ['cae', 'mw'],
    "sūpacaraṇa": ['cae', 'mw'],
    "sūpacāra": ['cae', 'mw'],
    "sūpadhārita": ['cped'],
    "sūpadhūpaka": ['mw'],
    "sūpadhūpana": ['mw'],
    "sūpadvaṃśa": ['mw'],
    "sūpadvāra": ['mw'],
    "sūpagandhi": ['mw'],
    "sūpaka": ['bhs'],
    "sūpakartṛ": ['cae', 'mw'],
    "sūpakāra": ['cae', 'mw'],
    "sūpakṛt": ['cae', 'mw'],
    "sūpaparṇī": ['mw'],
    "sūpaprati": ['mw'],
    "sūparasa": ['cae', 'cped', 'mw'],
    "sūpasadana": ['mw'],
    "sūpasampanna": ['mw'],
    "sūpasarpaṇa": ['mw'],
    "sūpasaṃskṛta": ['mw'],
    "sūpasaṃsṛṣṭa": ['mw'],
    "sūpasiddha": ['mw'],
    "sūpaskara": ['mw'],
    "sūpastha": ['gra'],
    "sūpasthā": ['mw'],
    "sūpasthāna": ['mw'],
    "sūpat": ['mw'],
    "sūpatittha": ['cped'],
    "sūpatīrtha": ['mw'],
    "sūpatīrthya": ['mw'],
    "sūpaudanaṣaṣṭhīpūjā": ['mw'],
    "sūpavañcana": ['cae', 'gra', 'mw'],
    "sūpaviṣṭa": ['mw'],
    "sūpayukta": ['mw'],
    "sūpaśreṣṭha": ['mw'],
    "sūpaśāstra": ['mw'],
    "sūpaḥ": ['ap90'],
    "sūpaṭṭhita": ['cped'],
    "sūpaṭṭhāka": ['cped'],
    "sūpeyya": ['cped'],
    "sūpeyyapaṇṇa": ['cped'],
    "sūpeśāṇa": ['mw'],
    "sūpika": ['bhs', 'cped', 'mw'],
    "sūpya": ['mw'],
    "sūpāvasāna": ['mw'],
    "sūpāvṛt": ['mw'],
    "sūpāya": ['cae', 'mw'],
    "sūpāyana": ['cae', 'gra', 'mw'],
    "sūpāṅga": ['mw'],
    "sūpīya": ['mw'],
    "sūr": ['ap90', 'ddsa', 'gra', 'mw'],
    "sūra": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "sūrabhāva": ['cped'],
    "sūracakṣas": ['cae', 'gra', 'mw'],
    "sūracandra": ['mw'],
    "sūradāsa": ['mw'],
    "sūrajī": ['mw'],
    "sūrakanda": ['mw'],
    "sūrakṛt": ['mw'],
    "sūramasa": ['mw'],
    "sūrasena": ['mw'],
    "sūrasuta": ['cae', 'mw'],
    "sūrasūta": ['mw'],
    "sūrata": ['ap90', 'bhs', 'mw'],
    "sūratakalpataru": ['mw'],
    "sūratasiṃha": ['mw'],
    "sūratha": ['mw'],
    "sūratā": ['cped', 'mw'],
    "sūravarman": ['mw'],
    "sūravat": ['mw'],
    "sūraḥ": ['ap90'],
    "sūraṇa": ['mw'],
    "sūraṇaḥ": ['ap90'],
    "sūri": ['cae', 'ddsa', 'gra', 'mw'],
    "sūria": ['gra'],
    "sūriaraśmi": ['gra'],
    "sūriatvac": ['gra'],
    "sūriaśvit": ['gra'],
    "sūribhaṭṭa": ['mw'],
    "sūrideva": ['mw'],
    "sūrin": ['ap90', 'mw'],
    "sūrisaṃtoṣa": ['mw'],
    "sūriya": ['cped'],
    "sūriā": ['gra'],
    "sūriāmās": ['gra'],
    "sūriāvasu": ['gra'],
    "sūriḥ": ['ap90'],
    "sūrjana": ['mw'],
    "sūrjanacarita": ['mw'],
    "sūrkṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "sūrkṣaṇa": ['mw'],
    "sūrkṣaṇaṃ": ['ap90'],
    "sūrkṣy": ['ap90', 'mw'],
    "sūrkṣya": ['cae', 'mw'],
    "sūrkṣyaḥ": ['ap90'],
    "sūrkṣyaṇaṃ": ['ap90'],
    "sūrmi": ['cae', 'ddsa', 'gra', 'mw'],
    "sūrmiḥ": ['ap90'],
    "sūrmya": ['cae', 'mw'],
    "sūrmyā": ['mw'],
    "sūrmī": ['cae', 'gra', 'mw'],
    "sūrpa": ['ap90', 'mw'],
    "sūrta": ['cae', 'ddsa', 'gra', 'mw'],
    "sūrvya": ['mw'],
    "sūrya": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "sūryabali": ['mw'],
    "sūryabalirāma": ['mw'],
    "sūryabhakta": ['mw'],
    "sūryabhaktaka": ['mw'],
    "sūryabhaktā": ['mw'],
    "sūryabhaṭṭa": ['mw'],
    "sūryabhaṭṭīya": ['mw'],
    "sūryabhrāj": ['mw'],
    "sūryabhrātṛ": ['mw'],
    "sūryabhā": ['mw'],
    "sūryabhāgā": ['mw'],
    "sūryabhānu": ['mw'],
    "sūryabhās": ['mw'],
    "sūryabimba": ['cae', 'mw'],
    "sūryabimbatīrtha": ['mw'],
    "sūryacakṣus": ['mw'],
    "sūryacandra": ['mw'],
    "sūryacandragrahaṇa": ['mw'],
    "sūryacandramas": ['mw'],
    "sūryacandramasa": ['mw'],
    "sūryacandrastotra": ['mw'],
    "sūryacandravrata": ['mw'],
    "sūryacandravratakalpa": ['mw'],
    "sūryacandroparāgaśānti": ['mw'],
    "sūryadatta": ['mw'],
    "sūryadaśāphala": ['mw'],
    "sūryadeva": ['mw'],
    "sūryadevatya": ['mw'],
    "sūryadhara": ['mw'],
    "sūryadhvaja": ['bhs', 'mw'],
    "sūryadhvajapatākin": ['mw'],
    "sūryadhyāna": ['mw'],
    "sūryadvādaśāryā": ['mw'],
    "sūryadāsa": ['mw'],
    "sūryadṛś": ['mw'],
    "sūryagarbha": ['bhs', 'mw'],
    "sūryagaṅgātīrtha": ['mw'],
    "sūryagraha": ['mw'],
    "sūryagrahaṇa": ['mw'],
    "sūryagupta": ['bhs', 'mw'],
    "sūryagātrapravara": ['bhs'],
    "sūryahṛdaya": ['mw'],
    "sūryaja": ['cae', 'mw'],
    "sūryajyotis": ['cae', 'mw'],
    "sūryajā": ['mw'],
    "sūryaka": ['mw'],
    "sūryakalpa": ['mw'],
    "sūryakamala": ['mw'],
    "sūryakara": ['cae', 'mw'],
    "sūryakaramiśra": ['mw'],
    "sūryakavaca": ['mw'],
    "sūryakavi": ['mw'],
    "sūryakesaranirbhāsā": ['bhs'],
    "sūryaketu": ['mw'],
    "sūryakrānta": ['mw'],
    "sūryakāla": ['mw'],
    "sūryakālānala": ['mw'],
    "sūryakālānalacakra": ['mw'],
    "sūryakānta": ['cae', 'mw'],
    "sūryakānti": ['mw'],
    "sūryakṣaya": ['mw'],
    "sūryalatā": ['mw'],
    "sūryalocanā": ['bhs', 'mw'],
    "sūryaloka": ['mw'],
    "sūryamalla": ['mw'],
    "sūryamantra": ['mw'],
    "sūryamarut": ['mw'],
    "sūryamaruta": ['mw'],
    "sūryamatī": ['mw'],
    "sūryamaṇi": ['mw'],
    "sūryamaṇivṛkṣa": ['mw'],
    "sūryamaṇḍala": ['cae', 'mw'],
    "sūryamaṇḍalapratibhāsottamaśrī": ['bhs'],
    "sūryamitra": ['bhs'],
    "sūryampaśya": ['mw'],
    "sūryamukhī": ['mw'],
    "sūryamāla": ['mw'],
    "sūryamāsa": ['mw'],
    "sūryanagara": ['mw'],
    "sūryanakṣatra": ['mw'],
    "sūryanakṣatrayoga": ['mw'],
    "sūryanamaskāra": ['mw'],
    "sūryanamaskāramantra": ['mw'],
    "sūryanamaskāravidhi": ['mw'],
    "sūryanandana": ['mw'],
    "sūryanetra": ['mw'],
    "sūryantī": ['mw'],
    "sūryanābha": ['mw'],
    "sūryanārāyaṇa": ['mw'],
    "sūryanārāyaṇakavaca": ['mw'],
    "sūryanārāyaṇapūjā": ['mw'],
    "sūryanārāyaṇastotra": ['mw'],
    "sūryanārāyaṇavrata": ['mw'],
    "sūryanāḍī": ['mw'],
    "sūryapakṣakaraṇa": ['mw'],
    "sūryapakṣaśaraṇa": ['mw'],
    "sūryaparvan": ['mw'],
    "sūryaparṇī": ['mw'],
    "sūryapati": ['mw'],
    "sūryapatnī": ['mw'],
    "sūryapattra": ['mw'],
    "sūryapañcāṅga": ['mw'],
    "sūryapañcāṅgastotra": ['mw'],
    "sūryapaṇḍita": ['mw'],
    "sūryaphaṇicakra": ['mw'],
    "sūryaprabha": ['bhs', 'cae', 'mw'],
    "sūryaprabhatejas": ['bhs'],
    "sūryaprabhatā": ['mw'],
    "sūryaprabhava": ['mw'],
    "sūryaprabhātejas": ['mw'],
    "sūryaprabhīya": ['mw'],
    "sūryapradīpa": ['bhs', 'mw'],
    "sūryapradīpaketuśrī": ['bhs'],
    "sūryaprajñapti": ['mw'],
    "sūryaprakāśa": ['mw'],
    "sūryapratibhāsa": ['bhs'],
    "sūryapratiṣṭhā": ['mw'],
    "sūryapratiṣṭhāmāhātmya": ['mw'],
    "sūryapraśiṣya": ['mw'],
    "sūryapura": ['mw'],
    "sūryapurāṇa": ['mw'],
    "sūryaputra": ['cae', 'mw'],
    "sūryaputrī": ['mw'],
    "sūryapāda": ['cae', 'mw'],
    "sūryapūjā": ['mw'],
    "sūryapūjāvidhi": ['mw'],
    "sūryarahasya": ['mw'],
    "sūryaratha": ['mw'],
    "sūryaraśmi": ['cae', 'gra', 'mw'],
    "sūryarc": ['mw'],
    "sūryarkṣa": ['mw'],
    "sūryaruc": ['mw'],
    "sūryarājya": ['mw'],
    "sūryarāma": ['mw'],
    "sūryasadṛśa": ['mw'],
    "sūryasahasranāman": ['mw'],
    "sūryasahasranāmāvalī": ['mw'],
    "sūryasama": ['cae', 'mw'],
    "sūryasaptati": ['mw'],
    "sūryasaptāryā": ['mw'],
    "sūryasaṃjña": ['mw'],
    "sūryasaṃkrama": ['mw'],
    "sūryasaṃkrānti": ['mw'],
    "sūryasena": ['mw'],
    "sūryasiddhānta": ['cae', 'mw'],
    "sūryasiddhāntabhāṣya": ['mw'],
    "sūryasiddhāntadīpikā": ['mw'],
    "sūryasiddhāntamañjarī": ['mw'],
    "sūryasiddhāntapradīpikā": ['mw'],
    "sūryasiddhāntaprakāśa": ['mw'],
    "sūryasiddhāntarahasya": ['mw'],
    "sūryasiddhāntasāraṇī": ['mw'],
    "sūryasiddhāntavyākhyā": ['mw'],
    "sūryasiddhāntavyākhyāna": ['mw'],
    "sūryasiddhāntavyākhyāvivaraṇa": ['mw'],
    "sūryasiddhāntavāsanābhāṣya": ['mw'],
    "sūryasiddhāntaṭīkā": ['mw'],
    "sūryasiddhāntodāharaṇa": ['mw'],
    "sūryasiṃha": ['mw'],
    "sūryastavakapālamocana": ['mw'],
    "sūryastavana": ['mw'],
    "sūryastotra": ['mw'],
    "sūryastut": ['mw'],
    "sūryastuti": ['mw'],
    "sūryasuta": ['mw'],
    "sūryasāman": ['mw'],
    "sūryasārathi": ['mw'],
    "sūryasāvarṇi": ['mw'],
    "sūryasāvarṇika": ['mw'],
    "sūryasāvitra": ['mw'],
    "sūryasūkta": ['mw'],
    "sūryasūri": ['mw'],
    "sūryasūta": ['mw'],
    "sūryatanaya": ['cae', 'mw'],
    "sūryatanayā": ['mw'],
    "sūryatapas": ['mw'],
    "sūryatejas": ['bhs', 'cae', 'mw'],
    "sūryatvac": ['cae', 'gra', 'mw'],
    "sūryatvaca": ['mw'],
    "sūryatvacas": ['cae', 'mw'],
    "sūryatāpinī": ['mw'],
    "sūryatīrtha": ['mw'],
    "sūryavaiśvānara": ['mw'],
    "sūryavajrapañjara": ['mw'],
    "sūryavaktra": ['mw'],
    "sūryavallī": ['mw'],
    "sūryavana": ['mw'],
    "sūryavant": ['cae'],
    "sūryavara": ['mw'],
    "sūryavaralocana": ['mw'],
    "sūryavarcas": ['cae', 'mw'],
    "sūryavarga": ['mw'],
    "sūryavarman": ['mw'],
    "sūryavaruṇa": ['mw'],
    "sūryavarṇa": ['cae', 'mw'],
    "sūryavat": ['mw'],
    "sūryavatī": ['mw'],
    "sūryavaṃśa": ['cae', 'mw'],
    "sūryavaṃśya": ['mw'],
    "sūryaveśman": ['mw'],
    "sūryavidyutprabha": ['bhs'],
    "sūryavighna": ['mw'],
    "sūryavikramasamantapratibhāsa": ['bhs'],
    "sūryavikrānta": ['bhs'],
    "sūryavikāsin": ['mw'],
    "sūryavilokana": ['mw'],
    "sūryavrata": ['mw'],
    "sūryavratakathā": ['mw'],
    "sūryavratamahiman": ['mw'],
    "sūryavāra": ['cae', 'mw'],
    "sūryayama": ['mw'],
    "sūryayantra": ['mw'],
    "sūryaśataka": ['mw'],
    "sūryaśiṣya": ['mw'],
    "sūryaśiṣyāntevāsin": ['mw'],
    "sūryaśobhā": ['mw'],
    "sūryaśrit": ['mw'],
    "sūryaśrī": ['mw'],
    "sūryaśvit": ['gra', 'mw'],
    "sūryaśānti": ['mw'],
    "sūryaḥ": ['ap90'],
    "sūryaṣaḍakṣarī": ['mw'],
    "sūryaṣaṭpadī": ['mw'],
    "sūryendusaṃgama": ['mw'],
    "sūryeṣṭiprayoga": ['mw'],
    "sūryobhāsa": ['bhs'],
    "sūryodana": ['bhs'],
    "sūryodaya": ['bhs', 'cae', 'mw'],
    "sūryodayagiri": ['mw'],
    "sūryodayana": ['mw'],
    "sūryodayanibandha": ['mw'],
    "sūryodayasaṃkalpanāṭaka": ['mw'],
    "sūryodayavarṇana": ['mw'],
    "sūryodayāsta": ['mw'],
    "sūryodayāstakāla": ['mw'],
    "sūryodyāna": ['mw'],
    "sūryopaniṣad": ['bhs', 'mw'],
    "sūryopasthānamantra": ['mw'],
    "sūryopasthānavidhi": ['mw'],
    "sūryopāsaka": ['mw'],
    "sūryopāsanā": ['mw'],
    "sūryopāsanāvidhi": ['mw'],
    "sūryottarajñānin": ['bhs'],
    "sūryotthāna": ['mw'],
    "sūryoḍha": ['cae', 'ddsa', 'mw'],
    "sūryā": ['ap90', 'ddsa', 'gra', 'mw'],
    "sūryābhinimlukta": ['mw'],
    "sūryābhinimrukta": ['mw'],
    "sūryābhyudita": ['mw'],
    "sūryācandramas": ['cae', 'gra'],
    "sūryācandramasau": ['mw'],
    "sūryācandramasā": ['mw'],
    "sūryādigrahaphalakuṇḍalī": ['mw'],
    "sūryādigrahaprītyarthadāna": ['mw'],
    "sūryādigrahasādhana": ['mw'],
    "sūryādipañcāyatanapratiṣṭhāpaddhati": ['mw'],
    "sūryādipratimāpratiṣṭhāvidhi": ['mw'],
    "sūryādivarṣaphalokti": ['mw'],
    "sūryādri": ['mw'],
    "sūryāgama": ['mw'],
    "sūryāgnī": ['mw'],
    "sūryāhva": ['mw'],
    "sūryākara": ['mw'],
    "sūryākṣa": ['mw'],
    "sūryāloka": ['mw'],
    "sūryāmās": ['cae', 'gra'],
    "sūryāmāsā": ['mw'],
    "sūryānana": ['bhs', 'mw'],
    "sūryānuvādinī": ['mw'],
    "sūryāpāya": ['mw'],
    "sūryāpīḍa": ['mw'],
    "sūryārghya": ['mw'],
    "sūryārghyadānapaddhati": ['mw'],
    "sūryārghyavidhi": ['mw'],
    "sūryāruṇakarmavipāka": ['mw'],
    "sūryāruṇasaṃvāda": ['mw'],
    "sūryāruṇasmṛti": ['mw'],
    "sūryāruṇaśataka": ['mw'],
    "sūryāryā": ['mw'],
    "sūryārṇava": ['mw'],
    "sūryārṇavakarmavipāka": ['mw'],
    "sūryāsta": ['cae', 'mw'],
    "sūryāstamaya": ['mw'],
    "sūryāstamayavat": ['mw'],
    "sūryāstaṃgamana": ['mw'],
    "sūryāsūkta": ['mw'],
    "sūryātapa": ['cae', 'mw'],
    "sūryātapacchinnadṛṣṭi": ['mw'],
    "sūryātapaparikṣipta": ['mw'],
    "sūryātharvaśīrṣopaniṣad": ['mw'],
    "sūryātharvāṅgirasopaniṣad": ['mw'],
    "sūryātmaja": ['mw'],
    "sūryāvabhāsa": ['bhs'],
    "sūryāvalokanaprayoga": ['mw'],
    "sūryāvarta": ['bhs', 'mw'],
    "sūryāvartarasa": ['mw'],
    "sūryāvartā": ['bhs', 'mw'],
    "sūryāvasu": ['gra', 'mw'],
    "sūryāvekṣaṇa": ['mw'],
    "sūryāvid": ['mw'],
    "sūryāvivāha": ['mw'],
    "sūryāśman": ['mw'],
    "sūryāśva": ['mw'],
    "sūryāṃśu": ['ddsa', 'mw'],
    "sūryāṇī": ['mw'],
    "sūryāṣṭaka": ['mw'],
    "sūryāṣṭaśatanāman": ['mw'],
    "sūryāṣṭottaraśatanāman": ['mw'],
    "sūrācārya": ['mw'],
    "sūrāpagā": ['mw'],
    "sūrāsanadeśa": ['mw'],
    "sūrī": ['ap90', 'bhs', 'mw'],
    "sūrṇa": ['ap90'],
    "sūt": ['ap90', 'mw'],
    "sūta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "sūtaduhitṛ": ['mw'],
    "sūtagrāmaṇī": ['mw'],
    "sūtaja": ['cae', 'mw'],
    "sūtaka": ['cae', 'ddsa', 'mw'],
    "sūtakabhojana": ['mw'],
    "sūtakarman": ['mw'],
    "sūtakasiddhānta": ['mw'],
    "sūtakasāra": ['mw'],
    "sūtakaṃ": ['ap90'],
    "sūtakin": ['mw'],
    "sūtakā": ['ap90', 'mw'],
    "sūtakāgni": ['mw'],
    "sūtakāgṛha": ['mw'],
    "sūtakānna": ['cae', 'mw'],
    "sūtakānnādya": ['cae', 'mw'],
    "sūtamahodadhi": ['mw'],
    "sūtamukha": ['mw'],
    "sūtanandana": ['mw'],
    "sūtaputra": ['cae', 'mw'],
    "sūtaputraka": ['mw'],
    "sūtaputrī": ['mw'],
    "sūtarāj": ['mw'],
    "sūtasava": ['mw'],
    "sūtasaṃhitā": ['mw'],
    "sūtasaṃhitāsaṃgraha": ['mw'],
    "sūtasaṃhitātātparyadīpikā": ['mw'],
    "sūtasaṃhitāvyākhyā": ['mw'],
    "sūtatanaya": ['cae', 'mw'],
    "sūtatva": ['ddsa', 'mw'],
    "sūtatā": ['mw'],
    "sūtavaśā": ['mw'],
    "sūtave": ['mw'],
    "sūtavyasanin": ['mw'],
    "sūti": ['cae', 'ddsa', 'gra', 'mw'],
    "sūtighara": ['cped'],
    "sūtigṛha": ['mw'],
    "sūtika": ['mw'],
    "sūtikotthāna": ['mw'],
    "sūtikā": ['ap90', 'ddsa', 'mw'],
    "sūtikābhavana": ['mw'],
    "sūtikāgada": ['mw'],
    "sūtikāgeha": ['mw'],
    "sūtikāgni": ['mw'],
    "sūtikāgāra": ['mw'],
    "sūtikāgṛha": ['mw'],
    "sūtikāla": ['mw'],
    "sūtikāmāruta": ['mw'],
    "sūtikānna": ['cae'],
    "sūtikāroga": ['mw'],
    "sūtikāvāsa": ['mw'],
    "sūtikāṣaṣṭhī": ['mw'],
    "sūtikāṣaṣṭhīpūjā": ['mw'],
    "sūtimatī": ['mw'],
    "sūtimāruta": ['mw'],
    "sūtimās": ['mw'],
    "sūtimāsa": ['mw'],
    "sūtiroga": ['mw'],
    "sūtivāta": ['mw'],
    "sūtiḥ": ['ap90'],
    "sūtkhalin": ['bhs'],
    "sūtkāra": ['ddsa', 'mw'],
    "sūtkṛta": ['mw'],
    "sūtpalāvatī": ['mw'],
    "sūtpara": ['mw'],
    "sūtparaṃ": ['ap90'],
    "sūtr": ['ap90', 'mw'],
    "sūtra": ['bhs', 'cae', 'ddsa', 'mw'],
    "sūtrabhid": ['mw'],
    "sūtrabhāṣya": ['mw'],
    "sūtrabhāṣyavyākhyā": ['mw'],
    "sūtrabhṛt": ['cae', 'mw'],
    "sūtracaraṇa": ['mw'],
    "sūtradaridra": ['mw'],
    "sūtradaridratā": ['mw'],
    "sūtradhara": ['bhs', 'mw'],
    "sūtradhāra": ['cae', 'mw'],
    "sūtradhāramaṇḍana": ['mw'],
    "sūtradhārī": ['mw'],
    "sūtradhṛk": ['mw'],
    "sūtradīpikā": ['mw'],
    "sūtragaṇita": ['mw'],
    "sūtragaṇḍikā": ['mw'],
    "sūtragraha": ['mw'],
    "sūtragrantha": ['mw'],
    "sūtragrāha": ['mw'],
    "sūtrajāla": ['mw'],
    "sūtraka": ['mw'],
    "sūtrakaraṇa": ['mw'],
    "sūtrakarmakṛt": ['mw'],
    "sūtrakarman": ['mw'],
    "sūtrakarmaviśārada": ['mw'],
    "sūtrakartṛ": ['cae', 'mw'],
    "sūtrakaṇṭha": ['mw'],
    "sūtrakośa": ['mw'],
    "sūtrakoṇa": ['mw'],
    "sūtrakoṇaka": ['mw'],
    "sūtrakrīḍā": ['mw'],
    "sūtrakāra": ['cae', 'mw'],
    "sūtrakṛt": ['cae', 'mw'],
    "sūtrakṛtāṅgavṛtti": ['mw'],
    "sūtralā": ['ap90', 'mw'],
    "sūtramadhyabhū": ['mw'],
    "sūtramantraprakāśaka": ['mw'],
    "sūtramaya": ['mw'],
    "sūtramuktākalāpa": ['mw'],
    "sūtranaḍa": ['mw'],
    "sūtranyāsa": ['mw'],
    "sūtrapada": ['bhs'],
    "sūtrapadī": ['mw'],
    "sūtrapattrakara": ['mw'],
    "sūtrapattrin": ['mw'],
    "sūtrapiṭaka": ['bhs', 'mw'],
    "sūtraprakāśabhāṣya": ['mw'],
    "sūtraprakāśikā": ['mw'],
    "sūtraprasthāna": ['mw'],
    "sūtraprota": ['mw'],
    "sūtrapuṣpa": ['mw'],
    "sūtrapāda": ['mw'],
    "sūtrapāta": ['mw'],
    "sūtrapāṭhānukrama": ['mw'],
    "sūtrarāja": ['mw'],
    "sūtrasamuccaya": ['mw'],
    "sūtrasaṃgraha": ['mw'],
    "sūtrasaṃgrahadīpikā": ['mw'],
    "sūtrasthāna": ['mw'],
    "sūtratantu": ['mw'],
    "sūtratarkuṭī": ['mw'],
    "sūtraveṣṭana": ['mw'],
    "sūtravid": ['mw'],
    "sūtravikrayin": ['mw'],
    "sūtravāpa": ['mw'],
    "sūtravīṇā": ['mw'],
    "sūtray": ['cae'],
    "sūtraya": ['ddsa', 'mw'],
    "sūtrayantra": ['mw'],
    "sūtrayati": ['bhs', 'mw'],
    "sūtrayitavya": ['ddsa', 'mw'],
    "sūtraśākha": ['mw'],
    "sūtraṃ": ['ap90'],
    "sūtraṇa": ['mw'],
    "sūtraṇaṃ": ['ap90'],
    "sūtrika": ['mw'],
    "sūtrikā": ['ap90', 'ddsa', 'mw'],
    "sūtrin": ['ap90', 'cae', 'mw'],
    "sūtrita": ['ap90', 'mw'],
    "sūtritatva": ['mw'],
    "sūtropanyāsa": ['mw'],
    "sūtrota": ['mw'],
    "sūtrālaṃkāra": ['mw'],
    "sūtrālaṃkārabhāṣya": ['mw'],
    "sūtrālaṃkāraṭīkā": ['mw'],
    "sūtrālī": ['mw'],
    "sūtrāman": ['ap90', 'mw'],
    "sūtrānta": ['bhs', 'mw'],
    "sūtrāntaka": ['bhs', 'mw'],
    "sūtrārtha": ['mw'],
    "sūtrārthacandrikā": ['mw'],
    "sūtrārthadarpaṇa": ['mw'],
    "sūtrātman": ['cae', 'ddsa', 'mw'],
    "sūtrī": ['cae', 'mw'],
    "sūtrīkṛ": ['mw'],
    "sūtrīya": ['mw'],
    "sūtta": ['mw'],
    "sūttara": ['mw'],
    "sūtthita": ['mw'],
    "sūtthāna": ['mw'],
    "sūtu": ['cae', 'mw'],
    "sūty": ['mw'],
    "sūtya": ['mw'],
    "sūtyā": ['ap90', 'mw'],
    "sūtyāśauca": ['mw'],
    "sūtā": ['ap90', 'mw'],
    "sūtārṇava": ['mw'],
    "sūtī": ['mw'],
    "sūtīgṛha": ['mw'],
    "sūtīmāsa": ['mw'],
    "sūtīvṛtti": ['mw'],
    "sūvan": ['gra', 'mw'],
    "sūvarī": ['cae'],
    "sūya": ['mw'],
    "sūyamāna": ['cped'],
    "sūyati": ['cped'],
    "sūyavasa": ['cae', 'gra', 'mw'],
    "sūyavasin": ['cae', 'gra'],
    "sūyavasyu": ['cae', 'gra'],
    "sūyavasād": ['gra'],
    "sūḍa": ['mw'],
    "sūṣ": ['ap90', 'mw'],
    "sūṣa": ['mw'],
    "sūṣas": ['mw'],
    "sūṣaṇā": ['ap90', 'mw'],
    "sūṣuvāṇa": ['mw'],
    "sūṣyantī": ['mw'],
    "sūṣyatī": ['ap90'],
    "sūṣā": ['mw'],
    "sṁsuddhi": ['cped'],
    "sṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sṛbh": ['ap90', 'mw'],
    "sṛbinda": ['cae', 'gra', 'mw'],
    "sṛdara": ['mw'],
    "sṛdaraḥ": ['ap90'],
    "sṛdh": ['mw'],
    "sṛdāgu": ['mw'],
    "sṛdāku": ['mw'],
    "sṛdākuḥ": ['ap90'],
    "sṛga": ['mw'],
    "sṛgavant": ['cae'],
    "sṛgavat": ['mw'],
    "sṛgaḥ": ['ap90'],
    "sṛgāla": ['cae', 'ddsa', 'mw'],
    "sṛgālagarta": ['mw'],
    "sṛgālagartīya": ['mw'],
    "sṛgālaghaṇṭī": ['mw'],
    "sṛgālajambu": ['mw'],
    "sṛgālajambū": ['mw'],
    "sṛgālakaṇṭaka": ['mw'],
    "sṛgālakoli": ['mw'],
    "sṛgālarūpa": ['mw'],
    "sṛgālavadana": ['mw'],
    "sṛgālavinnā": ['mw'],
    "sṛgālavāstuka": ['mw'],
    "sṛgālavāṭī": ['mw'],
    "sṛgālavāṭīya": ['mw'],
    "sṛgālavṛntā": ['mw'],
    "sṛgālayoni": ['mw'],
    "sṛgālaḥ": ['ap90'],
    "sṛgālikā": ['mw'],
    "sṛgālinī": ['mw'],
    "sṛgālāsthimaya": ['mw'],
    "sṛgālī": ['mw'],
    "sṛgāvant": ['cae'],
    "sṛgāyin": ['cae', 'mw'],
    "sṛj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sṛja": ['ddsa'],
    "sṛjana": ['mw'],
    "sṛjati": ['ddsa', 'mw'],
    "sṛjatvakarman": ['ddsa', 'mw'],
    "sṛjavāna": ['mw'],
    "sṛjaya": ['cae', 'mw'],
    "sṛjayā": ['mw'],
    "sṛjikākṣāra": ['mw'],
    "sṛjikākṣāraḥ": ['ap90'],
    "sṛjya": ['mw'],
    "sṛjāna": ['mw'],
    "sṛk": ['mw'],
    "sṛka": ['cae', 'ddsa', 'gra', 'mw'],
    "sṛkavant": ['cae'],
    "sṛkavat": ['mw'],
    "sṛkaḥ": ['ap90'],
    "sṛkaṃḍu": ['ap90'],
    "sṛkaṇḍu": ['mw'],
    "sṛkka": ['mw'],
    "sṛkkan": ['ap90'],
    "sṛkkaṃ": ['ap90'],
    "sṛkkaṇī": ['ap90', 'mw'],
    "sṛkkin": ['ap90'],
    "sṛkkiṇī": ['ap90'],
    "sṛkkṛ": ['mw'],
    "sṛkthā": ['mw'],
    "sṛkva": ['cae', 'mw'],
    "sṛkvan": ['ap90', 'cae', 'gra', 'mw'],
    "sṛkvaṃ": ['ap90'],
    "sṛkvaṇī": ['ap90', 'ddsa', 'mw'],
    "sṛkvi": ['cae', 'mw'],
    "sṛkvin": ['ap90'],
    "sṛkviṇī": ['ap90', 'mw'],
    "sṛkāhasta": ['cae', 'mw'],
    "sṛkāla": ['mw'],
    "sṛkālaḥ": ['ap90'],
    "sṛkāvant": ['cae'],
    "sṛkāvat": ['mw'],
    "sṛkāvin": ['cae', 'mw'],
    "sṛkāyin": ['cae', 'mw'],
    "sṛma": ['cae', 'mw'],
    "sṛmala": ['mw'],
    "sṛmara": ['ap90', 'cae', 'ddsa', 'mw'],
    "sṛmbh": ['mw'],
    "sṛp": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "sṛpa": ['mw'],
    "sṛpman": ['mw'],
    "sṛpra": ['cae', 'ddsa', 'gra', 'mw'],
    "sṛprabhojas": ['gra', 'mw'],
    "sṛpradānu": ['gra', 'mw'],
    "sṛprakarasna": ['gra', 'mw'],
    "sṛpravandhura": ['gra', 'mw'],
    "sṛpraḥ": ['ap90'],
    "sṛprā": ['mw'],
    "sṛpta": ['cae', 'ddsa', 'mw'],
    "sṛpāṭa": ['mw'],
    "sṛpāṭaḥ": ['ap90'],
    "sṛpāṭikā": ['ap90', 'mw'],
    "sṛpāṭī": ['ap90', 'mw'],
    "sṛt": ['cae', 'ddsa', 'mw'],
    "sṛta": ['cae', 'ddsa', 'mw'],
    "sṛtajava": ['mw'],
    "sṛtaṃjaya": ['mw'],
    "sṛti": ['cae', 'ddsa', 'mw'],
    "sṛtiḥ": ['ap90'],
    "sṛtvan": ['cae', 'ddsa', 'gra', 'mw'],
    "sṛtvara": ['ap90', 'mw'],
    "sṛtvarī": ['mw'],
    "sṛtya": ['cae', 'mw'],
    "sṛñjarī": ['mw'],
    "sṛñjaya": ['cae', 'ddsa', 'gra', 'mw'],
    "sṛñjayī": ['mw'],
    "sṛṃjayāḥ": ['ap90'],
    "sṛṅgāpuṭa": ['bhs'],
    "sṛṅkā": ['cae', 'mw'],
    "sṛṇi": ['cae', 'gra', 'mw'],
    "sṛṇia": ['gra'],
    "sṛṇika": ['mw'],
    "sṛṇikā": ['ap90', 'mw'],
    "sṛṇiḥ": ['ap90'],
    "sṛṇya": ['gra', 'mw'],
    "sṛṇī": ['ap90', 'ddsa', 'mw'],
    "sṛṇīka": ['mw'],
    "sṛṇīkā": ['ap90', 'mw'],
    "sṛṇīrāja": ['mw'],
    "sṛṣtārtha": ['mw'],
    "sṛṣṭa": ['ap90', 'cae', 'mw'],
    "sṛṣṭamāruta": ['mw'],
    "sṛṣṭamūtrapurīṣa": ['mw'],
    "sṛṣṭarūpa": ['bhs'],
    "sṛṣṭavat": ['mw'],
    "sṛṣṭaviṇmūtra": ['mw'],
    "sṛṣṭi": ['cae', 'ddsa', 'mw'],
    "sṛṣṭidhara": ['mw'],
    "sṛṣṭidā": ['mw'],
    "sṛṣṭikaraṇaṭīkā": ['mw'],
    "sṛṣṭikartṛ": ['mw'],
    "sṛṣṭikhaṇḍa": ['mw'],
    "sṛṣṭikṛt": ['cae', 'mw'],
    "sṛṣṭimat": ['mw'],
    "sṛṣṭipattana": ['mw'],
    "sṛṣṭipradā": ['mw'],
    "sṛṣṭiprasaṅga": ['mw'],
    "sṛṣṭisaṃhitā": ['mw'],
    "sṛṣṭiḥ": ['ap90'],
    "sṛṣṭy": ['mw'],
    "sṛṣṭyantara": ['mw'],
    "sṛṣṭyantaraja": ['mw'],
    "sṛṣṭā": ['mw'],
    "sṝ": ['ap90', 'mw'],
    "ta": ['cae', 'ddsa', 'gra', 'mw'],
    "ta(d)": ['cped'],
    "tabalākṛti": ['mw'],
    "tabbahula": ['cped'],
    "tabdha": ['bhs'],
    "tabha": ['mw'],
    "tac": ['mw'],
    "taca(s)": ['cped'],
    "tacamaṁsāvalepana": ['cped'],
    "tacasara": ['cped'],
    "taccarita": ['cae'],
    "taccha": ['cped'],
    "tacchabdatva": ['mw'],
    "tacchaka": ['bhs', 'cped'],
    "tacchanta": ['cped'],
    "tacchati": ['cped'],
    "tacchenta": ['cped'],
    "taccheti": ['cped'],
    "tacchetvā": ['cped'],
    "tacchi": ['cped'],
    "tacchita": ['bhs'],
    "tacchīla": ['cae', 'ddsa', 'mw'],
    "tacotata": ['cped'],
    "tacotthata": ['cped'],
    "tacoṭṭhaṭa": ['cped'],
    "tad": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "tadabhimukham": ['cae'],
    "tadagge": ['cped'],
    "tadaggena": ['cped'],
    "tadahar": ['mw'],
    "tadahe": ['cped', 'mw'],
    "tadahopoṣadhe": ['bhs'],
    "tadahu": ['cped'],
    "tadam": ['mw'],
    "tadanantara": ['cae', 'ddsa', 'mw'],
    "tadanantaram": ['mw'],
    "tadanna": ['gra', 'mw'],
    "tadanta": ['cae', 'mw'],
    "tadantarbhūta": ['cae'],
    "tadanu": ['cae', 'ddsa', 'mw'],
    "tadanuguṇa": ['cae'],
    "tadanukṛti": ['cae', 'ddsa', 'mw'],
    "tadanulomika": ['cped'],
    "tadanurūpa": ['cped'],
    "tadanusaraṇa": ['mw'],
    "tadanusaraṇakrameṇa": ['mw'],
    "tadanuvartaka": ['bhs'],
    "tadanvaya": ['mw'],
    "tadanya": ['mw'],
    "tadapas": ['cae', 'gra', 'mw'],
    "tadapatya": ['cae', 'mw'],
    "tadapatyamaya": ['mw'],
    "tadapatyatā": ['mw'],
    "tadapekṣa": ['cae', 'mw'],
    "tadardhika": ['cae', 'mw'],
    "tadarha": ['mw'],
    "tadarpaṇa": ['mw'],
    "tadartha": ['cae', 'mw'],
    "tadarthaka": ['mw'],
    "tadartham": ['mw'],
    "tadarthatā": ['mw'],
    "tadarthin": ['cae'],
    "tadarthīya": ['cae', 'mw'],
    "tadatipāta": ['mw'],
    "tadavadhi": ['mw'],
    "tadavastha": ['cae', 'mw'],
    "tadaṁ": ['cped'],
    "tadaṅga": ['cped'],
    "tadbahu": ['mw'],
    "tadbahulavihārin": ['mw'],
    "tadbala": ['mw'],
    "tadbalā": ['mw'],
    "tadbandhu": ['gra', 'mw'],
    "tadbhava": ['cae', 'ddsa', 'mw'],
    "tadbhinna": ['mw'],
    "tadbhāgin": ['cae'],
    "tadbhāva": ['mw'],
    "tadbhūta": ['mw'],
    "tadbuddhi": ['cae', 'ddsa'],
    "taddaivata": ['mw'],
    "taddaivatya": ['mw'],
    "taddevata": ['mw'],
    "taddevatya": ['mw'],
    "taddevatāka": ['ddsa', 'mw'],
    "taddeśya": ['mw'],
    "taddhana": ['mw'],
    "taddharma": ['mw'],
    "taddharman": ['mw'],
    "taddharmatva": ['mw'],
    "taddharmin": ['mw'],
    "taddharmya": ['mw'],
    "taddhita": ['cae', 'ddsa', 'mw'],
    "taddhitaḍhuṇḍhī": ['mw'],
    "taddhu": ['bhs'],
    "taddhāraṇa": ['mw'],
    "taddiguṇa": ['cped'],
    "taddina": ['mw'],
    "taddinam": ['mw'],
    "tadduḥkha": ['mw'],
    "taddviguṇa": ['cae'],
    "taddvitīya": ['mw'],
    "tadekacitta": ['mw'],
    "tadekatya": ['bhs'],
    "tadekaṭṭha": ['cped'],
    "tadevopaniṣad": ['mw'],
    "tadgata": ['cae', 'ddsa', 'mw'],
    "tadguṇa": ['cae', 'mw'],
    "tadguṇasaṃvijñāna": ['mw'],
    "tadguṇatva": ['mw'],
    "tadidartha": ['gra', 'mw'],
    "tadidāsīya": ['mw'],
    "tadiṣṭi": ['mw'],
    "tadojas": ['gra', 'mw'],
    "tadokas": ['cae', 'ddsa', 'gra', 'mw'],
    "tadrasa": ['ddsa', 'mw'],
    "tadriyañc": ['mw'],
    "tadryañc": ['mw'],
    "tadrāja": ['mw'],
    "tadrūpa": ['cae', 'mw'],
    "tadrūpatva": ['mw'],
    "tadubhaya": ['cped'],
    "tadupahita": ['cae'],
    "tadupakārin": ['cae'],
    "tadurī": ['mw'],
    "taduttha": ['ddsa'],
    "taduṭṭhāya": ['cped'],
    "tadvacana": ['cae'],
    "tadvacaḥpratīta": ['mw'],
    "tadvaktṛ": ['cae'],
    "tadvan": ['mw'],
    "tadvasati": ['mw'],
    "tadvat": ['ap90', 'cae', 'mw'],
    "tadvattā": ['cae', 'mw'],
    "tadvayas": ['cae', 'mw'],
    "tadvaśa": ['cae', 'gra', 'mw'],
    "tadvaṃśya": ['cae'],
    "tadvid": ['cae', 'mw'],
    "tadvidha": ['cae', 'mw'],
    "tadvidhatva": ['mw'],
    "tadvidya": ['mw'],
    "tadvikāra": ['mw'],
    "tadviṣaya": ['cae', 'mw'],
    "tadviṣayaka": ['mw'],
    "tadvrata": ['mw'],
    "tadvā": ['mw'],
    "tadvācaka": ['mw'],
    "tadvīryavidvas": ['mw'],
    "tadvṛtti": ['cae', 'mw'],
    "tadyathā": ['bhs'],
    "tadyukta": ['cae'],
    "tadyuta": ['cae'],
    "tadā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "tadādi": ['ddsa', 'mw'],
    "tadāgata": ['bhs'],
    "tadāhiṃ": ['bhs'],
    "tadākāra": ['ddsa', 'mw'],
    "tadākāraparijñāna": ['mw'],
    "tadālambana": ['cped'],
    "tadāmukha": ['mw'],
    "tadāni": ['bhs'],
    "tadānīm": ['cae', 'ddsa', 'gra', 'mw'],
    "tadānīṃ": ['ap90', 'mw'],
    "tadānīṃdugdha": ['mw'],
    "tadānīṃtana": ['ap90', 'mw'],
    "tadārammaṇa": ['cped'],
    "tadātmaka": ['mw'],
    "tadātman": ['cae'],
    "tadātva": ['cae', 'ddsa', 'mw'],
    "tadātvamātraśraddheya": ['mw'],
    "tadātvaṃ": ['ap90'],
    "tadāśraya": ['cae'],
    "tadāśrayin": ['cae'],
    "tadīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "tadīyasaṅga": ['mw'],
    "tadūbhaya": ['cped'],
    "tadūna": ['cae'],
    "tadūpaka": ['cped'],
    "tadūpiya": ['cped'],
    "tagara": ['cped', 'mw'],
    "tagaracandani(n)": ['cped'],
    "tagaraka": ['mw'],
    "tagaramallikā": ['cped'],
    "tagarapura": ['mw'],
    "tagarapādi": ['mw'],
    "tagarapādika": ['mw'],
    "tagarapādikā": ['mw'],
    "tagaravalli": ['mw'],
    "tagaraśikhi": ['bhs'],
    "tagaraśikhin": ['mw'],
    "tagaraḥ": ['ap90'],
    "tagarika": ['mw'],
    "tagarikī": ['mw'],
    "tagarī": ['mw'],
    "tagaḍavallī": ['mw'],
    "taggha": ['cped'],
    "tahaṁ": ['cped'],
    "tahi": ['bhs'],
    "tahiṁ": ['cped'],
    "taigmya": ['mw'],
    "taijana": ['mw'],
    "taijanitvac": ['mw'],
    "taijasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "taijasāvartanī": ['mw'],
    "taijasāvartinī": ['mw'],
    "taijasī": ['mw'],
    "taikāyana": ['mw'],
    "taikāyani": ['mw'],
    "taikāyanīya": ['mw'],
    "taikṣṇya": ['cae', 'ddsa', 'mw'],
    "taikṣṇyaṃ": ['ap90'],
    "taikṣṇāyana": ['mw'],
    "taila": ['cae', 'ddsa', 'mw'],
    "tailabīja": ['mw'],
    "tailacaurikā": ['mw'],
    "tailadroṇī": ['mw'],
    "tailaghṛta": ['cae', 'mw'],
    "tailaka": ['mw'],
    "tailakalkaja": ['mw'],
    "tailakalpanā": ['mw'],
    "tailakanda": ['mw'],
    "tailakaṃ": ['ap90'],
    "tailakiṭṭa": ['mw'],
    "tailakuṇḍa": ['cae', 'mw'],
    "tailakuṇḍikā": ['bhs'],
    "tailakya": ['mw'],
    "tailakāra": ['cae', 'ddsa', 'mw'],
    "tailakīṭa": ['mw'],
    "tailampātā": ['mw'],
    "tailamālin": ['mw'],
    "tailamālī": ['mw'],
    "tailapa": ['mw'],
    "tailapaka": ['cae', 'mw'],
    "tailaparṇa": ['mw'],
    "tailaparṇaka": ['mw'],
    "tailaparṇika": ['cae', 'mw'],
    "tailaparṇī": ['mw'],
    "tailapeṣam": ['mw'],
    "tailaphala": ['mw'],
    "tailapipīlikā": ['mw'],
    "tailapiñja": ['mw'],
    "tailapradyotikam": ['bhs'],
    "tailapradīpa": ['cae', 'mw'],
    "tailapā": ['mw'],
    "tailapācikam": ['bhs'],
    "tailapātra": ['cae', 'mw'],
    "tailapāyika": ['mw'],
    "tailapāyikā": ['mw'],
    "tailapāyin": ['mw'],
    "tailapāyinī": ['mw'],
    "tailapīta": ['mw'],
    "tailapūra": ['mw'],
    "tailaspandā": ['mw'],
    "tailasphaṭika": ['mw'],
    "tailasādhana": ['mw'],
    "tailatva": ['mw'],
    "tailavaka": ['mw'],
    "tailavallī": ['mw'],
    "tailayantra": ['cae', 'mw'],
    "tailayantracakra": ['mw'],
    "tailaśālikā": ['mw'],
    "tailaṃ": ['ap90'],
    "tailaṃgaḥ": ['ap90'],
    "tailaṃpātā": ['ap90'],
    "tailaṅga": ['mw'],
    "tailika": ['cae', 'ddsa', 'mw'],
    "tailikacakra": ['mw'],
    "tailikaḥ": ['ap90'],
    "tailikī": ['mw'],
    "tailin": ['mw'],
    "tailinī": ['ap90', 'mw'],
    "tailiśālā": ['mw'],
    "tailotsava": ['mw'],
    "tailvaka": ['ddsa', 'mw'],
    "tailābhyaṅga": ['mw'],
    "tailāguru": ['mw'],
    "tailākhya": ['mw'],
    "tailāmbukā": ['mw'],
    "tailāṭī": ['mw'],
    "tailīna": ['mw'],
    "tailīnaṃ": ['ap90'],
    "taimira": ['cae', 'mw'],
    "taimiraroga": ['ddsa'],
    "taimiraḥ": ['ap90'],
    "taimirika": ['cae', 'ddsa', 'mw'],
    "taimirya": ['cae', 'ddsa', 'mw'],
    "taimitya": ['mw'],
    "taimāta": ['mw'],
    "tainduka": ['mw'],
    "taira": ['mw'],
    "tairabhukta": ['mw'],
    "tairaścya": ['mw'],
    "tairaṇa": ['mw'],
    "tairohnya": ['mw'],
    "tairovirāma": ['mw'],
    "tairovyañjana": ['mw'],
    "tairtha": ['ap90', 'mw'],
    "tairthaka": ['mw'],
    "tairthika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "tairthya": ['mw'],
    "tairyagayanika": ['mw'],
    "tairyagyona": ['cae', 'ddsa', 'mw'],
    "tairyagyoni": ['cae', 'mw'],
    "tairyagyonika": ['bhs'],
    "tairyagyonya": ['cae', 'mw'],
    "taisṛka": ['mw'],
    "taitala": ['mw'],
    "taitikṣa": ['ap90', 'mw'],
    "taitikṣava": ['mw'],
    "taitikṣya": ['mw'],
    "taitila": ['ddsa', 'mw'],
    "taitilakadrū": ['mw'],
    "taitilaḥ": ['ap90'],
    "taitili": ['mw'],
    "taitilin": ['mw'],
    "taitilāyani": ['mw'],
    "taitiraḥ": ['ap90'],
    "taittira": ['cae', 'ddsa', 'mw'],
    "taittiraḥ": ['ap90'],
    "taittiri": ['mw'],
    "taittirika": ['mw'],
    "taittirikaḥ": ['ap90'],
    "taittirya": ['mw'],
    "taittirīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "taittirīyabrāhmaṇa": ['cae', 'mw'],
    "taittirīyacaraṇa": ['mw'],
    "taittirīyaka": ['mw'],
    "taittirīyakopaniṣad": ['mw'],
    "taittirīyaprātiśākhya": ['mw'],
    "taittirīyasaṃhitā": ['cae', 'mw'],
    "taittirīyaveda": ['mw'],
    "taittirīyavārttika": ['mw'],
    "taittirīyayajurveda": ['mw'],
    "taittirīyaśākhin": ['mw'],
    "taittirīyaśākhā": ['mw'],
    "taittirīyin": ['cae'],
    "taittirīyopaniṣad": ['cae', 'mw'],
    "taittirīyāraṇyaka": ['cae', 'mw'],
    "taittiḍīka": ['mw'],
    "taivradārava": ['mw'],
    "taivraka": ['mw'],
    "taiṃtiḍīka": ['ap90'],
    "taiṣa": ['cae', 'ddsa', 'mw'],
    "taiṣaḥ": ['ap90'],
    "taiṣī": ['mw'],
    "taj": ['mw'],
    "tajja": ['cae', 'cped', 'mw'],
    "tajjaghanya": ['mw'],
    "tajjalān": ['mw'],
    "tajjaniya": ['cped'],
    "tajjaniyakamma": ['cped'],
    "tajjaniyakammakata": ['cped'],
    "tajjanīkata": ['cped'],
    "tajjanīya": ['cped'],
    "tajjanīyakamma": ['cped'],
    "tajjanīyakammakata": ['cped'],
    "tajjaya": ['mw'],
    "tajjayati": ['cped'],
    "tajjesi": ['cped'],
    "tajjeti": ['cped'],
    "tajjita": ['cped'],
    "tajjña": ['cae', 'mw'],
    "tajjātīya": ['mw'],
    "tajjātīyaka": ['mw'],
    "tajjīvana": ['ddsa'],
    "tajvī": ['mw'],
    "tak": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "taka": ['ap90', 'bhs', 'cae', 'cped', 'gra', 'mw'],
    "takaraka": ['mw'],
    "takari": ['mw'],
    "takarī": ['mw'],
    "takavāna": ['gra', 'mw'],
    "takila": ['ap90', 'mw'],
    "takilā": ['mw'],
    "takka": ['cped'],
    "takkan": ['ap90'],
    "takkapariyāhata": ['cped'],
    "takkara": ['cped'],
    "takki(n)": ['cped'],
    "takkika": ['cped'],
    "takkiya": ['cped'],
    "takkola": ['mw'],
    "takkā": ['cped'],
    "takkārī": ['cped'],
    "takkāsaya": ['cped'],
    "takman": ['cae', 'ddsa', 'mw'],
    "takmanāśana": ['mw'],
    "takmanāśanagaṇa": ['mw'],
    "takra": ['cae', 'ddsa', 'mw'],
    "takrabhaktā": ['mw'],
    "takrabhid": ['mw'],
    "takrakurcikā": ['mw'],
    "takramāṃsa": ['mw'],
    "takrapiṇḍa": ['mw'],
    "takrasāra": ['mw'],
    "takraṃ": ['ap90'],
    "takrā": ['mw'],
    "takrāhvā": ['mw'],
    "takrāṭa": ['ddsa', 'mw'],
    "takta": ['mw'],
    "taku": ['ap90', 'cae', 'gra', 'mw'],
    "takva": ['cae', 'gra', 'mw'],
    "takvan": ['ap90', 'cae', 'gra', 'mw'],
    "takvavī": ['cae', 'gra', 'mw'],
    "takvavīya": ['gra', 'mw'],
    "takya": ['mw'],
    "takāra": ['mw'],
    "takāravipulā": ['mw'],
    "takṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "takṣa": ['cae', 'ddsa', 'mw'],
    "takṣaka": ['cae', 'mw'],
    "takṣakarman": ['mw'],
    "takṣakaḥ": ['ap90'],
    "takṣakīyā": ['mw'],
    "takṣan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "takṣarathakāra": ['mw'],
    "takṣavat": ['mw'],
    "takṣaśila": ['cae', 'mw'],
    "takṣaśilaka": ['bhs'],
    "takṣaśilā": ['cae', 'ddsa', 'mw'],
    "takṣaśilāvatī": ['mw'],
    "takṣaṇa": ['cae', 'mw'],
    "takṣaṇaṃ": ['ap90'],
    "takṣaṇī": ['mw'],
    "takṣitṛ": ['mw'],
    "takṣiṇī": ['mw'],
    "takṣya": ['cae', 'mw'],
    "takṣāyaskāra": ['mw'],
    "takṣāṇa": ['bhs'],
    "takṣṇī": ['mw'],
    "tal": ['ap90', 'mw'],
    "tala": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "talabaddha": ['mw'],
    "talabha": ['mw'],
    "talagata": ['mw'],
    "talaghoṣa": ['cae'],
    "talaghāta": ['mw'],
    "talaghātaka": ['cped'],
    "talahṛdaya": ['mw'],
    "talaka": ['bhs', 'mw'],
    "talakaṃ": ['ap90'],
    "talakoṭa": ['mw'],
    "talaloka": ['cae', 'mw'],
    "talalokapāla": ['mw'],
    "talamukha": ['mw'],
    "talamīna": ['mw'],
    "talaniṣpeṣa": ['mw'],
    "talaprahāra": ['mw'],
    "talapuṣpapuṭa": ['mw'],
    "talasampāta": ['mw'],
    "talasattikā": ['cped'],
    "talastha": ['mw'],
    "talasthita": ['mw'],
    "talasāraka": ['mw'],
    "talasāraṇa": ['mw'],
    "talasārika": ['mw'],
    "talatas": ['mw'],
    "talataḥ": ['ap90'],
    "talatra": ['mw'],
    "talatravat": ['mw'],
    "talatrāṇa": ['mw'],
    "talatāla": ['mw'],
    "talava": ['cae', 'ddsa', 'mw'],
    "talavakāra": ['cae', 'mw'],
    "talavakārabrāhmaṇa": ['mw'],
    "talavakārakalpa": ['mw'],
    "talavakāropaniṣad": ['cae', 'mw'],
    "talavara": ['mw'],
    "talavarga": ['bhs'],
    "talavāraṇa": ['mw'],
    "talavāraṇaṃ": ['ap90'],
    "talayuddha": ['mw'],
    "talayukta": ['mw'],
    "talaśabda": ['mw'],
    "talaśaktikā": ['bhs'],
    "talaḥ": ['ap90'],
    "talekṣaṇa": ['mw'],
    "talikā": ['ap90', 'bhs', 'mw'],
    "talima": ['cae', 'ddsa', 'mw'],
    "talimaṃ": ['ap90'],
    "talin": ['mw'],
    "talina": ['ap90', 'cae', 'ddsa', 'mw'],
    "talinodarī": ['mw'],
    "talit": ['ap90'],
    "talita": ['ap90', 'cae', 'mw'],
    "talka": ['mw'],
    "talkaṃ": ['ap90'],
    "talla": ['mw'],
    "tallaja": ['mw'],
    "tallajaḥ": ['ap90'],
    "tallakṣaṇa": ['bhs', 'mw'],
    "tallaḥ": ['ap90'],
    "tallikā": ['ap90', 'mw'],
    "tallī": ['mw'],
    "talodara": ['mw'],
    "talodā": ['mw'],
    "talpa": ['cae', 'ddsa', 'gra', 'mw'],
    "talpaga": ['cae', 'mw'],
    "talpagiri": ['mw'],
    "talpaja": ['cae', 'mw'],
    "talpaka": ['mw'],
    "talpakaḥ": ['ap90'],
    "talpakīṭa": ['mw'],
    "talpala": ['ddsa', 'mw'],
    "talpalaṃ": ['ap90'],
    "talpana": ['mw'],
    "talpanaṃ": ['ap90'],
    "talpasadya": ['mw'],
    "talpaśīvan": ['gra', 'mw'],
    "talpaḥ": ['ap90'],
    "talpe": ['mw'],
    "talpeja": ['mw'],
    "talpeśaya": ['mw'],
    "talpya": ['cae', 'ddsa', 'mw'],
    "talpā": ['mw'],
    "talpīkṛta": ['ddsa', 'mw'],
    "talukṣa": ['mw'],
    "taluna": ['ap90', 'mw'],
    "talunī": ['mw'],
    "talva": ['mw'],
    "talvaṃ": ['ap90'],
    "talā": ['mw'],
    "talācī": ['ap90', 'mw'],
    "talāhvaya": ['mw'],
    "talārakṣa": ['mw'],
    "talāsi": ['mw'],
    "talātala": ['cae', 'ddsa', 'mw'],
    "talātali": ['mw'],
    "talāśā": ['cae', 'mw'],
    "talāṅgulitravat": ['mw'],
    "talīdya": ['cae', 'mw'],
    "tal̤it": ['cae'],
    "tal̤itas": ['cae'],
    "tam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tama": ['ap90', 'ddsa', 'mw'],
    "tama(s)": ['cped'],
    "tamagata": ['cped'],
    "tamaka": ['cae', 'ddsa', 'mw'],
    "tamakaḥ": ['ap90'],
    "tamakā": ['mw'],
    "tamam": ['mw'],
    "tamana": ['cae', 'mw'],
    "tamanaṃ": ['ap90'],
    "tamanuda": ['cped'],
    "tamap": ['ddsa'],
    "tamaparāyaṇa": ['cped'],
    "tamaprabha": ['mw'],
    "tamaprabhā": ['mw'],
    "tamara": ['mw'],
    "tamaraṃ": ['ap90'],
    "tamarāja": ['mw'],
    "tamas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tamasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "tamaska": ['mw'],
    "tamaskalpa": ['mw'],
    "tamaskāṇḍa": ['mw'],
    "tamastati": ['mw'],
    "tamasundarī": ['bhs'],
    "tamasvan": ['mw'],
    "tamasvant": ['cae'],
    "tamasvat": ['ap90', 'mw'],
    "tamasvatī": ['mw'],
    "tamasvinī": ['ap90', 'mw'],
    "tamasā": ['mw'],
    "tamasākṛta": ['mw'],
    "tamasāvana": ['bhs', 'mw'],
    "tamasīkaraṇa": ['bhs'],
    "tamata": ['ap90', 'mw'],
    "tamatagge": ['cped'],
    "tamaḥ": ['mw'],
    "tamaḥprabha": ['mw'],
    "tamaḥprabhā": ['mw'],
    "tamaḥpracchādaka": ['mw'],
    "tamaḥpraveśa": ['mw'],
    "tamaḥsaṃghāta": ['mw'],
    "tamaḥspṛś": ['ddsa', 'mw'],
    "tamaḥsthita": ['mw'],
    "tamaṃ": ['ap90'],
    "tamaṃgakaḥ": ['ap90'],
    "tamaṃgaḥ": ['ap90'],
    "tamaṅga": ['mw'],
    "tamaṅgaka": ['mw'],
    "tamb": ['mw'],
    "tambaka": ['cped'],
    "tambaloha": ['cped'],
    "tambā": ['mw'],
    "tambīra": ['mw'],
    "tamenaṃ": ['bhs'],
    "tami": ['ap90', 'mw'],
    "tamin": ['mw'],
    "tamisra": ['ap90', 'cae', 'ddsa', 'mw'],
    "tamisrapakṣa": ['mw'],
    "tamisrita": ['bhs'],
    "tamisrā": ['ap90', 'gra', 'mw'],
    "tamisrāyitatva": ['bhs'],
    "tamiṣīcī": ['gra', 'mw'],
    "tammaya": ['cped'],
    "tamo": ['mw'],
    "tamobhid": ['mw'],
    "tamobhāga": ['mw'],
    "tamobhūta": ['cae', 'mw'],
    "tamodghātana": ['bhs'],
    "tamoghna": ['cae', 'mw'],
    "tamoguṇa": ['mw'],
    "tamoguṇin": ['mw'],
    "tamogā": ['ddsa', 'gra', 'mw'],
    "tamohan": ['cae', 'gra', 'mw'],
    "tamohara": ['mw'],
    "tamojyotis": ['mw'],
    "tamoliptī": ['mw'],
    "tamomaya": ['ap90', 'cae', 'mw'],
    "tamomayīkṛ": ['mw'],
    "tamomaṇi": ['mw'],
    "tamondhakāra": ['mw'],
    "tamondhakārabhūmi": ['mw'],
    "tamondhakārābhūmi": ['mw'],
    "tamoniṣṭha": ['cae', 'mw'],
    "tamontakṛt": ['mw'],
    "tamontya": ['mw'],
    "tamonud": ['cae', 'mw'],
    "tamonuda": ['cae', 'cped', 'mw'],
    "tamopaha": ['mw'],
    "tamori": ['mw'],
    "tamorivivara": ['mw'],
    "tamorūpa": ['cae', 'mw'],
    "tamorūpin": ['cae', 'mw'],
    "tamovairin": ['mw'],
    "tamovant": ['cae'],
    "tamovat": ['mw'],
    "tamovikāra": ['mw'],
    "tamoviśāla": ['mw'],
    "tamovāsas": ['mw'],
    "tamovṛdh": ['cae', 'gra', 'mw'],
    "tamovṛta": ['mw'],
    "tampuruka": ['bhs'],
    "tampā": ['mw'],
    "tamra": ['cae', 'gra', 'mw'],
    "tamuṣṭuhīya": ['mw'],
    "tamā": ['mw'],
    "tamāhvaya": ['mw'],
    "tamāla": ['cae', 'ddsa', 'mw'],
    "tamālaka": ['mw'],
    "tamālakaḥ": ['ap90'],
    "tamālakā": ['mw'],
    "tamālakī": ['mw'],
    "tamālapattra": ['mw'],
    "tamālapattracandanagandha": ['bhs', 'mw'],
    "tamālapattracandanagandhābhijña": ['bhs'],
    "tamālaḥ": ['ap90'],
    "tamālikā": ['ddsa', 'mw'],
    "tamālinī": ['ap90', 'mw'],
    "tamālī": ['mw'],
    "tamām": ['cae', 'ddsa', 'mw'],
    "tamī": ['ddsa', 'mw'],
    "tamīśvara": ['mw'],
    "tan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tana": ['cae', 'gra', 'mw'],
    "tanabāla": ['mw'],
    "tanaka": ['mw'],
    "tanas": ['ap90', 'cae', 'gra', 'mw'],
    "tanaya": ['cae', 'ddsa', 'gra', 'mw'],
    "tanayabhavana": ['mw'],
    "tanayasaras": ['mw'],
    "tanayaḥ": ['ap90'],
    "tanayitnu": ['ap90', 'cae', 'gra', 'mw'],
    "tanayā": ['mw'],
    "tanayīkṛta": ['ddsa', 'mw'],
    "tanaḥ": ['ap90'],
    "tand": ['cae', 'ddsa', 'gra', 'mw'],
    "tandi": ['cped'],
    "tandiṭṭhika": ['cped'],
    "tandr": ['cae', 'mw'],
    "tandra": ['cae', 'gra', 'mw'],
    "tandravāya": ['mw'],
    "tandraya": ['ddsa'],
    "tandrayu": ['cae', 'gra', 'mw'],
    "tandri": ['mw'],
    "tandrija": ['mw'],
    "tandrika": ['mw'],
    "tandrikā": ['mw'],
    "tandrin": ['mw'],
    "tandripāla": ['mw'],
    "tandrita": ['mw'],
    "tandritā": ['mw'],
    "tandrā": ['cae', 'ddsa', 'mw'],
    "tandrālu": ['ddsa', 'mw'],
    "tandrāvin": ['mw'],
    "tandrāy": ['cae'],
    "tandrāya": ['ddsa'],
    "tandrī": ['cae', 'mw'],
    "tandī": ['cped'],
    "tanikā": ['ap90', 'ddsa', 'mw'],
    "taniman": ['ap90', 'cae', 'ddsa', 'mw'],
    "tanitṛ": ['mw'],
    "taniṣṭha": ['ap90', 'cae', 'mw'],
    "tanmadhya": ['mw'],
    "tanmadhyastha": ['mw'],
    "tanmadhyāt": ['mw'],
    "tanman": ['mw'],
    "tanmanas": ['cae', 'ddsa', 'mw'],
    "tanmaya": ['ap90', 'cae', 'mw'],
    "tanmayatva": ['mw'],
    "tanmayatā": ['mw'],
    "tanmayībhāva": ['mw'],
    "tanmukhikayā": ['bhs', 'mw'],
    "tanmānin": ['mw'],
    "tanmātra": ['cae', 'mw'],
    "tanmātraka": ['mw'],
    "tanmātrasarga": ['mw'],
    "tanmātratva": ['mw'],
    "tanmātratā": ['mw'],
    "tanmātrika": ['mw'],
    "tanmāṃsāda": ['cae'],
    "tanmūla": ['cae', 'mw'],
    "tanmūlatva": ['mw'],
    "tanni": ['mw'],
    "tannimitta": ['cae', 'ddsa', 'mw'],
    "tannimittatva": ['mw'],
    "tanniṣṭha": ['cae'],
    "tannāmika": ['mw'],
    "tannāśa": ['mw'],
    "tanonu": ['mw'],
    "tanta": ['cped'],
    "tantabhaṇdaka": ['cped'],
    "tantaka": ['cped'],
    "tantasya": ['mw'],
    "tantavāya": ['cped'],
    "tanthī": ['mw'],
    "tanti": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "tantibaddha": ['cped'],
    "tanticara": ['mw'],
    "tantija": ['mw'],
    "tantipāla": ['mw'],
    "tantipālaka": ['mw'],
    "tantissara": ['cped'],
    "tantra": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "tantrabheda": ['mw'],
    "tantracūḍāmaṇi": ['mw'],
    "tantragandharva": ['mw'],
    "tantragarbha": ['mw'],
    "tantrahṛdaya": ['mw'],
    "tantrajālajāta": ['bhs'],
    "tantraka": ['cae', 'ddsa', 'mw'],
    "tantrakaumudī": ['mw'],
    "tantrakāra": ['cae', 'ddsa', 'mw'],
    "tantrakāṣṭha": ['mw'],
    "tantramantraprakāśa": ['mw'],
    "tantrapradīpa": ['mw'],
    "tantraprakāśa": ['mw'],
    "tantraratna": ['mw'],
    "tantrarāja": ['mw'],
    "tantrarājaka": ['mw'],
    "tantrasāra": ['mw'],
    "tantratva": ['mw'],
    "tantratā": ['mw'],
    "tantravāpa": ['mw'],
    "tantravārttika": ['mw'],
    "tantravāya": ['cae', 'ddsa', 'mw'],
    "tantray": ['cae'],
    "tantraya": ['ddsa', 'mw'],
    "tantraśāstra": ['mw'],
    "tantraṇa": ['mw'],
    "tantraṭīkā": ['mw'],
    "tantreṇa": ['mw'],
    "tantri": ['mw'],
    "tantrija": ['mw'],
    "tantrikā": ['mw'],
    "tantrila": ['mw'],
    "tantrillaka": ['ddsa', 'mw'],
    "tantrin": ['ddsa', 'mw'],
    "tantripāla": ['mw'],
    "tantripālaka": ['mw'],
    "tantrita": ['mw'],
    "tantritā": ['mw'],
    "tantrottara": ['mw'],
    "tantrā": ['mw'],
    "tantrākulajāta": ['bhs'],
    "tantrāntarīya": ['mw'],
    "tantrāvāpa": ['mw'],
    "tantrāyin": ['cae', 'mw'],
    "tantrī": ['bhs', 'ddsa', 'mw'],
    "tantrībhāṇḍa": ['mw'],
    "tantrīmukha": ['mw'],
    "tantrīsvana": ['cae'],
    "tantu": ['cae', 'ddsa', 'gra', 'mw'],
    "tantubha": ['mw'],
    "tantubhūta": ['cae', 'mw'],
    "tantujāla": ['mw'],
    "tantuka": ['ddsa', 'mw'],
    "tantukaraṇa": ['mw'],
    "tantukarttṛ": ['mw'],
    "tantukriyā": ['mw'],
    "tantukārya": ['mw'],
    "tantukāṣṭha": ['mw'],
    "tantukī": ['mw'],
    "tantukīṭa": ['mw'],
    "tantukṛntana": ['mw'],
    "tantula": ['mw'],
    "tantumadhya": ['mw'],
    "tantumant": ['cae'],
    "tantumat": ['mw'],
    "tantumatī": ['mw'],
    "tantuniryāsa": ['mw'],
    "tantunābha": ['mw'],
    "tantunāga": ['mw'],
    "tantuparvan": ['mw'],
    "tantura": ['mw'],
    "tantusaṃtata": ['mw'],
    "tantusaṃtati": ['mw'],
    "tantusaṃtāna": ['mw'],
    "tantusāra": ['mw'],
    "tantusāraka": ['mw'],
    "tantutva": ['mw'],
    "tantuvardhana": ['mw'],
    "tantuvigrahā": ['mw'],
    "tantuvādya": ['mw'],
    "tantuvāna": ['cae', 'mw'],
    "tantuvāpa": ['mw'],
    "tantuvāya": ['cae', 'mw'],
    "tantuvāyadaṇḍa": ['mw'],
    "tantuvāyaśālā": ['mw'],
    "tantuśālā": ['mw'],
    "tantuṇa": ['mw'],
    "tantv": ['mw'],
    "tantvagra": ['mw'],
    "tantvagrīya": ['mw'],
    "tantākulakajāta": ['cped'],
    "tantāvuta": ['cped'],
    "tantī": ['cae', 'mw'],
    "tantīyajña": ['mw'],
    "tanu": ['ap90', 'bhs', 'cped', 'ddsa', 'gra', 'mw'],
    "tanubala": ['mw'],
    "tanubhastrā": ['mw'],
    "tanubhava": ['mw'],
    "tanubhāva": ['cae', 'mw'],
    "tanubhūmi": ['mw'],
    "tanubhṛt": ['mw'],
    "tanubīja": ['mw'],
    "tanucchad": ['mw'],
    "tanucchada": ['cae', 'ddsa', 'mw'],
    "tanucchāya": ['mw'],
    "tanudagdha": ['mw'],
    "tanudhī": ['cae', 'mw'],
    "tanudāna": ['ddsa', 'mw'],
    "tanudīrghaghoṇa": ['mw'],
    "tanugātra": ['cae'],
    "tanugṛha": ['mw'],
    "tanuhrada": ['mw'],
    "tanuja": ['cae', 'mw'],
    "tanujanman": ['mw'],
    "tanujatva": ['mw'],
    "tanujihvatā": ['mw'],
    "tanujā": ['mw'],
    "tanuka": ['ap90', 'cped', 'mw'],
    "tanukaṁ": ['cped'],
    "tanukeśa": ['mw'],
    "tanukeśā": ['mw'],
    "tanukā": ['mw'],
    "tanukībhūta": ['bhs'],
    "tanukūpa": ['mw'],
    "tanukṣīra": ['mw'],
    "tanula": ['ap90', 'mw'],
    "tanulatā": ['mw'],
    "tanumadhya": ['cae', 'mw'],
    "tanumadhyama": ['cae', 'mw'],
    "tanumadhyā": ['mw'],
    "tanumat": ['mw'],
    "tanumūrti": ['mw'],
    "tanupattra": ['mw'],
    "tanupādakṣapāṭana": ['mw'],
    "tanurasa": ['mw'],
    "tanuruh": ['mw'],
    "tanuruha": ['bhs', 'mw'],
    "tanus": ['ap90', 'mw'],
    "tanusatya": ['mw'],
    "tanusaṃcāriṇī": ['mw'],
    "tanusthāna": ['mw'],
    "tanutara": ['cped', 'mw'],
    "tanutra": ['cae', 'ddsa', 'mw'],
    "tanutravat": ['mw'],
    "tanutrin": ['mw'],
    "tanutrāṇa": ['cae', 'mw'],
    "tanutta": ['cped'],
    "tanutva": ['mw'],
    "tanutvac": ['mw'],
    "tanutvaca": ['mw'],
    "tanutvakka": ['mw'],
    "tanutyaj": ['cae', 'mw'],
    "tanutyāga": ['cae', 'mw'],
    "tanutā": ['ap90', 'mw'],
    "tanuvarman": ['cae', 'mw'],
    "tanuvraṇa": ['mw'],
    "tanuvāta": ['mw'],
    "tanuya": ['cped'],
    "tanuśarīra": ['cae', 'mw'],
    "tanuśiras": ['mw'],
    "tanv": ['mw'],
    "tanva": ['mw'],
    "tanvaṅga": ['cae', 'ddsa', 'mw'],
    "tanvaṅgī": ['mw'],
    "tanvi": ['mw'],
    "tanvin": ['mw'],
    "tanvī": ['ap90', 'ddsa', 'mw'],
    "tanvībhavati": ['bhs'],
    "tanyatu": ['cae', 'ddsa', 'gra', 'mw'],
    "tanyatā": ['cae', 'gra'],
    "tanyu": ['cae', 'gra', 'mw'],
    "tanyutaḥ": ['ap90'],
    "tanā": ['gra', 'mw'],
    "tanādi": ['mw'],
    "tanīyas": ['ap90', 'mw'],
    "tanīyaṃs": ['cae'],
    "tanū": ['ap90', 'ddsa', 'gra', 'mw'],
    "tanūbala": ['cae', 'mw'],
    "tanūbhava": ['ddsa', 'mw'],
    "tanūbhūmi": ['bhs'],
    "tanūbhūta": ['mw'],
    "tanūdara": ['mw'],
    "tanūdbhava": ['mw'],
    "tanūdevatā": ['mw'],
    "tanūdeśa": ['mw'],
    "tanūdūṣi": ['mw'],
    "tanūhavis": ['mw'],
    "tanūhrada": ['mw'],
    "tanūja": ['cae', 'ddsa', 'mw'],
    "tanūjani": ['mw'],
    "tanūjanman": ['mw'],
    "tanūjā": ['mw'],
    "tanūkaraṇa": ['ddsa', 'mw'],
    "tanūkartṛ": ['mw'],
    "tanūkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "tanūkṛt": ['gra', 'mw'],
    "tanūkṛta": ['mw'],
    "tanūkṛtha": ['cae', 'gra', 'mw'],
    "tanūna": ['mw'],
    "tanūnapa": ['mw'],
    "tanūnaptṛ": ['mw'],
    "tanūnapāt": ['cae', 'ddsa', 'gra', 'mw'],
    "tanūnapātvat": ['mw'],
    "tanūpaa": ['gra'],
    "tanūpā": ['cae', 'gra', 'mw'],
    "tanūpāna": ['cae', 'mw'],
    "tanūpāvan": ['mw'],
    "tanūpṛṣṭha": ['mw'],
    "tanūrja": ['mw'],
    "tanūruc": ['cae', 'gra', 'mw'],
    "tanūruha": ['cae', 'mw'],
    "tanūtala": ['mw'],
    "tanūtyaj": ['cae', 'gra', 'mw'],
    "tanūvaśin": ['mw'],
    "tanūśubhra": ['gra', 'mw'],
    "tap": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tapa": ['ap90', 'cae', 'ddsa', 'mw'],
    "tapa(s)": ['cped'],
    "tapa(t)": ['cped'],
    "tapana": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "tapanacchada": ['mw'],
    "tapanadyuti": ['mw'],
    "tapanakara": ['mw'],
    "tapanamaṇi": ['mw'],
    "tapanasutā": ['mw'],
    "tapanatanaya": ['mw'],
    "tapanatanayeṣṭā": ['mw'],
    "tapanatanayā": ['mw'],
    "tapaneyya": ['cped'],
    "tapaneṣṭa": ['mw'],
    "tapanopala": ['mw'],
    "tapanta": ['cped'],
    "tapantaka": ['ddsa', 'mw'],
    "tapantī": ['bhs', 'mw'],
    "tapanātmajā": ['mw'],
    "tapanāśman": ['mw'],
    "tapanī": ['ap90', 'bhs', 'gra', 'mw'],
    "tapanīya": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "tapanīyaka": ['mw'],
    "tapanīyamaya": ['mw'],
    "tapanīyāśoka": ['cae'],
    "tapara": ['bhs', 'mw'],
    "taparakaraṇa": ['mw'],
    "taparloka": ['mw'],
    "tapartu": ['mw'],
    "taparuj": ['mw'],
    "tapas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tapasa": ['mw'],
    "tapasaḥ": ['ap90'],
    "tapasomūrti": ['mw'],
    "tapaspati": ['mw'],
    "tapassi(n)": ['cped'],
    "tapastakṣa": ['mw'],
    "tapastanu": ['mw'],
    "tapastaṅka": ['mw'],
    "tapastīrtha": ['mw'],
    "tapasvant": ['cae'],
    "tapasvanī": ['bhs'],
    "tapasvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "tapasvijana": ['cae'],
    "tapasvikanyakā": ['mw'],
    "tapasvikanyā": ['cae', 'mw'],
    "tapasvin": ['ap90', 'cae', 'ddsa', 'mw'],
    "tapasvinī": ['mw'],
    "tapasvipattra": ['mw'],
    "tapasvitā": ['ap90', 'mw'],
    "tapasvīṣṭā": ['mw'],
    "tapasy": ['cae'],
    "tapasya": ['ap90', 'cae', 'ddsa', 'mw'],
    "tapasyati": ['ap90'],
    "tapasyā": ['mw'],
    "tapasyāmatsya": ['mw'],
    "tapasīvan": ['mw'],
    "tapat": ['mw'],
    "tapati": ['cped'],
    "tapatā": ['mw'],
    "tapatāmpati": ['mw'],
    "tapatī": ['ap90', 'cae', 'mw'],
    "tapayati": ['cped'],
    "tapañña": ['cped'],
    "tapaātaṅka": ['mw'],
    "tapaś": ['mw'],
    "tapaścaraṇa": ['cae', 'ddsa', 'mw'],
    "tapaścaryā": ['mw'],
    "tapaścit": ['mw'],
    "tapaścitāmayana": ['mw'],
    "tapaḥ": ['mw'],
    "tapaḥkara": ['mw'],
    "tapaḥklama": ['cae'],
    "tapaḥkleśasaha": ['mw'],
    "tapaḥkṛśa": ['mw'],
    "tapaḥkṣama": ['cae'],
    "tapaḥparārdha": ['mw'],
    "tapaḥprabhāva": ['ddsa', 'mw'],
    "tapaḥpradhāna": ['mw'],
    "tapaḥpātra": ['mw'],
    "tapaḥsahāya": ['mw'],
    "tapaḥsamādhi": ['mw'],
    "tapaḥsiddha": ['mw'],
    "tapaḥsthala": ['mw'],
    "tapaḥsthalī": ['mw'],
    "tapaḥsuta": ['mw'],
    "tapaḥsādhya": ['mw'],
    "tapaḥśīla": ['mw'],
    "tapeti": ['cped'],
    "tapita": ['ap90', 'mw'],
    "tapitabba": ['cped'],
    "tapiṣṇu": ['ap90', 'cae', 'mw'],
    "tapiṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "tapo": ['mw'],
    "tapobala": ['mw'],
    "tapobhaṅga": ['mw'],
    "tapobhṛt": ['cae', 'mw'],
    "tapoda": ['bhs', 'mw'],
    "tapodhana": ['cae', 'ddsa', 'mw'],
    "tapodhanā": ['mw'],
    "tapodharma": ['mw'],
    "tapodhāman": ['mw'],
    "tapodhṛti": ['mw'],
    "tapodyuti": ['mw'],
    "tapodāna": ['mw'],
    "tapogaccha": ['mw'],
    "tapojigucchā": ['cped'],
    "tapojā": ['gra', 'mw'],
    "tapoloka": ['mw'],
    "tapolubdha": ['cae'],
    "tapomadhya": ['cae'],
    "tapomaya": ['ap90', 'mw'],
    "tapomūla": ['cae', 'mw'],
    "tapomūrti": ['mw'],
    "taponidhi": ['cae', 'mw'],
    "taponidhāna": ['mw'],
    "taponitya": ['mw'],
    "taponiṣṭha": ['mw'],
    "taponta": ['cae', 'mw'],
    "taponubhāva": ['mw'],
    "tapopakkama": ['cped'],
    "taporata": ['cae', 'mw'],
    "taporati": ['cae', 'mw'],
    "taporavi": ['mw'],
    "taporthīya": ['mw'],
    "taporāja": ['mw'],
    "taporāśi": ['mw'],
    "tapovana": ['cae', 'mw'],
    "tapovant": ['cae'],
    "tapovanā": ['mw'],
    "tapovariṣṭha": ['mw'],
    "tapovat": ['mw'],
    "tapovaṭa": ['mw'],
    "tapovidhi": ['mw'],
    "tapovidhāna": ['mw'],
    "tapovrāta": ['mw'],
    "tapovāsa": ['mw'],
    "tapovṛddha": ['cae', 'mw'],
    "tapoyajña": ['cae', 'mw'],
    "tapoyoga": ['cae', 'mw'],
    "tapoyukta": ['cae', 'mw'],
    "tapośana": ['mw'],
    "tappamāna": ['cped'],
    "tapparāyaṇa": ['cped'],
    "tappati": ['cped'],
    "tappayati": ['cped'],
    "tappeta(r)": ['cped'],
    "tappeti": ['cped'],
    "tappita": ['cped'],
    "tapta": ['ap90', 'cae', 'ddsa', 'mw'],
    "taptahema": ['mw'],
    "taptahemamaya": ['mw'],
    "taptajāmbūnadamaya": ['mw'],
    "taptaka": ['mw'],
    "taptakumbha": ['mw'],
    "taptakūpa": ['mw'],
    "taptakṛcchra": ['cae', 'ddsa', 'mw'],
    "taptaloha": ['mw'],
    "taptalomaśa": ['mw'],
    "taptam": ['mw'],
    "taptamudrā": ['mw'],
    "taptapāṣāṇakuṇḍa": ['mw'],
    "taptarahasa": ['mw'],
    "taptarūpa": ['mw'],
    "taptarūpaka": ['mw'],
    "taptasurākuṇḍa": ['mw'],
    "taptasūrmi": ['mw'],
    "taptasūrmikuṇḍa": ['mw'],
    "taptatapas": ['mw'],
    "taptatapta": ['mw'],
    "taptatāmra": ['mw'],
    "taptavrata": ['mw'],
    "taptavya": ['mw'],
    "taptavāluka": ['mw'],
    "taptavālukā": ['mw'],
    "tapti": ['cae', 'ddsa', 'mw'],
    "taptodakasvāmin": ['mw'],
    "taptābharaṇa": ['mw'],
    "taptānna": ['mw'],
    "taptāyana": ['mw'],
    "taptāyas": ['cae'],
    "taptṛ": ['cae', 'mw'],
    "tapu": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "tapur": ['mw'],
    "tapuragra": ['gra', 'mw'],
    "tapurjambha": ['gra', 'mw'],
    "tapurmūrdhan": ['gra', 'mw'],
    "tapurvadha": ['gra', 'mw'],
    "tapus": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tapuṣi": ['cae', 'ddsa', 'gra', 'mw'],
    "tapuṣpā": ['cae', 'ddsa', 'gra', 'mw'],
    "tapuṣī": ['ap90', 'mw'],
    "tapya": ['mw'],
    "tapyati": ['cae', 'mw'],
    "tapyatu": ['cae', 'gra', 'mw'],
    "tapyatva": ['mw'],
    "tapā": ['bhs', 'mw'],
    "tapāgaccha": ['mw'],
    "tapānta": ['cae', 'mw'],
    "tapātyaya": ['cae', 'ddsa', 'mw'],
    "tapīyas": ['mw'],
    "tapīyaṃs": ['cae'],
    "tar": ['cae', 'gra'],
    "tara": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "taraccha": ['cped'],
    "tarad": ['ap90', 'mw'],
    "taraddveṣas": ['cae', 'gra', 'mw'],
    "taradhyai": ['cae'],
    "taradī": ['mw'],
    "tarahi": ['cped'],
    "tarakṣa": ['cae', 'ddsa', 'mw'],
    "tarakṣaḥ": ['ap90'],
    "tarakṣu": ['cae', 'mw'],
    "tarakṣuka": ['mw'],
    "tarala": ['ap90', 'cae', 'ddsa', 'mw'],
    "taralalekhā": ['ddsa', 'mw'],
    "taralalocanā": ['mw'],
    "taralanayanī": ['mw'],
    "taralatva": ['mw'],
    "taralatā": ['mw'],
    "taralay": ['cae'],
    "taralaya": ['ddsa', 'mw'],
    "taralayati": ['ap90'],
    "taralikā": ['cae', 'ddsa', 'mw'],
    "taralita": ['ap90', 'mw'],
    "taralitahāra": ['mw'],
    "taralā": ['mw'],
    "taralāya": ['mw'],
    "taralāyate": ['ap90'],
    "taralāyita": ['mw'],
    "taralāyitaḥ": ['ap90'],
    "tarambuja": ['mw'],
    "taramāna": ['cped'],
    "taramāna-rūpa": ['cped'],
    "taranta": ['cped', 'gra', 'mw'],
    "tarantuka": ['mw'],
    "tarantī": ['mw'],
    "tarapaṇya": ['bhs', 'mw'],
    "tarapaṇyika": ['mw'],
    "tarapuṭa": ['bhs'],
    "taras": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tarasa": ['cae', 'mw'],
    "tarasagadattā": ['mw'],
    "tarasamaya": ['mw'],
    "tarasapuroḍāśa": ['mw'],
    "tarasat": ['gra', 'mw'],
    "tarasaṃ": ['ap90'],
    "tarasmat": ['mw'],
    "tarasthāna": ['mw'],
    "tarasvant": ['cae'],
    "tarasvat": ['ap90', 'ddsa', 'mw'],
    "tarasvin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tarasā": ['mw'],
    "tarasāna": ['mw'],
    "tarasānaḥ": ['ap90'],
    "tarasārika": ['mw'],
    "tarat": ['mw'],
    "taratamatas": ['cae', 'ddsa', 'mw'],
    "taratha": ['mw'],
    "tarati": ['cped'],
    "taratsala": ['mw'],
    "taratsama": ['mw'],
    "taratsamandī": ['ddsa', 'mw'],
    "taratsamandīya": ['mw'],
    "taravaṭa": ['mw'],
    "taravālikā": ['mw'],
    "taravāri": ['mw'],
    "taravāriḥ": ['ap90'],
    "taravī": ['mw'],
    "taraṃg": ['cae'],
    "taraṃga": ['cae', 'mw'],
    "taraṃgabhīru": ['mw'],
    "taraṃgaka": ['mw'],
    "taraṃgamālin": ['mw'],
    "taraṃgavatī": ['mw'],
    "taraṃgavāta": ['cae'],
    "taraṃgay": ['cae'],
    "taraṃgaya": ['mw'],
    "taraṃgaḥ": ['ap90'],
    "taraṃgikā": ['mw'],
    "taraṃgin": ['ap90', 'cae', 'mw'],
    "taraṃgita": ['ap90', 'cae', 'mw'],
    "taraṃgiṇī": ['mw'],
    "taraṃgiṇībhartṛ": ['mw'],
    "taraṃgiṇīnātha": ['mw'],
    "taraṃgāpatrasta": ['mw'],
    "taraṃtaḥ": ['ap90'],
    "taraṃtī": ['ap90'],
    "taraṃḍaḥ": ['ap90'],
    "taraṅga": ['ddsa'],
    "taraṅgavatī": ['bhs'],
    "taraṅgaya": ['ddsa'],
    "taraṅgin": ['ddsa'],
    "taraṅgāyate": ['bhs'],
    "taraṇa": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "taraṇaḥ": ['ap90'],
    "taraṇi": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "taraṇidhanya": ['mw'],
    "taraṇipeṭaka": ['mw'],
    "taraṇiratna": ['mw'],
    "taraṇitanayā": ['mw'],
    "taraṇitva": ['cae', 'gra', 'mw'],
    "taraṇya": ['mw'],
    "taraṇyati": ['ap90'],
    "taraṇī": ['mw'],
    "taraṇīvallī": ['mw'],
    "taraṇīya": ['cae', 'cped', 'mw'],
    "taraṇḍa": ['mw'],
    "taraṇḍaka": ['mw'],
    "taraṇḍapādā": ['mw'],
    "taraṭa": ['mw'],
    "taraṭī": ['mw'],
    "tarb": ['ap90', 'mw'],
    "tarbaṭa": ['mw'],
    "tarbaṭaḥ": ['ap90'],
    "tard": ['ap90', 'mw'],
    "tarda": ['cae', 'mw'],
    "tardana": ['cae', 'mw'],
    "tardma": ['mw'],
    "tardman": ['ap90', 'cae', 'mw'],
    "tardmasamuta": ['mw'],
    "tardmavat": ['mw'],
    "tardu": ['ap90'],
    "tardāpati": ['mw'],
    "tardū": ['mw'],
    "tareti": ['cped'],
    "tarh": ['gra'],
    "tarha": ['mw'],
    "tarhaṇa": ['cae', 'gra', 'mw'],
    "tarhaṇaṃ": ['ap90'],
    "tarhi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tari": ['cae', 'ddsa', 'mw'],
    "tarika": ['cae', 'mw'],
    "tarikaḥ": ['ap90'],
    "tarikin": ['ap90', 'mw'],
    "tarikā": ['mw'],
    "tarin": ['mw'],
    "tariratha": ['mw'],
    "tarita": ['cped'],
    "taritabba": ['cped'],
    "taritavya": ['mw'],
    "taritra": ['mw'],
    "taritraṃ": ['ap90'],
    "tarituṁ": ['cped'],
    "taritvā": ['cped'],
    "taritā": ['ap90', 'mw'],
    "taritādhāraṇayantra": ['mw'],
    "taritāpūjāyantra": ['mw'],
    "taritṛ": ['mw'],
    "tarivāra": ['cae'],
    "tariḥ": ['ap90'],
    "tariṁsu": ['cped'],
    "tariṇī": ['cae', 'mw'],
    "tarj": ['ap90', 'cae', 'ddsa', 'mw'],
    "tarjaka": ['mw'],
    "tarjana": ['cae', 'ddsa', 'mw'],
    "tarjanaṃ": ['ap90'],
    "tarjanikā": ['mw'],
    "tarjanā": ['mw'],
    "tarjanī": ['mw'],
    "tarjanīya": ['bhs', 'mw'],
    "tarjika": ['mw'],
    "tarjita": ['ap90', 'cae', 'mw'],
    "tark": ['ap90', 'cae', 'ddsa', 'mw'],
    "tarka": ['bhs', 'cae', 'ddsa', 'mw'],
    "tarkabhāṣā": ['mw'],
    "tarkabhāṣābhāvaprahāśikā": ['mw'],
    "tarkabhāṣāprakāśa": ['mw'],
    "tarkabhāṣāprakāśikā": ['mw'],
    "tarkabhāṣāsāramañjarī": ['mw'],
    "tarkacandrikā": ['mw'],
    "tarkacūḍāmaṇi": ['mw'],
    "tarkadīpikā": ['mw'],
    "tarkagrantha": ['mw'],
    "tarkajvālā": ['mw'],
    "tarkajñāna": ['mw'],
    "tarkaka": ['ap90', 'mw'],
    "tarkakarkaśa": ['mw'],
    "tarkakarman": ['mw'],
    "tarkakaumudī": ['mw'],
    "tarkakutūhala": ['mw'],
    "tarkakārikā": ['mw'],
    "tarkamañjarī": ['mw'],
    "tarkamudrā": ['mw'],
    "tarkaparibhāṣā": ['mw'],
    "tarkaparibhāṣāvṛtti": ['mw'],
    "tarkapañcānana": ['mw'],
    "tarkapradīpa": ['mw'],
    "tarkaprakāśa": ['mw'],
    "tarkarahasya": ['mw'],
    "tarkarahasyadīpikā": ['mw'],
    "tarkaratna": ['mw'],
    "tarkasamaya": ['mw'],
    "tarkasaṃgraha": ['cae', 'mw'],
    "tarkasaṃgrahadīpikā": ['mw'],
    "tarkasādhya": ['mw'],
    "tarkataraṃgiṇī": ['mw'],
    "tarkavid": ['mw'],
    "tarkavidyā": ['mw'],
    "tarkavāda": ['mw'],
    "tarkavāgīśa": ['mw'],
    "tarkayukta": ['mw'],
    "tarkaśāstra": ['mw'],
    "tarkaḥ": ['ap90'],
    "tarkaṇa": ['mw'],
    "tarkaṇaṃ": ['ap90'],
    "tarkaṇīya": ['mw'],
    "tarkin": ['ap90', 'cae', 'ddsa', 'mw'],
    "tarkita": ['ap90', 'mw'],
    "tarkiṇa": ['mw'],
    "tarku": ['cae', 'ddsa', 'mw'],
    "tarkuka": ['ddsa', 'mw'],
    "tarkukarman": ['mw'],
    "tarkukaḥ": ['ap90'],
    "tarkulāsaka": ['mw'],
    "tarkupiṇḍa": ['mw'],
    "tarkupāṭhī": ['mw'],
    "tarkupīṭha": ['mw'],
    "tarkupīṭhī": ['mw'],
    "tarkuśāna": ['mw'],
    "tarkuḥ": ['ap90'],
    "tarkuṭa": ['mw'],
    "tarkuṭī": ['mw'],
    "tarkya": ['mw'],
    "tarkā": ['mw'],
    "tarkābhāsa": ['mw'],
    "tarkālaṃkāra": ['mw'],
    "tarkāmṛta": ['mw'],
    "tarkāmṛtacaṣaka": ['mw'],
    "tarkāmṛtataraṃgiṇī": ['mw'],
    "tarkānubhāṣā": ['mw'],
    "tarkāri": ['mw'],
    "tarkārī": ['mw'],
    "tarkāṭa": ['mw'],
    "tarkṣu": ['mw'],
    "tarkṣuḥ": ['ap90'],
    "tarkṣya": ['mw'],
    "tarkṣyaḥ": ['ap90'],
    "tarman": ['ap90', 'cae', 'gra', 'mw'],
    "tarpaka": ['mw'],
    "tarpara": ['mw'],
    "tarpayitavya": ['mw'],
    "tarpaṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "tarpaṇavidhi": ['mw'],
    "tarpaṇaṃ": ['ap90'],
    "tarpaṇecchu": ['mw'],
    "tarpaṇī": ['mw'],
    "tarpaṇīya": ['cae', 'ddsa', 'mw'],
    "tarphitṛ": ['ap90', 'mw'],
    "tarpin": ['ap90', 'mw'],
    "tarpita": ['ap90', 'mw'],
    "tarpiṇī": ['mw'],
    "tarsa": ['mw'],
    "tartarīka": ['mw'],
    "tartavya": ['mw'],
    "taru": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "tarubhuj": ['mw'],
    "tarucchāyā": ['cae', 'mw'],
    "tarudūlikā": ['mw'],
    "tarugahana": ['cae', 'mw'],
    "taruja": ['mw'],
    "tarujīvana": ['mw'],
    "tarukhaṇḍa": ['mw'],
    "tarukoṭara": ['cae', 'mw'],
    "tarukūṇi": ['mw'],
    "tarukṣa": ['gra', 'mw'],
    "tarumahiman": ['mw'],
    "tarumastaka": ['mw'],
    "tarumaṇḍapa": ['cae', 'mw'],
    "tarumūla": ['cae', 'mw'],
    "tarumṛga": ['mw'],
    "tarunakha": ['mw'],
    "tarupaṅkti": ['mw'],
    "tarurohiṇī": ['mw'],
    "taruruhā": ['mw'],
    "tarurāga": ['mw'],
    "tarurāja": ['mw'],
    "tarurājan": ['mw'],
    "tarurāji": ['cae'],
    "tarus": ['ap90', 'cae', 'gra', 'mw'],
    "tarusthā": ['mw'],
    "tarusāra": ['mw'],
    "tarusāramaya": ['mw'],
    "tarutala": ['cae', 'ddsa', 'mw'],
    "tarutra": ['ap90', 'cae', 'gra', 'mw'],
    "tarutā": ['mw'],
    "tarutūlikā": ['mw'],
    "tarutṛ": ['ap90', 'cae', 'gra', 'mw'],
    "taruvallī": ['mw'],
    "taruvara": ['mw'],
    "taruviṭapa": ['mw'],
    "taruśa": ['ap90', 'mw'],
    "taruśreṣṭha": ['mw'],
    "taruśāyin": ['mw'],
    "taruṇa": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "taruṇadadhi": ['mw'],
    "taruṇajvara": ['mw'],
    "taruṇajvarāri": ['mw'],
    "taruṇaka": ['bhs', 'cped', 'mw'],
    "taruṇakaṃ": ['ap90'],
    "taruṇapītikā": ['mw'],
    "taruṇatā": ['mw'],
    "taruṇavuta": ['cped'],
    "taruṇay": ['cae'],
    "taruṇaya": ['ddsa', 'mw'],
    "taruṇayati": ['ap90'],
    "taruṇendu": ['mw'],
    "taruṇiman": ['ap90', 'cae', 'ddsa', 'mw'],
    "taruṇābhāsa": ['mw'],
    "taruṇāditya": ['cae', 'mw'],
    "taruṇārkabhānu": ['bhs'],
    "taruṇāsthi": ['mw'],
    "taruṇāya": ['ddsa', 'mw'],
    "taruṇāyate": ['ap90'],
    "taruṇī": ['cped', 'ddsa', 'mw'],
    "taruṇībhū": ['mw'],
    "taruṇībhūta": ['mw'],
    "taruṇīgaṇa": ['mw'],
    "taruṇījana": ['mw'],
    "taruṇīkaṭākṣakāma": ['mw'],
    "taruṇīkaṭākṣamāla": ['mw'],
    "taruṇīratna": ['mw'],
    "taruṣ": ['cae', 'mw'],
    "taruṣa": ['cae', 'gra', 'mw'],
    "taruṣaḥ": ['ap90'],
    "taruṣaṇḍa": ['cae', 'mw'],
    "taruṣy": ['cae', 'gra'],
    "taruṣyat": ['mw'],
    "taruṣyati": ['ap90'],
    "taruṣī": ['mw'],
    "taruṭaḥ": ['ap90'],
    "tarvan": ['mw'],
    "tarya": ['cae', 'gra', 'mw'],
    "tarālu": ['mw'],
    "tarām": ['cae', 'ddsa', 'mw'],
    "tarāndhu": ['mw'],
    "tarārka": ['bhs'],
    "tarāyaṇa": ['mw'],
    "tarāṃdhuḥ": ['ap90'],
    "tarī": ['cae', 'mw'],
    "tarīpa": ['mw'],
    "tarītu": ['mw'],
    "tarītṛ": ['mw'],
    "tarīyas": ['gra', 'mw'],
    "tarīyaṃs": ['cae'],
    "tarīṣa": ['mw'],
    "tarīṣaḥ": ['ap90'],
    "tarīṣaṇi": ['cae', 'mw'],
    "tarūtṛ": ['mw'],
    "tarūṇaka": ['mw'],
    "tarūṣas": ['cae', 'gra', 'mw'],
    "tarūṭa": ['cae', 'ddsa', 'mw'],
    "tarṇa": ['mw'],
    "tarṇaka": ['cae', 'ddsa', 'mw'],
    "tarṇaḥ": ['ap90'],
    "tarṇi": ['mw'],
    "tarṣa": ['cae', 'ddsa', 'mw'],
    "tarṣacetas": ['mw'],
    "tarṣam": ['mw'],
    "tarṣaḥ": ['ap90'],
    "tarṣaṇa": ['mw'],
    "tarṣaṇaṃ": ['ap90'],
    "tarṣita": ['ap90', 'cae', 'mw'],
    "tarṣiāvat": ['gra'],
    "tarṣuka": ['mw'],
    "tarṣula": ['mw'],
    "tarṣyāvant": ['cae'],
    "tarṣyāvat": ['gra', 'mw'],
    "tarṣā": ['mw'],
    "tas": ['ap90', 'mw'],
    "tasa": ['cped'],
    "tasara": ['cae', 'cped', 'gra', 'mw'],
    "tasarikā": ['bhs', 'mw'],
    "tasathāvara": ['cped'],
    "tasati": ['cped'],
    "tasdī": ['mw'],
    "tasinā": ['cped'],
    "tasiṇā": ['bhs', 'cped'],
    "taskara": ['cae', 'ddsa', 'gra', 'mw'],
    "taskarasnāyu": ['mw'],
    "taskaratva": ['mw'],
    "taskaratā": ['ap90', 'mw'],
    "taskaravat": ['mw'],
    "taskaravṛtti": ['mw'],
    "taskaraḥ": ['ap90'],
    "taskarāya": ['ddsa', 'mw'],
    "taskarī": ['mw'],
    "tasmā": ['cped'],
    "tasmāt": ['cae', 'ddsa', 'mw'],
    "tasmātiha": ['cped'],
    "tassapāpiyasakā": ['cped'],
    "tassapāpiyasakākamma": ['cped'],
    "tassapāpiyasakākammakata": ['cped'],
    "tasthivas": ['mw'],
    "tasthu": ['ap90', 'cae', 'mw'],
    "tasthāna": ['mw'],
    "tasthī": ['mw'],
    "tastuva": ['mw'],
    "tasyāśitīya": ['mw'],
    "tasīra": ['mw'],
    "tat": ['mw'],
    "tata": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "tatacihna": ['mw'],
    "tatadruh": ['mw'],
    "tatama": ['ap90', 'mw'],
    "tatanuṣṭi": ['gra', 'mw'],
    "tatapattrī": ['mw'],
    "tatara": ['ap90', 'mw'],
    "tatas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tatastya": ['ap90', 'ddsa', 'mw'],
    "tatatata": ['mw'],
    "tatatva": ['mw'],
    "tatavat": ['mw'],
    "tataṃjacala": ['bhs'],
    "tatha": ['cped'],
    "tathariva": ['bhs'],
    "tathatva": ['bhs'],
    "tathatā": ['bhs'],
    "tathatāprabha": ['bhs'],
    "tathatāsthitaniścitta": ['bhs'],
    "tathiva": ['cped'],
    "tathiya": ['cped'],
    "tathopama": ['mw'],
    "tathotsāha": ['mw'],
    "tathya": ['ap90', 'cae', 'ddsa', 'mw'],
    "tathyatas": ['mw'],
    "tathyavacana": ['mw'],
    "tathyavādin": ['mw'],
    "tathyena": ['mw'],
    "tathā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "tathā hi": ['cped'],
    "tathābhavitavyatā": ['mw'],
    "tathābhāva": ['cae', 'mw'],
    "tathābhāvin": ['cae', 'mw'],
    "tathābhūta": ['cae', 'mw'],
    "tathādarśana": ['bhs'],
    "tathāgata": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "tathāgatabhadra": ['mw'],
    "tathāgatabimbaparivarta": ['bhs'],
    "tathāgatagarbha": ['bhs', 'mw'],
    "tathāgataguhyaka": ['mw'],
    "tathāgataguhyasūtra": ['bhs'],
    "tathāgataguṇajñānācintyaviṣayāvatāranirdeśa": ['mw'],
    "tathāgatahṛdaya": ['bhs'],
    "tathāgatajñānamudrāsamādhi": ['bhs'],
    "tathāgataka": ['cped'],
    "tathāgatakośaparipālitā": ['bhs', 'mw'],
    "tathāgatakoṣa": ['bhs'],
    "tathāgatakulagotrodgata": ['bhs'],
    "tathāgatamahākaruṇānirdeśa": ['bhs'],
    "tathāgataśrīgarbha": ['bhs'],
    "tathāgatotpattisaṃbhavanirdeśa": ['bhs'],
    "tathāgatācintyaguhyanirdeśa": ['bhs'],
    "tathāgatānisevita": ['cped'],
    "tathāgatārañjita": ['cped'],
    "tathāguṇa": ['cae', 'mw'],
    "tathājātīya": ['mw'],
    "tathājātīyaka": ['mw'],
    "tathākaraṇa": ['mw'],
    "tathākratu": ['mw'],
    "tathākāram": ['mw'],
    "tathākṛta": ['mw'],
    "tathāmukha": ['mw'],
    "tathāprabhāva": ['mw'],
    "tathārtha": ['mw'],
    "tathārthatva": ['mw'],
    "tathārthavāc": ['mw'],
    "tathārāja": ['mw'],
    "tathārūpa": ['cae', 'cped', 'ddsa', 'mw'],
    "tathārūpin": ['cae', 'mw'],
    "tathāsvara": ['mw'],
    "tathātta": ['cped'],
    "tathātva": ['bhs', 'mw'],
    "tathātvaṃ": ['ap90'],
    "tathātā": ['bhs', 'cped', 'mw'],
    "tathāvidha": ['cae', 'cped', 'mw'],
    "tathāvidham": ['mw'],
    "tathāvidhāna": ['mw'],
    "tathāvrata": ['cae', 'mw'],
    "tathāvādi(n)": ['cped'],
    "tathāvādin": ['mw'],
    "tathāvīrya": ['cae', 'mw'],
    "tathāyatam": ['ddsa', 'mw'],
    "tathāśīla": ['mw'],
    "tathāśīlasamācāra": ['mw'],
    "tathūpama": ['cped'],
    "tathūpamaṁ": ['cped'],
    "tati": ['ap90', 'cae', 'ddsa', 'mw'],
    "tatidhā": ['cae', 'mw'],
    "tatitha": ['ap90', 'cae', 'ddsa', 'mw'],
    "tatiya": ['cped'],
    "tatiyaka": ['cped'],
    "tatiyaṁ": ['cped'],
    "tatiḥ": ['ap90'],
    "tatkara": ['bhs', 'mw'],
    "tatkarmakārin": ['cae', 'mw'],
    "tatkartavya": ['ddsa', 'mw'],
    "tatkartṛ": ['cae', 'mw'],
    "tatkatara": ['bhs'],
    "tatkriya": ['mw'],
    "tatkulīna": ['mw'],
    "tatkāla": ['cae', 'mw'],
    "tatkāladhī": ['mw'],
    "tatkālalavaṇa": ['mw'],
    "tatkālam": ['mw'],
    "tatkālavedin": ['cae'],
    "tatkālotpannadhī": ['mw'],
    "tatkālīna": ['cae', 'mw'],
    "tatkāraṇa": ['cae'],
    "tatkārin": ['cae', 'mw'],
    "tatkāryakāraṇāt": ['cae'],
    "tatkṛta": ['cae'],
    "tatkṛte": ['mw'],
    "tatkṣaṇa": ['bhs', 'cae', 'mw'],
    "tatkṣaṇam": ['mw'],
    "tatkṣaṇe": ['mw'],
    "tatkṣaṇikā": ['bhs', 'mw'],
    "tatkṣaṇāt": ['mw'],
    "tato": ['cped', 'mw'],
    "tato nidānaṁ": ['cped'],
    "tato nimittaṁ": ['cped'],
    "tatobhavat": ['mw'],
    "tatobṛhatīka": ['mw'],
    "tatoja": ['cped'],
    "tatomukha": ['bhs', 'cae'],
    "tatonidāna": ['mw'],
    "tatonidānaṃ": ['bhs'],
    "tatophabutika": ['cped'],
    "tatpada": ['cae', 'ddsa', 'mw'],
    "tatpara": ['cae', 'mw'],
    "tatparatva": ['mw'],
    "tatparatā": ['mw'],
    "tatparā": ['mw'],
    "tatparāyaṇa": ['cae', 'mw'],
    "tatphala": ['mw'],
    "tatprabhāte": ['mw'],
    "tatprabhṛti": ['mw'],
    "tatpradhāna": ['cae', 'mw'],
    "tatprakāra": ['mw'],
    "tatprakṛta": ['mw'],
    "tatprathama": ['mw'],
    "tatprathamakarmika": ['bhs'],
    "tatprathamam": ['mw'],
    "tatprathamataram": ['mw'],
    "tatprathamatas": ['bhs', 'mw'],
    "tatpratipādaka": ['cae'],
    "tatpratyayam": ['mw'],
    "tatpratyayatva": ['mw'],
    "tatpravaravat": ['mw'],
    "tatprayojaka": ['cae'],
    "tatprepsu": ['mw'],
    "tatpuruṣa": ['cae', 'mw'],
    "tatpuruṣavaktra": ['mw'],
    "tatpāṇini": ['mw'],
    "tatpūrva": ['mw'],
    "tatpūrvam": ['mw'],
    "tatpūrvasaṅga": ['mw'],
    "tatpūrvatā": ['mw'],
    "tatpṛṣṭha": ['mw'],
    "tatra": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "tatrabhava": ['mw'],
    "tatrabhavant": ['cae'],
    "tatrabhavat": ['ddsa', 'mw'],
    "tatrabhavatī": ['mw'],
    "tatracakṣurmanas": ['ddsa', 'mw'],
    "tatraloka": ['mw'],
    "tatraskandha": ['mw'],
    "tatrastha": ['cae', 'ddsa', 'mw'],
    "tatratatrābhinandana": ['cped'],
    "tatratatrābhinandi(n)": ['cped'],
    "tatratya": ['ap90', 'cae', 'ddsa', 'mw'],
    "tatravāsin": ['mw'],
    "tatraṭṭha": ['cped'],
    "tatrupayaññu": ['cped'],
    "tatrāntare": ['cae', 'ddsa'],
    "tatrūpāya": ['cped'],
    "tatsad": ['mw'],
    "tatsadṛśa": ['mw'],
    "tatsahāya": ['cae'],
    "tatsakha": ['cae'],
    "tatsama": ['cae', 'mw'],
    "tatsamakṣam": ['cae'],
    "tatsamanantaram": ['mw'],
    "tatsaṃbandhin": ['cae'],
    "tatsaṃkhyāka": ['cae', 'mw'],
    "tatsaṃskārārthatva": ['mw'],
    "tatsaṅkhyāka": ['ddsa'],
    "tatsina": ['gra', 'mw'],
    "tatspṛṣṭin": ['cae', 'mw'],
    "tatstha": ['mw'],
    "tatsthatadañjanatā": ['mw'],
    "tatsthāna": ['mw'],
    "tatsvabhāvaiṣīya": ['bhs'],
    "tatsvarūpa": ['cae'],
    "tatsādhukārin": ['mw'],
    "tatta": ['cped'],
    "tattaddeśīya": ['mw'],
    "tattaka": ['bhs', 'cped'],
    "tattha": ['cped'],
    "tatthajātaka": ['cped'],
    "tatthaparinibbāyi(n)": ['cped'],
    "tattribhāgaka": ['mw'],
    "tattulya": ['cae', 'mw'],
    "tattva": ['cae', 'ddsa', 'mw'],
    "tattvabhāva": ['cae', 'mw'],
    "tattvabhūta": ['cae', 'mw'],
    "tattvabindu": ['mw'],
    "tattvabodha": ['cae', 'mw'],
    "tattvabodhinī": ['mw'],
    "tattvacandra": ['mw'],
    "tattvacintāmaṇi": ['mw'],
    "tattvadarśa": ['mw'],
    "tattvadarśin": ['cae', 'mw'],
    "tattvadīpana": ['mw'],
    "tattvadṛś": ['cae', 'mw'],
    "tattvajña": ['cae', 'ddsa', 'mw'],
    "tattvajñāna": ['cae', 'mw'],
    "tattvajñānin": ['mw'],
    "tattvakathana": ['cae'],
    "tattvakaumudī": ['mw'],
    "tattvamuktāvalī": ['mw'],
    "tattvanikaṣagrāvan": ['mw'],
    "tattvaniścaya": ['mw'],
    "tattvaniṣṭhatā": ['mw'],
    "tattvanyāsa": ['mw'],
    "tattvaprabodhaprakaraṇa": ['mw'],
    "tattvaprakāśa": ['mw'],
    "tattvasamāsa": ['mw'],
    "tattvasatyaśāstra": ['mw'],
    "tattvasaṃgraha": ['mw'],
    "tattvasāgara": ['mw'],
    "tattvasāra": ['mw'],
    "tattvataraṃgiṇī": ['mw'],
    "tattvatas": ['mw'],
    "tattvataḥ": ['ap90'],
    "tattvatrayamaya": ['mw'],
    "tattvatyaj": ['mw'],
    "tattvatā": ['mw'],
    "tattvavat": ['mw'],
    "tattvavid": ['cae', 'mw'],
    "tattvaviveka": ['mw'],
    "tattvavivekadīpana": ['mw'],
    "tattvavivitsā": ['mw'],
    "tattvavādarahasya": ['mw'],
    "tattvaśambara": ['mw'],
    "tattvaśambaraka": ['mw'],
    "tattvaśuddhi": ['cae', 'mw'],
    "tattvaṃ": ['ap90'],
    "tattvena": ['mw'],
    "tattvābhiyoga": ['cae', 'mw'],
    "tattvādhigata": ['mw'],
    "tattvākhyānopamā": ['cae', 'ddsa', 'mw'],
    "tattvāpahnavarūpaka": ['mw'],
    "tattvārtha": ['cae', 'mw'],
    "tattvārthaikadeśānupraveśa": ['bhs'],
    "tattvārthakaumudī": ['mw'],
    "tattvārthasūtra": ['mw'],
    "tattvārthavid": ['mw'],
    "tattvāvabodha": ['mw'],
    "tattīra": ['ddsa'],
    "tattṛtīya": ['mw'],
    "taturi": ['ap90', 'cae', 'gra', 'mw'],
    "tatuttarita": ['cped'],
    "tatāmaha": ['ddsa', 'mw'],
    "tatīyaka": ['cped'],
    "taubaraka": ['mw'],
    "taubha": ['mw'],
    "taucchya": ['mw'],
    "tauda": ['mw'],
    "taudeya": ['bhs', 'mw'],
    "taudādika": ['mw'],
    "taudī": ['mw'],
    "taugria": ['gra'],
    "taugrya": ['cae', 'ddsa', 'gra', 'mw'],
    "taukṣika": ['mw'],
    "taukṣikaḥ": ['ap90'],
    "taukṣāyaṇa": ['mw'],
    "taula": ['mw'],
    "taulakeśi": ['mw'],
    "taulakeśin": ['mw'],
    "taulaṃ": ['ap90'],
    "taulika": ['mw'],
    "taulikaḥ": ['ap90'],
    "taulikika": ['mw'],
    "taulin": ['ap90', 'mw'],
    "taulvali": ['mw'],
    "taulvalyādi": ['mw'],
    "taulvalāyana": ['mw'],
    "taulya": ['cae', 'ddsa', 'mw'],
    "taulyaṃ": ['ap90'],
    "taumburava": ['mw'],
    "taumburavin": ['mw'],
    "taura": ['mw'],
    "taurayāṇa": ['mw'],
    "tauraśravasa": ['mw'],
    "tauraṃgika": ['mw'],
    "taururava": ['mw'],
    "tauruṣkika": ['mw'],
    "taurvaśa": ['mw'],
    "taurya": ['cae', 'mw'],
    "tauryatraya": ['ddsa'],
    "tauryatrika": ['mw'],
    "tauryaṃ": ['ap90'],
    "taurāyaṇika": ['mw'],
    "tautika": ['mw'],
    "tautikaḥ": ['ap90'],
    "tauttāyana": ['mw'],
    "tautātita": ['mw'],
    "tauvilikā": ['mw'],
    "tauṇḍikera": ['mw'],
    "tauṣāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "tauṣāyaṇa": ['mw'],
    "tavaka": ['mw'],
    "tavakṣīra": ['mw'],
    "tavakṣīraṃ": ['ap90'],
    "tavakṣīrī": ['mw'],
    "tavapriya": ['mw'],
    "tavara": ['bhs', 'mw'],
    "tavarga": ['mw'],
    "tavargīya": ['mw'],
    "tavarāja": ['mw'],
    "tavarājaḥ": ['ap90'],
    "tavas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tavasvant": ['cae'],
    "tavasvat": ['gra', 'mw'],
    "tavasya": ['ap90', 'cae', 'gra', 'mw'],
    "tavaśravīya": ['mw'],
    "taviṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "taviṣy": ['cae', 'gra'],
    "taviṣya": ['ddsa', 'mw'],
    "taviṣyā": ['ap90', 'cae', 'gra', 'mw'],
    "taviṣī": ['ddsa', 'gra', 'mw'],
    "taviṣībhis": ['mw'],
    "taviṣīmant": ['cae'],
    "taviṣīmat": ['gra', 'mw'],
    "taviṣīvant": ['cae'],
    "taviṣīvat": ['gra', 'mw'],
    "taviṣīy": ['cae', 'gra'],
    "taviṣīya": ['ddsa', 'mw'],
    "taviṣīyu": ['cae', 'gra', 'mw'],
    "tavya": ['ap90', 'cae', 'gra', 'mw'],
    "tavyas": ['gra', 'mw'],
    "tavyaṃs": ['cae'],
    "tavāgo": ['mw'],
    "tavāgā": ['cae', 'gra', 'mw'],
    "tavīyas": ['ddsa', 'gra', 'mw'],
    "tavīyaṃs": ['cae'],
    "tavīṣa": ['mw'],
    "tavīṣaḥ": ['ap90'],
    "tavīṣī": ['mw'],
    "tay": ['ap90', 'mw'],
    "taya": ['mw'],
    "tayaḥ": ['ap90'],
    "tayyathāpināma": ['bhs'],
    "tañc": ['cae', 'ddsa', 'mw'],
    "tañj": ['mw'],
    "tañjala": ['mw'],
    "taślī": ['mw'],
    "taḍ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "taḍaga": ['mw'],
    "taḍagaḥ": ['ap90'],
    "taḍataḍiti": ['mw'],
    "taḍatkārin": ['mw'],
    "taḍi": ['ap90', 'mw'],
    "taḍid": ['mw'],
    "taḍidgarbha": ['mw'],
    "taḍidvāsas": ['mw'],
    "taḍil": ['mw'],
    "taḍillatā": ['cae', 'ddsa', 'mw'],
    "taḍillekhā": ['cae', 'mw'],
    "taḍin": ['mw'],
    "taḍinmaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "taḍinmālā": ['cae', 'mw'],
    "taḍinmālāvalambin": ['mw'],
    "taḍit": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "taḍitas": ['mw'],
    "taḍiti": ['mw'],
    "taḍitkumāra": ['mw'],
    "taḍitpati": ['mw'],
    "taḍitprabhā": ['mw'],
    "taḍitvant": ['cae'],
    "taḍitvat": ['ap90', 'mw'],
    "taḍāga": ['cae', 'ddsa', 'mw'],
    "taḍāgabhavanotsarga": ['mw'],
    "taḍāgabhedaka": ['mw'],
    "taḍāgada": ['mw'],
    "taḍāgapālinī": ['bhs'],
    "taḍāgavat": ['mw'],
    "taḍāgaḥ": ['ap90'],
    "taḍāghātaḥ": ['ap90'],
    "taḍāka": ['mw'],
    "taḍākaḥ": ['ap90'],
    "taḍākini": ['mw'],
    "taḍākā": ['mw'],
    "taḥ": ['ap90'],
    "taḷaka": ['cped'],
    "taḷāka": ['cped'],
    "taṁ": ['cped'],
    "taṁcatuttha": ['cped'],
    "taṁdasama": ['cped'],
    "taṁdiṭṭhika": ['cped'],
    "taṁdukkha": ['cped'],
    "taṁkhantika": ['cped'],
    "taṁpañcama": ['cped'],
    "taṁrucika": ['cped'],
    "taṁsukha": ['cped'],
    "taṁvusita": ['cped'],
    "taṁvīsa": ['cped'],
    "taṃbhū": ['bhs'],
    "taṃbā": ['ap90'],
    "taṃc": ['ap90'],
    "taṃdra": ['ap90'],
    "taṃdrikā": ['ap90'],
    "taṃdrin": ['ap90'],
    "taṃdrita": ['ap90'],
    "taṃdriḥ": ['ap90'],
    "taṃdrā": ['ap90'],
    "taṃdrālu": ['ap90'],
    "taṃg": ['ap90'],
    "taṃj": ['ap90'],
    "taṃk": ['ap90'],
    "taṃkanaṃ": ['ap90'],
    "taṃkaḥ": ['ap90'],
    "taṃs": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "taṃsu": ['mw'],
    "taṃsurodha": ['mw'],
    "taṃtiḥ": ['ap90'],
    "taṃtr": ['ap90'],
    "taṃtrakaḥ": ['ap90'],
    "taṃtratā": ['ap90'],
    "taṃtraṃ": ['ap90'],
    "taṃtraṇaṃ": ['ap90'],
    "taṃtrin": ['ap90'],
    "taṃtriḥ": ['ap90'],
    "taṃtrā": ['ap90'],
    "taṃtrāyin": ['ap90'],
    "taṃtukaḥ": ['ap90'],
    "taṃtunaḥ": ['ap90'],
    "taṃturaṃ": ['ap90'],
    "taṃtuḥ": ['ap90'],
    "taṃḍ": ['ap90'],
    "taṃḍakaḥ": ['ap90'],
    "taṃḍulaḥ": ['ap90'],
    "taṃḍurīṇaḥ": ['ap90'],
    "taṃḍā": ['ap90'],
    "taṅg": ['mw'],
    "taṅgalva": ['mw'],
    "taṅgana": ['cae'],
    "taṅganakhatā": ['mw'],
    "taṅgati": ['bhs'],
    "taṅgaṇa": ['cae', 'ddsa', 'mw'],
    "taṅk": ['mw'],
    "taṅka": ['mw'],
    "taṅkhanika": ['cped'],
    "taṇhacchida": ['cped'],
    "taṇhadhipanna": ['cped'],
    "taṇhagata": ['cped'],
    "taṇhakkhaya": ['cped'],
    "taṇhā": ['cped'],
    "taṇhādutiya": ['cped'],
    "taṇhāgata": ['cped'],
    "taṇhājatika": ['cped'],
    "taṇhājāla": ['cped'],
    "taṇhākāya": ['cped'],
    "taṇhāmūlaka": ['cped'],
    "taṇhānigghātana": ['cped'],
    "taṇhāsammudita": ['cped'],
    "taṇhāvicarita": ['cped'],
    "taṇhāyati": ['cped'],
    "taṇhīyati": ['cped'],
    "taṇḍ": ['mw'],
    "taṇḍa": ['mw'],
    "taṇḍaka": ['mw'],
    "taṇḍavataṇḍa": ['mw'],
    "taṇḍi": ['mw'],
    "taṇḍibrāhmaṇa": ['mw'],
    "taṇḍiputra": ['mw'],
    "taṇḍivāha": ['mw'],
    "taṇḍu": ['mw'],
    "taṇḍula": ['cae', 'cped', 'ddsa', 'mw'],
    "taṇḍuladeva": ['mw'],
    "taṇḍulahoma": ['cped'],
    "taṇḍulakaṇa": ['cae', 'mw'],
    "taṇḍulakaṇḍana": ['cae', 'mw'],
    "taṇḍulakiṇva": ['mw'],
    "taṇḍulakusumabaliprakāra": ['mw'],
    "taṇḍulakusumabalivikāra": ['mw'],
    "taṇḍulamuṭṭhi": ['cped'],
    "taṇḍulapaṭhibasta": ['cped'],
    "taṇḍulaphalā": ['mw'],
    "taṇḍulapphala": ['cped'],
    "taṇḍulaugha": ['mw'],
    "taṇḍulavaitālika": ['mw'],
    "taṇḍulera": ['mw'],
    "taṇḍulika": ['mw'],
    "taṇḍulikāśrama": ['mw'],
    "taṇḍulin": ['mw'],
    "taṇḍulodaka": ['cae', 'mw'],
    "taṇḍulottha": ['mw'],
    "taṇḍulu": ['mw'],
    "taṇḍulā": ['mw'],
    "taṇḍulāmbu": ['mw'],
    "taṇḍulī": ['mw'],
    "taṇḍulīka": ['mw'],
    "taṇḍulīya": ['mw'],
    "taṇḍulīyaka": ['mw'],
    "taṇḍulīyikā": ['mw'],
    "taṇḍurīṇa": ['mw'],
    "taṇḍyāyanī": ['mw'],
    "taṇḍā": ['mw'],
    "taṇḍālakṣaṇa": ['mw'],
    "taṇḍāpracara": ['mw'],
    "taṇḍāpratara": ['mw'],
    "taṇḍūlikāśrama": ['mw'],
    "taṣṭa": ['ap90', 'mw'],
    "taṣṭi": ['cae', 'mw'],
    "taṣṭṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "taṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "taṭa": ['cae', 'ddsa', 'mw'],
    "taṭabhū": ['mw'],
    "taṭadruma": ['ddsa', 'mw'],
    "taṭagaḥ": ['ap90'],
    "taṭaka": ['mw'],
    "taṭakaṃ": ['ap90'],
    "taṭastha": ['cae', 'mw'],
    "taṭasthita": ['mw'],
    "taṭataṭa": ['mw'],
    "taṭataṭasvana": ['mw'],
    "taṭaḥ": ['ap90'],
    "taṭinī": ['ap90', 'cae', 'ddsa', 'mw'],
    "taṭinīpati": ['mw'],
    "taṭiskandha": ['bhs'],
    "taṭya": ['mw'],
    "taṭyaḥ": ['ap90'],
    "taṭāghāta": ['mw'],
    "taṭāka": ['cae', 'ddsa', 'mw'],
    "taṭākaḥ": ['ap90'],
    "taṭākinī": ['mw'],
    "taṭāya": ['mw'],
    "taṭī": ['mw'],
    "taṭṭa": ['bhs'],
    "taṭṭika": ['cped'],
    "te": ['ddsa'],
    "tecattālīsa(ṁ)": ['cped'],
    "tecattārīsa(ṁ)": ['cped'],
    "tecattārīsaka": ['cped'],
    "tecattāḷīsa(ṁ)": ['cped'],
    "tecīvara": ['cped'],
    "tecīvari(n)": ['cped'],
    "tecīvarika": ['cped'],
    "tedani": ['cae', 'ddsa'],
    "tedanī": ['cae', 'mw'],
    "tedasa": ['cped'],
    "tedaṇḍika": ['cped'],
    "tedhā": ['cped'],
    "tega": ['mw'],
    "tej": ['ap90', 'mw'],
    "teja": ['cae', 'ddsa', 'mw'],
    "teja(s)": ['cped'],
    "tejadhātu": ['cped'],
    "tejagaharaka": ['cped'],
    "tejagupta": ['bhs'],
    "tejaguptarājan": ['bhs'],
    "tejajiggicchaka": ['cped'],
    "tejalaḥ": ['ap90'],
    "tejana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "tejanaka": ['mw'],
    "tejanaṃ": ['ap90'],
    "tejanin": ['mw'],
    "tejanī": ['mw'],
    "tejanīdanta": ['mw'],
    "tejapattra": ['mw'],
    "tejapāla": ['mw'],
    "tejas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tejasa": ['mw'],
    "tejasi(n)": ['cped'],
    "tejasiṃha": ['mw'],
    "tejaska": ['mw'],
    "tejaskara": ['mw'],
    "tejaskāma": ['cae', 'ddsa', 'mw'],
    "tejaskāya": ['mw'],
    "tejaspada": ['mw'],
    "tejassi(n)": ['cped'],
    "tejastejas": ['mw'],
    "tejastimira": ['mw'],
    "tejastva": ['mw'],
    "tejasvant": ['cae'],
    "tejasvat": ['ap90', 'mw'],
    "tejasvatī": ['mw'],
    "tejasvin": ['ap90', 'cae', 'mw'],
    "tejasvinitamā": ['mw'],
    "tejasvinī": ['mw'],
    "tejasvinītamā": ['mw'],
    "tejasvipraśaṃsā": ['mw'],
    "tejasvitva": ['mw'],
    "tejasvitā": ['cae', 'mw'],
    "tejasya": ['cae', 'mw'],
    "tejasāmadhīśa": ['mw'],
    "tejavalkala": ['mw'],
    "tejavativegaprabha": ['bhs'],
    "tejavatī": ['mw'],
    "tejaśiri": ['bhs'],
    "tejaḥ": ['ap90', 'mw'],
    "tejaḥpattra": ['mw'],
    "tejaḥphala": ['mw'],
    "tejaḥprabha": ['mw'],
    "tejaḥpāla": ['mw'],
    "tejaḥsambhava": ['mw'],
    "tejaḥsena": ['ddsa', 'mw'],
    "tejaḥsiṃha": ['mw'],
    "tejeyu": ['mw'],
    "tejeśvara": ['bhs'],
    "teji(n)": ['cped'],
    "tejinī": ['mw'],
    "tejita": ['ap90', 'bhs', 'mw'],
    "tejiṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "tejiṣṭham": ['mw'],
    "tejo": ['mw'],
    "tejobalasamāyukta": ['mw'],
    "tejobhaṅga": ['mw'],
    "tejobhibhavana": ['mw'],
    "tejobhīru": ['mw'],
    "tejobindūpaniṣad": ['mw'],
    "tejobīja": ['mw'],
    "tejodhipati": ['bhs'],
    "tejodhātu": ['bhs'],
    "tejodvaya": ['cae', 'ddsa'],
    "tejohara": ['mw'],
    "tejohrāsa": ['mw'],
    "tejohvā": ['mw'],
    "tejoja": ['mw'],
    "tejojala": ['mw'],
    "tejokasiṇa": ['cped'],
    "tejomantha": ['mw'],
    "tejomaya": ['ap90', 'cae', 'mw'],
    "tejomaṇḍala": ['mw'],
    "tejomātrā": ['mw'],
    "tejomūrti": ['cae', 'mw'],
    "tejomṛtamaya": ['mw'],
    "tejonidhi": ['mw'],
    "tejonāthatīrtha": ['mw'],
    "tejorāśi": ['bhs', 'cae', 'mw'],
    "tejorūpa": ['cae', 'mw'],
    "tejovaidagdhyaśīlavat": ['mw'],
    "tejovant": ['cae'],
    "tejovat": ['mw'],
    "tejovatī": ['bhs', 'mw'],
    "tejovid": ['mw'],
    "tejovṛddhi": ['mw'],
    "tejovṛkṣa": ['mw'],
    "tejovṛtta": ['cae', 'mw'],
    "tejā": ['mw'],
    "tejāhvā": ['mw'],
    "tejāura": ['mw'],
    "tejīyas": ['gra', 'mw'],
    "tejīyaṃs": ['cae'],
    "tekaṭula": ['cped'],
    "tekiccha": ['cped'],
    "tekṣṇiṣṭham": ['cae', 'mw'],
    "tela": ['bhs', 'cped', 'mw'],
    "telaka": ['cped'],
    "telapāka": ['cped'],
    "telu": ['mw'],
    "telā": ['bhs'],
    "tema": ['mw'],
    "temana": ['mw'],
    "temanaṃ": ['ap90'],
    "temanī": ['mw'],
    "temayati": ['cped'],
    "temaḥ": ['ap90'],
    "temetabba": ['cped'],
    "temeti": ['cped'],
    "temetvā": ['cped'],
    "temāsa": ['cped'],
    "temīyati": ['cped'],
    "tena": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "tena hi": ['cped'],
    "tena upāyena": ['cped'],
    "tenaḥ": ['ap90'],
    "tep": ['ap90', 'mw'],
    "tepaññasa": ['cped'],
    "tepaññasa(ṁ)": ['cped'],
    "tera": ['mw'],
    "terasa": ['cped'],
    "terasaka": ['cped'],
    "terasama": ['cped'],
    "teraṇa": ['mw'],
    "terovassika": ['cped'],
    "tesaṭṭhi": ['cped'],
    "tettiṁsa": ['cped'],
    "tev": ['ap90', 'mw'],
    "tevana": ['mw'],
    "tevanaṃ": ['ap90'],
    "tevijja": ['cped'],
    "tevijjaka": ['cped'],
    "tevijjiriṇa": ['cped'],
    "tevijjīriṇa": ['cped'],
    "tevācika": ['cped'],
    "tevīsa": ['cped'],
    "tevīsati": ['cped'],
    "tevīsatima": ['cped'],
    "teḷasa": ['cped'],
    "teṣā": ['bhs'],
    "tha": ['mw'],
    "thaddha": ['cped'],
    "thaddhana": ['cped'],
    "thaithai": ['ap90', 'mw'],
    "thakayati": ['cped'],
    "thakenta": ['cped'],
    "thakesi": ['cped'],
    "thaketabba": ['cped'],
    "thaketi": ['cped'],
    "thaketvā": ['cped'],
    "thakita": ['cped'],
    "thakkana": ['ddsa', 'mw'],
    "thakriya": ['ddsa', 'mw'],
    "thakviyaka": ['ddsa', 'mw'],
    "thakāra": ['mw'],
    "thakīyati": ['cped'],
    "thala": ['bhs', 'cped'],
    "thalaṭṭha": ['cped'],
    "thalyoraka": ['ddsa', 'mw'],
    "thamati": ['cped'],
    "thamba": ['cped'],
    "thambenta": ['cped'],
    "thambha": ['cped'],
    "thambhayati": ['cped'],
    "thambheti": ['cped'],
    "thambhi(n)": ['cped'],
    "thana": ['cped'],
    "thanaka": ['cped'],
    "thanati": ['cped'],
    "thanaya(t)": ['cped'],
    "thanayanta": ['cped'],
    "thanayati": ['cped'],
    "thanayitvā": ['cped'],
    "thaneti": ['cped'],
    "thapakarṇi": ['bhs'],
    "thapati": ['cped'],
    "thapayati": ['bhs', 'cped'],
    "thapeti": ['cped'],
    "thapita": ['cped'],
    "tharatharāy": ['cae'],
    "tharatharāya": ['ddsa', 'mw'],
    "tharatharāyate": ['bhs'],
    "tharu": ['bhs', 'cped'],
    "tharv": ['ap90', 'mw'],
    "thassanti": ['cped'],
    "thassati": ['cped'],
    "thatvā": ['cped'],
    "thauṇeya": ['mw'],
    "thauṇeyaka": ['mw'],
    "thavana": ['bhs'],
    "thavati": ['cped'],
    "thavikā": ['cped'],
    "thañña": ['cped'],
    "thaḥ": ['ap90'],
    "thaṇḍila": ['bhs'],
    "thaṇḍilaseyyā": ['cped'],
    "thaṇḍilasāyikā": ['cped'],
    "thena": ['cped'],
    "thera": ['bhs', 'cped'],
    "theradhika": ['cped'],
    "theragāthā": ['cped'],
    "theraka": ['cped'],
    "theranutherā": ['cped'],
    "therapāli": ['cped'],
    "therapāḷi": ['cped'],
    "theratara": ['cped'],
    "theravāda": ['cped'],
    "therika": ['cped'],
    "therikā": ['cped'],
    "theriya": ['cped'],
    "therovassika": ['cped'],
    "therī": ['cped'],
    "therīgāthā": ['cped'],
    "theta": ['cped'],
    "theva": ['cped'],
    "thevaka": ['cped'],
    "thevikī": ['cped'],
    "theyya": ['cped'],
    "theyyacitta": ['cped'],
    "theyyasattha": ['cped'],
    "theyyasaṁvāsaka": ['cped'],
    "theyyasaṅkhātaṁ": ['cped'],
    "thira": ['cped'],
    "thoka": ['cped'],
    "thokaka": ['cped'],
    "thokatara": ['cped'],
    "thokathoka": ['cped'],
    "thokathokaṁ": ['cped'],
    "thokaṁ thokaṁ": ['cped'],
    "thomayanta": ['cped'],
    "thomayati": ['cped'],
    "thometi": ['cped'],
    "thomita": ['cped'],
    "thoḍana": ['mw'],
    "thoḍanaṃ": ['ap90'],
    "thulla": ['cped'],
    "thullaccaya": ['cped'],
    "thullaccayāpatti": ['cped'],
    "thullakacchu": ['cped'],
    "thullakumārī": ['cped'],
    "thullakumārīka": ['cped'],
    "thullaphusitaka": ['cped'],
    "thullavajja": ['cped'],
    "thuna(t)": ['cped'],
    "thunati": ['cped'],
    "thurv": ['ap90', 'mw'],
    "thusa": ['cped'],
    "thusahoma": ['cped'],
    "thusodaka": ['cped'],
    "thuthu": ['mw'],
    "thuthukṛt": ['mw'],
    "thutkāra": ['mw'],
    "thutkāraḥ": ['ap90'],
    "thutthu": ['bhs'],
    "thutthukāraka": ['mw'],
    "thuḍ": ['ap90', 'mw'],
    "thālaka": ['cped'],
    "thālidhovana": ['cped'],
    "thālipāka": ['cped'],
    "thāma": ['bhs', 'cped'],
    "thāmagata": ['cped'],
    "thāmava(t)": ['cped'],
    "thāti": ['cped'],
    "thāvara": ['cped'],
    "thāvareyya": ['cped'],
    "thī": ['cped'],
    "thīna": ['bhs', 'cped'],
    "thīnamiddha": ['cped'],
    "thūla": ['cped'],
    "thūlakumārī": ['cped'],
    "thūlaphusitaka": ['cped'],
    "thūlavajja": ['cped'],
    "thūpa": ['cped'],
    "thūpacīvara": ['cped'],
    "thūpaka": ['cped'],
    "thūpīkata": ['cped'],
    "thūrv": ['cae'],
    "thūt": ['mw'],
    "thūthū": ['mw'],
    "thūtkāra": ['ddsa', 'mw'],
    "thūtkāraḥ": ['ap90'],
    "thūtkṛ": ['ddsa'],
    "thūtkṛta": ['ddsa', 'mw'],
    "thūtkṛtya": ['mw'],
    "thūṇa": ['cped'],
    "thūṇikā": ['cped'],
    "thūṇirā": ['cped'],
    "ti": ['bhs', 'cped', 'mw'],
    "tia": ['gra'],
    "tibba": ['cped'],
    "tibbagarava": ['cped'],
    "tibeṭa": ['mw'],
    "tibhava": ['cped'],
    "tibhāga": ['cped'],
    "ticīvara": ['cped'],
    "tidasa": ['cped'],
    "tidaṇḍa": ['cped'],
    "tidhā": ['cped'],
    "tidiva": ['cped'],
    "tig": ['mw'],
    "tigh": ['mw'],
    "tigita": ['cae', 'ddsa', 'gra', 'mw'],
    "tigma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tigmabhās": ['mw'],
    "tigmabhṛṣṭi": ['gra', 'mw'],
    "tigmadhāra": ['mw'],
    "tigmadyuti": ['mw'],
    "tigmadīdhiti": ['cae', 'mw'],
    "tigmaga": ['mw'],
    "tigmagati": ['mw'],
    "tigmagu": ['mw'],
    "tigmaheti": ['cae', 'gra', 'mw'],
    "tigmajambha": ['cae', 'gra', 'mw'],
    "tigmakara": ['cae', 'ddsa', 'mw'],
    "tigmaketu": ['mw'],
    "tigmamanyu": ['mw'],
    "tigmamayūkhamālin": ['mw'],
    "tigmamūrdhan": ['gra', 'mw'],
    "tigmanemi": ['mw'],
    "tigmaraśmi": ['cae', 'mw'],
    "tigmarocis": ['mw'],
    "tigmaruc": ['mw'],
    "tigmaruci": ['mw'],
    "tigmatejana": ['cae', 'mw'],
    "tigmatejas": ['cae', 'mw'],
    "tigmatā": ['mw'],
    "tigmavat": ['mw'],
    "tigmavega": ['mw'],
    "tigmavīrya": ['cae', 'mw'],
    "tigmayātana": ['mw'],
    "tigmaśocis": ['gra', 'mw'],
    "tigmaśṛṅga": ['gra', 'mw'],
    "tigmeṣu": ['cae', 'gra', 'mw'],
    "tigmānīka": ['gra', 'mw'],
    "tigmātman": ['mw'],
    "tigmāyudha": ['cae', 'gra', 'mw'],
    "tigmāṃśu": ['cae', 'ddsa', 'mw'],
    "tiguṇa": ['cped'],
    "tihan": ['mw'],
    "tihapaṭicchanna": ['cped'],
    "tij": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tijila": ['mw'],
    "tijilaḥ": ['ap90'],
    "tijinaḥ": ['ap90'],
    "tik": ['ap90', 'mw'],
    "tika": ['cped', 'mw'],
    "tikaka": ['cped'],
    "tikakitava": ['mw'],
    "tikakitavādi": ['mw'],
    "tikanipāta": ['cped'],
    "tikhiṇa": ['cped'],
    "tikicchaka": ['cped'],
    "tikicchanta": ['cped'],
    "tikicchati": ['cped'],
    "tikicchi": ['cped'],
    "tikicchita": ['cped'],
    "tikicchituṁ": ['cped'],
    "tikicchā": ['cped'],
    "tikkha": ['cped'],
    "tikkhattuṁ": ['cped'],
    "tikkhindriya": ['cped'],
    "tikkhiṇa": ['cped'],
    "tikta": ['ap90', 'cae', 'ddsa', 'mw'],
    "tiktabhadraka": ['mw'],
    "tiktabījā": ['mw'],
    "tiktadhātu": ['mw'],
    "tiktadugdhā": ['mw'],
    "tiktagandhā": ['mw'],
    "tiktaghṛta": ['mw'],
    "tiktaguñjā": ['mw'],
    "tiktaka": ['ap90', 'mw'],
    "tiktakandakā": ['mw'],
    "tiktakandikā": ['mw'],
    "tiktakā": ['mw'],
    "tiktamarica": ['mw'],
    "tiktaparvan": ['mw'],
    "tiktapattra": ['mw'],
    "tiktaphala": ['mw'],
    "tiktaphalā": ['mw'],
    "tiktapuṣpā": ['mw'],
    "tiktarohiṇikā": ['mw'],
    "tiktarohiṇī": ['mw'],
    "tiktasāra": ['mw'],
    "tiktataṇḍulā": ['mw'],
    "tiktatumbī": ['mw'],
    "tiktatuṇḍī": ['mw'],
    "tiktavallī": ['mw'],
    "tiktayavā": ['mw'],
    "tiktaśāka": ['mw'],
    "tiktikā": ['mw'],
    "tiktā": ['mw'],
    "tiktākhyā": ['mw'],
    "tiktāmṛtā": ['mw'],
    "tiktāsya": ['mw'],
    "tiktāsyatā": ['mw'],
    "tiktāy": ['cae'],
    "tiktāya": ['mw'],
    "tiktāyana": ['mw'],
    "tiktāṅgā": ['mw'],
    "tikādi": ['mw'],
    "tikīya": ['mw'],
    "tikṣṇa": ['bhs'],
    "til": ['ap90', 'mw'],
    "tila": ['cae', 'cped', 'ddsa', 'mw'],
    "tilabhāra": ['mw'],
    "tilabhāvinī": ['mw'],
    "tilabhṛṣṭa": ['mw'],
    "tilacaturthī": ['mw'],
    "tilacitrapattraka": ['mw'],
    "tilacūrṇa": ['mw'],
    "tiladeśvaratīrtha": ['mw'],
    "tiladhenu": ['mw'],
    "tiladhenudāna": ['mw'],
    "tiladhenukā": ['mw'],
    "tiladroṇa": ['cae'],
    "tiladroṇamaya": ['mw'],
    "tiladvādaśī": ['mw'],
    "tilagañji": ['mw'],
    "tilagañjin": ['mw'],
    "tilagrāma": ['mw'],
    "tilahoma": ['mw'],
    "tilahomin": ['mw'],
    "tilaka": ['cae', 'ddsa', 'mw'],
    "tilakabhūta": ['cae'],
    "tilakaka": ['mw'],
    "tilakakka": ['cped'],
    "tilakakriyā": ['cae'],
    "tilakalatā": ['mw'],
    "tilakalka": ['mw'],
    "tilakalkaja": ['mw'],
    "tilakamañjarī": ['mw'],
    "tilakarāja": ['ddsa', 'mw'],
    "tilakasiṃha": ['mw'],
    "tilakavatī": ['mw'],
    "tilakavrata": ['mw'],
    "tilakay": ['cae'],
    "tilakaya": ['ddsa', 'mw'],
    "tilakaḥ": ['ap90'],
    "tilakaṇa": ['ddsa', 'mw'],
    "tilakaṭa": ['mw'],
    "tilakeśvaratīrtha": ['mw'],
    "tilakhali": ['mw'],
    "tilakhalī": ['mw'],
    "tilakin": ['mw'],
    "tilakita": ['ap90', 'mw'],
    "tilakiṭṭa": ['mw'],
    "tilakocavaka": ['bhs'],
    "tilakottara": ['mw'],
    "tilakā": ['mw'],
    "tilakācārya": ['mw'],
    "tilakāhata": ['cped'],
    "tilakālaka": ['mw'],
    "tilakārṣika": ['ddsa', 'mw'],
    "tilakāvala": ['mw'],
    "tilakāyate": ['ap90'],
    "tilakāyita": ['mw'],
    "tilakāśraya": ['mw'],
    "tilamaya": ['cae', 'mw'],
    "tilamayūra": ['mw'],
    "tilamiśla": ['cae', 'mw'],
    "tilamiśra": ['cae', 'mw'],
    "tilamāṣa": ['mw'],
    "tilaparṇa": ['cae', 'mw'],
    "tilaparṇaka": ['mw'],
    "tilaparṇika": ['cae', 'mw'],
    "tilaparṇikā": ['cae', 'mw'],
    "tilaparṇī": ['cae', 'mw'],
    "tilapeja": ['mw'],
    "tilapiccaṭa": ['mw'],
    "tilapiñja": ['mw'],
    "tilapiñjī": ['mw'],
    "tilaprada": ['cae'],
    "tilapuṣpa": ['mw'],
    "tilapuṣpaka": ['mw'],
    "tilapīḍa": ['cae', 'mw'],
    "tilarasa": ['mw'],
    "tilasambaddha": ['mw'],
    "tilasarṣapa": ['cae'],
    "tilasaṃbaddha": ['cae'],
    "tilasaṅguḷikā": ['cped'],
    "tilasneha": ['mw'],
    "tilasnāyin": ['mw'],
    "tilasṛṣṭa": ['mw'],
    "tilataila": ['cae', 'mw'],
    "tilataṇḍulaka": ['mw'],
    "tilatejāhvā": ['mw'],
    "tilatela": ['cped'],
    "tilaudana": ['cae', 'mw'],
    "tilavatsa": ['mw'],
    "tilavratin": ['mw'],
    "tilaśama": ['mw'],
    "tilaśas": ['cae', 'ddsa', 'mw'],
    "tilaśaḥ": ['ap90'],
    "tilaśikhin": ['mw'],
    "tilaḥ": ['ap90'],
    "tilaṃtuda": ['mw'],
    "tilaṃtudaḥ": ['ap90'],
    "tilitsa": ['mw'],
    "tilitsaka": ['mw'],
    "tilitsaḥ": ['ap90'],
    "tiliṅga": ['cae', 'ddsa', 'mw'],
    "tiliṅgadeśa": ['cae'],
    "till": ['mw'],
    "tilodaka": ['cae', 'mw'],
    "tilodakin": ['mw'],
    "tilodana": ['cae', 'ddsa', 'mw'],
    "tilodara": ['mw'],
    "tilottamā": ['cae', 'ddsa', 'mw'],
    "tilottamīya": ['mw'],
    "tilpilika": ['mw'],
    "tilpiñja": ['cae', 'mw'],
    "tilva": ['mw'],
    "tilvaka": ['cae', 'ddsa', 'mw'],
    "tilvarīka": ['mw'],
    "tilvaḥ": ['ap90'],
    "tilvila": ['cae', 'ddsa', 'gra', 'mw'],
    "tilvilāy": ['gra'],
    "tilvilāya": ['mw'],
    "tilvilīka": ['mw'],
    "tilvirīka": ['mw'],
    "tilya": ['ap90', 'mw'],
    "tilāmbu": ['cae', 'mw'],
    "tilānna": ['mw'],
    "tilāpatyā": ['mw'],
    "tilāṃśa": ['ddsa', 'mw'],
    "tilāṅkitadala": ['mw'],
    "tim": ['ap90', 'cae', 'ddsa', 'mw'],
    "tima": ['mw'],
    "timaṇḍala": ['cped'],
    "timbaruka": ['cped'],
    "timbarusaka": ['cped'],
    "timbarutthanī": ['cped'],
    "timbarūsaka": ['cped'],
    "timi": ['cae', 'cped', 'ddsa', 'mw'],
    "timidhvaja": ['mw'],
    "timighātin": ['mw'],
    "timija": ['mw'],
    "timikośa": ['mw'],
    "timilā": ['mw'],
    "timimālin": ['mw'],
    "timira": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "timiracchid": ['mw'],
    "timiramaya": ['mw'],
    "timiramayaḥ": ['ap90'],
    "timiranayana": ['mw'],
    "timiranud": ['mw'],
    "timiranāśana": ['mw'],
    "timirapaṭala": ['mw'],
    "timirapiṅgala": ['cped'],
    "timirapratiṣedha": ['mw'],
    "timiraripu": ['mw'],
    "timiratā": ['mw'],
    "timiraugha": ['cae', 'ddsa', 'mw'],
    "timiravana": ['mw'],
    "timiray": ['cae'],
    "timiraya": ['ddsa', 'mw'],
    "timirayati": ['ap90'],
    "timirgha": ['mw'],
    "timiri": ['mw'],
    "timirin": ['ap90', 'mw'],
    "timirodghāṭa": ['mw'],
    "timirā": ['mw'],
    "timirākula": ['ddsa', 'mw'],
    "timirākulatā": ['mw'],
    "timirāpagata": ['bhs', 'mw'],
    "timirāpaha": ['mw'],
    "timirāri": ['mw'],
    "timirāriripu": ['mw'],
    "timirāya": ['mw'],
    "timirāyate": ['ap90'],
    "timirāyita": ['cped'],
    "timirāyitatta": ['cped'],
    "timirīkṛta": ['bhs'],
    "timisa": ['cped'],
    "timisikā": ['bhs'],
    "timisrā": ['bhs'],
    "timisrāyitatva": ['bhs'],
    "timissā": ['cped'],
    "timita": ['ap90', 'mw'],
    "timitimiṃgila": ['mw'],
    "timitimiṅgila": ['bhs'],
    "timiśa": ['mw'],
    "timiśatru": ['mw'],
    "timiḥ": ['ap90'],
    "timiṃgila": ['cae', 'mw'],
    "timiṃgilagila": ['cae', 'mw'],
    "timiṃgilaḥ": ['ap90'],
    "timiṃgilāśana": ['mw'],
    "timiṃgira": ['mw'],
    "timiṅgala": ['bhs', 'cped'],
    "timiṅgila": ['cped', 'ddsa'],
    "timiṅgira": ['bhs'],
    "timiṣa": ['mw'],
    "timmaya": ['mw'],
    "timī": ['mw'],
    "timīra": ['mw'],
    "timīsa": ['cped'],
    "timīsaka": ['bhs'],
    "timīsā": ['cped'],
    "timūlaka": ['cped'],
    "timūlika": ['cped'],
    "tindinī": ['mw'],
    "tindiśa": ['mw'],
    "tindu": ['mw'],
    "tindubilva": ['mw'],
    "tinduka": ['cae', 'ddsa', 'mw'],
    "tindukhāṇu": ['cped'],
    "tinduki": ['mw'],
    "tindukinī": ['mw'],
    "tindukācīra": ['cped'],
    "tindukālāta": ['cped'],
    "tindukī": ['mw'],
    "tindula": ['mw'],
    "tinikā": ['mw'],
    "tiniśa": ['cae', 'mw'],
    "tiniśaḥ": ['ap90'],
    "tintilikā": ['mw'],
    "tintilī": ['mw'],
    "tintilīka": ['mw'],
    "tintilīkā": ['mw'],
    "tintina": ['cped'],
    "tintiḍa": ['ddsa', 'mw'],
    "tintiḍikā": ['cae', 'mw'],
    "tintiḍī": ['cae', 'mw'],
    "tintiḍīdyūta": ['mw'],
    "tintiḍīka": ['mw'],
    "tintiḍīphala": ['mw'],
    "tintiṇa": ['cped'],
    "tināśaka": ['mw'],
    "tip": ['ap90', 'mw'],
    "tipada": ['cped'],
    "tipakkhavasana": ['cped'],
    "tipeṭaka": ['cped'],
    "tipeṭaki(n)": ['cped'],
    "tiporisa": ['cped'],
    "tiporisaṁ": ['cped'],
    "tippa": ['cped'],
    "tipu": ['cped'],
    "tipurisa": ['cped'],
    "tipya": ['ddsa', 'mw'],
    "tipyaka": ['bhs'],
    "tir": ['gra'],
    "tira": ['ddsa'],
    "tiraccha": ['bhs', 'cped'],
    "tiracchayoni": ['cped'],
    "tiracchāna": ['bhs', 'cped'],
    "tiracchānagata": ['cped'],
    "tiracchānakathika": ['cped'],
    "tiracchānakathā": ['cped'],
    "tiracchānavijjā": ['cped'],
    "tiracchānayoni": ['cped'],
    "tiracchānayonigamanīya": ['cped'],
    "tiracchānayonigāmi(n)": ['cped'],
    "tiracchānayonika": ['cped'],
    "tiraka": ['bhs'],
    "tiras": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "tirasahnia": ['gra'],
    "tirasahnya": ['gra'],
    "tiraskara": ['ap90', 'cae', 'ddsa', 'mw'],
    "tiraskaraṇi": ['mw'],
    "tiraskarin": ['cae', 'mw'],
    "tiraskariṇī": ['ap90', 'mw'],
    "tiraskriyā": ['mw'],
    "tiraskuḍya": ['mw'],
    "tiraskāra": ['cae', 'mw'],
    "tiraskāraḥ": ['ap90'],
    "tiraskārin": ['mw'],
    "tiraskāriṇī": ['ap90', 'mw'],
    "tiraskṛ": ['ap90', 'mw'],
    "tiraskṛta": ['ap90', 'mw'],
    "tiraskṛtaprātiveśya": ['mw'],
    "tiraskṛtasambhāṣa": ['mw'],
    "tiraskṛti": ['cae', 'mw'],
    "tiraspaṭa": ['mw'],
    "tirasprākāra": ['mw'],
    "tirasya": ['mw'],
    "tirasyati": ['ap90'],
    "tiray": ['cae'],
    "tiraya": ['ddsa', 'mw'],
    "tirayati": ['ap90'],
    "tiraśc": ['ddsa', 'mw'],
    "tiraśca": ['mw'],
    "tiraścathā": ['mw'],
    "tiraścatā": ['gra', 'mw'],
    "tiraści": ['mw'],
    "tiraścikā": ['mw'],
    "tiraścirāji": ['mw'],
    "tiraścya": ['mw'],
    "tiraścā": ['mw'],
    "tiraścī": ['ap90', 'gra', 'mw'],
    "tiraścīna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tiraścīnanidhana": ['mw'],
    "tiraścīnapṛśni": ['mw'],
    "tiraścīnavaṃśa": ['cae', 'mw'],
    "tiraścīnavāya": ['mw'],
    "tiraḥ": ['mw'],
    "tiraḥkṛ": ['mw'],
    "tiraḥprātiveśya": ['mw'],
    "tiriac": ['gra'],
    "tiriccha": ['bhs'],
    "tiricchāna": ['bhs'],
    "tirigicchi": ['mw'],
    "tirijihvika": ['mw'],
    "tirima": ['mw'],
    "tirindira": ['gra', 'mw'],
    "tiriya": ['mw'],
    "tiriyaṁ": ['cped'],
    "tiriyaṁtaraṇā": ['cped'],
    "tiriyaṅgama": ['cped'],
    "tiriyā": ['cped'],
    "tiriṇīkaṇṭa": ['mw'],
    "tiriṭa": ['mw'],
    "tiriṭi": ['mw'],
    "tiro": ['mw'],
    "tiroahniya": ['mw'],
    "tiroahnya": ['cae', 'gra', 'mw'],
    "tirobhavitṛ": ['mw'],
    "tirobhāva": ['cped', 'mw'],
    "tirobhāvaḥ": ['ap90'],
    "tirobhū": ['ap90', 'mw'],
    "tirobhūta": ['cae'],
    "tirodhā": ['ap90', 'cae', 'mw'],
    "tirodhāna": ['cae', 'mw'],
    "tirodhānaṃ": ['ap90'],
    "tirodhātavya": ['ddsa', 'mw'],
    "tirodussantena": ['cped'],
    "tirogata": ['mw'],
    "tirogāma": ['cped'],
    "tirogāmaka": ['cped'],
    "tirohayati": ['ap90'],
    "tirohita": ['ap90', 'cae', 'mw'],
    "tirohitatva": ['mw'],
    "tirohitatā": ['mw'],
    "tirohnya": ['cae', 'mw'],
    "tirojanam": ['cae', 'mw'],
    "tirojanapada": ['cped'],
    "tirokaraṇī": ['cped'],
    "tirokkha": ['cped'],
    "tirokucchigata": ['cped'],
    "tirokuḍḍamhi": ['cped'],
    "tirokuḍḍaṁ": ['cped'],
    "tirokuḍḍe": ['cped'],
    "tirokuḍḍā": ['cped'],
    "tiropabbataṁ": ['cped'],
    "tiropākāra": ['cped'],
    "tiroraṭṭha": ['cped'],
    "tirorāja(n)": ['cped'],
    "tirovarṣa": ['mw'],
    "tirpirika": ['mw'],
    "tirumaleśa": ['mw'],
    "tiruvānandapura": ['mw'],
    "tirya": ['bhs', 'mw'],
    "tiryac": ['ap90', 'gra'],
    "tiryadryañc": ['mw'],
    "tiryag": ['mw'],
    "tiryaga": ['mw'],
    "tiryagantara": ['mw'],
    "tiryaganūka": ['mw'],
    "tiryagapaccheda": ['mw'],
    "tiryagapāṅga": ['mw'],
    "tiryagayana": ['mw'],
    "tiryagbhedā": ['mw'],
    "tiryagbila": ['mw'],
    "tiryagdhāra": ['mw'],
    "tiryagdiś": ['mw'],
    "tiryagga": ['cae', 'mw'],
    "tiryaggama": ['mw'],
    "tiryaggamana": ['mw'],
    "tiryaggata": ['cae', 'mw'],
    "tiryaggati": ['cae', 'mw'],
    "tiryaggatimatin": ['mw'],
    "tiryagghātin": ['mw'],
    "tiryaggrīvam": ['mw'],
    "tiryagguṇana": ['mw'],
    "tiryaggāmin": ['mw'],
    "tiryagja": ['cae', 'mw'],
    "tiryagjana": ['cae', 'mw'],
    "tiryagjyā": ['mw'],
    "tiryagjāti": ['mw'],
    "tiryaglokadhātu": ['bhs'],
    "tiryagnāsa": ['mw'],
    "tiryagvalana": ['cae', 'mw'],
    "tiryagviddha": ['mw'],
    "tiryagvisaṃsarpin": ['mw'],
    "tiryagvātasevā": ['mw'],
    "tiryagyavodara": ['mw'],
    "tiryagyona": ['cae', 'mw'],
    "tiryagyoni": ['cae', 'mw'],
    "tiryagyonigamana": ['mw'],
    "tiryagyonika": ['bhs'],
    "tiryagyoninyanvaya": ['mw'],
    "tiryagyonyanvaya": ['mw'],
    "tiryagyāna": ['mw'],
    "tiryagyāta": ['mw'],
    "tiryagāgata": ['mw'],
    "tiryagākṛti": ['mw'],
    "tiryagāyata": ['cae', 'ddsa', 'mw'],
    "tiryagīkṣa": ['mw'],
    "tiryagīśa": ['mw'],
    "tiryagḍīna": ['mw'],
    "tiryak": ['ap90', 'bhs', 'mw'],
    "tiryakkāma": ['bhs'],
    "tiryakkāram": ['mw'],
    "tiryakkṛtya": ['mw'],
    "tiryakkṣipta": ['mw'],
    "tiryakphalā": ['mw'],
    "tiryakpramāṇa": ['mw'],
    "tiryakpratimukhāgata": ['cae', 'mw'],
    "tiryakprekṣaṇa": ['mw'],
    "tiryakprekṣin": ['mw'],
    "tiryakpātana": ['mw'],
    "tiryakpātin": ['mw'],
    "tiryaksrotas": ['mw'],
    "tiryaksūtra": ['mw'],
    "tiryaktva": ['mw'],
    "tiryaktā": ['ap90', 'cae', 'ddsa', 'mw'],
    "tiryañc": ['cae', 'ddsa', 'mw'],
    "tiryaṅ": ['mw'],
    "tiryaṅmānī": ['mw'],
    "tiryaṅniraya": ['mw'],
    "tiryaṅnāsa": ['mw'],
    "tirīcīna": ['mw'],
    "tirīṭa": ['cae', 'cped', 'mw'],
    "tirīṭaka": ['cped', 'mw'],
    "tirīṭin": ['mw'],
    "tirīṭī": ['bhs'],
    "tisahassa": ['cped'],
    "tisata": ['cped'],
    "tisattati": ['cped'],
    "tisaṃlayana": ['bhs'],
    "tisraloka": ['bhs'],
    "tisraskāram": ['mw'],
    "tisrā": ['mw'],
    "tisṛ": ['cae', 'ddsa', 'mw'],
    "tisṛdhanva": ['mw'],
    "tisṛkā": ['mw'],
    "titaniṣu": ['mw'],
    "titau": ['cae', 'gra', 'mw'],
    "titauḥ": ['ap90'],
    "titha": ['mw'],
    "tithaḥ": ['ap90'],
    "tithi": ['cae', 'ddsa', 'mw'],
    "tithidevatā": ['mw'],
    "tithidvaidhaprakaraṇa": ['mw'],
    "tithidvaita": ['mw'],
    "tithidāna": ['mw'],
    "tithikṣaya": ['mw'],
    "tithinirṇaya": ['mw'],
    "tithinirṇayasaṃgraha": ['mw'],
    "tithinirṇayasaṃkṣepa": ['mw'],
    "tithinirṇayasāra": ['mw'],
    "tithiniyama": ['mw'],
    "tithipati": ['mw'],
    "tithipattrī": ['mw'],
    "tithiprakaraṇa": ['mw'],
    "tithipralaya": ['mw'],
    "tithipraṇī": ['mw'],
    "tithipālana": ['mw'],
    "tithisāraṇikā": ['mw'],
    "tithitattva": ['mw'],
    "tithiviveka": ['mw'],
    "tithivārayoga": ['mw'],
    "tithiḥ": ['ap90'],
    "tithy": ['mw'],
    "tithyantanirṇaya": ['mw'],
    "tithyardha": ['mw'],
    "tithī": ['mw'],
    "tithīśa": ['mw'],
    "titibha": ['mw'],
    "titibhaḥ": ['ap90'],
    "titikkhati": ['cped'],
    "titikkhā": ['cped'],
    "titikkhācammasannāha": ['cped'],
    "titikṣa": ['mw'],
    "titikṣita": ['mw'],
    "titikṣu": ['ap90', 'mw'],
    "titikṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "titila": ['mw'],
    "titiraḥ": ['ap90'],
    "titiri": ['mw'],
    "titiru": ['mw'],
    "titta": ['cped'],
    "tittaka": ['cped'],
    "tittalābu": ['cped'],
    "tittha": ['cped'],
    "titthakara": ['cped'],
    "titthika": ['cped'],
    "titthiya": ['cped'],
    "titthiya(d)dhaja": ['cped'],
    "titthiyapakkantaka": ['cped'],
    "titthāyatana": ['cped'],
    "titti": ['cped'],
    "tittika": ['cped'],
    "tittira": ['cae', 'cped', 'ddsa', 'mw'],
    "tittiraja": ['mw'],
    "tittirapattika": ['cped'],
    "tittiravallara": ['mw'],
    "tittiri": ['cae', 'ddsa', 'mw'],
    "tittirika": ['mw'],
    "tittirikaḥ": ['ap90'],
    "tittiritva": ['mw'],
    "tittiriya": ['cped'],
    "tittiriḥ": ['ap90'],
    "tittirāṅga": ['mw'],
    "tittirīka": ['ap90'],
    "tittirīphala": ['mw'],
    "tittiḍa": ['mw'],
    "tittiḍīka": ['mw'],
    "tittākagga": ['cped'],
    "tittālābu": ['cped'],
    "titāla": ['cped'],
    "titālaṁ": ['cped'],
    "titīla": ['bhs', 'mw'],
    "titīrṣu": ['ap90', 'mw'],
    "titīrṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "tivagga": ['cped'],
    "tividha": ['cped'],
    "tividhaṁ": ['cped'],
    "tividhena": ['cped'],
    "tividhenūpaparikkhi(n)": ['cped'],
    "tivisākha": ['cped'],
    "tivya": ['ddsa', 'mw'],
    "tiyaddha": ['cped'],
    "tiyojana": ['cped'],
    "tiyojanasatika": ['cped'],
    "tiṁsa": ['cped'],
    "tiṁsati": ['cped'],
    "tiṁsavassika": ['cped'],
    "tiṁsaṁ": ['cped'],
    "tiṃdukaṃ": ['ap90'],
    "tiṃduḥ": ['ap90'],
    "tiṃtilī": ['ap90'],
    "tiṃtiḍaḥ": ['ap90'],
    "tiṅ": ['ddsa', 'mw'],
    "tiṅanta": ['mw'],
    "tiṅsubantacaya": ['mw'],
    "tiṇa": ['cped'],
    "tiṇabhakkha": ['cped'],
    "tiṇabhisi": ['cped'],
    "tiṇagahana": ['cped'],
    "tiṇagahaṇa": ['cped'],
    "tiṇahāraka": ['cped'],
    "tiṇahāri": ['cped'],
    "tiṇakaṭṭhapaṇṇakasaṭa": ['cped'],
    "tiṇakaṭṭhapaṇṇasaṭa": ['cped'],
    "tiṇapurisa": ['cped'],
    "tiṇapurisaka": ['cped'],
    "tiṇasanthara": ['cped'],
    "tiṇasantharaka": ['cped'],
    "tiṇasanthāra": ['cped'],
    "tiṇasanthāraka": ['cped'],
    "tiṇava": ['cped'],
    "tiṇavatthāraka": ['cped'],
    "tiṇaṇḍupaka": ['cped'],
    "tiṇaṇḍūpaka": ['cped'],
    "tiṇha": ['cped'],
    "tiṇhadhāra": ['cped'],
    "tiṇhaphala": ['cped'],
    "tiṇisa": ['mw'],
    "tiṇukkā": ['cped'],
    "tiṇṇa": ['cped'],
    "tiṇṭī": ['mw'],
    "tiṣia": ['gra'],
    "tiṣya": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "tiṣyagupta": ['mw'],
    "tiṣyaka": ['mw'],
    "tiṣyakaḥ": ['ap90'],
    "tiṣyaketu": ['mw'],
    "tiṣyaphalā": ['mw'],
    "tiṣyapunarvasavīya": ['mw'],
    "tiṣyapunarvasu": ['mw'],
    "tiṣyapuṣpā": ['mw'],
    "tiṣyarakṣitā": ['bhs', 'mw'],
    "tiṣyā": ['mw'],
    "tiṣyāmratīrtha": ['mw'],
    "tiṣyāpūrṇamāsa": ['mw'],
    "tiṣṭhad": ['mw'],
    "tiṣṭhaddhoma": ['mw'],
    "tiṣṭhaddhomaḥ": ['ap90'],
    "tiṣṭhadgu": ['ap90', 'mw'],
    "tiṣṭhantika": ['bhs'],
    "tiṣṭhatu": ['bhs'],
    "tiṣṭhavākya": ['bhs'],
    "tiṭibha": ['mw'],
    "tiṭilambha": ['bhs', 'mw'],
    "tiṭṭha": ['cped'],
    "tiṭṭha(t)": ['cped'],
    "tiṭṭhabhadantika": ['cped'],
    "tiṭṭhabhaddantika": ['cped'],
    "tiṭṭhamha": ['cped'],
    "tiṭṭhamāna": ['cped'],
    "tiṭṭhanta": ['cped'],
    "tiṭṭhantu": ['cped'],
    "tiṭṭhati": ['cped'],
    "tiṭṭhatu": ['cped'],
    "tiṭṭhaṁasu": ['cped'],
    "tiṭṭhissanti": ['cped'],
    "tiṭṭhituṁ": ['cped'],
    "tiṭṭhiṁsu": ['cped'],
    "tiṭṭhāhi": ['cped'],
    "tman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tmanyā": ['mw'],
    "tmanā": ['mw'],
    "tmanī": ['gra'],
    "toda": ['cae', 'ddsa', 'gra', 'mw'],
    "todana": ['cae', 'mw'],
    "todanaṃ": ['ap90'],
    "todaparṇī": ['mw'],
    "todaḥ": ['ap90'],
    "todeya": ['bhs'],
    "todita": ['mw'],
    "todya": ['cae', 'mw'],
    "toka": ['cae', 'ddsa', 'gra', 'mw'],
    "tokakaḥ": ['ap90'],
    "tokasāti": ['cae', 'gra', 'mw'],
    "tokatā": ['mw'],
    "tokavat": ['gra', 'mw'],
    "tokavatī": ['mw'],
    "tokaṃ": ['ap90'],
    "tokinī": ['cae', 'mw'],
    "tokma": ['cae', 'ddsa', 'mw'],
    "tokman": ['gra', 'mw'],
    "tokmaḥ": ['ap90'],
    "tokāya": ['mw'],
    "tola": ['ap90', 'mw'],
    "tolaka": ['ddsa', 'mw'],
    "tolana": ['cae', 'ddsa', 'mw'],
    "tolanaṃ": ['ap90'],
    "tolaḥ": ['ap90'],
    "toleti": ['cped'],
    "toleyati": ['cped'],
    "tolikā": ['mw'],
    "tolya": ['ap90', 'cae', 'mw'],
    "tolā": ['mw'],
    "tomara": ['bhs', 'cae', 'ddsa', 'mw'],
    "tomaradhara": ['mw'],
    "tomaragraha": ['bhs', 'mw'],
    "tomarahattha": ['cped'],
    "tomaraḥ": ['ap90'],
    "tomarikā": ['ap90', 'mw'],
    "tomarāṇa": ['ddsa', 'mw'],
    "toragrīva": ['bhs'],
    "toramāṇa": ['mw'],
    "toraṇa": ['cae', 'cped', 'ddsa', 'mw'],
    "toraṇamāla": ['mw'],
    "toraṇaḥ": ['ap90'],
    "toraṇā": ['bhs'],
    "tosala": ['bhs', 'mw'],
    "tosaliputra": ['mw'],
    "tosana": ['cped'],
    "tosayī": ['cped'],
    "tosesi": ['cped'],
    "tosetvā": ['cped'],
    "tosita": ['cped'],
    "tosun": ['ddsa'],
    "totala": ['mw'],
    "totalā": ['mw'],
    "tote": ['mw'],
    "totilā": ['mw'],
    "toto": ['mw'],
    "totraṃ": ['ap90'],
    "tottalā": ['mw'],
    "tottra": ['cae', 'mw'],
    "tottraprajita": ['mw'],
    "tottraṃ": ['ap90'],
    "tottāyana": ['mw'],
    "tot‍tra": ['ddsa'],
    "toya": ['cae', 'cped', 'ddsa', 'mw'],
    "toyacara": ['cae', 'mw'],
    "toyada": ['cae', 'mw'],
    "toyadhara": ['cae', 'mw'],
    "toyadhi": ['cae', 'mw'],
    "toyadhipriya": ['mw'],
    "toyadhāra": ['cae', 'mw'],
    "toyadhārā": ['mw'],
    "toyadāna": ['mw'],
    "toyadātyaya": ['cae', 'mw'],
    "toyagarbha": ['mw'],
    "toyaja": ['cae', 'mw'],
    "toyajākṣī": ['mw'],
    "toyakarman": ['cae', 'mw'],
    "toyakaṇa": ['cae', 'ddsa', 'mw'],
    "toyakrīḍā": ['mw'],
    "toyakumbhā": ['mw'],
    "toyakāma": ['mw'],
    "toyakṛcchra": ['mw'],
    "toyakṛt": ['mw'],
    "toyamala": ['mw'],
    "toyamaya": ['cae', 'mw'],
    "toyamuc": ['cae', 'mw'],
    "toyanidhi": ['mw'],
    "toyanīvī": ['mw'],
    "toyaphalā": ['mw'],
    "toyapippalī": ['mw'],
    "toyaprasādana": ['mw'],
    "toyapraṣṭhā": ['mw'],
    "toyapuṣpī": ['mw'],
    "toyapāta": ['cae', 'mw'],
    "toyapāṣāṇajamala": ['mw'],
    "toyarasa": ['mw'],
    "toyarāj": ['cae', 'mw'],
    "toyarāśi": ['cae', 'mw'],
    "toyasarpikā": ['mw'],
    "toyasūcaka": ['mw'],
    "toyavallikā": ['mw'],
    "toyavallī": ['mw'],
    "toyavat": ['mw'],
    "toyavatī": ['mw'],
    "toyavyatikara": ['mw'],
    "toyavāha": ['cae', 'mw'],
    "toyavṛkṣa": ['mw'],
    "toyavṛtti": ['mw'],
    "toyayantra": ['mw'],
    "toyaśuktikā": ['mw'],
    "toyaśūka": ['mw'],
    "toyaḍimba": ['mw'],
    "toyaḍimbha": ['mw'],
    "toyaṃ": ['ap90'],
    "toyeśa": ['mw'],
    "toyikā": ['bhs', 'mw'],
    "toyodbhavā": ['mw'],
    "toyotsarga": ['mw'],
    "toyādhivāsinī": ['mw'],
    "toyādhāra": ['cae', 'mw'],
    "toyāgni": ['ddsa', 'mw'],
    "toyāhāra": ['mw'],
    "toyālaya": ['cae', 'mw'],
    "toyāmbudhi": ['mw'],
    "toyāpāmārga": ['mw'],
    "toyāñjali": ['cae', 'mw'],
    "toyāśaya": ['cae', 'mw'],
    "tośa": ['cae', 'gra', 'mw'],
    "tośas": ['cae', 'gra', 'mw'],
    "toḍ": ['ap90', 'mw'],
    "toḍalatantra": ['mw'],
    "toḍana": ['mw'],
    "toḍanaṃ": ['ap90'],
    "toḍarānanda": ['mw'],
    "toḍikā": ['mw'],
    "toḍī": ['mw'],
    "toṇehāra": ['bhs'],
    "toṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "toṣaka": ['mw'],
    "toṣalaṃ": ['ap90'],
    "toṣayitavya": ['cae', 'mw'],
    "toṣayitṛ": ['mw'],
    "toṣaḥ": ['ap90'],
    "toṣaṇa": ['ap90', 'cae', 'mw'],
    "toṣaṇā": ['bhs'],
    "toṣaṇī": ['mw'],
    "toṣaṇīya": ['bhs', 'cae', 'mw'],
    "toṣin": ['ap90', 'cae', 'mw'],
    "toṣita": ['ap90', 'mw'],
    "toṣya": ['mw'],
    "toṭaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "toṭṭhabba": ['cped'],
    "tra": ['mw'],
    "trada": ['cae', 'gra', 'mw'],
    "trai": ['ap90', 'mw'],
    "traibali": ['mw'],
    "traibhāvya": ['mw'],
    "traicīvarika": ['bhs', 'mw'],
    "traidaśika": ['ap90', 'cae', 'ddsa', 'mw'],
    "traidaṇḍika": ['bhs'],
    "traidha": ['ap90', 'mw'],
    "traidham": ['cae', 'ddsa', 'mw'],
    "traidhātavyā": ['mw'],
    "traidhātavī": ['mw'],
    "traidhātavīya": ['mw'],
    "traidhātavīyā": ['mw'],
    "traidhātuka": ['bhs', 'mw'],
    "traidhātukasamatā": ['mw'],
    "traidhātva": ['mw'],
    "traigarta": ['ddsa', 'mw'],
    "traigartaka": ['mw'],
    "traigartāyana": ['mw'],
    "traigartāyanaka": ['mw'],
    "traigartī": ['mw'],
    "traiguṇika": ['ap90', 'mw'],
    "traiguṇya": ['cae', 'ddsa', 'mw'],
    "traiguṇyavat": ['mw'],
    "traiguṇyaṃ": ['ap90'],
    "traihāyaṇa": ['cae', 'mw'],
    "traikakakubha": ['mw'],
    "traikakuda": ['mw'],
    "traikaṇṭaka": ['mw'],
    "traikuntaka": ['bhs', 'mw'],
    "traikālika": ['ap90', 'cae', 'ddsa', 'mw'],
    "traikālya": ['cae', 'mw'],
    "traikālyadarśin": ['cae'],
    "traikālyaṃ": ['ap90'],
    "trailiṅga": ['mw'],
    "trailiṅgya": ['cae', 'mw'],
    "trailocana": ['mw'],
    "trailokaḥ": ['ap90'],
    "trailokya": ['cae', 'ddsa', 'mw'],
    "trailokyabandhu": ['mw'],
    "trailokyabhayakāraka": ['mw'],
    "trailokyacintāmaṇirasa": ['mw'],
    "trailokyadarśin": ['cae'],
    "trailokyadevī": ['mw'],
    "trailokyadīpikā": ['mw'],
    "trailokyakartṛ": ['mw'],
    "trailokyamālin": ['mw'],
    "trailokyanātha": ['mw'],
    "trailokyaprabhava": ['mw'],
    "trailokyaprabhā": ['mw'],
    "trailokyaprakāśa": ['mw'],
    "trailokyarāja": ['mw'],
    "trailokyarājya": ['cae', 'mw'],
    "trailokyasundara": ['mw'],
    "trailokyasundarī": ['mw'],
    "trailokyasāgara": ['mw'],
    "trailokyasāra": ['mw'],
    "trailokyavajra": ['bhs'],
    "trailokyavaśaṃkara": ['bhs'],
    "trailokyavijaya": ['bhs'],
    "trailokyavijayā": ['mw'],
    "trailokyavikramin": ['mw'],
    "trailokyavikrāmin": ['bhs'],
    "trailokyaḍambara": ['mw'],
    "trailokyaṃ": ['ap90'],
    "trailokyādhipatitva": ['mw'],
    "trailokyādhipatya": ['mw'],
    "trailāṭa": ['mw'],
    "trailāṭaka": ['bhs'],
    "trailāṭā": ['bhs'],
    "traimāsa": ['bhs'],
    "traimāsika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "traimāsya": ['mw'],
    "traimāsyaṃ": ['ap90'],
    "traimāsī": ['mw'],
    "traimātura": ['mw'],
    "traimāturaḥ": ['ap90'],
    "trainiṣkika": ['ap90', 'mw'],
    "traipada": ['cae', 'ddsa', 'mw'],
    "traipakṣika": ['mw'],
    "traipatha": ['mw'],
    "traiphala": ['mw'],
    "traipiṣṭapa": ['mw'],
    "traipura": ['cae', 'ddsa', 'mw'],
    "traipuraḥ": ['ap90'],
    "traipuruṣa": ['ap90', 'mw'],
    "traipurīya": ['mw'],
    "traipārāyaṇika": ['mw'],
    "trairātrika": ['mw'],
    "trairāśika": ['mw'],
    "trairāśikaṃ": ['ap90'],
    "trairāśya": ['mw'],
    "trairūpya": ['cae', 'ddsa', 'mw'],
    "traisamika": ['mw'],
    "traisrotasa": ['cae', 'ddsa', 'mw'],
    "traisvarya": ['cae', 'mw'],
    "traisānu": ['mw'],
    "traita": ['cae', 'mw'],
    "traitana": ['cae', 'gra', 'mw'],
    "traitaṃ": ['ap90'],
    "traitīyaka": ['bhs'],
    "traivaidika": ['bhs'],
    "traivargika": ['ap90', 'cae', 'ddsa', 'mw'],
    "traivargya": ['cae', 'mw'],
    "traivarṇa": ['mw'],
    "traivarṇika": ['ap90', 'ddsa', 'mw'],
    "traivarṣika": ['ap90', 'cae', 'mw'],
    "traivaṇa": ['mw'],
    "traivaṇi": ['cae', 'mw'],
    "traivaṇīya": ['mw'],
    "traivedika": ['cae', 'mw'],
    "traivida": ['mw'],
    "traividhya": ['cae', 'mw'],
    "traividhyaṃ": ['ap90'],
    "traividya": ['bhs', 'cae', 'mw'],
    "traividyaka": ['mw'],
    "traividyaṃ": ['ap90'],
    "traivikrama": ['ap90', 'mw'],
    "traivikramī": ['mw'],
    "traiviṣṭapa": ['cae', 'mw'],
    "traiviṣṭapaḥ": ['ap90'],
    "traiviṣṭapeya": ['cae', 'mw'],
    "traivārṣika": ['cae', 'mw'],
    "traivṛta": ['mw'],
    "traivṛṣṇa": ['gra', 'mw'],
    "traiyadhvika": ['bhs'],
    "traiyakṣa": ['mw'],
    "traiyalinda": ['mw'],
    "traiyambaka": ['cae', 'ddsa', 'mw'],
    "traiyambakamantra": ['mw'],
    "traiyambakasaras": ['mw'],
    "traiyāhāvaka": ['mw'],
    "traiśabdya": ['mw'],
    "traiśaṃkavaḥ": ['ap90'],
    "traiśaṅkava": ['mw'],
    "traiśoka": ['mw'],
    "traiśāli": ['mw'],
    "traiśāmba": ['mw'],
    "traiśāni": ['mw'],
    "traiśāṇa": ['mw'],
    "traiśīrṣa": ['mw'],
    "traiśṛṅga": ['mw'],
    "traiṃśa": ['mw'],
    "traiṃśika": ['mw'],
    "traiṣṭubha": ['cae', 'ddsa', 'gra', 'mw'],
    "trakh": ['mw'],
    "tramidā": ['bhs'],
    "trand": ['mw'],
    "trap": ['ap90', 'cae', 'ddsa', 'mw'],
    "trapa": ['cae'],
    "trapita": ['ap90'],
    "trapiṣṭha": ['ap90', 'mw'],
    "trapsya": ['mw'],
    "trapsyaṃ": ['ap90'],
    "trapu": ['ap90', 'cae', 'ddsa', 'mw'],
    "trapukarkaṭī": ['mw'],
    "trapukarṇin": ['bhs', 'mw'],
    "trapula": ['mw'],
    "trapulaṃ": ['ap90'],
    "trapupaṭṭa": ['mw'],
    "trapupaṭṭikā": ['mw'],
    "trapus": ['cae', 'mw'],
    "trapusa": ['mw'],
    "trapusī": ['mw'],
    "trapuṣa": ['bhs', 'mw'],
    "trapā": ['ap90', 'ddsa', 'mw'],
    "trapāhīna": ['mw'],
    "trapāka": ['mw'],
    "trapānvita": ['mw'],
    "trapāraṇḍā": ['mw'],
    "trapāvat": ['mw'],
    "trapāyukta": ['mw'],
    "trapīyas": ['ap90', 'mw'],
    "tras": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "trasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "trasacchidra": ['bhs'],
    "trasadasyu": ['cae', 'gra', 'mw'],
    "trasaddasyu": ['mw'],
    "trasana": ['mw'],
    "trasanaṃ": ['ap90'],
    "trasara": ['cae', 'mw'],
    "trasaraḥ": ['ap90'],
    "trasareṇu": ['cae', 'mw'],
    "trasnu": ['cae', 'ddsa', 'mw'],
    "trasta": ['ap90', 'mw'],
    "trastanayana": ['cae'],
    "trasura": ['ap90', 'mw'],
    "trauk": ['mw'],
    "traya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "trayadhā": ['cae', 'gra'],
    "trayas": ['ap90', 'mw'],
    "trayastriṃśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "trayastriṃśadakṣara": ['mw'],
    "trayastriṃśadrātra": ['mw'],
    "trayastriṃśapati": ['mw'],
    "trayastriṃśastoma": ['mw'],
    "trayastriṃśat": ['cae', 'ddsa', 'gra', 'mw'],
    "trayastriṃśati": ['mw'],
    "trayastriṃśatsaṃmita": ['mw'],
    "trayastriṃśavartani": ['mw'],
    "trayastriṃśin": ['mw'],
    "trayatiṃśad": ['bhs'],
    "trayayāyia": ['gra'],
    "trayayāyya": ['cae', 'gra', 'mw'],
    "trayaś": ['mw'],
    "trayaścatvāriṃśa": ['mw'],
    "trayaścatvāriṃśat": ['mw'],
    "trayaḥ": ['mw'],
    "trayaḥpañcāśat": ['cae', 'mw'],
    "trayaḥsaptati": ['mw'],
    "trayaḥśataśatārdha": ['mw'],
    "trayaḥṣaṣṭi": ['mw'],
    "trayo": ['mw'],
    "trayodaśa": ['cae', 'ddsa', 'mw'],
    "trayodaśadhā": ['cae', 'ddsa', 'mw'],
    "trayodaśadvīpavatī": ['mw'],
    "trayodaśaka": ['mw'],
    "trayodaśama": ['mw'],
    "trayodaśamāsa": ['mw'],
    "trayodaśamāsika": ['mw'],
    "trayodaśan": ['cae', 'ddsa'],
    "trayodaśarca": ['ddsa', 'mw'],
    "trayodaśarātra": ['mw'],
    "trayodaśavarjyasaptamī": ['mw'],
    "trayodaśavidha": ['mw'],
    "trayodaśavārṣika": ['mw'],
    "trayodaśika": ['mw'],
    "trayodaśin": ['mw'],
    "trayodaśāha": ['mw'],
    "trayodaśākṣara": ['mw'],
    "trayodaśāratni": ['mw'],
    "trayodaśī": ['mw'],
    "trayonavati": ['mw'],
    "trayoviṃśa": ['cae', 'ddsa', 'mw'],
    "trayoviṃśat": ['mw'],
    "trayoviṃśati": ['cae', 'ddsa', 'mw'],
    "trayoviṃśatidhā": ['mw'],
    "trayoviṃśatidāru": ['mw'],
    "trayoviṃśatika": ['mw'],
    "trayoviṃśatirātra": ['mw'],
    "trayoviṃśatitama": ['mw'],
    "trayoviṃśatitattva": ['mw'],
    "trayyanta": ['mw'],
    "trayyāruṇa": ['mw'],
    "trayyāruṇi": ['mw'],
    "trayī": ['ap90', 'mw'],
    "trayībhāṣya": ['mw'],
    "trayīdeha": ['mw'],
    "trayīdharma": ['cae', 'mw'],
    "trayīdhāmavant": ['cae'],
    "trayīdhāmavat": ['ddsa', 'mw'],
    "trayīmaya": ['cae', 'mw'],
    "trayīmukha": ['mw'],
    "trayīniṣkarṣa": ['cae', 'mw'],
    "trayītanu": ['mw'],
    "trayīvida": ['mw'],
    "traṃd": ['ap90'],
    "traṃk": ['ap90'],
    "traṃs": ['ap90', 'mw'],
    "traṅg": ['mw'],
    "traṅga": ['mw'],
    "traṅk": ['mw'],
    "traṅkh": ['mw'],
    "traṭat": ['mw'],
    "traṭatkāra": ['mw'],
    "traṭatraṭa": ['mw'],
    "traṭattraṭiti": ['mw'],
    "tre": ['bhs'],
    "tredaṇḍika": ['bhs'],
    "tredhā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tredhābhāva": ['mw'],
    "tredhāsaṃnaddha": ['mw'],
    "tredhāsthita": ['mw'],
    "tredhāvihita": ['mw'],
    "trehika": ['bhs'],
    "trembuka": ['bhs'],
    "tremāsika": ['bhs'],
    "tretinī": ['gra', 'mw'],
    "tretā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tretāchandas": ['mw'],
    "tretāgni": ['mw'],
    "tretāgnihotra": ['mw'],
    "tretāstoma": ['mw'],
    "tretātva": ['mw'],
    "tretāya": ['mw'],
    "tretāyuga": ['mw'],
    "treviṃśat": ['bhs'],
    "treṇī": ['mw'],
    "tri": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "triambaka": ['gra'],
    "trianīka": ['gra'],
    "triaruṇa": ['gra'],
    "triaruṣa": ['gra'],
    "triavi": ['gra'],
    "tribandhana": ['mw'],
    "tribandhu": ['cae', 'gra', 'mw'],
    "tribarhis": ['gra', 'mw'],
    "tribha": ['mw'],
    "tribhajyā": ['mw'],
    "tribhajīvā": ['mw'],
    "tribhamaurvikā": ['mw'],
    "tribhauma": ['cae', 'mw'],
    "tribhava": ['bhs', 'mw'],
    "tribhaṅgi": ['mw'],
    "tribhaṅgī": ['mw'],
    "tribhaṇḍī": ['mw'],
    "tribhinna": ['mw'],
    "tribhonalagna": ['mw'],
    "tribhuj": ['cae', 'mw'],
    "tribhuja": ['cae', 'mw'],
    "tribhuktirāja": ['mw'],
    "tribhuvana": ['cae', 'mw'],
    "tribhuvanaguru": ['cae', 'mw'],
    "tribhuvanamalladeva": ['mw'],
    "tribhuvanamāṇikyacarita": ['mw'],
    "tribhuvanapati": ['cae', 'mw'],
    "tribhuvanaprabhā": ['mw'],
    "tribhuvanapāladeva": ['mw'],
    "tribhuvaneśvara": ['cae', 'mw'],
    "tribhuvaneśvaraliṅga": ['mw'],
    "tribhuvanābhoga": ['mw'],
    "tribhāga": ['cae', 'mw'],
    "tribhāj": ['mw'],
    "tribhānu": ['mw'],
    "tribhāva": ['mw'],
    "tribhāṇḍī": ['mw'],
    "tribhāṣyaratna": ['mw'],
    "tribhūma": ['mw'],
    "tribrahman": ['mw'],
    "tribāhu": ['cae', 'mw'],
    "tribīja": ['mw'],
    "trica": ['cae', 'ddsa', 'mw'],
    "tricakra": ['cae', 'ddsa', 'gra', 'mw'],
    "tricakṣus": ['cae', 'mw'],
    "tricatura": ['cae', 'mw'],
    "tricaturdaśa": ['mw'],
    "tricatvāriṃśa": ['mw'],
    "tricatvāriṃśat": ['mw'],
    "tricit": ['mw'],
    "tricitīka": ['mw'],
    "tricīvara": ['bhs', 'mw'],
    "tridalikā": ['mw'],
    "tridalā": ['mw'],
    "tridamathavastukuśala": ['mw'],
    "tridanta": ['mw'],
    "tridantī": ['mw'],
    "tridat": ['mw'],
    "tridaśa": ['cae', 'ddsa', 'mw'],
    "tridaśadīrghikā": ['mw'],
    "tridaśagopa": ['mw'],
    "tridaśagopaka": ['mw'],
    "tridaśaguru": ['mw'],
    "tridaśamañjarī": ['mw'],
    "tridaśanadī": ['mw'],
    "tridaśapati": ['cae', 'mw'],
    "tridaśapratipakṣa": ['mw'],
    "tridaśapuṃgava": ['mw'],
    "tridaśasarṣapa": ['mw'],
    "tridaśatva": ['mw'],
    "tridaśatā": ['cae', 'mw'],
    "tridaśavadhū": ['mw'],
    "tridaśavanitā": ['mw'],
    "tridaśaśaila": ['mw'],
    "tridaśaśreṣṭha": ['cae', 'mw'],
    "tridaśendra": ['cae', 'ddsa', 'mw'],
    "tridaśendraśatru": ['mw'],
    "tridaśeśa": ['cae', 'mw'],
    "tridaśeśadviṣ": ['mw'],
    "tridaśeśvara": ['cae', 'mw'],
    "tridaśeśvaradviṣ": ['mw'],
    "tridaśeśvarī": ['mw'],
    "tridaśācārya": ['mw'],
    "tridaśādhipa": ['cae', 'ddsa', 'mw'],
    "tridaśādhipati": ['cae', 'mw'],
    "tridaśāhāra": ['mw'],
    "tridaśālaya": ['cae', 'mw'],
    "tridaśāri": ['cae', 'mw'],
    "tridaśāvāsa": ['mw'],
    "tridaśāyana": ['mw'],
    "tridaśāyudha": ['cae', 'mw'],
    "tridaśāṅganā": ['mw'],
    "tridaśāṅkuśa": ['mw'],
    "tridaśībhū": ['ddsa'],
    "tridaśībhūta": ['mw'],
    "tridaṇḍa": ['cae', 'mw'],
    "tridaṇḍaka": ['bhs', 'mw'],
    "tridaṇḍin": ['mw'],
    "tridhanvan": ['mw'],
    "tridharman": ['mw'],
    "tridhā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tridhākṛ": ['mw'],
    "tridhāman": ['cae', 'ddsa', 'mw'],
    "tridhāmūrti": ['mw'],
    "tridhāra": ['mw'],
    "tridhāraka": ['mw'],
    "tridhārasnuhī": ['mw'],
    "tridhārā": ['mw'],
    "tridhātu": ['cae', 'ddsa', 'gra', 'mw'],
    "tridhātuka": ['mw'],
    "tridhātutva": ['mw'],
    "tridhātuśṛṅga": ['gra', 'mw'],
    "tridhātva": ['mw'],
    "tridhātve": ['mw'],
    "tridinaspṛś": ['mw'],
    "tridiva": ['cae', 'ddsa', 'gra', 'mw'],
    "tridivagata": ['mw'],
    "tridivasa": ['mw'],
    "tridivaukas": ['cae', 'mw'],
    "tridiveśa": ['mw'],
    "tridiveśvara": ['cae', 'mw'],
    "tridiveśāna": ['mw'],
    "tridivin": ['mw'],
    "tridivodbhavā": ['mw'],
    "tridivā": ['mw'],
    "tridivādhīśa": ['mw'],
    "tridoṣa": ['mw'],
    "tridoṣaghna": ['mw'],
    "tridoṣahārin": ['mw'],
    "tridoṣaja": ['mw'],
    "tridoṣakṛt": ['mw'],
    "tridoṣaśamana": ['mw'],
    "tridoṣāpaha": ['mw'],
    "tridvyekabhojana": ['mw'],
    "tridvāra": ['mw'],
    "tridṛś": ['mw'],
    "trigambhīra": ['mw'],
    "trigandhaka": ['mw'],
    "trigarta": ['ap90', 'cae', 'ddsa', 'mw'],
    "trigartaka": ['mw'],
    "trigartaṣaṣṭha": ['mw'],
    "trigartika": ['mw'],
    "trigartā": ['mw'],
    "trigata": ['mw'],
    "trigaṅga": ['mw'],
    "trigaṇa": ['mw'],
    "trighana": ['mw'],
    "trigrāhin": ['mw'],
    "trigrāmī": ['ddsa', 'mw'],
    "trigupta": ['bhs'],
    "triguṇa": ['cae', 'ddsa', 'mw'],
    "triguṇam": ['mw'],
    "triguṇaparivāra": ['mw'],
    "triguṇākarṇa": ['mw'],
    "triguṇākhya": ['mw'],
    "triguṇākṛta": ['mw'],
    "triguṇātmaka": ['cae', 'mw'],
    "triguṇīkṛtya": ['mw'],
    "trigūḍha": ['mw'],
    "trigūḍhaka": ['mw'],
    "trihalikāgrāma": ['mw'],
    "trihalya": ['mw'],
    "trihavis": ['mw'],
    "trihaviṣka": ['mw'],
    "trihāyaṇa": ['cae', 'ddsa', 'mw'],
    "trijagadīśvara": ['mw'],
    "trijagajjananī": ['mw'],
    "trijaganmohinī": ['mw'],
    "trijagat": ['cae', 'mw'],
    "trijagatī": ['mw'],
    "trijaya": ['mw'],
    "trijaṭa": ['cae', 'mw'],
    "trijaṭā": ['bhs', 'mw'],
    "trijaṭāsvapnadarśana": ['mw'],
    "trijyā": ['mw'],
    "trijāta": ['mw'],
    "trijātaka": ['mw'],
    "trijīvā": ['mw'],
    "trika": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "trikadruka": ['cae', 'ddsa', 'gra', 'mw'],
    "trikadrukīya": ['mw'],
    "trikahṛdaya": ['mw'],
    "trikaika": ['mw'],
    "trikakubh": ['cae', 'ddsa', 'gra', 'mw'],
    "trikakud": ['cae', 'ddsa', 'mw'],
    "trikakuda": ['mw'],
    "trikaliṅga": ['mw'],
    "trikalā": ['mw'],
    "trikapardin": ['mw'],
    "trikapāla": ['mw'],
    "trikaraṇī": ['mw'],
    "trikarmakṛt": ['cae', 'mw'],
    "trikarman": ['cae', 'mw'],
    "trikarṇa": ['mw'],
    "trikarṣa": ['mw'],
    "trikasthāna": ['mw'],
    "trikasāra": ['mw'],
    "trikatraya": ['mw'],
    "trikauśeya": ['mw'],
    "trikavedanā": ['mw'],
    "trikaśa": ['gra', 'mw'],
    "trikaṇṭa": ['mw'],
    "trikaṇṭaka": ['mw'],
    "trikaṇṭhaka": ['bhs'],
    "trikaṭa": ['mw'],
    "trikaṭu": ['mw'],
    "trikaṭuka": ['mw'],
    "trikha": ['mw'],
    "trikharva": ['mw'],
    "trikhaṇḍa": ['mw'],
    "trikhaṭva": ['mw'],
    "trikoṇa": ['cae', 'mw'],
    "trikoṇabhavana": ['mw'],
    "trikoṇaka": ['mw'],
    "trikoṇaphala": ['mw'],
    "trikoṇā": ['mw'],
    "trikoṭi": ['bhs'],
    "trikrama": ['mw'],
    "trikulā": ['mw'],
    "trikumārīka": ['mw'],
    "trikuṇḍīśvara": ['mw'],
    "trikā": ['mw'],
    "trikāgnikāla": ['mw'],
    "trikāla": ['cae', 'ddsa', 'mw'],
    "trikāladarśin": ['cae', 'mw'],
    "trikālajña": ['cae', 'mw'],
    "trikālam": ['mw'],
    "trikālanātha": ['mw'],
    "trikālarūpa": ['cae', 'mw'],
    "trikālavid": ['mw'],
    "trikārṣika": ['mw'],
    "trikātyāyanī": ['bhs'],
    "trikāya": ['mw'],
    "trikāṇḍa": ['mw'],
    "trikāṇḍamaṇḍana": ['mw'],
    "trikūrcaka": ['mw'],
    "trikūṭa": ['cae', 'ddsa', 'mw'],
    "trikūṭalavaṇa": ['mw'],
    "trikūṭavat": ['mw'],
    "trikṛtvas": ['cae', 'mw'],
    "trikṣeptṛ": ['mw'],
    "trikṣura": ['mw'],
    "trikṣutto": ['bhs'],
    "trikṣāra": ['mw'],
    "trilauha": ['mw'],
    "trilava": ['mw'],
    "trilavaṇa": ['mw'],
    "triliṅga": ['cae', 'mw'],
    "triliṅgaka": ['mw'],
    "triliṅgī": ['mw'],
    "trillaka": ['ddsa', 'mw'],
    "trillasena": ['mw'],
    "trilocana": ['cae', 'ddsa', 'mw'],
    "trilocanadāsa": ['mw'],
    "trilocanapāla": ['mw'],
    "trilocanatīrtha": ['mw'],
    "trilocaneśvaratīrtha": ['mw'],
    "trilocanā": ['mw'],
    "trilocanāṣṭamī": ['mw'],
    "triloha": ['mw'],
    "trilohaka": ['mw'],
    "triloka": ['cae', 'mw'],
    "trilokanātha": ['cae', 'mw'],
    "trilokarakṣin": ['mw'],
    "trilokasāra": ['mw'],
    "trilokavaśaṃkara": ['mw'],
    "trilokavīra": ['mw'],
    "trilokeśa": ['cae', 'mw'],
    "trilokātman": ['mw'],
    "trilokī": ['mw'],
    "trilokījit": ['mw'],
    "trilokīkṛti": ['mw'],
    "trilokīnātha": ['cae', 'mw'],
    "trilokīpati": ['cae', 'mw'],
    "trilokīrāja": ['mw'],
    "trimada": ['mw'],
    "trimadhu": ['mw'],
    "trimadhura": ['mw'],
    "trimala": ['mw'],
    "trimalla": ['mw'],
    "trimallacandra": ['mw'],
    "trimantu": ['gra', 'mw'],
    "trimaṅgala": ['bhs'],
    "trimaṇḍala": ['bhs'],
    "trimaṇḍalapariśuddha": ['mw'],
    "trimaṇḍalā": ['mw'],
    "trimukha": ['mw'],
    "trimukhā": ['mw'],
    "trimukuṭa": ['mw'],
    "trimuni": ['mw'],
    "trimārga": ['mw'],
    "trimārgagamana": ['mw'],
    "trimārgagā": ['mw'],
    "trimārgī": ['mw'],
    "trimārikā": ['mw'],
    "trimātra": ['cae', 'mw'],
    "trimātrika": ['mw'],
    "trimātrākāla": ['mw'],
    "trimātṛ": ['gra', 'mw'],
    "trimūrdha": ['mw'],
    "trimūrdhan": ['cae', 'gra', 'mw'],
    "trimūrti": ['cae', 'mw'],
    "trimūḍha": ['mw'],
    "trimūḍhaka": ['mw'],
    "trinagarītīrtha": ['mw'],
    "trinaiṣkika": ['mw'],
    "trinavaha": ['mw'],
    "trinavata": ['mw'],
    "trinavati": ['mw'],
    "trinavatitama": ['mw'],
    "trinayana": ['bhs', 'cae', 'mw'],
    "trinayanā": ['mw'],
    "trinemi": ['mw'],
    "trinetra": ['mw'],
    "trinetracūḍāmaṇi": ['mw'],
    "trinetraphala": ['mw'],
    "trinetrodbhava": ['mw'],
    "trinetrā": ['mw'],
    "trinetrī": ['mw'],
    "trinidhana": ['mw'],
    "trinidāna": ['bhs'],
    "trinivitka": ['mw'],
    "triniṣka": ['mw'],
    "trinābha": ['mw'],
    "trinābhi": ['gra', 'mw'],
    "trināka": ['gra', 'mw'],
    "trināli": ['mw'],
    "tripacchas": ['mw'],
    "tripad": ['cae', 'ddsa', 'gra', 'mw'],
    "tripada": ['cae', 'mw'],
    "tripadaprabhṛti": ['mw'],
    "tripadikā": ['mw'],
    "tripadya": ['cae', 'mw'],
    "tripadā": ['mw'],
    "tripadī": ['mw'],
    "tripakṣa": ['cae', 'mw'],
    "tripakṣaka": ['mw'],
    "tripala": ['mw'],
    "tripanna": ['mw'],
    "triparikrānta": ['mw'],
    "triparivarta": ['bhs', 'mw'],
    "triparus": ['mw'],
    "triparva": ['mw'],
    "triparvan": ['mw'],
    "triparvata": ['mw'],
    "triparyāya": ['mw'],
    "triparṇa": ['mw'],
    "triparṇikā": ['mw'],
    "triparṇā": ['mw'],
    "triparṇī": ['mw'],
    "tripastia": ['gra'],
    "tripastya": ['gra', 'mw'],
    "tripatat": ['mw'],
    "tripatha": ['cae', 'mw'],
    "tripathagā": ['mw'],
    "tripathagāminī": ['mw'],
    "tripathaka": ['mw'],
    "tripattra": ['mw'],
    "tripattraka": ['mw'],
    "tripatāka": ['mw'],
    "tripatī": ['mw'],
    "tripauruṣa": ['mw'],
    "tripañcaka": ['mw'],
    "tripañcāśa": ['cae', 'gra', 'mw'],
    "tripañcāśat": ['mw'],
    "tripañcāśattama": ['mw'],
    "tripaśu": ['mw'],
    "tripaṭu": ['mw'],
    "triphala": ['bhs', 'cae', 'mw'],
    "triphalin": ['bhs'],
    "triphalā": ['mw'],
    "triphalī": ['mw'],
    "tripiba": ['mw'],
    "tripiṇḍaka": ['mw'],
    "tripiṇḍī": ['cae', 'mw'],
    "tripiṣṭapa": ['cae', 'mw'],
    "tripiṣṭapasad": ['mw'],
    "tripiṭa": ['bhs', 'mw'],
    "tripiṭaka": ['bhs', 'cae', 'mw'],
    "triplakṣa": ['mw'],
    "triplakṣāvaharaṇa": ['mw'],
    "tripradakṣiṇīkṛtya": ['bhs'],
    "triprakāra": ['cae', 'mw'],
    "tripralamba": ['mw'],
    "tripralambin": ['mw'],
    "triprasruta": ['mw'],
    "tripratiṣṭhita": ['mw'],
    "triprātihāryasampanna": ['mw'],
    "tripu": ['mw'],
    "tripur": ['mw'],
    "tripura": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "tripurabhairava": ['mw'],
    "tripurabhairavī": ['mw'],
    "tripuradahana": ['mw'],
    "tripuradruh": ['cae', 'mw'],
    "tripuradviṣ": ['cae', 'mw'],
    "tripuradāha": ['mw'],
    "tripuraghna": ['mw'],
    "tripuraghātin": ['cae', 'mw'],
    "tripurahan": ['cae', 'mw'],
    "tripurahara": ['cae', 'mw'],
    "tripurajit": ['mw'],
    "tripurakumāra": ['mw'],
    "tripuramallikā": ['mw'],
    "tripuramālī": ['mw'],
    "tripurapramāthin": ['mw'],
    "tripurasundarī": ['mw'],
    "tripuravadha": ['mw'],
    "tripuravidhvaṃsaka": ['mw'],
    "tripuravighna": ['mw'],
    "tripuravijaya": ['mw'],
    "tripuravijayin": ['mw'],
    "tripureśvara": ['mw'],
    "tripureśādri": ['ddsa', 'mw'],
    "tripuropākhyāna": ['mw'],
    "tripuruṣa": ['ddsa', 'mw'],
    "tripuruṣam": ['mw'],
    "tripuruṣī": ['mw'],
    "tripurā": ['mw'],
    "tripurābhairavī": ['mw'],
    "tripurādhipati": ['mw'],
    "tripurāntaka": ['cae', 'ddsa', 'mw'],
    "tripurāntakara": ['mw'],
    "tripurāntakṛt": ['mw'],
    "tripurārdana": ['mw'],
    "tripurāri": ['cae', 'mw'],
    "tripurārāti": ['cae', 'mw'],
    "tripurārṇava": ['mw'],
    "tripurāsamuccaya": ['mw'],
    "tripurāsāra": ['mw'],
    "tripurātapana": ['mw'],
    "tripurātāpanī": ['mw'],
    "tripurāṇaka": ['ddsa', 'mw'],
    "tripurāṇīya": ['mw'],
    "tripurī": ['mw'],
    "tripurīkṣetra": ['mw'],
    "tripurīprakaraṇa": ['mw'],
    "triputra": ['mw'],
    "tripuṇḍarīkṛta": ['bhs'],
    "tripuṇḍhra": ['mw'],
    "tripuṇḍra": ['cae', 'mw'],
    "tripuṇḍraka": ['cae', 'mw'],
    "tripuṇḍrin": ['mw'],
    "tripuṣkara": ['bhs', 'ddsa', 'mw'],
    "tripuṣā": ['mw'],
    "tripuṭa": ['cae', 'mw'],
    "tripuṭaka": ['cae', 'mw'],
    "tripuṭin": ['mw'],
    "tripuṭiphala": ['mw'],
    "tripuṭā": ['mw'],
    "tripād": ['mw'],
    "tripāda": ['mw'],
    "tripādaka": ['cae', 'mw'],
    "tripādavigraha": ['mw'],
    "tripādikā": ['mw'],
    "tripādvibhūtikathana": ['mw'],
    "tripādī": ['mw'],
    "tripājasya": ['gra', 'mw'],
    "tripāṇa": ['mw'],
    "tripāṭa": ['mw'],
    "tripāṭhin": ['cae', 'mw'],
    "tripāṭikā": ['mw'],
    "tripūruṣa": ['mw'],
    "tripṛṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "trir": ['mw'],
    "trirakṣara": ['mw'],
    "trirasaka": ['mw'],
    "triratna": ['bhs', 'mw'],
    "triraśri": ['cae', 'gra', 'mw'],
    "trirekha": ['mw'],
    "trirekhāpuṭa": ['mw'],
    "trirekhāṅkita": ['mw'],
    "trirunnata": ['mw'],
    "trirvyūha": ['mw'],
    "trirātra": ['cae', 'mw'],
    "trirātram": ['mw'],
    "trirātreṇa": ['mw'],
    "trirātrāt": ['mw'],
    "trirātrāvaram": ['mw'],
    "trirātrīṇā": ['mw'],
    "trirāva": ['mw'],
    "trirāśipa": ['mw'],
    "trirūpa": ['cae', 'mw'],
    "tris": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "trisahasra": ['bhs'],
    "trisama": ['mw'],
    "trisamayarāja": ['bhs'],
    "trisamṛddha": ['mw'],
    "trisapta": ['cae', 'mw'],
    "trisaptaka": ['mw'],
    "trisaptata": ['mw'],
    "trisaptati": ['mw'],
    "trisaptatitama": ['mw'],
    "trisara": ['mw'],
    "trisaraka": ['mw'],
    "trisarga": ['mw'],
    "trisarī": ['mw'],
    "trisatya": ['ddsa', 'mw'],
    "trisaugandhya": ['mw'],
    "trisauparṇa": ['mw'],
    "trisavana": ['cae', 'mw'],
    "trisaṃdhi": ['mw'],
    "trisaṃdhika": ['mw'],
    "trisaṃdhya": ['cae', 'mw'],
    "trisaṃdhyakusumā": ['mw'],
    "trisaṃdhyam": ['mw'],
    "trisaṃdhyā": ['mw'],
    "trisaṃdhyī": ['mw'],
    "trisaṃdhī": ['mw'],
    "trisaṃvatsara": ['mw'],
    "trisitā": ['mw'],
    "triskandha": ['bhs', 'mw'],
    "triskandhaka": ['bhs', 'mw'],
    "triskandhapathadaiśika": ['mw'],
    "trisrotas": ['cae', 'mw'],
    "trisrotasī": ['mw'],
    "tristana": ['cae', 'mw'],
    "tristanī": ['mw'],
    "tristhalī": ['mw'],
    "tristhalīsetu": ['mw'],
    "tristhāna": ['mw'],
    "tristhūṇa": ['mw'],
    "tristāvā": ['mw'],
    "trisugandha": ['mw'],
    "trisugandhi": ['mw'],
    "trisugandhika": ['mw'],
    "trisundara": ['mw'],
    "trisuparṇa": ['cae', 'mw'],
    "trisuvarcaka": ['mw'],
    "trisādhana": ['cae', 'mw'],
    "trisāhasra": ['mw'],
    "trisāhasramahāsāhasra": ['bhs', 'mw'],
    "trisāhasramahāsāhasrika": ['bhs', 'mw'],
    "trisāhasrika": ['bhs'],
    "trisāhasrā": ['bhs'],
    "trisāhasrī": ['bhs'],
    "trisāman": ['mw'],
    "trisāmya": ['mw'],
    "trisāmā": ['mw'],
    "trisānu": ['mw'],
    "trisāṃvatsara": ['mw'],
    "trisītya": ['mw'],
    "trisūtra": ['mw'],
    "trisūtrī": ['mw'],
    "trisūtrīkaraṇa": ['mw'],
    "trita": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "tritakūpa": ['mw'],
    "tritakṣa": ['mw'],
    "tritakṣī": ['mw'],
    "tritanti": ['mw'],
    "tritantrikā": ['mw'],
    "tritantu": ['gra', 'mw'],
    "tritas": ['mw'],
    "tritaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "tritrika": ['mw'],
    "tritrikoṇa": ['mw'],
    "tritva": ['mw'],
    "tritā": ['mw'],
    "tritāmra": ['mw'],
    "triudhan": ['gra'],
    "triudāya": ['gra'],
    "trivaistika": ['mw'],
    "trivakrā": ['mw'],
    "trivali": ['cae', 'mw'],
    "trivalī": ['mw'],
    "trivalīka": ['mw'],
    "trivalīvat": ['mw'],
    "trivandhura": ['cae', 'ddsa', 'gra', 'mw'],
    "trivarga": ['cae', 'mw'],
    "trivargacintana": ['mw'],
    "trivargapārīṇa": ['mw'],
    "trivartmagā": ['mw'],
    "trivartman": ['mw'],
    "trivartu": ['cae', 'gra', 'mw'],
    "trivarūtha": ['cae', 'gra', 'mw'],
    "trivarṇa": ['cae', 'mw'],
    "trivarṇaka": ['mw'],
    "trivarṇakṛt": ['mw'],
    "trivarṣa": ['cae', 'mw'],
    "trivarṣaka": ['mw'],
    "trivarṣapūrva": ['mw'],
    "trivarṣīya": ['mw'],
    "trivastu": ['mw'],
    "trivat": ['mw'],
    "trivatsa": ['cae', 'mw'],
    "trivayas": ['gra', 'mw'],
    "trivaṇasaṃjñikā": ['mw'],
    "trivaṇī": ['mw'],
    "triveda": ['cae', 'mw'],
    "trivedin": ['mw'],
    "trivedī": ['mw'],
    "trivedītanu": ['mw'],
    "trivelā": ['mw'],
    "triveṇi": ['mw'],
    "triveṇikā": ['mw'],
    "triveṇu": ['mw'],
    "triveṇī": ['mw'],
    "trivibudhī": ['mw'],
    "trividha": ['cae', 'mw'],
    "trividhadamathavastukuśala": ['mw'],
    "trividhā": ['cae'],
    "trividya": ['cae', 'mw'],
    "trividyā": ['mw'],
    "trivikrama": ['cae', 'mw'],
    "trivikramabhaṭṭa": ['mw'],
    "trivikramadeva": ['mw'],
    "trivikramasena": ['cae', 'mw'],
    "trivikramatīrtha": ['mw'],
    "trivikramācārya": ['mw'],
    "trivinata": ['mw'],
    "trivista": ['mw'],
    "trivitasta": ['mw'],
    "triviṣūka": ['mw'],
    "triviṣṭabdha": ['mw'],
    "triviṣṭabdhaka": ['mw'],
    "triviṣṭapa": ['cae', 'mw'],
    "triviṣṭapasad": ['mw'],
    "triviṣṭi": ['cae', 'gra', 'mw'],
    "triviṣṭidhātu": ['gra', 'mw'],
    "trivrata": ['mw'],
    "trivyāma": ['mw'],
    "trivācika": ['mw'],
    "trivāra": ['mw'],
    "trivāram": ['mw'],
    "trivārṣika": ['mw'],
    "trivṛcchiras": ['mw'],
    "trivṛnta": ['mw'],
    "trivṛntikā": ['mw'],
    "trivṛt": ['cae', 'gra', 'mw'],
    "trivṛtkaraṇa": ['cae', 'mw'],
    "trivṛtparṇī": ['mw'],
    "trivṛtprāya": ['mw'],
    "trivṛtstoma": ['mw'],
    "trivṛtti": ['mw'],
    "trivṛttā": ['cae', 'mw'],
    "trivṛtā": ['mw'],
    "trivṛṣa": ['mw'],
    "trivṛṣan": ['mw'],
    "triy": ['mw'],
    "triyadhva": ['bhs'],
    "triyadhvan": ['mw'],
    "triyadhvaprabhaghoṣa": ['bhs'],
    "triyadhvapratibhāsaprabha": ['bhs'],
    "triyajña": ['mw'],
    "triyakṣa": ['mw'],
    "triyambaka": ['ddsa', 'mw'],
    "triyantara": ['bhs'],
    "triyava": ['ddsa', 'mw'],
    "triyavastha": ['mw'],
    "triyavi": ['mw'],
    "triyaṣṭi": ['mw'],
    "triyojana": ['mw'],
    "triyoni": ['mw'],
    "triyuga": ['cae', 'gra', 'mw'],
    "triyugma": ['mw'],
    "triyukta": ['mw'],
    "triyāma": ['cae', 'mw'],
    "triyāmaka": ['mw'],
    "triyāmā": ['mw'],
    "triyāna": ['bhs', 'cae', 'mw'],
    "triyūha": ['mw'],
    "triyūpa": ['mw'],
    "triyṛca": ['mw'],
    "triāśir": ['gra'],
    "triśakala": ['mw'],
    "triśakti": ['mw'],
    "triśakunīya": ['bhs'],
    "triśala": ['mw'],
    "triśalya": ['mw'],
    "triśalā": ['mw'],
    "triśaraṇa": ['mw'],
    "triśarkarā": ['mw'],
    "triśarīra": ['mw'],
    "triśarīrin": ['mw'],
    "triśas": ['cae', 'mw'],
    "triśata": ['cae', 'gra', 'mw'],
    "triśataka": ['mw'],
    "triśatatama": ['cae', 'mw'],
    "triśataṃṣaṣṭiparvan": ['mw'],
    "triśatikāprajñāpāramitā": ['bhs'],
    "triśatī": ['mw'],
    "triśaṅkha": ['mw'],
    "triśaṅku": ['bhs', 'cae', 'ddsa', 'mw'],
    "triśaṅkuja": ['mw'],
    "triśaṅkuka": ['bhs', 'mw'],
    "triśaṅkukā": ['mw'],
    "triśaṅkutilaka": ['mw'],
    "triśaṅkuyājin": ['mw'],
    "triśikha": ['cae', 'mw'],
    "triśikhara": ['cae', 'mw'],
    "triśikhidalā": ['mw'],
    "triśikhī": ['mw'],
    "triśila": ['mw'],
    "triśira": ['mw'],
    "triśiragiri": ['mw'],
    "triśiras": ['cae', 'mw'],
    "triśirā": ['mw'],
    "triśoka": ['cae', 'gra', 'mw'],
    "triśrut": ['mw'],
    "triśruti": ['mw'],
    "triśuc": ['cae', 'mw'],
    "triśukla": ['bhs', 'mw'],
    "triśukra": ['mw'],
    "triśukriya": ['mw'],
    "triśyeta": ['mw'],
    "triśākha": ['cae', 'mw'],
    "triśākhapattra": ['mw'],
    "triśāla": ['mw'],
    "triśālaka": ['mw'],
    "triśānu": ['mw'],
    "triśāṇa": ['mw'],
    "triśāṇya": ['mw'],
    "triśīrṣa": ['bhs', 'cae', 'mw'],
    "triśīrṣaguhā": ['mw'],
    "triśīrṣaka": ['bhs', 'mw'],
    "triśīrṣan": ['cae', 'gra', 'mw'],
    "triśīrṣavat": ['mw'],
    "triśīrṣākhyaguhā": ['mw'],
    "triśūla": ['bhs', 'cae', 'mw'],
    "triśūlagaṅgā": ['mw'],
    "triśūlahasta": ['mw'],
    "triśūlakhāta": ['mw'],
    "triśūlapaṭṭiśadhara": ['mw'],
    "triśūlapurī": ['mw'],
    "triśūlapāṇi": ['bhs'],
    "triśūlapāṇī": ['bhs'],
    "triśūlavarapāṇin": ['mw'],
    "triśūlikā": ['ddsa', 'mw'],
    "triśūlin": ['bhs', 'mw'],
    "triśūlinī": ['mw'],
    "triśūlāya": ['ddsa', 'mw'],
    "triśūlāṅka": ['mw'],
    "triśṛṅga": ['cae', 'mw'],
    "triśṛṅgin": ['mw'],
    "triḥ": ['mw'],
    "triḥprakāra": ['mw'],
    "triḥprasrutamada": ['mw'],
    "triḥpratihāram": ['mw'],
    "triḥsahasrā": ['bhs'],
    "triḥsahavacana": ['mw'],
    "triḥsamṛddhatva": ['mw'],
    "triḥsapta": ['mw'],
    "triḥsaptakṛtvas": ['mw'],
    "triḥsnāna": ['ddsa', 'mw'],
    "triḥśreṇi": ['mw'],
    "triḥśrāvaṇa": ['mw'],
    "triḥśukla": ['mw'],
    "triḥśveta": ['cae', 'ddsa', 'mw'],
    "triḥṣamṛddha": ['mw'],
    "triṃśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "triṃśacchata": ['cae', 'gra', 'mw'],
    "triṃśacchlokī": ['mw'],
    "triṃśad": ['mw'],
    "triṃśadakṣara": ['mw'],
    "triṃśadara": ['mw'],
    "triṃśadaṅga": ['mw'],
    "triṃśadbhāga": ['ddsa'],
    "triṃśadrātra": ['mw'],
    "triṃśadvarṣa": ['cae', 'mw'],
    "triṃśadvikrama": ['mw'],
    "triṃśadviṃśa": ['mw'],
    "triṃśadyogāvali": ['mw'],
    "triṃśaka": ['ap90', 'mw'],
    "triṃśat": ['ap90', 'cae', 'gra', 'mw'],
    "triṃśati": ['cae', 'mw'],
    "triṃśatiḥ": ['ap90'],
    "triṃśatka": ['ddsa', 'mw'],
    "triṃśatkaṃ": ['ap90'],
    "triṃśatpattra": ['mw'],
    "triṃśatsāhasra": ['mw'],
    "triṃśattama": ['cae', 'mw'],
    "triṃśattva": ['mw'],
    "triṃśikā": ['mw'],
    "triṃśin": ['mw'],
    "triṃśāṃśa": ['mw'],
    "triṃśāṃśaka": ['mw'],
    "triṅkh": ['mw'],
    "triṇa": ['mw'],
    "triṇata": ['mw'],
    "triṇatā": ['mw'],
    "triṇava": ['mw'],
    "triṇavarātra": ['mw'],
    "triṇavasāhasra": ['mw'],
    "triṇavavartani": ['mw'],
    "triṇavātmaka": ['mw'],
    "triṇemi": ['mw'],
    "triṇidhana": ['mw'],
    "triṇāciketa": ['cae', 'mw'],
    "triṇāka": ['mw'],
    "triṇāman": ['mw'],
    "triṇītā": ['mw'],
    "triṣadhastha": ['cae', 'ddsa', 'gra', 'mw'],
    "triṣama": ['mw'],
    "triṣapta": ['cae', 'gra', 'mw'],
    "triṣaptīya": ['mw'],
    "triṣatya": ['cae', 'mw'],
    "triṣavaṇa": ['cae', 'mw'],
    "triṣavaṇam": ['mw'],
    "triṣavaṇasnāyin": ['mw'],
    "triṣaṃdhi": ['mw'],
    "triṣaṃvatsara": ['mw'],
    "triṣaṃyukta": ['mw'],
    "triṣaṣ": ['cae', 'mw'],
    "triṣaṣṭa": ['mw'],
    "triṣaṣṭi": ['mw'],
    "triṣaṣṭidhā": ['mw'],
    "triṣaṣṭitama": ['mw'],
    "triṣaṣṭiśalākāpuruṣacarita": ['mw'],
    "triṣkarma": ['bhs'],
    "triṣkāla": ['bhs'],
    "triṣkṛtvas": ['bhs'],
    "triṣprakāra": ['mw'],
    "triṣuvarcaka": ['mw'],
    "triṣāhasra": ['cae', 'mw'],
    "triṣṭha": ['cae', 'gra', 'mw'],
    "triṣṭhin": ['cae', 'mw'],
    "triṣṭoma": ['mw'],
    "triṣṭubh": ['cae', 'gra', 'mw'],
    "triṣṭuk": ['mw'],
    "triṣṭupchandas": ['mw'],
    "triṣṭuṇmukha": ['mw'],
    "triṣṭāvarūtrī": ['mw'],
    "trotala": ['mw'],
    "trotalottara": ['mw'],
    "trotra": ['mw'],
    "trotraṃ": ['ap90'],
    "troṭaka": ['cae', 'ddsa', 'mw'],
    "troṭakahasta": ['mw'],
    "troṭakaṃ": ['ap90'],
    "troṭakī": ['mw'],
    "troṭi": ['mw'],
    "troṭita": ['mw'],
    "troṭiḥ": ['ap90'],
    "trump": ['mw'],
    "trumph": ['mw'],
    "trup": ['ap90', 'mw'],
    "truph": ['mw'],
    "truṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "truṭi": ['bhs', 'cae', 'ddsa', 'mw'],
    "truṭibīja": ['mw'],
    "truṭipattra": ['mw'],
    "truṭita": ['ap90', 'mw'],
    "truṭiśas": ['mw'],
    "truṭiḥ": ['ap90'],
    "truṭyavayava": ['mw'],
    "truṭī": ['mw'],
    "try": ['mw'],
    "tryabda": ['cae', 'ddsa', 'mw'],
    "tryabdam": ['mw'],
    "tryabdapūrva": ['mw'],
    "tryadhipati": ['mw'],
    "tryadhiṣṭhāna": ['cae', 'mw'],
    "tryadhva": ['bhs'],
    "tryadhvagā": ['mw'],
    "tryadhvalakṣaṇapratibhāsateja": ['bhs'],
    "tryadhvāvabhāsabuddhi": ['bhs'],
    "tryadhīśa": ['mw'],
    "tryaha": ['cae', 'ddsa', 'mw'],
    "tryahaihika": ['cae', 'mw'],
    "tryaham": ['mw'],
    "tryahasparśa": ['mw'],
    "tryahaspṛśa": ['mw'],
    "tryahavṛtta": ['cae', 'mw'],
    "tryahe": ['mw'],
    "tryahena": ['mw'],
    "tryahna": ['mw'],
    "tryahāt": ['mw'],
    "tryahīna": ['cae', 'mw'],
    "tryaihika": ['mw'],
    "tryakṣa": ['cae', 'ddsa', 'mw'],
    "tryakṣaka": ['cae', 'mw'],
    "tryakṣan": ['cae', 'mw'],
    "tryakṣapatnī": ['mw'],
    "tryakṣara": ['cae', 'mw'],
    "tryakṣāyaṇa": ['mw'],
    "tryalinda": ['mw'],
    "tryambaka": ['cae', 'ddsa', 'gra', 'mw'],
    "tryambakamāhātmya": ['mw'],
    "tryambakaparvata": ['mw'],
    "tryambakasakha": ['mw'],
    "tryambakavṛṣabha": ['mw'],
    "tryambakeśvarapurī": ['mw'],
    "tryambakā": ['mw'],
    "tryambuka": ['bhs', 'mw'],
    "tryanta": ['mw'],
    "tryanīka": ['cae', 'gra', 'mw'],
    "tryanīkā": ['mw'],
    "tryara": ['cae', 'mw'],
    "tryaratni": ['mw'],
    "tryartha": ['mw'],
    "tryaruṇa": ['cae', 'gra', 'mw'],
    "tryaruṣa": ['cae', 'gra', 'mw'],
    "tryasra": ['mw'],
    "tryavanata": ['mw'],
    "tryavara": ['cae', 'ddsa', 'mw'],
    "tryavaram": ['mw'],
    "tryavarārdhyam": ['cae', 'mw'],
    "tryavi": ['cae', 'gra', 'mw'],
    "tryañjala": ['mw'],
    "tryañjali": ['mw'],
    "tryañjana": ['mw'],
    "tryaśra": ['cae', 'mw'],
    "tryaśrakuṇḍa": ['mw'],
    "tryaśraphalā": ['mw'],
    "tryaśīta": ['cae', 'ddsa', 'mw'],
    "tryaśīti": ['cae', 'mw'],
    "tryaśītitama": ['mw'],
    "tryaṃśa": ['cae', 'ddsa', 'mw'],
    "tryaṃśanātha": ['mw'],
    "tryaṅga": ['cae', 'mw'],
    "tryaṅgaṭa": ['mw'],
    "tryaṅgula": ['cae', 'mw'],
    "tryaṅgya": ['mw'],
    "tryaṅkaṭa": ['mw'],
    "tryaṣṭaka": ['ddsa', 'mw'],
    "tryaṣṭavarṣa": ['cae', 'mw'],
    "tryenī": ['cae', 'mw'],
    "tryeṇī": ['cae', 'ddsa', 'mw'],
    "tryuddhi": ['mw'],
    "tryudhan": ['cae', 'gra', 'mw'],
    "tryudāya": ['gra', 'mw'],
    "tryunnata": ['mw'],
    "tryupasatka": ['mw'],
    "tryuttarībhāva": ['mw'],
    "tryuṣaṇa": ['mw'],
    "tryāhala": ['mw'],
    "tryāhika": ['cae', 'ddsa', 'mw'],
    "tryāhāva": ['mw'],
    "tryākṣāyaṇa": ['mw'],
    "tryālikhita": ['mw'],
    "tryālikhitavat": ['mw'],
    "tryāruṇi": ['mw'],
    "tryārṣeya": ['mw'],
    "tryāvṛt": ['mw'],
    "tryāyuṣa": ['cae', 'mw'],
    "tryāśir": ['cae', 'gra', 'mw'],
    "tryūṣaṇa": ['mw'],
    "tryṛca": ['cae', 'ddsa', 'mw'],
    "trā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "trāman": ['cae', 'gra', 'mw'],
    "trāpusa": ['mw'],
    "trāpuṣa": ['cae', 'ddsa', 'mw'],
    "trāpya": ['mw'],
    "trāsa": ['ap90', 'cae', 'ddsa', 'mw'],
    "trāsadasyava": ['gra', 'mw'],
    "trāsadāyin": ['mw'],
    "trāsakara": ['mw'],
    "trāsakṛt": ['mw'],
    "trāsana": ['ap90', 'cae', 'ddsa', 'mw'],
    "trāsanīya": ['cae', 'mw'],
    "trāsin": ['cae', 'mw'],
    "trāsita": ['ap90'],
    "trāta": ['ap90', 'cae', 'mw'],
    "trātavya": ['cae', 'ddsa', 'mw'],
    "trātra": ['cae', 'gra', 'mw'],
    "trātṛ": ['ap90', 'cae', 'gra', 'mw'],
    "trāyamāṇa": ['mw'],
    "trāyamāṇikā": ['mw'],
    "trāyamāṇā": ['mw'],
    "trāyantikā": ['mw'],
    "trāyantī": ['mw'],
    "trāyastriṃśa": ['bhs'],
    "trāyastriṃśaka": ['bhs'],
    "trāyati": ['ddsa'],
    "trāyatriṃśa": ['bhs'],
    "trāyaṇa": ['bhs'],
    "trāyin": ['bhs'],
    "trāyodaśa": ['mw'],
    "trāṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "trāṇakartṛ": ['mw'],
    "trāṇakārin": ['mw'],
    "trāṇana": ['cae', 'ddsa', 'mw'],
    "trāṇasārin": ['mw'],
    "trāṇā": ['mw'],
    "trāṭaka": ['mw'],
    "trīhika": ['bhs'],
    "trīndriya": ['mw'],
    "trīrātrīṇa": ['cae'],
    "trīrāvatīka": ['mw'],
    "trīśaṭa": ['mw'],
    "trīṣu": ['mw'],
    "trīṣuka": ['mw'],
    "trīṣṭaka": ['mw'],
    "tsar": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tsaru": ['cae', 'ddsa', 'gra', 'mw'],
    "tsaruka": ['mw'],
    "tsarumat": ['mw'],
    "tsarumārga": ['mw'],
    "tsaruḥ": ['ap90'],
    "tsarā": ['cae', 'mw'],
    "tsāra": ['mw'],
    "tsārin": ['cae', 'gra', 'mw'],
    "tsāruka": ['ap90', 'mw'],
    "tta": ['mw'],
    "tti": ['mw'],
    "tu": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "tua": ['gra'],
    "tubara": ['cae', 'ddsa', 'mw'],
    "tubaraka": ['mw'],
    "tubarayāvanāla": ['mw'],
    "tubarikā": ['mw'],
    "tubarī": ['mw'],
    "tubarīśimba": ['mw'],
    "tubh": ['ap90', 'mw'],
    "tuc": ['ap90', 'cae', 'gra', 'mw'],
    "tuccha": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "tucchadaya": ['mw'],
    "tucchadhānya": ['mw'],
    "tucchadhānyaka": ['mw'],
    "tucchadru": ['mw'],
    "tucchaka": ['ap90', 'bhs', 'cped', 'mw'],
    "tucchakaṁ": ['cped'],
    "tucchakena": ['cped'],
    "tucchaprāya": ['mw'],
    "tucchatva": ['mw'],
    "tucchay": ['cae'],
    "tucchaya": ['cae', 'ddsa', 'mw'],
    "tucchayati": ['ap90'],
    "tucchaṁ": ['cped'],
    "tucchena": ['cped'],
    "tucchya": ['ap90', 'ddsa', 'mw'],
    "tucchā": ['cped', 'mw'],
    "tucchīkṛ": ['ap90'],
    "tucchīkṛta": ['mw'],
    "tuchya": ['gra'],
    "tud": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tuda": ['ap90', 'cae', 'ddsa', 'mw'],
    "tudana": ['bhs'],
    "tudati": ['cped'],
    "tudādi": ['mw'],
    "tudāya": ['ddsa'],
    "tueṣita": ['gra'],
    "tugra": ['cae', 'ddsa', 'gra', 'mw'],
    "tugria": ['gra'],
    "tugriya": ['mw'],
    "tugriāvṛdh": ['gra'],
    "tugrya": ['cae', 'gra', 'mw'],
    "tugryā": ['ap90', 'mw'],
    "tugryāvṛdh": ['gra', 'mw'],
    "tugvan": ['cae', 'gra', 'mw'],
    "tugā": ['mw'],
    "tugākṣīrī": ['mw'],
    "tuh": ['mw'],
    "tuhara": ['mw'],
    "tuhi": ['mw'],
    "tuhina": ['ap90', 'cae', 'ddsa', 'mw'],
    "tuhinadyuti": ['cae', 'mw'],
    "tuhinadīdhiti": ['mw'],
    "tuhinagiri": ['cae', 'mw'],
    "tuhinagirimaya": ['mw'],
    "tuhinagu": ['mw'],
    "tuhinakara": ['cae', 'mw'],
    "tuhinakarasutā": ['mw'],
    "tuhinakaṇa": ['mw'],
    "tuhinakiraṇa": ['cae', 'mw'],
    "tuhinakiraṇaputra": ['mw'],
    "tuhinakṣitibhṛt": ['mw'],
    "tuhinakṣmābhṛt": ['mw'],
    "tuhinamayūkha": ['cae', 'mw'],
    "tuhinaraśmi": ['mw'],
    "tuhinaya": ['ddsa', 'mw'],
    "tuhinaśaila": ['mw'],
    "tuhinaśarkarā": ['ddsa', 'mw'],
    "tuhinā": ['mw'],
    "tuhinācala": ['cae', 'mw'],
    "tuhinādri": ['cae', 'mw'],
    "tuhināṃśu": ['mw'],
    "tuhināṃśutaila": ['mw'],
    "tuhuṇḍa": ['mw'],
    "tuhyādiparibhāṣā": ['ddsa'],
    "tuhāra": ['mw'],
    "tuj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tuja": ['ap90', 'mw'],
    "tujase": ['cae'],
    "tuji": ['cae', 'gra', 'mw'],
    "tujjamāna": ['cped'],
    "tujya": ['cae', 'mw'],
    "tujyo": ['bhs'],
    "tuk": ['cae', 'ddsa', 'mw'],
    "tuka": ['gra', 'mw'],
    "tukhāra": ['mw'],
    "tukka": ['mw'],
    "tukkhāra": ['mw'],
    "tukkhāraḥ": ['ap90'],
    "tukākṣīrī": ['mw'],
    "tukṣa": ['mw'],
    "tul": ['ap90', 'cae', 'ddsa', 'mw'],
    "tula": ['bhs', 'cped', 'mw'],
    "tulabha": ['mw'],
    "tulabhīya": ['mw'],
    "tulaji": ['mw'],
    "tulaka": ['bhs', 'mw'],
    "tulakuci": ['bhs', 'mw'],
    "tulana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "tulanaṃ": ['ap90'],
    "tulanā": ['bhs', 'cped', 'mw'],
    "tulasi": ['mw'],
    "tulasikā": ['mw'],
    "tulasāriṇī": ['ap90', 'mw'],
    "tulasī": ['ap90', 'mw'],
    "tulasīdveṣā": ['mw'],
    "tulasīpattra": ['mw'],
    "tulasīvivāha": ['mw'],
    "tulasīvṛndāvana": ['mw'],
    "tulayati": ['cped'],
    "tulayitabba": ['cped'],
    "tulayitvā": ['cped'],
    "tulayitvāna": ['cped'],
    "tuletabba": ['cped'],
    "tuleti": ['cped'],
    "tuletvā": ['cped'],
    "tuli": ['mw'],
    "tulikā": ['cped', 'mw'],
    "tulima": ['cae', 'mw'],
    "tulinī": ['mw'],
    "tulita": ['ap90', 'cped', 'mw'],
    "tuliya": ['cped'],
    "tuliḥ": ['ap90'],
    "tulla": ['cped'],
    "tulvala": ['mw'],
    "tulya": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "tulyabala": ['mw'],
    "tulyabhāgya": ['cae'],
    "tulyabhāvanā": ['mw'],
    "tulyacodana": ['mw'],
    "tulyadarśana": ['mw'],
    "tulyagariman": ['mw'],
    "tulyaguṇa": ['mw'],
    "tulyajātīya": ['cae', 'mw'],
    "tulyakakṣa": ['ddsa', 'mw'],
    "tulyakarmaka": ['mw'],
    "tulyakrama": ['mw'],
    "tulyakulya": ['mw'],
    "tulyakāla": ['mw'],
    "tulyakālatva": ['mw'],
    "tulyakālīya": ['mw'],
    "tulyalakṣman": ['mw'],
    "tulyam": ['mw'],
    "tulyamūlya": ['mw'],
    "tulyanaktaṃdina": ['mw'],
    "tulyanindāstuti": ['mw'],
    "tulyanāman": ['mw'],
    "tulyaprabhāva": ['cae'],
    "tulyapāna": ['mw'],
    "tulyarūpa": ['mw'],
    "tulyasevi(n)": ['cped'],
    "tulyatarka": ['mw'],
    "tulyatejas": ['mw'],
    "tulyatva": ['mw'],
    "tulyatā": ['mw'],
    "tulyavarcas": ['cae'],
    "tulyavat": ['mw'],
    "tulyavayas": ['mw'],
    "tulyavaṃśa": ['mw'],
    "tulyavikrama": ['mw'],
    "tulyavīrya": ['mw'],
    "tulyavṛtti": ['mw'],
    "tulyayogitā": ['mw'],
    "tulyayogopamā": ['cae', 'mw'],
    "tulyaśas": ['mw'],
    "tulyaśikha": ['mw'],
    "tulyaśodhana": ['mw'],
    "tulyaśruti": ['mw'],
    "tulyaśuddhi": ['mw'],
    "tulyaśīlatā": ['cae'],
    "tulyodyoga": ['mw'],
    "tulyābhidhāna": ['mw'],
    "tulyābhijana": ['cae'],
    "tulyākṛti": ['ddsa', 'mw'],
    "tulyāntaram": ['cae', 'mw'],
    "tulyānumāna": ['mw'],
    "tulyārimitratā": ['cae'],
    "tulyārtha": ['cae', 'mw'],
    "tulyātulya": ['mw'],
    "tulyāvastha": ['cae', 'mw'],
    "tulā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "tulābhavānī": ['mw'],
    "tulābhāra": ['mw'],
    "tulābhṛt": ['mw'],
    "tulābīja": ['mw'],
    "tulādhara": ['mw'],
    "tulādhaṭa": ['mw'],
    "tulādhiroha": ['mw'],
    "tulādhirohaṇa": ['mw'],
    "tulādhāna": ['mw'],
    "tulādhāra": ['cped', 'mw'],
    "tulādhāraṇa": ['cae', 'mw'],
    "tulādāna": ['mw'],
    "tulāguḍa": ['mw'],
    "tulākoṣa": ['mw'],
    "tulākoṭi": ['cae', 'ddsa', 'mw'],
    "tulākūṭa": ['bhs'],
    "tulāmāna": ['cae', 'mw'],
    "tulāpaddhati": ['mw'],
    "tulāparīkṣā": ['mw'],
    "tulāpragraha": ['mw'],
    "tulāpragrāha": ['mw'],
    "tulāpuruṣa": ['mw'],
    "tulāpuruṣadāna": ['mw'],
    "tulāpuṃs": ['mw'],
    "tulāsūtra": ['mw'],
    "tulāvant": ['cae'],
    "tulāvarārdha": ['mw'],
    "tulāvarārdhya": ['mw'],
    "tulāvat": ['mw'],
    "tulāyaṣṭi": ['cae', 'mw'],
    "tulāyoga": ['cae'],
    "tuma": ['cped'],
    "tumala": ['mw'],
    "tumb": ['mw'],
    "tumba": ['cae', 'cped', 'ddsa', 'mw'],
    "tumbaka": ['bhs', 'mw'],
    "tumbakaṭāha": ['cped'],
    "tumbakī": ['mw'],
    "tumbara": ['mw'],
    "tumbaraka": ['mw'],
    "tumbaru": ['mw'],
    "tumbarī": ['mw'],
    "tumbavana": ['mw'],
    "tumbavīṇa": ['mw'],
    "tumbi": ['mw'],
    "tumbikā": ['mw'],
    "tumbinī": ['mw'],
    "tumbuka": ['mw'],
    "tumbukin": ['mw'],
    "tumbuma": ['mw'],
    "tumbura": ['mw'],
    "tumburu": ['bhs', 'cae', 'mw'],
    "tumburī": ['mw'],
    "tumbā": ['mw'],
    "tumbī": ['mw'],
    "tumbīpuṣpa": ['mw'],
    "tumbīvīṇā": ['mw'],
    "tumbīvīṇāpriya": ['mw'],
    "tumhādisa": ['cped'],
    "tumiñja": ['mw'],
    "tump": ['mw'],
    "tumph": ['mw'],
    "tumra": ['ap90', 'cae', 'gra', 'mw'],
    "tumula": ['ap90', 'cae', 'ddsa', 'mw'],
    "tumura": ['mw'],
    "tuna": ['mw'],
    "tund": ['mw'],
    "tunda": ['cae', 'ddsa', 'mw'],
    "tundakūpikā": ['mw'],
    "tundakūpī": ['mw'],
    "tundaparimārja": ['mw'],
    "tundaparimārjaka": ['mw'],
    "tundaparimṛja": ['mw'],
    "tundavat": ['mw'],
    "tundi": ['mw'],
    "tundibha": ['mw'],
    "tundika": ['mw'],
    "tundikara": ['mw'],
    "tundikā": ['mw'],
    "tundila": ['cae', 'mw'],
    "tundilaphalā": ['mw'],
    "tundilita": ['mw'],
    "tundilīkaraṇa": ['mw'],
    "tundin": ['mw'],
    "tundita": ['mw'],
    "tundādi": ['mw'],
    "tundī": ['mw'],
    "tunna": ['ap90', 'cped', 'mw'],
    "tunnaka": ['mw'],
    "tunnasevanī": ['mw'],
    "tunnavāya": ['cae', 'cped', 'ddsa', 'mw'],
    "tunnā": ['mw'],
    "tunyu": ['mw'],
    "tuota": ['gra'],
    "tuoti": ['gra'],
    "tup": ['ap90', 'mw'],
    "tuph": ['mw'],
    "tur": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tura": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "turaga": ['cae', 'ddsa', 'mw'],
    "turagabrahmacaryaka": ['mw'],
    "turagadaitya": ['mw'],
    "turagadānava": ['mw'],
    "turagagandhā": ['mw'],
    "turagakriyāvat": ['mw'],
    "turagakāntā": ['mw'],
    "turagakāntāmukha": ['mw'],
    "turagalīlaka": ['mw'],
    "turagamedha": ['mw'],
    "turagamukha": ['mw'],
    "turaganīlatāla": ['mw'],
    "turagaparicāraka": ['mw'],
    "turagapriya": ['mw'],
    "turagapātaka": ['mw'],
    "turagarakṣa": ['mw'],
    "turagaratha": ['mw'],
    "turagavāhyālī": ['mw'],
    "turagaḥ": ['ap90'],
    "turagin": ['ap90', 'mw'],
    "turagopacāraka": ['mw'],
    "turagānana": ['mw'],
    "turagāroha": ['mw'],
    "turagātu": ['cae', 'gra', 'mw'],
    "turagī": ['mw'],
    "turaka": ['cae', 'mw'],
    "turakin": ['ap90', 'mw'],
    "turakva": ['mw'],
    "turakvaḥ": ['ap90'],
    "turam": ['cae', 'mw'],
    "turaspeya": ['gra', 'mw'],
    "turati": ['cped'],
    "turayā": ['cae', 'gra', 'mw'],
    "turaśravas": ['mw'],
    "turaṃga": ['cae', 'mw'],
    "turaṃgadveṣaṇī": ['mw'],
    "turaṃgagandhā": ['mw'],
    "turaṃgakaḥ": ['ap90'],
    "turaṃgalīla": ['mw'],
    "turaṃgama": ['cae', 'mw'],
    "turaṃgamaratha": ['mw'],
    "turaṃgamaśālā": ['mw'],
    "turaṃgamaḥ": ['ap90'],
    "turaṃgamedha": ['mw'],
    "turaṃgamukha": ['mw'],
    "turaṃgamī": ['mw'],
    "turaṃganātha": ['mw'],
    "turaṃgapriya": ['mw'],
    "turaṃgaskandha": ['mw'],
    "turaṃgasthāna": ['mw'],
    "turaṃgasādin": ['mw'],
    "turaṃgavadana": ['mw'],
    "turaṃgavaktra": ['mw'],
    "turaṃgayāyin": ['mw'],
    "turaṃgaḥ": ['ap90'],
    "turaṃgin": ['cae', 'mw'],
    "turaṃgiṇī": ['mw'],
    "turaṃgāhvā": ['mw'],
    "turaṃgāri": ['mw'],
    "turaṃgī": ['mw'],
    "turaṃgībhūya": ['mw'],
    "turaṅga": ['ddsa'],
    "turaṅgama": ['ddsa'],
    "turaṅgībhū": ['ddsa'],
    "turaṇa": ['ap90', 'cae', 'gra', 'mw'],
    "turaṇy": ['cae', 'gra'],
    "turaṇya": ['mw'],
    "turaṇyasad": ['gra', 'mw'],
    "turaṇyati": ['ap90'],
    "turaṇyu": ['cae', 'gra', 'mw'],
    "turaṣka": ['mw'],
    "turi": ['cae', 'gra', 'mw'],
    "turita": ['cped'],
    "turiya": ['bhs', 'cped'],
    "turphari": ['gra', 'mw'],
    "turpharī": ['ap90'],
    "turpharītu": ['gra', 'mw'],
    "turuṣka": ['cae', 'ddsa', 'mw'],
    "turuṣkadatta": ['mw'],
    "turuṣkagaṇḍa": ['mw'],
    "turuṣkakarpūra": ['mw'],
    "turuṣkāḥ": ['ap90'],
    "turv": ['ap90', 'cae', 'ddsa', 'mw'],
    "turva": ['cae', 'gra', 'mw'],
    "turvan": ['gra'],
    "turvasu": ['cae', 'mw'],
    "turvaśa": ['cae', 'gra', 'mw'],
    "turvaśāyadu": ['gra'],
    "turvaṇe": ['cae', 'mw'],
    "turvaṇi": ['ap90', 'cae', 'gra', 'mw'],
    "turvīti": ['cae', 'ddsa', 'gra', 'mw'],
    "turya": ['ap90', 'cae', 'ddsa', 'mw'],
    "turyabhikṣā": ['mw'],
    "turyauhī": ['mw'],
    "turyavah": ['cae', 'ddsa', 'mw'],
    "turyayantra": ['mw'],
    "turyā": ['cae', 'mw'],
    "turyāśra": ['mw'],
    "turāsāh": ['ap90'],
    "turāyaṇa": ['cae', 'mw'],
    "turāyaṇaṃ": ['ap90'],
    "turāṣāh": ['ddsa', 'gra', 'mw'],
    "turī": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "turīpa": ['cae', 'gra', 'mw'],
    "turīya": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "turīyabhāga": ['mw'],
    "turīyabhāj": ['cae', 'mw'],
    "turīyaka": ['ap90', 'ddsa', 'mw'],
    "turīyakavaca": ['mw'],
    "turīyamāna": ['mw'],
    "turīyavarṇa": ['mw'],
    "turīyāditya": ['mw'],
    "turīyārdha": ['mw'],
    "turīyātīta": ['mw'],
    "tus": ['ap90', 'mw'],
    "tusa": ['ap90'],
    "tusita": ['cped'],
    "tussati": ['cped'],
    "tusta": ['mw'],
    "tustaṃ": ['ap90'],
    "tutha": ['mw'],
    "tutta": ['cped'],
    "tutth": ['ap90'],
    "tuttha": ['cae', 'ddsa', 'mw'],
    "tutthaka": ['mw'],
    "tutthakaṃ": ['ap90'],
    "tutthaya": ['mw'],
    "tutthaḥ": ['ap90'],
    "tutthā": ['mw'],
    "tutthāñjana": ['mw'],
    "tuturvaṇi": ['cae', 'gra', 'mw'],
    "tutāta": ['mw'],
    "tuvara": ['ap90', 'mw'],
    "tuvarikā": ['ap90'],
    "tuvaṁtuvaṁpesuññamusāvādā": ['cped'],
    "tuvaṭaṁ": ['cped'],
    "tuvaṭṭa": ['cped'],
    "tuvaṭṭati": ['cped'],
    "tuvaṭṭavagga": ['cped'],
    "tuvaṭṭayati": ['cped'],
    "tuvaṭṭayuṁ": ['cped'],
    "tuvaṭṭenta": ['cped'],
    "tuvaṭṭesum": ['cped'],
    "tuvaṭṭeti": ['cped'],
    "tuvaṭṭitabba": ['cped'],
    "tuvi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tuvibrahman": ['gra', 'mw'],
    "tuvibādha": ['gra', 'mw'],
    "tuvideṣṇa": ['gra', 'mw'],
    "tuvidyumna": ['cae', 'gra', 'mw'],
    "tuvigra": ['gra', 'mw'],
    "tuvigri": ['gra', 'mw'],
    "tuvigrābha": ['gra', 'mw'],
    "tuvigrīva": ['gra', 'mw'],
    "tuvijāta": ['cae', 'gra', 'mw'],
    "tuvikratu": ['cae', 'gra', 'mw'],
    "tuvikūrmi": ['cae', 'gra', 'mw'],
    "tuvikūrmin": ['cae', 'gra', 'mw'],
    "tuvikṣa": ['gra', 'mw'],
    "tuvikṣatra": ['mw'],
    "tuvimagha": ['gra', 'mw'],
    "tuvimanyu": ['cae', 'gra', 'mw'],
    "tuvimrakṣa": ['gra', 'mw'],
    "tuvimātra": ['gra', 'mw'],
    "tuvinṛmṇa": ['cae', 'gra', 'mw'],
    "tuviojas": ['gra'],
    "tuviprati": ['gra', 'mw'],
    "tuvirādhas": ['cae', 'gra', 'mw'],
    "tuvis": ['ap90', 'cae', 'gra'],
    "tuvivāja": ['gra', 'mw'],
    "tuviśagma": ['gra', 'mw'],
    "tuviśravas": ['gra', 'mw'],
    "tuviśuṣma": ['gra', 'mw'],
    "tuviṣ": ['mw'],
    "tuviṣmant": ['cae'],
    "tuviṣmat": ['ddsa', 'gra', 'mw'],
    "tuviṣvan": ['cae', 'gra', 'mw'],
    "tuviṣvaṇas": ['cae', 'gra', 'mw'],
    "tuviṣvaṇi": ['cae', 'gra', 'mw'],
    "tuviṣṭama": ['cae', 'gra', 'mw'],
    "tuvyojas": ['gra', 'mw'],
    "tuvī": ['mw'],
    "tuvīmagha": ['cae', 'gra', 'mw'],
    "tuvīrava": ['cae', 'gra', 'mw'],
    "tuvīravas": ['mw'],
    "tuvīravat": ['gra'],
    "tuñja": ['cae', 'gra', 'mw'],
    "tuñjīna": ['ddsa', 'mw'],
    "tuādatta": ['gra'],
    "tuādūta": ['gra'],
    "tuānid": ['gra'],
    "tuāvasu": ['gra'],
    "tuāvat": ['gra'],
    "tuāy": ['gra'],
    "tuāyu": ['gra'],
    "tuāyā": ['gra'],
    "tuāūta": ['gra'],
    "tuś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tuḍ": ['ap90', 'mw'],
    "tuḍiga": ['mw'],
    "tuḍī": ['mw'],
    "tuḍḍ": ['ap90', 'mw'],
    "tuḥkhāra": ['ddsa', 'mw'],
    "tuṃb": ['ap90'],
    "tuṃbaraḥ": ['ap90'],
    "tuṃbaruḥ": ['ap90'],
    "tuṃbaḥ": ['ap90'],
    "tuṃbiḥ": ['ap90'],
    "tuṃburuḥ": ['ap90'],
    "tuṃdavat": ['ap90'],
    "tuṃdaṃ": ['ap90'],
    "tuṃdi": ['ap90'],
    "tuṃdika": ['ap90'],
    "tuṃdikaraḥ": ['ap90'],
    "tuṃga": ['ap90'],
    "tuṃgin": ['ap90'],
    "tuṃgī": ['ap90'],
    "tuṃj": ['ap90'],
    "tuṃḍ": ['ap90'],
    "tuṃḍakerikā": ['ap90'],
    "tuṃḍaṃ": ['ap90'],
    "tuṃḍibha": ['ap90'],
    "tuṃḍika": ['ap90'],
    "tuṃḍikerī": ['ap90'],
    "tuṃḍila": ['ap90'],
    "tuṃḍin": ['ap90'],
    "tuṃḍiḥ": ['ap90'],
    "tuṅga": ['cae', 'ddsa', 'mw'],
    "tuṅgabala": ['cae', 'mw'],
    "tuṅgabha": ['mw'],
    "tuṅgabhadra": ['mw'],
    "tuṅgabhadrā": ['mw'],
    "tuṅgabhadrāmāhātmya": ['mw'],
    "tuṅgabīja": ['mw'],
    "tuṅgadhanvan": ['mw'],
    "tuṅgaka": ['mw'],
    "tuṅgakūṭa": ['mw'],
    "tuṅgamukha": ['mw'],
    "tuṅganābha": ['mw'],
    "tuṅganāsa": ['mw'],
    "tuṅganāsika": ['cped'],
    "tuṅganāsikā": ['mw'],
    "tuṅganāsikī": ['mw'],
    "tuṅganātha": ['mw'],
    "tuṅgaprastha": ['mw'],
    "tuṅgatva": ['mw'],
    "tuṅgaveṇā": ['mw'],
    "tuṅgaśaila": ['mw'],
    "tuṅgaśailamāhātmya": ['mw'],
    "tuṅgaśekhara": ['mw'],
    "tuṅgeśvara": ['mw'],
    "tuṅgeśvarāpaṇa": ['mw'],
    "tuṅgiman": ['cae', 'ddsa', 'mw'],
    "tuṅgin": ['ddsa', 'mw'],
    "tuṅginī": ['mw'],
    "tuṅgā": ['mw'],
    "tuṅgī": ['mw'],
    "tuṅgīnāsa": ['mw'],
    "tuṅgīpati": ['mw'],
    "tuṅgīśa": ['mw'],
    "tuṇ": ['ap90', 'mw'],
    "tuṇa": ['bhs'],
    "tuṇatuṇāyati": ['bhs'],
    "tuṇava": ['bhs'],
    "tuṇhika": ['cped'],
    "tuṇhiṁ": ['cped'],
    "tuṇhī": ['cped'],
    "tuṇhī bhavati": ['cped'],
    "tuṇhībhāva": ['cped'],
    "tuṇhībhūta": ['cped'],
    "tuṇhīṁ": ['cped'],
    "tuṇi": ['mw'],
    "tuṇika": ['mw'],
    "tuṇḍ": ['mw'],
    "tuṇḍa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "tuṇḍadeva": ['mw'],
    "tuṇḍadevabhakta": ['mw'],
    "tuṇḍaka": ['bhs'],
    "tuṇḍakerikā": ['mw'],
    "tuṇḍakerī": ['mw'],
    "tuṇḍaturika": ['bhs'],
    "tuṇḍela": ['cae', 'mw'],
    "tuṇḍi": ['mw'],
    "tuṇḍibha": ['cae', 'ddsa', 'mw'],
    "tuṇḍicela": ['bhs', 'mw'],
    "tuṇḍika": ['cae', 'mw'],
    "tuṇḍikera": ['cae', 'mw'],
    "tuṇḍikerin": ['mw'],
    "tuṇḍikerī": ['mw'],
    "tuṇḍikeśī": ['mw'],
    "tuṇḍikira": ['cped'],
    "tuṇḍikā": ['mw'],
    "tuṇḍikīra": ['cped'],
    "tuṇḍila": ['cae', 'mw'],
    "tuṇḍin": ['mw'],
    "tuṇḍī": ['mw'],
    "tuṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tuṣa": ['cae', 'ddsa', 'mw'],
    "tuṣadhānya": ['cae', 'mw'],
    "tuṣagraha": ['mw'],
    "tuṣaja": ['mw'],
    "tuṣajaka": ['mw'],
    "tuṣakhaṇḍana": ['ddsa', 'mw'],
    "tuṣapakva": ['mw'],
    "tuṣasāra": ['mw'],
    "tuṣaḥ": ['ap90'],
    "tuṣita": ['bhs', 'cae', 'ddsa', 'mw'],
    "tuṣitakāyika": ['mw'],
    "tuṣitā": ['mw'],
    "tuṣitāḥ": ['ap90'],
    "tuṣodaka": ['mw'],
    "tuṣottha": ['mw'],
    "tuṣya": ['mw'],
    "tuṣyaḥ": ['ap90'],
    "tuṣāgni": ['cae', 'mw'],
    "tuṣāmbu": ['cae', 'mw'],
    "tuṣānala": ['cae', 'mw'],
    "tuṣāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "tuṣāradyuti": ['cae', 'mw'],
    "tuṣāragaura": ['mw'],
    "tuṣāragharaṭṭikā": ['mw'],
    "tuṣāragiri": ['cae', 'mw'],
    "tuṣārakara": ['cae', 'mw'],
    "tuṣārakaṇa": ['cae', 'mw'],
    "tuṣārakiraṇa": ['cae', 'mw'],
    "tuṣāramūrti": ['mw'],
    "tuṣārapatana": ['cae', 'mw'],
    "tuṣāraraśmi": ['cae', 'mw'],
    "tuṣārartu": ['mw'],
    "tuṣārasruti": ['mw'],
    "tuṣāratviṣ": ['mw'],
    "tuṣāravarṣa": ['mw'],
    "tuṣāravarṣin": ['mw'],
    "tuṣāraśaila": ['mw'],
    "tuṣāraśikharin": ['mw'],
    "tuṣārādri": ['cae', 'mw'],
    "tuṣārāṃśu": ['cae', 'ddsa', 'mw'],
    "tuṣṭa": ['ap90', 'mw'],
    "tuṣṭaprakṛti": ['cae'],
    "tuṣṭi": ['cae', 'ddsa', 'mw'],
    "tuṣṭida": ['mw'],
    "tuṣṭijanana": ['mw'],
    "tuṣṭikara": ['cae', 'mw'],
    "tuṣṭimant": ['cae'],
    "tuṣṭimat": ['mw'],
    "tuṣṭiḥ": ['ap90'],
    "tuṣṭuḥ": ['ap90'],
    "tuṣṭūṣita": ['mw'],
    "tuṭ": ['ap90', 'mw'],
    "tuṭi": ['mw'],
    "tuṭituṭa": ['mw'],
    "tuṭituṭaḥ": ['ap90'],
    "tuṭuma": ['mw'],
    "tuṭumaḥ": ['ap90'],
    "tuṭṭha": ['cped'],
    "tuṭṭhabba": ['cped'],
    "tuṭṭhi": ['cped'],
    "tv-": ['cped'],
    "tva": ['cae', 'ddsa', 'gra', 'mw'],
    "tvac": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tvaca": ['bhs', 'cae', 'ddsa', 'mw'],
    "tvacana": ['cae', 'mw'],
    "tvacanaṃ": ['ap90'],
    "tvacas": ['ap90', 'mw'],
    "tvacasya": ['cae', 'mw'],
    "tvacaya": ['mw'],
    "tvacayati": ['ap90'],
    "tvacaṃ": ['ap90'],
    "tvacisāra": ['mw'],
    "tvacita": ['mw'],
    "tvaciṣṭha": ['mw'],
    "tvacya": ['ap90', 'cae', 'mw'],
    "tvacā": ['ap90', 'mw'],
    "tvacāpattra": ['mw'],
    "tvacāyani": ['mw'],
    "tvacīyas": ['mw'],
    "tvad": ['ap90', 'cae', 'ddsa', 'mw'],
    "tvadanya": ['mw'],
    "tvadartham": ['mw'],
    "tvadarthe": ['mw'],
    "tvadbhaya": ['mw'],
    "tvadbhū": ['mw'],
    "tvaddevatya": ['mw'],
    "tvaddhita": ['mw'],
    "tvadgṛha": ['mw'],
    "tvadrik": ['cae', 'gra', 'mw'],
    "tvadvidha": ['ap90', 'cae', 'ddsa', 'mw'],
    "tvadvivācana": ['mw'],
    "tvadviyoga": ['mw'],
    "tvadya": ['mw'],
    "tvadyoni": ['mw'],
    "tvadānīm": ['mw'],
    "tvadīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "tvag": ['mw'],
    "tvagasthibhūta": ['mw'],
    "tvagasthiśeṣa": ['mw'],
    "tvagaṅkura": ['mw'],
    "tvagbheda": ['cae', 'mw'],
    "tvagbhedaka": ['cae', 'mw'],
    "tvagbhāra": ['bhs'],
    "tvagbila": ['mw'],
    "tvagdoṣa": ['cae', 'mw'],
    "tvagdoṣin": ['mw'],
    "tvagdoṣāpahā": ['mw'],
    "tvagdoṣāri": ['mw'],
    "tvagela": ['mw'],
    "tvaggandha": ['mw'],
    "tvagindriya": ['mw'],
    "tvagja": ['mw'],
    "tvagjala": ['mw'],
    "tvagroga": ['mw'],
    "tvaguttarāsaṅgavat": ['ddsa', 'mw'],
    "tvagutthā": ['mw'],
    "tvagvat": ['mw'],
    "tvagākṣīrī": ['mw'],
    "tvai": ['mw'],
    "tvak": ['mw'],
    "tvakam": ['mw'],
    "tvakat": ['mw'],
    "tvakatpitṛka": ['mw'],
    "tvakchada": ['mw'],
    "tvakcheda": ['mw'],
    "tvakchedana": ['mw'],
    "tvakkaṇḍura": ['mw'],
    "tvakkṣīrā": ['mw'],
    "tvakkṣīrī": ['mw'],
    "tvakpalita": ['mw'],
    "tvakparipuṭana": ['mw'],
    "tvakparṇī": ['mw'],
    "tvakpattra": ['mw'],
    "tvakpattraka": ['mw'],
    "tvakpattrī": ['mw'],
    "tvakpuṣpa": ['mw'],
    "tvakpuṣpikā": ['mw'],
    "tvakpuṣpī": ['mw'],
    "tvakpāka": ['mw'],
    "tvakpāruṣya": ['mw'],
    "tvaksraja": ['mw'],
    "tvaksugandha": ['mw'],
    "tvaksugandhā": ['mw'],
    "tvaksvādvī": ['mw'],
    "tvaksāra": ['cae', 'ddsa', 'mw'],
    "tvaksārabhedinī": ['mw'],
    "tvaksāravyavahāravat": ['mw'],
    "tvaksārā": ['mw'],
    "tvaktaraṃgaka": ['mw'],
    "tvaktobila": ['mw'],
    "tvaktra": ['cae', 'ddsa', 'mw'],
    "tvaktrāṇa": ['mw'],
    "tvakśūnyatā": ['mw'],
    "tvakṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tvakṣas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tvakṣīyas": ['gra', 'mw'],
    "tvakṣīyaṃs": ['cae'],
    "tvam": ['cae', 'ddsa'],
    "tvamīdṛśa": ['bhs'],
    "tvan": ['mw'],
    "tvanmanya": ['mw'],
    "tvanmaya": ['cae', 'ddsa', 'mw'],
    "tvantā": ['mw'],
    "tvar": ['ap90', 'cae', 'ddsa', 'mw'],
    "tvara": ['mw'],
    "tvarayā": ['mw'],
    "tvaraṇa": ['cae', 'mw'],
    "tvaraṇaṃ": ['ap90'],
    "tvaraṇīya": ['mw'],
    "tvari": ['mw'],
    "tvarita": ['ap90', 'cae', 'ddsa', 'mw'],
    "tvaritadāna": ['cae'],
    "tvaritagati": ['mw'],
    "tvaritaka": ['mw'],
    "tvaritakā": ['mw'],
    "tvaritam": ['mw'],
    "tvaritaram": ['mw'],
    "tvaritata": ['mw'],
    "tvaritavikrama": ['mw'],
    "tvaritodita": ['mw'],
    "tvaritā": ['mw'],
    "tvarā": ['ap90', 'ddsa', 'mw'],
    "tvarāroha": ['mw'],
    "tvarāvant": ['cae'],
    "tvarāvat": ['mw'],
    "tvarāyasya": ['mw'],
    "tvarāyukta": ['mw'],
    "tvat": ['ddsa', 'mw'],
    "tvatka": ['mw'],
    "tvatkapitṛka": ['mw'],
    "tvatkṛta": ['cae', 'ddsa', 'mw'],
    "tvatpitṛ": ['mw'],
    "tvatprasūta": ['mw'],
    "tvatpratīkṣin": ['mw'],
    "tvatsaṃgama": ['mw'],
    "tvattanāt": ['mw'],
    "tvattara": ['mw'],
    "tvattas": ['cae', 'mw'],
    "tvayata": ['gra', 'mw'],
    "tvañc": ['mw'],
    "tvaṁ": ['cped'],
    "tvaṁ mūlakaṁ": ['cped'],
    "tvaṃ": ['mw'],
    "tvaṃg": ['ap90'],
    "tvaṃkāra": ['cae', 'mw'],
    "tvaṃkāraḥ": ['ap90'],
    "tvaṃkṛtya": ['mw'],
    "tvaṃpada": ['cae'],
    "tvaṃsādṛśaka": ['bhs'],
    "tvaṅ": ['mw'],
    "tvaṅg": ['cae', 'ddsa', 'mw'],
    "tvaṅkāra": ['ddsa'],
    "tvaṅmala": ['mw'],
    "tvaṅmaya": ['mw'],
    "tvaṅmāṃsāsthimaya": ['ddsa', 'mw'],
    "tvaṣṭa": ['ap90', 'mw'],
    "tvaṣṭi": ['cae', 'ddsa', 'mw'],
    "tvaṣṭiḥ": ['ap90'],
    "tvaṣṭumat": ['mw'],
    "tvaṣṭāvarūtrī": ['mw'],
    "tvaṣṭīmatī": ['mw'],
    "tvaṣṭṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tvaṣṭṛdevatya": ['mw'],
    "tvaṣṭṛmat": ['gra', 'mw'],
    "tve": ['ddsa'],
    "tveṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tveṣadyumna": ['cae', 'gra', 'mw'],
    "tveṣanṛmṇa": ['cae', 'gra', 'mw'],
    "tveṣapratīka": ['cae', 'gra', 'mw'],
    "tveṣaratha": ['gra', 'mw'],
    "tveṣas": ['cae', 'gra', 'mw'],
    "tveṣasaṃdṛś": ['cae', 'gra', 'mw'],
    "tveṣatha": ['cae', 'gra', 'mw'],
    "tveṣayāma": ['cae', 'gra', 'mw'],
    "tveṣia": ['gra'],
    "tveṣin": ['gra', 'mw'],
    "tveṣita": ['gra', 'mw'],
    "tveṣya": ['cae', 'gra', 'mw'],
    "tviṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tviṣi": ['cae', 'ddsa', 'gra', 'mw'],
    "tviṣimat": ['mw'],
    "tviṣita": ['mw'],
    "tviṣiḥ": ['ap90'],
    "tviṣā": ['ap90', 'mw'],
    "tviṣāmpati": ['mw'],
    "tviṣāmīśa": ['mw'],
    "tviṣīmat": ['gra', 'mw'],
    "tviṭpati": ['mw'],
    "tvota": ['cae', 'ddsa', 'gra', 'mw'],
    "tvoti": ['cae', 'gra', 'mw'],
    "tvā": ['gra'],
    "tvāca": ['ap90', 'mw'],
    "tvādatta": ['cae', 'gra', 'mw'],
    "tvādāta": ['cae', 'gra', 'mw'],
    "tvādūta": ['cae', 'gra', 'mw'],
    "tvādṛś": ['ap90', 'cae', 'ddsa', 'mw'],
    "tvādṛśa": ['cae', 'mw'],
    "tvādṛśaka": ['mw'],
    "tvāhata": ['gra'],
    "tvāmāhuti": ['mw'],
    "tvānid": ['gra', 'mw'],
    "tvātputra": ['mw'],
    "tvāva": ['mw'],
    "tvāvant": ['cae'],
    "tvāvasu": ['gra', 'mw'],
    "tvāvat": ['ddsa', 'gra', 'mw'],
    "tvāvṛdha": ['gra', 'mw'],
    "tvāy": ['gra'],
    "tvāyant": ['cae'],
    "tvāyat": ['mw'],
    "tvāyu": ['cae', 'gra', 'mw'],
    "tvāyā": ['cae', 'ddsa', 'gra', 'mw'],
    "tvāṃkāma": ['gra', 'mw'],
    "tvāṣṭara": ['gra'],
    "tvāṣṭra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tvāṣṭreya": ['mw'],
    "tvāṣṭrī": ['mw'],
    "tvāṣṭrīsāman": ['mw'],
    "tvāṣṭī": ['mw'],
    "tvī": ['cae'],
    "ty-": ['cped'],
    "tya": ['cae', 'ddsa', 'gra', 'mw'],
    "tyad": ['cae', 'ddsa', 'mw'],
    "tyadam": ['mw'],
    "tyagnāyis": ['mw'],
    "tyaj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tyaja": ['mw'],
    "tyajana": ['cae', 'ddsa', 'mw'],
    "tyajanaṃ": ['ap90'],
    "tyajanīya": ['mw'],
    "tyajapa": ['mw'],
    "tyajas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tyajita": ['mw'],
    "tyakta": ['ap90', 'mw'],
    "tyaktajīvita": ['cae', 'ddsa', 'mw'],
    "tyaktalajja": ['mw'],
    "tyaktaprāṇa": ['mw'],
    "tyaktapunaḥsvikṛta": ['mw'],
    "tyaktavat": ['mw'],
    "tyaktavidhi": ['mw'],
    "tyaktavya": ['cae', 'ddsa', 'mw'],
    "tyaktaśrī": ['mw'],
    "tyaktukāma": ['cae', 'ddsa', 'mw'],
    "tyaktvā": ['cae', 'ddsa'],
    "tyaktāgni": ['cae', 'ddsa', 'mw'],
    "tyaktātman": ['mw'],
    "tyaktṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "tyatra": ['mw'],
    "tyatratya": ['mw'],
    "tyugra": ['mw'],
    "tyāda": ['mw'],
    "tyādāyani": ['mw'],
    "tyādṛś": ['mw'],
    "tyādṛśa": ['mw'],
    "tyāga": ['cae', 'ddsa', 'gra', 'mw'],
    "tyāgagatā": ['bhs', 'mw'],
    "tyāgavant": ['bhs'],
    "tyāgayuta": ['mw'],
    "tyāgaśīla": ['mw'],
    "tyāgaśīlatā": ['mw'],
    "tyāgaḥ": ['ap90'],
    "tyāgima": ['mw'],
    "tyāgin": ['ap90', 'cae', 'ddsa', 'mw'],
    "tyāgitā": ['cae', 'ddsa', 'mw'],
    "tyājaka": ['cae', 'ddsa', 'mw'],
    "tyājana": ['cae', 'mw'],
    "tyājita": ['ap90', 'mw'],
    "tyājya": ['ap90', 'cae', 'mw'],
    "tā": ['mw'],
    "tābuva": ['mw'],
    "tācchabdya": ['mw'],
    "tācchīlika": ['mw'],
    "tācchīlikaḥ": ['ap90'],
    "tācchīlya": ['ddsa', 'mw'],
    "tācchīlyaṃ": ['ap90'],
    "tādarthika": ['ap90', 'mw'],
    "tādarthya": ['cae', 'ddsa', 'mw'],
    "tādarthyaṃ": ['ap90'],
    "tādarthyena": ['mw'],
    "tādavasthya": ['mw'],
    "tāddharmya": ['mw'],
    "tāddhita": ['mw'],
    "tādi(n)": ['cped'],
    "tādin": ['bhs'],
    "tādisa": ['cped'],
    "tādisaka": ['cped'],
    "tādrūpya": ['cae', 'ddsa', 'mw'],
    "tādurī": ['mw'],
    "tādvidhya": ['cae', 'ddsa', 'mw'],
    "tādātmaka": ['mw'],
    "tādātmya": ['cae', 'ddsa', 'mw'],
    "tādātmyaṃ": ['ap90'],
    "tādāyani": ['mw'],
    "tādītnā": ['cae', 'gra', 'mw'],
    "tādṛ": ['bhs'],
    "tādṛg": ['mw'],
    "tādṛgbhāva": ['mw'],
    "tādṛgguṇa": ['cae', 'ddsa', 'mw'],
    "tādṛgrūpa": ['cae', 'mw'],
    "tādṛgrūpavant": ['cae'],
    "tādṛgrūpavat": ['mw'],
    "tādṛgvidha": ['cae', 'mw'],
    "tādṛk": ['mw'],
    "tādṛkṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "tādṛś": ['cae', 'ddsa', 'gra', 'mw'],
    "tādṛśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "tādṛśaka": ['bhs'],
    "tāhi": ['bhs'],
    "tājadbhaṅga": ['mw'],
    "tājak": ['cae', 'mw'],
    "tājaka": ['cae', 'mw'],
    "tājat": ['ap90', 'cae', 'mw'],
    "tājika": ['cae', 'ddsa', 'mw'],
    "tākṣaka": ['mw'],
    "tākṣaśila": ['mw'],
    "tākṣaṇya": ['mw'],
    "tākṣaṇyaḥ": ['ap90'],
    "tākṣṇa": ['cae', 'ddsa', 'mw'],
    "tāla": ['bhs', 'cae', 'ddsa', 'mw'],
    "tālabaddha": ['mw'],
    "tālabhaṅga": ['mw'],
    "tālabhaṭa": ['mw'],
    "tālabhṛt": ['mw'],
    "tālacara": ['mw'],
    "tāladhvaja": ['bhs', 'cae', 'mw'],
    "tāladhvajā": ['mw'],
    "tāladhvajī": ['mw'],
    "tāladhāraka": ['mw'],
    "tāladruma": ['cae', 'mw'],
    "tālagarbha": ['mw'],
    "tālaja": ['cae', 'mw'],
    "tālajaṅgha": ['cae', 'ddsa', 'mw'],
    "tālajaṭā": ['mw'],
    "tālajña": ['mw'],
    "tālaka": ['bhs', 'cae', 'mw'],
    "tālakaṃ": ['ap90'],
    "tālaketu": ['cae', 'mw'],
    "tālakeśvara": ['mw'],
    "tālakābha": ['mw'],
    "tālakī": ['mw'],
    "tālakṣīra": ['mw'],
    "tālakṣīraka": ['mw'],
    "tālalakṣman": ['mw'],
    "tālamardaka": ['mw'],
    "tālamardala": ['mw'],
    "tālamaya": ['mw'],
    "tālamukta": ['bhs'],
    "tālamātra": ['mw'],
    "tālamātram": ['mw'],
    "tālamūlikā": ['mw'],
    "tālamūlī": ['mw'],
    "tālana": ['cae', 'ddsa'],
    "tālanavamī": ['mw'],
    "tālaparṇa": ['mw'],
    "tālaparṇī": ['mw'],
    "tālapattra": ['cae', 'mw'],
    "tālapattrī": ['mw'],
    "tālapat‍tra": ['ddsa'],
    "tālaphala": ['cae', 'mw'],
    "tālapralamba": ['mw'],
    "tālapramāṇa": ['mw'],
    "tālapuṣpaka": ['mw'],
    "tālarecanaka": ['mw'],
    "tālasvana": ['cae', 'mw'],
    "tālavalī": ['mw'],
    "tālavana": ['mw'],
    "tālavastu": ['bhs'],
    "tālavaṇṭaka": ['bhs'],
    "tālavecanaka": ['mw'],
    "tālavya": ['ap90', 'cae', 'ddsa', 'mw'],
    "tālavādya": ['mw'],
    "tālavṛndaka": ['bhs'],
    "tālavṛnta": ['cae', 'mw'],
    "tālavṛntaka": ['mw'],
    "tālavṛntanivāsin": ['mw'],
    "tālavṛntībhū": ['mw'],
    "tālayantra": ['mw'],
    "tālaśabda": ['cae', 'mw'],
    "tālaśuddha": ['mw'],
    "tālaśīla": ['mw'],
    "tālaḥ": ['ap90'],
    "tālaṃkaḥ": ['ap90'],
    "tālaṅkīkṛ": ['ddsa', 'mw'],
    "tāli": ['mw'],
    "tālika": ['bhs', 'mw'],
    "tālikaḥ": ['ap90'],
    "tālikaṭa": ['mw'],
    "tālikā": ['ddsa', 'mw'],
    "tālin": ['ap90', 'ddsa', 'mw'],
    "tālita": ['mw'],
    "tālitanagara": ['mw'],
    "tālitaṃ": ['ap90'],
    "tāliśa": ['mw'],
    "tāliśaḥ": ['ap90'],
    "tālodghāṭinī": ['mw'],
    "tālopaniṣad": ['mw'],
    "tālpa": ['cae', 'ddsa', 'mw'],
    "tālu": ['ap90', 'cae', 'ddsa', 'mw'],
    "tālugalapraśoṣa": ['mw'],
    "tāluja": ['mw'],
    "tālujihva": ['mw'],
    "tālujihvikā": ['mw'],
    "tāluka": ['cae', 'mw'],
    "tālukaṃ": ['ap90'],
    "tālukaṇṭaka": ['mw'],
    "tālukā": ['bhs', 'mw'],
    "tālukṣya": ['mw'],
    "tālukṣyāyaṇī": ['mw'],
    "tālumūla": ['mw'],
    "tāluna": ['mw'],
    "tālunāśa": ['mw'],
    "tālupuppuṭa": ['mw'],
    "tālupāka": ['mw'],
    "tālupāta": ['mw'],
    "tālupīḍaka": ['mw'],
    "tālura": ['mw'],
    "tālusthāna": ['mw'],
    "tāluvi": ['mw'],
    "tāluvidradhī": ['mw'],
    "tāluviśoṣaṇa": ['mw'],
    "tāluśoṣa": ['mw'],
    "tālā": ['mw'],
    "tālādhyāya": ['mw'],
    "tālādi": ['mw'],
    "tālākaṭa": ['mw'],
    "tālākhyā": ['mw'],
    "tālāna": ['mw'],
    "tālāpacara": ['mw'],
    "tālāvacara": ['ddsa', 'mw'],
    "tālāvacaraṇa": ['mw'],
    "tālāṅga": ['mw'],
    "tālāṅka": ['mw'],
    "tālī": ['ap90', 'ddsa', 'mw'],
    "tālīpattra": ['mw'],
    "tālīpaṭṭa": ['mw'],
    "tālīpuṭa": ['mw'],
    "tālīrasaja": ['mw'],
    "tālīyaka": ['cae', 'ddsa', 'mw'],
    "tālīśa": ['bhs', 'mw'],
    "tālīśaka": ['mw'],
    "tālīśapattra": ['mw'],
    "tālūka": ['bhs'],
    "tālūra": ['cae', 'mw'],
    "tālūraḥ": ['ap90'],
    "tālūṣaka": ['cae', 'ddsa', 'mw'],
    "tālūṣakaṃ": ['ap90'],
    "tāma": ['cae', 'ddsa', 'mw'],
    "tāmala": ['mw'],
    "tāmalakī": ['mw'],
    "tāmalipta": ['mw'],
    "tāmaliptaka": ['mw'],
    "tāmaliptī": ['mw'],
    "tāmam": ['mw'],
    "tāmara": ['mw'],
    "tāmarasa": ['cae', 'ddsa', 'mw'],
    "tāmarasaṃ": ['ap90'],
    "tāmarasekṣaṇā": ['mw'],
    "tāmarasī": ['mw'],
    "tāmaraṃ": ['ap90'],
    "tāmarā": ['bhs'],
    "tāmasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "tāmasaguṇa": ['mw'],
    "tāmasakīlaka": ['mw'],
    "tāmasalīnā": ['mw'],
    "tāmasatapaḥśīla": ['mw'],
    "tāmasika": ['ap90', 'mw'],
    "tāmasī": ['mw'],
    "tāmaḥ": ['ap90'],
    "tāmbala": ['cae', 'ddsa', 'mw'],
    "tāmbūla": ['cae', 'ddsa', 'mw'],
    "tāmbūlabhakṣaṇa": ['mw'],
    "tāmbūlada": ['mw'],
    "tāmbūladhara": ['mw'],
    "tāmbūladāyaka": ['mw'],
    "tāmbūladāyinī": ['mw'],
    "tāmbūlaja": ['mw'],
    "tāmbūlakaraṅka": ['mw'],
    "tāmbūlakaraṅkavāha": ['mw'],
    "tāmbūlakaraṅkavāhinī": ['mw'],
    "tāmbūlapattra": ['mw'],
    "tāmbūlapeṭikā": ['mw'],
    "tāmbūlarāga": ['mw'],
    "tāmbūlavallikā": ['mw'],
    "tāmbūlavallī": ['mw'],
    "tāmbūlavāhaka": ['mw'],
    "tāmbūlavāhinī": ['mw'],
    "tāmbūlavīṭikā": ['cae', 'mw'],
    "tāmbūlika": ['cae', 'ddsa', 'mw'],
    "tāmbūlikasarpa": ['mw'],
    "tāmbūlin": ['mw'],
    "tāmbūlādhikāra": ['mw'],
    "tāmbūlākta": ['mw'],
    "tāmbūlī": ['mw'],
    "tāmi": ['cae', 'ddsa', 'mw'],
    "tāmisra": ['cae', 'ddsa', 'mw'],
    "tāmisraḥ": ['ap90'],
    "tāmra": ['ap90', 'cae', 'ddsa', 'mw'],
    "tāmrabīja": ['mw'],
    "tāmracakṣus": ['mw'],
    "tāmracūḍa": ['cae', 'mw'],
    "tāmracūḍabhairava": ['mw'],
    "tāmracūḍaka": ['mw'],
    "tāmracūḍā": ['mw'],
    "tāmradhvaja": ['mw'],
    "tāmradhātu": ['mw'],
    "tāmradhūmra": ['cae', 'mw'],
    "tāmradru": ['mw'],
    "tāmradugdhā": ['mw'],
    "tāmradugdhī": ['mw'],
    "tāmradvīpa": ['bhs', 'mw'],
    "tāmradvīpaka": ['bhs', 'mw'],
    "tāmragarbha": ['mw'],
    "tāmraguhā": ['mw'],
    "tāmraja": ['mw'],
    "tāmrajākṣa": ['mw'],
    "tāmrajīva": ['mw'],
    "tāmraka": ['ddsa', 'mw'],
    "tāmrakarṇī": ['mw'],
    "tāmrakaṃ": ['ap90'],
    "tāmrakaṇṭaka": ['mw'],
    "tāmrakili": ['mw'],
    "tāmrakrami": ['mw'],
    "tāmrakuṇḍa": ['mw'],
    "tāmrakuṭṭa": ['cae', 'mw'],
    "tāmrakuṭṭaka": ['mw'],
    "tāmrakuṭṭī": ['mw'],
    "tāmrakāra": ['mw'],
    "tāmrakūṭa": ['mw'],
    "tāmrakṛmi": ['mw'],
    "tāmralipta": ['ap90', 'cae', 'mw'],
    "tāmraliptaka": ['mw'],
    "tāmraliptarṣi": ['mw'],
    "tāmraliptikā": ['mw'],
    "tāmraliptā": ['mw'],
    "tāmraliptī": ['mw'],
    "tāmraloha": ['bhs'],
    "tāmramaya": ['cae', 'mw'],
    "tāmramukha": ['mw'],
    "tāmramāraṇa": ['mw'],
    "tāmramūlā": ['mw'],
    "tāmramṛga": ['mw'],
    "tāmramṛṣṭānulepin": ['mw'],
    "tāmranakha": ['cae', 'mw'],
    "tāmranakhatā": ['mw'],
    "tāmranetra": ['mw'],
    "tāmrapakṣa": ['mw'],
    "tāmrapakṣā": ['mw'],
    "tāmrapallava": ['mw'],
    "tāmraparṇa": ['mw'],
    "tāmraparṇi": ['mw'],
    "tāmraparṇī": ['ap90', 'mw'],
    "tāmraparṇītaṭāka": ['mw'],
    "tāmraparṇīya": ['mw'],
    "tāmrapattra": ['mw'],
    "tāmrapattraka": ['mw'],
    "tāmrapaṭṭa": ['cae', 'mw'],
    "tāmraphala": ['mw'],
    "tāmraphalaka": ['mw'],
    "tāmrapuṣpa": ['mw'],
    "tāmrapuṣpaka": ['mw'],
    "tāmrapuṣpikā": ['mw'],
    "tāmrapuṣpī": ['mw'],
    "tāmrapādī": ['mw'],
    "tāmrapākin": ['mw'],
    "tāmrapātra": ['cae', 'mw'],
    "tāmrapātramaya": ['mw'],
    "tāmrarajas": ['mw'],
    "tāmrarasā": ['mw'],
    "tāmrarasāyanī": ['mw'],
    "tāmraratha": ['mw'],
    "tāmrasena": ['mw'],
    "tāmrasāgara": ['mw'],
    "tāmrasāra": ['mw'],
    "tāmrasāraka": ['mw'],
    "tāmratanu": ['mw'],
    "tāmratapta": ['mw'],
    "tāmratrapuja": ['mw'],
    "tāmratuṇḍa": ['mw'],
    "tāmratva": ['mw'],
    "tāmratā": ['mw'],
    "tāmravallī": ['mw'],
    "tāmravarṇa": ['cae', 'mw'],
    "tāmravarṇaka": ['mw'],
    "tāmravarṇā": ['mw'],
    "tāmravarṇī": ['mw'],
    "tāmravṛkṣa": ['mw'],
    "tāmravṛnta": ['mw'],
    "tāmravṛntā": ['mw'],
    "tāmrayaṃ": ['ap90'],
    "tāmraśikhin": ['mw'],
    "tāmraśāsana": ['mw'],
    "tāmraśāṭīya": ['bhs', 'mw'],
    "tāmrika": ['ap90', 'cae', 'ddsa', 'mw'],
    "tāmrikā": ['mw'],
    "tāmriman": ['ap90', 'mw'],
    "tāmropajīvin": ['mw'],
    "tāmroṣṭha": ['ddsa', 'mw'],
    "tāmrya": ['mw'],
    "tāmrā": ['mw'],
    "tāmrābha": ['mw'],
    "tāmrādharoṣṭha": ['mw'],
    "tāmrākhya": ['mw'],
    "tāmrāku": ['mw'],
    "tāmrākṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "tāmrārdha": ['mw'],
    "tāmrāruṇa": ['mw'],
    "tāmrāruṇā": ['mw'],
    "tāmrāvatī": ['mw'],
    "tāmrāyasa": ['mw'],
    "tāmrāyaṇa": ['mw'],
    "tāmrāśman": ['mw'],
    "tāmrāśva": ['mw'],
    "tāmrāṭavī": ['bhs', 'mw'],
    "tāmrī": ['mw'],
    "tāmrīkṛ": ['mw'],
    "tāmu": ['mw'],
    "tāmya": ['mw'],
    "tāmāleya": ['mw'],
    "tāmī": ['cae', 'mw'],
    "tāna": ['cae', 'ddsa', 'mw'],
    "tānabhaṭṭa": ['mw'],
    "tānakarman": ['mw'],
    "tānasvara": ['mw'],
    "tānava": ['cae', 'ddsa', 'mw'],
    "tānavakṛt": ['mw'],
    "tānavaṃ": ['ap90'],
    "tānavya": ['mw'],
    "tānavyāyanī": ['mw'],
    "tānaḥ": ['ap90'],
    "tānika": ['bhs'],
    "tānta": ['mw'],
    "tāntava": ['cae', 'ddsa', 'mw'],
    "tāntavya": ['mw'],
    "tāntavyāyanī": ['mw'],
    "tānti": ['cae', 'mw'],
    "tāntra": ['cae', 'ddsa', 'mw'],
    "tāntrika": ['cae', 'ddsa', 'mw'],
    "tāntuvāyya": ['mw'],
    "tāntānta": ['mw'],
    "tānua": ['gra'],
    "tānuka": ['mw'],
    "tānva": ['gra', 'mw'],
    "tānvaṅga": ['ddsa', 'mw'],
    "tānūnaptra": ['cae', 'ddsa', 'mw'],
    "tānūnaptrapātra": ['mw'],
    "tānūnaptratva": ['mw'],
    "tānūnaptrin": ['mw'],
    "tānūnapāta": ['mw'],
    "tānūra": ['mw'],
    "tānūraḥ": ['ap90'],
    "tāpa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "tāpabhṛt": ['mw'],
    "tāpada": ['mw'],
    "tāpaharī": ['mw'],
    "tāpaka": ['ap90', 'cae', 'mw'],
    "tāpakṣetra": ['mw'],
    "tāpana": ['ap90', 'bhs', 'cae', 'mw'],
    "tāpanā": ['mw'],
    "tāpanī": ['mw'],
    "tāpanīya": ['ap90', 'bhs', 'cae', 'mw'],
    "tāpanīyopaniṣad": ['cae', 'mw'],
    "tāpasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "tāpasadruma": ['mw'],
    "tāpasadrumasaṃnibhā": ['mw'],
    "tāpasaja": ['mw'],
    "tāpasapattra": ['mw'],
    "tāpasapattrī": ['mw'],
    "tāpasapriya": ['mw'],
    "tāpasapriyā": ['mw'],
    "tāpasasūtra": ['bhs'],
    "tāpasataru": ['mw'],
    "tāpasavatsarāja": ['mw'],
    "tāpasaveṣabhṛt": ['cae'],
    "tāpasavṛkṣa": ['mw'],
    "tāpasekṣu": ['mw'],
    "tāpaseṣṭa": ['mw'],
    "tāpasveda": ['mw'],
    "tāpasya": ['cae', 'mw'],
    "tāpasyaṃ": ['ap90'],
    "tāpasādhyuṣita": ['mw'],
    "tāpasāraṇya": ['mw'],
    "tāpasāyani": ['mw'],
    "tāpasī": ['mw'],
    "tāpatya": ['mw'],
    "tāpatyaḥ": ['ap90'],
    "tāpayati": ['bhs'],
    "tāpayitṛ": ['mw'],
    "tāpayiṣṇu": ['cae', 'ddsa', 'gra', 'mw'],
    "tāpayāna": ['ap90'],
    "tāpaścita": ['cae', 'mw'],
    "tāpaḥ": ['ap90'],
    "tāpeśvaratīrtha": ['mw'],
    "tāpiccha": ['cae', 'ddsa', 'mw'],
    "tāpicchaḥ": ['ap90'],
    "tāpika": ['mw'],
    "tāpikā": ['mw'],
    "tāpin": ['ap90', 'cae', 'ddsa', 'mw'],
    "tāpinī": ['mw'],
    "tāpita": ['ap90', 'mw'],
    "tāpiñcha": ['cae', 'mw'],
    "tāpiñja": ['mw'],
    "tāpya": ['bhs', 'cae', 'ddsa', 'mw'],
    "tāpyaka": ['mw'],
    "tāpyaṃ": ['ap90'],
    "tāpyutthasaṃjñaka": ['mw'],
    "tāpāyana": ['mw'],
    "tāpī": ['ap90', 'mw'],
    "tāpīja": ['mw'],
    "tāpījaṃ": ['ap90'],
    "tāpīmāhātmya": ['mw'],
    "tāpīsamudbhava": ['mw'],
    "tāpītaṭa": ['mw'],
    "tāpītaṭadeśa": ['mw'],
    "tāra": ['ap90', 'cae', 'ddsa', 'mw'],
    "tāradī": ['mw'],
    "tāradīrgha": ['ddsa', 'mw'],
    "tārahemābha": ['mw'],
    "tāraja": ['mw'],
    "tāraka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "tārakadvādaśī": ['mw'],
    "tārakajaya": ['mw'],
    "tārakajit": ['mw'],
    "tārakamantra": ['mw'],
    "tārakaripu": ['ddsa', 'mw'],
    "tārakasūdana": ['mw'],
    "tārakatva": ['mw'],
    "tārakatīrtha": ['mw'],
    "tārakavadha": ['mw'],
    "tārakavairin": ['mw'],
    "tārakaḥ": ['ap90'],
    "tārakeśvara": ['cae', 'ddsa', 'mw'],
    "tārakita": ['ap90', 'ddsa', 'mw'],
    "tārakiṇī": ['ap90', 'mw'],
    "tārakopama": ['bhs'],
    "tārakopaniṣad": ['cae', 'mw'],
    "tārakā": ['ap90', 'mw'],
    "tārakādi": ['mw'],
    "tārakākṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "tārakāmaya": ['mw'],
    "tārakāmāna": ['mw'],
    "tārakāntaka": ['cae', 'mw'],
    "tārakāri": ['mw'],
    "tārakārāja": ['cae', 'ddsa', 'mw'],
    "tārakāyana": ['mw'],
    "tārakṣiti": ['mw'],
    "tārala": ['ap90', 'mw'],
    "tāralya": ['cae', 'ddsa', 'mw'],
    "tāralyaṃ": ['ap90'],
    "tāramākṣika": ['mw'],
    "tāramūla": ['mw'],
    "tāranāda": ['mw'],
    "tāranātha": ['mw'],
    "tārapatana": ['mw'],
    "tārapaṇyika": ['bhs'],
    "tārapaṭṭaka": ['mw'],
    "tārapuṣpa": ['mw'],
    "tārapāla": ['mw'],
    "tārasthāna": ['mw'],
    "tārasvara": ['mw'],
    "tārasāra": ['mw'],
    "tāratama": ['mw'],
    "tāratamya": ['cae', 'ddsa', 'mw'],
    "tāratamyaṃ": ['ap90'],
    "tāratamyena": ['mw'],
    "tārataṇḍula": ['mw'],
    "tāratāra": ['mw'],
    "tārava": ['cae', 'mw'],
    "tāravimalā": ['mw'],
    "tārayantī": ['mw'],
    "tārayitṛ": ['mw'],
    "tāraśuddhikara": ['mw'],
    "tāraśuddhikṛt": ['mw'],
    "tāraṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "tāraṇeya": ['mw'],
    "tāraṇi": ['mw'],
    "tāraṇiḥ": ['ap90'],
    "tāraṭī": ['mw'],
    "tārcha": ['mw'],
    "tārendra": ['mw'],
    "tāreya": ['mw'],
    "tāreyaḥ": ['ap90'],
    "tāreśvararāja": ['bhs'],
    "tārika": ['cae', 'ddsa', 'mw'],
    "tārikaṃ": ['ap90'],
    "tārikā": ['mw'],
    "tārin": ['ap90', 'cae', 'mw'],
    "tārita": ['ap90', 'mw'],
    "tāritṛ": ['mw'],
    "tāriṇī": ['bhs', 'mw'],
    "tāriṇīkalpa": ['mw'],
    "tāriṇītantra": ['mw'],
    "tārka": ['mw'],
    "tārkava": ['ap90', 'mw'],
    "tārkika": ['cae', 'ddsa', 'mw'],
    "tārkikacūḍāmaṇi": ['mw'],
    "tārkikakārikā": ['mw'],
    "tārkikarakṣā": ['mw'],
    "tārkikatva": ['mw'],
    "tārkikaśiromaṇi": ['mw'],
    "tārkikaḥ": ['ap90'],
    "tārkṣa": ['cae', 'mw'],
    "tārkṣaja": ['mw'],
    "tārkṣaka": ['mw'],
    "tārkṣaputra": ['mw'],
    "tārkṣasuta": ['mw'],
    "tārkṣaḥ": ['ap90'],
    "tārkṣya": ['cae', 'ddsa', 'gra', 'mw'],
    "tārkṣyadhvaja": ['mw'],
    "tārkṣyaja": ['mw'],
    "tārkṣyalakṣaṇa": ['mw'],
    "tārkṣyanāyaka": ['mw'],
    "tārkṣyanāśaka": ['mw'],
    "tārkṣyaprasava": ['mw'],
    "tārkṣyaputra": ['mw'],
    "tārkṣyaratna": ['ddsa', 'mw'],
    "tārkṣyaratnamaya": ['mw'],
    "tārkṣyasuta": ['mw'],
    "tārkṣyasāman": ['mw'],
    "tārkṣyaśaila": ['mw'],
    "tārkṣyaḥ": ['ap90'],
    "tārkṣyāsana": ['mw'],
    "tārkṣyāyaṇa": ['mw'],
    "tārkṣyāyaṇabhakta": ['mw'],
    "tārkṣyāyaṇi": ['mw'],
    "tārkṣyāyaṇī": ['mw'],
    "tārkṣāka": ['mw'],
    "tārkṣī": ['mw'],
    "tārpya": ['cae', 'mw'],
    "tārtīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "tārtīyaka": ['mw'],
    "tārtīyasavana": ['mw'],
    "tārtīyasavanika": ['mw'],
    "tārtīyāhnika": ['mw'],
    "tārtīyīka": ['ap90', 'cae', 'mw'],
    "tārtīyīkatā": ['mw'],
    "tārukṣya": ['mw'],
    "tārukṣyāyaṇī": ['mw'],
    "tārukṣāyaṇi": ['mw'],
    "tāruṇa": ['ap90', 'mw'],
    "tāruṇya": ['cae', 'ddsa', 'mw'],
    "tāruṇyaṃ": ['ap90'],
    "tārya": ['ap90', 'cae', 'ddsa', 'mw'],
    "tārā": ['ap90', 'bhs', 'ddsa', 'mw'],
    "tārābha": ['mw'],
    "tārābhra": ['mw'],
    "tārābhūṣā": ['mw'],
    "tārācakra": ['mw'],
    "tārācandra": ['mw'],
    "tārācandrodaya": ['mw'],
    "tārācchāya": ['mw'],
    "tārādharma": ['mw'],
    "tārādhipa": ['cae', 'mw'],
    "tārādhipati": ['mw'],
    "tārādhīśa": ['mw'],
    "tārāgaṇa": ['mw'],
    "tārāgraha": ['mw'],
    "tārāguru": ['mw'],
    "tārāj": ['mw'],
    "tārākavaca": ['mw'],
    "tārākāruṇya": ['mw'],
    "tārākṣa": ['bhs', 'cae', 'mw'],
    "tārāmaitraka": ['cae', 'mw'],
    "tārāmantra": ['mw'],
    "tārāmaya": ['cae', 'mw'],
    "tārāmaṇḍala": ['mw'],
    "tārāmṛga": ['cae', 'mw'],
    "tārāpaharaṇa": ['mw'],
    "tārāpajjhaṭikā": ['mw'],
    "tārāpatha": ['mw'],
    "tārāpati": ['cae', 'mw'],
    "tārāpramāṇa": ['mw'],
    "tārāpura": ['mw'],
    "tārāpīḍa": ['mw'],
    "tārāramaṇa": ['ddsa', 'mw'],
    "tārāri": ['mw'],
    "tārārūpa": ['mw'],
    "tārātīrtha": ['mw'],
    "tārāvaloka": ['mw'],
    "tārāvalī": ['mw'],
    "tārāvana": ['bhs'],
    "tārāvarta": ['bhs'],
    "tārāvartman": ['mw'],
    "tārāvarṣa": ['mw'],
    "tārāvatī": ['mw'],
    "tārāvilāpa": ['mw'],
    "tārāvilāsa": ['mw'],
    "tārāvākya": ['mw'],
    "tārāyaṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "tārāyaṇaḥ": ['ap90'],
    "tārṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "tārṇabindavīya": ['mw'],
    "tārṇaka": ['mw'],
    "tārṇakarṇa": ['mw'],
    "tārṇakarṇīputra": ['mw'],
    "tārṇi": ['mw'],
    "tārṇiḥ": ['ap90'],
    "tārṇāyana": ['mw'],
    "tārṣṭāgha": ['cae', 'mw'],
    "tāsa": ['cped'],
    "tāsayati": ['cped'],
    "tāseti": ['cped'],
    "tāskarya": ['cae', 'ddsa', 'mw'],
    "tāskaryaṃ": ['ap90'],
    "tāspandra": ['mw'],
    "tāspindra": ['mw'],
    "tāsīra": ['mw'],
    "tāsūna": ['cae', 'ddsa', 'mw'],
    "tāt": ['cae', 'ddsa', 'gra', 'mw'],
    "tāta": ['cae', 'cped', 'ddsa', 'mw'],
    "tātagu": ['mw'],
    "tātajanayitrī": ['mw'],
    "tātaka": ['bhs'],
    "tātala": ['ap90', 'mw'],
    "tātana": ['mw'],
    "tātanaḥ": ['ap90'],
    "tātatulya": ['mw'],
    "tātaḥ": ['ap90'],
    "tāthābhāvya": ['mw'],
    "tāthāgata": ['bhs'],
    "tāti": ['mw'],
    "tātiḥ": ['ap90'],
    "tātkarmya": ['ddsa', 'mw'],
    "tātkālika": ['ap90', 'cae', 'mw'],
    "tātkālikatva": ['mw'],
    "tātkālya": ['mw'],
    "tātkālyaṃ": ['ap90'],
    "tātparya": ['cae', 'ddsa', 'mw'],
    "tātparyabodhinī": ['mw'],
    "tātparyaka": ['ap90', 'mw'],
    "tātparyanirṇaya": ['mw'],
    "tātparyapariśuddhi": ['mw'],
    "tātparyatas": ['mw'],
    "tātparyavid": ['mw'],
    "tātparyaṃ": ['ap90'],
    "tātparyeṇa": ['mw'],
    "tātparyārtha": ['mw'],
    "tātsthya": ['cae', 'ddsa', 'mw'],
    "tātstomya": ['mw'],
    "tāttvika": ['ap90', 'cae', 'ddsa', 'mw'],
    "tāttvikatva": ['mw'],
    "tātya": ['cae', 'gra', 'mw'],
    "tātārya": ['mw'],
    "tātṛpi": ['cae', 'gra', 'mw'],
    "tātṛṣāṇa": ['mw'],
    "tāva": ['cped'],
    "tāvac": ['mw'],
    "tāvacchas": ['cae', 'mw'],
    "tāvacchata": ['cae', 'ddsa', 'mw'],
    "tāvad": ['mw'],
    "tāvaddhā": ['ap90', 'ddsa', 'mw'],
    "tāvaddvayasa": ['mw'],
    "tāvadeva": ['cped'],
    "tāvadguṇa": ['cae', 'mw'],
    "tāvadguṇita": ['mw'],
    "tāvadvarṣa": ['mw'],
    "tāvadvidha": ['mw'],
    "tāvadvyakta": ['mw'],
    "tāvadvīryavat": ['mw'],
    "tāvajjyok": ['cae', 'ddsa', 'mw'],
    "tāvaka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tāvakālika": ['bhs', 'cped'],
    "tāvakālikaṁ": ['cped'],
    "tāvakīna": ['cae', 'mw'],
    "tāvan": ['mw'],
    "tāvanmāna": ['mw'],
    "tāvanmātra": ['cae', 'ddsa', 'mw'],
    "tāvanmātre": ['mw'],
    "tāvant": ['cae'],
    "tāvanta": ['mw'],
    "tāvantaraṃ": ['bhs'],
    "tāvara": ['mw'],
    "tāvaraṃ": ['ap90'],
    "tāvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "tāvataka": ['cped'],
    "tāvataka vā": ['cped'],
    "tāvatakena": ['cped'],
    "tāvati": ['mw'],
    "tāvatihaṁ": ['cped'],
    "tāvatika": ['ap90', 'cped', 'mw'],
    "tāvatitha": ['mw'],
    "tāvatiṁsa": ['cped'],
    "tāvatka": ['mw'],
    "tāvatkālam": ['cae', 'ddsa', 'mw'],
    "tāvatkṛtvas": ['cae', 'mw'],
    "tāvatphala": ['cae', 'mw'],
    "tāvatpriya": ['mw'],
    "tāvatsūtra": ['mw'],
    "tāvattaka": ['cped'],
    "tāvattakaṃ": ['bhs'],
    "tāvattāt": ['cae', 'mw'],
    "tāvatā": ['cped', 'mw'],
    "tāviṣa": ['mw'],
    "tāviṣaḥ": ['ap90'],
    "tāviṣī": ['mw'],
    "tāvura": ['mw'],
    "tāvuri": ['mw'],
    "tāvuriḥ": ['ap90'],
    "tāvuru": ['mw'],
    "tāvīṣa": ['mw'],
    "tāvīṣaḥ": ['ap90'],
    "tāvīṣī": ['mw'],
    "tāy": ['ap90', 'cae', 'mw'],
    "tāya": ['ddsa', 'mw'],
    "tāyana": ['cae', 'ddsa', 'mw'],
    "tāyanaṃ": ['ap90'],
    "tāyaṇa": ['bhs'],
    "tāyika": ['mw'],
    "tāyin": ['bhs', 'mw'],
    "tāyu": ['cae', 'ddsa', 'gra', 'mw'],
    "tāyuḥ": ['ap90'],
    "tāyādara": ['mw'],
    "tāḍa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "tāḍagha": ['mw'],
    "tāḍaghāta": ['mw'],
    "tāḍaka": ['bhs', 'cae', 'mw'],
    "tāḍakeya": ['mw'],
    "tāḍakeyaḥ": ['ap90'],
    "tāḍakā": ['ap90', 'mw'],
    "tāḍakāphala": ['mw'],
    "tāḍakāyana": ['mw'],
    "tāḍam": ['mw'],
    "tāḍana": ['ap90', 'cae', 'ddsa', 'mw'],
    "tāḍanā": ['bhs'],
    "tāḍanī": ['mw'],
    "tāḍanīya": ['cae', 'mw'],
    "tāḍapattra": ['mw'],
    "tāḍavakra": ['mw'],
    "tāḍayitṛ": ['mw'],
    "tāḍaṃkaḥ": ['ap90'],
    "tāḍaṅka": ['ddsa', 'mw'],
    "tāḍaṅkīkṛ": ['mw'],
    "tāḍi": ['mw'],
    "tāḍikā": ['mw'],
    "tāḍita": ['ap90', 'mw'],
    "tāḍiḥ": ['ap90'],
    "tāḍula": ['ap90', 'mw'],
    "tāḍya": ['cae', 'ddsa', 'mw'],
    "tāḍyamāna": ['ap90'],
    "tāḍāga": ['ap90', 'cae', 'ddsa', 'mw'],
    "tāḍāvacara": ['bhs', 'mw'],
    "tāḍī": ['mw'],
    "tāḍīdala": ['mw'],
    "tāḍīpuṭa": ['mw'],
    "tāḷacchidda": ['cped'],
    "tāḷacchiggala": ['cped'],
    "tāḷayati": ['cped'],
    "tāḷeti": ['cped'],
    "tāḷetvā": ['cped'],
    "tāḷāvacara": ['cped'],
    "tāṃbūlaṃ": ['ap90'],
    "tāṃbūlikaḥ": ['ap90'],
    "tāṃbūlin": ['ap90'],
    "tāṃbūlī": ['ap90'],
    "tāṃta": ['ap90'],
    "tāṃtava": ['ap90'],
    "tāṃtrika": ['ap90'],
    "tāṃtuvāyiḥ": ['ap90'],
    "tāṃḍavaḥ": ['ap90'],
    "tāṃḍavita": ['ap90'],
    "tāṃḍiḥ": ['ap90'],
    "tāṇa": ['cped'],
    "tāṇḍa": ['mw'],
    "tāṇḍaka": ['mw'],
    "tāṇḍava": ['cae', 'ddsa', 'mw'],
    "tāṇḍavapriya": ['mw'],
    "tāṇḍavatālika": ['mw'],
    "tāṇḍavayitṛ": ['mw'],
    "tāṇḍavika": ['bhs'],
    "tāṇḍavikā": ['mw'],
    "tāṇḍavita": ['cae', 'mw'],
    "tāṇḍi": ['mw'],
    "tāṇḍin": ['mw'],
    "tāṇḍya": ['cae', 'ddsa', 'mw'],
    "tāṇḍyabrāhmaṇa": ['cae', 'mw'],
    "tāṇḍyāyana": ['mw'],
    "tāṭakā": ['ap90'],
    "tāṭasthya": ['mw'],
    "tāṭasthyaṃ": ['ap90'],
    "tāṭaṃkaḥ": ['ap90'],
    "tāṭaṅka": ['mw'],
    "tāṭaṅkin": ['mw'],
    "tīha": ['cped'],
    "tīk": ['ap90', 'mw'],
    "tīkṣṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "tīkṣṇabhaṅga": ['cae'],
    "tīkṣṇabuddhi": ['mw'],
    "tīkṣṇadaṃṣṭra": ['cae', 'mw'],
    "tīkṣṇadaṃṣṭraka": ['mw'],
    "tīkṣṇadaṃṣṭratā": ['mw'],
    "tīkṣṇadaṇḍa": ['cae', 'mw'],
    "tīkṣṇadhāra": ['cae', 'mw'],
    "tīkṣṇadhāraka": ['mw'],
    "tīkṣṇagandha": ['bhs', 'mw'],
    "tīkṣṇagandhaka": ['mw'],
    "tīkṣṇagandhā": ['mw'],
    "tīkṣṇahṛdaya": ['cae'],
    "tīkṣṇahṛdayatva": ['mw'],
    "tīkṣṇaka": ['mw'],
    "tīkṣṇakalka": ['mw'],
    "tīkṣṇakanda": ['mw'],
    "tīkṣṇakara": ['cae', 'ddsa', 'mw'],
    "tīkṣṇakarmakṛt": ['mw'],
    "tīkṣṇakarman": ['mw'],
    "tīkṣṇakaṇṭa": ['mw'],
    "tīkṣṇakaṇṭaka": ['mw'],
    "tīkṣṇakaṇṭakā": ['mw'],
    "tīkṣṇakāntā": ['mw'],
    "tīkṣṇalavaṇa": ['mw'],
    "tīkṣṇaloha": ['mw'],
    "tīkṣṇamañjarī": ['mw'],
    "tīkṣṇamārga": ['mw'],
    "tīkṣṇamūla": ['mw'],
    "tīkṣṇanāsika": ['mw'],
    "tīkṣṇapattra": ['mw'],
    "tīkṣṇaphala": ['mw'],
    "tīkṣṇapriya": ['mw'],
    "tīkṣṇapuṣpa": ['mw'],
    "tīkṣṇapuṣpā": ['mw'],
    "tīkṣṇarasa": ['mw'],
    "tīkṣṇarasadāyin": ['mw'],
    "tīkṣṇaraśmi": ['mw'],
    "tīkṣṇarūpin": ['mw'],
    "tīkṣṇasrotas": ['mw'],
    "tīkṣṇasāra": ['mw'],
    "tīkṣṇasārā": ['mw'],
    "tīkṣṇataila": ['mw'],
    "tīkṣṇatara": ['mw'],
    "tīkṣṇataṇḍulā": ['mw'],
    "tīkṣṇatuṇḍa": ['mw'],
    "tīkṣṇatva": ['mw'],
    "tīkṣṇatā": ['cae', 'mw'],
    "tīkṣṇavaktra": ['mw'],
    "tīkṣṇavarman": ['mw'],
    "tīkṣṇavega": ['mw'],
    "tīkṣṇavipāka": ['cae', 'mw'],
    "tīkṣṇaviṣa": ['mw'],
    "tīkṣṇavṛṣaṇa": ['mw'],
    "tīkṣṇaśastra": ['mw'],
    "tīkṣṇaśigru": ['mw'],
    "tīkṣṇaśūka": ['mw'],
    "tīkṣṇaśṛṅga": ['cae', 'gra', 'mw'],
    "tīkṣṇaśṛṅgī": ['mw'],
    "tīkṣṇaṃ": ['bhs'],
    "tīkṣṇendriya": ['bhs'],
    "tīkṣṇeṣu": ['cae', 'mw'],
    "tīkṣṇopāya": ['mw'],
    "tīkṣṇā": ['mw'],
    "tīkṣṇāgni": ['mw'],
    "tīkṣṇāgra": ['cae', 'mw'],
    "tīkṣṇāmla": ['cae', 'mw'],
    "tīkṣṇārcis": ['cae', 'mw'],
    "tīkṣṇāyasa": ['mw'],
    "tīkṣṇāṃśu": ['cae', 'ddsa', 'mw'],
    "tīkṣṇāṃśudehaprabhava": ['mw'],
    "tīkṣṇāṃśutanaya": ['mw'],
    "tīkṣṇīyas": ['mw'],
    "tīm": ['ap90', 'mw'],
    "tīmana": ['mw'],
    "tīmayati": ['bhs'],
    "tīr": ['ap90'],
    "tīra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "tīrabhukti": ['mw'],
    "tīrabhuktīya": ['mw'],
    "tīrabhāj": ['mw'],
    "tīradassi(n)": ['cped'],
    "tīragraha": ['mw'],
    "tīraja": ['cae', 'mw'],
    "tīraruha": ['cae', 'ddsa', 'mw'],
    "tīrastha": ['mw'],
    "tīravilagna": ['mw'],
    "tīray": ['cae'],
    "tīraya": ['ddsa', 'mw'],
    "tīrayati": ['cped'],
    "tīraṃ": ['ap90'],
    "tīraṇa": ['bhs', 'mw'],
    "tīreti": ['cped'],
    "tīretvā": ['cped'],
    "tīrikā": ['cae', 'mw'],
    "tīrita": ['ap90', 'mw'],
    "tīrtha": ['cae', 'ddsa', 'gra', 'mw'],
    "tīrthabhūta": ['mw'],
    "tīrthacaryā": ['mw'],
    "tīrthacintāmaṇi": ['mw'],
    "tīrthadeva": ['mw'],
    "tīrthadevamaya": ['mw'],
    "tīrthadhvāṅkṣa": ['mw'],
    "tīrthagopāla": ['mw'],
    "tīrthaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "tīrthakamaṇḍalu": ['mw'],
    "tīrthakara": ['bhs', 'cae', 'mw'],
    "tīrthakāka": ['mw'],
    "tīrthakāśikā": ['mw'],
    "tīrthakīrti": ['mw'],
    "tīrthakṛt": ['mw'],
    "tīrthamahiman": ['mw'],
    "tīrthamahāhrada": ['mw'],
    "tīrthamāhātmya": ['mw'],
    "tīrthamṛttikā": ['cae'],
    "tīrthanirṇaya": ['mw'],
    "tīrthapad": ['mw'],
    "tīrthapada": ['mw'],
    "tīrthapati": ['mw'],
    "tīrthapratipādana": ['mw'],
    "tīrthapāda": ['mw'],
    "tīrthapādīya": ['mw'],
    "tīrthapūjā": ['mw'],
    "tīrtharājī": ['mw'],
    "tīrthasad": ['mw'],
    "tīrthasaukhya": ['mw'],
    "tīrthaseni": ['mw'],
    "tīrthasevin": ['mw'],
    "tīrthasevā": ['mw'],
    "tīrthatama": ['mw'],
    "tīrthavat": ['mw'],
    "tīrthavatī": ['mw'],
    "tīrthavidhi": ['mw'],
    "tīrthavāka": ['mw'],
    "tīrthavāsin": ['mw'],
    "tīrthavāyasa": ['mw'],
    "tīrthayātrin": ['mw'],
    "tīrthayātrā": ['cae', 'mw'],
    "tīrthayātrāparvan": ['mw'],
    "tīrthayātrātattva": ['mw'],
    "tīrthayātrāvidhi": ['mw'],
    "tīrthaśilā": ['mw'],
    "tīrthaśravas": ['mw'],
    "tīrthaśrāddhaprayoga": ['mw'],
    "tīrthaṃ": ['ap90'],
    "tīrthaṃkara": ['mw'],
    "tīrtheśvara": ['mw'],
    "tīrthika": ['bhs', 'mw'],
    "tīrthikara": ['bhs'],
    "tīrthikaḥ": ['ap90'],
    "tīrthodaka": ['cae', 'ddsa', 'mw'],
    "tīrthya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "tīrthyaka": ['bhs'],
    "tīrthyakara": ['bhs'],
    "tīrthāsevana": ['mw'],
    "tīrthī": ['mw'],
    "tīrthībhūta": ['ap90', 'mw'],
    "tīrthīkaraṇa": ['mw'],
    "tīrthīkṛ": ['ap90', 'ddsa', 'mw'],
    "tīrthīkṛta": ['mw'],
    "tīrtvā": ['mw'],
    "tīruḥ": ['ap90'],
    "tīrāntara": ['mw'],
    "tīrāṭa": ['mw'],
    "tīrī": ['mw'],
    "tīrīyaka": ['bhs'],
    "tīrṇa": ['ap90', 'ddsa', 'mw'],
    "tīrṇapadī": ['mw'],
    "tīrṇapratijña": ['mw'],
    "tīrṇā": ['mw'],
    "tīsaṭa": ['mw'],
    "tīv": ['ap90', 'mw'],
    "tīvara": ['cae', 'ddsa', 'mw'],
    "tīvaraḥ": ['ap90'],
    "tīvarī": ['mw'],
    "tīvra": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "tīvradyuti": ['mw'],
    "tīvradāru": ['mw'],
    "tīvragandhā": ['mw'],
    "tīvragati": ['mw'],
    "tīvrajvālā": ['mw'],
    "tīvrakanda": ['mw'],
    "tīvrakaṇṭha": ['mw'],
    "tīvram": ['mw'],
    "tīvramada": ['mw'],
    "tīvramārga": ['mw'],
    "tīvrapauruṣa": ['mw'],
    "tīvraroṣasamāviṣṭa": ['mw'],
    "tīvraruja": ['mw'],
    "tīvrasava": ['mw'],
    "tīvrasoma": ['mw'],
    "tīvrasut": ['gra', 'mw'],
    "tīvratā": ['mw'],
    "tīvravedanā": ['mw'],
    "tīvravipāka": ['mw'],
    "tīvraya": ['mw'],
    "tīvrayati": ['ap90'],
    "tīvraśokasamāviṣṭa": ['mw'],
    "tīvraśokārta": ['mw'],
    "tīvrā": ['mw'],
    "tīvrānanda": ['mw'],
    "tīvrānta": ['mw'],
    "tīvrātitīvra": ['mw'],
    "tīvrī": ['mw'],
    "tīvrībhū": ['mw'],
    "tīvrīkṛ": ['mw'],
    "tūbara": ['mw'],
    "tūbaraka": ['mw'],
    "tūbaraḥ": ['ap90'],
    "tūbarikā": ['mw'],
    "tūda": ['mw'],
    "tūdaḥ": ['ap90'],
    "tūdī": ['mw'],
    "tūkha": ['mw'],
    "tūl": ['ap90', 'mw'],
    "tūla": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "tūlacāpa": ['mw'],
    "tūladāham": ['mw'],
    "tūlaka": ['mw'],
    "tūlakaṃ": ['ap90'],
    "tūlakaṇa": ['mw'],
    "tūlakaṇāya": ['mw'],
    "tūlakārmuka": ['mw'],
    "tūlalāsikā": ['mw'],
    "tūlamūla": ['mw'],
    "tūlanālikā": ['mw'],
    "tūlanālā": ['mw'],
    "tūlanālī": ['mw'],
    "tūlapaṭikā": ['mw'],
    "tūlapaṭī": ['mw'],
    "tūlaphala": ['mw'],
    "tūlapicu": ['bhs', 'cped', 'mw'],
    "tūlapuṇṇika": ['cped'],
    "tūlapīṭhī": ['mw'],
    "tūlapūrṇa": ['mw'],
    "tūlasadṛśasukumārapāṇitā": ['mw'],
    "tūlasannibha": ['cped'],
    "tūlasecana": ['mw'],
    "tūlavatī": ['mw'],
    "tūlavṛkṣa": ['mw'],
    "tūlaśarkarā": ['mw'],
    "tūlaśodhana": ['mw'],
    "tūlaśodhinī": ['mw'],
    "tūlaḥ": ['ap90'],
    "tūli": ['bhs', 'mw'],
    "tūlika": ['cae', 'mw'],
    "tūlikā": ['ap90', 'cped', 'ddsa', 'mw'],
    "tūlinī": ['ap90', 'cae', 'cped', 'mw'],
    "tūliphalā": ['mw'],
    "tūliḥ": ['ap90'],
    "tūlā": ['mw'],
    "tūlī": ['mw'],
    "tūpara": ['cae', 'ddsa', 'mw'],
    "tūparaḥ": ['ap90'],
    "tūr": ['ap90', 'cae', 'mw'],
    "tūra": ['ap90', 'mw'],
    "tūraṃ": ['ap90'],
    "tūrbhis": ['mw'],
    "tūrghna": ['mw'],
    "tūri": ['cped'],
    "tūriya": ['cped'],
    "tūrta": ['cae', 'mw'],
    "tūrti": ['cae', 'gra', 'mw'],
    "tūrv": ['cae', 'gra'],
    "tūrvayāṇa": ['ap90', 'cae', 'gra', 'mw'],
    "tūrvi": ['cae', 'gra', 'mw'],
    "tūrya": ['cae', 'ddsa', 'gra', 'mw'],
    "tūryagaṇḍa": ['mw'],
    "tūryaghoṣa": ['bhs', 'cae', 'mw'],
    "tūryakhaṇḍa": ['mw'],
    "tūryamaya": ['mw'],
    "tūryantī": ['mw'],
    "tūryaugha": ['mw'],
    "tūryaḥ": ['ap90'],
    "tūryāṃśa": ['mw'],
    "tūrā": ['mw'],
    "tūrī": ['mw'],
    "tūrṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "tūrṇaga": ['mw'],
    "tūrṇaka": ['mw'],
    "tūrṇam": ['mw'],
    "tūrṇataram": ['mw'],
    "tūrṇi": ['ap90', 'cae', 'gra', 'mw'],
    "tūrṇiartha": ['gra'],
    "tūrṇodita": ['mw'],
    "tūrṇyartha": ['gra', 'mw'],
    "tūrṇāśa": ['cae', 'gra', 'mw'],
    "tūsta": ['cae', 'mw'],
    "tūstaṃ": ['ap90'],
    "tūta": ['cae', 'ddsa', 'mw'],
    "tūtaka": ['mw'],
    "tūtuji": ['cae', 'ddsa', 'gra', 'mw'],
    "tūtujāna": ['ap90', 'cae', 'mw'],
    "tūtuma": ['ap90', 'cae', 'gra', 'mw'],
    "tūvara": ['ap90'],
    "tūvaraka": ['ap90'],
    "tūya": ['ap90', 'cae', 'gra', 'mw'],
    "tūyam": ['ddsa', 'mw'],
    "tūḍ": ['ap90', 'mw'],
    "tūṇ": ['ap90', 'mw'],
    "tūṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "tūṇadhāra": ['mw'],
    "tūṇaka": ['ddsa', 'mw'],
    "tūṇamukha": ['mw'],
    "tūṇava": ['cae', 'ddsa', 'mw'],
    "tūṇavadhma": ['cae', 'mw'],
    "tūṇavat": ['mw'],
    "tūṇaḥ": ['ap90'],
    "tūṇi": ['cae', 'mw'],
    "tūṇika": ['mw'],
    "tūṇin": ['mw'],
    "tūṇiḥ": ['ap90'],
    "tūṇī": ['mw'],
    "tūṇīdhāra": ['mw'],
    "tūṇīka": ['mw'],
    "tūṇīkānta": ['mw'],
    "tūṇīkṛ": ['mw'],
    "tūṇīra": ['cae', 'ddsa', 'mw'],
    "tūṇīravat": ['mw'],
    "tūṇīrāya": ['ddsa'],
    "tūṇīrāyamāṇa": ['mw'],
    "tūṇīśaya": ['mw'],
    "tūṣ": ['ap90', 'mw'],
    "tūṣa": ['cae', 'ddsa', 'mw'],
    "tūṣaḥ": ['ap90'],
    "tūṣādhāna": ['mw'],
    "tūṣṇī": ['bhs'],
    "tūṣṇībhāva": ['bhs', 'cae'],
    "tūṣṇīka": ['ap90', 'cae', 'ddsa', 'mw'],
    "tūṣṇīkam": ['mw'],
    "tūṣṇīkaśobhana": ['bhs'],
    "tūṣṇīkām": ['mw'],
    "tūṣṇīm": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tūṣṇīṃ": ['mw'],
    "tūṣṇīṃbhāva": ['mw'],
    "tūṣṇīṃbhāvam": ['mw'],
    "tūṣṇīṃbhūta": ['mw'],
    "tūṣṇīṃbhūya": ['mw'],
    "tūṣṇīṃdaṇḍa": ['mw'],
    "tūṣṇīṃgaṅga": ['mw'],
    "tūṣṇīṃhoma": ['mw'],
    "tūṣṇīṃjapa": ['mw'],
    "tūṣṇīṃsthāna": ['mw'],
    "tūṣṇīṃsāra": ['mw'],
    "tūṣṇīṃviprakramaṇa": ['mw'],
    "tūṣṇīṃśaṃsa": ['mw'],
    "tūṣṇīṃśīla": ['mw'],
    "tṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "tṛbhava": ['bhs'],
    "tṛbhi": ['cae', 'mw'],
    "tṛca": ['cae', 'ddsa', 'mw'],
    "tṛcabhāgā": ['mw'],
    "tṛcakḷpta": ['mw'],
    "tṛcin": ['mw'],
    "tṛd": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tṛdhā": ['bhs'],
    "tṛdila": ['cae', 'gra', 'mw'],
    "tṛh": ['ap90', 'cae', 'ddsa', 'mw'],
    "tṛkha": ['mw'],
    "tṛkhaṃ": ['ap90'],
    "tṛkṣ": ['ap90', 'mw'],
    "tṛkṣa": ['mw'],
    "tṛkṣas": ['mw'],
    "tṛkṣaḥ": ['ap90'],
    "tṛkṣi": ['gra', 'mw'],
    "tṛkṣāka": ['mw'],
    "tṛmp": ['mw'],
    "tṛmpaṇa": ['mw'],
    "tṛmpaṇīya": ['mw'],
    "tṛmph": ['mw'],
    "tṛmuṇḍīkṛtā": ['bhs'],
    "tṛn": ['ddsa'],
    "tṛp": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tṛpa": ['gra', 'mw'],
    "tṛpala": ['ap90', 'cae', 'gra', 'mw'],
    "tṛpalam": ['mw'],
    "tṛpalaprabharman": ['gra', 'mw'],
    "tṛpalā": ['mw'],
    "tṛpat": ['ap90', 'cae', 'mw'],
    "tṛpataḥ": ['ap90'],
    "tṛph": ['mw'],
    "tṛphalā": ['mw'],
    "tṛphū": ['mw'],
    "tṛphūḥ": ['ap90'],
    "tṛpita": ['mw'],
    "tṛpra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tṛpradaṃśin": ['mw'],
    "tṛpram": ['mw'],
    "tṛprin": ['mw'],
    "tṛprālu": ['mw'],
    "tṛprāya": ['mw'],
    "tṛpta": ['ap90', 'mw'],
    "tṛptaaṃśu": ['gra'],
    "tṛptam": ['mw'],
    "tṛptatā": ['cae', 'mw'],
    "tṛptavasantagandha": ['bhs'],
    "tṛpti": ['cae', 'ddsa', 'gra', 'mw'],
    "tṛptida": ['mw'],
    "tṛptidīpa": ['mw'],
    "tṛptighna": ['mw'],
    "tṛptikara": ['cae', 'ddsa', 'mw'],
    "tṛptikāraka": ['cae', 'mw'],
    "tṛptikṛt": ['mw'],
    "tṛptimat": ['mw'],
    "tṛptitā": ['bhs'],
    "tṛptiyoga": ['mw'],
    "tṛptiḥ": ['ap90'],
    "tṛptātman": ['mw'],
    "tṛptāṃśu": ['cae', 'gra', 'mw'],
    "tṛptīkṛ": ['mw'],
    "tṛpu": ['mw'],
    "tṛpuḥ": ['ap90'],
    "tṛpyat": ['mw'],
    "tṛpā": ['mw'],
    "tṛpāya": ['mw'],
    "tṛta": ['mw'],
    "tṛtiya": ['bhs'],
    "tṛtsu": ['cae', 'ddsa', 'gra', 'mw'],
    "tṛtīya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tṛtīyabhikṣā": ['mw'],
    "tṛtīyadivasa": ['cae', 'ddsa', 'mw'],
    "tṛtīyaka": ['ap90', 'mw'],
    "tṛtīyakajvara": ['mw'],
    "tṛtīyakam": ['bhs'],
    "tṛtīyakaraṇī": ['mw'],
    "tṛtīyam": ['mw'],
    "tṛtīyaprakṛti": ['mw'],
    "tṛtīyasavana": ['cae', 'mw'],
    "tṛtīyasavanīya": ['mw'],
    "tṛtīyasvara": ['mw'],
    "tṛtīyatva": ['mw'],
    "tṛtīyatā": ['mw'],
    "tṛtīyena": ['mw'],
    "tṛtīyika": ['mw'],
    "tṛtīyikā": ['mw'],
    "tṛtīyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "tṛtīyā": ['ap90', 'mw'],
    "tṛtīyākṛ": ['mw'],
    "tṛtīyāsamāsa": ['cae', 'mw'],
    "tṛtīyāṃśa": ['cae', 'mw'],
    "tṛvidha": ['bhs'],
    "tṛvṛt": ['mw'],
    "tṛḍha": ['ddsa', 'gra', 'mw'],
    "tṛṃh": ['ap90'],
    "tṛṃhaṇa": ['bhs', 'mw'],
    "tṛṃhaṇaṃ": ['ap90'],
    "tṛṃhaṇīya": ['mw'],
    "tṛṃp": ['ap90'],
    "tṛṃḍha": ['ap90'],
    "tṛṇ": ['ap90', 'mw'],
    "tṛṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "tṛṇabalvajā": ['mw'],
    "tṛṇabhuj": ['cae', 'mw'],
    "tṛṇabhūta": ['mw'],
    "tṛṇabindu": ['mw'],
    "tṛṇabinduśaras": ['mw'],
    "tṛṇabīja": ['mw'],
    "tṛṇabījaka": ['mw'],
    "tṛṇabījottama": ['mw'],
    "tṛṇacara": ['mw'],
    "tṛṇacchedin": ['cae', 'mw'],
    "tṛṇadhvaja": ['mw'],
    "tṛṇadhānya": ['mw'],
    "tṛṇadruma": ['mw'],
    "tṛṇagandhā": ['mw'],
    "tṛṇagaura": ['mw'],
    "tṛṇagaḍa": ['mw'],
    "tṛṇagaṇanā": ['mw'],
    "tṛṇagaṇāya": ['mw'],
    "tṛṇagodhā": ['mw'],
    "tṛṇagranthi": ['mw'],
    "tṛṇagrāhin": ['mw'],
    "tṛṇaharmya": ['mw'],
    "tṛṇaidha": ['mw'],
    "tṛṇajalāyukā": ['cae', 'mw'],
    "tṛṇajalūkā": ['cae', 'mw'],
    "tṛṇajambhan": ['mw'],
    "tṛṇajantu": ['mw'],
    "tṛṇajyotis": ['mw'],
    "tṛṇajāti": ['mw'],
    "tṛṇaka": ['mw'],
    "tṛṇakarṇa": ['mw'],
    "tṛṇakaṃ": ['ap90'],
    "tṛṇaketakī": ['mw'],
    "tṛṇaketu": ['mw'],
    "tṛṇaketuka": ['mw'],
    "tṛṇakuñcaka": ['bhs', 'mw'],
    "tṛṇakuṅkuma": ['mw'],
    "tṛṇakuṭi": ['cae', 'mw'],
    "tṛṇakuṭī": ['mw'],
    "tṛṇakuṭīra": ['cae', 'ddsa', 'mw'],
    "tṛṇakuṭīraka": ['cae', 'mw'],
    "tṛṇakāṇḍa": ['mw'],
    "tṛṇakāṣṭha": ['cae', 'mw'],
    "tṛṇakīyā": ['ap90', 'mw'],
    "tṛṇakūrcikā": ['mw'],
    "tṛṇakūrma": ['mw'],
    "tṛṇakūṭa": ['cae', 'mw'],
    "tṛṇalava": ['cae', 'mw'],
    "tṛṇamaya": ['cae', 'mw'],
    "tṛṇamaṇi": ['mw'],
    "tṛṇamuṣṭi": ['mw'],
    "tṛṇanimbā": ['mw'],
    "tṛṇapa": ['mw'],
    "tṛṇapadī": ['mw'],
    "tṛṇaparṇī": ['mw'],
    "tṛṇapattrikā": ['mw'],
    "tṛṇapattrī": ['mw'],
    "tṛṇapañcamūla": ['mw'],
    "tṛṇapañcikā": ['mw'],
    "tṛṇaprastāraka": ['bhs'],
    "tṛṇaprāsana": ['mw'],
    "tṛṇaprāya": ['cae', 'mw'],
    "tṛṇapulaka": ['mw'],
    "tṛṇapulī": ['mw'],
    "tṛṇapuruṣaka": ['mw'],
    "tṛṇapuṣpa": ['mw'],
    "tṛṇapuṣpī": ['mw'],
    "tṛṇapāṇi": ['mw'],
    "tṛṇapīḍa": ['mw'],
    "tṛṇapūla": ['mw'],
    "tṛṇapūlaka": ['mw'],
    "tṛṇapūlika": ['mw'],
    "tṛṇapūlī": ['mw'],
    "tṛṇarāj": ['cae', 'ddsa', 'mw'],
    "tṛṇarāja": ['cae', 'mw'],
    "tṛṇarājan": ['mw'],
    "tṛṇasa": ['mw'],
    "tṛṇasaṃcaya": ['mw'],
    "tṛṇasaṃvara": ['mw'],
    "tṛṇasaṃvāha": ['mw'],
    "tṛṇasiṃha": ['mw'],
    "tṛṇaskanda": ['cae', 'gra', 'mw'],
    "tṛṇasomāṅgiras": ['mw'],
    "tṛṇastāraka": ['mw'],
    "tṛṇasāra": ['mw'],
    "tṛṇasārā": ['mw'],
    "tṛṇasārīkṛta": ['mw'],
    "tṛṇatantu": ['cae', 'ddsa'],
    "tṛṇatva": ['mw'],
    "tṛṇatvaca": ['mw'],
    "tṛṇatā": ['ddsa', 'mw'],
    "tṛṇaukas": ['mw'],
    "tṛṇauṣadha": ['mw'],
    "tṛṇavant": ['cae'],
    "tṛṇavat": ['cae', 'mw'],
    "tṛṇavistara": ['mw'],
    "tṛṇavṛkṣa": ['mw'],
    "tṛṇay": ['cae'],
    "tṛṇaya": ['ddsa', 'mw'],
    "tṛṇaśauṇḍikā": ['mw'],
    "tṛṇaśoṇita": ['mw'],
    "tṛṇaśoṣaka": ['mw'],
    "tṛṇaśīta": ['mw'],
    "tṛṇaśītā": ['mw'],
    "tṛṇaśūlya": ['mw'],
    "tṛṇaśūnya": ['mw'],
    "tṛṇaṃ": ['ap90'],
    "tṛṇaṣaṭpada": ['mw'],
    "tṛṇekṣu": ['mw'],
    "tṛṇendra": ['cae', 'mw'],
    "tṛṇodaka": ['cae', 'ddsa', 'mw'],
    "tṛṇodakabhūmi": ['mw'],
    "tṛṇodbhava": ['mw'],
    "tṛṇolapa": ['mw'],
    "tṛṇolkā": ['cae', 'mw'],
    "tṛṇottama": ['mw'],
    "tṛṇottha": ['mw'],
    "tṛṇyā": ['ap90', 'mw'],
    "tṛṇāda": ['cae', 'mw'],
    "tṛṇādhipa": ['mw'],
    "tṛṇāgni": ['cae', 'ddsa', 'mw'],
    "tṛṇāmalla": ['mw'],
    "tṛṇāmla": ['mw'],
    "tṛṇānna": ['mw'],
    "tṛṇāri": ['mw'],
    "tṛṇāsṛj": ['mw'],
    "tṛṇāvallī": ['mw'],
    "tṛṇāvarta": ['mw'],
    "tṛṇāñcana": ['mw'],
    "tṛṇāñjana": ['mw'],
    "tṛṇāśa": ['cae', 'mw'],
    "tṛṇāśana": ['cae', 'mw'],
    "tṛṇāśin": ['cae', 'mw'],
    "tṛṇāḍhya": ['mw'],
    "tṛṇāṅku": ['mw'],
    "tṛṇāṅkura": ['cae', 'mw'],
    "tṛṇāṭavī": ['mw'],
    "tṛṇīkṛ": ['ap90', 'ddsa', 'mw'],
    "tṛṇīya": ['mw'],
    "tṛṇṇa": ['mw'],
    "tṛṣ": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "tṛṣama": ['mw'],
    "tṛṣita": ['ap90', 'mw'],
    "tṛṣitottarā": ['mw'],
    "tṛṣu": ['ap90', 'cae', 'gra', 'mw'],
    "tṛṣucyavas": ['cae', 'gra', 'mw'],
    "tṛṣucyut": ['cae', 'gra', 'mw'],
    "tṛṣya": ['ap90'],
    "tṛṣyāvant": ['cae'],
    "tṛṣyāvat": ['ddsa', 'gra', 'mw'],
    "tṛṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "tṛṣābhū": ['mw'],
    "tṛṣāha": ['mw'],
    "tṛṣāroga": ['mw'],
    "tṛṣārta": ['cae', 'mw'],
    "tṛṣṇaj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tṛṣṇaka": ['mw'],
    "tṛṣṇā": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "tṛṣṇāghna": ['mw'],
    "tṛṣṇākṣaya": ['mw'],
    "tṛṣṇālu": ['ap90'],
    "tṛṣṇāmāra": ['mw'],
    "tṛṣṇāri": ['mw'],
    "tṛṣṇārta": ['cae', 'mw'],
    "tṛṣṇāsaṅga": ['cae', 'mw'],
    "tṛṣṇāvarūtrī": ['mw'],
    "tṛṣṇī": ['bhs'],
    "tṛṣṭa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "tṛṣṭadaṃśman": ['mw'],
    "tṛṣṭadhūma": ['mw'],
    "tṛṣṭajambha": ['mw'],
    "tṛṣṭavandana": ['mw'],
    "tṛṣṭikā": ['mw'],
    "tṛṣṭāmā": ['cae', 'gra', 'mw'],
    "tṝ": ['ap90', 'mw'],
    "u": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ubbandhitvā": ['cped'],
    "ubbaṭuma": ['cped'],
    "ubbaṭṭayati": ['cped'],
    "ubbaṭṭeti": ['cped'],
    "ubbedhena": ['cped'],
    "ubbega": ['cped'],
    "ubbega-uttāsabhayāpanūdana": ['cped'],
    "ubbejeta": ['cped'],
    "ubbejetar": ['cped'],
    "ubbejita": ['cped'],
    "ubbejitar": ['cped'],
    "ubbhajānumaṇḍala": ['cped'],
    "ubbhajānumaṇḍalaṁ": ['cped'],
    "ubbhajānumaṇḍalikā": ['cped'],
    "ubbhakkhaka": ['cped'],
    "ubbhamukha": ['cped'],
    "ubbhata": ['cped'],
    "ubbhaṁ": ['cped'],
    "ubbhaṇḍita": ['cped'],
    "ubbhaṭṭhaka": ['cped'],
    "ubbhida": ['cped'],
    "ubbhidodaka": ['cped'],
    "ubbhijja": ['cped'],
    "ubbhijjitvā": ['cped'],
    "ubbhindati": ['cped'],
    "ubbhinditvā": ['cped'],
    "ubbhuji": ['cped'],
    "ubbhujitabba": ['cped'],
    "ubbhujitvā": ['cped'],
    "ubbhujitvāna": ['cped'],
    "ubbhāra": ['cped'],
    "ubbigga": ['cped'],
    "ubbijati": ['cped'],
    "ubbiji": ['cped'],
    "ubbijjati": ['cped'],
    "ubbijjeti": ['cped'],
    "ubbijji": ['cped'],
    "ubbilla": ['cped'],
    "ubbinaya": ['cped'],
    "ubbādhanā": ['cped'],
    "ubbāhapetabba": ['cped'],
    "ubbāhapeti": ['cped'],
    "ubbāhapetvā": ['cped'],
    "ubbāheti": ['cped'],
    "ubbāhetvā": ['cped'],
    "ubbāhikā": ['cped'],
    "ubbāhāpetabba": ['cped'],
    "ubbāhāpeti": ['cped'],
    "ubbāhāpetvā": ['cped'],
    "ubh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ubha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ubhanta": ['cped'],
    "ubhato": ['cped'],
    "ubhatobhāgavimaṭṭha": ['cped'],
    "ubhatobhāge": ['cped'],
    "ubhatodaṇḍak": ['cped'],
    "ubhatodhāra": ['cped'],
    "ubhatokoṭika": ['cped'],
    "ubhatokāja": ['cped'],
    "ubhatolohitakūpadhāna": ['cped'],
    "ubhatomukha": ['cped'],
    "ubhatopakkhaṁ": ['cped'],
    "ubhatopassa": ['cped'],
    "ubhatosaṅgha": ['cped'],
    "ubhatovaṇṭikamālā": ['cped'],
    "ubhatovyañjana": ['cped'],
    "ubhatovyañjanaka": ['cped'],
    "ubhaya": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ubhaya-m-antare": ['cped'],
    "ubhaya-m-antarena": ['cped'],
    "ubhayabhāga": ['mw'],
    "ubhayabhāgahara": ['mw'],
    "ubhayabhāj": ['mw'],
    "ubhayacakravartin": ['cae'],
    "ubhayacara": ['mw'],
    "ubhayacchannā": ['mw'],
    "ubhayacchikāṇa": ['cped'],
    "ubhayacārin": ['mw'],
    "ubhayadant": ['cae'],
    "ubhayadat": ['mw'],
    "ubhayadyus": ['ap90', 'mw'],
    "ubhayaguṇa": ['mw'],
    "ubhayakāma": ['mw'],
    "ubhayamukha": ['mw'],
    "ubhayantarena": ['cped'],
    "ubhayapad": ['mw'],
    "ubhayapadin": ['mw'],
    "ubhayaprāpti": ['ddsa'],
    "ubhayapārśvatas": ['mw'],
    "ubhayasambhava": ['mw'],
    "ubhayasaptamī": ['mw'],
    "ubhayasnātaka": ['mw'],
    "ubhayaspṛṣṭi": ['mw'],
    "ubhayastobha": ['mw'],
    "ubhayasāman": ['mw'],
    "ubhayata": ['mw'],
    "ubhayataeta": ['mw'],
    "ubhayatas": ['cae', 'ddsa', 'gra', 'mw'],
    "ubhayatastīkṣṇa": ['mw'],
    "ubhayataukthya": ['mw'],
    "ubhayataś": ['mw'],
    "ubhayataścakra": ['mw'],
    "ubhayataḥ": ['ap90', 'mw'],
    "ubhayataḥkālam": ['mw'],
    "ubhayataḥkṣṇut": ['mw'],
    "ubhayataḥkṣṇū": ['mw'],
    "ubhayataḥpad": ['mw'],
    "ubhayataḥpakṣa": ['mw'],
    "ubhayataḥparigṛhīta": ['mw'],
    "ubhayataḥprajña": ['mw'],
    "ubhayataḥprauga": ['mw'],
    "ubhayataḥpraṇava": ['mw'],
    "ubhayataḥprāṇa": ['mw'],
    "ubhayataḥpāśa": ['mw'],
    "ubhayataḥsasya": ['mw'],
    "ubhayataḥsaṃśvāyin": ['mw'],
    "ubhayataḥstobha": ['mw'],
    "ubhayataḥsujāta": ['mw'],
    "ubhayataḥśīrṣan": ['mw'],
    "ubhayataḥśīrṣatva": ['mw'],
    "ubhayathā": ['ap90', 'cae', 'mw'],
    "ubhayato": ['cped', 'mw'],
    "ubhayatobhāgahara": ['mw'],
    "ubhayatobhāgavimukta": ['bhs'],
    "ubhayatobhāj": ['mw'],
    "ubhayatobhāṣa": ['mw'],
    "ubhayatobārhatam": ['mw'],
    "ubhayatodant": ['cae'],
    "ubhayatodanta": ['cae', 'mw'],
    "ubhayatodat": ['mw'],
    "ubhayatodhāra": ['mw'],
    "ubhayatodvāra": ['mw'],
    "ubhayatohrasva": ['mw'],
    "ubhayatojyotis": ['mw'],
    "ubhayatomukha": ['mw'],
    "ubhayatonamaskāra": ['mw'],
    "ubhayatonābhi": ['mw'],
    "ubhayatotirātra": ['mw'],
    "ubhayatoṅga": ['mw'],
    "ubhayatra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ubhayattha": ['cped'],
    "ubhayavartanin": ['mw'],
    "ubhayavat": ['mw'],
    "ubhayavaṃśya": ['mw'],
    "ubhayavetana": ['mw'],
    "ubhayavetanatva": ['mw'],
    "ubhayavidha": ['mw'],
    "ubhayavidyā": ['mw'],
    "ubhayavipulā": ['mw'],
    "ubhayavyañjana": ['bhs', 'mw'],
    "ubhayavāsin": ['mw'],
    "ubhayaśiras": ['mw'],
    "ubhayaṁ": ['cped'],
    "ubhayaṁsa": ['cped'],
    "ubhayaṁsabhāvita": ['cped'],
    "ubhayaṃ": ['bhs'],
    "ubhayaṃkara": ['gra', 'mw'],
    "ubhayedyus": ['ap90', 'mw'],
    "ubhayena": ['cped'],
    "ubhayā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ubhayābāhu": ['mw'],
    "ubhayācakra": ['mw'],
    "ubhayāda": ['ddsa', 'mw'],
    "ubhayādanti": ['mw'],
    "ubhayādat": ['gra', 'mw'],
    "ubhayāhasti": ['gra', 'mw'],
    "ubhayāhastia": ['gra'],
    "ubhayāhastya": ['gra'],
    "ubhayāhastyā": ['mw'],
    "ubhayākarṇi": ['mw'],
    "ubhayālaṃkāra": ['mw'],
    "ubhayānumata": ['mw'],
    "ubhayāpad": ['mw'],
    "ubhayāpāṇi": ['mw'],
    "ubhayārtham": ['mw'],
    "ubhayātmaka": ['cae', 'ddsa', 'mw'],
    "ubhayāvin": ['gra', 'mw'],
    "ubhayāvṛtti": ['ddsa', 'mw'],
    "ubhayāyin": ['mw'],
    "ubhayāñjali": ['mw'],
    "ubhayī": ['mw'],
    "ubhayīya": ['ap90', 'mw'],
    "ubho": ['cped'],
    "ubhosaṅga": ['cped'],
    "ubhā": ['mw'],
    "ubhābāhu": ['mw'],
    "ubhādanti": ['mw'],
    "ubhāhasti": ['mw'],
    "ubhākarṇi": ['mw'],
    "ubhāpāṇi": ['mw'],
    "ubhāñjali": ['mw'],
    "ubj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ucatha": ['cae', 'ddsa', 'gra', 'mw'],
    "ucathaṃ": ['ap90'],
    "ucathia": ['gra'],
    "ucathya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ucca": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "uccabhāṣaṇa": ['mw'],
    "uccabhāṣin": ['mw'],
    "uccadeva": ['mw'],
    "uccadevatā": ['mw'],
    "uccadhvaja": ['bhs', 'mw'],
    "uccagghana": ['bhs'],
    "uccagghati": ['bhs'],
    "uccaghana": ['mw'],
    "uccaghanaṃ": ['ap90'],
    "uccagir": ['ddsa', 'mw'],
    "uccagopura": ['ddsa'],
    "uccair": ['mw'],
    "uccairabhijana": ['ddsa', 'mw'],
    "uccairbhuja": ['cae', 'mw'],
    "uccairbhāṣaṇa": ['mw'],
    "uccairbhāṣya": ['mw'],
    "uccairdhāman": ['cae', 'mw'],
    "uccairdviṣ": ['mw'],
    "uccairgati": ['mw'],
    "uccairghoṣa": ['cae', 'mw'],
    "uccairghuṣṭa": ['mw'],
    "uccairgotra": ['mw'],
    "uccairmanyu": ['mw'],
    "uccairmukha": ['mw'],
    "uccairmāna": ['mw'],
    "uccais": ['cae', 'ddsa', 'gra', 'mw'],
    "uccaistama": ['ap90'],
    "uccaistamām": ['mw'],
    "uccaistamāṃ": ['ap90'],
    "uccaistana": ['mw'],
    "uccaistara": ['ap90', 'cae', 'ddsa', 'mw'],
    "uccaistaraṃ": ['ap90'],
    "uccaistarām": ['mw'],
    "uccaistaṭa": ['mw'],
    "uccaistva": ['mw'],
    "uccaiḥ": ['ap90', 'mw'],
    "uccaiḥkara": ['mw'],
    "uccaiḥkula": ['cae', 'ddsa', 'mw'],
    "uccaiḥkāram": ['mw'],
    "uccaiḥpada": ['cae', 'mw'],
    "uccaiḥpaurṇamāsī": ['mw'],
    "uccaiḥstheya": ['mw'],
    "uccaiḥsthāna": ['cae', 'ddsa', 'mw'],
    "uccaiḥsvara": ['mw'],
    "uccaiḥśabdam": ['mw'],
    "uccaiḥśiras": ['cae', 'ddsa', 'mw'],
    "uccaiḥśravas": ['cae', 'mw'],
    "uccaiḥśravasa": ['mw'],
    "uccaiḥśravyakarṇaka": ['mw'],
    "uccak": ['mw'],
    "uccaka": ['bhs', 'cped'],
    "uccakais": ['ddsa', 'mw'],
    "uccakaiḥ": ['ap90', 'mw'],
    "uccakalpa": ['mw'],
    "uccakita": ['mw'],
    "uccakṣus": ['ap90', 'ddsa', 'mw'],
    "uccakṣūas": ['mw'],
    "uccakṣūbhū": ['mw'],
    "uccakṣūkṛ": ['mw'],
    "uccal": ['ap90', 'mw'],
    "uccala": ['ap90', 'ddsa', 'mw'],
    "uccalalāṭikā": ['mw'],
    "uccalalāṭā": ['mw'],
    "uccalana": ['bhs', 'mw'],
    "uccalanaṃ": ['ap90'],
    "uccalita": ['ap90', 'mw'],
    "uccandra": ['mw'],
    "uccandrabhakta": ['bhs'],
    "uccanīca": ['mw'],
    "uccapada": ['mw'],
    "uccar": ['ap90', 'mw'],
    "uccaraṇa": ['mw'],
    "uccaraṇaṃ": ['ap90'],
    "uccaraṇya": ['mw'],
    "uccarita": ['ap90', 'mw'],
    "uccasadda": ['cped'],
    "uccasaṃrāga": ['mw'],
    "uccasaṃśraya": ['cae', 'ddsa', 'mw'],
    "uccataraka": ['bhs'],
    "uccataratā": ['mw'],
    "uccataru": ['mw'],
    "uccati": ['bhs'],
    "uccattana": ['cped'],
    "uccattena": ['cped'],
    "uccatva": ['mw'],
    "uccatā": ['ap90', 'ddsa', 'mw'],
    "uccatāla": ['mw'],
    "uccavaca": ['cped'],
    "uccavacaṁ": ['cped'],
    "uccavatthuka": ['cped'],
    "uccaya": ['cae', 'cped', 'ddsa', 'mw'],
    "uccayaḥ": ['ap90'],
    "uccayāpacaya": ['mw'],
    "uccaśas": ['mw'],
    "uccaṃdraḥ": ['ap90'],
    "uccaṃgama": ['bhs'],
    "uccaṃḍa": ['ap90'],
    "uccaṇḍa": ['cae', 'ddsa', 'mw'],
    "uccaṭ": ['ap90', 'mw'],
    "uccaṭhāniya": ['cped'],
    "uccaṭyana": ['bhs'],
    "uccaṭā": ['ap90', 'mw'],
    "uccaṭṭhāniya": ['cped'],
    "ucceya": ['ddsa', 'mw'],
    "ucch": ['ap90', 'ddsa'],
    "ucchad": ['mw'],
    "ucchada": ['bhs'],
    "ucchadaka": ['bhs'],
    "ucchahati": ['bhs'],
    "ucchal": ['ap90', 'mw'],
    "ucchalana": ['mw'],
    "ucchalanaṃ": ['ap90'],
    "ucchalant": ['cae'],
    "ucchalat": ['ap90'],
    "ucchalita": ['ap90', 'cae', 'mw'],
    "ucchanna": ['ap90', 'mw'],
    "uccharkara": ['bhs'],
    "ucchata": ['bhs'],
    "ucchava": ['bhs'],
    "ucchaṃs": ['mw'],
    "ucchaṅga": ['bhs', 'cped'],
    "ucchaṅgapañña": ['cped'],
    "ucchaṅkha": ['bhs'],
    "ucchecchāmi": ['cped'],
    "uccheda": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ucchedadiṭṭhi": ['cped'],
    "ucchedana": ['bhs', 'mw'],
    "ucchedanīya": ['cae', 'mw'],
    "ucchedavāda": ['cped', 'mw'],
    "ucchedavādin": ['mw'],
    "ucchedaḥ": ['ap90'],
    "ucchedin": ['ap90', 'cae', 'mw'],
    "ucchedya": ['mw'],
    "ucchejjati": ['cped'],
    "ucchepaka": ['cped'],
    "ucchettṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "uccheṣa": ['cae', 'ddsa', 'mw'],
    "uccheṣaḥ": ['ap90'],
    "uccheṣaṇa": ['mw'],
    "uccheṣaṇīkṛ": ['mw'],
    "uccheṣṭum": ['bhs'],
    "ucchid": ['ap90', 'mw'],
    "ucchidya": ['mw'],
    "ucchihitvā": ['bhs'],
    "ucchijja": ['cped'],
    "ucchijjati": ['cped'],
    "ucchikha": ['ap90', 'cae', 'ddsa', 'mw'],
    "ucchikhaṇḍa": ['cae', 'ddsa', 'mw'],
    "ucchilīndhra": ['mw'],
    "ucchilīṃdhra": ['ap90', 'cae'],
    "ucchindati": ['cped'],
    "ucchinna": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "ucchiras": ['ap90', 'cae', 'mw'],
    "ucchiraska": ['bhs'],
    "ucchitti": ['cae', 'mw'],
    "ucchittiḥ": ['ap90'],
    "ucchitya": ['bhs'],
    "ucchiṃghanaṃ": ['ap90'],
    "ucchiṃhana": ['mw'],
    "ucchiṅghana": ['mw'],
    "ucchiṣ": ['ap90', 'mw'],
    "ucchiṣya": ['mw'],
    "ucchiṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ucchiṣṭabhojana": ['mw'],
    "ucchiṣṭabhojin": ['cae', 'mw'],
    "ucchiṣṭabhoktṛ": ['mw'],
    "ucchiṣṭabhāj": ['mw'],
    "ucchiṣṭacāṇḍālinī": ['mw'],
    "ucchiṣṭagaṇapati": ['mw'],
    "ucchiṣṭagaṇeśa": ['mw'],
    "ucchiṣṭakalpanā": ['mw'],
    "ucchiṣṭamodana": ['mw'],
    "ucchiṣṭatva": ['mw'],
    "ucchiṣṭatā": ['mw'],
    "ucchiṣṭita": ['mw'],
    "ucchiṣṭānna": ['mw'],
    "ucchiṣṭāśana": ['mw'],
    "ucchiṭṭhodaka": ['cped'],
    "ucchlakaḥ": ['ap90'],
    "ucchlakha": ['mw'],
    "ucchocana": ['mw'],
    "ucchocanaṃ": ['ap90'],
    "ucchopha": ['mw'],
    "ucchophaḥ": ['ap90'],
    "ucchotha": ['cae', 'ddsa', 'mw'],
    "ucchoṣa": ['bhs'],
    "ucchoṣaṇa": ['ap90', 'cae', 'mw'],
    "ucchoṣuka": ['ap90', 'mw'],
    "ucchrath": ['mw'],
    "ucchraya": ['bhs', 'cae', 'ddsa', 'mw'],
    "ucchrayaḥ": ['ap90'],
    "ucchrayaṇa": ['ap90', 'mw'],
    "ucchrayopeta": ['mw'],
    "ucchrepana": ['bhs'],
    "ucchrepayati": ['bhs'],
    "ucchreya": ['ap90', 'mw'],
    "ucchri": ['ap90', 'mw'],
    "ucchrita": ['ap90', 'cae', 'mw'],
    "ucchritapāṇi": ['mw'],
    "ucchriti": ['cae', 'mw'],
    "ucchritiḥ": ['ap90'],
    "ucchritya": ['mw'],
    "ucchrāpayati": ['bhs'],
    "ucchrāvaṇaṃ": ['ap90'],
    "ucchrāya": ['mw'],
    "ucchrāyayati": ['bhs'],
    "ucchrāyaḥ": ['ap90'],
    "ucchrāyin": ['ap90', 'mw'],
    "ucchrāyī": ['mw'],
    "ucchu": ['bhs', 'cped'],
    "ucchuc": ['mw'],
    "ucchuna": ['mw'],
    "ucchurita": ['bhs'],
    "ucchuṣ": ['ap90', 'mw'],
    "ucchuṣka": ['ap90', 'cae', 'ddsa', 'mw'],
    "ucchuṣma": ['bhs', 'mw'],
    "ucchuṣmabhairava": ['mw'],
    "ucchuṣmakalpa": ['mw'],
    "ucchuṣmarudra": ['mw'],
    "ucchuṣmaṃ": ['ap90'],
    "ucchuṣmā": ['mw'],
    "ucchvas": ['ap90', 'mw'],
    "ucchvasana": ['cae', 'ddsa', 'mw'],
    "ucchvasanaṃ": ['ap90'],
    "ucchvasat": ['mw'],
    "ucchvasita": ['ap90', 'cae', 'mw'],
    "ucchvayana": ['mw'],
    "ucchvañc": ['mw'],
    "ucchvañcasva": ['ddsa'],
    "ucchvaṃkaḥ": ['ap90'],
    "ucchvaṅka": ['mw'],
    "ucchvi": ['mw'],
    "ucchvāsa": ['cae', 'gra', 'mw'],
    "ucchvāsapraśvāsa": ['bhs'],
    "ucchvāsaḥ": ['ap90'],
    "ucchvāsin": ['ap90', 'cae', 'mw'],
    "ucchvāsita": ['ap90', 'mw'],
    "ucchādaka": ['bhs'],
    "ucchādana": ['bhs', 'cped', 'mw'],
    "ucchādanaṃ": ['ap90'],
    "ucchādita": ['bhs'],
    "ucchādya": ['bhs', 'mw'],
    "ucchān": ['ddsa'],
    "ucchās": ['mw'],
    "ucchāsana": ['ap90'],
    "ucchāstra": ['ap90'],
    "ucchāstravartin": ['cae', 'ddsa', 'mw'],
    "ucchī": ['mw'],
    "ucchīrṣaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "ucchūna": ['ap90', 'cae', 'mw'],
    "ucchūḍā": ['ap90'],
    "ucchṛta": ['bhs'],
    "ucchṛṃkhala": ['ap90'],
    "ucchṛṅgita": ['mw'],
    "ucchṛṅkhala": ['cae', 'ddsa', 'mw'],
    "ucci": ['ap90', 'mw'],
    "uccicīṣā": ['ddsa', 'mw'],
    "ucciliṅga": ['mw'],
    "uccinati": ['cped'],
    "uccinitvā": ['cped'],
    "uccināti": ['cped'],
    "uccita": ['mw'],
    "uccitra": ['ap90', 'cae'],
    "uccitraṇa": ['mw'],
    "uccitrita": ['mw'],
    "ucciṃgaṭaḥ": ['ap90'],
    "ucciṅgaṭa": ['mw'],
    "ucciṭaṃgaḥ": ['ap90'],
    "ucciṭiṃgaḥ": ['ap90'],
    "ucciṭiṅga": ['mw'],
    "ucculump": ['mw'],
    "uccumb": ['mw'],
    "uccumbya": ['mw'],
    "uccyu": ['mw'],
    "uccā": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "uccābudhna": ['gra', 'mw'],
    "uccācakra": ['gra', 'mw'],
    "uccākaṇerukā": ['cped'],
    "uccākula": ['cped'],
    "uccākulika": ['cped'],
    "uccākulīna": ['cped'],
    "uccākāḷārikā": ['cped'],
    "uccāliṅgapāṇaka": ['cped'],
    "uccāliṅgapāṇakadaṭṭha": ['cped'],
    "uccāra": ['cae', 'cped', 'ddsa', 'mw'],
    "uccāraka": ['ap90', 'mw'],
    "uccārapassāva": ['cped'],
    "uccārapassāvakamma": ['cped'],
    "uccāraprasravaṇa": ['mw'],
    "uccāraprasrāvasthāna": ['mw'],
    "uccārayitṛ": ['mw'],
    "uccāraḥ": ['ap90'],
    "uccāraṇa": ['cae', 'cped', 'mw'],
    "uccāraṇajña": ['mw'],
    "uccāraṇasthāna": ['mw'],
    "uccāraṇaṃ": ['ap90'],
    "uccāraṇārtha": ['mw'],
    "uccāraṇīya": ['mw'],
    "uccāresi": ['cped'],
    "uccāreti": ['cped'],
    "uccāretvā": ['cped'],
    "uccārin": ['mw'],
    "uccārita": ['ap90', 'mw'],
    "uccāritakata": ['cped'],
    "uccārya": ['mw'],
    "uccāryamāṇa": ['mw'],
    "uccāsadda": ['cped'],
    "uccāsana": ['cae'],
    "uccāsoṇḍā": ['cped'],
    "uccāvaca": ['ap90', 'cae', 'ddsa', 'mw'],
    "uccāvacatā": ['bhs'],
    "uccāṭa": ['mw'],
    "uccāṭana": ['mw'],
    "uccāṭanaṃ": ['ap90'],
    "uccāṭanīya": ['mw'],
    "uccāṭita": ['mw'],
    "uccūḍa": ['mw'],
    "uccūḍaḥ": ['ap90'],
    "uch": ['mw'],
    "ucita": ['ap90', 'bhs', 'cae', 'mw'],
    "ucitadarśitva": ['mw'],
    "ucitajña": ['ddsa', 'mw'],
    "ucitatva": ['mw'],
    "ucyati": ['bhs'],
    "ud": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uda": ['cae', 'cped', 'ddsa', 'mw'],
    "uda vā": ['cped'],
    "udabbadhī": ['cped'],
    "udabbahati": ['cped'],
    "udabbahi": ['cped'],
    "udabbahiṁ": ['cped'],
    "udabhāra": ['mw'],
    "udabhī": ['mw'],
    "udabindu": ['cae', 'cped', 'ddsa', 'mw'],
    "udabindunipāta": ['cped'],
    "udac": ['ap90', 'gra', 'mw'],
    "udacamasa": ['mw'],
    "udacandra": ['bhs'],
    "udacchidā": ['cped'],
    "udadhi": ['cae', 'cped', 'gra', 'mw'],
    "udadhijalamaya": ['mw'],
    "udadhikrā": ['mw'],
    "udadhikumāra": ['mw'],
    "udadhimala": ['mw'],
    "udadhimekhalā": ['mw'],
    "udadhinemi": ['mw'],
    "udadhirāja": ['mw'],
    "udadhisaṃbhava": ['mw'],
    "udadhisutā": ['mw'],
    "udadhisutānāyaka": ['mw'],
    "udadhivastrā": ['mw'],
    "udadhiḥ": ['ap90'],
    "udadhāna": ['ddsa', 'mw'],
    "udadhānāyatana": ['mw'],
    "udadhārā": ['mw'],
    "udadhīy": ['cae'],
    "udadhīya": ['ddsa', 'mw'],
    "udag": ['mw'],
    "udagadri": ['mw'],
    "udagagra": ['mw'],
    "udagapavargam": ['mw'],
    "udagayana": ['cae', 'ddsa', 'mw'],
    "udagbhava": ['mw'],
    "udagbhūma": ['mw'],
    "udagdakṣiṇa": ['mw'],
    "udagdaśa": ['mw'],
    "udagdvāra": ['mw'],
    "udagdvāram": ['mw'],
    "udagga": ['cped'],
    "udaggati": ['mw'],
    "udaggudagga": ['cped'],
    "udaghoṣa": ['mw'],
    "udaghāta": ['ddsa'],
    "udagra": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "udagradat": ['mw'],
    "udagragāmin": ['bhs'],
    "udagrapluta": ['cae'],
    "udagraplutatva": ['mw'],
    "udagrayati": ['ap90'],
    "udagrābha": ['gra', 'mw'],
    "udagrī": ['bhs'],
    "udagrīva": ['ddsa'],
    "udagāha": ['mw'],
    "udagāvṛtta": ['mw'],
    "udagāvṛtti": ['mw'],
    "udagāyata": ['mw'],
    "udaharaṇa": ['mw'],
    "udahāra": ['cae', 'ddsa', 'mw'],
    "udahāraka": ['bhs'],
    "udaj": ['ap90', 'mw'],
    "udaja": ['cae', 'ddsa', 'mw'],
    "udajalaka": ['mw'],
    "udajaḥ": ['ap90'],
    "udajina": ['mw'],
    "udajña": ['mw'],
    "udak": ['ap90', 'ddsa', 'mw'],
    "udaka": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "udakabhrama": ['bhs'],
    "udakabhāra": ['mw'],
    "udakabhūma": ['mw'],
    "udakabindu": ['mw'],
    "udakacandra": ['bhs', 'mw'],
    "udakacara": ['cped'],
    "udakacikkhalla": ['cped'],
    "udakada": ['mw'],
    "udakadhara": ['mw'],
    "udakadhārā": ['mw'],
    "udakadoṇikā": ['cped'],
    "udakadāna": ['mw'],
    "udakadānika": ['mw'],
    "udakadātṛ": ['mw'],
    "udakadāyin": ['cae', 'mw'],
    "udakaghāta": ['mw'],
    "udakagiri": ['mw'],
    "udakagāha": ['mw'],
    "udakahāra": ['bhs', 'cped', 'mw'],
    "udakakarman": ['cae', 'mw'],
    "udakakaṭāha": ['cped'],
    "udakakicca": ['cped'],
    "udakakkhandha": ['cped'],
    "udakakoṭṭhaka": ['cped'],
    "udakakriyā": ['cae', 'mw'],
    "udakakrīḍana": ['mw'],
    "udakakumbha": ['mw'],
    "udakakārya": ['cae', 'mw'],
    "udakakṛcchra": ['mw'],
    "udakakṣveḍikā": ['mw'],
    "udakala": ['ap90', 'mw'],
    "udakamantha": ['mw'],
    "udakamaya": ['mw'],
    "udakamañjarī": ['mw'],
    "udakamañjarīrasa": ['mw'],
    "udakamaṇi": ['bhs'],
    "udakamaṇḍalu": ['mw'],
    "udakameha": ['mw'],
    "udakamehin": ['mw'],
    "udakamātikā": ['cped'],
    "udakaniddhamana": ['cped'],
    "udakanisseka": ['cped'],
    "udakaniśrita": ['bhs'],
    "udakaparvata": ['mw'],
    "udakaparīkṣā": ['mw'],
    "udakaplotika": ['bhs'],
    "udakaprasāda": ['bhs'],
    "udakaprasādaka": ['bhs'],
    "udakapratīkāśa": ['mw'],
    "udakapuñchana": ['cped'],
    "udakapūrva": ['mw'],
    "udakapūrvakam": ['mw'],
    "udakarakṣikā": ['mw'],
    "udakarākṣasa": ['bhs'],
    "udakasaktu": ['mw'],
    "udakasaṃvāsa": ['bhs'],
    "udakasecana": ['cae', 'mw'],
    "udakasparśa": ['mw'],
    "udakasparśana": ['mw'],
    "udakasuddhika": ['cped'],
    "udakasuddhikā": ['cped'],
    "udakasādhu": ['mw'],
    "udakasāṭi": ['cped'],
    "udakatarpaṇa": ['mw'],
    "udakaudana": ['mw'],
    "udakavajra": ['mw'],
    "udakavant": ['cae'],
    "udakavat": ['mw'],
    "udakavindu": ['mw'],
    "udakavādya": ['mw'],
    "udakavāha": ['bhs'],
    "udakavāhaka": ['cped'],
    "udakavāhanarajju": ['cped'],
    "udakavīvadha": ['mw'],
    "udakaśuddha": ['mw'],
    "udakaśāka": ['mw'],
    "udakaśānti": ['mw'],
    "udakaśāntiprayoga": ['mw'],
    "udakaśāṭikā": ['bhs'],
    "udakaśīla": ['mw'],
    "udakaṃ": ['ap90'],
    "udakecara": ['cped', 'mw'],
    "udakecaraḥ": ['ap90'],
    "udakeviśīrṇa": ['ap90', 'mw'],
    "udakeśaya": ['mw'],
    "udakila": ['ap90', 'mw'],
    "udakkūla": ['mw'],
    "udakodara": ['mw'],
    "udakodarin": ['mw'],
    "udakodañjana": ['mw'],
    "udakopasparśana": ['ddsa', 'mw'],
    "udakopasparśin": ['mw'],
    "udakorohaka": ['cped'],
    "udakorohana": ['cped'],
    "udakorohaṇa": ['cped'],
    "udakorohaṇanuyoga": ['cped'],
    "udakotsecana": ['mw'],
    "udakoṣṭha": ['mw'],
    "udakpatha": ['mw'],
    "udakprasravaṇa": ['mw'],
    "udakprasravaṇānvita": ['mw'],
    "udakpravaṇa": ['mw'],
    "udakpāda": ['mw'],
    "udaksamāsa": ['mw'],
    "udaksaṃstha": ['mw'],
    "udaksena": ['mw'],
    "udakta": ['ap90', 'mw'],
    "udaktas": ['cae', 'ddsa', 'mw'],
    "udaktāt": ['ap90', 'cae', 'gra', 'mw'],
    "udakukkhepa": ['cped'],
    "udakumbha": ['cae', 'cped', 'ddsa', 'mw'],
    "udakumbhaka": ['cped'],
    "udakupasaṭṭhā": ['cped'],
    "udakupassaṭṭhā": ['cped'],
    "udakya": ['ap90', 'cae', 'ddsa', 'mw'],
    "udakyā": ['mw'],
    "udakyāgamana": ['mw'],
    "udakābhyavāyin": ['mw'],
    "udakādhāna": ['cped'],
    "udakādhāra": ['mw'],
    "udakāhāra": ['mw'],
    "udakānta": ['cae', 'mw'],
    "udakāntam": ['mw'],
    "udakārtha": ['cae', 'mw'],
    "udakārtham": ['mw'],
    "udakārthin": ['mw'],
    "udakārṇava": ['cae', 'mw'],
    "udakātman": ['mw'],
    "udakāñjali": ['cae', 'ddsa', 'mw'],
    "udakāṃsya": ['mw'],
    "udakīrya": ['mw'],
    "udakīryā": ['mw'],
    "udakīrṇa": ['mw'],
    "udakīya": ['mw'],
    "udakśiras": ['mw'],
    "udala": ['mw'],
    "udalākāśyapa": ['mw'],
    "udalāvaṇika": ['mw'],
    "udamantha": ['mw'],
    "udamaya": ['cae', 'mw'],
    "udambhas": ['ddsa'],
    "udamegha": ['gra', 'mw'],
    "udamehin": ['mw'],
    "udamāna": ['mw'],
    "udan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "udanemi": ['mw'],
    "udania": ['gra'],
    "udanimat": ['gra', 'mw'],
    "udanta": ['cae', 'ddsa', 'mw'],
    "udantaka": ['mw'],
    "udantam": ['mw'],
    "udantikā": ['mw'],
    "udantya": ['cae', 'ddsa', 'mw'],
    "udanvant": ['cae'],
    "udanvat": ['ap90', 'gra', 'mw'],
    "udany": ['cae', 'gra'],
    "udanya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "udanyaja": ['gra', 'mw'],
    "udanyati": ['ap90'],
    "udanyu": ['ap90', 'cae', 'gra', 'mw'],
    "udanyā": ['mw'],
    "udapa": ['mw'],
    "udapajjatha": ['cped'],
    "udapatta": ['cped'],
    "udapeṣam": ['mw'],
    "udaplava": ['mw'],
    "udapluta": ['mw'],
    "udaprut": ['cae', 'gra', 'mw'],
    "udapura": ['mw'],
    "udapurā": ['mw'],
    "udapādi": ['cped'],
    "udapāna": ['cae', 'cped', 'mw'],
    "udapānamaṇḍūka": ['mw'],
    "udapānāli": ['cped'],
    "udapānāḷi": ['cped'],
    "udapās": ['mw'],
    "udapāsi": ['bhs'],
    "udapātra": ['cae', 'ddsa', 'mw'],
    "udapātrī": ['mw'],
    "udapīti": ['mw'],
    "udapū": ['mw'],
    "udara": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "udarabharaṇamātrakevalecchu": ['mw'],
    "udaradāra": ['mw'],
    "udaragranthi": ['mw'],
    "udaraka": ['ap90', 'mw'],
    "udarakrimi": ['mw'],
    "udarakṛmi": ['mw'],
    "udarambhara": ['ddsa'],
    "udarapiśāca": ['mw'],
    "udarapoṣaṇa": ['mw'],
    "udarapātra": ['mw'],
    "udarapūra": ['cped'],
    "udarapūram": ['mw'],
    "udararandhra": ['ddsa', 'mw'],
    "udararoga": ['mw'],
    "udarasarpin": ['mw'],
    "udarasarvasva": ['mw'],
    "udarastha": ['mw'],
    "udarasthita": ['mw'],
    "udarathi": ['mw'],
    "udarathiḥ": ['ap90'],
    "udaratrāṇa": ['mw'],
    "udaratāḍam": ['mw'],
    "udaravadehakaṁ": ['cped'],
    "udaravat": ['ap90', 'mw'],
    "udaravistāra": ['cae', 'mw'],
    "udaravyādhi": ['mw'],
    "udaraśaya": ['mw'],
    "udaraśāṇḍilya": ['mw'],
    "udaraṃ": ['ap90'],
    "udaraṃbhara": ['cae', 'mw'],
    "udaraṃbhari": ['ap90', 'cae', 'mw'],
    "udaraṇa": ['cae', 'mw'],
    "udarc": ['mw'],
    "udarcis": ['ap90', 'cae', 'ddsa', 'mw'],
    "udard": ['mw'],
    "udarda": ['mw'],
    "udardaḥ": ['ap90'],
    "udarddha": ['mw'],
    "udardhaḥ": ['ap90'],
    "udarika": ['mw'],
    "udarila": ['mw'],
    "udarin": ['ap90', 'ddsa', 'mw'],
    "udariya": ['cped'],
    "udariṇī": ['mw'],
    "udarka": ['cae', 'ddsa', 'gra', 'mw'],
    "udarkaḥ": ['ap90'],
    "udarya": ['ap90', 'mw'],
    "udaryā": ['bhs'],
    "udarādhmāna": ['mw'],
    "udarāgni": ['mw'],
    "udarākṣa": ['mw'],
    "udarāmaya": ['mw'],
    "udarāmayin": ['mw'],
    "udarāvarta": ['mw'],
    "udarāveṣṭa": ['mw'],
    "udarāṭa": ['mw'],
    "udarṣa": ['mw'],
    "udas": ['ap90', 'mw'],
    "udasaktu": ['mw'],
    "udasana": ['mw'],
    "udasanaṃ": ['ap90'],
    "udasra": ['mw'],
    "udasta": ['ap90', 'mw'],
    "udasthālī": ['mw'],
    "udasthāna": ['mw'],
    "udastoka": ['mw'],
    "udastāt": ['mw'],
    "udasya": ['mw'],
    "udatantu": ['mw'],
    "udataulika": ['mw'],
    "udatāri": ['cped'],
    "udaudana": ['mw'],
    "udavagraha": ['mw'],
    "udavagrahaḥ": ['ap90'],
    "udavajra": ['ddsa', 'mw'],
    "udavasita": ['ddsa', 'mw'],
    "udavasitaṃ": ['ap90'],
    "udavaso": ['mw'],
    "udavasya": ['mw'],
    "udavasāna": ['mw'],
    "udavasānīya": ['ap90', 'mw'],
    "udavasānīyā": ['mw'],
    "udavasātṛ": ['mw'],
    "udavasāya": ['mw'],
    "udavindu": ['mw'],
    "udavraja": ['gra', 'mw'],
    "udavāha": ['cae', 'gra', 'mw'],
    "udavāhana": ['mw'],
    "udavāsa": ['cae', 'ddsa', 'mw'],
    "udavāsin": ['mw'],
    "udavīvadha": ['mw'],
    "udaya": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "udayabbaya": ['cped'],
    "udayadhavala": ['mw'],
    "udayagiri": ['cae', 'mw'],
    "udayagupta": ['mw'],
    "udayagāmi": ['bhs'],
    "udayajit": ['mw'],
    "udayajyā": ['mw'],
    "udayakara": ['mw'],
    "udayana": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "udayanacarita": ['mw'],
    "udayanatas": ['mw'],
    "udayanavatsarājaparipṛcchā": ['bhs'],
    "udayanaṃ": ['ap90'],
    "udayanopādhi": ['mw'],
    "udayanācārya": ['mw'],
    "udayanīya": ['ap90', 'mw'],
    "udayaparvata": ['mw'],
    "udayaprastha": ['mw'],
    "udayaprāṇa": ['mw'],
    "udayapura": ['mw'],
    "udayarkṣa": ['mw'],
    "udayarāja": ['ddsa', 'mw'],
    "udayarāśi": ['mw'],
    "udayasiṃha": ['mw'],
    "udayat": ['cped'],
    "udayataṭa": ['cae', 'mw'],
    "udayati": ['cped'],
    "udayatthagāmi": ['cped'],
    "udayatthagāmin": ['cped'],
    "udayatuṅga": ['mw'],
    "udayavarman": ['mw'],
    "udayavat": ['mw'],
    "udayavatī": ['mw'],
    "udayavaya": ['cped'],
    "udayavyaya": ['cped'],
    "udayavyayin": ['mw'],
    "udayaśaila": ['cae', 'mw'],
    "udayaḥ": ['ap90'],
    "udayibhadra": ['bhs', 'mw'],
    "udayin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "udayonmukha": ['mw'],
    "udayorvībhṛt": ['cae', 'ddsa', 'mw'],
    "udayācala": ['cae', 'ddsa', 'mw'],
    "udayādhipa": ['cae'],
    "udayāditya": ['mw'],
    "udayādri": ['mw'],
    "udayānta": ['mw'],
    "udayāntara": ['mw'],
    "udayāstamaya": ['cae', 'mw'],
    "udayāsu": ['mw'],
    "udayāśva": ['mw'],
    "udañc": ['cae', 'ddsa', 'mw'],
    "udañcana": ['cae', 'ddsa', 'gra', 'mw'],
    "udañcanika": ['cped'],
    "udañcati": ['bhs'],
    "udañcita": ['mw'],
    "udañcu": ['mw'],
    "udañj": ['mw'],
    "udañjala": ['cped'],
    "udañjali": ['cae', 'ddsa', 'mw'],
    "udañji": ['mw'],
    "udaś": ['mw'],
    "udaśarāva": ['mw'],
    "udaśocā": ['mw'],
    "udaśraya": ['ddsa', 'mw'],
    "udaśrayaṇa": ['mw'],
    "udaśru": ['ap90', 'cae', 'ddsa', 'mw'],
    "udaśuddha": ['mw'],
    "udaśvidvat": ['mw'],
    "udaśvin": ['bhs'],
    "udaśvit": ['mw'],
    "udaṃbhas": ['ap90'],
    "udaṃc": ['ap90'],
    "udaṃcanaṃ": ['ap90'],
    "udaṃcu": ['ap90'],
    "udaṃjali": ['ap90'],
    "udaṃkaḥ": ['ap90'],
    "udaṃta": ['ap90'],
    "udaṃtakaḥ": ['ap90'],
    "udaṃtikā": ['ap90'],
    "udaṃtya": ['ap90'],
    "udaṃḍapālaḥ": ['ap90'],
    "udaṅ": ['mw'],
    "udaṅgulīka": ['mw'],
    "udaṅka": ['mw'],
    "udaṅkya": ['mw'],
    "udaṅkī": ['mw'],
    "udaṅmukha": ['cae', 'ddsa', 'mw'],
    "udaṅmṛttika": ['mw'],
    "udaṅīṣa": ['mw'],
    "udaṇḍapāla": ['mw'],
    "udbaddha": ['cae', 'mw'],
    "udbadhya": ['mw'],
    "udbala": ['ap90', 'mw'],
    "udbandh": ['mw'],
    "udbandha": ['cae', 'ddsa', 'mw'],
    "udbandhana": ['mw'],
    "udbandhuka": ['mw'],
    "udbarhis": ['mw'],
    "udbaṃdh": ['ap90'],
    "udbaṃdha": ['ap90'],
    "udbaṃdhakaḥ": ['ap90'],
    "udbaṃdhukaḥ": ['ap90'],
    "udbhagna": ['cae', 'mw'],
    "udbharts": ['mw'],
    "udbhasa": ['mw'],
    "udbhava": ['ap90', 'cae', 'ddsa', 'mw'],
    "udbhavakara": ['mw'],
    "udbhavakośaka": ['mw'],
    "udbhavakṣetra": ['mw'],
    "udbhavaḥ": ['ap90'],
    "udbhañj": ['mw'],
    "udbhaṅga": ['ddsa', 'mw'],
    "udbhaṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "udbhaṭatva": ['mw'],
    "udbheda": ['cae', 'ddsa', 'mw'],
    "udbhedana": ['mw'],
    "udbhedaḥ": ['ap90'],
    "udbhid": ['ap90', 'cae', 'gra', 'mw'],
    "udbhida": ['ap90', 'bhs', 'mw'],
    "udbhidvidyā": ['mw'],
    "udbhij": ['mw'],
    "udbhijja": ['cae', 'ddsa', 'mw'],
    "udbhinna": ['ap90', 'cae', 'mw'],
    "udbhram": ['ap90', 'mw'],
    "udbhrama": ['mw'],
    "udbhramaḥ": ['ap90'],
    "udbhramaṇa": ['ddsa', 'mw'],
    "udbhramaṇaṃ": ['ap90'],
    "udbhrānta": ['cae', 'ddsa', 'mw'],
    "udbhrāntaka": ['cae', 'mw'],
    "udbhrāṃta": ['ap90'],
    "udbhrū": ['mw'],
    "udbhuja": ['mw'],
    "udbhuta": ['bhs'],
    "udbhyasa": ['mw'],
    "udbhā": ['mw'],
    "udbhās": ['ap90', 'mw'],
    "udbhāsa": ['mw'],
    "udbhāsavat": ['mw'],
    "udbhāsaḥ": ['ap90'],
    "udbhāsin": ['ap90', 'cae', 'ddsa', 'mw'],
    "udbhāsita": ['mw'],
    "udbhāsura": ['mw'],
    "udbhāva": ['mw'],
    "udbhāvaka": ['bhs'],
    "udbhāvana": ['bhs', 'ddsa', 'mw'],
    "udbhāvanaṃ": ['ap90'],
    "udbhāvayitṛ": ['ap90', 'mw'],
    "udbhāvaḥ": ['ap90'],
    "udbhāvin": ['mw'],
    "udbhāvita": ['mw'],
    "udbhū": ['ap90', 'cae', 'mw'],
    "udbhūta": ['ap90', 'cae', 'mw'],
    "udbhūtarūpa": ['mw'],
    "udbhūtasparśavat": ['ddsa', 'mw'],
    "udbhūtatva": ['mw'],
    "udbhūtavastuka": ['bhs'],
    "udbhūti": ['cae', 'ddsa', 'mw'],
    "udbhūtiḥ": ['ap90'],
    "udbhṛ": ['mw'],
    "udbila": ['ap90', 'mw'],
    "udbilya": ['bhs'],
    "udbodha": ['mw'],
    "udbodhaka": ['ap90', 'mw'],
    "udbodhana": ['mw'],
    "udbodhaḥ": ['ap90'],
    "udbrū": ['mw'],
    "udbudbuda": ['ddsa', 'mw'],
    "udbuddha": ['ap90', 'cae', 'mw'],
    "udbuddhasaṃskāra": ['mw'],
    "udbudh": ['ap90', 'mw'],
    "udbudhnya": ['mw'],
    "udbādh": ['mw'],
    "udbāhu": ['ap90', 'ddsa', 'mw'],
    "udbāhuka": ['mw'],
    "udbāṣpa": ['ap90', 'cae', 'ddsa', 'mw'],
    "udbṛṃhaṇa": ['mw'],
    "udda": ['cped'],
    "uddahati": ['bhs'],
    "uddaka": ['bhs'],
    "uddal": ['mw'],
    "uddala": ['mw'],
    "uddalana": ['ddsa', 'mw'],
    "uddalomi": ['cped'],
    "uddalomin": ['cped'],
    "uddalomī": ['cped'],
    "uddam": ['mw'],
    "uddama": ['mw'],
    "uddamaḥ": ['ap90'],
    "uddamya": ['mw'],
    "uddantura": ['mw'],
    "uddarpa": ['ddsa'],
    "uddarśana": ['mw'],
    "uddarśanaṃ": ['ap90'],
    "uddarśita": ['mw'],
    "uddassayati": ['cped'],
    "uddassesi": ['cped'],
    "uddassetabba": ['cped'],
    "uddasseti": ['cped'],
    "uddassetvā": ['cped'],
    "uddaṃtura": ['ap90'],
    "uddaṃśa": ['mw'],
    "uddaṃśaḥ": ['ap90'],
    "uddaṃḍa": ['ap90'],
    "uddaṇḍa": ['cae', 'ddsa', 'mw'],
    "uddaṇḍakavi": ['mw'],
    "uddaṇḍapāla": ['mw'],
    "uddaṇḍaraṅganātha": ['mw'],
    "uddaṇḍita": ['mw'],
    "uddeha": ['mw'],
    "uddehika": ['mw'],
    "uddehikā": ['ap90', 'mw'],
    "uddeka": ['cped'],
    "uddekanika": ['cped'],
    "uddesa": ['cped'],
    "uddesabhatta": ['cped'],
    "uddesaka": ['cped'],
    "uddeśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "uddeśaka": ['ap90', 'bhs', 'mw'],
    "uddeśakavṛkṣa": ['mw'],
    "uddeśana": ['mw'],
    "uddeśapādapa": ['mw'],
    "uddeśatas": ['mw'],
    "uddeśavidheyavicāra": ['mw'],
    "uddeśavṛkṣa": ['mw'],
    "uddeśaḥ": ['ap90'],
    "uddeśena": ['mw'],
    "uddeśika": ['bhs'],
    "uddeśin": ['mw'],
    "uddeśya": ['ap90', 'mw'],
    "uddeśyaka": ['mw'],
    "uddeśyapādapa": ['mw'],
    "uddeśyavidheyabodhasthalīyavicāra": ['mw'],
    "uddeśāt": ['mw'],
    "uddeṣṭṛ": ['ap90', 'mw'],
    "uddha": ['cped'],
    "uddhacca": ['cped'],
    "uddhaccakukkucca": ['cped'],
    "uddhagga": ['cped'],
    "uddhaggaloma": ['cped'],
    "uddhaggika": ['cped'],
    "uddhagāmi": ['cped'],
    "uddhagāmin": ['cped'],
    "uddhama": ['ap90', 'mw'],
    "uddhamavidhamā": ['mw'],
    "uddhamma": ['cped'],
    "uddhan": ['ap90', 'mw'],
    "uddhana": ['cped', 'mw'],
    "uddhanana": ['bhs', 'mw'],
    "uddhapāda": ['cped'],
    "uddhara": ['ap90', 'bhs', 'mw'],
    "uddharati": ['bhs', 'cped'],
    "uddharaṇa": ['cae', 'cped', 'ddsa', 'mw'],
    "uddharaṇaṃ": ['ap90'],
    "uddharaṇīya": ['mw'],
    "uddharitabba": ['cped'],
    "uddharituṁ": ['cped'],
    "uddharitvā": ['cped'],
    "uddhariyyati": ['cped'],
    "uddhariṁsu": ['cped'],
    "uddharma": ['mw'],
    "uddharotsṛjā": ['mw'],
    "uddhartavya": ['mw'],
    "uddhartya": ['bhs'],
    "uddhartṛ": ['ap90', 'mw'],
    "uddharāpesuṁ": ['cped'],
    "uddharāpetabba": ['cped'],
    "uddharāpeti": ['cped'],
    "uddharāpetvā": ['cped'],
    "uddharāvasṛjā": ['mw'],
    "uddharīyati": ['cped'],
    "uddharṣa": ['ap90', 'mw'],
    "uddharṣaṇa": ['ap90', 'mw'],
    "uddharṣaṇī": ['mw'],
    "uddharṣin": ['ap90', 'mw'],
    "uddharṣiṇī": ['mw'],
    "uddhas": ['mw'],
    "uddhasta": ['ap90', 'cped', 'mw'],
    "uddhasudha": ['cped'],
    "uddhata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "uddhatamanas": ['mw'],
    "uddhatamanaska": ['mw'],
    "uddhatamanaskatva": ['mw'],
    "uddhatatva": ['mw'],
    "uddhati": ['ddsa', 'mw'],
    "uddhatiśrit": ['mw'],
    "uddhatiḥ": ['ap90'],
    "uddhatārṇavanisvana": ['mw'],
    "uddhava": ['bhs', 'mw'],
    "uddhavadūta": ['mw'],
    "uddhavasaṃdeśa": ['mw'],
    "uddhavaḥ": ['ap90'],
    "uddhavirecana": ['cped'],
    "uddhaya": ['mw'],
    "uddhaṁ": ['cped'],
    "uddhaṁ-āghātanika": ['cped'],
    "uddhaṁbhāgiya": ['cped'],
    "uddhaṁpāda": ['cped'],
    "uddhaṁsarāsatti": ['cped'],
    "uddhaṁsarāsuddhi": ['cped'],
    "uddhaṁsota": ['cped'],
    "uddhaṅ-gama": ['cped'],
    "uddhaṅ-gāmi": ['cped'],
    "uddhaṅ-gāmin": ['cped'],
    "uddhaṭa": ['cped'],
    "uddhi": ['cae', 'mw'],
    "uddhita": ['ap90', 'cae', 'mw'],
    "uddhiḥ": ['ap90'],
    "uddhmā": ['ap90', 'mw'],
    "uddhmāna": ['mw'],
    "uddhmānaṃ": ['ap90'],
    "uddhmāya": ['mw'],
    "uddhumāta": ['cped'],
    "uddhumātaka": ['cped'],
    "uddhumāyikā": ['cped'],
    "uddhura": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "uddhuta": ['cae'],
    "uddhuṣaṇa": ['mw'],
    "uddhvasyate": ['bhs'],
    "uddhvaṃs": ['mw'],
    "uddhvaṃsa": ['mw'],
    "uddhvaṃsana": ['mw'],
    "uddhvaṃsaḥ": ['ap90'],
    "uddhve": ['mw'],
    "uddhya": ['bhs', 'mw'],
    "uddhyaḥ": ['ap90'],
    "uddhā": ['ap90', 'mw'],
    "uddhāna": ['ap90', 'mw'],
    "uddhānana": ['bhs'],
    "uddhānta": ['mw'],
    "uddhāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "uddhāraka": ['bhs', 'mw'],
    "uddhārakavidhi": ['mw'],
    "uddhārakośa": ['mw'],
    "uddhāravibhāga": ['mw'],
    "uddhāraḥ": ['ap90'],
    "uddhāraṇa": ['mw'],
    "uddhāraṇaṃ": ['ap90'],
    "uddhārita": ['mw'],
    "uddhārya": ['mw'],
    "uddhārā": ['mw'],
    "uddhātuṁ": ['cped'],
    "uddhāṃta": ['ap90'],
    "uddhī": ['mw'],
    "uddhū": ['ap90', 'mw'],
    "uddhūlana": ['mw'],
    "uddhūlanaṃ": ['ap90'],
    "uddhūlay": ['cae'],
    "uddhūlaya": ['ddsa', 'mw'],
    "uddhūlayati": ['ap90'],
    "uddhūmāy": ['cae'],
    "uddhūmāyita": ['mw'],
    "uddhūnana": ['ddsa', 'mw'],
    "uddhūnanaṃ": ['ap90'],
    "uddhūpana": ['mw'],
    "uddhūpanaṃ": ['ap90'],
    "uddhūta": ['ap90', 'cae', 'mw'],
    "uddhūtapāpa": ['mw'],
    "uddhūti": ['cae', 'mw'],
    "uddhūṣaṇa": ['mw'],
    "uddhūṣaṇaṃ": ['ap90'],
    "uddhūṣita": ['ddsa', 'mw'],
    "uddhṛ": ['ap90', 'mw'],
    "uddhṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "uddhṛtasneha": ['cae', 'mw'],
    "uddhṛti": ['cae', 'mw'],
    "uddhṛtiḥ": ['ap90'],
    "uddhṛtoddhāra": ['mw'],
    "uddhṛtya": ['cae', 'mw'],
    "uddhṛtāri": ['mw'],
    "uddhṛṣ": ['mw'],
    "uddidhīrṣu": ['mw'],
    "uddidhīrṣā": ['mw'],
    "uddih": ['mw'],
    "uddina": ['mw'],
    "uddinaṃ": ['ap90'],
    "uddisanta": ['cped'],
    "uddisati": ['cped'],
    "uddisi": ['cped'],
    "uddisita": ['cped'],
    "uddisitabba": ['cped'],
    "uddisitar": ['cped'],
    "uddisituṁ": ['cped'],
    "uddisitvā": ['cped'],
    "uddisiṁsu": ['cped'],
    "uddissa": ['cped'],
    "uddissakata": ['cped'],
    "uddissamāna": ['cped'],
    "uddissati": ['cped'],
    "uddissiyati": ['cped'],
    "uddissiyyati": ['cped'],
    "uddissīyati": ['cped'],
    "uddisāpetabba": ['cped'],
    "uddisāpeti": ['cped'],
    "uddita": ['ap90', 'mw'],
    "uddiś": ['ap90', 'mw'],
    "uddiśana": ['bhs'],
    "uddiśati": ['bhs'],
    "uddiśya": ['ap90', 'cae', 'ddsa', 'mw'],
    "uddiśyati": ['bhs'],
    "uddiṣṭa": ['ap90', 'mw'],
    "uddiṣṭaka": ['bhs'],
    "uddiṭṭha": ['cped'],
    "uddosita": ['cped'],
    "uddraṣṭṛ": ['mw'],
    "uddru": ['mw'],
    "uddruta": ['mw'],
    "uddrutya": ['mw'],
    "uddrāva": ['ap90', 'mw'],
    "udduṣ": ['mw'],
    "uddyota": ['ap90', 'cae', 'ddsa', 'mw'],
    "uddyotaka": ['mw'],
    "uddyotakara": ['mw'],
    "uddyotakarācārya": ['mw'],
    "uddyotakārin": ['mw'],
    "uddyotamayūkha": ['mw'],
    "uddyotana": ['mw'],
    "uddyotanasūri": ['mw'],
    "uddyotin": ['mw'],
    "uddyotita": ['mw'],
    "uddyut": ['ap90', 'mw'],
    "uddā": ['mw'],
    "uddāha": ['bhs', 'cae', 'mw'],
    "uddāhana": ['bhs'],
    "uddāla": ['mw'],
    "uddālaka": ['cae', 'ddsa', 'mw'],
    "uddālakapuṣpabhañjikā": ['mw'],
    "uddālakavrata": ['mw'],
    "uddālakaḥ": ['ap90'],
    "uddālakāyana": ['mw'],
    "uddālana": ['mw'],
    "uddālanaka": ['cped'],
    "uddālaḥ": ['ap90'],
    "uddāletvā": ['cped'],
    "uddālin": ['mw'],
    "uddālitvā": ['cped'],
    "uddālya": ['mw'],
    "uddāma": ['ap90', 'cae', 'ddsa', 'mw'],
    "uddāmam": ['mw'],
    "uddāmaya": ['ddsa', 'mw'],
    "uddāna": ['bhs', 'cped', 'ddsa', 'mw'],
    "uddānato": ['cped'],
    "uddānaṃ": ['ap90'],
    "uddānta": ['mw'],
    "uddāpava": ['cped'],
    "uddāpavat": ['cped'],
    "uddāsa": ['mw'],
    "uddāsin": ['mw'],
    "uddāya": ['mw'],
    "uddāyāda": ['bhs'],
    "uddāṃta": ['ap90'],
    "uddīkṣā": ['mw'],
    "uddīp": ['ap90', 'mw'],
    "uddīpa": ['mw'],
    "uddīpaka": ['ap90', 'mw'],
    "uddīpana": ['ddsa', 'mw'],
    "uddīpanaṃ": ['ap90'],
    "uddīpaḥ": ['ap90'],
    "uddīpikā": ['mw'],
    "uddīpra": ['ap90', 'mw'],
    "uddīpta": ['ap90', 'mw'],
    "uddīpti": ['mw'],
    "uddīrṇa": ['mw'],
    "uddīśa": ['mw'],
    "uddūṣya": ['mw'],
    "uddṛś": ['ap90', 'mw'],
    "uddṛṃh": ['mw'],
    "uddṛṣṭa": ['cae', 'mw'],
    "uddṝ": ['mw'],
    "ude": ['mw'],
    "udej": ['mw'],
    "udejaya": ['ap90', 'mw'],
    "udetavya": ['ddsa'],
    "udeti": ['cped'],
    "udetos": ['cae', 'ddsa'],
    "udeyivas": ['mw'],
    "udeṣyat": ['ap90', 'mw'],
    "udga": ['bhs'],
    "udgadgadikā": ['ddsa', 'mw'],
    "udgai": ['ap90', 'mw'],
    "udgal": ['mw'],
    "udgala": ['mw'],
    "udgam": ['ap90', 'mw'],
    "udgama": ['cae', 'ddsa', 'mw'],
    "udgamana": ['cae', 'ddsa', 'mw'],
    "udgamanaṃ": ['ap90'],
    "udgamanīya": ['ap90', 'cae', 'mw'],
    "udgamayati": ['bhs'],
    "udgamaḥ": ['ap90'],
    "udgandhi": ['mw'],
    "udgantṛ": ['mw'],
    "udgarbha": ['cae', 'mw'],
    "udgarj": ['mw'],
    "udgarjita": ['cae', 'mw'],
    "udgata": ['ap90', 'bhs', 'cae', 'mw'],
    "udgataka": ['bhs'],
    "udgataśṛṅga": ['mw'],
    "udgati": ['ddsa', 'mw'],
    "udgatiḥ": ['ap90'],
    "udgatā": ['ddsa', 'mw'],
    "udgatāsu": ['mw'],
    "udgaṃdhi": ['ap90'],
    "udgehī": ['mw'],
    "udgeya": ['mw'],
    "udgha": ['mw'],
    "udghana": ['mw'],
    "udghanaḥ": ['ap90'],
    "udgharṣa": ['mw'],
    "udgharṣaṇa": ['cae', 'mw'],
    "udgharṣaṇaṃ": ['ap90'],
    "udghasaṃ": ['ap90'],
    "udghaḥ": ['ap90'],
    "udghaṭ": ['ap90', 'mw'],
    "udghaṭaka": ['bhs'],
    "udghaṭita": ['mw'],
    "udghaṭitajña": ['bhs'],
    "udghaṭitaṃ": ['ap90'],
    "udghaṭṭ": ['mw'],
    "udghaṭṭaka": ['mw'],
    "udghaṭṭakaḥ": ['ap90'],
    "udghaṭṭana": ['cae', 'ddsa', 'mw'],
    "udghaṭṭanaṃ": ['ap90'],
    "udghaṭṭayati": ['bhs'],
    "udghaṭṭita": ['ap90', 'mw'],
    "udghoṇa": ['ddsa', 'mw'],
    "udghoṣa": ['cae', 'ddsa', 'mw'],
    "udghoṣaka": ['mw'],
    "udghoṣaḍiṇḍima": ['mw'],
    "udghoṣaḥ": ['ap90'],
    "udghoṣaṇa": ['cae', 'mw'],
    "udghuṣ": ['ap90', 'mw'],
    "udghuṣṭa": ['ap90', 'cae', 'mw'],
    "udghāta": ['cae', 'mw'],
    "udghātaka": ['mw'],
    "udghātana": ['mw'],
    "udghātaḥ": ['ap90'],
    "udghātikā": ['bhs'],
    "udghātin": ['ap90', 'cae', 'mw'],
    "udghātya": ['mw'],
    "udghātyaka": ['mw'],
    "udghāṭa": ['bhs', 'cae', 'ddsa', 'mw'],
    "udghāṭaka": ['bhs', 'cae', 'mw'],
    "udghāṭakaḥ": ['ap90'],
    "udghāṭana": ['ap90', 'cae', 'mw'],
    "udghāṭanīya": ['mw'],
    "udghāṭaḥ": ['ap90'],
    "udghāṭin": ['cae', 'mw'],
    "udghāṭita": ['ap90', 'mw'],
    "udghāṭitajña": ['mw'],
    "udghāṭitāṅga": ['mw'],
    "udghūrṇa": ['ddsa', 'mw'],
    "udghṛṣ": ['ap90', 'mw'],
    "udghṛṣṭa": ['mw'],
    "udghṛṣṭaṃ": ['ap90'],
    "udgiraṇa": ['cae', 'ddsa', 'mw'],
    "udgiraṇaṃ": ['ap90'],
    "udgoraṇa": ['mw'],
    "udgrabhaṇa": ['mw'],
    "udgrabhaṇaṃ": ['ap90'],
    "udgrah": ['ap90', 'mw'],
    "udgraha": ['bhs'],
    "udgrahaḥ": ['ap90'],
    "udgrahaṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "udgrahaṇikā": ['mw'],
    "udgranth": ['mw'],
    "udgrantha": ['mw'],
    "udgranthi": ['mw'],
    "udgranthya": ['mw'],
    "udgrathana": ['ddsa', 'mw'],
    "udgrathita": ['mw'],
    "udgrathya": ['mw'],
    "udgraṃth": ['ap90'],
    "udgraṃtha": ['ap90'],
    "udgraṃthi": ['ap90'],
    "udgrābha": ['mw'],
    "udgrāha": ['cae', 'ddsa', 'mw'],
    "udgrāhapadavṛtti": ['mw'],
    "udgrāhavat": ['mw'],
    "udgrāhaḥ": ['ap90'],
    "udgrāhaṇikā": ['ap90', 'mw'],
    "udgrāhita": ['ap90', 'mw'],
    "udgrāhiṇī": ['mw'],
    "udgrāsaka": ['mw'],
    "udgrīva": ['ap90', 'cae', 'mw'],
    "udgrīvikā": ['mw'],
    "udgrīvin": ['mw'],
    "udguh": ['mw'],
    "udgur": ['ap90', 'mw'],
    "udguraṇa": ['bhs'],
    "udguṇṭhikā": ['bhs'],
    "udgā": ['mw'],
    "udgāh": ['mw'],
    "udgāla": ['mw'],
    "udgāra": ['cae', 'ddsa', 'mw'],
    "udgāracūḍaka": ['mw'],
    "udgāraśodhana": ['mw'],
    "udgāraḥ": ['ap90'],
    "udgārika": ['bhs'],
    "udgārin": ['ap90', 'cae', 'mw'],
    "udgāthā": ['ap90', 'mw'],
    "udgātrādi": ['mw'],
    "udgātukāma": ['mw'],
    "udgātṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "udgātṛdamana": ['mw'],
    "udgāḍha": ['ap90', 'cae', 'mw'],
    "udgāḍham": ['mw'],
    "udgīraṇa": ['bhs'],
    "udgīrya": ['mw'],
    "udgīrṇa": ['cae', 'mw'],
    "udgīta": ['cae', 'mw'],
    "udgītha": ['cae', 'ddsa', 'mw'],
    "udgīthaḥ": ['ap90'],
    "udgīti": ['cae', 'ddsa', 'mw'],
    "udgītiḥ": ['ap90'],
    "udgīya": ['mw'],
    "udgūhana": ['mw'],
    "udgūrayitṛ": ['mw'],
    "udgūrṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "udgṛbhāya": ['mw'],
    "udgṛhya": ['mw'],
    "udgṛhīta": ['mw'],
    "udgṛhṇāti": ['bhs'],
    "udgṝ": ['ap90', 'mw'],
    "udhan": ['mw'],
    "udhas": ['ap90', 'mw'],
    "udhras": ['ap90', 'mw'],
    "udi": ['ap90', 'mw'],
    "udicca": ['cped'],
    "udiccare": ['cped'],
    "udikkhati": ['cped'],
    "udikkhisaṁ": ['cped'],
    "udikkhita": ['cped'],
    "udikkhitar": ['cped'],
    "udikṣati": ['bhs'],
    "udinakṣ": ['mw'],
    "udita": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uditahomin": ['mw'],
    "uditi": ['cae', 'ddsa', 'gra', 'mw'],
    "uditiḥ": ['ap90'],
    "uditodita": ['ddsa', 'mw'],
    "uditvara": ['mw'],
    "uditādhāna": ['mw'],
    "uditānudita": ['mw'],
    "uditānuvādin": ['mw'],
    "udiyāna": ['bhs'],
    "udiṅg": ['mw'],
    "udiṅgana": ['mw'],
    "udman": ['ap90', 'cae', 'mw'],
    "udojas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "udra": ['cae', 'ddsa', 'gra', 'mw'],
    "udrabhati": ['cped'],
    "udrahati": ['cped'],
    "udraka": ['mw'],
    "udrakarāmaputra": ['bhs'],
    "udram": ['mw'],
    "udrapāraka": ['mw'],
    "udratha": ['mw'],
    "udrathaḥ": ['ap90'],
    "udrañj": ['mw'],
    "udraśmi": ['ddsa', 'mw'],
    "udraḥ": ['ap90'],
    "udraṃkaḥ": ['ap90'],
    "udraṅga": ['mw'],
    "udraṅka": ['mw'],
    "udrecaka": ['mw'],
    "udreka": ['cae', 'ddsa', 'mw'],
    "udrekaḥ": ['ap90'],
    "udrekin": ['ap90', 'mw'],
    "udrekā": ['mw'],
    "udric": ['ap90', 'mw'],
    "udrikta": ['ap90', 'cae', 'mw'],
    "udriktacetas": ['mw'],
    "udriktacitta": ['ddsa', 'mw'],
    "udrin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "udriyati": ['cped'],
    "udrodhana": ['ddsa', 'mw'],
    "udrodhanaṃ": ['ap90'],
    "udroka": ['mw'],
    "udruc": ['mw'],
    "udrudh": ['mw'],
    "udruja": ['ap90', 'mw'],
    "udrāva": ['mw'],
    "udrāvaḥ": ['ap90'],
    "udrāyaṇa": ['bhs', 'mw'],
    "udrīyati": ['cped'],
    "udubj": ['mw'],
    "udubja": ['mw'],
    "uduha": ['mw'],
    "udukkhala": ['cped'],
    "udukkhalikā": ['cped'],
    "udukṣ": ['mw'],
    "udumbala": ['cae', 'ddsa', 'gra', 'mw'],
    "udumbara": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "udumbarakhādikaṁ": ['cped'],
    "udumbarakhādikā": ['cped'],
    "udumbhara": ['mw'],
    "udumā": ['bhs'],
    "udupāna": ['bhs'],
    "uduta": ['mw'],
    "uduṃbala": ['ap90'],
    "uduṃbaraḥ": ['ap90'],
    "uduṣ": ['mw'],
    "uduṣṭa": ['ap90', 'mw'],
    "uduṣṭamukha": ['mw'],
    "udvad": ['mw'],
    "udvadh": ['mw'],
    "udvah": ['ap90', 'mw'],
    "udvaha": ['ap90', 'cae', 'ddsa', 'mw'],
    "udvahana": ['bhs', 'cae', 'mw'],
    "udvahanaṃ": ['ap90'],
    "udvahni": ['mw'],
    "udvahnijvāla": ['mw'],
    "udvahā": ['mw'],
    "udvai": ['mw'],
    "udvaktra": ['mw'],
    "udvam": ['ap90', 'mw'],
    "udvamana": ['mw'],
    "udvamanaṃ": ['ap90'],
    "udvamita": ['mw'],
    "udvana": ['mw'],
    "udvanhi": ['ddsa'],
    "udvap": ['ap90', 'mw'],
    "udvapana": ['mw'],
    "udvapanaṃ": ['ap90'],
    "udvapanī": ['mw'],
    "udvardhana": ['mw'],
    "udvardhanaṃ": ['ap90'],
    "udvarga": ['mw'],
    "udvarhita": ['ap90'],
    "udvarta": ['ap90', 'mw'],
    "udvartaka": ['ap90', 'mw'],
    "udvartana": ['cae', 'ddsa', 'mw'],
    "udvartanaṃ": ['ap90'],
    "udvartayati": ['bhs'],
    "udvartin": ['mw'],
    "udvartita": ['ap90', 'mw'],
    "udvartman": ['mw'],
    "udvas": ['ap90', 'mw'],
    "udvasa": ['ap90', 'ddsa', 'mw'],
    "udvastra": ['mw'],
    "udvat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "udvatsara": ['mw'],
    "udvatsaraḥ": ['ap90'],
    "udvatsarīya": ['mw'],
    "udvayas": ['ap90', 'mw'],
    "udvaśyate": ['bhs'],
    "udvaṃśa": ['mw'],
    "udvaṃśīya": ['mw'],
    "udvaṃśīyottara": ['mw'],
    "udve": ['mw'],
    "udvecam": ['mw'],
    "udvedha": ['bhs'],
    "udvedi": ['ap90', 'ddsa', 'mw'],
    "udvega": ['ap90', 'cae', 'ddsa', 'mw'],
    "udvegakara": ['cae', 'mw'],
    "udvegakartarī": ['mw'],
    "udvegakāraka": ['mw'],
    "udvegakārin": ['mw'],
    "udvegavāhin": ['mw'],
    "udvegin": ['ddsa', 'mw'],
    "udvejaka": ['ddsa', 'mw'],
    "udvejana": ['ap90', 'cae', 'mw'],
    "udvejanakara": ['cae', 'mw'],
    "udvejanīya": ['cae', 'mw'],
    "udvejayitṛ": ['ap90', 'mw'],
    "udvejin": ['ap90', 'mw'],
    "udvejita": ['mw'],
    "udvela": ['ap90', 'ddsa', 'mw'],
    "udvelaya": ['mw'],
    "udvelita": ['mw'],
    "udvell": ['ap90', 'mw'],
    "udvellana": ['mw'],
    "udvellita": ['ap90', 'cae', 'mw'],
    "udvep": ['mw'],
    "udvepa": ['mw'],
    "udvepaḥ": ['ap90'],
    "udvepin": ['mw'],
    "udvetana": ['bhs'],
    "udveṣṭ": ['mw'],
    "udveṣṭa": ['ap90', 'mw'],
    "udveṣṭana": ['ap90', 'ddsa', 'mw'],
    "udveṣṭanīya": ['ddsa', 'mw'],
    "udveṣṭayati": ['ap90', 'bhs'],
    "udveṣṭita": ['ap90', 'mw'],
    "udvicakṣ": ['mw'],
    "udviciya": ['bhs'],
    "udviddha": ['cae', 'mw'],
    "udvidṝ": ['mw'],
    "udvighuṣ": ['mw'],
    "udvighāṭana": ['bhs'],
    "udvigna": ['ap90', 'cae', 'ddsa', 'mw'],
    "udvignacetas": ['mw'],
    "udvignacitta": ['mw'],
    "udvignadṛś": ['mw'],
    "udvignahṛdaya": ['mw'],
    "udvignalocana": ['mw'],
    "udvignamanas": ['mw'],
    "udvignodvigna": ['cae'],
    "udvij": ['ap90', 'mw'],
    "udvijitavya": ['ddsa'],
    "udvikāsin": ['ddsa', 'mw'],
    "udvilya": ['bhs'],
    "udvisṛj": ['mw'],
    "udvivarhaṇa": ['mw'],
    "udvoḍhukāma": ['mw'],
    "udvoḍhṛ": ['ap90', 'mw'],
    "udvraj": ['mw'],
    "udvyadh": ['mw'],
    "udvyastikā": ['bhs'],
    "udvyudas": ['mw'],
    "udvyūḍha": ['cae', 'mw'],
    "udvā": ['mw'],
    "udvācana": ['mw'],
    "udvādana": ['mw'],
    "udvādanaṃ": ['ap90'],
    "udvāha": ['cae', 'ddsa', 'mw'],
    "udvāhakarman": ['mw'],
    "udvāhamaṅgala": ['cae', 'mw'],
    "udvāhana": ['ap90', 'mw'],
    "udvāhanī": ['mw'],
    "udvāharkṣa": ['mw'],
    "udvāhatattva": ['mw'],
    "udvāhaḥ": ['ap90'],
    "udvāhika": ['ap90', 'mw'],
    "udvāhin": ['ap90', 'mw'],
    "udvāhinī": ['mw'],
    "udvāhita": ['ap90', 'mw'],
    "udvālavat": ['mw'],
    "udvāmin": ['mw'],
    "udvāna": ['ap90', 'mw'],
    "udvānta": ['mw'],
    "udvānti": ['mw'],
    "udvāpa": ['mw'],
    "udvāpana": ['mw'],
    "udvāpaḥ": ['ap90'],
    "udvāra": ['mw'],
    "udvāsa": ['ap90', 'mw'],
    "udvāsana": ['mw'],
    "udvāsanaṃ": ['ap90'],
    "udvāsanīya": ['mw'],
    "udvāsas": ['mw'],
    "udvāsavat": ['mw'],
    "udvāsaḥ": ['ap90'],
    "udvāsin": ['mw'],
    "udvāsya": ['ap90', 'mw'],
    "udvāsīkārin": ['mw'],
    "udvāś": ['mw'],
    "udvāṃta": ['ap90'],
    "udvāṣpa": ['mw'],
    "udvāṣpatva": ['mw'],
    "udvīj": ['ap90', 'mw'],
    "udvījanaṃ": ['ap90'],
    "udvīkṣ": ['ap90', 'mw'],
    "udvīkṣaṇa": ['cae', 'ddsa', 'mw'],
    "udvīkṣaṇaṃ": ['ap90'],
    "udvīkṣita": ['mw'],
    "udvīkṣya": ['bhs', 'mw'],
    "udvīta": ['mw'],
    "udvṛ": ['mw'],
    "udvṛddha": ['mw'],
    "udvṛdh": ['mw'],
    "udvṛh": ['ap90', 'mw'],
    "udvṛj": ['mw'],
    "udvṛt": ['ap90', 'mw'],
    "udvṛtta": ['ap90', 'cae', 'mw'],
    "udvṛtya": ['mw'],
    "udvṛḍha": ['mw'],
    "udvṛṃhaṇa": ['mw'],
    "udvṛṃhaṇaṃ": ['ap90'],
    "udvṛṣ": ['mw'],
    "udvṛṣabhayajña": ['mw'],
    "udya": ['bhs', 'mw'],
    "udyadgiri": ['mw'],
    "udyam": ['ap90', 'mw'],
    "udyama": ['cae', 'ddsa', 'mw'],
    "udyamabhaṅga": ['mw'],
    "udyamabhṛt": ['cae', 'mw'],
    "udyamana": ['cae', 'mw'],
    "udyamanaṃ": ['ap90'],
    "udyamaḥ": ['ap90'],
    "udyamin": ['ap90', 'ddsa', 'mw'],
    "udyamita": ['mw'],
    "udyamya": ['mw'],
    "udyamīyas": ['gra', 'mw'],
    "udyantṛ": ['gra', 'mw'],
    "udyat": ['ap90', 'mw'],
    "udyata": ['ap90', 'cae', 'ddsa', 'mw'],
    "udyatadaṇḍa": ['cae', 'mw'],
    "udyatagada": ['mw'],
    "udyataka": ['bhs'],
    "udyatakārmuka": ['mw'],
    "udyatasruc": ['gra', 'mw'],
    "udyataśūla": ['mw'],
    "udyati": ['cae', 'ddsa', 'gra', 'mw'],
    "udyatiḥ": ['ap90'],
    "udyatparvata": ['mw'],
    "udyatāstra": ['mw'],
    "udyatāyudha": ['mw'],
    "udyatī": ['mw'],
    "udyaṃtṛ": ['ap90'],
    "udyoga": ['cae', 'ddsa', 'mw'],
    "udyogaparvan": ['mw'],
    "udyogapāla": ['bhs'],
    "udyogasamartha": ['mw'],
    "udyogaḥ": ['ap90'],
    "udyogin": ['ap90', 'cae', 'mw'],
    "udyojayati": ['bhs'],
    "udyojita": ['mw'],
    "udyoṭita": ['bhs'],
    "udyu": ['mw'],
    "udyudh": ['mw'],
    "udyuga": ['ddsa', 'mw'],
    "udyuj": ['ap90', 'mw'],
    "udyukta": ['ap90', 'cae', 'mw'],
    "udyuta": ['mw'],
    "udyā": ['ap90', 'mw'],
    "udyāma": ['bhs', 'mw'],
    "udyāmaḥ": ['ap90'],
    "udyāna": ['bhs', 'cae', 'ddsa', 'mw'],
    "udyānagahana": ['cae'],
    "udyānaka": ['mw'],
    "udyānakaṃ": ['ap90'],
    "udyānamālā": ['cae', 'mw'],
    "udyānapāla": ['cae', 'mw'],
    "udyānapālaka": ['mw'],
    "udyānapālikā": ['mw'],
    "udyānapālī": ['mw'],
    "udyānarakṣaka": ['mw'],
    "udyānavāṭa": ['cae'],
    "udyānaṃ": ['ap90'],
    "udyāpana": ['mw'],
    "udyāpanaṃ": ['ap90'],
    "udyāpanikā": ['mw'],
    "udyāpita": ['ap90', 'mw'],
    "udyāsa": ['mw'],
    "udyāsaḥ": ['ap90'],
    "udyāva": ['mw'],
    "udyāvaḥ": ['ap90'],
    "udyūthikā": ['bhs'],
    "udācakṣ": ['mw'],
    "udācam": ['mw'],
    "udācar": ['mw'],
    "udācāra": ['ddsa', 'mw'],
    "udādru": ['mw'],
    "udādyanta": ['mw'],
    "udādā": ['mw'],
    "udāgata": ['bhs'],
    "udāgā": ['mw'],
    "udāhan": ['mw'],
    "udāharana": ['cae'],
    "udāharati": ['cped'],
    "udāharaṇa": ['ddsa', 'mw'],
    "udāharaṇacandrikā": ['mw'],
    "udāharaṇaṃ": ['ap90'],
    "udāharaṇānugama": ['mw'],
    "udāharaṇīya": ['mw'],
    "udāharin": ['mw'],
    "udāharitabba": ['cped'],
    "udāhita": ['ap90', 'mw'],
    "udāhitatara": ['mw'],
    "udāhu": ['cped'],
    "udāhāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "udāhāraḥ": ['ap90'],
    "udāhārya": ['ddsa', 'mw'],
    "udāhṛ": ['ap90', 'mw'],
    "udāhṛta": ['ap90', 'cae', 'mw'],
    "udāhṛti": ['mw'],
    "udāhṛtiḥ": ['ap90'],
    "udāhṛtya": ['mw'],
    "udāj": ['mw'],
    "udāja": ['cae', 'mw'],
    "udājan": ['mw'],
    "udājaḥ": ['ap90'],
    "udājita": ['cped'],
    "udākhyā": ['mw'],
    "udākhyāya": ['mw'],
    "udākṛ": ['mw'],
    "udālin": ['bhs'],
    "udāmantraṇa": ['mw'],
    "udāna": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "udānabhṛt": ['mw'],
    "udānaya": ['mw'],
    "udānayat": ['cped'],
    "udānayati": ['bhs'],
    "udānaḥ": ['ap90'],
    "udānesi": ['cped'],
    "udāneti": ['cped'],
    "udānta": ['bhs'],
    "udānī": ['mw'],
    "udāp": ['mw'],
    "udāpi": ['mw'],
    "udāplu": ['mw'],
    "udāpluta": ['mw'],
    "udāpyaṃ": ['ap90'],
    "udāpyām": ['mw'],
    "udāra": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "udārabhāva": ['mw'],
    "udāracarita": ['cae', 'ddsa', 'mw'],
    "udāracetas": ['mw'],
    "udāradarśana": ['mw'],
    "udāradeva": ['bhs'],
    "udāradhiṣaṇa": ['mw'],
    "udāradhī": ['cae', 'mw'],
    "udāragata": ['bhs'],
    "udāragupta": ['bhs'],
    "udāraka": ['ddsa', 'mw'],
    "udārakīrti": ['mw'],
    "udāramati": ['mw'],
    "udārasattva": ['mw'],
    "udārasattvābhijana": ['mw'],
    "udārataraka": ['bhs'],
    "udārathi": ['ap90', 'gra', 'mw'],
    "udāratva": ['mw'],
    "udāratā": ['ap90', 'cae', 'mw'],
    "udāravikrama": ['mw'],
    "udāravīrya": ['mw'],
    "udāravṛttārthapada": ['mw'],
    "udāraśobha": ['mw'],
    "udāraśīla": ['cae'],
    "udārika": ['bhs'],
    "udāruh": ['mw'],
    "udārākṣa": ['mw'],
    "udārārtha": ['mw'],
    "udās": ['ap90', 'mw'],
    "udāsa": ['ap90', 'mw'],
    "udāsaḥ": ['ap90'],
    "udāsin": ['mw'],
    "udāsitṛ": ['ap90', 'ddsa', 'mw'],
    "udāsthita": ['ap90', 'ddsa', 'mw'],
    "udāsthā": ['mw'],
    "udāsyapuccha": ['mw'],
    "udāsīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "udāsīnatā": ['mw'],
    "udātan": ['mw'],
    "udātta": ['ap90', 'cae', 'ddsa', 'mw'],
    "udāttakīrti": ['bhs'],
    "udāttamaya": ['mw'],
    "udāttarāghava": ['mw'],
    "udāttatara": ['ap90'],
    "udāttatva": ['mw'],
    "udāttatā": ['mw'],
    "udāttavarṇa": ['bhs'],
    "udāttavastra": ['bhs'],
    "udāttavat": ['mw'],
    "udāttaya": ['mw'],
    "udāttaśruti": ['mw'],
    "udāttaśrutitā": ['mw'],
    "udāttokti": ['mw'],
    "udāttālaṅkāra": ['ddsa'],
    "udāvah": ['mw'],
    "udāvarta": ['mw'],
    "udāvartaka": ['mw'],
    "udāvartana": ['mw'],
    "udāvartaḥ": ['ap90'],
    "udāvartin": ['mw'],
    "udāvartā": ['mw'],
    "udāvas": ['mw'],
    "udāvasu": ['mw'],
    "udāvatsara": ['mw'],
    "udāvatsaraḥ": ['ap90'],
    "udāvraj": ['mw'],
    "udāvṛt": ['mw'],
    "udāya": ['gra', 'mw'],
    "udāyam": ['mw'],
    "udāyasa": ['mw'],
    "udāyin": ['bhs', 'mw'],
    "udāyu": ['mw'],
    "udāyudha": ['ap90', 'ddsa', 'mw'],
    "udāyā": ['mw'],
    "udāśaya": ['mw'],
    "udāśaṃs": ['mw'],
    "udīcya": ['ap90', 'cae', 'ddsa', 'mw'],
    "udīcyavṛtti": ['mw'],
    "udīcī": ['ap90', 'ddsa', 'mw'],
    "udīcīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "udīcīnakumba": ['mw'],
    "udīcīnapravaṇa": ['mw'],
    "udīcīpatha": ['mw'],
    "udīkṣ": ['ap90', 'mw'],
    "udīkṣaṇa": ['mw'],
    "udīkṣaṇaṃ": ['ap90'],
    "udīkṣita": ['mw'],
    "udīkṣya": ['mw'],
    "udīkṣā": ['cae', 'ddsa', 'mw'],
    "udīpa": ['ap90', 'ddsa', 'mw'],
    "udīr": ['ap90', 'mw'],
    "udīrayanta": ['cped'],
    "udīrayati": ['cped'],
    "udīrayi": ['cped'],
    "udīraṇa": ['cae', 'ddsa', 'mw'],
    "udīraṇaṃ": ['ap90'],
    "udīreti": ['cped'],
    "udīrita": ['cped', 'mw'],
    "udīritadhī": ['mw'],
    "udīritendriya": ['mw'],
    "udīrya": ['mw'],
    "udīrṇa": ['ap90', 'cae', 'mw'],
    "udīrṇadīdhiti": ['mw'],
    "udīrṇatā": ['mw'],
    "udīrṇavarāhatīrtha": ['mw'],
    "udīrṇavega": ['mw'],
    "udīta": ['mw'],
    "udīyyati": ['cped'],
    "udīṣ": ['mw'],
    "udīṣita": ['ap90', 'cae', 'mw'],
    "udūh": ['mw'],
    "udūha": ['mw'],
    "udūkhala": ['ap90', 'mw'],
    "udūrmi": ['mw'],
    "udūḍha": ['ap90', 'bhs', 'mw'],
    "udūḍhā": ['cae'],
    "udṛ": ['mw'],
    "udṛc": ['ap90', 'cae', 'gra', 'mw'],
    "udṛci": ['mw'],
    "udṛṣ": ['mw'],
    "ugaṇa": ['ap90', 'mw'],
    "ugga": ['cped'],
    "uggacchamāna": ['cped'],
    "uggacchanta": ['cped'],
    "uggacchati": ['cped'],
    "uggacchi": ['cped'],
    "uggaha": ['cped'],
    "uggahesi": ['cped'],
    "uggahessati": ['cped'],
    "uggaheta": ['cped'],
    "uggahetabba": ['cped'],
    "uggahetar": ['cped'],
    "uggahetuṁ": ['cped'],
    "uggahetvā": ['cped'],
    "uggahetvāna": ['cped'],
    "uggahita": ['cped'],
    "uggahitapaṭiggahitaka": ['cped'],
    "uggahāpeti": ['cped'],
    "uggahāpetvā": ['cped'],
    "uggahīta": ['cped'],
    "uggam": ['bhs'],
    "uggamana": ['cped'],
    "uggamissati": ['cped'],
    "uggantvā": ['cped'],
    "uggaputta": ['cped'],
    "uggata": ['bhs', 'cped'],
    "uggateja": ['cped'],
    "uggavādi": ['cped'],
    "uggavādin": ['cped'],
    "uggayha": ['cped'],
    "uggañchi": ['cped'],
    "uggaṇhanta": ['cped'],
    "uggaṇhāpeti": ['cped'],
    "uggaṇhāpetvā": ['cped'],
    "uggaṇhāti": ['cped'],
    "ugghara": ['cped'],
    "uggharanta": ['cped'],
    "uggharat": ['cped'],
    "ugghaṁsetabba": ['cped'],
    "ugghaṁseti": ['cped'],
    "ugghaṭeti": ['cped'],
    "ugghaṭṭa": ['cped'],
    "ugghaṭṭapāda": ['cped'],
    "ugghaṭṭha": ['cped'],
    "ugghātita": ['cped'],
    "ugghāṭana": ['cped'],
    "ugghāṭanakiṭika": ['cped'],
    "ugghāṭeti": ['cped'],
    "ugghāṭetvā": ['cped'],
    "ugghāṭita": ['cped'],
    "ugghāṭitaññu": ['cped'],
    "uggilati": ['cped'],
    "uggira": ['cped'],
    "uggiranta": ['cped'],
    "uggirati": ['cped'],
    "uggirita": ['cped'],
    "uggiriṁsu": ['cped'],
    "ugit": ['ddsa'],
    "ugra": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ugrabhairava": ['mw'],
    "ugrabhaṭa": ['mw'],
    "ugrabāhu": ['cae', 'gra', 'mw'],
    "ugracaya": ['mw'],
    "ugracaṇḍā": ['mw'],
    "ugracārin": ['mw'],
    "ugracāriṇī": ['mw'],
    "ugradanta": ['mw'],
    "ugradarśana": ['mw'],
    "ugradattaparipṛcchā": ['bhs'],
    "ugradaṃṣṭra": ['mw'],
    "ugradaṇḍa": ['mw'],
    "ugradeva": ['mw'],
    "ugradhanvan": ['gra', 'mw'],
    "ugradhṛtāyudha": ['mw'],
    "ugraduhitṛ": ['mw'],
    "ugragandha": ['mw'],
    "ugragandhikā": ['mw'],
    "ugragandhin": ['mw'],
    "ugragandhā": ['mw'],
    "ugragādha": ['mw'],
    "ugrajit": ['mw'],
    "ugrajāti": ['mw'],
    "ugraka": ['ap90', 'mw'],
    "ugrakarman": ['cae', 'mw'],
    "ugrakarṇika": ['mw'],
    "ugrakālī": ['mw'],
    "ugrakāṇḍa": ['mw'],
    "ugralipi": ['bhs'],
    "ugramaya": ['mw'],
    "ugranāsika": ['mw'],
    "ugraparipṛcchā": ['bhs'],
    "ugrapaśya": ['mw'],
    "ugrapaśyā": ['mw'],
    "ugraprabhāva": ['cae'],
    "ugraputra": ['gra', 'mw'],
    "ugraputrī": ['mw'],
    "ugrapūti": ['cae', 'mw'],
    "ugraretas": ['mw'],
    "ugraruṣ": ['mw'],
    "ugrarūpa": ['cae'],
    "ugrasena": ['bhs', 'cae', 'mw'],
    "ugrasenaja": ['mw'],
    "ugrasenānī": ['mw'],
    "ugrasenī": ['mw'],
    "ugrasevita": ['mw'],
    "ugrasūtra": ['bhs'],
    "ugratapas": ['mw'],
    "ugratejas": ['bhs', 'mw'],
    "ugratva": ['mw'],
    "ugratā": ['ap90', 'cae', 'mw'],
    "ugratārā": ['mw'],
    "ugravega": ['mw'],
    "ugravyagra": ['mw'],
    "ugravīra": ['mw'],
    "ugravīrya": ['mw'],
    "ugraśakti": ['mw'],
    "ugraśekharā": ['mw'],
    "ugraśoka": ['mw'],
    "ugraśravas": ['mw'],
    "ugraśravaṇadarśana": ['mw'],
    "ugraśāsana": ['cae', 'mw'],
    "ugraṃpaśya": ['ap90'],
    "ugreśa": ['mw'],
    "ugrā": ['mw'],
    "ugrācārya": ['mw'],
    "ugrādeva": ['gra', 'mw'],
    "ugrānna": ['cae', 'mw'],
    "ugrātapa": ['cae', 'mw'],
    "ugrāyudha": ['mw'],
    "ugrī": ['mw'],
    "uh": ['ap90', 'cae', 'ddsa', 'mw'],
    "uha": ['ap90'],
    "uhan": ['gra'],
    "uhlaṇa": ['mw'],
    "uhoḍima": ['bhs'],
    "uhra": ['mw'],
    "uhraḥ": ['ap90'],
    "uhuvāyivāsiṣṭha": ['mw'],
    "uhya": ['ddsa'],
    "uhyagāna": ['mw'],
    "uhyamāna": ['cae', 'mw'],
    "uhyamānaka": ['cae'],
    "uhāna": ['mw'],
    "uhū": ['gra', 'mw'],
    "uhūḥ": ['ap90'],
    "uj": ['gra'],
    "ujjagghanti": ['cped'],
    "ujjagghati": ['cped'],
    "ujjaggheti": ['cped'],
    "ujjagghi": ['cped'],
    "ujjagghikā": ['cped'],
    "ujjagghiyamāna": ['cped'],
    "ujjaha": ['cped'],
    "ujjahat": ['cped'],
    "ujjahati": ['cped'],
    "ujjalayati": ['cped'],
    "ujjaletabba": ['cped'],
    "ujjaleti": ['cped'],
    "ujjaliyati": ['cped'],
    "ujjaliṁsu": ['cped'],
    "ujjan": ['mw'],
    "ujjas": ['ap90', 'mw'],
    "ujjava": ['cped'],
    "ujjavajjava": ['cped'],
    "ujjavanikā": ['cped'],
    "ujjavi": ['cped'],
    "ujjaviṁsu": ['cped'],
    "ujjayana": ['mw'],
    "ujjayanta": ['mw'],
    "ujjayanī": ['ap90', 'mw'],
    "ujjayinī": ['ap90', 'cae', 'ddsa', 'mw'],
    "ujjaṅgala": ['bhs'],
    "ujjaṅgalanagaraka": ['cped'],
    "ujjaṅkikā": ['bhs'],
    "ujjendra": ['mw'],
    "ujjeṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ujjeṣavat": ['mw'],
    "ujjeṣin": ['mw'],
    "ujjh": ['ap90', 'cae', 'ddsa', 'mw'],
    "ujjha": ['ap90', 'cae', 'ddsa', 'mw'],
    "ujjhaka": ['mw'],
    "ujjhakaḥ": ['ap90'],
    "ujjhana": ['mw'],
    "ujjhanaṃ": ['ap90'],
    "ujjhati": ['cped'],
    "ujjhatti": ['cped'],
    "ujjhattibala": ['cped'],
    "ujjhaṭaḍimba": ['mw'],
    "ujjhaṭita": ['ap90', 'cae', 'mw'],
    "ujjhebhakatoṇehāraka": ['bhs'],
    "ujjhita": ['cae', 'cped', 'mw'],
    "ujjhitakarṇaka": ['mw'],
    "ujjhitapara": ['bhs'],
    "ujjhitavat": ['mw'],
    "ujjhiti": ['mw'],
    "ujjhitvā": ['cped'],
    "ujjhitṛ": ['mw'],
    "ujjhānasaññi": ['cped'],
    "ujjhānasaññika": ['cped'],
    "ujjhānasaññin": ['cped'],
    "ujjhāpana": ['cped'],
    "ujjhāpanaka": ['cped'],
    "ujjhāpayati": ['cped'],
    "ujjhāpenta": ['cped'],
    "ujjhāpesi": ['cped'],
    "ujjhāpetabba": ['cped'],
    "ujjhāpeti": ['cped'],
    "ujjhāpita": ['cped'],
    "ujjhāyanta": ['cped'],
    "ujjhāyati": ['cped'],
    "ujji": ['ap90', 'mw'],
    "ujjigamiṣā": ['mw'],
    "ujjighra": ['ap90', 'mw'],
    "ujjighrant": ['bhs'],
    "ujjihāna": ['mw'],
    "ujjihānajīvita": ['cae', 'mw'],
    "ujjihānā": ['mw'],
    "ujjihīrṣu": ['mw'],
    "ujjihīrṣā": ['mw'],
    "ujjitapara": ['bhs'],
    "ujjiti": ['cae', 'ddsa', 'mw'],
    "ujjitiḥ": ['ap90'],
    "ujju": ['bhs', 'cped'],
    "ujjuka": ['bhs', 'cped'],
    "ujjval": ['ap90', 'mw'],
    "ujjvala": ['ap90', 'cae', 'ddsa', 'mw'],
    "ujjvalabhāṣya": ['mw'],
    "ujjvaladatta": ['mw'],
    "ujjvalana": ['mw'],
    "ujjvalanarasiṃha": ['mw'],
    "ujjvalanaṃ": ['ap90'],
    "ujjvalanīlamaṇi": ['mw'],
    "ujjvalarasakaṇā": ['mw'],
    "ujjvalatva": ['mw'],
    "ujjvalatā": ['mw'],
    "ujjvalita": ['ap90', 'mw'],
    "ujjvalitatva": ['mw'],
    "ujjvalā": ['mw'],
    "ujjvālana": ['mw'],
    "ujjya": ['ap90', 'cae', 'mw'],
    "ujjāgara": ['ddsa', 'mw'],
    "ujjāgṛ": ['mw'],
    "ujjāluka": ['mw'],
    "ujjānaka": ['mw'],
    "ujjānakaḥ": ['ap90'],
    "ujjāsana": ['mw'],
    "ujjāsanaṃ": ['ap90'],
    "ujjīv": ['ap90', 'mw'],
    "ujjīvanaṃ": ['ap90'],
    "ujjīvin": ['ap90', 'ddsa', 'mw'],
    "ujjīvitamadālasa": ['mw'],
    "ujjūṭaḍimba": ['mw'],
    "ujjūṭita": ['mw'],
    "ujjṛmbh": ['mw'],
    "ujjṛmbha": ['cae', 'ddsa', 'mw'],
    "ujjṛmbhaṇa": ['cae', 'mw'],
    "ujjṛmbhaṇā": ['mw'],
    "ujjṛmbhita": ['cae', 'mw'],
    "ujjṛṃbh": ['ap90'],
    "ujjṛṃbha": ['ap90'],
    "ujjṛṃbhita": ['ap90'],
    "ujjṛṃbhā": ['ap90'],
    "uju": ['cped'],
    "ujuka": ['cped'],
    "ujuvipaccanīkavāda": ['cped'],
    "ujuṁ": ['cped'],
    "ujñaka": ['bhs'],
    "uka": ['ddsa', 'mw'],
    "ukanāha": ['mw'],
    "ukara": ['bhs'],
    "ukaṇa": ['mw'],
    "ukh": ['ap90', 'mw'],
    "ukha": ['cae', 'ddsa', 'gra', 'mw'],
    "ukhacchid": ['cae', 'mw'],
    "ukhachid": ['gra'],
    "ukhala": ['mw'],
    "ukharvala": ['mw'],
    "ukharvalaḥ": ['ap90'],
    "ukhaḍa": ['mw'],
    "ukhaḥ": ['ap90'],
    "ukhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ukhā": ['gra', 'mw'],
    "ukhāsaṃbharaṇa": ['mw'],
    "ukirati": ['bhs'],
    "ukka": ['cped'],
    "ukkala": ['bhs'],
    "ukkalā": ['cped'],
    "ukkamma": ['cped'],
    "ukkantitvā": ['cped'],
    "ukkapiṇḍaka": ['cped'],
    "ukkarikā": ['bhs'],
    "ukkaḍḍhati": ['cped'],
    "ukkaṁsati": ['cped'],
    "ukkaṁsavakaṁsa": ['cped'],
    "ukkaṁsayati": ['cped'],
    "ukkaṁseti": ['cped'],
    "ukkaṇḍaka": ['cped'],
    "ukkaṇṇaka": ['cped'],
    "ukkaṇṭaka": ['cped'],
    "ukkaṇṭhana": ['cped'],
    "ukkaṇṭhati": ['cped'],
    "ukkaṇṭhita": ['cped'],
    "ukkaṭṭati": ['bhs'],
    "ukkaṭṭha": ['cped'],
    "ukkaṭṭhita": ['cped'],
    "ukkhalikā": ['cped'],
    "ukkhaliparimajjana": ['cped'],
    "ukkhepa": ['cped'],
    "ukkhepaka": ['cped'],
    "ukkhepana": ['cped'],
    "ukkhepaniya": ['cped'],
    "ukkhepaniyakamma": ['cped'],
    "ukkhepaniyakammakata": ['cped'],
    "ukkheṭita": ['cped'],
    "ukkhipati": ['cped'],
    "ukkhipi": ['cped'],
    "ukkhipitabba": ['cped'],
    "ukkhipitvā": ['cped'],
    "ukkhipiyamāna": ['cped'],
    "ukkhipiyati": ['cped'],
    "ukkhipiyiṁsu": ['cped'],
    "ukkhipiyyati": ['cped'],
    "ukkhipiṁsu": ['cped'],
    "ukkhitta": ['cped'],
    "ukkhitta-ojjagghikā": ['cped'],
    "ukkhittaka": ['cped'],
    "ukkhittapaligha": ['cped'],
    "ukkhittasika": ['cped'],
    "ukkhā": ['cped'],
    "ukkhāsata": ['cped'],
    "ukkiratiparikha": ['cped'],
    "ukkoṭa": ['cped'],
    "ukkoṭana": ['cped'],
    "ukkoṭanaka": ['cped'],
    "ukkoṭanavañcananikatisāciyoga": ['cped'],
    "ukkoṭenta": ['cped'],
    "ukkoṭesuṁ": ['cped'],
    "ukkoṭeti": ['cped'],
    "ukkoṭitita": ['cped'],
    "ukkujitabba": ['cped'],
    "ukkujja": ['cped'],
    "ukkujjanā": ['cped'],
    "ukkujjati": ['cped'],
    "ukkujjavakujja": ['cped'],
    "ukkujjeti": ['cped'],
    "ukkujjita": ['cped'],
    "ukkujjitvā": ['cped'],
    "ukkuṭika": ['cped'],
    "ukkuṭikappadhāna": ['cped'],
    "ukkuṭikaṁ": ['cped'],
    "ukkuṭikā": ['cped'],
    "ukkuṭṭhi": ['cped'],
    "ukkā": ['cped'],
    "ukkācita": ['cped'],
    "ukkācitavinīta": ['cped'],
    "ukkādhāra": ['cped'],
    "ukkāmukha": ['cped'],
    "ukkāpata": ['cped'],
    "ukkārika": ['bhs'],
    "ukkāsana": ['bhs'],
    "ukkāsati": ['bhs', 'cped'],
    "ukkāsi": ['cped'],
    "ukkāsikā": ['cped'],
    "ukkāsita": ['bhs'],
    "ukkāsitabba": ['cped'],
    "ukkāsitasadda": ['cped'],
    "ukkāsitvā": ['cped'],
    "ukkūlavikūla": ['cped'],
    "uklāpa": ['cped'],
    "ukramati": ['bhs'],
    "ukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "uktabhāva": ['mw'],
    "uktamuṣṭivat": ['bhs'],
    "uktamātra": ['cae', 'mw'],
    "uktanirvāha": ['mw'],
    "uktapratyukta": ['cae', 'mw'],
    "uktapuṃska": ['mw'],
    "uktapūrva": ['cae', 'mw'],
    "uktarṣi": ['mw'],
    "uktatva": ['mw'],
    "uktavarjam": ['mw'],
    "uktavat": ['mw'],
    "uktavākya": ['cae', 'mw'],
    "uktha": ['cae', 'ddsa', 'gra', 'mw'],
    "ukthaarka": ['gra'],
    "ukthabhṛt": ['gra', 'mw'],
    "ukthadoha": ['mw'],
    "ukthamukha": ['mw'],
    "ukthapattra": ['mw'],
    "ukthapātra": ['mw'],
    "ukthasaṃpad": ['mw'],
    "ukthavardhana": ['gra', 'mw'],
    "ukthavat": ['mw'],
    "ukthavid": ['mw'],
    "ukthavidha": ['mw'],
    "ukthavāhas": ['gra', 'mw'],
    "ukthavīrya": ['mw'],
    "ukthaśas": ['gra', 'mw'],
    "ukthaśasa": ['mw'],
    "ukthaśaṃsin": ['gra', 'mw'],
    "ukthaśuṣma": ['gra', 'mw'],
    "ukthaśāstra": ['mw'],
    "ukthaṃ": ['ap90'],
    "ukthaṃvāc": ['mw'],
    "ukthia": ['gra'],
    "ukthin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ukthya": ['ap90', 'cae', 'gra', 'mw'],
    "ukthyapātra": ['mw'],
    "ukthyasthālī": ['mw'],
    "ukthā": ['mw'],
    "ukthādi": ['mw'],
    "ukthāmada": ['mw'],
    "ukthārka": ['gra', 'mw'],
    "ukthāvī": ['mw'],
    "ukthāyu": ['mw'],
    "ukthāśastra": ['mw'],
    "ukti": ['cae', 'ddsa', 'gra', 'mw'],
    "uktipoṣa": ['mw'],
    "uktipratyuktikā": ['mw'],
    "uktiḥ": ['ap90'],
    "uktopaniṣatka": ['mw'],
    "uktopasaṃhāra": ['mw'],
    "uktvā": ['ddsa', 'mw'],
    "uktānukta": ['mw'],
    "uktānuśāsana": ['mw'],
    "uktārtha": ['mw'],
    "ukuṇa": ['mw'],
    "ukuṇaḥ": ['ap90'],
    "ukānahaḥ": ['ap90'],
    "ukāra": ['cae', 'ddsa', 'mw'],
    "ukāraḥ": ['ap90'],
    "ukṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ukṣa": ['ap90', 'bhs', 'mw'],
    "ukṣan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ukṣasena": ['mw'],
    "ukṣatara": ['mw'],
    "ukṣavaśa": ['mw'],
    "ukṣavehat": ['mw'],
    "ukṣaṇa": ['cae', 'ddsa', 'mw'],
    "ukṣaṇaṃ": ['ap90'],
    "ukṣaṇiāyana": ['gra'],
    "ukṣaṇy": ['cae', 'gra'],
    "ukṣaṇya": ['ddsa', 'mw'],
    "ukṣaṇyati": ['ap90'],
    "ukṣaṇyu": ['ap90', 'ddsa', 'gra', 'mw'],
    "ukṣaṇyāyana": ['gra', 'mw'],
    "ukṣita": ['ap90', 'mw'],
    "ukṣāla": ['ap90'],
    "ukṣānna": ['gra', 'mw'],
    "ukṣāṇa": ['mw'],
    "ukṣṇorandhra": ['mw'],
    "ul": ['ap90', 'mw'],
    "ula": ['cae', 'mw'],
    "ulabha": ['mw'],
    "ulana": ['bhs'],
    "ulanda": ['mw'],
    "ulandaka": ['mw'],
    "ulapa": ['cae', 'gra', 'mw'],
    "ulaparāji": ['mw'],
    "ulaparājikā": ['mw'],
    "ulaparājī": ['mw'],
    "ulapaḥ": ['ap90'],
    "ulapin": ['mw'],
    "ulapya": ['ap90', 'mw'],
    "ulapā": ['mw'],
    "ulaḍ": ['mw'],
    "ulaḥ": ['ap90'],
    "ulba": ['cae', 'ddsa', 'gra', 'mw'],
    "ulbaṃ": ['ap90'],
    "ulbaṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ulbaṇatāpa": ['mw'],
    "ulbaṇiṣṇu": ['mw'],
    "ulbaṇā": ['mw'],
    "ulbya": ['mw'],
    "ulbyaṃ": ['ap90'],
    "ulinda": ['mw'],
    "uliṃdaḥ": ['ap90'],
    "ulka": ['mw'],
    "ulkin": ['bhs'],
    "ulkuṣyanta": ['mw'],
    "ulkuṣī": ['ap90', 'mw'],
    "ulkuṣīmat": ['mw'],
    "ulkā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ulkācakra": ['mw'],
    "ulkādhārin": ['bhs', 'mw'],
    "ulkājihva": ['mw'],
    "ulkālakṣaṇa": ['mw'],
    "ulkāmukha": ['bhs', 'cae', 'mw'],
    "ulkāmukhī": ['bhs', 'mw'],
    "ulkāmālin": ['mw'],
    "ulkānavamī": ['mw'],
    "ulkānavamīvrata": ['mw'],
    "ulkānirhata": ['mw'],
    "ulkāpāta": ['mw'],
    "ulla": ['bhs', 'mw'],
    "ullagna": ['mw'],
    "ullaka": ['mw'],
    "ullakasana": ['mw'],
    "ullakasanaṃ": ['ap90'],
    "ullal": ['mw'],
    "ullala": ['ap90', 'mw'],
    "ullalana": ['ddsa', 'mw'],
    "ullalat": ['ap90'],
    "ullalayati": ['ap90'],
    "ullalita": ['ap90'],
    "ullamb": ['mw'],
    "ullambin": ['mw'],
    "ullambita": ['mw'],
    "ullamphana": ['mw'],
    "ullap": ['ap90', 'mw'],
    "ullapana": ['cped'],
    "ullapanta": ['cped'],
    "ullapati": ['bhs', 'cped'],
    "ullapitabba": ['cped'],
    "ullapitvā": ['cped'],
    "ullapiyamāna": ['cped'],
    "ullas": ['ap90', 'mw'],
    "ullasa": ['ap90', 'mw'],
    "ullasanaṃ": ['ap90'],
    "ullasat": ['mw'],
    "ullasatphala": ['mw'],
    "ullasatā": ['mw'],
    "ullasita": ['ap90', 'cae', 'ddsa', 'mw'],
    "ullaṃbita": ['ap90'],
    "ullaṃgh": ['ap90'],
    "ullaṃghanaṃ": ['ap90'],
    "ullaṃghita": ['ap90'],
    "ullaṅgh": ['mw'],
    "ullaṅghana": ['cae', 'ddsa', 'mw'],
    "ullaṅghanā": ['cped'],
    "ullaṅghanīya": ['cae', 'mw'],
    "ullaṅghayati": ['cped'],
    "ullaṅgheti": ['cped'],
    "ullaṅghikā": ['bhs'],
    "ullaṅghita": ['mw'],
    "ullaṅghitaśāsana": ['mw'],
    "ullaṅghitādhvan": ['mw'],
    "ullaṅghya": ['cae', 'mw'],
    "ullekha": ['cae', 'ddsa', 'mw'],
    "ullekhana": ['cae', 'mw'],
    "ullekhanaṃ": ['ap90'],
    "ullekhanīya": ['mw'],
    "ullekhaḥ": ['ap90'],
    "ullekhin": ['ap90', 'mw'],
    "ullekhya": ['cae', 'mw'],
    "ullekhā": ['mw'],
    "ullih": ['mw'],
    "ullikh": ['ap90', 'mw'],
    "ullikhana": ['mw'],
    "ullikhi": ['cped'],
    "ullikhita": ['ap90', 'cped', 'ddsa', 'mw'],
    "ullikhāpeti": ['cped'],
    "ullipta": ['bhs'],
    "ullitavalitta": ['cped'],
    "ullitavalittaka": ['cped'],
    "ullitta": ['cped'],
    "ulliṃgita": ['ap90'],
    "ulliṅganāṣṭaka": ['mw'],
    "ulliṅgaya": ['ddsa', 'mw'],
    "ulliṅgita": ['mw'],
    "ulloca": ['cae', 'mw'],
    "ullocaka": ['bhs'],
    "ullocaḥ": ['ap90'],
    "ulloka": ['cped'],
    "ullokanaka": ['bhs'],
    "ullokanīya": ['bhs'],
    "ullokaya": ['cped'],
    "ullokayat": ['cped'],
    "ullokayati": ['bhs', 'cped'],
    "ullokenta": ['cped'],
    "ullokesi": ['cped'],
    "ulloketabba": ['cped'],
    "ulloketi": ['cped'],
    "ulloketvā": ['cped'],
    "ullola": ['ap90', 'cae', 'ddsa', 'mw'],
    "ullopam": ['mw'],
    "ullopana": ['bhs'],
    "ullopya": ['mw'],
    "ulloḍayati": ['bhs'],
    "ulluka": ['bhs'],
    "ullumpati": ['bhs', 'cped'],
    "ullup": ['mw'],
    "ullupta": ['mw'],
    "ulluñc": ['mw'],
    "ulluñcana": ['ddsa', 'mw'],
    "ulluñcita": ['cae', 'mw'],
    "ulluṃcanaṃ": ['ap90'],
    "ulluṃṭhanaṃ": ['ap90'],
    "ulluṃṭhita": ['ap90'],
    "ulluṇṭhā": ['mw'],
    "ulluṭh": ['mw'],
    "ullāgha": ['ap90', 'ddsa', 'mw'],
    "ullāghatā": ['mw'],
    "ullāghaya": ['ddsa', 'mw'],
    "ullāla": ['mw'],
    "ullāpa": ['ddsa', 'mw'],
    "ullāpaka": ['mw'],
    "ullāpana": ['bhs', 'mw'],
    "ullāpanaka": ['bhs'],
    "ullāpayati": ['bhs'],
    "ullāpaḥ": ['ap90'],
    "ullāpika": ['ap90', 'mw'],
    "ullāpin": ['ap90', 'bhs', 'mw'],
    "ullāpya": ['mw'],
    "ullāpyaṃ": ['ap90'],
    "ullāsa": ['cae', 'ddsa', 'mw'],
    "ullāsaka": ['mw'],
    "ullāsana": ['ap90', 'mw'],
    "ullāsanā": ['mw'],
    "ullāsaḥ": ['ap90'],
    "ullāsin": ['ap90', 'mw'],
    "ullāsita": ['ap90', 'mw'],
    "ullāḍayati": ['bhs'],
    "ullāṅgūla": ['mw'],
    "ullāṭṭayati": ['bhs'],
    "ullī": ['mw'],
    "ullīḍha": ['ap90', 'cae', 'mw'],
    "ullū": ['ap90', 'mw'],
    "ullūna": ['cae', 'mw'],
    "ulmuka": ['cae', 'ddsa', 'mw'],
    "ulmukamathya": ['mw'],
    "ulmukaḥ": ['ap90'],
    "ulmukyā": ['mw'],
    "uloka": ['gra', 'mw'],
    "ulokakṛt": ['gra'],
    "ulokakṛtnu": ['gra'],
    "uluka": ['bhs'],
    "ululi": ['mw'],
    "ululiḥ": ['ap90'],
    "ulumbā": ['mw'],
    "ulupa": ['ap90', 'mw'],
    "ulupin": ['ap90', 'mw'],
    "ulupya": ['mw'],
    "uluvillikā": ['bhs'],
    "ulva": ['ap90', 'ddsa', 'mw'],
    "ulvaṇa": ['ap90', 'mw'],
    "ulvaṇā": ['mw'],
    "ulāra": ['cped'],
    "ulūka": ['cae', 'ddsa', 'gra', 'mw'],
    "ulūkaceṭī": ['mw'],
    "ulūkajit": ['mw'],
    "ulūkapakṣa": ['mw'],
    "ulūkapakṣika": ['bhs'],
    "ulūkapuccha": ['mw'],
    "ulūkapāka": ['mw'],
    "ulūkayātu": ['gra', 'mw'],
    "ulūkaḥ": ['ap90'],
    "ulūkhala": ['cae', 'ddsa', 'gra', 'mw'],
    "ulūkhalabudhna": ['mw'],
    "ulūkhalaka": ['gra', 'mw'],
    "ulūkhalakaṃ": ['ap90'],
    "ulūkhalamusala": ['cae', 'mw'],
    "ulūkhalarūpatā": ['mw'],
    "ulūkhalasuta": ['gra', 'mw'],
    "ulūkhalaḥ": ['ap90'],
    "ulūkhalika": ['ap90', 'mw'],
    "ulūkhalin": ['mw'],
    "ulūkhalāṅghri": ['mw'],
    "ulūkāri": ['mw'],
    "ulūkī": ['mw'],
    "ulūli": ['mw'],
    "ulūlu": ['mw'],
    "ulūpa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ulūpin": ['mw'],
    "ulūpī": ['ap90', 'mw'],
    "ulūta": ['mw'],
    "ulūtaḥ": ['ap90'],
    "ulūtī": ['mw'],
    "ulūtīśa": ['mw'],
    "ulūṭa": ['mw'],
    "um": ['ap90', 'mw'],
    "uma": ['mw'],
    "umaka": ['bhs'],
    "umaḥ": ['ap90'],
    "umbara": ['mw'],
    "umbeka": ['mw'],
    "umbh": ['mw'],
    "umbhita": ['mw'],
    "umbikā": ['mw'],
    "umbura": ['mw'],
    "umbī": ['mw'],
    "umeśa": ['cae', 'mw'],
    "umeśvara": ['bhs'],
    "umlocā": ['mw'],
    "ummaddeti": ['cped'],
    "ummaddita": ['cped'],
    "ummaddāpenta": ['cped'],
    "ummaddāpesuṁ": ['cped'],
    "ummaddāpeti": ['cped'],
    "ummagga": ['cped'],
    "ummasanā": ['cped'],
    "ummasati": ['cped'],
    "ummatta": ['cped'],
    "ummattaka": ['cped'],
    "ummaṇga": ['cped'],
    "ummihati": ['cped'],
    "ummujjamāna": ['cped'],
    "ummujjamānaka": ['cped'],
    "ummujjana": ['cped'],
    "ummujjanimujjā": ['cped'],
    "ummujjanta": ['cped'],
    "ummujjati": ['cped'],
    "ummujjitvā": ['cped'],
    "ummuka": ['cped'],
    "ummukka": ['cped'],
    "ummāda": ['cped'],
    "ummādana": ['cped'],
    "ummādananta": ['cped'],
    "ummāpuppha": ['cped'],
    "ummāra": ['cped'],
    "ummī": ['cped'],
    "ummīlayati": ['cped'],
    "ummīleti": ['cped'],
    "ummūla": ['cped'],
    "ummūlaṁ karoti": ['cped'],
    "umya": ['mw'],
    "umyaṃ": ['ap90'],
    "umā": ['ap90', 'cae', 'ddsa', 'mw'],
    "umācaturthī": ['mw'],
    "umāguru": ['mw'],
    "umāgurunadī": ['mw'],
    "umākaṭa": ['mw'],
    "umākānta": ['mw'],
    "umāmaheśvaravrata": ['mw'],
    "umānātha": ['cae', 'mw'],
    "umāpariṇayana": ['mw'],
    "umāpati": ['cae', 'mw'],
    "umāpatidatta": ['mw'],
    "umāpatidhara": ['mw'],
    "umāpatisevin": ['mw'],
    "umāsahāya": ['mw'],
    "umāsaṃhitā": ['mw'],
    "umāsuta": ['mw'],
    "umāvana": ['mw'],
    "umāvṛṣāṅka": ['mw'],
    "und": ['ddsa', 'gra', 'mw'],
    "undana": ['mw'],
    "undanī": ['mw'],
    "undapura": ['mw'],
    "undara": ['cae'],
    "undaru": ['mw'],
    "undura": ['cae', 'cped', 'mw'],
    "undurakarṇikā": ['mw'],
    "undurakarṇī": ['mw'],
    "undurakhāyita": ['cped'],
    "undurakkhāyita": ['cped'],
    "unduru": ['cae', 'mw'],
    "undūra": ['cped'],
    "unmad": ['ap90', 'mw'],
    "unmada": ['ap90', 'bhs', 'ddsa', 'mw'],
    "unmadana": ['ap90', 'mw'],
    "unmadita": ['mw'],
    "unmadiṣṇu": ['ap90', 'mw'],
    "unmagna": ['cae'],
    "unmajj": ['ap90', 'mw'],
    "unmajjaka": ['ap90', 'mw'],
    "unmajjana": ['mw'],
    "unmajjanaṃ": ['ap90'],
    "unmakara": ['mw'],
    "unmana": ['mw'],
    "unmananā": ['bhs'],
    "unmanas": ['ap90', 'cae', 'ddsa', 'mw'],
    "unmanaska": ['cae', 'mw'],
    "unmanaskatā": ['mw'],
    "unmanaya": ['mw'],
    "unmand": ['mw'],
    "unmanth": ['mw'],
    "unmantha": ['mw'],
    "unmanthaka": ['mw'],
    "unmanthana": ['mw'],
    "unmanāya": ['ddsa', 'mw'],
    "unmanāyate": ['ap90'],
    "unmanīas": ['mw'],
    "unmanībhāva": ['mw'],
    "unmanībhū": ['mw'],
    "unmanīkṛ": ['ap90', 'mw'],
    "unmarda": ['cae', 'mw'],
    "unmardana": ['bhs', 'cae', 'ddsa', 'mw'],
    "unmardanaṃ": ['ap90'],
    "unmardita": ['mw'],
    "unmasj": ['ap90'],
    "unmath": ['ap90', 'mw'],
    "unmathana": ['ap90', 'ddsa', 'mw'],
    "unmathita": ['mw'],
    "unmathya": ['cae', 'mw'],
    "unmathāy": ['mw'],
    "unmatta": ['ap90', 'cae', 'ddsa', 'mw'],
    "unmattabhairava": ['mw'],
    "unmattabhairavatantra": ['mw'],
    "unmattabhairavī": ['mw'],
    "unmattacitta": ['mw'],
    "unmattadarśana": ['mw'],
    "unmattagaṅga": ['mw'],
    "unmattagaṅgam": ['mw'],
    "unmattaka": ['ap90', 'mw'],
    "unmattakīrti": ['mw'],
    "unmattaliṅgin": ['mw'],
    "unmattapralapita": ['mw'],
    "unmattarāghava": ['mw'],
    "unmattarūpa": ['mw'],
    "unmattatara": ['mw'],
    "unmattatva": ['mw'],
    "unmattatā": ['mw'],
    "unmattavat": ['mw'],
    "unmattaveṣa": ['mw'],
    "unmatti": ['bhs'],
    "unmattāvanti": ['mw'],
    "unmattībhūta": ['cae'],
    "unmayūkha": ['ap90', 'ddsa', 'mw'],
    "unmaṃthaka": ['ap90'],
    "unmaṃthanaṃ": ['ap90'],
    "unmaṃthaḥ": ['ap90'],
    "unmaṇi": ['mw'],
    "unmaṇḍala": ['mw'],
    "unmedā": ['ap90', 'mw'],
    "unmeya": ['ap90', 'mw'],
    "unmeṣa": ['cae', 'ddsa', 'mw'],
    "unmeṣaḥ": ['ap90'],
    "unmeṣaṇa": ['mw'],
    "unmeṣin": ['ap90', 'cae', 'mw'],
    "unmi": ['mw'],
    "unmijitakā": ['bhs'],
    "unmita": ['ap90', 'mw'],
    "unmiti": ['mw'],
    "unmitiḥ": ['ap90'],
    "unmiñja": ['bhs', 'mw'],
    "unmiñjita": ['bhs'],
    "unmiśra": ['ap90', 'cae', 'mw'],
    "unmiṣ": ['ap90', 'mw'],
    "unmiṣa": ['ap90', 'mw'],
    "unmiṣita": ['ap90', 'cae', 'ddsa', 'mw'],
    "unmocana": ['ddsa', 'mw'],
    "unmocanapramocana": ['mw'],
    "unmocanaṃ": ['ap90'],
    "unmocanīya": ['mw'],
    "unmokṣā": ['mw'],
    "unmoṭana": ['ddsa'],
    "unmuc": ['ap90', 'mw'],
    "unmuca": ['mw'],
    "unmucu": ['mw'],
    "unmud": ['mw'],
    "unmudita": ['mw'],
    "unmudra": ['ap90', 'mw'],
    "unmugdha": ['mw'],
    "unmuh": ['mw'],
    "unmukha": ['ap90', 'cae', 'ddsa', 'mw'],
    "unmukhadarśana": ['mw'],
    "unmukhara": ['ap90', 'mw'],
    "unmukhatā": ['mw'],
    "unmukhīkaraṇa": ['mw'],
    "unmukhīkāra": ['mw'],
    "unmukta": ['ap90', 'cae', 'mw'],
    "unmukti": ['mw'],
    "unmukṣā": ['mw'],
    "unmurch": ['mw'],
    "unmuṣ": ['mw'],
    "unmuṣita": ['mw'],
    "unmā": ['ap90', 'mw'],
    "unmāda": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "unmādaka": ['mw'],
    "unmādakaḥ": ['ap90'],
    "unmādana": ['ap90', 'mw'],
    "unmādavant": ['cae'],
    "unmādavat": ['mw'],
    "unmādayantī": ['bhs'],
    "unmādayitṛ": ['cae', 'mw'],
    "unmādayitṛka": ['ap90'],
    "unmādin": ['ap90', 'cae', 'mw'],
    "unmādinī": ['mw'],
    "unmāditā": ['mw'],
    "unmāduka": ['ap90', 'mw'],
    "unmāna": ['mw'],
    "unmānaṃ": ['ap90'],
    "unmārga": ['ap90', 'cae', 'ddsa', 'mw'],
    "unmārgagamana": ['mw'],
    "unmārgagata": ['mw'],
    "unmārgagāmin": ['cae', 'mw'],
    "unmārgajalavāhin": ['mw'],
    "unmārgavartin": ['cae', 'mw'],
    "unmārgavṛtti": ['mw'],
    "unmārgayāta": ['mw'],
    "unmārgin": ['ap90', 'mw'],
    "unmārjana": ['mw'],
    "unmārjanaṃ": ['ap90'],
    "unmārjita": ['mw'],
    "unmātha": ['ap90', 'ddsa', 'mw'],
    "unmāthin": ['ap90', 'mw'],
    "unmī": ['mw'],
    "unmīl": ['ap90', 'mw'],
    "unmīla": ['mw'],
    "unmīlana": ['cae', 'mw'],
    "unmīlaḥ": ['ap90'],
    "unmīlita": ['ap90', 'cae', 'mw'],
    "unmūl": ['ap90', 'cae', 'ddsa'],
    "unmūla": ['mw'],
    "unmūlana": ['cae', 'ddsa', 'mw'],
    "unmūlanaṃ": ['ap90'],
    "unmūlanīya": ['mw'],
    "unmūlita": ['mw'],
    "unmūrdhaka": ['bhs'],
    "unmūrdhan": ['ddsa'],
    "unmūḍha": ['bhs'],
    "unmūḍhi": ['bhs'],
    "unmṛd": ['mw'],
    "unmṛj": ['ap90', 'mw'],
    "unmṛjāvamṛjā": ['ap90', 'mw'],
    "unmṛś": ['mw'],
    "unmṛśya": ['mw'],
    "unmṛṣṭa": ['ap90', 'cae', 'mw'],
    "unna": ['ap90', 'ddsa', 'mw'],
    "unnabh": ['mw'],
    "unnad": ['ap90', 'mw'],
    "unnaddha": ['ap90', 'cae', 'mw'],
    "unnah": ['ap90', 'mw'],
    "unnahana": ['bhs', 'mw'],
    "unnala": ['cped'],
    "unnam": ['ap90', 'mw'],
    "unnamana": ['bhs', 'ddsa', 'mw'],
    "unnamanaṃ": ['ap90'],
    "unnamati": ['cped'],
    "unnamayya": ['mw'],
    "unnameti": ['cped'],
    "unnamita": ['ap90', 'mw'],
    "unnamra": ['ap90', 'ddsa', 'mw'],
    "unnamratā": ['mw'],
    "unnamya": ['mw'],
    "unnasa": ['ap90', 'mw'],
    "unnata": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "unnatacaraṇa": ['mw'],
    "unnatakokilā": ['mw'],
    "unnatakāla": ['mw'],
    "unnatanābhi": ['mw'],
    "unnatatva": ['mw'],
    "unnatatvaṃ": ['ap90'],
    "unnatavanata": ['cped'],
    "unnataśiras": ['mw'],
    "unnateccha": ['mw'],
    "unnati": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "unnatimat": ['ap90', 'mw'],
    "unnatiḥ": ['ap90'],
    "unnatoṣṇīṣa": ['bhs'],
    "unnatunnata": ['cped'],
    "unnatunnata-onata": ['cped'],
    "unnatānata": ['mw'],
    "unnatīśa": ['mw'],
    "unnaya": ['ap90', 'mw'],
    "unnayana": ['ap90', 'cae', 'ddsa', 'mw'],
    "unnayanapaṅkti": ['mw'],
    "unnayati": ['bhs'],
    "unnayaḥ": ['ap90'],
    "unnaś": ['mw'],
    "unnaḍa": ['bhs'],
    "unnaḷa": ['cped'],
    "unnaṭ": ['mw'],
    "unnetavya": ['mw'],
    "unnetra": ['mw'],
    "unnetraṃ": ['ap90'],
    "unnetṛ": ['ap90', 'mw'],
    "unneya": ['mw'],
    "unnidhā": ['mw'],
    "unnidra": ['ap90', 'cae', 'ddsa', 'mw'],
    "unnidraka": ['mw'],
    "unnidratā": ['mw'],
    "unnidraya": ['mw'],
    "unnodana": ['bhs'],
    "unnābha": ['ap90', 'ddsa', 'mw'],
    "unnāda": ['mw'],
    "unnādaḥ": ['ap90'],
    "unnādi": ['cped'],
    "unnādin": ['cped'],
    "unnāha": ['cae', 'mw'],
    "unnāhaḥ": ['ap90'],
    "unnāla": ['ap90', 'cae', 'ddsa', 'mw'],
    "unnāma": ['bhs', 'mw'],
    "unnāmaninnāmi": ['cped'],
    "unnāmaninnāmin": ['cped'],
    "unnāmaḥ": ['ap90'],
    "unnāmininnāmi": ['cped'],
    "unnāmininnāmin": ['cped'],
    "unnāmita": ['mw'],
    "unnāmya": ['mw'],
    "unnāya": ['mw'],
    "unnāyaka": ['ap90'],
    "unnī": ['ap90', 'mw'],
    "unnīpam": ['mw'],
    "unnīta": ['mw'],
    "unnītaśikha": ['mw'],
    "unnītaśuṣma": ['mw'],
    "unnītin": ['mw'],
    "unnīya": ['mw'],
    "unnīyam": ['mw'],
    "upa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "upabaddha": ['mw'],
    "upabahu": ['ap90', 'mw'],
    "upabandh": ['mw'],
    "upabandha": ['ddsa', 'mw'],
    "upabarha": ['cae', 'mw'],
    "upabarhaḥ": ['ap90'],
    "upabarhaṇa": ['gra', 'mw'],
    "upabarhaṇī": ['gra', 'mw'],
    "upabarhiṇa": ['mw'],
    "upabaṃdhaḥ": ['ap90'],
    "upabbajati": ['cped'],
    "upabda": ['cae', 'ddsa', 'gra', 'mw'],
    "upabdaḥ": ['ap90'],
    "upabdi": ['cae', 'gra', 'mw'],
    "upabdimat": ['mw'],
    "upabhaimī": ['mw'],
    "upabhaj": ['mw'],
    "upabhakṣ": ['mw'],
    "upabhakṣita": ['mw'],
    "upabhaṃgaḥ": ['ap90'],
    "upabhaṅga": ['cae', 'ddsa', 'mw'],
    "upabheda": ['mw'],
    "upabhoga": ['cae', 'ddsa', 'mw'],
    "upabhogakṣama": ['mw'],
    "upabhogaparibhoga": ['cped'],
    "upabhogaḥ": ['ap90'],
    "upabhogin": ['ap90', 'cae', 'mw'],
    "upabhogya": ['ap90', 'cae', 'mw'],
    "upabhogyatva": ['mw'],
    "upabhojin": ['mw'],
    "upabhojya": ['mw'],
    "upabhoktavya": ['ddsa'],
    "upabhoktṛ": ['ap90', 'mw'],
    "upabhram": ['mw'],
    "upabhuj": ['ap90', 'mw'],
    "upabhukta": ['mw'],
    "upabhuktadhana": ['ddsa', 'mw'],
    "upabhukti": ['mw'],
    "upabhuktiḥ": ['ap90'],
    "upabhāṣā": ['ap90', 'ddsa', 'mw'],
    "upabhū": ['mw'],
    "upabhūṣ": ['mw'],
    "upabhūṣaṇa": ['mw'],
    "upabhūṣaṇaṃ": ['ap90'],
    "upabhṛ": ['mw'],
    "upabhṛt": ['ap90', 'ddsa', 'mw'],
    "upabhṛta": ['mw'],
    "upabhṛtopaśama": ['mw'],
    "upabila": ['mw'],
    "upabilam": ['mw'],
    "upabindu": ['bhs', 'mw'],
    "upablaya": ['mw'],
    "upabrū": ['mw'],
    "upabāhu": ['mw'],
    "upabāhuḥ": ['ap90'],
    "upabṛh": ['mw'],
    "upabṛṃhaṇa": ['mw'],
    "upabṛṃhaṇaṃ": ['ap90'],
    "upabṛṃhin": ['ap90', 'ddsa', 'mw'],
    "upabṛṃhita": ['ap90', 'cae'],
    "upaca": ['mw'],
    "upacakra": ['mw'],
    "upacakraḥ": ['ap90'],
    "upacakṣus": ['ap90', 'mw'],
    "upacar": ['ap90', 'mw'],
    "upacara": ['cae', 'ddsa', 'mw'],
    "upacaradhyai": ['mw'],
    "upacaraka": ['mw'],
    "upacarati": ['cped'],
    "upacaraḥ": ['ap90'],
    "upacaraṇa": ['bhs', 'mw'],
    "upacaraṇīya": ['mw'],
    "upacarita": ['mw'],
    "upacaritavya": ['cae', 'mw'],
    "upacaritavyā": ['mw'],
    "upacarma": ['ap90', 'mw'],
    "upacarya": ['ap90', 'mw'],
    "upacaryā": ['cae', 'mw'],
    "upacatura": ['mw'],
    "upacaturam": ['mw'],
    "upacaya": ['cae', 'cped', 'ddsa', 'mw'],
    "upacayaḥ": ['ap90'],
    "upacayāpacaya": ['mw'],
    "upacayāvaha": ['mw'],
    "upaccagaṁ": ['cped'],
    "upaccaguṁ": ['cped'],
    "upaccagā": ['cped'],
    "upaccagū": ['cped'],
    "upacchad": ['mw'],
    "upacchadaḥ": ['ap90'],
    "upacchal": ['mw'],
    "upacchand": ['mw'],
    "upacchanda": ['mw'],
    "upacchandana": ['ddsa', 'mw'],
    "upacchandita": ['mw'],
    "upacchanna": ['cae', 'mw'],
    "upacchaṃd": ['ap90'],
    "upacchaṃdanaṃ": ['ap90'],
    "upaccheda": ['bhs'],
    "upacchedana": ['bhs'],
    "upacchijjati": ['cped'],
    "upacchinatti": ['bhs'],
    "upacchindati": ['cped'],
    "upacchinna": ['cped'],
    "upacchubhati": ['cped'],
    "upacchumbhati": ['cped'],
    "upacelā": ['bhs'],
    "upaceya": ['mw'],
    "upaceṣṭita": ['bhs'],
    "upaci": ['ap90', 'mw'],
    "upacikā": ['cped'],
    "upacikīrṣu": ['mw'],
    "upacinitvā": ['cped'],
    "upacināti": ['cped'],
    "upacit": ['mw'],
    "upacita": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "upacitabali": ['ddsa'],
    "upacitahanu": ['bhs'],
    "upacitarasa": ['mw'],
    "upacitaskandha": ['bhs'],
    "upaciti": ['mw'],
    "upacitiḥ": ['ap90'],
    "upacitra": ['bhs', 'mw'],
    "upacitraka": ['mw'],
    "upacitrā": ['ap90', 'mw'],
    "upacitībhū": ['mw'],
    "upacyava": ['gra', 'mw'],
    "upacyavaḥ": ['ap90'],
    "upacāku": ['mw'],
    "upacāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "upacāracchala": ['mw'],
    "upacāraka": ['cae', 'cped', 'mw'],
    "upacārakaraṇa": ['mw'],
    "upacārakarman": ['mw'],
    "upacārakriyā": ['mw'],
    "upacārapada": ['mw'],
    "upacārapara": ['mw'],
    "upacāraparibhraṣṭa": ['mw'],
    "upacāraparīta": ['mw'],
    "upacāravat": ['mw'],
    "upacāraḥ": ['ap90'],
    "upacārika": ['mw'],
    "upacārin": ['ap90', 'ddsa', 'mw'],
    "upacāru": ['bhs', 'mw'],
    "upacārumat": ['mw'],
    "upacārya": ['ap90', 'mw'],
    "upacāryā": ['mw'],
    "upacārāt": ['mw'],
    "upacāyaka": ['bhs'],
    "upacāyin": ['ap90', 'mw'],
    "upacāyya": ['mw'],
    "upacāyyaka": ['mw'],
    "upacāyyaḥ": ['ap90'],
    "upacīkā": ['mw'],
    "upacīrṇa": ['mw'],
    "upacīyate": ['cped'],
    "upacīyati": ['cped'],
    "upacīyyati": ['cped'],
    "upacūlana": ['mw'],
    "upacūlanaṃ": ['ap90'],
    "upacūḍana": ['ddsa', 'mw'],
    "upacṛt": ['mw'],
    "upadadhi": ['mw'],
    "upadadya": ['mw'],
    "upadagdha": ['mw'],
    "upadah": ['mw'],
    "upadahanta": ['cped'],
    "upadahati": ['cped'],
    "upadahita": ['cped'],
    "upadahitabba": ['cped'],
    "upadahiṁsu": ['cped'],
    "upadahātabba": ['cped'],
    "upadambh": ['mw'],
    "upadarśaka": ['ap90', 'mw'],
    "upadarśana": ['mw'],
    "upadarśanaṃ": ['ap90'],
    "upadarśayati": ['bhs'],
    "upadarśita": ['mw'],
    "upadas": ['ap90', 'mw'],
    "upadasta": ['mw'],
    "upadaśa": ['ap90', 'mw'],
    "upadaśya": ['mw'],
    "upadaṁsayati": ['cped'],
    "upadaṁsayi": ['cped'],
    "upadaṁseta": ['cped'],
    "upadaṁsetar": ['cped'],
    "upadaṁseti": ['cped'],
    "upadaṁsetuṁ": ['cped'],
    "upadaṁsita": ['cped'],
    "upadaṁsitar": ['cped'],
    "upadaṃś": ['ap90', 'mw'],
    "upadaṃśa": ['mw'],
    "upadaṃśaka": ['mw'],
    "upadaṃśam": ['mw'],
    "upadaṃśaḥ": ['ap90'],
    "upadaṃśin": ['ap90', 'mw'],
    "upaddava": ['cped'],
    "upadduta": ['cped'],
    "upaddūta": ['cped'],
    "upadeha": ['mw'],
    "upadehavat": ['mw'],
    "upadehaḥ": ['ap90'],
    "upadehikā": ['mw'],
    "upadeva": ['mw'],
    "upadevatā": ['mw'],
    "upadevaḥ": ['ap90'],
    "upadeśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "upadeśaka": ['ap90', 'mw'],
    "upadeśakarṇikā": ['mw'],
    "upadeśamālā": ['mw'],
    "upadeśana": ['cae', 'mw'],
    "upadeśanavat": ['mw'],
    "upadeśanaṃ": ['ap90'],
    "upadeśanā": ['mw'],
    "upadeśapañcaka": ['mw'],
    "upadeśarasāyana": ['mw'],
    "upadeśaratnamālā": ['mw'],
    "upadeśasāhasrī": ['mw'],
    "upadeśatā": ['ap90', 'mw'],
    "upadeśaḥ": ['ap90'],
    "upadeśeti": ['bhs'],
    "upadeśin": ['ap90', 'cae', 'mw'],
    "upadeśya": ['mw'],
    "upadeśāmṛta": ['mw'],
    "upadeśārthavākya": ['mw'],
    "upadeṣṭavya": ['ddsa', 'mw'],
    "upadeṣṭṛ": ['ap90', 'mw'],
    "upadeṣṭṛtva": ['mw'],
    "upadhamana": ['mw'],
    "upadharma": ['bhs', 'cae', 'ddsa', 'mw'],
    "upadharmaḥ": ['ap90'],
    "upadhe": ['mw'],
    "upadhenu": ['ddsa', 'mw'],
    "upadheti": ['cped'],
    "upadheya": ['mw'],
    "upadhi": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "upadhika": ['bhs', 'mw'],
    "upadhikaḥ": ['ap90'],
    "upadhivāra": ['bhs'],
    "upadhivāraka": ['bhs'],
    "upadhiḥ": ['ap90'],
    "upadhmā": ['ap90', 'mw'],
    "upadhmāna": ['mw'],
    "upadhmānaḥ": ['ap90'],
    "upadhmānin": ['ap90'],
    "upadhmānīya": ['cae', 'mw'],
    "upadhmānīyaḥ": ['ap90'],
    "upadhvasta": ['ap90', 'cae', 'mw'],
    "upadhvaṃs": ['mw'],
    "upadhyai": ['mw'],
    "upadhyāta": ['mw'],
    "upadhyāyati": ['bhs'],
    "upadhā": ['ap90', 'cae', 'ddsa', 'mw'],
    "upadhābhṛta": ['mw'],
    "upadhālopa": ['mw'],
    "upadhālopin": ['mw'],
    "upadhāna": ['ap90', 'bhs', 'cae', 'mw'],
    "upadhānaka": ['mw'],
    "upadhānaliṅga": ['mw'],
    "upadhānavidhi": ['mw'],
    "upadhānī": ['bhs', 'mw'],
    "upadhānīya": ['ap90', 'cae', 'mw'],
    "upadhārayati": ['cped'],
    "upadhāraṇa": ['cped', 'mw'],
    "upadhāraṇaṃ": ['ap90'],
    "upadhāreti": ['cped'],
    "upadhārita": ['cped'],
    "upadhārya": ['mw'],
    "upadhātu": ['mw'],
    "upadhātuḥ": ['ap90'],
    "upadhāv": ['ap90', 'mw'],
    "upadhāvana": ['mw'],
    "upadhāvanaḥ": ['ap90'],
    "upadhāvati": ['cped'],
    "upadhāvitvā": ['cped'],
    "upadhāya": ['cped', 'mw'],
    "upadhāyin": ['ap90', 'mw'],
    "upadhāśuci": ['mw'],
    "upadhūmitā": ['mw'],
    "upadhūpaya": ['mw'],
    "upadhūpita": ['ap90', 'mw'],
    "upadhūpitā": ['mw'],
    "upadhṛ": ['ap90', 'mw'],
    "upadhṛti": ['mw'],
    "upadhṛtiḥ": ['ap90'],
    "upadhṛṣ": ['mw'],
    "upadidikṣu": ['mw'],
    "upadidikṣā": ['mw'],
    "upadigdha": ['ap90', 'cae', 'mw'],
    "upadigdhatā": ['ddsa', 'mw'],
    "upadih": ['mw'],
    "upadisati": ['cped'],
    "upadissati": ['cped'],
    "upadiś": ['ap90', 'cae', 'ddsa', 'mw'],
    "upadiśa": ['mw'],
    "upadiśam": ['mw'],
    "upadiśya": ['ap90', 'mw'],
    "upadiśyati": ['bhs'],
    "upadiśā": ['cae', 'mw'],
    "upadiṣṭa": ['ap90', 'mw'],
    "upadoha": ['mw'],
    "upadohana": ['mw'],
    "upadohaḥ": ['ap90'],
    "upadrava": ['cae', 'ddsa', 'mw'],
    "upadravaḥ": ['ap90'],
    "upadravin": ['ap90', 'mw'],
    "upadraṣṭṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "upadraṣṭṛkā": ['mw'],
    "upadraṣṭṛmat": ['mw'],
    "upadraṣṭṛmati": ['mw'],
    "upadrotar": ['bhs'],
    "upadru": ['ap90', 'mw'],
    "upadruta": ['ap90', 'mw'],
    "upaduh": ['mw'],
    "upadukura": ['bhs'],
    "upadundubhi": ['bhs'],
    "upadussati": ['cped'],
    "upadussiṁ": ['cped'],
    "upaduṣ": ['mw'],
    "upadvāra": ['mw'],
    "upadvīpa": ['mw'],
    "upadvīpaḥ": ['ap90'],
    "upadā": ['ap90', 'cae', 'ddsa', 'mw'],
    "upadāna": ['mw'],
    "upadānaka": ['mw'],
    "upadānavī": ['ap90', 'mw'],
    "upadānaṃ": ['ap90'],
    "upadāsa": ['mw'],
    "upadāsuka": ['ap90', 'mw'],
    "upadātavya": ['mw'],
    "upadātṛ": ['ddsa', 'mw'],
    "upadī": ['ap90', 'mw'],
    "upadīka": ['mw'],
    "upadīkā": ['ap90'],
    "upadīkṛ": ['ap90'],
    "upadīkṛta": ['mw'],
    "upadīkṣ": ['mw'],
    "upadīkṣin": ['ap90', 'mw'],
    "upadīkṣya": ['mw'],
    "upadīp": ['mw'],
    "upadīpayitvā": ['mw'],
    "upadṛś": ['ap90', 'cae', 'gra', 'mw'],
    "upadṛṣad": ['mw'],
    "upadṛṣadam": ['mw'],
    "upadṛṣṭi": ['mw'],
    "upadṛṣṭiḥ": ['ap90'],
    "upaga": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "upagacchati": ['cped'],
    "upagacchi": ['cped'],
    "upagacchisati": ['cped'],
    "upagacchiṁ": ['cped'],
    "upagacchiṁsu": ['cped'],
    "upagacchu": ['cped'],
    "upagacchuṁ": ['cped'],
    "upagahana": ['mw'],
    "upagai": ['ap90', 'mw'],
    "upagam": ['ap90', 'mw'],
    "upagama": ['bhs', 'mw'],
    "upagamana": ['cped', 'mw'],
    "upagamaḥ": ['ap90'],
    "upagamiṁsu": ['cped'],
    "upagamma": ['cped'],
    "upagamya": ['mw'],
    "upagandhin": ['mw'],
    "upaganta": ['cped'],
    "upagantabba": ['cped'],
    "upagantar": ['cped'],
    "upagantuṁ": ['cped'],
    "upagantvā": ['cped'],
    "upagata": ['ap90', 'cae', 'cped', 'mw'],
    "upagataka": ['bhs'],
    "upagatavat": ['mw'],
    "upagati": ['cae', 'mw'],
    "upagatiḥ": ['ap90'],
    "upagatya": ['mw'],
    "upagañchi": ['cped'],
    "upagañchiṁ": ['cped'],
    "upagañchu": ['cped'],
    "upagañchuṁ": ['cped'],
    "upagaṃdhaḥ": ['ap90'],
    "upagaṃtṛ": ['ap90'],
    "upagaṇa": ['ap90', 'mw'],
    "upageya": ['mw'],
    "upaghaṭṭ": ['mw'],
    "upaghna": ['ddsa', 'mw'],
    "upaghnataru": ['mw'],
    "upaghnaḥ": ['ap90'],
    "upaghoṣaṇa": ['ddsa', 'mw'],
    "upaghoṣaṇaṃ": ['ap90'],
    "upaghrā": ['mw'],
    "upaghrāta": ['mw'],
    "upaghrāyam": ['mw'],
    "upaghuṣ": ['ap90', 'mw'],
    "upaghuṣṭa": ['ap90', 'mw'],
    "upaghāta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "upaghātaka": ['ap90', 'cae', 'mw'],
    "upaghātam": ['mw'],
    "upaghātaḥ": ['ap90'],
    "upaghāti": ['cped'],
    "upaghātika": ['bhs', 'cped'],
    "upaghātin": ['cae', 'mw'],
    "upaghāṭa": ['bhs'],
    "upagiram": ['mw'],
    "upagiri": ['ap90', 'ddsa', 'mw'],
    "upagohya": ['ap90', 'mw'],
    "upagrah": ['ap90', 'mw'],
    "upagraha": ['cae', 'ddsa', 'mw'],
    "upagrahaḥ": ['ap90'],
    "upagrahaṇa": ['cae', 'mw'],
    "upagrahaṇaṃ": ['ap90'],
    "upagranth": ['mw'],
    "upagrantha": ['mw'],
    "upagras": ['mw'],
    "upagraṃthaḥ": ['ap90'],
    "upagrāha": ['cae', 'mw'],
    "upagrāhaḥ": ['ap90'],
    "upagrāhya": ['ap90', 'mw'],
    "upagrāmam": ['ddsa', 'mw'],
    "upagu": ['ap90', 'mw'],
    "upagudha": ['mw'],
    "upaguh": ['ap90', 'mw'],
    "upaguhya": ['mw'],
    "upagup": ['mw'],
    "upagupta": ['ap90', 'bhs', 'mw'],
    "upaguptaka": ['bhs'],
    "upaguptavitta": ['mw'],
    "upaguru": ['mw'],
    "upaguruḥ": ['ap90'],
    "upaguṇṭhita": ['bhs'],
    "upagā": ['ap90', 'cped', 'mw'],
    "upagāh": ['mw'],
    "upagāmin": ['ap90', 'ddsa', 'mw'],
    "upagāna": ['cae', 'ddsa', 'mw'],
    "upagātṛ": ['ap90', 'mw'],
    "upagāyana": ['mw'],
    "upagīta": ['ap90', 'cae', 'mw'],
    "upagītha": ['mw'],
    "upagīti": ['cae', 'ddsa', 'mw'],
    "upagītiḥ": ['ap90'],
    "upagūhana": ['mw'],
    "upagūhanaṃ": ['ap90'],
    "upagūhya": ['mw'],
    "upagūḍha": ['ap90', 'cae', 'ddsa', 'mw'],
    "upagūḍhaka": ['bhs'],
    "upagūḍhavat": ['mw'],
    "upagṛhya": ['mw'],
    "upagṛhīta": ['mw'],
    "upagṛṇīte": ['bhs'],
    "upagṝ": ['mw'],
    "upahacca": ['cped'],
    "upahaccaparinibbāyi": ['cped'],
    "upahaccaparinibbāyin": ['cped'],
    "upahadana": ['mw'],
    "upahan": ['ap90', 'mw'],
    "upahanati": ['cped'],
    "upahantavya": ['mw'],
    "upahanti": ['cped'],
    "upahantvāna": ['cped'],
    "upahantṛ": ['mw'],
    "upaharati": ['cped'],
    "upaharaṇa": ['cae', 'ddsa', 'mw'],
    "upaharaṇaṃ": ['ap90'],
    "upaharaṇīya": ['mw'],
    "upahartavya": ['mw'],
    "upahartṛ": ['cae', 'mw'],
    "upahas": ['ap90', 'mw'],
    "upahasita": ['ap90', 'mw'],
    "upahasta": ['mw'],
    "upahastaya": ['mw'],
    "upahastikā": ['ap90', 'ddsa', 'mw'],
    "upahasvan": ['gra', 'mw'],
    "upahata": ['ap90', 'cped', 'mw'],
    "upahatadhī": ['mw'],
    "upahataka": ['ap90', 'mw'],
    "upahati": ['mw'],
    "upahatiḥ": ['ap90'],
    "upahatnu": ['ap90', 'cae', 'gra', 'mw'],
    "upahatta": ['cped'],
    "upahattar": ['cped'],
    "upahatya": ['bhs'],
    "upahatyā": ['ap90', 'mw'],
    "upahatātman": ['ddsa', 'mw'],
    "upahava": ['cae', 'mw'],
    "upahavaḥ": ['ap90'],
    "upahavya": ['mw'],
    "upahavyaḥ": ['ap90'],
    "upahaññati": ['cped'],
    "upahaṃtṛ": ['ap90'],
    "upahita": ['ap90', 'cae', 'ddsa', 'mw'],
    "upahiti": ['mw'],
    "upahiṁsati": ['cped'],
    "upahiṃs": ['mw'],
    "upahoma": ['ddsa', 'mw'],
    "upahomaḥ": ['ap90'],
    "upahu": ['mw'],
    "upahvara": ['cae', 'ddsa', 'gra', 'mw'],
    "upahvaraḥ": ['ap90'],
    "upahvartavya": ['mw'],
    "upahve": ['ap90', 'mw'],
    "upahvāna": ['mw'],
    "upahvānaṃ": ['ap90'],
    "upahvṛ": ['mw'],
    "upahā": ['mw'],
    "upahālaka": ['mw'],
    "upahālakaḥ": ['ap90'],
    "upahāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "upahāraka": ['cae', 'mw'],
    "upahārapaśu": ['mw'],
    "upahāratva": ['mw'],
    "upahāratā": ['mw'],
    "upahāravarman": ['mw'],
    "upahāraḥ": ['ap90'],
    "upahārika": ['bhs'],
    "upahārin": ['ap90', 'mw'],
    "upahārya": ['cae', 'mw'],
    "upahārīcikīrṣu": ['mw'],
    "upahārīkṛ": ['cae', 'mw'],
    "upahāsa": ['cae', 'ddsa', 'mw'],
    "upahāsagir": ['mw'],
    "upahāsaka": ['ap90', 'mw'],
    "upahāsanīyatā": ['cae', 'mw'],
    "upahāsaḥ": ['ap90'],
    "upahāsin": ['cae', 'mw'],
    "upahāsya": ['ap90', 'cae', 'mw'],
    "upahāsyatā": ['mw'],
    "upahāsāspada": ['mw'],
    "upahūta": ['cae', 'mw'],
    "upahūti": ['ddsa', 'mw'],
    "upahūtiḥ": ['ap90'],
    "upahūya": ['mw'],
    "upahṛ": ['ap90', 'mw'],
    "upahṛdaya": ['bhs'],
    "upahṛta": ['ap90', 'bhs', 'mw'],
    "upahṛtya": ['mw'],
    "upaidh": ['mw'],
    "upaiḍakīya": ['mw'],
    "upaja": ['ap90', 'cae', 'ddsa', 'mw'],
    "upajagatī": ['ap90', 'mw'],
    "upajalp": ['ap90', 'mw'],
    "upajalpanaṃ": ['ap90'],
    "upajalpin": ['ap90', 'ddsa', 'mw'],
    "upajalpita": ['mw'],
    "upajalā": ['mw'],
    "upajan": ['ap90', 'mw'],
    "upajana": ['mw'],
    "upajanam": ['mw'],
    "upajanana": ['mw'],
    "upajanayati": ['bhs'],
    "upajanaḥ": ['ap90'],
    "upajandhani": ['mw'],
    "upajap": ['ap90', 'mw'],
    "upajapta": ['mw'],
    "upajapya": ['ap90', 'ddsa', 'mw'],
    "upajaras": ['ap90'],
    "upajarasam": ['mw'],
    "upajenitvā": ['bhs'],
    "upaji": ['mw'],
    "upajigamiṣu": ['cae', 'ddsa', 'mw'],
    "upajighraṇa": ['mw'],
    "upajihvikā": ['gra', 'mw'],
    "upajihvā": ['ap90', 'cae', 'ddsa', 'mw'],
    "upajihīrṣā": ['mw'],
    "upajijñāsu": ['mw'],
    "upajijñāsya": ['mw'],
    "upajjhā": ['cped'],
    "upajjhāya": ['cped'],
    "upajjhāyamatta": ['cped'],
    "upajjhāyamūlaka": ['cped'],
    "upajjhāyā": ['cped'],
    "upajman": ['ap90', 'mw'],
    "upajoṣa": ['mw'],
    "upajoṣam": ['ddsa', 'mw'],
    "upajoṣaḥ": ['ap90'],
    "upajoṣaṇa": ['mw'],
    "upajri": ['mw'],
    "upajuṣ": ['mw'],
    "upajuṣṭa": ['ap90'],
    "upajval": ['mw'],
    "upajvalana": ['mw'],
    "upajvalita": ['ap90', 'mw'],
    "upajyotiṣa": ['mw'],
    "upajñā": ['ap90', 'ddsa', 'mw'],
    "upajñāta": ['ap90', 'mw'],
    "upajā": ['ap90', 'mw'],
    "upajānu": ['mw'],
    "upajānāti": ['cped'],
    "upajāpa": ['cae', 'ddsa', 'mw'],
    "upajāpaka": ['ap90', 'cae', 'mw'],
    "upajāpaḥ": ['ap90'],
    "upajāta": ['ap90', 'mw'],
    "upajātakheda": ['mw'],
    "upajātakopa": ['ddsa', 'mw'],
    "upajātakrodha": ['mw'],
    "upajātaviśvāsa": ['mw'],
    "upajāti": ['cae', 'mw'],
    "upajātikā": ['mw'],
    "upajātiḥ": ['ap90'],
    "upajāyati": ['cped'],
    "upajīka": ['ap90'],
    "upajīkā": ['mw'],
    "upajīv": ['ap90', 'mw'],
    "upajīva": ['ap90', 'mw'],
    "upajīvaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "upajīvamāna": ['cped'],
    "upajīvana": ['cae', 'mw'],
    "upajīvanaṃ": ['ap90'],
    "upajīvanīya": ['cae', 'mw'],
    "upajīvati": ['cped'],
    "upajīvin": ['cae', 'mw'],
    "upajīvita": ['bhs'],
    "upajīvitṛ": ['mw'],
    "upajīvya": ['ap90', 'cae', 'mw'],
    "upajīvā": ['mw'],
    "upaka": ['bhs', 'mw'],
    "upakacchaka": ['cped'],
    "upakakṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "upakakṣadaghna": ['mw'],
    "upakalpa": ['mw'],
    "upakalpana": ['mw'],
    "upakalpanaṃ": ['ap90'],
    "upakalpanā": ['mw'],
    "upakalpanīya": ['mw'],
    "upakalpayitavya": ['mw'],
    "upakalpin": ['mw'],
    "upakalpita": ['ap90', 'mw'],
    "upakalpya": ['mw'],
    "upakalāpam": ['mw'],
    "upakambala": ['bhs'],
    "upakaniṣṭhikā": ['ap90', 'mw'],
    "upakanyā": ['ap90', 'mw'],
    "upakanyāpuram": ['mw'],
    "upakappati": ['cped'],
    "upakappeti": ['cped'],
    "upakara": ['bhs'],
    "upakaraṇa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "upakaraṇavat": ['mw'],
    "upakaraṇaṃ": ['ap90'],
    "upakaraṇārtha": ['mw'],
    "upakaraṇībhū": ['mw'],
    "upakaraṇīkṛ": ['mw'],
    "upakaraṇīya": ['mw'],
    "upakartavya": ['mw'],
    "upakartṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "upakarṇ": ['ap90'],
    "upakarṇam": ['mw'],
    "upakarṇanaṃ": ['ap90'],
    "upakarṇaṃ": ['ap90'],
    "upakarṇikā": ['ap90', 'mw'],
    "upakarṣam": ['mw'],
    "upakarṣaṇa": ['mw'],
    "upakarṣikā": ['bhs'],
    "upakathā": ['ap90', 'mw'],
    "upakaḍḍhati": ['cped'],
    "upakaṃṭha": ['ap90'],
    "upakaṇṇakajappi": ['cped'],
    "upakaṇṇakajappin": ['cped'],
    "upakaṇṇakamhi": ['cped'],
    "upakaṇṇakaṁ": ['cped'],
    "upakaṇṇake": ['cped'],
    "upakaṇṭha": ['cae', 'mw'],
    "upakaṇṭhaka": ['bhs'],
    "upakaṇṭham": ['mw'],
    "upakaṭṭha": ['cped'],
    "upakeru": ['mw'],
    "upaketu": ['mw'],
    "upakeśinī": ['bhs'],
    "upakeśī": ['bhs'],
    "upakhila": ['mw'],
    "upakhyā": ['mw'],
    "upakhātam": ['mw'],
    "upakileśa": ['bhs'],
    "upakiliṭṭha": ['cped'],
    "upakiraṇa": ['ap90', 'mw'],
    "upakiraṇaṃ": ['ap90'],
    "upakirituṁ": ['cped'],
    "upakka": ['cped'],
    "upakkama": ['cped'],
    "upakkamat": ['cped'],
    "upakkamati": ['cped'],
    "upakkami": ['cped'],
    "upakkamitvā": ['cped'],
    "upakkamiṁsu": ['cped'],
    "upakkhalati": ['cped'],
    "upakkhaṭa": ['cped'],
    "upakkilesa": ['cped'],
    "upakkiliṭṭha": ['cped'],
    "upakkitaka": ['cped'],
    "upakkosati": ['cped'],
    "upakkītaka": ['cped'],
    "upakleda": ['bhs'],
    "upaklesa": ['cped'],
    "upakleśa": ['bhs', 'mw'],
    "upaklid": ['mw'],
    "upaklinna": ['mw'],
    "upakliśyate": ['bhs'],
    "upakosala": ['mw'],
    "upakośā": ['ddsa', 'mw'],
    "upakoṇa": ['mw'],
    "upakram": ['ap90', 'mw'],
    "upakrama": ['bhs', 'cae', 'ddsa', 'mw'],
    "upakramaparākrama": ['mw'],
    "upakramati": ['bhs'],
    "upakramaḥ": ['ap90'],
    "upakramaṇa": ['bhs', 'mw'],
    "upakramaṇaṃ": ['ap90'],
    "upakramaṇikā": ['ap90'],
    "upakramaṇīya": ['ap90', 'mw'],
    "upakramika": ['bhs'],
    "upakramitavya": ['ap90', 'mw'],
    "upakramitṛ": ['ap90'],
    "upakramya": ['mw'],
    "upakrantṛ": ['mw'],
    "upakraṃtṛ": ['ap90'],
    "upakriyā": ['cae', 'ddsa', 'mw'],
    "upakrośa": ['ddsa', 'mw'],
    "upakrośana": ['mw'],
    "upakrośanakara": ['mw'],
    "upakrośaḥ": ['ap90'],
    "upakroṣṭṛ": ['ap90', 'mw'],
    "upakruś": ['ap90', 'mw'],
    "upakruśya": ['mw'],
    "upakruṣṭa": ['cae', 'mw'],
    "upakrāmya": ['mw'],
    "upakrānta": ['cae', 'mw'],
    "upakrī": ['mw'],
    "upakrīya": ['mw'],
    "upakrīḍ": ['mw'],
    "upakrīḍā": ['ap90', 'ddsa', 'mw'],
    "upakula": ['mw'],
    "upakulyā": ['ap90', 'mw'],
    "upakumbha": ['mw'],
    "upakumbham": ['mw'],
    "upakumbhe": ['mw'],
    "upakumbhena": ['mw'],
    "upakumbhā": ['mw'],
    "upakumbhāt": ['mw'],
    "upakuraṅga": ['mw'],
    "upakurvāṇa": ['ap90', 'ddsa', 'mw'],
    "upakurvāṇaka": ['mw'],
    "upakuñci": ['mw'],
    "upakuñcikā": ['mw'],
    "upakuśa": ['bhs', 'mw'],
    "upakuśaḥ": ['ap90'],
    "upakuṃbha": ['ap90'],
    "upakuṃciḥ": ['ap90'],
    "upakvasa": ['mw'],
    "upakvasaḥ": ['ap90'],
    "upakvaṇa": ['mw'],
    "upakvaṇaṃ": ['ap90'],
    "upakvāṇa": ['mw'],
    "upakvāṇaṃ": ['ap90'],
    "upakādi": ['mw'],
    "upakāla": ['bhs', 'mw'],
    "upakālaka": ['bhs'],
    "upakālikā": ['mw'],
    "upakāntam": ['ddsa', 'mw'],
    "upakāra": ['cae', 'cped', 'ddsa', 'mw'],
    "upakāraka": ['ap90', 'cae', 'mw'],
    "upakārakatva": ['mw'],
    "upakārapara": ['mw'],
    "upakāraḥ": ['ap90'],
    "upakāraṇa": ['bhs'],
    "upakārikā": ['ap90', 'mw'],
    "upakārin": ['ap90', 'mw'],
    "upakāritva": ['mw'],
    "upakārya": ['ap90', 'cae', 'mw'],
    "upakāryā": ['mw'],
    "upakārāpakāra": ['mw'],
    "upakārī": ['cped', 'mw'],
    "upakāsiṁ": ['cped'],
    "upakāśa": ['mw'],
    "upakāśinī": ['mw'],
    "upakāṇa": ['bhs'],
    "upakīcaka": ['mw'],
    "upakīcakaḥ": ['ap90'],
    "upakīrṇa": ['mw'],
    "upakīrṇaka": ['bhs'],
    "upakītaka": ['cped'],
    "upakūj": ['ap90', 'mw'],
    "upakūjita": ['ap90', 'mw'],
    "upakūla": ['ddsa', 'mw'],
    "upakūlaka": ['mw'],
    "upakūlam": ['mw'],
    "upakūlatas": ['mw'],
    "upakūlaṃ": ['ap90'],
    "upakūlita": ['cped'],
    "upakūpa": ['mw'],
    "upakūpajalāśaya": ['mw'],
    "upakūpaṃ": ['ap90'],
    "upakūpe": ['mw'],
    "upakūḷita": ['cped'],
    "upakḷp": ['ap90', 'mw'],
    "upakḷpta": ['ap90', 'cae', 'mw'],
    "upakṛ": ['ap90', 'mw'],
    "upakṛt": ['mw'],
    "upakṛta": ['ap90', 'mw'],
    "upakṛti": ['cae', 'ddsa', 'mw'],
    "upakṛtimat": ['mw'],
    "upakṛtin": ['mw'],
    "upakṛtiḥ": ['ap90'],
    "upakṛṣ": ['mw'],
    "upakṛṣṇa": ['mw'],
    "upakṛṣṇaka": ['mw'],
    "upakṝ": ['ap90', 'mw'],
    "upakṣapayitṛ": ['mw'],
    "upakṣar": ['mw'],
    "upakṣatra": ['mw'],
    "upakṣaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "upakṣepa": ['cae', 'ddsa', 'mw'],
    "upakṣepaka": ['mw'],
    "upakṣepaḥ": ['ap90'],
    "upakṣepaṇa": ['mw'],
    "upakṣepaṇaṃ": ['ap90'],
    "upakṣetra": ['bhs'],
    "upakṣetṛ": ['ap90', 'gra', 'mw'],
    "upakṣi": ['ap90', 'mw'],
    "upakṣip": ['ap90', 'mw'],
    "upakṣit": ['ap90', 'gra', 'mw'],
    "upakṣita": ['mw'],
    "upakṣudra": ['mw'],
    "upakṣīṇa": ['ap90', 'mw'],
    "upala": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "upalabbhati": ['cped'],
    "upalabbhiyati": ['cped'],
    "upalabdha": ['ap90', 'bhs', 'mw'],
    "upalabdhasukha": ['mw'],
    "upalabdhavya": ['mw'],
    "upalabdhi": ['cae', 'ddsa', 'mw'],
    "upalabdhimat": ['mw'],
    "upalabdhimattva": ['mw'],
    "upalabdhisama": ['mw'],
    "upalabdhiḥ": ['ap90'],
    "upalabdhārtha": ['mw'],
    "upalabdhṛ": ['ap90', 'mw'],
    "upalabh": ['ap90', 'mw'],
    "upalabhedin": ['mw'],
    "upalabhiyati": ['cped'],
    "upalabhya": ['ap90', 'ddsa', 'mw'],
    "upalabhyate": ['bhs'],
    "upaladhi": ['mw'],
    "upaladhipriyaḥ": ['ap90'],
    "upalagna": ['bhs'],
    "upalahasta": ['mw'],
    "upalaka": ['mw'],
    "upalakaḥ": ['ap90'],
    "upalakuṇḍaka": ['bhs'],
    "upalakṣ": ['ap90', 'mw'],
    "upalakṣa": ['mw'],
    "upalakṣaka": ['ap90', 'ddsa', 'mw'],
    "upalakṣayitavya": ['mw'],
    "upalakṣaṇa": ['cae', 'mw'],
    "upalakṣaṇatva": ['mw'],
    "upalakṣaṇatā": ['mw'],
    "upalakṣaṇaṃ": ['ap90'],
    "upalakṣita": ['ap90', 'mw'],
    "upalakṣmī": ['mw'],
    "upalakṣya": ['ap90', 'cae', 'mw'],
    "upalal": ['ap90', 'mw'],
    "upalambha": ['bhs', 'cae', 'mw'],
    "upalambhadṛṣṭika": ['bhs'],
    "upalambhaka": ['mw'],
    "upalambhana": ['mw'],
    "upalambhika": ['bhs'],
    "upalambhya": ['mw'],
    "upalaprakṣin": ['cae', 'ddsa', 'gra', 'mw'],
    "upalaviṣama": ['ddsa'],
    "upalaya": ['mw'],
    "upalaḥ": ['ap90'],
    "upalaṃbhaka": ['ap90'],
    "upalaṃbhanaṃ": ['ap90'],
    "upalaṃbhaḥ": ['ap90'],
    "upalekha": ['mw'],
    "upalekhabhāṣya": ['mw'],
    "upalekhapañjikā": ['mw'],
    "upalepa": ['cae', 'mw'],
    "upalepana": ['cae', 'ddsa', 'mw'],
    "upalepanaṃ": ['ap90'],
    "upalepaḥ": ['ap90'],
    "upalepin": ['ap90', 'mw'],
    "upaleṭa": ['mw'],
    "upalikh": ['mw'],
    "upalikhya": ['mw'],
    "upalikkhati": ['cped'],
    "upalimpati": ['cped'],
    "upalip": ['ap90', 'mw'],
    "upalippati": ['cped'],
    "upalipsu": ['mw'],
    "upalipsā": ['ap90', 'ddsa', 'mw'],
    "upalipta": ['mw'],
    "upalipya": ['mw'],
    "upalitta": ['cped'],
    "upaliṃgaṃ": ['ap90'],
    "upaliṅga": ['mw'],
    "upallaviṁ": ['cped'],
    "upaloha": ['mw'],
    "upaloṭa": ['mw'],
    "upalubh": ['mw'],
    "upalā": ['ddsa', 'mw'],
    "upalābha": ['mw'],
    "upalāla": ['bhs'],
    "upalālana": ['mw'],
    "upalālanaṃ": ['ap90'],
    "upalālikā": ['ap90'],
    "upalālita": ['mw'],
    "upalāpana": ['bhs', 'cped'],
    "upalāpayati": ['bhs'],
    "upalāpenta": ['cped'],
    "upalāpesuṁ": ['cped'],
    "upalāpetabba": ['cped'],
    "upalāpeti": ['cped'],
    "upalāpetvā": ['cped'],
    "upalāśa": ['mw'],
    "upalāḍana": ['bhs'],
    "upalāḍayati": ['bhs'],
    "upalī": ['mw'],
    "upama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "upamad": ['mw'],
    "upamadgu": ['mw'],
    "upamadhyamā": ['mw'],
    "upamadā": ['bhs'],
    "upamajj": ['mw'],
    "upamajjana": ['mw'],
    "upamanthana": ['mw'],
    "upamanthanī": ['mw'],
    "upamanthitṛ": ['mw'],
    "upamantr": ['mw'],
    "upamantraṇa": ['cae', 'mw'],
    "upamantrin": ['cae', 'ddsa', 'gra', 'mw'],
    "upamantrita": ['mw'],
    "upamanyu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "upamarda": ['bhs', 'cae', 'ddsa', 'mw'],
    "upamardaka": ['ap90', 'bhs', 'cae', 'mw'],
    "upamardana": ['cae', 'mw'],
    "upamardaḥ": ['ap90'],
    "upamardin": ['cae', 'mw'],
    "upamarṣita": ['mw'],
    "upamath": ['mw'],
    "upamathita": ['mw'],
    "upamathya": ['mw'],
    "upamaśravas": ['gra', 'mw'],
    "upamaśravastama": ['mw'],
    "upamaṃthanī": ['ap90'],
    "upamaṃthitṛ": ['ap90'],
    "upamaṃtr": ['ap90'],
    "upamaṃtraṇaṃ": ['ap90'],
    "upamaṃtrin": ['ap90'],
    "upamekhalam": ['mw'],
    "upameta": ['mw'],
    "upameya": ['ap90', 'cae', 'mw'],
    "upameyopamā": ['cae', 'mw'],
    "upami": ['mw'],
    "upamih": ['mw'],
    "upamit": ['ap90', 'gra', 'mw'],
    "upamita": ['ap90', 'mw'],
    "upamiti": ['cae', 'ddsa', 'mw'],
    "upamitiḥ": ['ap90'],
    "upamitra": ['mw'],
    "upamluc": ['mw'],
    "upamlup": ['mw'],
    "upamlupta": ['mw'],
    "upamopanyāsa": ['bhs'],
    "upamuc": ['mw'],
    "upamukham": ['mw'],
    "upamya": ['bhs'],
    "upamā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "upamāda": ['ap90', 'gra', 'mw'],
    "upamādravya": ['mw'],
    "upamālinī": ['mw'],
    "upamālinītīram": ['mw'],
    "upamām": ['cae', 'mw'],
    "upamāna": ['bhs', 'cae', 'mw'],
    "upamānacintāmaṇi": ['mw'],
    "upamānatva": ['mw'],
    "upamānatā": ['mw'],
    "upamānavat": ['mw'],
    "upamānaṃ": ['ap90'],
    "upamānopameyabhāva": ['mw'],
    "upamāraṇa": ['mw'],
    "upamāraṇaṃ": ['ap90'],
    "upamārūpaka": ['mw'],
    "upamāsya": ['ap90', 'mw'],
    "upamāt": ['mw'],
    "upamāti": ['cae', 'gra', 'mw'],
    "upamātivani": ['gra', 'mw'],
    "upamātiḥ": ['ap90'],
    "upamātṛ": ['ap90', 'mw'],
    "upamāvyatireka": ['cae', 'mw'],
    "upamīmāṃsā": ['ap90', 'mw'],
    "upamūlam": ['mw'],
    "upamṛ": ['mw'],
    "upamṛd": ['ap90', 'mw'],
    "upamṛj": ['mw'],
    "upamṛta": ['mw'],
    "upamṛṣ": ['mw'],
    "upamṝ": ['mw'],
    "upanaccantī": ['cped'],
    "upanad": ['mw'],
    "upanadam": ['mw'],
    "upanaddha": ['cped', 'mw'],
    "upanaddhavya": ['mw'],
    "upanadi": ['mw'],
    "upanagara": ['mw'],
    "upanagarabhava": ['mw'],
    "upanagaram": ['mw'],
    "upanagaraṃ": ['ap90'],
    "upanah": ['ap90', 'mw'],
    "upanahana": ['mw'],
    "upanahanaṃ": ['ap90'],
    "upanahyati": ['bhs'],
    "upanakha": ['mw'],
    "upanakhaṃ": ['ap90'],
    "upanakṣ": ['mw'],
    "upanakṣatra": ['mw'],
    "upanakṣatraṃ": ['ap90'],
    "upanala": ['bhs'],
    "upanam": ['ap90', 'mw'],
    "upanama": ['cped'],
    "upanamat": ['cped'],
    "upanamati": ['cped'],
    "upanamra": ['mw'],
    "upananda": ['bhs', 'mw'],
    "upanandaka": ['bhs', 'mw'],
    "upanandana": ['mw'],
    "upanandhati": ['cped'],
    "upanandhi": ['cped'],
    "upanara": ['bhs', 'mw'],
    "upanata": ['ap90', 'cae', 'mw'],
    "upanati": ['cae', 'mw'],
    "upanatiḥ": ['ap90'],
    "upanaya": ['cae', 'ddsa', 'mw'],
    "upanayana": ['cae', 'mw'],
    "upanayanacintāmaṇi": ['mw'],
    "upanayanalakṣaṇa": ['mw'],
    "upanayanaṃ": ['ap90'],
    "upanayaḥ": ['ap90'],
    "upanayhati": ['cped'],
    "upanaśyati": ['bhs'],
    "upanenta": ['cped'],
    "upanesi": ['cped'],
    "upanesuṁ": ['cped'],
    "upanetabba": ['cped'],
    "upanetavya": ['ap90', 'ddsa', 'mw'],
    "upaneti": ['cped'],
    "upanetrī": ['bhs'],
    "upanetvā": ['cped'],
    "upanetṛ": ['ap90', 'cae', 'mw'],
    "upaneya": ['bhs', 'mw'],
    "upaneyya": ['cped'],
    "upanibaddha": ['cae', 'cped', 'mw'],
    "upanibadhnāti": ['bhs'],
    "upanibajjate": ['cped'],
    "upanibajjati": ['cped'],
    "upanibanddhṛ": ['ddsa'],
    "upanibandh": ['mw'],
    "upanibandha": ['bhs', 'ddsa', 'mw'],
    "upanibandhana": ['cae', 'cped', 'mw'],
    "upanibandhati": ['cped'],
    "upanibandhitvā": ['cped'],
    "upanibatta": ['cped'],
    "upanibaṃdh": ['ap90'],
    "upanibaṃdhanaṃ": ['ap90'],
    "upanibha": ['mw'],
    "upanidadhāti": ['bhs'],
    "upanidhi": ['cae', 'cped', 'ddsa', 'mw'],
    "upanidhiḥ": ['ap90'],
    "upanidhyāna": ['bhs'],
    "upanidhyātavya": ['mw'],
    "upanidhyāti": ['bhs'],
    "upanidhyāyanatā": ['bhs'],
    "upanidhyāyati": ['bhs'],
    "upanidhā": ['ap90', 'cped', 'mw'],
    "upanidhāna": ['mw'],
    "upanidhānaṃ": ['ap90'],
    "upanidhātṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "upanidhāya": ['cped', 'mw'],
    "upanigam": ['mw'],
    "upanighaṁsanta": ['cped'],
    "upanigrah": ['mw'],
    "upanigrāham": ['mw'],
    "upanihan": ['mw'],
    "upanihita": ['ap90', 'mw'],
    "upanijjhāya": ['cped'],
    "upanijjhāyat": ['cped'],
    "upanijjhāyati": ['cped'],
    "upanijjhāyi": ['cped'],
    "upanijjhāyita": ['cped'],
    "upanijjhāyitabba": ['cped'],
    "upanikkhamanta": ['cped'],
    "upanikkhamati": ['cped'],
    "upanikkhepana": ['cped'],
    "upanikkhipana": ['cped'],
    "upanikkhipati": ['cped'],
    "upanikkhipi": ['cped'],
    "upanikkhipitabba": ['cped'],
    "upanikkhipitvā": ['cped'],
    "upanikkhitta": ['cped'],
    "upanikṣepa": ['ddsa', 'mw'],
    "upanikṣepaka": ['bhs'],
    "upanikṣepaḥ": ['ap90'],
    "upanikṣepaṇa": ['bhs'],
    "upanikṣip": ['ap90', 'mw'],
    "upanikṣipati": ['bhs'],
    "upanimajj": ['mw'],
    "upanimand": ['mw'],
    "upanimantr": ['mw'],
    "upanimantraṇa": ['ddsa', 'mw'],
    "upanimaṃtraṇaṃ": ['ap90'],
    "upanimreḍ": ['mw'],
    "upaninīṣu": ['mw'],
    "upanipad": ['mw'],
    "upanipajjati": ['cped'],
    "upanipanna": ['cped'],
    "upanipat": ['ap90', 'mw'],
    "upaniplu": ['mw'],
    "upanipāta": ['cae', 'ddsa', 'mw'],
    "upanipātana": ['mw'],
    "upanipātaḥ": ['ap90'],
    "upanipātin": ['ap90', 'cae', 'mw'],
    "upanipātita": ['bhs'],
    "upanipīḍ": ['mw'],
    "upanipīḍayati": ['bhs'],
    "upanipīḍita": ['mw'],
    "upanirbaddha": ['bhs'],
    "upanirgama": ['cae', 'mw'],
    "upanirhṛ": ['mw'],
    "upanirudh": ['mw'],
    "upanirvṛt": ['mw'],
    "upanisa": ['cped'],
    "upanisevati": ['cped'],
    "upanisevin": ['bhs'],
    "upanisinna": ['cped'],
    "upanissita": ['cped'],
    "upanissāya": ['cped'],
    "upanisā": ['cped'],
    "upanisīdapetvā": ['cped'],
    "upanisīdati": ['cped'],
    "upanisīditvā": ['cped'],
    "upanisṛtya": ['bhs'],
    "upanivap": ['mw'],
    "upanivapana": ['mw'],
    "upanivapanaṃ": ['ap90'],
    "upanivartam": ['mw'],
    "upanivattati": ['cped'],
    "upaniveśa": ['mw'],
    "upaniveśin": ['ap90', 'mw'],
    "upaniveśinī": ['mw'],
    "upaniveśita": ['ap90'],
    "upaniveṣṭ": ['mw'],
    "upaniviś": ['mw'],
    "upaniviṣṭa": ['mw'],
    "upanivṛ": ['mw'],
    "upanivṛt": ['mw'],
    "upaniyuj": ['mw'],
    "upaniśam": ['mw'],
    "upaniśamya": ['mw'],
    "upaniśraya": ['bhs'],
    "upaniśri": ['mw'],
    "upaniśrita": ['bhs'],
    "upaniśritya": ['bhs'],
    "upaniśrāya": ['bhs'],
    "upaniśā": ['bhs'],
    "upaniḥśri": ['mw'],
    "upaniḥśritya": ['mw'],
    "upaniṣad": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "upaniṣada": ['mw'],
    "upaniṣadbrāhmaṇa": ['mw'],
    "upaniṣadratna": ['mw'],
    "upaniṣadvivaraṇa": ['mw'],
    "upaniṣatkṛ": ['mw'],
    "upaniṣaṇṇa": ['bhs'],
    "upaniṣaṇṇaka": ['bhs'],
    "upaniṣev": ['mw'],
    "upaniṣkara": ['mw'],
    "upaniṣkaraḥ": ['ap90'],
    "upaniṣkram": ['mw'],
    "upaniṣkramaṇa": ['ddsa', 'mw'],
    "upaniṣkramaṇaṃ": ['ap90'],
    "upaniṣkramya": ['mw'],
    "upaniṣkrānta": ['mw'],
    "upaniṣādin": ['ap90', 'mw'],
    "upanud": ['mw'],
    "upanunna": ['mw'],
    "upanyas": ['ap90', 'mw'],
    "upanyasana": ['ddsa'],
    "upanyasta": ['ap90', 'bhs', 'cae', 'mw'],
    "upanyasya": ['mw'],
    "upanyācar": ['mw'],
    "upanyāhṛ": ['mw'],
    "upanyāplu": ['mw'],
    "upanyāsa": ['cae', 'ddsa', 'mw'],
    "upanyāsaḥ": ['ap90'],
    "upanyāsya": ['mw'],
    "upanādita": ['mw'],
    "upanāgara": ['mw'],
    "upanāgarikā": ['ap90', 'mw'],
    "upanāha": ['bhs', 'cped', 'mw'],
    "upanāhana": ['mw'],
    "upanāhanaṃ": ['ap90'],
    "upanāhasveda": ['mw'],
    "upanāhaḥ": ['ap90'],
    "upanāhi": ['cped'],
    "upanāhin": ['bhs', 'cped'],
    "upanāman": ['ap90', 'mw'],
    "upanāmayati": ['bhs', 'cped'],
    "upanāmayi": ['cped'],
    "upanāmayuṁ": ['cped'],
    "upanāmesi": ['cped'],
    "upanāmesuṁ": ['cped'],
    "upanāmetabba": ['cped'],
    "upanāmeti": ['cped'],
    "upanāmita": ['cped'],
    "upanāmuka": ['ap90', 'mw'],
    "upanāsika": ['mw'],
    "upanāsikaṃ": ['ap90'],
    "upanāth": ['mw'],
    "upanāya": ['gra', 'mw'],
    "upanāyaka": ['ap90', 'mw'],
    "upanāyana": ['cae', 'ddsa', 'mw'],
    "upanāyaḥ": ['ap90'],
    "upanāyika": ['bhs', 'mw'],
    "upanāyikā": ['ap90'],
    "upanāyin": ['mw'],
    "upanī": ['ap90', 'mw'],
    "upanīhātuṁ": ['cped'],
    "upanīta": ['ap90', 'bhs', 'cped', 'mw'],
    "upanītavaya": ['cped'],
    "upanīti": ['mw'],
    "upanīya": ['cped'],
    "upanīyamāna": ['cped'],
    "upanīyati": ['cped'],
    "upanīyyati": ['cped'],
    "upanṛt": ['ap90', 'mw'],
    "upanṛtta": ['mw'],
    "upanṛtya": ['mw'],
    "upanṛtyaṃ": ['ap90'],
    "upapad": ['ap90', 'mw'],
    "upapada": ['cae', 'ddsa', 'mw'],
    "upapadasamāsa": ['mw'],
    "upapadaṃ": ['ap90'],
    "upapaddha": ['bhs'],
    "upapadyate": ['bhs'],
    "upapajja": ['cped'],
    "upapajjat": ['cped'],
    "upapajjatha": ['cped'],
    "upapajjati": ['cped'],
    "upapajjaṁ": ['cped'],
    "upapajji": ['cped'],
    "upapajjita": ['cped'],
    "upapajjitar": ['cped'],
    "upapajjiṁsu": ['cped'],
    "upapakṣa": ['cae', 'mw'],
    "upapakṣadaghna": ['mw'],
    "upapakṣau": ['mw'],
    "upapakṣaḥ": ['ap90'],
    "upapakṣma": ['mw'],
    "upapakṣya": ['ap90', 'mw'],
    "upapalvalam": ['mw'],
    "upapalyayya": ['mw'],
    "upapalī": ['mw'],
    "upapanna": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "upapannārtha": ['cae', 'mw'],
    "upaparcana": ['ap90', 'gra', 'mw'],
    "upapare": ['mw'],
    "upaparikkha": ['cped'],
    "upaparikkhat": ['cped'],
    "upaparikkhati": ['cped'],
    "upaparikkhi": ['cped'],
    "upaparikkhitabba": ['cped'],
    "upaparvan": ['mw'],
    "upaparyāvṛt": ['mw'],
    "upaparāmṛś": ['mw'],
    "upaparāsṛ": ['mw'],
    "upaparāsṛtya": ['mw'],
    "upaparīkṣ": ['mw'],
    "upaparīkṣaka": ['bhs'],
    "upaparīkṣate": ['bhs'],
    "upaparīkṣaṇa": ['bhs', 'mw'],
    "upaparīkṣā": ['ap90', 'mw'],
    "upaparīṣa": ['mw'],
    "upaparśukā": ['ap90', 'mw'],
    "upapat": ['mw'],
    "upapatanīya": ['mw'],
    "upapatha": ['mw'],
    "upapatham": ['mw'],
    "upapathaṃ": ['ap90'],
    "upapati": ['cae', 'ddsa', 'mw'],
    "upapatiḥ": ['ap90'],
    "upapatti": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "upapattika": ['bhs'],
    "upapattimat": ['mw'],
    "upapattiparityakta": ['mw'],
    "upapattipaṭilābhiya": ['cped'],
    "upapattisama": ['mw'],
    "upapattivaśitā": ['bhs'],
    "upapattiyukta": ['mw'],
    "upapattiḥ": ['ap90'],
    "upapattyaṃśika": ['bhs'],
    "upapauraka": ['ddsa'],
    "upapaurika": ['ap90', 'mw'],
    "upapaurṇamāsam": ['mw'],
    "upapaurṇamāsi": ['mw'],
    "upapañcaka": ['bhs'],
    "upapeta": ['bhs'],
    "upapisana": ['cped'],
    "upapiṁsana": ['cped'],
    "upaplava": ['cae', 'ddsa', 'mw'],
    "upaplavaḥ": ['ap90'],
    "upaplavin": ['ap90', 'mw'],
    "upaplaviṁ": ['cped'],
    "upaplavya": ['mw'],
    "upaple": ['mw'],
    "upaplu": ['ap90', 'mw'],
    "upapluta": ['ap90', 'cae', 'mw'],
    "upaplutekṣaṇa": ['mw'],
    "upaplutā": ['mw'],
    "upaprabhid": ['mw'],
    "upaprabhinna": ['mw'],
    "upaprabhū": ['mw'],
    "upaprabhūṣ": ['mw'],
    "upaprach": ['mw'],
    "upapradarśana": ['mw'],
    "upapradarśanaṃ": ['ap90'],
    "upapradā": ['mw'],
    "upapradāna": ['ddsa', 'mw'],
    "upapradānaṃ": ['ap90'],
    "upapradṛś": ['mw'],
    "upapragā": ['mw'],
    "upaprahi": ['mw'],
    "upapraiṣa": ['ddsa', 'mw'],
    "upapraiṣaḥ": ['ap90'],
    "upaprajan": ['mw'],
    "upaprajinv": ['mw'],
    "upaprakṣe": ['gra', 'mw'],
    "upapralobhana": ['ddsa', 'mw'],
    "upapralobhanaṃ": ['ap90'],
    "upaprasad": ['mw'],
    "upaprastṛ": ['mw'],
    "upaprasṛ": ['mw'],
    "upapratigrah": ['mw'],
    "upapratṝ": ['mw'],
    "upapravad": ['mw'],
    "upapravahati": ['bhs'],
    "upapravṛh": ['mw'],
    "upapravṛt": ['mw'],
    "upaprayam": ['mw'],
    "upaprayā": ['mw'],
    "upapraśri": ['mw'],
    "upapre": ['mw'],
    "upaprekṣ": ['ap90', 'mw'],
    "upaprekṣaṇa": ['ddsa', 'mw'],
    "upaprekṣaṇaṃ": ['ap90'],
    "upapreṣ": ['mw'],
    "upaprut": ['gra', 'mw'],
    "upaprāp": ['mw'],
    "upaprāpta": ['mw'],
    "upaprāyā": ['mw'],
    "upaprāṇa": ['mw'],
    "upaprāṇaḥ": ['ap90'],
    "upapura": ['mw'],
    "upapuraṃ": ['ap90'],
    "upapurāṇa": ['cae', 'ddsa', 'mw'],
    "upapurāṇaṃ": ['ap90'],
    "upapurī": ['mw'],
    "upapuṣpikā": ['ap90', 'mw'],
    "upapā": ['mw'],
    "upapāda": ['bhs', 'mw'],
    "upapādaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "upapādana": ['cae', 'mw'],
    "upapādanaṃ": ['ap90'],
    "upapādanīya": ['mw'],
    "upapādin": ['mw'],
    "upapādita": ['mw'],
    "upapādiṁ": ['cped'],
    "upapāduka": ['ap90', 'bhs', 'mw'],
    "upapādya": ['mw'],
    "upapāpa": ['ddsa', 'mw'],
    "upapāpaṃ": ['ap90'],
    "upapārśva": ['cae', 'ddsa', 'mw'],
    "upapārśvaḥ": ['ap90'],
    "upapāta": ['cae', 'ddsa', 'mw'],
    "upapātaka": ['cae', 'ddsa', 'mw'],
    "upapātakaṃ": ['ap90'],
    "upapātakin": ['ap90', 'mw'],
    "upapātaḥ": ['ap90'],
    "upapātin": ['cae', 'ddsa', 'mw'],
    "upapātra": ['mw'],
    "upapāyana": ['mw'],
    "upapīlu": ['bhs'],
    "upapīḍ": ['ap90', 'mw'],
    "upapīḍam": ['mw'],
    "upapīḍana": ['cae', 'ddsa', 'mw'],
    "upapīḍanaṃ": ['ap90'],
    "upapīḍita": ['mw'],
    "upapūrva": ['ddsa'],
    "upapūrvarātram": ['mw'],
    "upapūrvāhṇam": ['mw'],
    "upapṛc": ['gra', 'mw'],
    "upapṝ": ['mw'],
    "upara": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uparac": ['mw'],
    "uparacita": ['mw'],
    "uparadh": ['mw'],
    "uparajja": ['cped'],
    "uparajya": ['mw'],
    "uparakta": ['ap90', 'cae', 'mw'],
    "uparakṣaḥ": ['ap90'],
    "uparakṣaṇa": ['mw'],
    "uparakṣaṇaṃ": ['ap90'],
    "uparam": ['ap90', 'mw'],
    "uparama": ['cae', 'mw'],
    "uparamatva": ['cae', 'mw'],
    "uparamaḥ": ['ap90'],
    "uparamaṇa": ['cae', 'mw'],
    "uparamaṇaṃ": ['ap90'],
    "uparambh": ['mw'],
    "uparandhra": ['mw'],
    "uparasa": ['mw'],
    "uparasaḥ": ['ap90'],
    "uparata": ['ap90', 'cped', 'mw'],
    "uparatarāsa": ['mw'],
    "uparataspṛha": ['mw'],
    "uparataviṣayābhilāṣa": ['mw'],
    "uparataśoṇitā": ['mw'],
    "uparathyā": ['mw'],
    "uparati": ['cae', 'ddsa', 'mw'],
    "uparatiḥ": ['ap90'],
    "uparatna": ['mw'],
    "uparatnaṃ": ['ap90'],
    "uparatāri": ['mw'],
    "uparatāt": ['gra'],
    "uparatāti": ['ap90', 'mw'],
    "uparava": ['mw'],
    "uparavaḥ": ['ap90'],
    "uparañj": ['mw'],
    "uparañjaka": ['mw'],
    "uparañjya": ['mw'],
    "uparaṃj": ['ap90'],
    "uparddha": ['bhs'],
    "uparddhakāśikā": ['bhs'],
    "upari": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "uparibabhrava": ['mw'],
    "uparibhakta": ['mw'],
    "uparibhāga": ['ddsa', 'mw'],
    "uparibhāva": ['mw'],
    "uparibhāvaṅgamanīya": ['cped'],
    "uparibhūmi": ['mw'],
    "uparibuddhi": ['mw'],
    "uparibudhna": ['gra', 'mw'],
    "uparibṛhatī": ['mw'],
    "uparicara": ['mw'],
    "uparicihnita": ['mw'],
    "uparicita": ['mw'],
    "uparidaśa": ['mw'],
    "uparidaṃṣṭrin": ['mw'],
    "upariga": ['mw'],
    "uparigarbholika": ['bhs'],
    "uparigata": ['mw'],
    "uparihasta": ['mw'],
    "uparija": ['mw'],
    "uparijānu": ['ddsa', 'mw'],
    "uparikoṣṭhaka": ['bhs'],
    "uparikuṭī": ['mw'],
    "uparikāṇḍa": ['mw'],
    "uparim": ['bhs'],
    "uparima": ['bhs', 'cped'],
    "uparimartia": ['gra'],
    "uparimartya": ['gra', 'mw'],
    "uparimekhala": ['mw'],
    "uparinihita": ['mw'],
    "uparinyasta": ['mw'],
    "uparinābhi": ['mw'],
    "upariprut": ['mw'],
    "uparipuruṣa": ['mw'],
    "uparipāsāda": ['cped'],
    "uparipātra": ['mw'],
    "uparisad": ['mw'],
    "uparisadya": ['mw'],
    "uparispṛś": ['gra', 'mw'],
    "uparistha": ['mw'],
    "uparisthita": ['mw'],
    "uparisthāpana": ['mw'],
    "uparisthāyin": ['mw'],
    "uparitala": ['mw'],
    "uparitana": ['cae', 'mw'],
    "uparitas": ['mw'],
    "uparito": ['cped'],
    "uparivehāsakutī": ['cped'],
    "upariyāna": ['mw'],
    "upariśaya": ['mw'],
    "upariśayana": ['mw'],
    "upariśayyā": ['mw'],
    "upariśreṇika": ['mw'],
    "upariśāyin": ['mw'],
    "upariṣad": ['mw'],
    "upariṣadya": ['mw'],
    "upariṣṭa": ['bhs'],
    "upariṣṭha": ['ddsa', 'mw'],
    "upariṣṭima": ['bhs'],
    "upariṣṭā": ['bhs'],
    "upariṣṭād": ['mw'],
    "upariṣṭādbṛhatī": ['mw'],
    "upariṣṭāddhomabhāj": ['mw'],
    "upariṣṭādudarka": ['mw'],
    "upariṣṭādupayāma": ['mw'],
    "upariṣṭādvāta": ['mw'],
    "upariṣṭāj": ['mw'],
    "upariṣṭājjyotis": ['mw'],
    "upariṣṭājjyotiṣmatī": ['mw'],
    "upariṣṭāl": ['mw'],
    "upariṣṭāllakṣaṇa": ['mw'],
    "upariṣṭāllakṣman": ['mw'],
    "upariṣṭāt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "upariṣṭātkāla": ['mw'],
    "upariṣṭātsvāhākāra": ['mw'],
    "upariṣṭātsvāhākṛti": ['mw'],
    "uparodha": ['cae', 'ddsa', 'mw'],
    "uparodhaka": ['ap90', 'bhs', 'mw'],
    "uparodhakārin": ['mw'],
    "uparodham": ['mw'],
    "uparodhana": ['cped', 'mw'],
    "uparodhanaṃ": ['ap90'],
    "uparodhati": ['cped'],
    "uparodhaśīla": ['bhs'],
    "uparodhaḥ": ['ap90'],
    "uparodheti": ['cped'],
    "uparodhin": ['ap90', 'mw'],
    "uparopa": ['cped'],
    "uparuc": ['mw'],
    "uparuddha": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "uparuddhati": ['cped'],
    "uparudh": ['ap90', 'mw'],
    "uparudhya": ['mw'],
    "uparudita": ['ddsa', 'mw'],
    "uparuh": ['mw'],
    "uparujjhati": ['cped'],
    "uparundhati": ['cped'],
    "uparundhiya": ['cped'],
    "uparundhiṁ": ['cped'],
    "uparyāsana": ['mw'],
    "uparyāsīna": ['mw'],
    "uparādhaya": ['mw'],
    "uparāga": ['cae', 'ddsa', 'mw'],
    "uparāgavat": ['mw'],
    "uparāgaḥ": ['ap90'],
    "uparāja": ['mw'],
    "uparājam": ['mw'],
    "uparājaḥ": ['ap90'],
    "uparāma": ['mw'],
    "uparāmam": ['mw'],
    "uparāmaḥ": ['ap90'],
    "uparāva": ['mw'],
    "uparītaka": ['mw'],
    "uparītakaḥ": ['ap90'],
    "uparūpa": ['mw'],
    "uparūpaka": ['cae', 'ddsa', 'mw'],
    "uparūpakaṃ": ['ap90'],
    "uparūpari": ['cped'],
    "uparūḍha": ['cae', 'mw'],
    "upas": ['gra', 'mw'],
    "upasac": ['mw'],
    "upasad": ['ap90', 'cae', 'gra', 'mw'],
    "upasada": ['ap90', 'mw'],
    "upasadana": ['cae', 'ddsa', 'mw'],
    "upasadanaṃ": ['ap90'],
    "upasaddhoma": ['mw'],
    "upasadrūpa": ['mw'],
    "upasadvan": ['mw'],
    "upasadvrata": ['mw'],
    "upasadvratin": ['mw'],
    "upasadya": ['cae', 'gra', 'mw'],
    "upasadī": ['ap90', 'mw'],
    "upasagga": ['cped'],
    "upasakta": ['cae', 'mw'],
    "upasama": ['cped'],
    "upasamaddhiṭṭhāna": ['cped'],
    "upasamanvāhṛta": ['bhs'],
    "upasamas": ['mw'],
    "upasamasya": ['mw'],
    "upasamati": ['cped'],
    "upasamaś": ['mw'],
    "upasame": ['mw'],
    "upasami": ['mw'],
    "upasamidham": ['mw'],
    "upasamika": ['bhs'],
    "upasamindh": ['mw'],
    "upasamindhana": ['mw'],
    "upasamit": ['mw'],
    "upasammati": ['cped'],
    "upasampadā": ['cped'],
    "upasampajja": ['cped'],
    "upasampajjati": ['cped'],
    "upasampajjituṁ": ['cped'],
    "upasampanna": ['cped'],
    "upasampādayati": ['cped'],
    "upasampādenta": ['cped'],
    "upasampādesi": ['cped'],
    "upasampādesuṁ": ['cped'],
    "upasampādeta": ['cped'],
    "upasampādetabba": ['cped'],
    "upasampādetar": ['cped'],
    "upasampādeti": ['cped'],
    "upasampādetvā": ['cped'],
    "upasampādita": ['cped'],
    "upasamādhā": ['ap90', 'mw'],
    "upasamādhāna": ['mw'],
    "upasamādhānaṃ": ['ap90'],
    "upasamādhāya": ['mw'],
    "upasamāhita": ['mw'],
    "upasamāhārya": ['ap90', 'mw'],
    "upasamāhṛ": ['mw'],
    "upasamākṛ": ['mw'],
    "upasamāvṛt": ['mw'],
    "upasamūh": ['mw'],
    "upasamūhana": ['mw'],
    "upasandhyam": ['ddsa'],
    "upasanna": ['ap90', 'cae', 'mw'],
    "upasanta": ['cped'],
    "upasantapadissa": ['cped'],
    "upasapatni": ['ddsa', 'mw'],
    "upasara": ['ap90', 'mw'],
    "upasaraja": ['mw'],
    "upasaraṇa": ['cae', 'ddsa', 'mw'],
    "upasaraṇaṃ": ['ap90'],
    "upasarga": ['cae', 'ddsa', 'mw'],
    "upasargahārastotra": ['mw'],
    "upasargavāda": ['mw'],
    "upasargaya": ['mw'],
    "upasargaḥ": ['ap90'],
    "upasargin": ['bhs', 'mw'],
    "upasarjana": ['cae', 'mw'],
    "upasarjanaṃ": ['ap90'],
    "upasarjanī": ['mw'],
    "upasarjita": ['mw'],
    "upasarpa": ['mw'],
    "upasarpaḥ": ['ap90'],
    "upasarpaṇa": ['cae', 'ddsa', 'mw'],
    "upasarpaṇaṃ": ['ap90'],
    "upasarpaṇīya": ['cae'],
    "upasarpin": ['ap90', 'cae', 'mw'],
    "upasarpitaka": ['mw'],
    "upasartavya": ['mw'],
    "upasaryā": ['ap90', 'mw'],
    "upasat": ['mw'],
    "upasatpatha": ['mw'],
    "upasatti": ['mw'],
    "upasattiḥ": ['ap90'],
    "upasattva": ['mw'],
    "upasattṛ": ['cae', 'ddsa', 'mw'],
    "upasañj": ['mw'],
    "upasaṁharanta": ['cped'],
    "upasaṁharati": ['cped'],
    "upasaṁharitvā": ['cped'],
    "upasaṁhariṁsu": ['cped'],
    "upasaṁhasi": ['cped'],
    "upasaṁyāti": ['cped'],
    "upasaṃbaddha": ['mw'],
    "upasaṃbandh": ['mw'],
    "upasaṃbhid": ['mw'],
    "upasaṃbhāra": ['bhs'],
    "upasaṃbhāṣaḥ": ['ap90'],
    "upasaṃbhāṣā": ['mw'],
    "upasaṃbhṛ": ['mw'],
    "upasaṃbhṛta": ['mw'],
    "upasaṃcar": ['mw'],
    "upasaṃcāra": ['mw'],
    "upasaṃdarśayati": ['bhs'],
    "upasaṃdhyam": ['mw'],
    "upasaṃdhā": ['ap90', 'mw'],
    "upasaṃdhānaṃ": ['ap90'],
    "upasaṃdhāya": ['mw'],
    "upasaṃgam": ['mw'],
    "upasaṃgamana": ['mw'],
    "upasaṃgata": ['mw'],
    "upasaṃghāta": ['mw'],
    "upasaṃgrah": ['ap90', 'mw'],
    "upasaṃgraha": ['cae', 'mw'],
    "upasaṃgrahaḥ": ['ap90'],
    "upasaṃgrahaṇa": ['cae', 'mw'],
    "upasaṃgrāhya": ['ap90', 'cae', 'mw'],
    "upasaṃgṛhya": ['mw'],
    "upasaṃgṛhīta": ['mw'],
    "upasaṃharati": ['bhs'],
    "upasaṃharaṇa": ['bhs', 'mw'],
    "upasaṃharaṇaṃ": ['ap90'],
    "upasaṃhartavya": ['mw'],
    "upasaṃharṣī": ['bhs'],
    "upasaṃhata": ['bhs', 'mw'],
    "upasaṃhita": ['ap90', 'cae', 'mw'],
    "upasaṃhāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "upasaṃhāraprakaraṇa": ['mw'],
    "upasaṃhāraḥ": ['ap90'],
    "upasaṃhāraṇa": ['bhs'],
    "upasaṃhārin": ['ap90', 'mw'],
    "upasaṃhṛ": ['ap90', 'mw'],
    "upasaṃhṛta": ['mw'],
    "upasaṃhṛti": ['mw'],
    "upasaṃhṛtiḥ": ['ap90'],
    "upasaṃjan": ['mw'],
    "upasaṃjaneti": ['bhs'],
    "upasaṃjāta": ['mw'],
    "upasaṃkhyeya": ['mw'],
    "upasaṃkhyāna": ['cae', 'mw'],
    "upasaṃkhyānaṃ": ['ap90'],
    "upasaṃkram": ['mw'],
    "upasaṃkrama": ['bhs'],
    "upasaṃkramati": ['bhs'],
    "upasaṃkramaṇa": ['bhs', 'mw'],
    "upasaṃkrānta": ['mw'],
    "upasaṃkrānti": ['mw'],
    "upasaṃkrāṃta": ['ap90'],
    "upasaṃkḷp": ['mw'],
    "upasaṃkḷpta": ['mw'],
    "upasaṃkṣepa": ['mw'],
    "upasaṃkṣepaḥ": ['ap90'],
    "upasaṃnaddha": ['mw'],
    "upasaṃnah": ['mw'],
    "upasaṃnud": ['mw'],
    "upasaṃnyāsa": ['mw'],
    "upasaṃnyāsaḥ": ['ap90'],
    "upasaṃpad": ['ap90', 'bhs', 'mw'],
    "upasaṃpadā": ['mw'],
    "upasaṃpanna": ['ap90', 'bhs', 'cae', 'mw'],
    "upasaṃpannaka": ['bhs'],
    "upasaṃparāṇī": ['mw'],
    "upasaṃpatti": ['mw'],
    "upasaṃpattiḥ": ['ap90'],
    "upasaṃprach": ['mw'],
    "upasaṃprayā": ['mw'],
    "upasaṃprāp": ['mw'],
    "upasaṃprāpta": ['mw'],
    "upasaṃprāpya": ['mw'],
    "upasaṃpādana": ['bhs', 'mw'],
    "upasaṃpādayati": ['bhs'],
    "upasaṃroha": ['mw'],
    "upasaṃrohaḥ": ['ap90'],
    "upasaṃrudh": ['mw'],
    "upasaṃruh": ['mw'],
    "upasaṃskaraṇaṃ": ['ap90'],
    "upasaṃskāra": ['mw'],
    "upasaṃskṛ": ['ap90', 'mw'],
    "upasaṃskṛta": ['mw'],
    "upasaṃsthita": ['mw'],
    "upasaṃsthā": ['mw'],
    "upasaṃsṛ": ['mw'],
    "upasaṃsṛj": ['mw'],
    "upasaṃsṛp": ['mw'],
    "upasaṃsṛpya": ['mw'],
    "upasaṃsṛtya": ['mw'],
    "upasaṃsṛṣṭa": ['mw'],
    "upasaṃtan": ['mw'],
    "upasaṃtāna": ['mw'],
    "upasaṃtānaḥ": ['ap90'],
    "upasaṃvarayati": ['bhs'],
    "upasaṃviś": ['mw'],
    "upasaṃvraj": ['mw'],
    "upasaṃvye": ['mw'],
    "upasaṃvyāna": ['cae', 'ddsa', 'mw'],
    "upasaṃvyānaṃ": ['ap90'],
    "upasaṃvāda": ['mw'],
    "upasaṃvādaḥ": ['ap90'],
    "upasaṃvīta": ['mw'],
    "upasaṃyam": ['mw'],
    "upasaṃyama": ['mw'],
    "upasaṃyamana": ['mw'],
    "upasaṃyamanaṃ": ['ap90'],
    "upasaṃyamaḥ": ['ap90'],
    "upasaṃyata": ['mw'],
    "upasaṃyoga": ['mw'],
    "upasaṃyogaḥ": ['ap90'],
    "upasaṃyuj": ['mw'],
    "upasaṃyā": ['mw'],
    "upasaṃśasya": ['mw'],
    "upasaṃśaṃs": ['mw'],
    "upasaṃśliṣ": ['mw'],
    "upasaṃśliṣṭa": ['mw'],
    "upasaṃśliṣṭatva": ['mw'],
    "upasaṃśri": ['mw'],
    "upasaṅgamana": ['ddsa'],
    "upasaṅgayha": ['cped'],
    "upasaṅkama": ['cped'],
    "upasaṅkamana": ['cped'],
    "upasaṅkamanta": ['cped'],
    "upasaṅkamat": ['cped'],
    "upasaṅkamati": ['cped'],
    "upasaṅkami": ['cped'],
    "upasaṅkamita": ['cped'],
    "upasaṅkamitabba": ['cped'],
    "upasaṅkamitar": ['cped'],
    "upasaṅkamituṁ": ['cped'],
    "upasaṅkamitvā": ['cped'],
    "upasaṅkamiṁsu": ['cped'],
    "upasaṅkamma": ['cped'],
    "upasaṅkanta": ['cped'],
    "upasaṅkheyya": ['cped'],
    "upasaṅkhyāna": ['ddsa'],
    "upasaṅkrānti": ['ddsa'],
    "upasaṅkṣepa": ['ddsa'],
    "upasaṭṭha": ['cped'],
    "upasecana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "upasecanī": ['mw'],
    "upaseka": ['mw'],
    "upasektṛ": ['ap90', 'mw'],
    "upasena": ['bhs', 'mw'],
    "upasev": ['ap90', 'mw'],
    "upasevaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "upasevamāna": ['cped'],
    "upasevana": ['cae', 'mw'],
    "upasevanaṃ": ['ap90'],
    "upasevanā": ['cped'],
    "upasevati": ['cped'],
    "upasevin": ['ap90', 'cae', 'mw'],
    "upasevā": ['mw'],
    "upasi": ['ap90'],
    "upasic": ['mw'],
    "upasicya": ['mw'],
    "upasiddha": ['cae', 'mw'],
    "upasidh": ['mw'],
    "upasikta": ['mw'],
    "upasindhu": ['ddsa'],
    "upasiṃha": ['bhs'],
    "upasiṅghati": ['cped'],
    "upaskambh": ['mw'],
    "upaskara": ['cae', 'ddsa', 'mw'],
    "upaskaraḥ": ['ap90'],
    "upaskaraṇa": ['mw'],
    "upaskaraṇaṃ": ['ap90'],
    "upaskāra": ['mw'],
    "upaskāraḥ": ['ap90'],
    "upaskṛ": ['ap90', 'mw'],
    "upaskṛta": ['ap90', 'bhs', 'cae', 'mw'],
    "upaskṛti": ['mw'],
    "upaskṛtiḥ": ['ap90'],
    "upasmi": ['mw'],
    "upasmāram": ['mw'],
    "upasmṛ": ['mw'],
    "upasmṛti": ['mw'],
    "upasmṛtiḥ": ['ap90'],
    "upasneha": ['mw'],
    "upasnehayati": ['ap90'],
    "upasnehaḥ": ['ap90'],
    "upasnih": ['mw'],
    "upasnihiti": ['mw'],
    "upasnu": ['mw'],
    "upasnuta": ['mw'],
    "upasobhati": ['cped'],
    "upasobhayanta": ['cped'],
    "upasobhita": ['cped'],
    "upasoma": ['mw'],
    "upasomam": ['mw'],
    "upasparśa": ['cae', 'mw'],
    "upasparśana": ['ddsa', 'mw'],
    "upasparśaḥ": ['ap90'],
    "upasparśin": ['ap90', 'cae', 'mw'],
    "upaspij": ['gra'],
    "upaspijam": ['mw'],
    "upaspṛś": ['ap90', 'gra', 'mw'],
    "upaspṛśya": ['mw'],
    "upaspṛṣṭa": ['cae', 'mw'],
    "upasravaṇa": ['mw'],
    "upasravaṇaṃ": ['ap90'],
    "upasrotas": ['mw'],
    "upasru": ['mw'],
    "upassagga": ['cped'],
    "upassaya": ['cped'],
    "upassaṭṭha": ['cped'],
    "upassutiṁ": ['cped'],
    "upastabdha": ['bhs', 'mw'],
    "upastambh": ['mw'],
    "upastambha": ['cae', 'ddsa', 'mw'],
    "upastambhaka": ['mw'],
    "upastambhana": ['mw'],
    "upastara": ['mw'],
    "upastaraṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "upastaraṇaṃ": ['ap90'],
    "upastava": ['mw'],
    "upastaṃbh": ['ap90'],
    "upastaṃbhaka": ['ap90'],
    "upastaṃbhaḥ": ['ap90'],
    "upastha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "upasthadaghna": ['mw'],
    "upasthaka": ['mw'],
    "upasthakṛta": ['mw'],
    "upasthanigraha": ['mw'],
    "upasthapadā": ['mw'],
    "upasthapattra": ['mw'],
    "upasthapeti": ['bhs'],
    "upasthapāda": ['mw'],
    "upasthasad": ['gra', 'mw'],
    "upastheya": ['cae', 'mw'],
    "upasthita": ['ap90', 'cae', 'mw'],
    "upasthitapracupita": ['mw'],
    "upasthitasaṃprahāra": ['mw'],
    "upasthitavaktṛ": ['mw'],
    "upasthiti": ['mw'],
    "upasthitiḥ": ['ap90'],
    "upasthā": ['ap90', 'mw'],
    "upasthāka": ['bhs'],
    "upasthāna": ['cae', 'mw'],
    "upasthānagṛha": ['mw'],
    "upasthānakāri": ['bhs'],
    "upasthānasāhasrī": ['mw'],
    "upasthānaśālā": ['bhs', 'mw'],
    "upasthānaṃ": ['ap90'],
    "upasthānāni": ['bhs'],
    "upasthānīya": ['ap90', 'mw'],
    "upasthāpaka": ['ap90', 'bhs', 'mw'],
    "upasthāpana": ['bhs', 'mw'],
    "upasthāpanakasūtra": ['bhs'],
    "upasthāpanaṃ": ['ap90'],
    "upasthāpanā": ['mw'],
    "upasthāpayati": ['bhs'],
    "upasthāpayitavya": ['mw'],
    "upasthāpya": ['mw'],
    "upasthātavya": ['cae', 'mw'],
    "upasthātṛ": ['ap90', 'cae', 'mw'],
    "upasthāvan": ['mw'],
    "upasthāvara": ['mw'],
    "upasthāya": ['gra', 'mw'],
    "upasthāyaka": ['bhs', 'mw'],
    "upasthāyakaḥ": ['ap90'],
    "upasthāyam": ['mw'],
    "upasthāyika": ['mw'],
    "upasthāyin": ['ap90', 'mw'],
    "upasthāyuka": ['mw'],
    "upasthūṇa": ['bhs'],
    "upasthūṇam": ['mw'],
    "upasti": ['cae', 'ddsa', 'gra', 'mw'],
    "upastir": ['ap90', 'gra', 'mw'],
    "upastire": ['cae', 'ddsa'],
    "upastitaram": ['mw'],
    "upastiḥ": ['ap90'],
    "upastrī": ['ap90', 'mw'],
    "upastu": ['ap90', 'mw'],
    "upastut": ['ap90', 'cae', 'gra'],
    "upastuta": ['gra', 'mw'],
    "upastuti": ['cae', 'ddsa', 'gra', 'mw'],
    "upastutiḥ": ['ap90'],
    "upastutya": ['gra', 'mw'],
    "upastāra": ['mw'],
    "upastīrya": ['mw'],
    "upastīrṇa": ['cae', 'mw'],
    "upastṛ": ['ap90', 'mw'],
    "upasumbhati": ['cped'],
    "upasunda": ['ddsa', 'mw'],
    "upasuparṇam": ['mw'],
    "upasussati": ['cped'],
    "upasussayati": ['cped'],
    "upasuṃdaḥ": ['ap90'],
    "upasvatva": ['mw'],
    "upasvatvaṃ": ['ap90'],
    "upasveda": ['cae', 'mw'],
    "upasvedana": ['mw'],
    "upasvedaḥ": ['ap90'],
    "upasvid": ['mw'],
    "upasvāvat": ['mw'],
    "upasvṛ": ['mw'],
    "upasādana": ['mw'],
    "upasādh": ['mw'],
    "upasādhaka": ['mw'],
    "upasādita": ['mw'],
    "upasādya": ['mw'],
    "upasāgara": ['bhs'],
    "upasāgaram": ['mw'],
    "upasāmayati": ['cped'],
    "upasāntvana": ['ddsa', 'mw'],
    "upasāntvaya": ['mw'],
    "upasāntvita": ['mw'],
    "upasāntvya": ['mw'],
    "upasārya": ['mw'],
    "upasāṃtv": ['ap90'],
    "upasāṃtvanaṃ": ['ap90'],
    "upasīma": ['mw'],
    "upasīram": ['mw'],
    "upasīraḥ": ['ap90'],
    "upasūc": ['mw'],
    "upasūcaka": ['mw'],
    "upasūcita": ['mw'],
    "upasūryaka": ['mw'],
    "upasūryakaṃ": ['ap90'],
    "upasūtikā": ['mw'],
    "upasṛ": ['ap90', 'mw'],
    "upasṛj": ['ap90', 'mw'],
    "upasṛjya": ['mw'],
    "upasṛp": ['ap90', 'mw'],
    "upasṛpta": ['mw'],
    "upasṛpya": ['mw'],
    "upasṛta": ['mw'],
    "upasṛtavat": ['mw'],
    "upasṛtya": ['mw'],
    "upasṛṣṭa": ['ap90', 'bhs', 'cae', 'mw'],
    "upataila": ['mw'],
    "upataiṣa": ['mw'],
    "upatakṣa": ['mw'],
    "upatakṣaka": ['mw'],
    "upatalpam": ['ddsa', 'mw'],
    "upatalpya": ['mw'],
    "upatap": ['ap90', 'mw'],
    "upatapana": ['ap90', 'mw'],
    "upatapat": ['ap90', 'mw'],
    "upatapta": ['ap90', 'cae', 'mw'],
    "upataptṛ": ['ap90', 'mw'],
    "upatarati": ['bhs'],
    "upataṭam": ['cae', 'ddsa', 'mw'],
    "upataṭaḥ": ['ap90'],
    "upatiṣya": ['bhs', 'mw'],
    "upatiṣyaṃ": ['ap90'],
    "upatiṣṭhāsu": ['ddsa', 'mw'],
    "upatiṭṭhanta": ['cped'],
    "upatiṭṭhati": ['cped'],
    "upatiṭṭhitvā": ['cped'],
    "upatoṣya": ['mw'],
    "upatriṃśa": ['mw'],
    "upatsar": ['mw'],
    "upatsarya": ['mw'],
    "upatthaddha": ['cped'],
    "upatuṣ": ['mw'],
    "upatya": ['ap90'],
    "upatyakā": ['ap90', 'cae', 'ddsa', 'mw'],
    "upatāpa": ['cae', 'ddsa', 'mw'],
    "upatāpaka": ['ap90', 'cae', 'mw'],
    "upatāpana": ['mw'],
    "upatāpanaṃ": ['ap90'],
    "upatāpaḥ": ['ap90'],
    "upatāpin": ['ap90', 'cae', 'mw'],
    "upatāraka": ['ap90', 'mw'],
    "upatīram": ['mw'],
    "upatīrtha": ['mw'],
    "upatūlam": ['mw'],
    "upatṛd": ['mw'],
    "upatṛṇya": ['mw'],
    "upatṛṇyaḥ": ['ap90'],
    "upavac": ['mw'],
    "upavad": ['ap90', 'mw'],
    "upavadamāna": ['cped'],
    "upavadati": ['bhs', 'cped'],
    "upavadh": ['mw'],
    "upavadita": ['cped'],
    "upavah": ['ap90', 'mw'],
    "upavaha": ['mw'],
    "upavahanaṃ": ['ap90'],
    "upavahas": ['mw'],
    "upavahaṃ": ['ap90'],
    "upavai": ['mw'],
    "upavaiṇava": ['mw'],
    "upavaiṇavaṃ": ['ap90'],
    "upavajja": ['cped'],
    "upavajjakula": ['cped'],
    "upavaktṛ": ['ap90', 'cae', 'gra', 'mw'],
    "upavalgita": ['ap90'],
    "upavalh": ['mw'],
    "upavalha": ['mw'],
    "upavalhaḥ": ['ap90'],
    "upavallikā": ['ap90', 'mw'],
    "upavan": ['mw'],
    "upavana": ['cae', 'ddsa', 'mw'],
    "upavanam": ['ddsa', 'mw'],
    "upavanavinoda": ['mw'],
    "upavanaṃ": ['ap90'],
    "upavap": ['mw'],
    "upavapana": ['mw'],
    "upavarga": ['bhs'],
    "upavarha": ['mw'],
    "upavarta": ['bhs', 'mw'],
    "upavartana": ['bhs', 'mw'],
    "upavartanaṃ": ['ap90'],
    "upavartaḥ": ['ap90'],
    "upavarṇ": ['ap90', 'mw'],
    "upavarṇa": ['mw'],
    "upavarṇana": ['ddsa', 'mw'],
    "upavarṇanaṃ": ['ap90'],
    "upavarṇanīya": ['mw'],
    "upavarṇaḥ": ['ap90'],
    "upavarṇita": ['mw'],
    "upavarṣa": ['ddsa', 'mw'],
    "upavarṣaḥ": ['ap90'],
    "upavarṣita": ['bhs'],
    "upavas": ['ap90', 'mw'],
    "upavasana": ['mw'],
    "upavasanīya": ['mw'],
    "upavasatha": ['cae', 'ddsa', 'mw'],
    "upavasathaḥ": ['ap90'],
    "upavasathya": ['mw'],
    "upavasathīya": ['ap90', 'mw'],
    "upavasati": ['cped'],
    "upavasitvā": ['cped'],
    "upavassa": ['cped'],
    "upavassaṁ": ['cped'],
    "upavasta": ['mw'],
    "upavastavya": ['mw'],
    "upavastaṃ": ['ap90'],
    "upavasti": ['mw'],
    "upavastiḥ": ['ap90'],
    "upavastra": ['mw'],
    "upavastrādi": ['mw'],
    "upavastṛ": ['ap90', 'mw'],
    "upavat": ['mw'],
    "upavatsati": ['bhs'],
    "upavatsyadbhakta": ['mw'],
    "upavatsyat": ['mw'],
    "upavattati": ['cped'],
    "upavatī": ['mw'],
    "upavañc": ['mw'],
    "upavañcana": ['gra', 'mw'],
    "upavañcita": ['mw'],
    "upavaṅga": ['mw'],
    "upavaṭa": ['mw'],
    "upavaṭaḥ": ['ap90'],
    "upave": ['mw'],
    "upaveda": ['ap90', 'mw'],
    "upavedana": ['mw'],
    "upavedanīya": ['mw'],
    "upavedaḥ": ['ap90'],
    "upavedi": ['mw'],
    "upaveśa": ['cae', 'mw'],
    "upaveśana": ['cae', 'ddsa', 'mw'],
    "upaveśaḥ": ['ap90'],
    "upaveśi": ['mw'],
    "upaveśin": ['ap90', 'mw'],
    "upaveśita": ['mw'],
    "upaveśya": ['ddsa'],
    "upaveṇu": ['mw'],
    "upaveṇā": ['mw'],
    "upaveṣa": ['mw'],
    "upaveṣaḥ": ['ap90'],
    "upaveṣṭ": ['mw'],
    "upaveṣṭana": ['mw'],
    "upaveṣṭita": ['mw'],
    "upaveṣṭitin": ['mw'],
    "upaveṣṭṛ": ['ap90'],
    "upavhayanta": ['cped'],
    "upavhayati": ['cped'],
    "upavicarati": ['bhs', 'cped'],
    "upavicinoti": ['bhs'],
    "upavicāra": ['bhs', 'cped', 'mw'],
    "upavicārayati": ['bhs'],
    "upavid": ['ap90', 'gra', 'mw'],
    "upavidh": ['mw'],
    "upavidyā": ['ap90', 'mw'],
    "upavigulph": ['mw'],
    "upavijañña": ['cped'],
    "upavimokam": ['mw'],
    "upavindhya": ['mw'],
    "upavindhyādrā": ['mw'],
    "upavindu": ['mw'],
    "upavipāśam": ['mw'],
    "upavisiṁ": ['cped'],
    "upavistīrṇa": ['bhs'],
    "upavitarka": ['bhs'],
    "upaviś": ['ap90', 'mw'],
    "upaviśeṣa": ['bhs'],
    "upaviśrambh": ['mw'],
    "upaviśrambhayya": ['mw'],
    "upaviśya": ['mw'],
    "upaviṃśa": ['mw'],
    "upaviṣ": ['mw'],
    "upaviṣa": ['mw'],
    "upaviṣaḥ": ['ap90'],
    "upaviṣā": ['mw'],
    "upaviṣṭa": ['cae', 'ddsa', 'mw'],
    "upaviṣṭaka": ['mw'],
    "upaviṣṭhā": ['mw'],
    "upaviṭṭha": ['cped'],
    "upavlaya": ['mw'],
    "upavraj": ['mw'],
    "upavrajam": ['mw'],
    "upavrajya": ['mw'],
    "upavrata": ['mw'],
    "upavrataya": ['mw'],
    "upavusta": ['bhs'],
    "upavuttha": ['cped'],
    "upavutthuposatha": ['cped'],
    "upavyadh": ['mw'],
    "upavye": ['mw'],
    "upavyuṣam": ['mw'],
    "upavyuṣasam": ['mw'],
    "upavyāghra": ['mw'],
    "upavyāghraḥ": ['ap90'],
    "upavyākhyāna": ['mw'],
    "upavyākhyānaṃ": ['ap90'],
    "upavā": ['ap90', 'mw'],
    "upavācia": ['gra'],
    "upavācya": ['gra', 'mw'],
    "upavāda": ['cped', 'mw'],
    "upavādaka": ['cped'],
    "upavādaḥ": ['ap90'],
    "upavādin": ['ap90', 'mw'],
    "upavāha": ['mw'],
    "upavāhana": ['mw'],
    "upavāhanaṃ": ['ap90'],
    "upavāhin": ['ap90', 'mw'],
    "upavāhya": ['ddsa', 'mw'],
    "upavāhyaḥ": ['ap90'],
    "upavājana": ['mw'],
    "upavājanaṃ": ['ap90'],
    "upavājaya": ['mw'],
    "upavāka": ['gra', 'mw'],
    "upavākaḥ": ['ap90'],
    "upavākia": ['gra'],
    "upavākya": ['gra', 'mw'],
    "upavāsa": ['cae', 'cped', 'ddsa', 'mw'],
    "upavāsaka": ['ap90', 'bhs', 'mw'],
    "upavāsana": ['mw'],
    "upavāsanaṃ": ['ap90'],
    "upavāsavratin": ['mw'],
    "upavāsaḥ": ['ap90'],
    "upavāsin": ['ap90', 'cae', 'mw'],
    "upavāsita": ['bhs'],
    "upavāta": ['mw'],
    "upavāya": ['mw'],
    "upavāyanta": ['cped'],
    "upavāyati": ['bhs', 'cped'],
    "upavī": ['mw'],
    "upavīj": ['mw'],
    "upavījita": ['mw'],
    "upavīkṣ": ['mw'],
    "upavīra": ['mw'],
    "upavīraṃ": ['ap90'],
    "upavīta": ['cae', 'ddsa', 'mw'],
    "upavītaka": ['mw'],
    "upavītaṃ": ['ap90'],
    "upavītin": ['ap90', 'cae', 'mw'],
    "upavīya": ['mw'],
    "upavīṇa": ['cped'],
    "upavīṇaya": ['ddsa', 'mw'],
    "upavīṇayati": ['ap90'],
    "upavṛt": ['ap90', 'mw'],
    "upavṛtta": ['mw'],
    "upavṛtti": ['mw'],
    "upavṛttiḥ": ['ap90'],
    "upavṛṃh": ['mw'],
    "upavṛṃha": ['ap90'],
    "upavṛṃhaṇa": ['mw'],
    "upavṛṃhin": ['mw'],
    "upavṛṃhita": ['mw'],
    "upaya": ['cped'],
    "upayaj": ['ap90', 'mw'],
    "upayam": ['ap90', 'mw'],
    "upayama": ['cae', 'mw'],
    "upayamana": ['cae', 'mw'],
    "upayamanaṃ": ['ap90'],
    "upayamanī": ['mw'],
    "upayamaḥ": ['ap90'],
    "upayanta": ['cped'],
    "upayantr": ['mw'],
    "upayantra": ['mw'],
    "upayantrita": ['mw'],
    "upayantṛ": ['cae', 'ddsa', 'mw'],
    "upayat": ['mw'],
    "upayaṃtraṃ": ['ap90'],
    "upayaṃtṛ": ['ap90'],
    "upayaṣṭṛ": ['ap90', 'mw'],
    "upayika": ['bhs'],
    "upayoga": ['cae', 'ddsa', 'mw'],
    "upayogaḥ": ['ap90'],
    "upayogika": ['bhs'],
    "upayogin": ['ap90', 'cae', 'mw'],
    "upayogitva": ['mw'],
    "upayogitā": ['ap90', 'mw'],
    "upayogya": ['mw'],
    "upayojana": ['mw'],
    "upayojanaṃ": ['ap90'],
    "upayojya": ['cae', 'ddsa', 'mw'],
    "upayoktavya": ['cae', 'ddsa', 'mw'],
    "upayoktṛ": ['mw'],
    "upayoṣam": ['mw'],
    "upayuj": ['ap90', 'mw'],
    "upayukta": ['ap90', 'cae', 'mw'],
    "upayupādāna": ['cped'],
    "upayuta": ['mw'],
    "upayuyukṣu": ['mw'],
    "upayā": ['ap90', 'mw'],
    "upayāc": ['ap90', 'mw'],
    "upayācaka": ['ap90', 'mw'],
    "upayācana": ['ddsa', 'mw'],
    "upayācanaṃ": ['ap90'],
    "upayācita": ['ap90', 'mw'],
    "upayācitaka": ['mw'],
    "upayācitakaṃ": ['ap90'],
    "upayāja": ['mw'],
    "upayājaḥ": ['ap90'],
    "upayāma": ['mw'],
    "upayāmavat": ['mw'],
    "upayāmaḥ": ['ap90'],
    "upayāmin": ['mw'],
    "upayāna": ['cae', 'cped', 'ddsa', 'mw'],
    "upayānaṃ": ['ap90'],
    "upayāpana": ['mw'],
    "upayāpetabba": ['cped'],
    "upayāpeti": ['cped'],
    "upayāsi": ['cped'],
    "upayāta": ['ap90', 'mw'],
    "upayāti": ['cped'],
    "upayāyin": ['ap90', 'ddsa', 'mw'],
    "upayūpādāna": ['cped'],
    "upaññassaṁ": ['cped'],
    "upaññissaṁ": ['cped'],
    "upaññāsiṁ": ['cped'],
    "upaññāta": ['cped'],
    "upaññātta": ['cped'],
    "upaśada": ['mw'],
    "upaśaila": ['mw'],
    "upaśak": ['mw'],
    "upaśalya": ['ddsa', 'mw'],
    "upaśalyaka": ['mw'],
    "upaśalyaṃ": ['ap90'],
    "upaśam": ['ap90', 'mw'],
    "upaśama": ['cae', 'ddsa', 'mw'],
    "upaśamaka": ['ap90'],
    "upaśamakṣaya": ['mw'],
    "upaśamana": ['cae', 'mw'],
    "upaśamanaṃ": ['ap90'],
    "upaśamanīya": ['mw'],
    "upaśamavant": ['bhs'],
    "upaśamavat": ['mw'],
    "upaśamaśīla": ['mw'],
    "upaśamaḥ": ['ap90'],
    "upaśamika": ['bhs'],
    "upaśamāyana": ['mw'],
    "upaśapha": ['mw'],
    "upaśaradam": ['mw'],
    "upaśaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "upaśayana": ['bhs'],
    "upaśayastha": ['mw'],
    "upaśayatva": ['mw'],
    "upaśayā": ['mw'],
    "upaśaṅk": ['mw'],
    "upaścyut": ['mw'],
    "upaśikṣana": ['mw'],
    "upaśikṣita": ['mw'],
    "upaśikṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "upaśiras": ['mw'],
    "upaśiva": ['mw'],
    "upaśiṃghanaṃ": ['ap90'],
    "upaśiṃhanaṃ": ['ap90'],
    "upaśiṅgh": ['mw'],
    "upaśiṅghana": ['mw'],
    "upaśiṣya": ['mw'],
    "upaśiṣyaḥ": ['ap90'],
    "upaśiṣṭa": ['bhs'],
    "upaśleṣa": ['ddsa', 'mw'],
    "upaśleṣaḥ": ['ap90'],
    "upaśleṣaṇa": ['mw'],
    "upaśliṣ": ['ap90', 'mw'],
    "upaśliṣṭa": ['ap90', 'cae', 'mw'],
    "upaśloka": ['mw'],
    "upaślokaya": ['mw'],
    "upaślokayati": ['ap90'],
    "upaślokayitavya": ['ddsa'],
    "upaślāghā": ['mw'],
    "upaśobhana": ['cae', 'ddsa', 'mw'],
    "upaśobhanaṃ": ['ap90'],
    "upaśobhikā": ['mw'],
    "upaśobhin": ['cae', 'mw'],
    "upaśobhita": ['mw'],
    "upaśobhā": ['cae', 'mw'],
    "upaśoṣa": ['mw'],
    "upaśoṣaṇa": ['mw'],
    "upaśoṣaṇaṃ": ['ap90'],
    "upaśoṣita": ['mw'],
    "upaśram": ['mw'],
    "upaśrambhayati": ['bhs'],
    "upaśrava": ['bhs'],
    "upaśri": ['mw'],
    "upaśrita": ['mw'],
    "upaśrotṛ": ['ap90', 'gra', 'mw'],
    "upaśru": ['ap90', 'mw'],
    "upaśrut": ['ap90'],
    "upaśruta": ['ap90', 'mw'],
    "upaśruti": ['gra', 'mw'],
    "upaśrutika": ['bhs'],
    "upaśrutiḥ": ['ap90'],
    "upaśrutya": ['mw'],
    "upaśrī": ['ap90', 'mw'],
    "upaśubh": ['ap90', 'mw'],
    "upaśuklaka": ['bhs'],
    "upaśunam": ['mw'],
    "upaśuṣ": ['mw'],
    "upaśuṣka": ['mw'],
    "upaśvas": ['mw'],
    "upaśvasa": ['ap90', 'mw'],
    "upaśāka": ['gra', 'mw'],
    "upaśākhā": ['ap90', 'mw'],
    "upaśāla": ['mw'],
    "upaśālam": ['mw'],
    "upaśālaṃ": ['ap90'],
    "upaśāmaka": ['mw'],
    "upaśānta": ['bhs', 'cae', 'mw'],
    "upaśāntavaira": ['mw'],
    "upaśānti": ['cae', 'ddsa', 'mw'],
    "upaśāntin": ['mw'],
    "upaśāntv": ['mw'],
    "upaśāntā": ['bhs'],
    "upaśāntātman": ['mw'],
    "upaśāstra": ['mw'],
    "upaśāstraṃ": ['ap90'],
    "upaśāya": ['mw'],
    "upaśāyaka": ['mw'],
    "upaśāyaḥ": ['ap90'],
    "upaśāyin": ['ap90', 'ddsa', 'mw'],
    "upaśāyitva": ['mw'],
    "upaśāyitā": ['mw'],
    "upaśāṃta": ['ap90'],
    "upaśāṃtin": ['ap90'],
    "upaśāṃtiḥ": ['ap90'],
    "upaśāṃtvanaṃ": ['ap90'],
    "upaśī": ['ap90', 'mw'],
    "upaśīrṣaka": ['mw'],
    "upaśīvan": ['mw'],
    "upaḍa": ['mw'],
    "upaḍhauk": ['ap90', 'mw'],
    "upaḍhaukana": ['mw'],
    "upaḍhaukanaṃ": ['ap90'],
    "upaḍhaukita": ['mw'],
    "upaḍḍha": ['cped'],
    "upaḍḍhullikhita": ['cped'],
    "upaḷāsetvā": ['cped'],
    "upaḷāsitvā": ['cped'],
    "upaṛ": ['mw'],
    "upaṣṭambha": ['ddsa', 'mw'],
    "upaṣṭut": ['ap90', 'gra', 'mw'],
    "upaṭṭhahanta": ['cped'],
    "upaṭṭhahati": ['cped'],
    "upaṭṭhaheti": ['cped'],
    "upaṭṭhahiyamāna": ['cped'],
    "upaṭṭhahiṁ": ['cped'],
    "upaṭṭhahiṁsū": ['cped'],
    "upaṭṭhapana": ['cped'],
    "upaṭṭhapayati": ['cped'],
    "upaṭṭhapeti": ['cped'],
    "upaṭṭhenta": ['cped'],
    "upaṭṭheti": ['cped'],
    "upaṭṭhita": ['cped'],
    "upaṭṭhābba": ['cped'],
    "upaṭṭhāka": ['cped'],
    "upaṭṭhāna": ['cped'],
    "upaṭṭhānasālā": ['cped'],
    "upaṭṭhāpana": ['cped'],
    "upaṭṭhāpaya": ['cped'],
    "upaṭṭhāpayat": ['cped'],
    "upaṭṭhāpayati": ['cped'],
    "upaṭṭhāpesi": ['cped'],
    "upaṭṭhāpeta": ['cped'],
    "upaṭṭhāpetabba": ['cped'],
    "upaṭṭhāpetar": ['cped'],
    "upaṭṭhāpeti": ['cped'],
    "upaṭṭhāpetvā": ['cped'],
    "upaṭṭhāpetvāna": ['cped'],
    "upaṭṭhāpittha": ['cped'],
    "upaṭṭhāsi": ['cped'],
    "upaṭṭhāsiṁ": ['cped'],
    "upaṭṭhāti": ['cped'],
    "upaṭṭhātuṁ": ['cped'],
    "upe": ['ap90', 'mw'],
    "upecca": ['cped'],
    "upekkha": ['cped'],
    "upekkhaka": ['cped'],
    "upekkhati": ['cped'],
    "upekkhindriya": ['cped'],
    "upekkhā": ['cped'],
    "upekkhāsahagata": ['cped'],
    "upekṣ": ['ap90', 'mw'],
    "upekṣa": ['mw'],
    "upekṣaka": ['ap90', 'ddsa', 'mw'],
    "upekṣate": ['bhs'],
    "upekṣaṇa": ['cae', 'mw'],
    "upekṣaṇaṃ": ['ap90'],
    "upekṣaṇīya": ['mw'],
    "upekṣita": ['mw'],
    "upekṣitavya": ['mw'],
    "upekṣya": ['mw'],
    "upekṣā": ['ap90', 'bhs', 'mw'],
    "upen": ['mw'],
    "upendhya": ['mw'],
    "upendra": ['bhs', 'cae', 'ddsa', 'mw'],
    "upendrabala": ['mw'],
    "upendradatta": ['mw'],
    "upendragupta": ['mw'],
    "upendravajrā": ['cae', 'mw'],
    "upendraśakti": ['mw'],
    "upendrā": ['mw'],
    "upenita": ['ap90', 'cae', 'mw'],
    "upenta": ['cped'],
    "upepsā": ['mw'],
    "upessaṁ": ['cped'],
    "upeta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "upetabba": ['cped'],
    "upetapūrva": ['cae', 'mw'],
    "upetavya": ['mw'],
    "upeti": ['cae', 'cped', 'gra', 'mw'],
    "upetiḥ": ['ap90'],
    "upetya": ['mw'],
    "upetṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "upeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "upeyivas": ['ddsa', 'mw'],
    "upeḍakīya": ['mw'],
    "upeṃdraḥ": ['ap90'],
    "upeṣ": ['mw'],
    "upeṣat": ['mw'],
    "upika": ['mw'],
    "upila": ['mw'],
    "upita": ['mw'],
    "upiya": ['mw'],
    "uplavati": ['cped'],
    "upod": ['mw'],
    "upodaka": ['ap90', 'ddsa', 'mw'],
    "upodayam": ['mw'],
    "upodbala": ['bhs'],
    "upodbalaka": ['ap90', 'ddsa', 'mw'],
    "upodbalana": ['mw'],
    "upodbalanaṃ": ['ap90'],
    "upodbalaya": ['mw'],
    "upodbalayati": ['ap90'],
    "upodbalita": ['mw'],
    "upoddhan": ['mw'],
    "upodghāta": ['cae', 'ddsa', 'mw'],
    "upodghātapāda": ['mw'],
    "upodghātaḥ": ['ap90'],
    "upodgrah": ['mw'],
    "upodgrahaḥ": ['ap90'],
    "upodgṛhya": ['mw'],
    "upodi": ['mw'],
    "upodita": ['mw'],
    "upoditi": ['mw'],
    "upodyam": ['mw'],
    "upodāhṛ": ['mw'],
    "upodāsṛp": ['mw'],
    "upodāsṛpta": ['mw'],
    "upodīkā": ['mw'],
    "upoh": ['ap90', 'mw'],
    "upoha": ['mw'],
    "upohaḥ": ['ap90'],
    "upohya": ['mw'],
    "upoktavatī": ['mw'],
    "upokṣ": ['mw'],
    "upolapa": ['mw'],
    "upolava": ['mw'],
    "upondana": ['mw'],
    "uponnī": ['mw'],
    "upopadhā": ['mw'],
    "upopaparāmṛś": ['mw'],
    "upopaviś": ['mw'],
    "upopayā": ['mw'],
    "upopayāta": ['mw'],
    "uposatha": ['cped'],
    "uposathagga": ['cped'],
    "uposathagāra": ['cped'],
    "uposathakamma": ['cped'],
    "uposathapamukha": ['cped'],
    "uposathappamukha": ['cped'],
    "uposathapucchaka": ['cped'],
    "uposathaṅga": ['cped'],
    "uposathika": ['cped'],
    "uposathūpavāsa": ['cped'],
    "upota": ['mw'],
    "upotkram": ['mw'],
    "upotsad": ['mw'],
    "upotsic": ['mw'],
    "upotta": ['mw'],
    "upottama": ['ap90', 'cae', 'mw'],
    "upottara": ['mw'],
    "upotthita": ['mw'],
    "upotthā": ['mw'],
    "upotthāya": ['mw'],
    "upotī": ['ap90', 'mw'],
    "upoḍha": ['ap90', 'cae', 'ddsa', 'mw'],
    "upoḍharāga": ['cae'],
    "upoḍhatapas": ['cae'],
    "upoḍhaśabda": ['cae'],
    "upoḍhā": ['mw'],
    "upoṣ": ['mw'],
    "upoṣadha": ['bhs', 'mw'],
    "upoṣadhika": ['bhs'],
    "upoṣatha": ['bhs'],
    "upoṣati": ['bhs'],
    "upoṣaya": ['mw'],
    "upoṣaṇa": ['cae', 'ddsa', 'mw'],
    "upoṣaṇaṃ": ['ap90'],
    "upoṣaṇīya": ['bhs'],
    "upoṣaṇīyaprabha": ['mw'],
    "upoṣita": ['cae', 'ddsa', 'mw'],
    "upoṣya": ['mw'],
    "uppacca": ['cped'],
    "uppajjamāna": ['cped'],
    "uppajjati": ['cped'],
    "uppajji": ['cped'],
    "uppajjitvā": ['cped'],
    "uppajjiyati": ['cped'],
    "uppakka": ['cped'],
    "uppala": ['cped'],
    "uppalagandhapaccatthika": ['cped'],
    "uppalaka": ['bhs', 'cped'],
    "uppalasikharopama": ['cped'],
    "uppalavati": ['cped'],
    "uppalinī": ['cped'],
    "uppanna": ['cped'],
    "uppata": ['cped'],
    "uppatanta": ['cped'],
    "uppatat": ['cped'],
    "uppatati": ['cped'],
    "uppatha": ['cped'],
    "uppatita": ['cped'],
    "uppatitvā": ['cped'],
    "uppatti": ['cped'],
    "uppaṇḍesuṁ": ['cped'],
    "uppaṇḍeti": ['cped'],
    "uppaṇḍita": ['cped'],
    "uppaṇḍiyamāna": ['cped'],
    "uppaṇḍu": ['cped'],
    "uppaṇḍuppaṇḍukajāta": ['cped'],
    "uppaṭipāṭikasutta": ['cped'],
    "uppharitvā": ['bhs'],
    "upphāletvā": ['cped'],
    "uppilavati": ['cped'],
    "uppilāvitatta": ['cped'],
    "upplavati": ['cped'],
    "uppāda": ['cped'],
    "uppādaya": ['cped'],
    "uppādayat": ['cped'],
    "uppādayati": ['cped'],
    "uppādesi": ['cped'],
    "uppādeta": ['cped'],
    "uppādetabba": ['cped'],
    "uppādetar": ['cped'],
    "uppādeti": ['cped'],
    "uppādetvā": ['cped'],
    "uppādita": ['cped'],
    "uppāta": ['cped'],
    "uppāṭaka": ['cped'],
    "uppāṭesi": ['cped'],
    "uppāṭetvā": ['cped'],
    "uppāṭiya": ['cped'],
    "upratyaya": ['ddsa'],
    "upta": ['ap90', 'cae', 'ddsa', 'mw'],
    "uptagāḍha": ['mw'],
    "uptakeśa": ['mw'],
    "uptakeśaśmaśru": ['mw'],
    "uptakṛṣṭa": ['mw'],
    "upti": ['cae', 'mw'],
    "uptivid": ['cae', 'mw'],
    "uptrima": ['mw'],
    "upya": ['mw'],
    "upā": ['mw'],
    "upābhigada": ['mw'],
    "upābhūṣ": ['mw'],
    "upābhṛt": ['ap90'],
    "upābhṛti": ['gra', 'mw'],
    "upācar": ['ap90', 'mw'],
    "upācarita": ['ap90', 'mw'],
    "upācikīrṣu": ['mw'],
    "upācyutam": ['mw'],
    "upācāra": ['mw'],
    "upācāraḥ": ['ap90'],
    "upācīrṇa": ['mw'],
    "upādahati": ['cped'],
    "upādaheti": ['cped'],
    "upādeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "upādeyatva": ['mw'],
    "upādhi": ['cae', 'ddsa', 'mw'],
    "upādhidūṣakatābīja": ['mw'],
    "upādhika": ['ap90', 'mw'],
    "upādhikhaṇḍana": ['mw'],
    "upādhimātrāyām": ['mw'],
    "upādhinyāyasaṃgraha": ['mw'],
    "upādhiruh": ['mw'],
    "upādhisiddhāntagrantha": ['mw'],
    "upādhitas": ['mw'],
    "upādhivivṛti": ['mw'],
    "upādhiḥ": ['ap90'],
    "upādhmā": ['mw'],
    "upādhu": ['bhs'],
    "upādhvaryu": ['mw'],
    "upādhyāya": ['cae', 'ddsa', 'mw'],
    "upādhyāyarājan": ['bhs'],
    "upādhyāyasarvasva": ['mw'],
    "upādhyāyaḥ": ['ap90'],
    "upādhyāyikā": ['bhs'],
    "upādhyāyānī": ['ap90', 'mw'],
    "upādhyāyī": ['mw'],
    "upādhyāyīkṛ": ['mw'],
    "upādhā": ['ap90', 'mw'],
    "upādhāna": ['bhs'],
    "upādhāv": ['mw'],
    "upādhāya": ['cae', 'mw'],
    "upādhāyyapūrvaya": ['mw'],
    "upādi": ['bhs'],
    "upādika": ['mw'],
    "upādikaḥ": ['ap90'],
    "upādinna": ['cped'],
    "upādisesa": ['cped'],
    "upāditsā": ['mw'],
    "upādiya": ['cped'],
    "upādiyamāna": ['cped'],
    "upādiyat": ['cped'],
    "upādiyati": ['bhs', 'cped'],
    "upādiyitvā": ['cped'],
    "upādiyiṁ": ['cped'],
    "upādiś": ['mw'],
    "upādiṇṇa": ['cped'],
    "upādru": ['mw'],
    "upādu": ['bhs'],
    "upādya": ['mw'],
    "upādā": ['ap90', 'mw'],
    "upādāna": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "upādānakkhandha": ['cped'],
    "upādānakāraṇa": ['mw'],
    "upādānalakṣaṇā": ['mw'],
    "upādānatva": ['mw'],
    "upādānatā": ['mw'],
    "upādānaṃ": ['ap90'],
    "upādāniya": ['cped'],
    "upādātar": ['bhs'],
    "upādāya": ['bhs', 'cae', 'cped', 'mw'],
    "upādāyarūpa": ['bhs'],
    "upādīp": ['mw'],
    "upādīpta": ['mw'],
    "upāgacchiṁ": ['cped'],
    "upāgam": ['ap90', 'mw'],
    "upāgama": ['bhs', 'mw'],
    "upāgamaḥ": ['ap90'],
    "upāgamaṁ": ['cped'],
    "upāgami": ['cped'],
    "upāgamiṁ": ['cped'],
    "upāgamma": ['cped'],
    "upāgamuṁ": ['cped'],
    "upāgamya": ['mw'],
    "upāgata": ['ap90', 'cped', 'mw'],
    "upāgatya": ['mw'],
    "upāgañchiṁ": ['cped'],
    "upāghrā": ['mw'],
    "upāgni": ['mw'],
    "upāgnikā": ['mw'],
    "upāgra": ['mw'],
    "upāgrah": ['mw'],
    "upāgrahaṇa": ['mw'],
    "upāgrahaṇaṃ": ['ap90'],
    "upāgrahāyaṇam": ['mw'],
    "upāgrahāyaṇi": ['mw'],
    "upāgraṃ": ['ap90'],
    "upāgrya": ['mw'],
    "upāgā": ['cped', 'mw'],
    "upāgṛhya": ['mw'],
    "upāhan": ['mw'],
    "upāhanaka": ['bhs'],
    "upāhanapappoṭhanasadda": ['cped'],
    "upāhanā": ['cped'],
    "upāhita": ['ap90', 'cae', 'ddsa', 'mw'],
    "upāhiṇḍ": ['mw'],
    "upāhiṇḍate": ['bhs'],
    "upāhve": ['mw'],
    "upāhāraḥ": ['ap90'],
    "upāhṛ": ['ap90', 'mw'],
    "upāhṛta": ['mw'],
    "upāj": ['mw'],
    "upāje": ['ap90', 'mw'],
    "upājinam": ['mw'],
    "upāka": ['ap90', 'cae', 'gra', 'mw'],
    "upākacakṣas": ['gra', 'mw'],
    "upākaraṇa": ['cae', 'ddsa', 'mw'],
    "upākaraṇavidhi": ['mw'],
    "upākaraṇaṃ": ['ap90'],
    "upākarman": ['ap90', 'cae', 'mw'],
    "upākarmaprayoga": ['mw'],
    "upākarmavidhi": ['mw'],
    "upākarṇaya": ['mw'],
    "upākarṇya": ['mw'],
    "upāke": ['mw'],
    "upākhya": ['mw'],
    "upākhyā": ['ap90', 'mw'],
    "upākhyāna": ['cae', 'ddsa', 'mw'],
    "upākhyānaka": ['cae', 'mw'],
    "upākhyānaṃ": ['ap90'],
    "upākram": ['mw'],
    "upākta": ['mw'],
    "upākā": ['mw'],
    "upākṛ": ['ap90', 'mw'],
    "upākṛta": ['ap90', 'mw'],
    "upākṛti": ['mw'],
    "upākṛtin": ['mw'],
    "upākṣa": ['mw'],
    "upākṣaka": ['mw'],
    "upākṣam": ['mw'],
    "upākṣaṃ": ['ap90'],
    "upālabdha": ['mw'],
    "upālabdhavya": ['cae', 'ddsa', 'mw'],
    "upālabh": ['ap90', 'mw'],
    "upālabhya": ['mw'],
    "upālakṣ": ['mw'],
    "upālakṣya": ['mw'],
    "upālambha": ['cae', 'mw'],
    "upālambhana": ['mw'],
    "upālambhanīya": ['cae'],
    "upālambhya": ['mw'],
    "upālaṃbhaḥ": ['ap90'],
    "upāli": ['bhs', 'ddsa', 'mw'],
    "upāligaṅgapālānāṃjātakaṃ": ['bhs'],
    "upāliparipṛcchā": ['bhs'],
    "upālipsu": ['mw'],
    "upālisūtra": ['bhs'],
    "upālālya": ['mw'],
    "upāmantr": ['mw'],
    "upāmantrita": ['mw'],
    "upāmantrya": ['mw'],
    "upānad": ['mw'],
    "upānadgūḍha": ['ddsa', 'mw'],
    "upānadyuga": ['mw'],
    "upānah": ['ap90', 'cae', 'ddsa', 'mw'],
    "upānaha": ['bhs', 'ddsa', 'mw'],
    "upānahin": ['mw'],
    "upānantarīya": ['bhs'],
    "upānas": ['ap90'],
    "upānasa": ['cae', 'gra', 'mw'],
    "upānasyaka": ['mw'],
    "upānayana": ['mw'],
    "upānta": ['bhs', 'cae', 'ddsa', 'mw'],
    "upāntabhāga": ['mw'],
    "upāntam": ['mw'],
    "upāntasarpin": ['mw'],
    "upānte": ['mw'],
    "upāntika": ['cae', 'mw'],
    "upāntikam": ['mw'],
    "upāntikāt": ['mw'],
    "upāntima": ['mw'],
    "upāntya": ['ddsa', 'mw'],
    "upāntāt": ['mw'],
    "upānuvākya": ['mw'],
    "upānvāharati": ['bhs'],
    "upānvāhāra": ['bhs'],
    "upānvāruh": ['mw'],
    "upānāmayati": ['bhs'],
    "upānī": ['mw'],
    "upāp": ['mw'],
    "upāpa": ['mw'],
    "upāpat": ['mw'],
    "upāprach": ['mw'],
    "upāpti": ['cae', 'mw'],
    "upāptiḥ": ['ap90'],
    "upār": ['mw'],
    "upāra": ['cae', 'gra', 'mw'],
    "upārabhyate": ['bhs'],
    "upāraddha": ['cped'],
    "upāram": ['ap90', 'mw'],
    "upārama": ['mw'],
    "upārambha": ['bhs', 'cped'],
    "upārambhacitta": ['cped'],
    "upārambhati": ['cped'],
    "upārambhānisaṁsa": ['cped'],
    "upārata": ['ap90', 'mw'],
    "upāraḥ": ['ap90'],
    "upāraṃbhaḥ": ['ap90'],
    "upāraṇa": ['gra', 'mw'],
    "upārch": ['mw'],
    "upārdh": ['mw'],
    "upārdha": ['bhs', 'mw'],
    "upārdhakālaka": ['bhs'],
    "upārdhakāśikā": ['bhs'],
    "upāriṣṭa": ['bhs'],
    "upārj": ['ap90', 'mw'],
    "upārjaka": ['ap90', 'mw'],
    "upārjana": ['cae', 'ddsa', 'mw'],
    "upārjanaṃ": ['ap90'],
    "upārjita": ['mw'],
    "upārjya": ['mw'],
    "upārodha": ['bhs'],
    "upārpya": ['mw'],
    "upārtha": ['ap90'],
    "upārud": ['mw'],
    "upāruh": ['gra', 'mw'],
    "upārādh": ['mw'],
    "upārādhya": ['mw'],
    "upārāma": ['mw'],
    "upārūḍha": ['ap90', 'mw'],
    "upārṣ": ['mw'],
    "upās": ['ap90', 'mw'],
    "upāsad": ['mw'],
    "upāsaka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "upāsakadaśā": ['mw'],
    "upāsakaḥ": ['ap90'],
    "upāsamāna": ['cped'],
    "upāsana": ['cae', 'cped', 'mw'],
    "upāsanaṃ": ['ap90'],
    "upāsanācandrāmṛta": ['mw'],
    "upāsanākhaṇḍa": ['mw'],
    "upāsanārtha": ['mw'],
    "upāsanīya": ['mw'],
    "upāsati": ['cped'],
    "upāsaṃgaḥ": ['ap90'],
    "upāsaṅga": ['mw'],
    "upāsikā": ['cped', 'mw'],
    "upāsita": ['cped', 'mw'],
    "upāsitar": ['cped'],
    "upāsitavya": ['mw'],
    "upāsituṁ": ['cped'],
    "upāsitṛ": ['ap90', 'mw'],
    "upāsnāta": ['mw'],
    "upāstamanavelā": ['mw'],
    "upāstamanaṃ": ['ap90'],
    "upāstamayam": ['mw'],
    "upāstamayaṃ": ['ap90'],
    "upāsthita": ['cae', 'mw'],
    "upāsthā": ['mw'],
    "upāsti": ['mw'],
    "upāstiḥ": ['ap90'],
    "upāstra": ['mw'],
    "upāstraṃ": ['ap90'],
    "upāstṛ": ['mw'],
    "upāsya": ['ap90', 'cae', 'mw'],
    "upāsyand": ['mw'],
    "upāsā": ['ap90', 'mw'],
    "upāsādita": ['mw'],
    "upāsāditin": ['mw'],
    "upāsādya": ['mw'],
    "upāsīna": ['mw'],
    "upāsṛj": ['mw'],
    "upātaṅkya": ['mw'],
    "upātidhāvati": ['bhs', 'cped'],
    "upātigā": ['cped'],
    "upātipanna": ['cped'],
    "upātivatta": ['cped'],
    "upātivattat": ['cped'],
    "upātivattati": ['cped'],
    "upātivattatittho": ['cped'],
    "upātivṛtta": ['bhs'],
    "upātta": ['ap90', 'cae', 'ddsa', 'mw'],
    "upāttaraṃhas": ['mw'],
    "upāttasāra": ['cae', 'mw'],
    "upāttavidya": ['mw'],
    "upāttaśastra": ['mw'],
    "upātyaya": ['mw'],
    "upātyayaḥ": ['ap90'],
    "upātī": ['mw'],
    "upāv": ['mw'],
    "upāvadhā": ['mw'],
    "upāvah": ['mw'],
    "upāvaharaṇa": ['mw'],
    "upāvaharaṇaṃ": ['ap90'],
    "upāvahita": ['mw'],
    "upāvahṛ": ['mw'],
    "upāvanam": ['mw'],
    "upāvanata": ['mw'],
    "upāvaram": ['mw'],
    "upāvarohaṇa": ['mw'],
    "upāvartana": ['ddsa', 'mw'],
    "upāvartanaṃ": ['ap90'],
    "upāvartayati": ['bhs'],
    "upāvartitṛ": ['mw'],
    "upāvaruh": ['mw'],
    "upāvasita": ['mw'],
    "upāvaso": ['mw'],
    "upāvasu": ['ap90', 'gra', 'mw'],
    "upāvasāyin": ['ap90', 'ddsa', 'mw'],
    "upāvasṛj": ['mw'],
    "upāvasṛp": ['mw'],
    "upāvasṛṣṭa": ['mw'],
    "upāvaśri": ['mw'],
    "upāve": ['mw'],
    "upāvekṣ": ['mw'],
    "upāvi": ['mw'],
    "upāvisi": ['cped'],
    "upāvisiṁ": ['cped'],
    "upāvisuṁ": ['cped'],
    "upāviś": ['mw'],
    "upāvraj": ['mw'],
    "upāvyādha": ['mw'],
    "upāvyādhaḥ": ['ap90'],
    "upāvī": ['mw'],
    "upāvṛ": ['mw'],
    "upāvṛt": ['ap90', 'cae', 'mw'],
    "upāvṛta": ['mw'],
    "upāvṛtta": ['ap90', 'cae', 'mw'],
    "upāvṛtti": ['cae', 'mw'],
    "upāvṛtya": ['mw'],
    "upāya": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "upāyacatuṣṭaya": ['mw'],
    "upāyacintā": ['mw'],
    "upāyajña": ['mw'],
    "upāyakauśalya": ['bhs', 'mw'],
    "upāyakosalla": ['cped'],
    "upāyakuśala": ['bhs'],
    "upāyana": ['cae', 'ddsa', 'gra', 'mw'],
    "upāyanayebhī": ['bhs'],
    "upāyanaṃ": ['ap90'],
    "upāyanīkṛ": ['mw'],
    "upāyanīkṛta": ['mw'],
    "upāyapramathana": ['bhs'],
    "upāyatas": ['mw'],
    "upāyaturīya": ['mw'],
    "upāyatva": ['mw'],
    "upāyavat": ['mw'],
    "upāyayoga": ['mw'],
    "upāyaññu": ['cped'],
    "upāyaśrībhadra": ['mw'],
    "upāyaḥ": ['ap90'],
    "upāyena": ['cped'],
    "upāyika": ['ap90'],
    "upāyikā": ['bhs'],
    "upāyin": ['ap90', 'cae', 'mw'],
    "upāyopeya": ['cae', 'ddsa', 'mw'],
    "upāyu": ['ap90', 'cae', 'mw'],
    "upāyuj": ['mw'],
    "upāyupādāna": ['cped'],
    "upāyā": ['mw'],
    "upāyākṣepa": ['mw'],
    "upāyāntara": ['mw'],
    "upāyāsa": ['bhs', 'cped'],
    "upāyāsabahula": ['cped'],
    "upāyāsita": ['cped'],
    "upāyāta": ['ap90', 'mw'],
    "upāyūpādāna": ['cped'],
    "upāñc": ['mw'],
    "upāñj": ['mw'],
    "upāñjana": ['cae', 'ddsa', 'mw'],
    "upāś": ['mw'],
    "upāśaṃsanīya": ['ap90', 'mw'],
    "upāśliṣ": ['mw'],
    "upāśliṣṭa": ['mw'],
    "upāśraya": ['ddsa', 'mw'],
    "upāśrayaḥ": ['ap90'],
    "upāśrayitvā": ['mw'],
    "upāśri": ['ap90', 'mw'],
    "upāśrita": ['ap90', 'cae', 'mw'],
    "upāśritya": ['cae'],
    "upāśāra": ['mw'],
    "upāṃgaḥ": ['ap90'],
    "upāṃjanaṃ": ['ap90'],
    "upāṃta": ['ap90'],
    "upāṃtika": ['ap90'],
    "upāṃtima": ['ap90'],
    "upāṃtya": ['ap90'],
    "upāṃśu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "upāṃśudaṇḍa": ['mw'],
    "upāṃśughātaka": ['mw'],
    "upāṃśugraha": ['mw'],
    "upāṃśuhavis": ['mw'],
    "upāṃśukrīḍita": ['mw'],
    "upāṃśupātra": ['mw'],
    "upāṃśusavana": ['mw'],
    "upāṃśutva": ['mw'],
    "upāṃśutā": ['mw'],
    "upāṃśuvadha": ['mw'],
    "upāṃśuvrata": ['cae', 'mw'],
    "upāṃśuyāja": ['mw'],
    "upāṃśvantaryāma": ['mw'],
    "upāṃśvāyatana": ['mw'],
    "upāṅga": ['cae', 'ddsa', 'mw'],
    "upāṅgagīta": ['mw'],
    "upāṅgalalitāvrata": ['mw'],
    "upāṅkya": ['mw'],
    "upāṅkyapṛṣṭha": ['mw'],
    "upīḍa": ['bhs'],
    "ur": ['ap90'],
    "ura": ['ap90', 'bhs', 'cae', 'cped'],
    "urabbha": ['cped'],
    "urabhra": ['bhs', 'cae', 'mw'],
    "urabhrasārikā": ['mw'],
    "urabhraḥ": ['ap90'],
    "uracakka": ['cped'],
    "uracchada": ['cped'],
    "uraga": ['cae', 'cped', 'ddsa', 'mw'],
    "uragabhūṣaṇa": ['mw'],
    "uragagarbha": ['bhs'],
    "uragarāja": ['mw'],
    "uragasthāna": ['mw'],
    "uragasāracandana": ['bhs', 'mw'],
    "uragasāracandanacūrṇa": ['mw'],
    "uragasāracandanamaya": ['mw'],
    "uragayava": ['mw'],
    "uragaḥ": ['ap90'],
    "uragendra": ['mw'],
    "uragā": ['mw'],
    "uragāri": ['mw'],
    "uragāriketana": ['mw'],
    "uragāsya": ['ddsa', 'mw'],
    "uragāśana": ['mw'],
    "uragī": ['mw'],
    "urala": ['ap90', 'mw'],
    "uralli": ['cae', 'mw'],
    "urandhrā": ['mw'],
    "urarī": ['ap90', 'mw'],
    "urarīkaraṇa": ['mw'],
    "urarīkāra": ['mw'],
    "urarīkāraḥ": ['ap90'],
    "urarīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "urarīkṛta": ['ap90', 'mw'],
    "uras": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "urasa": ['bhs', 'mw'],
    "urasi": ['mw'],
    "urasija": ['mw'],
    "urasikṛtya": ['mw'],
    "urasila": ['mw'],
    "urasiloman": ['ap90', 'mw'],
    "urasiruha": ['mw'],
    "uraska": ['mw'],
    "uraskaṭa": ['mw'],
    "uraskṛtya": ['mw'],
    "uraspeśa": ['mw'],
    "urastas": ['ap90', 'mw'],
    "urastra": ['mw'],
    "urastrāṇa": ['mw'],
    "urasvat": ['ap90', 'mw'],
    "urasya": ['ap90', 'mw'],
    "urasyati": ['ap90'],
    "uratrika": ['bhs'],
    "urattāḷiṁ": ['cped'],
    "urattāḷī": ['cped'],
    "uraś": ['mw'],
    "uraśa": ['mw'],
    "uraśaḥ": ['ap90'],
    "uraśchada": ['ddsa', 'mw'],
    "uraśā": ['mw'],
    "uraḥ": ['mw'],
    "uraḥkapāṭa": ['ddsa', 'mw'],
    "uraḥkṣata": ['mw'],
    "uraḥkṣatakāsa": ['mw'],
    "uraḥkṣaya": ['mw'],
    "uraḥstambha": ['mw'],
    "uraḥstha": ['mw'],
    "uraḥsthala": ['mw'],
    "uraḥsūtrikā": ['cae', 'ddsa', 'mw'],
    "uraḥśiras": ['mw'],
    "uraḥśūla": ['mw'],
    "uraḥśūlin": ['mw'],
    "uraṃga": ['cae', 'mw'],
    "uraṃgama": ['cae', 'mw'],
    "uraṃgaḥ": ['ap90'],
    "uraṅga": ['ddsa'],
    "uraṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "uraṇaka": ['mw'],
    "uraṇakavatsa": ['mw'],
    "uraṇakaḥ": ['ap90'],
    "uraṇaḥ": ['ap90'],
    "uraṇākhya": ['mw'],
    "uraṇākhyaka": ['mw'],
    "uraṇākṣa": ['mw'],
    "uraṇākṣaka": ['mw'],
    "urd": ['ap90', 'mw'],
    "urdi": ['mw'],
    "urdra": ['mw'],
    "urdraḥ": ['ap90'],
    "urj": ['ap90', 'mw'],
    "urjihānā": ['mw'],
    "urjita": ['ap90'],
    "urmilā": ['mw'],
    "urmya": ['ddsa'],
    "uro": ['mw'],
    "urobhūṣaṇa": ['mw'],
    "urobṛhatī": ['mw'],
    "urogama": ['mw'],
    "urogata": ['cae'],
    "uroghāta": ['mw'],
    "urograha": ['mw'],
    "urogrīva": ['mw'],
    "urohasta": ['mw'],
    "uroja": ['ddsa', 'mw'],
    "urovibandha": ['mw'],
    "uru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uruajra": ['gra'],
    "urubila": ['mw'],
    "urubilvā": ['mw'],
    "urubilvākalpa": ['mw'],
    "urubilvākāśyapa": ['mw'],
    "urubindu": ['mw'],
    "urubja": ['gra', 'mw'],
    "urucakra": ['gra', 'mw'],
    "urucakri": ['gra', 'mw'],
    "urucakṣas": ['cae', 'gra', 'mw'],
    "urudhiṣṇya": ['mw'],
    "urudhā": ['mw'],
    "urudhāra": ['gra', 'mw'],
    "urudrapsu": ['mw'],
    "urugavyūti": ['gra', 'mw'],
    "urugrāha": ['mw'],
    "urugāya": ['cae', 'gra', 'mw'],
    "urugāyavat": ['mw'],
    "urugūlā": ['mw'],
    "uruhāra": ['mw'],
    "urujman": ['mw'],
    "urujrayas": ['gra', 'mw'],
    "urujri": ['gra', 'mw'],
    "urukrama": ['cae', 'ddsa', 'gra', 'mw'],
    "urukāla": ['mw'],
    "urukālaka": ['mw'],
    "urukīrti": ['mw'],
    "urukṛt": ['cae', 'gra', 'mw'],
    "urukṣaya": ['gra', 'mw'],
    "urukṣiti": ['gra', 'mw'],
    "uruloka": ['gra', 'mw'],
    "urumuṇḍa": ['bhs', 'mw'],
    "urumārga": ['mw'],
    "urumāṇa": ['mw'],
    "urunda": ['cped'],
    "uruprathas": ['mw'],
    "urupuṇyakośa": ['mw'],
    "urupuṣpikā": ['mw'],
    "ururātri": ['mw'],
    "ururī": ['ap90', 'mw'],
    "urusattva": ['mw'],
    "urusvana": ['mw'],
    "urutva": ['mw'],
    "urutā": ['ap90', 'mw'],
    "urutāpa": ['mw'],
    "uruvalka": ['mw'],
    "uruvas": ['mw'],
    "uruvikrama": ['mw'],
    "uruvilvaka": ['bhs'],
    "uruvilvā": ['bhs', 'mw'],
    "uruvilvākalpa": ['bhs'],
    "uruvilvākāśyapa": ['bhs'],
    "uruvraja": ['gra', 'mw'],
    "uruvu": ['mw'],
    "uruvuka": ['mw'],
    "uruvuḥ": ['ap90'],
    "uruvyac": ['gra'],
    "uruvyacas": ['cae', 'gra', 'mw'],
    "uruvyañc": ['cae', 'mw'],
    "uruvāsa": ['mw'],
    "uruvūka": ['mw'],
    "uruyuga": ['gra', 'mw'],
    "uruyā": ['cae', 'mw'],
    "uruñjirā": ['mw'],
    "uruśarman": ['mw'],
    "uruśasa": ['cae'],
    "uruśaṃsa": ['gra', 'mw'],
    "uruśravas": ['mw'],
    "uruśṛṅga": ['mw'],
    "uruṇḍa": ['mw'],
    "uruṣy": ['cae', 'gra'],
    "uruṣya": ['ddsa', 'mw'],
    "uruṣyati": ['ap90'],
    "uruṣyu": ['ap90', 'gra', 'mw'],
    "uruṣyā": ['ap90', 'gra', 'mw'],
    "uruṣā": ['gra', 'mw'],
    "urv": ['ap90', 'mw'],
    "urva": ['mw'],
    "urvac": ['gra'],
    "urvajra": ['gra', 'mw'],
    "urvarita": ['ap90', 'ddsa', 'mw'],
    "urvarya": ['ap90', 'mw'],
    "urvarā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "urvarājit": ['gra', 'mw'],
    "urvarāpati": ['gra', 'mw'],
    "urvarāsā": ['gra', 'mw'],
    "urvarī": ['ap90', 'cae', 'mw'],
    "urvarīvat": ['mw'],
    "urvaśī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "urvaśīnāmamālā": ['mw'],
    "urvaśīramaṇa": ['mw'],
    "urvaśīsahāya": ['mw'],
    "urvaśīsuta": ['cae'],
    "urvaśītīrtha": ['mw'],
    "urvaśīvallabha": ['mw'],
    "urvaṅga": ['mw'],
    "urvaṭa": ['mw'],
    "urvaṭaḥ": ['ap90'],
    "urviyā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "urviūti": ['gra'],
    "urvyā": ['ap90', 'cae', 'mw'],
    "urvyūti": ['ap90', 'gra', 'mw'],
    "urvāru": ['cae', 'mw'],
    "urvāruka": ['cae', 'gra', 'mw'],
    "urvārukaṃ": ['ap90'],
    "urvāruḥ": ['ap90'],
    "urvī": ['ap90', 'ddsa', 'mw'],
    "urvībhuj": ['cae', 'mw'],
    "urvībhṛt": ['cae', 'mw'],
    "urvīdhara": ['mw'],
    "urvīpati": ['cae', 'mw'],
    "urvīruha": ['mw'],
    "urvītala": ['cae', 'ddsa', 'mw'],
    "urvīśa": ['cae', 'mw'],
    "urvīśvara": ['cae', 'mw'],
    "urā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "urāha": ['mw'],
    "urāhaḥ": ['ap90'],
    "urāmathi": ['gra', 'mw'],
    "urāṇa": ['gra', 'mw'],
    "urī": ['ap90', 'mw'],
    "urīkāra": ['ap90'],
    "urīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "urūcī": ['mw'],
    "urūka": ['ddsa', 'mw'],
    "urūkaḥ": ['ap90'],
    "urūla": ['ap90'],
    "urūḷhava": ['cped'],
    "urūḷhavat": ['cped'],
    "urūṇasa": ['cae', 'ddsa', 'gra', 'mw'],
    "urṇa": ['mw'],
    "urṇanābhaḥ": ['ap90'],
    "urṇā": ['ap90'],
    "usabha": ['cped'],
    "usar": ['ddsa'],
    "usma": ['cped'],
    "usman": ['cped'],
    "usmanudaka": ['cped'],
    "usmita": ['mw'],
    "usmā": ['cped'],
    "usmīkata": ['cped'],
    "usra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "usrayāman": ['gra', 'mw'],
    "usri": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "usrika": ['ddsa', 'gra', 'mw'],
    "usrikaḥ": ['ap90'],
    "usriya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "usriyā": ['mw'],
    "usriyātva": ['mw'],
    "usrā": ['ddsa', 'mw'],
    "usrīya": ['mw'],
    "ussa": ['cped'],
    "ussada": ['cped'],
    "ussadaka": ['cped'],
    "ussahanta": ['cped'],
    "ussahati": ['cped'],
    "ussahitvā": ['cped'],
    "ussahiṁsu": ['cped'],
    "ussajitvā": ['cped'],
    "ussajjitvā": ['cped'],
    "ussakkati": ['cped'],
    "ussakkitvā": ['cped'],
    "ussanna": ['cped'],
    "ussannatta": ['cped'],
    "ussannatā": ['cped'],
    "ussava": ['cped'],
    "ussayavādikā": ['cped'],
    "ussaṅkhapāda": ['cped'],
    "ussaṅki": ['cped'],
    "ussaṅkin": ['cped'],
    "ussaṅkitaparisaṅkita": ['cped'],
    "ussaṭa": ['cped'],
    "usseneti": ['cped'],
    "usseḷeti": ['cped'],
    "ussineti": ['cped'],
    "ussita": ['cped'],
    "ussoḷhi": ['cped'],
    "ussoḷhika": ['cped'],
    "ussuka": ['cped'],
    "ussukka": ['cped'],
    "ussukkati": ['cped'],
    "ussussati": ['cped'],
    "ussāda": ['cped'],
    "ussādanā": ['cped'],
    "ussādeta": ['cped'],
    "ussādetabba": ['cped'],
    "ussādetar": ['cped'],
    "ussādeti": ['cped'],
    "ussādita": ['cped'],
    "ussādiyati": ['cped'],
    "ussādiyittha": ['cped'],
    "ussādiyiṁsu": ['cped'],
    "ussāha": ['cped'],
    "ussāhana": ['cped'],
    "ussāhita": ['cped'],
    "ussāpana": ['cped'],
    "ussāpayati": ['cped'],
    "ussāpenta": ['cped'],
    "ussāpesi": ['cped'],
    "ussāpeti": ['cped'],
    "ussāpetvā": ['cped'],
    "ussārayati": ['cped'],
    "ussāreti": ['cped'],
    "ussāretvā": ['cped'],
    "ussārita": ['cped'],
    "ussāva": ['cped'],
    "ussāvabindu": ['cped'],
    "ussāvana": ['cped'],
    "ussāvanantikā": ['cped'],
    "ussīdati": ['cped'],
    "ussūra": ['cped'],
    "ussūrabhatta": ['cped'],
    "ussūraseyyā": ['cped'],
    "usu": ['cped'],
    "usukāra": ['cped'],
    "usuloma": ['cped'],
    "usuyyaka": ['cped'],
    "usuyyati": ['cped'],
    "usuyyā": ['cped'],
    "usīra": ['cped'],
    "usīragiri": ['bhs'],
    "usīranāḷa": ['cped'],
    "usūyaka": ['cped'],
    "usūyati": ['cped'],
    "usūyā": ['cped'],
    "usṛ": ['cae', 'gra', 'mw'],
    "ut": ['ap90', 'mw'],
    "uta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "utacchiyam": ['bhs'],
    "utapta": ['bhs'],
    "utathya": ['cae', 'ddsa', 'mw'],
    "utathyatanaya": ['cae', 'mw'],
    "utathyaḥ": ['ap90'],
    "utathyānuja": ['mw'],
    "utaṅka": ['mw'],
    "utaṅkamegha": ['mw'],
    "utittira": ['bhs'],
    "utka": ['ap90', 'cae', 'ddsa', 'mw'],
    "utkaca": ['ap90', 'bhs', 'mw'],
    "utkacaya": ['mw'],
    "utkacchā": ['ap90', 'mw'],
    "utkal": ['mw'],
    "utkala": ['ap90', 'ddsa', 'mw'],
    "utkaladeśa": ['mw'],
    "utkalakhaṇḍa": ['mw'],
    "utkalikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "utkalikāprāya": ['mw'],
    "utkalikāvailarī": ['mw'],
    "utkalita": ['ap90', 'cae', 'mw'],
    "utkalāpa": ['ap90', 'cae', 'ddsa', 'mw'],
    "utkalāpana": ['mw'],
    "utkalāpaya": ['mw'],
    "utkalāpayati": ['ap90'],
    "utkam": ['ap90'],
    "utkamp": ['mw'],
    "utkampa": ['cae', 'ddsa', 'mw'],
    "utkampana": ['cae', 'mw'],
    "utkampin": ['cae', 'mw'],
    "utkampita": ['cae'],
    "utkand": ['mw'],
    "utkandaka": ['mw'],
    "utkandhara": ['ddsa', 'mw'],
    "utkara": ['ap90', 'cae', 'ddsa', 'mw'],
    "utkaraḥ": ['ap90'],
    "utkarika": ['bhs'],
    "utkarikā": ['ap90', 'ddsa', 'mw'],
    "utkarkara": ['mw'],
    "utkarkaraḥ": ['ap90'],
    "utkartam": ['mw'],
    "utkartana": ['mw'],
    "utkartanaṃ": ['ap90'],
    "utkartṛtva": ['mw'],
    "utkarādi": ['mw'],
    "utkarīya": ['ap90', 'mw'],
    "utkarṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "utkarṇatāla": ['mw'],
    "utkarṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "utkarṣaka": ['ap90', 'mw'],
    "utkarṣasama": ['mw'],
    "utkarṣayati": ['bhs'],
    "utkarṣaṇa": ['bhs', 'mw'],
    "utkarṣaṇaṃ": ['ap90'],
    "utkarṣaṇī": ['mw'],
    "utkarṣin": ['ap90', 'cae', 'mw'],
    "utkarṣita": ['mw'],
    "utkarṣiṇī": ['mw'],
    "utkas": ['mw'],
    "utkatā": ['ap90', 'mw'],
    "utkaya": ['ddsa', 'mw'],
    "utkayati": ['ap90'],
    "utkañcuka": ['ddsa', 'mw'],
    "utkaṃcuka": ['ap90'],
    "utkaṃdhara": ['ap90'],
    "utkaṃp": ['ap90'],
    "utkaṃpa": ['ap90'],
    "utkaṃpin": ['ap90'],
    "utkaṃṭha": ['ap90'],
    "utkaṃṭhate": ['ap90'],
    "utkaṃṭhita": ['ap90'],
    "utkaṃṭhā": ['ap90'],
    "utkaṇikā": ['ap90', 'mw'],
    "utkaṇṭakin": ['mw'],
    "utkaṇṭakita": ['ddsa', 'mw'],
    "utkaṇṭh": ['cae', 'ddsa'],
    "utkaṇṭha": ['cae', 'ddsa', 'mw'],
    "utkaṇṭhaka": ['mw'],
    "utkaṇṭhamāhātmya": ['mw'],
    "utkaṇṭhati": ['bhs'],
    "utkaṇṭhita": ['cae', 'mw'],
    "utkaṇṭhitā": ['mw'],
    "utkaṇṭhā": ['bhs', 'cae', 'mw'],
    "utkaṇṭhābhāgin": ['cae'],
    "utkaṇṭhākārin": ['cae'],
    "utkaṇṭhānirbharam": ['cae', 'mw'],
    "utkaṣ": ['mw'],
    "utkaṣaṇa": ['cae', 'ddsa', 'mw'],
    "utkaṣaṇaṃ": ['ap90'],
    "utkaṭ": ['ap90'],
    "utkaṭa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "utkaṭikā": ['mw'],
    "utkaṭikāsana": ['mw'],
    "utkaṭuka": ['mw'],
    "utkaṭukāsanaṃ": ['ap90'],
    "utkaṭā": ['mw'],
    "utkaṭṭati": ['bhs'],
    "utketana": ['mw'],
    "utkhac": ['mw'],
    "utkhacita": ['ap90', 'cae', 'mw'],
    "utkhalati": ['bhs'],
    "utkhalin": ['bhs', 'mw'],
    "utkhalā": ['ap90', 'mw'],
    "utkhalī": ['bhs', 'mw'],
    "utkhan": ['ap90', 'mw'],
    "utkhanana": ['mw'],
    "utkhaṇḍita": ['cae', 'mw'],
    "utkheda": ['mw'],
    "utkhedaḥ": ['ap90'],
    "utkhid": ['ap90', 'mw'],
    "utkhilī": ['mw'],
    "utkhurī": ['bhs'],
    "utkhālī": ['mw'],
    "utkhānam": ['mw'],
    "utkhāta": ['ap90', 'cae', 'ddsa', 'mw'],
    "utkhātam": ['mw'],
    "utkhātin": ['ap90', 'cae', 'mw'],
    "utkhāya": ['mw'],
    "utkhāṭayitar": ['bhs'],
    "utkira": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "utkleda": ['mw'],
    "utkledaḥ": ['ap90'],
    "utkledin": ['ap90', 'mw'],
    "utkleśa": ['mw'],
    "utkleśaka": ['ap90', 'mw'],
    "utkleśana": ['ap90', 'mw'],
    "utkleśaḥ": ['ap90'],
    "utkleśin": ['mw'],
    "utkliś": ['ap90', 'mw'],
    "utkliśya": ['mw'],
    "utkliṣṭa": ['mw'],
    "utkoca": ['cae', 'ddsa', 'mw'],
    "utkocaka": ['ap90', 'cae', 'mw'],
    "utkocaḥ": ['ap90'],
    "utkocin": ['mw'],
    "utkodaḥ": ['ap90'],
    "utkopa": ['mw'],
    "utkoraka": ['mw'],
    "utkorakaya": ['ddsa', 'mw'],
    "utkośaya": ['mw'],
    "utkoṭana": ['bhs'],
    "utkoṭayati": ['bhs'],
    "utkoṭha": ['mw'],
    "utkoṭi": ['ap90', 'ddsa', 'mw'],
    "utkram": ['mw'],
    "utkrama": ['cae', 'ddsa', 'mw'],
    "utkramajyā": ['mw'],
    "utkramayya": ['mw'],
    "utkramaḥ": ['ap90'],
    "utkramaṇa": ['cae', 'mw'],
    "utkramaṇaṃ": ['ap90'],
    "utkramaṇīya": ['ap90', 'mw'],
    "utkramya": ['mw'],
    "utkraṣṭavya": ['mw'],
    "utkraṣṭṛ": ['cae', 'mw'],
    "utkroda": ['cae', 'mw'],
    "utkrodin": ['mw'],
    "utkrośa": ['bhs', 'ddsa', 'mw'],
    "utkrośana": ['bhs'],
    "utkrośate": ['bhs'],
    "utkrośayati": ['bhs'],
    "utkrośaḥ": ['ap90'],
    "utkrośīya": ['mw'],
    "utkruś": ['mw'],
    "utkruṣṭa": ['ap90', 'mw'],
    "utkrāma": ['mw'],
    "utkrāmaḥ": ['ap90'],
    "utkrānta": ['mw'],
    "utkrāntamedha": ['mw'],
    "utkrāntaśreyas": ['mw'],
    "utkrānti": ['mw'],
    "utkrāntin": ['mw'],
    "utkrāthinī": ['mw'],
    "utkrāṃta": ['ap90'],
    "utkrāṃtin": ['ap90'],
    "utkrāṃtiḥ": ['ap90'],
    "utkrī": ['mw'],
    "utkubjāpayati": ['bhs'],
    "utkuc": ['mw'],
    "utkula": ['ap90', 'cae', 'ddsa', 'mw'],
    "utkumbhati": ['bhs'],
    "utkumuda": ['mw'],
    "utkutuka": ['mw'],
    "utkuñcikā": ['mw'],
    "utkuñcitā": ['mw'],
    "utkuś": ['ap90'],
    "utkuṃcitā": ['ap90'],
    "utkuṇa": ['mw'],
    "utkuṇaḥ": ['ap90'],
    "utkuṭ": ['mw'],
    "utkuṭa": ['bhs', 'mw'],
    "utkuṭaka": ['ap90', 'mw'],
    "utkuṭakāsana": ['mw'],
    "utkuṭasthāyin": ['bhs'],
    "utkuṭaṃ": ['ap90'],
    "utkuṭuka": ['bhs', 'mw'],
    "utkuṭukikā": ['bhs'],
    "utkvath": ['mw'],
    "utkvātha": ['mw'],
    "utkākud": ['mw'],
    "utkākā": ['ap90', 'mw'],
    "utkānti": ['mw'],
    "utkāra": ['mw'],
    "utkāraḥ": ['ap90'],
    "utkāreti": ['bhs'],
    "utkārika": ['bhs'],
    "utkārikopanāha": ['mw'],
    "utkārikā": ['ap90', 'mw'],
    "utkās": ['mw'],
    "utkāsa": ['bhs', 'mw'],
    "utkāsana": ['mw'],
    "utkāsaḥ": ['ap90'],
    "utkāya": ['mw'],
    "utkāyate": ['ap90'],
    "utkāś": ['mw'],
    "utkāśa": ['bhs', 'mw'],
    "utkāśana": ['mw'],
    "utkāśanaśabda": ['bhs'],
    "utkāśanaṃ": ['ap90'],
    "utkāśaśabda": ['bhs'],
    "utkīl": ['mw'],
    "utkīla": ['mw'],
    "utkīlaka": ['bhs', 'mw'],
    "utkīlaya": ['mw'],
    "utkīlayati": ['bhs'],
    "utkīlita": ['ap90', 'ddsa', 'mw'],
    "utkīrtana": ['mw'],
    "utkīrtanaṃ": ['ap90'],
    "utkīrtita": ['ap90', 'mw'],
    "utkīrtya": ['mw'],
    "utkīrṇa": ['ap90', 'cae', 'mw'],
    "utkū": ['mw'],
    "utkūj": ['mw'],
    "utkūja": ['ddsa', 'mw'],
    "utkūjaḥ": ['ap90'],
    "utkūjita": ['mw'],
    "utkūla": ['ap90', 'bhs', 'ddsa', 'mw'],
    "utkūlagāmin": ['mw'],
    "utkūlaka": ['bhs'],
    "utkūlam": ['mw'],
    "utkūlanikūla": ['mw'],
    "utkūlaya": ['mw'],
    "utkūlita": ['ap90', 'mw'],
    "utkūrd": ['mw'],
    "utkūrdana": ['cae', 'ddsa', 'mw'],
    "utkūrdanaṃ": ['ap90'],
    "utkūṭa": ['mw'],
    "utkūṭaḥ": ['ap90'],
    "utkḷp": ['mw'],
    "utkṛ": ['ap90', 'mw'],
    "utkṛt": ['ap90', 'mw'],
    "utkṛti": ['ddsa', 'mw'],
    "utkṛtiḥ": ['ap90'],
    "utkṛtya": ['mw'],
    "utkṛtyamāna": ['mw'],
    "utkṛṣ": ['ap90', 'mw'],
    "utkṛṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "utkṛṣṭabhūma": ['mw'],
    "utkṛṣṭataraka": ['bhs'],
    "utkṛṣṭatva": ['mw'],
    "utkṛṣṭatā": ['ap90', 'mw'],
    "utkṛṣṭavedana": ['cae', 'mw'],
    "utkṛṣṭikā": ['bhs'],
    "utkṛṣṭopādhitā": ['mw'],
    "utkṝ": ['ap90', 'mw'],
    "utkṝt": ['ap90', 'mw'],
    "utkṣepa": ['ap90', 'mw'],
    "utkṣepaka": ['ap90', 'bhs', 'mw'],
    "utkṣepalipi": ['bhs', 'mw'],
    "utkṣepam": ['mw'],
    "utkṣepau": ['mw'],
    "utkṣepaṇa": ['mw'],
    "utkṣepaṇaṃ": ['ap90'],
    "utkṣepaṇīya": ['bhs'],
    "utkṣepā": ['mw'],
    "utkṣip": ['ap90', 'mw'],
    "utkṣipati": ['bhs'],
    "utkṣipaṇa": ['bhs'],
    "utkṣipta": ['ap90', 'mw'],
    "utkṣiptaka": ['bhs'],
    "utkṣipti": ['cae', 'ddsa', 'mw'],
    "utkṣiptikā": ['ap90', 'mw'],
    "utkṣvid": ['mw'],
    "uto": ['cae', 'ddsa'],
    "utpac": ['mw'],
    "utpacanipacā": ['mw'],
    "utpaciṣṇu": ['ap90', 'mw'],
    "utpad": ['ap90', 'mw'],
    "utpadyana": ['bhs'],
    "utpadyati": ['bhs'],
    "utpakva": ['cae', 'mw'],
    "utpakṣa": ['mw'],
    "utpakṣmala": ['cae', 'mw'],
    "utpakṣman": ['ap90', 'cae', 'ddsa', 'mw'],
    "utpala": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "utpalabhedyaka": ['mw'],
    "utpalabhūti": ['bhs'],
    "utpalacakṣus": ['mw'],
    "utpaladṛś": ['cae', 'mw'],
    "utpalagandhika": ['bhs', 'mw'],
    "utpalagopā": ['mw'],
    "utpalaka": ['bhs', 'mw'],
    "utpalamālā": ['mw'],
    "utpalamālābharin": ['mw'],
    "utpalanetra": ['bhs'],
    "utpalapadmanetra": ['bhs'],
    "utpalapattra": ['mw'],
    "utpalapattraka": ['mw'],
    "utpalapattranīla": ['mw'],
    "utpalapura": ['mw'],
    "utpalarāja": ['mw'],
    "utpalasārivā": ['mw'],
    "utpalavaktra": ['bhs'],
    "utpalavana": ['cae', 'mw'],
    "utpalavarṇā": ['bhs', 'mw'],
    "utpalaśrīgarbha": ['bhs', 'mw'],
    "utpalaśāka": ['mw'],
    "utpalaṣaṭka": ['mw'],
    "utpalin": ['ap90', 'cae', 'ddsa', 'mw'],
    "utpalinī": ['mw'],
    "utpalā": ['bhs', 'mw'],
    "utpalābha": ['mw'],
    "utpalācārya": ['mw'],
    "utpalākṣa": ['mw'],
    "utpalākṣī": ['mw'],
    "utpalāpīḍa": ['mw'],
    "utpalāvana": ['mw'],
    "utpalāvartaka": ['mw'],
    "utpalāvarṇā": ['bhs'],
    "utpalāvatī": ['bhs', 'mw'],
    "utpalī": ['mw'],
    "utpanna": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "utpannabala": ['mw'],
    "utpannabhakṣin": ['mw'],
    "utpannabuddhi": ['cae', 'mw'],
    "utpannatantu": ['mw'],
    "utpannatva": ['mw'],
    "utpannavināśin": ['mw'],
    "utpannāpavargin": ['mw'],
    "utparyāṇita": ['mw'],
    "utpat": ['ap90', 'mw'],
    "utpata": ['mw'],
    "utpatana": ['cae', 'ddsa', 'mw'],
    "utpatanaṃ": ['ap90'],
    "utpatanipatā": ['mw'],
    "utpataḥ": ['ap90'],
    "utpatha": ['cae', 'ddsa', 'mw'],
    "utpathavārika": ['mw'],
    "utpathaya": ['mw'],
    "utpathaḥ": ['ap90'],
    "utpathika": ['bhs'],
    "utpathin": ['bhs'],
    "utpathājīva": ['bhs'],
    "utpatin": ['mw'],
    "utpatita": ['mw'],
    "utpatitavya": ['ddsa', 'mw'],
    "utpatitṛ": ['mw'],
    "utpatiṣṇu": ['ap90', 'mw'],
    "utpattati": ['bhs'],
    "utpattavya": ['ddsa', 'mw'],
    "utpatti": ['bhs', 'cae', 'ddsa', 'mw'],
    "utpattidhāman": ['mw'],
    "utpattika": ['bhs'],
    "utpattiketana": ['mw'],
    "utpattikrama": ['mw'],
    "utpattikāla": ['mw'],
    "utpattikālāvacchinnatva": ['mw'],
    "utpattikālīna": ['mw'],
    "utpattimat": ['mw'],
    "utpattiprakaraṇa": ['mw'],
    "utpattiprayoga": ['mw'],
    "utpattividhi": ['mw'],
    "utpattivyañjaka": ['cae', 'mw'],
    "utpattivākya": ['mw'],
    "utpattiśiṣṭa": ['mw'],
    "utpattiḥ": ['ap90'],
    "utpattra": ['bhs', 'mw'],
    "utpatāka": ['ap90', 'ddsa', 'mw'],
    "utpatākā": ['mw'],
    "utpatākādhvaja": ['mw'],
    "utpavana": ['cae', 'ddsa', 'mw'],
    "utpavanaṃ": ['ap90'],
    "utpavitṛ": ['ap90', 'cae', 'mw'],
    "utpaś": ['mw'],
    "utpaśya": ['ap90', 'mw'],
    "utpaṭ": ['ap90', 'mw'],
    "utpaṭa": ['mw'],
    "utpaṭaḥ": ['ap90'],
    "utphal": ['ap90', 'mw'],
    "utphala": ['mw'],
    "utphalaṃ": ['ap90'],
    "utpharati": ['bhs'],
    "utphaṇa": ['mw'],
    "utphikā": ['bhs'],
    "utphuliṅga": ['mw'],
    "utphulla": ['ap90', 'cae', 'ddsa', 'mw'],
    "utphāla": ['cae', 'ddsa', 'mw'],
    "utphālaḥ": ['ap90'],
    "utpiba": ['mw'],
    "utpika": ['bhs'],
    "utpipāna": ['mw'],
    "utpitsu": ['mw'],
    "utpiñja": ['ddsa', 'mw'],
    "utpiñjala": ['mw'],
    "utpiñjalaka": ['mw'],
    "utpiñjara": ['mw'],
    "utpiñjarībhūta": ['mw'],
    "utpiṃjara": ['ap90'],
    "utpiṃṣṭa": ['cae'],
    "utpiṇḍa": ['bhs', 'mw'],
    "utpiṇḍita": ['mw'],
    "utpiṣ": ['ap90', 'mw'],
    "utpiṣṭa": ['ap90', 'mw'],
    "utplava": ['bhs', 'mw'],
    "utplavana": ['ddsa', 'mw'],
    "utplavanaṃ": ['ap90'],
    "utplavaḥ": ['ap90'],
    "utplavā": ['mw'],
    "utplu": ['ap90', 'mw'],
    "utpluta": ['mw'],
    "utplutya": ['mw'],
    "utplāva": ['bhs'],
    "utplāvaka": ['bhs'],
    "utplāvana": ['bhs'],
    "utplāvayati": ['bhs'],
    "utpoṣadha": ['mw'],
    "utprabandha": ['cae'],
    "utprabaṃdha": ['ap90'],
    "utprabha": ['ap90', 'mw'],
    "utprabhātīya": ['mw'],
    "utprasava": ['mw'],
    "utprasavaḥ": ['ap90'],
    "utpraveṣṭṛ": ['mw'],
    "utpraveṣṭṛtva": ['mw'],
    "utpravāla": ['mw'],
    "utprekṣ": ['ap90', 'mw'],
    "utprekṣaka": ['mw'],
    "utprekṣaṇa": ['cae', 'ddsa', 'mw'],
    "utprekṣaṇaṃ": ['ap90'],
    "utprekṣaṇīya": ['mw'],
    "utprekṣita": ['mw'],
    "utprekṣitopamā": ['cae', 'mw'],
    "utprekṣya": ['mw'],
    "utprekṣā": ['ap90', 'cae', 'mw'],
    "utprekṣādhvani": ['mw'],
    "utprekṣākṣepa": ['mw'],
    "utprekṣāvallabha": ['mw'],
    "utprekṣāvayava": ['mw'],
    "utpru": ['mw'],
    "utpruṣ": ['ap90', 'mw'],
    "utprāsa": ['cae', 'mw'],
    "utprāsana": ['mw'],
    "utprāsaya": ['mw'],
    "utprāsayati": ['bhs'],
    "utprāsaḥ": ['ap90'],
    "utprāśanaṃ": ['ap90'],
    "utpuccha": ['ap90', 'mw'],
    "utpucchaya": ['mw'],
    "utpucchayate": ['ap90'],
    "utpulaka": ['ap90', 'mw'],
    "utpupluṣā": ['mw'],
    "utpuñjaya": ['mw'],
    "utpuṃsana": ['mw'],
    "utpuṃsaya": ['mw'],
    "utpuṭa": ['ap90', 'mw'],
    "utpuṭaka": ['mw'],
    "utpuṭakaḥ": ['ap90'],
    "utpyai": ['mw'],
    "utpā": ['mw'],
    "utpācita": ['mw'],
    "utpāda": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "utpādaka": ['ap90', 'cae', 'mw'],
    "utpādana": ['ap90', 'cae', 'mw'],
    "utpādapūrva": ['mw'],
    "utpādayati": ['bhs'],
    "utpādayitavya": ['mw'],
    "utpādayitṛ": ['mw'],
    "utpādaśayāna": ['mw'],
    "utpādika": ['bhs'],
    "utpādikā": ['ap90', 'mw'],
    "utpādin": ['ap90', 'cae', 'mw'],
    "utpādita": ['mw'],
    "utpādya": ['mw'],
    "utpādyamāna": ['mw'],
    "utpādyotpādakatā": ['mw'],
    "utpālikā": ['mw'],
    "utpālī": ['ap90', 'mw'],
    "utpāra": ['mw'],
    "utpāram": ['mw'],
    "utpāraṇa": ['mw'],
    "utpāraṇaṃ": ['ap90'],
    "utpāta": ['bhs', 'cae', 'ddsa', 'mw'],
    "utpātaka": ['ap90', 'mw'],
    "utpātalakṣaṇa": ['mw'],
    "utpātaḥ": ['ap90'],
    "utpātika": ['mw'],
    "utpātin": ['mw'],
    "utpāva": ['mw'],
    "utpāvaḥ": ['ap90'],
    "utpāṇḍūtpāṇḍu": ['bhs'],
    "utpāṭa": ['bhs', 'mw'],
    "utpāṭaka": ['bhs', 'mw'],
    "utpāṭakaḥ": ['ap90'],
    "utpāṭana": ['cae', 'ddsa', 'mw'],
    "utpāṭanaṃ": ['ap90'],
    "utpāṭayoga": ['mw'],
    "utpāṭaḥ": ['ap90'],
    "utpāṭikā": ['ap90', 'mw'],
    "utpāṭin": ['ap90', 'cae', 'mw'],
    "utpāṭita": ['mw'],
    "utpāṭya": ['mw'],
    "utpīna": ['mw'],
    "utpīḍ": ['ap90', 'mw'],
    "utpīḍa": ['ap90', 'cae', 'mw'],
    "utpīḍana": ['mw'],
    "utpīḍanaṃ": ['ap90'],
    "utpīḍita": ['mw'],
    "utpīḍya": ['mw'],
    "utpū": ['ap90', 'mw'],
    "utpūta": ['mw'],
    "utpṛ": ['mw'],
    "utpṛṣṭi": ['mw'],
    "utpṝ": ['mw'],
    "utrasta": ['cped'],
    "utrāsa": ['cped'],
    "utrāsi": ['cped'],
    "utrāsin": ['cped'],
    "utsa": ['cae', 'ddsa', 'gra', 'mw'],
    "utsad": ['ap90', 'mw'],
    "utsada": ['bhs', 'mw'],
    "utsadana": ['bhs'],
    "utsadhi": ['cae', 'ddsa', 'gra', 'mw'],
    "utsah": ['ap90', 'mw'],
    "utsaha": ['mw'],
    "utsahanatā": ['bhs'],
    "utsahanā": ['bhs'],
    "utsajati": ['bhs'],
    "utsaktha": ['ap90', 'mw'],
    "utsaktikā": ['bhs'],
    "utsanna": ['ap90', 'bhs', 'cae', 'mw'],
    "utsannayajña": ['mw'],
    "utsara": ['mw'],
    "utsaraḥ": ['ap90'],
    "utsaraṇa": ['bhs', 'mw'],
    "utsarga": ['cae', 'ddsa', 'mw'],
    "utsargam": ['mw'],
    "utsargamayūkha": ['mw'],
    "utsarganirṇaya": ['mw'],
    "utsargapaddhati": ['mw'],
    "utsargasamiti": ['mw'],
    "utsargatas": ['mw'],
    "utsargataḥ": ['ap90'],
    "utsargaḥ": ['ap90'],
    "utsargin": ['ap90', 'mw'],
    "utsarj": ['mw'],
    "utsarjam": ['mw'],
    "utsarjana": ['cae', 'mw'],
    "utsarjanaprayoga": ['mw'],
    "utsarjanaṃ": ['ap90'],
    "utsarpa": ['mw'],
    "utsarpaḥ": ['ap90'],
    "utsarpaṇa": ['cae', 'ddsa', 'mw'],
    "utsarpin": ['ap90', 'cae', 'mw'],
    "utsarpita": ['bhs'],
    "utsarpiṇī": ['mw'],
    "utsaryati": ['bhs'],
    "utsaryā": ['ap90', 'mw'],
    "utsatti": ['mw'],
    "utsava": ['cae', 'ddsa', 'gra', 'mw'],
    "utsavapratāna": ['mw'],
    "utsavapriya": ['cae', 'mw'],
    "utsavasaṃketa": ['mw'],
    "utsavavidhi": ['mw'],
    "utsavaḥ": ['ap90'],
    "utsavika": ['bhs'],
    "utsavāya": ['ddsa'],
    "utsañjana": ['mw'],
    "utsaḥ": ['ap90'],
    "utsaṃgaḥ": ['ap90'],
    "utsaṃgin": ['ap90'],
    "utsaṃgita": ['ap90'],
    "utsaṃjanaṃ": ['ap90'],
    "utsaṃkalita": ['ap90'],
    "utsaṅga": ['bhs', 'cae', 'ddsa', 'mw'],
    "utsaṅgaka": ['mw'],
    "utsaṅgapādatā": ['mw'],
    "utsaṅgavat": ['mw'],
    "utsaṅgin": ['mw'],
    "utsaṅginī": ['mw'],
    "utsaṅgita": ['mw'],
    "utsaṅgādi": ['mw'],
    "utsecana": ['mw'],
    "utsecanaṃ": ['ap90'],
    "utsedha": ['ap90', 'cae', 'ddsa', 'mw'],
    "utsedhavistāratas": ['mw'],
    "utseka": ['cae', 'ddsa', 'mw'],
    "utsekaḥ": ['ap90'],
    "utsekin": ['ap90', 'mw'],
    "utsekya": ['mw'],
    "utsi": ['mw'],
    "utsic": ['ap90', 'mw'],
    "utsicati": ['bhs'],
    "utsidh": ['mw'],
    "utsikta": ['ap90', 'cae', 'mw'],
    "utsiktamanas": ['cae', 'mw'],
    "utsisṛkṣu": ['mw'],
    "utsita": ['cae', 'mw'],
    "utsiv": ['mw'],
    "utsiṣṭa": ['bhs'],
    "utskhalati": ['bhs'],
    "utsmaya": ['mw'],
    "utsmayaḥ": ['ap90'],
    "utsmayitvā": ['mw'],
    "utsmi": ['ap90', 'mw'],
    "utsmita": ['mw'],
    "utsnehana": ['mw'],
    "utsnā": ['mw'],
    "utsnāna": ['mw'],
    "utsnāta": ['mw'],
    "utsnāya": ['mw'],
    "utsoḍhi": ['bhs'],
    "utsphura": ['cae'],
    "utspṛś": ['mw'],
    "utsrasta": ['cae'],
    "utsraṣṭavya": ['ddsa', 'mw'],
    "utsraṣṭukāma": ['mw'],
    "utsrotas": ['mw'],
    "utsrāvin": ['ddsa'],
    "utstana": ['mw'],
    "utsthala": ['ddsa', 'mw'],
    "utstīrya": ['bhs'],
    "utsuka": ['ap90', 'cae', 'ddsa', 'mw'],
    "utsukatva": ['mw'],
    "utsukatā": ['ap90', 'mw'],
    "utsukavadana": ['cae'],
    "utsukay": ['cae'],
    "utsukaya": ['ddsa'],
    "utsukayati": ['ap90'],
    "utsukha": ['bhs'],
    "utsukya": ['bhs'],
    "utsukāya": ['mw'],
    "utsukāyate": ['ap90'],
    "utsvana": ['ap90', 'mw'],
    "utsvapna": ['mw'],
    "utsvapnāy": ['cae'],
    "utsvapnāya": ['ddsa', 'mw'],
    "utsvapnāyate": ['ap90'],
    "utsvapnāyita": ['mw'],
    "utsvedana": ['mw'],
    "utsya": ['ap90', 'mw'],
    "utsyūta": ['mw'],
    "utsāda": ['mw'],
    "utsādaka": ['ap90', 'mw'],
    "utsādana": ['cae', 'ddsa', 'mw'],
    "utsādanaṃ": ['ap90'],
    "utsādanīya": ['ap90', 'mw'],
    "utsādayitavya": ['mw'],
    "utsādaḥ": ['ap90'],
    "utsādhana": ['mw'],
    "utsādi": ['mw'],
    "utsādin": ['mw'],
    "utsādita": ['ap90', 'mw'],
    "utsādya": ['mw'],
    "utsāha": ['cae', 'ddsa', 'mw'],
    "utsāhagātratā": ['mw'],
    "utsāhaka": ['ap90', 'mw'],
    "utsāhakāraṇa": ['cae'],
    "utsāhana": ['bhs', 'mw'],
    "utsāhanaṃ": ['ap90'],
    "utsāhanī": ['bhs'],
    "utsāhasaṃpanna": ['mw'],
    "utsāhavardhana": ['mw'],
    "utsāhavat": ['mw'],
    "utsāhayati": ['bhs'],
    "utsāhayitṛ": ['cae'],
    "utsāhayoga": ['cae', 'mw'],
    "utsāhaśakti": ['mw'],
    "utsāhaśauryadhanasāhasavat": ['mw'],
    "utsāhaḥ": ['ap90'],
    "utsāhin": ['ap90', 'mw'],
    "utsāraka": ['bhs', 'mw'],
    "utsārakaḥ": ['ap90'],
    "utsārayati": ['bhs'],
    "utsāraṇa": ['bhs', 'ddsa', 'mw'],
    "utsāraṇaṃ": ['ap90'],
    "utsāraṇā": ['mw'],
    "utsāraṇīya": ['mw'],
    "utsārin": ['mw'],
    "utsārita": ['mw'],
    "utsārya": ['mw'],
    "utsīdana": ['bhs'],
    "utsū": ['mw'],
    "utsūra": ['mw'],
    "utsūraḥ": ['ap90'],
    "utsūrya": ['mw'],
    "utsūtra": ['ap90', 'ddsa', 'mw'],
    "utsūḍhi": ['bhs'],
    "utsṛ": ['ap90', 'mw'],
    "utsṛcita": ['bhs'],
    "utsṛj": ['ap90', 'mw'],
    "utsṛjana": ['bhs'],
    "utsṛjya": ['mw'],
    "utsṛjyate": ['bhs'],
    "utsṛp": ['ap90', 'mw'],
    "utsṛta": ['bhs', 'mw'],
    "utsṛṣṭa": ['ap90', 'mw'],
    "utsṛṣṭaloman": ['ddsa'],
    "utsṛṣṭapaśu": ['mw'],
    "utsṛṣṭavat": ['mw'],
    "utsṛṣṭi": ['cae', 'ddsa', 'mw'],
    "utsṛṣṭikārika": ['mw'],
    "utsṛṣṭikāṅka": ['mw'],
    "utsṛṣṭiḥ": ['ap90'],
    "utsṛṣṭāgni": ['mw'],
    "utta": ['ap90', 'bhs', 'mw'],
    "uttabdha": ['cae', 'ddsa', 'mw'],
    "uttabdhi": ['mw'],
    "uttabhita": ['cae', 'mw'],
    "uttaka": ['bhs'],
    "uttakṣ": ['mw'],
    "uttalita": ['ap90'],
    "uttam": ['ap90', 'mw'],
    "uttama": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "uttamabala": ['mw'],
    "uttamacaritra": ['mw'],
    "uttamadarśana": ['mw'],
    "uttamagandhāḍhya": ['ddsa', 'mw'],
    "uttamagāya": ['mw'],
    "uttamajana": ['cae', 'mw'],
    "uttamakulīna": ['cped'],
    "uttamalābha": ['mw'],
    "uttamam": ['mw'],
    "uttamamaṇi": ['mw'],
    "uttamanaṃ": ['ap90'],
    "uttamapada": ['mw'],
    "uttamaphalinī": ['mw'],
    "uttamaporisa": ['cped'],
    "uttamapurisa": ['cped'],
    "uttamapuruṣa": ['cae', 'mw'],
    "uttamapūruṣa": ['cae', 'mw'],
    "uttamarṇa": ['cae', 'ddsa', 'mw'],
    "uttamarṇika": ['cae', 'mw'],
    "uttamarṇin": ['mw'],
    "uttamasaṃgraha": ['mw'],
    "uttamastrīsaṃgrahaṇa": ['mw'],
    "uttamasukha": ['mw'],
    "uttamasāhasa": ['cae', 'mw'],
    "uttamatejas": ['cae', 'mw'],
    "uttamattha": ['cped'],
    "uttamatva": ['mw'],
    "uttamatā": ['ap90', 'mw'],
    "uttamaudārya": ['mw'],
    "uttamaujas": ['cae', 'ddsa', 'mw'],
    "uttamavarṇa": ['cae', 'ddsa', 'mw'],
    "uttamavayasa": ['mw'],
    "uttamaveṣa": ['mw'],
    "uttamavid": ['mw'],
    "uttamavida": ['cae'],
    "uttamaśloka": ['mw'],
    "uttamaślokatīrtha": ['mw'],
    "uttamaśruta": ['mw'],
    "uttamaśākha": ['mw'],
    "uttamaśākhīya": ['mw'],
    "uttamaṅga": ['cped'],
    "uttambh": ['mw'],
    "uttambha": ['mw'],
    "uttambhana": ['mw'],
    "uttambhita": ['mw'],
    "uttambhitavya": ['mw'],
    "uttamopapada": ['mw'],
    "uttamottama": ['mw'],
    "uttamottamaka": ['mw'],
    "uttamottamika": ['mw'],
    "uttamottarīya": ['mw'],
    "uttamā": ['mw'],
    "uttamādhama": ['mw'],
    "uttamādhamamadhyama": ['mw'],
    "uttamāha": ['mw'],
    "uttamāmbhas": ['mw'],
    "uttamāraṇī": ['mw'],
    "uttamārdha": ['mw'],
    "uttamārdhya": ['mw'],
    "uttamāyia": ['gra'],
    "uttamāyya": ['ap90', 'gra', 'mw'],
    "uttamāṅga": ['cae', 'ddsa', 'mw'],
    "uttamīya": ['ap90', 'mw'],
    "uttan": ['ap90', 'mw'],
    "uttanta": ['cped'],
    "uttanūruha": ['bhs', 'mw'],
    "uttap": ['ap90', 'mw'],
    "uttapana": ['mw'],
    "uttapanīya": ['mw'],
    "uttapta": ['ap90', 'bhs', 'cae', 'mw'],
    "uttaptarāṣṭra": ['bhs'],
    "uttaptavaiḍūryanirbhāsa": ['bhs', 'mw'],
    "uttaptavīrya": ['bhs'],
    "uttaptaśrī": ['bhs'],
    "uttara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "uttarabarhis": ['mw'],
    "uttarabhadrapadā": ['mw'],
    "uttarabhaktika": ['mw'],
    "uttarabhādrapadā": ['mw'],
    "uttarabhāga": ['mw'],
    "uttaracchada": ['ddsa', 'mw'],
    "uttaradanta": ['mw'],
    "uttaradatta": ['bhs'],
    "uttaradeśa": ['mw'],
    "uttaradharma": ['mw'],
    "uttaradheya": ['mw'],
    "uttaradhurīṇa": ['mw'],
    "uttaradhāraya": ['mw'],
    "uttaradigīśa": ['mw'],
    "uttaradikstha": ['mw'],
    "uttaradiś": ['mw'],
    "uttaradru": ['mw'],
    "uttaradāyaka": ['cae', 'mw'],
    "uttaraga": ['mw'],
    "uttaraghṛta": ['mw'],
    "uttaragrantha": ['mw'],
    "uttaragārgya": ['mw'],
    "uttaragītā": ['mw'],
    "uttarahanu": ['mw'],
    "uttaraja": ['mw'],
    "uttarajyotiṣa": ['mw'],
    "uttarajyā": ['mw'],
    "uttaraka": ['bhs'],
    "uttarakalpa": ['mw'],
    "uttarakalā": ['bhs'],
    "uttarakaurava": ['bhs'],
    "uttarakhaṇḍa": ['mw'],
    "uttarakhaṇḍana": ['mw'],
    "uttarakosala": ['cae'],
    "uttarakośalā": ['mw'],
    "uttarakrama": ['mw'],
    "uttarakriyā": ['mw'],
    "uttarakuru": ['bhs', 'cae', 'mw'],
    "uttarakurudvīpalipi": ['bhs'],
    "uttarakururāja": ['bhs'],
    "uttarakāla": ['cae', 'mw'],
    "uttarakālam": ['mw'],
    "uttarakālatas": ['mw'],
    "uttarakāmākhyatantra": ['mw'],
    "uttarakāya": ['ddsa', 'mw'],
    "uttarakāṇḍa": ['mw'],
    "uttarala": ['cae', 'ddsa', 'mw'],
    "uttaralakṣaṇa": ['mw'],
    "uttaralakṣman": ['mw'],
    "uttaralita": ['mw'],
    "uttaraloman": ['ddsa', 'mw'],
    "uttaralāya": ['ddsa', 'mw'],
    "uttaralīkṛ": ['mw'],
    "uttaram": ['bhs', 'cae', 'ddsa', 'mw'],
    "uttaramandrā": ['mw'],
    "uttaramandrādyā": ['mw'],
    "uttaramantrin": ['bhs'],
    "uttaramanuṣyadharma": ['bhs'],
    "uttaramati": ['bhs', 'mw'],
    "uttaramānasa": ['mw'],
    "uttaramānuṣa": ['bhs'],
    "uttaramārga": ['mw'],
    "uttaramātra": ['mw'],
    "uttaramīmāṃsā": ['cae', 'mw'],
    "uttaramūla": ['mw'],
    "uttaranta": ['cped'],
    "uttaranābhi": ['mw'],
    "uttaranārāyaṇa": ['mw'],
    "uttarapada": ['cae', 'mw'],
    "uttarapadakīya": ['mw'],
    "uttarapadika": ['mw'],
    "uttarapadārthapradhāna": ['mw'],
    "uttarapakṣa": ['cae', 'mw'],
    "uttarapakṣatva": ['mw'],
    "uttarapakṣatā": ['mw'],
    "uttaraparvata": ['mw'],
    "uttarapatha": ['mw'],
    "uttarapathika": ['mw'],
    "uttarapaścima": ['mw'],
    "uttarapaścimā": ['mw'],
    "uttarapaścārdha": ['mw'],
    "uttarapaṭa": ['mw'],
    "uttaraphalgunī": ['mw'],
    "uttaraphālgunī": ['mw'],
    "uttarapracchada": ['mw'],
    "uttarapratyuttara": ['mw'],
    "uttaraproṣṭhapadā": ['mw'],
    "uttarapurastāt": ['mw'],
    "uttarapurāṇa": ['mw'],
    "uttarapāda": ['mw'],
    "uttarapāsaka": ['cped'],
    "uttarapūjā": ['mw'],
    "uttarapūrva": ['mw'],
    "uttarapūrvā": ['mw'],
    "uttararahita": ['mw'],
    "uttararāmacampū": ['mw'],
    "uttararāmacarita": ['cae', 'mw'],
    "uttararāmacaritra": ['cae', 'mw'],
    "uttararūpa": ['mw'],
    "uttarasaktha": ['mw'],
    "uttarasaṃjñita": ['mw'],
    "uttarasetu": ['cped'],
    "uttarasuve": ['cped'],
    "uttarasve": ['cped'],
    "uttarasādhaka": ['mw'],
    "uttarasākṣin": ['mw'],
    "uttarasīsaka": ['cped'],
    "uttaratantra": ['mw'],
    "uttaratara": ['ap90', 'mw'],
    "uttaratas": ['cae', 'ddsa', 'mw'],
    "uttarataḥ": ['ap90'],
    "uttarataḥpaścāt": ['mw'],
    "uttarati": ['bhs', 'cped'],
    "uttarato": ['cped'],
    "uttaratra": ['ap90', 'mw'],
    "uttaratāpanīya": ['mw'],
    "uttarauṣṭha": ['cae', 'mw'],
    "uttaravallī": ['mw'],
    "uttaravasti": ['mw'],
    "uttaravastra": ['mw'],
    "uttaravayasa": ['mw'],
    "uttaravedi": ['cae', 'mw'],
    "uttaravedī": ['cae'],
    "uttaravādin": ['mw'],
    "uttaravāsas": ['mw'],
    "uttaravīthi": ['mw'],
    "uttaraya": ['mw'],
    "uttarayuga": ['mw'],
    "uttaraśaila": ['mw'],
    "uttaraśalaṅkaṭa": ['mw'],
    "uttaraśrī": ['bhs'],
    "uttaraśānti": ['mw'],
    "uttaraṃga": ['ap90', 'mw'],
    "uttaraṃgaya": ['mw'],
    "uttaraṃgaṃ": ['ap90'],
    "uttaraṃgi": ['ap90', 'mw'],
    "uttaraṃmanuṣyadharma": ['bhs'],
    "uttaraṅga": ['cae', 'ddsa'],
    "uttaraṅgin": ['cae'],
    "uttaraṇa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "uttaraṇasetu": ['cae', 'mw'],
    "uttaraṇī": ['cped'],
    "uttaredyus": ['cae', 'ddsa', 'mw'],
    "uttaredyuḥ": ['ap90'],
    "uttarena": ['cped'],
    "uttarenamukha": ['cped'],
    "uttarenta": ['cped'],
    "uttarenābhimukha": ['cped'],
    "uttaretarā": ['mw'],
    "uttareṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "uttari": ['bhs', 'cped'],
    "uttari-karaṇīya": ['cped'],
    "uttaribhaṅga": ['cped'],
    "uttarika": ['bhs'],
    "uttarikaraṇīya": ['bhs'],
    "uttarikā": ['bhs', 'mw'],
    "uttarim": ['bhs'],
    "uttarimanussadhamma": ['cped'],
    "uttarin": ['ap90', 'mw'],
    "uttaritara": ['cped'],
    "uttarituṁ": ['cped'],
    "uttaritvā": ['cped'],
    "uttariyati": ['cped'],
    "uttariṁ": ['cped'],
    "uttarjana": ['mw'],
    "uttarjanaṃ": ['ap90'],
    "uttarjanīka": ['mw'],
    "uttarottara": ['cae', 'ddsa', 'mw'],
    "uttarottaram": ['mw'],
    "uttarottarapracchalā": ['mw'],
    "uttarottaravaktṛ": ['mw'],
    "uttarottarin": ['mw'],
    "uttarottarokta": ['cae'],
    "uttaroṣṭha": ['cae', 'mw'],
    "uttarya": ['bhs'],
    "uttarā": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "uttarābhimukha": ['mw'],
    "uttarābhāsa": ['mw'],
    "uttarābhāsatva": ['mw'],
    "uttarābhāsatā": ['mw'],
    "uttarādhara": ['cae', 'ddsa', 'mw'],
    "uttarādharavivara": ['mw'],
    "uttarādhikāra": ['mw'],
    "uttarādhikāratva": ['mw'],
    "uttarādhikāratā": ['mw'],
    "uttarādhikārin": ['mw'],
    "uttarādri": ['mw'],
    "uttarāgamana": ['bhs'],
    "uttarāgāra": ['mw'],
    "uttarāha": ['mw'],
    "uttarāhi": ['ap90', 'cae', 'ddsa', 'mw'],
    "uttarālumpa": ['cped'],
    "uttarām": ['cae', 'ddsa'],
    "uttarāmnāya": ['mw'],
    "uttarāmukha": ['cped'],
    "uttarāpatha": ['cae', 'ddsa', 'mw'],
    "uttarāpathaka": ['bhs'],
    "uttarāraṇi": ['cae', 'mw'],
    "uttarārcika": ['mw'],
    "uttarārdha": ['cae', 'mw'],
    "uttarārdhapaścārdha": ['mw'],
    "uttarārdhapūrvārdha": ['mw'],
    "uttarārdhya": ['mw'],
    "uttarārka": ['mw'],
    "uttarārtha": ['cae', 'mw'],
    "uttarāsad": ['mw'],
    "uttarāsaṅga": ['cae', 'cped', 'mw'],
    "uttarāt": ['cae', 'ddsa', 'gra', 'mw'],
    "uttarātsad": ['mw'],
    "uttarāttāt": ['gra', 'mw'],
    "uttarāvant": ['cae'],
    "uttarāvat": ['mw'],
    "uttarāyaṇa": ['cae', 'ddsa', 'mw'],
    "uttarāśmaka": ['mw'],
    "uttarāśman": ['mw'],
    "uttarāśramin": ['mw'],
    "uttarāśrita": ['mw'],
    "uttarāśā": ['mw'],
    "uttarāśādhipati": ['mw'],
    "uttarāḷumpa": ['cped'],
    "uttarāḷuva": ['cped'],
    "uttarāṃsa": ['mw'],
    "uttarāṅga": ['mw'],
    "uttarāṣāḍhā": ['mw'],
    "uttarī": ['bhs'],
    "uttarīya": ['ddsa', 'mw'],
    "uttarīyaka": ['mw'],
    "uttarīyatā": ['mw'],
    "uttarīyaṃ": ['ap90'],
    "uttasa": ['cped'],
    "uttasat": ['cped'],
    "uttasati": ['cped'],
    "uttasitvā": ['cped'],
    "uttata": ['mw'],
    "uttathya": ['mw'],
    "uttaṃbh": ['ap90'],
    "uttaṃbhaḥ": ['ap90'],
    "uttaṃsa": ['cae', 'ddsa', 'mw'],
    "uttaṃsaka": ['mw'],
    "uttaṃsay": ['cae'],
    "uttaṃsaya": ['ddsa', 'mw'],
    "uttaṃsayati": ['ap90'],
    "uttaṃsaḥ": ['ap90'],
    "uttaṃsika": ['mw'],
    "uttaṃsita": ['ap90', 'mw'],
    "uttaṅka": ['cae', 'ddsa', 'mw'],
    "uttaṅkamegha": ['mw'],
    "uttaṭa": ['ap90', 'ddsa', 'mw'],
    "uttejaka": ['ap90', 'mw'],
    "uttejana": ['mw'],
    "uttejanaṃ": ['ap90'],
    "uttejanā": ['ddsa'],
    "uttejita": ['ap90', 'mw'],
    "utterita": ['mw'],
    "utteritaṃ": ['ap90'],
    "uttha": ['ap90', 'cae', 'ddsa', 'mw'],
    "utthala": ['bhs'],
    "utthapeti": ['bhs'],
    "uttharati": ['bhs'],
    "utthita": ['ap90', 'cae', 'mw'],
    "utthitatā": ['mw'],
    "utthiti": ['mw'],
    "utthitiḥ": ['ap90'],
    "utthitāṅguli": ['mw'],
    "utthā": ['ap90', 'mw'],
    "utthāna": ['ap90', 'cae', 'mw'],
    "utthānahīna": ['mw'],
    "utthānaikādaśī": ['mw'],
    "utthānavat": ['mw'],
    "utthānavīra": ['cae', 'mw'],
    "utthānayukta": ['mw'],
    "utthānaśīla": ['mw'],
    "utthānaśīlin": ['mw'],
    "utthānīya": ['mw'],
    "utthāpaka": ['ap90', 'mw'],
    "utthāpana": ['bhs', 'cae', 'mw'],
    "utthāpanaṃ": ['ap90'],
    "utthāpanī": ['mw'],
    "utthāpanīya": ['mw'],
    "utthāpayitṛ": ['mw'],
    "utthāpita": ['mw'],
    "utthāpya": ['ap90', 'mw'],
    "utthātavya": ['mw'],
    "utthātṛ": ['ap90', 'mw'],
    "utthāya": ['mw'],
    "utthāyam": ['mw'],
    "utthāyin": ['ap90', 'cae', 'mw'],
    "utthāyitva": ['mw'],
    "utthāyotthāya": ['mw'],
    "uttij": ['ap90', 'mw'],
    "uttima": ['bhs'],
    "uttitīrṣu": ['ddsa', 'mw'],
    "uttiya": ['bhs'],
    "uttiṅga": ['mw'],
    "uttiṇa": ['cped'],
    "uttiṇīkaroti": ['bhs'],
    "uttiṇṇa": ['cped'],
    "uttiṣṭhate": ['bhs'],
    "uttiṣṭhāsā": ['mw'],
    "uttiṭṭhapatta": ['cped'],
    "uttiṭṭhapiṇḍa": ['cped'],
    "uttiṭṭhati": ['cped'],
    "uttmroṣṭha, uttarauṣṭha": ['ddsa'],
    "uttolana": ['mw'],
    "uttolanaṃ": ['ap90'],
    "uttolita": ['mw'],
    "uttoraṇa": ['ap90', 'ddsa', 'mw'],
    "uttoraṇapatāka": ['mw'],
    "uttras": ['ap90', 'mw'],
    "uttrasta": ['cae', 'mw'],
    "uttripada": ['mw'],
    "uttripadaṃ": ['ap90'],
    "uttruṭ": ['mw'],
    "uttruṭita": ['mw'],
    "uttrāsa": ['bhs', 'mw'],
    "uttrāsaka": ['mw'],
    "uttrāsana": ['bhs'],
    "uttrāsanī": ['bhs'],
    "uttrāsaḥ": ['ap90'],
    "uttu": ['mw'],
    "uttud": ['mw'],
    "uttuda": ['mw'],
    "uttul": ['ap90', 'mw'],
    "uttuttariṁ": ['cped'],
    "uttuṃga": ['ap90'],
    "uttuṃḍitaṃ": ['ap90'],
    "uttuṅga": ['cae', 'ddsa', 'mw'],
    "uttuṅgatva": ['mw'],
    "uttuṅgatā": ['mw'],
    "uttuṅgita": ['mw'],
    "uttuṇḍita": ['mw'],
    "uttuṣa": ['mw'],
    "uttuṣaḥ": ['ap90'],
    "uttyaj": ['mw'],
    "uttyakta": ['ap90', 'mw'],
    "uttyāga": ['mw'],
    "uttyāgaḥ": ['ap90'],
    "uttāla": ['ap90', 'cae', 'ddsa', 'mw'],
    "uttālībhavana": ['mw'],
    "uttāna": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "uttānabarhis": ['mw'],
    "uttānahasta": ['gra', 'mw'],
    "uttānahaya": ['mw'],
    "uttānahṛdaya": ['cae', 'mw'],
    "uttānaka": ['bhs', 'cped', 'mw'],
    "uttānakaḥ": ['ap90'],
    "uttānakuttānaka": ['cped'],
    "uttānakūrmaka": ['mw'],
    "uttānamukha": ['cped'],
    "uttānapad": ['gra', 'mw'],
    "uttānaparṇa": ['gra', 'mw'],
    "uttānaparṇaka": ['mw'],
    "uttānapattraka": ['mw'],
    "uttānapāda": ['mw'],
    "uttānapādaja": ['mw'],
    "uttānapāṇidvaya": ['mw'],
    "uttānarecita": ['mw'],
    "uttānaseyyaka": ['cped'],
    "uttānaśaya": ['mw'],
    "uttānaśāyin": ['mw'],
    "uttānaśīvan": ['mw'],
    "uttānikamma": ['cped'],
    "uttānikaroti": ['cped'],
    "uttānikata": ['cped'],
    "uttānikā": ['ap90', 'mw'],
    "uttānita": ['ap90', 'mw'],
    "uttānobhāsa": ['cped'],
    "uttānārtha": ['mw'],
    "uttānīkamma": ['cped'],
    "uttānīkarman": ['bhs'],
    "uttānīkaroti": ['bhs', 'cped'],
    "uttānīkata": ['cped'],
    "uttānīkatabba": ['cped'],
    "uttānīkayiramāna": ['cped'],
    "uttānīkātuṁ": ['cped'],
    "uttānīkātvā": ['cped'],
    "uttānīkṛ": ['cae', 'mw'],
    "uttānīkṛbhū": ['mw'],
    "uttāpa": ['ddsa', 'mw'],
    "uttāpana": ['mw'],
    "uttāpanarājamati": ['bhs'],
    "uttāpayati": ['bhs'],
    "uttāpaḥ": ['ap90'],
    "uttāpita": ['ap90', 'mw'],
    "uttāra": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "uttāraka": ['mw'],
    "uttārakaḥ": ['ap90'],
    "uttārasetu": ['cped'],
    "uttārayati": ['bhs'],
    "uttārayitar": ['bhs'],
    "uttāraṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "uttāresi": ['cped'],
    "uttāresuṁ": ['cped'],
    "uttārin": ['ap90', 'mw'],
    "uttārya": ['ap90', 'mw'],
    "uttāsa": ['cped'],
    "uttāsava": ['cped'],
    "uttāsavat": ['cped'],
    "uttāsayati": ['cped'],
    "uttāsenta": ['cped'],
    "uttāseti": ['cped'],
    "uttāsi": ['cped'],
    "uttāsin": ['cped'],
    "uttīram": ['mw'],
    "uttīrya": ['mw'],
    "uttīrṇa": ['ap90', 'cae', 'mw'],
    "uttīrṇavikṛti": ['mw'],
    "uttṛd": ['mw'],
    "uttṛṇīkaroti": ['bhs'],
    "uttṝ": ['ap90', 'mw'],
    "utu": ['cped'],
    "utuddhata": ['cped'],
    "utuddhaṭa": ['cped'],
    "utukāla": ['cped'],
    "utunī": ['cped'],
    "utupariṇāma": ['cped'],
    "utupariṇāmi": ['cped'],
    "utupariṇāmin": ['cped'],
    "utuveramaṇī": ['cped'],
    "utāho": ['cae', 'ddsa', 'mw'],
    "utāhosvid": ['mw'],
    "utūla": ['cae', 'mw'],
    "uvaṭa": ['mw'],
    "uve": ['mw'],
    "uviṭṭha": ['cped'],
    "uvyadha": ['bhs'],
    "uvāca": ['ddsa'],
    "uvāsa": ['ddsa'],
    "uyate": ['bhs'],
    "uyyamati": ['cped'],
    "uyyodhi": ['cped'],
    "uyyodhikā": ['cped'],
    "uyyogamukha": ['cped'],
    "uyyojana": ['cped'],
    "uyyojanikapaṭisaṁyutta": ['cped'],
    "uyyojayati": ['cped'],
    "uyyojenta": ['cped'],
    "uyyojesi": ['cped'],
    "uyyojesuṁ": ['cped'],
    "uyyojetabba": ['cped'],
    "uyyojeti": ['cped'],
    "uyyojetvā": ['cped'],
    "uyyojita": ['cped'],
    "uyyojiyamāna": ['cped'],
    "uyyuta": ['cped'],
    "uyyutta": ['cped'],
    "uyyuñjati": ['cped'],
    "uyyāna": ['cped'],
    "uyyānabhūmi": ['cped'],
    "uyyānapāla": ['cped'],
    "uyyāpeti": ['cped'],
    "uñcadeśa": ['mw'],
    "uñch": ['cae', 'ddsa', 'mw'],
    "uñcha": ['cae', 'cped', 'ddsa', 'mw'],
    "uñchabhuj": ['mw'],
    "uñchadharman": ['mw'],
    "uñchana": ['mw'],
    "uñchapattāgata": ['cped'],
    "uñchavartin": ['cae', 'mw'],
    "uñchavṛtti": ['cae', 'mw'],
    "uñchaśila": ['cae', 'mw'],
    "uñchādi": ['mw'],
    "uñchāsaka": ['cped'],
    "uññā": ['cped'],
    "uññātabba": ['cped'],
    "uśabda": ['ddsa'],
    "uśadah": ['mw'],
    "uśadhak": ['gra'],
    "uśanas": ['ap90', 'cae', 'ddsa', 'mw'],
    "uśant": ['cae'],
    "uśanā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uśat": ['ddsa', 'mw'],
    "uśata": ['mw'],
    "uśatī": ['ap90', 'mw'],
    "uśaṃgava": ['mw'],
    "uśenia": ['gra'],
    "uśenya": ['ap90', 'gra', 'mw'],
    "uśij": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uśija": ['mw'],
    "uśika": ['mw'],
    "uśrāyus": ['mw'],
    "uśvasati": ['bhs'],
    "uśāna": ['cae'],
    "uśānā": ['ap90', 'mw'],
    "uśī": ['ap90', 'bhs', 'mw'],
    "uśīnara": ['cae', 'ddsa', 'gra', 'mw'],
    "uśīnaragiri": ['mw'],
    "uśīnarāḥ": ['ap90'],
    "uśīnarāṇī": ['mw'],
    "uśīra": ['cae', 'ddsa', 'mw'],
    "uśīrabīja": ['mw'],
    "uśīragiri": ['bhs', 'mw'],
    "uśīraka": ['mw'],
    "uśīraḥ": ['ap90'],
    "uśīrika": ['ap90', 'mw'],
    "uśīrī": ['mw'],
    "uḍaya": ['bhs'],
    "uḍigalla": ['bhs'],
    "uḍra": ['mw'],
    "uḍraḥ": ['ap90'],
    "uḍu": ['cae', 'ddsa', 'mw'],
    "uḍugaṇādhipa": ['mw'],
    "uḍugaṇādhiparkṣa": ['mw'],
    "uḍuloman": ['mw'],
    "uḍumbara": ['mw'],
    "uḍumbaradalā": ['mw'],
    "uḍumbaraparṇī": ['mw'],
    "uḍumbarāvatī": ['mw'],
    "uḍumbarī": ['mw'],
    "uḍunātha": ['mw'],
    "uḍupa": ['cae', 'ddsa', 'mw'],
    "uḍupabhṛt": ['mw'],
    "uḍupasahā": ['mw'],
    "uḍupatha": ['mw'],
    "uḍupati": ['cae', 'mw'],
    "uḍurāj": ['mw'],
    "uḍuḥ": ['ap90'],
    "uḍuṃbaraḥ": ['ap90'],
    "uḍūpa": ['mw'],
    "uḍūpaḥ": ['ap90'],
    "uḍḍamara": ['cae', 'mw'],
    "uḍḍamarita": ['mw'],
    "uḍḍara": ['bhs'],
    "uḍḍayana": ['cae', 'ddsa', 'mw'],
    "uḍḍayanaṃ": ['ap90'],
    "uḍḍayati": ['cped'],
    "uḍḍepeti": ['cped'],
    "uḍḍeti": ['cped'],
    "uḍḍita": ['cped'],
    "uḍḍiyāna": ['bhs', 'mw'],
    "uḍḍiyānaka": ['bhs'],
    "uḍḍiyāṇa": ['mw'],
    "uḍḍāmara": ['ap90', 'cae', 'mw'],
    "uḍḍāmaratantra": ['mw'],
    "uḍḍāmarin": ['mw'],
    "uḍḍāpeti": ['cped'],
    "uḍḍī": ['ap90', 'mw'],
    "uḍḍīna": ['ap90', 'cae', 'mw'],
    "uḍḍīyakavi": ['mw'],
    "uḍḍīyamāna": ['mw'],
    "uḍḍīyana": ['cae', 'mw'],
    "uḍḍīyanaṃ": ['ap90'],
    "uḍḍīśa": ['mw'],
    "uḍḍīśaḥ": ['ap90'],
    "uḥ": ['ap90'],
    "uḷumpa": ['cped'],
    "uḷāra": ['cped'],
    "uḷāratama": ['cped'],
    "uḷāratta": ['cped'],
    "uḷūka": ['cped'],
    "uḷūkapakkha": ['cped'],
    "uḷūkapakkkhika": ['cped'],
    "uṃbaraḥ": ['ap90'],
    "uṃburaḥ": ['ap90'],
    "uṃbī": ['ap90'],
    "uṃch": ['ap90'],
    "uṃchanaṃ": ['ap90'],
    "uṃchaḥ": ['ap90'],
    "uṃd": ['ap90'],
    "uṃdanaṃ": ['ap90'],
    "uṃdaruḥ": ['ap90'],
    "uṃkuṇaḥ": ['ap90'],
    "uṃḍerakaḥ": ['ap90'],
    "uṃḍukaḥ": ['ap90'],
    "uṅkh": ['mw'],
    "uṅkuṇa": ['mw'],
    "uṅkāra": ['mw'],
    "uṇaka": ['ap90', 'mw'],
    "uṇha": ['cped'],
    "uṇhabhitatta": ['cped'],
    "uṇhodaka": ['cped'],
    "uṇhīsa": ['cped'],
    "uṇhīsasīsa": ['cped'],
    "uṇādi": ['cae', 'ddsa', 'mw'],
    "uṇādisūtra": ['mw'],
    "uṇādisūtravṛtti": ['mw'],
    "uṇādiḥ": ['ap90'],
    "uṇḍeraka": ['mw'],
    "uṇḍerakasraj": ['ddsa', 'mw'],
    "uṇḍuka": ['mw'],
    "uṇṇabhisi": ['cped'],
    "uṇṇamati": ['cped'],
    "uṇṇameti": ['cped'],
    "uṇṇanābhi": ['cped'],
    "uṇṇata": ['cped'],
    "uṇṇati": ['cped'],
    "uṇṇatuṇṇata": ['cped'],
    "uṇṇā": ['cped'],
    "uṇṇābhisi": ['cped'],
    "uṇṇānābhi": ['cped'],
    "uṇṇī": ['cped'],
    "uṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uṣadgu": ['mw'],
    "uṣadratha": ['mw'],
    "uṣapa": ['mw'],
    "uṣapaḥ": ['ap90'],
    "uṣar": ['gra', 'mw'],
    "uṣarbudh": ['cae', 'ddsa', 'gra', 'mw'],
    "uṣarbudha": ['mw'],
    "uṣas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uṣasta": ['mw'],
    "uṣasti": ['mw'],
    "uṣasya": ['ap90', 'ddsa', 'mw'],
    "uṣasī": ['mw'],
    "uṣat": ['mw'],
    "uṣatī": ['ap90', 'mw'],
    "uṣaḥ": ['mw'],
    "uṣaḥkala": ['mw'],
    "uṣaṃgu": ['mw'],
    "uṣaṃguḥ": ['ap90'],
    "uṣaṇa": ['mw'],
    "uṣaṇaṃ": ['ap90'],
    "uṣaṇā": ['mw'],
    "uṣeśa": ['mw'],
    "uṣidatta": ['bhs'],
    "uṣija": ['mw'],
    "uṣita": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "uṣitavant": ['bhs'],
    "uṣitavya": ['mw'],
    "uṣitaṃgavīna": ['mw'],
    "uṣitvā": ['mw'],
    "uṣma": ['mw'],
    "uṣmagata": ['bhs'],
    "uṣmaja": ['mw'],
    "uṣmaka": ['mw'],
    "uṣman": ['ap90', 'cae', 'ddsa', 'mw'],
    "uṣmapa": ['mw'],
    "uṣmasveda": ['mw'],
    "uṣmatā": ['mw'],
    "uṣmavat": ['mw'],
    "uṣmaḥ": ['ap90'],
    "uṣmaṃ": ['ap90'],
    "uṣmopagama": ['mw'],
    "uṣmāgama": ['mw'],
    "uṣmānvita": ['mw'],
    "uṣmāya": ['mw'],
    "uṣmāyaṇa": ['mw'],
    "uṣmāyaṇaḥ": ['ap90'],
    "uṣo": ['mw'],
    "uṣodevatya": ['mw'],
    "uṣojala": ['ddsa', 'mw'],
    "uṣorāga": ['mw'],
    "uṣya": ['cae', 'mw'],
    "uṣyala": ['mw'],
    "uṣā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uṣācarita": ['mw'],
    "uṣāharaṇa": ['mw'],
    "uṣākala": ['mw'],
    "uṣākara": ['mw'],
    "uṣānidāna": ['mw'],
    "uṣāpariṇaya": ['mw'],
    "uṣāpati": ['mw'],
    "uṣāramaṇa": ['mw'],
    "uṣārāgodaya": ['mw'],
    "uṣāsā": ['mw'],
    "uṣāsānaktaṃ": ['ap90'],
    "uṣāsānaktā": ['cae', 'ddsa', 'gra', 'mw'],
    "uṣāsāsūrya": ['mw'],
    "uṣīra": ['ap90', 'mw'],
    "uṣṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "uṣṇabhās": ['mw'],
    "uṣṇabhṛt": ['mw'],
    "uṣṇadīdhiti": ['mw'],
    "uṣṇadīrgham": ['cae'],
    "uṣṇaga": ['mw'],
    "uṣṇagandhā": ['mw'],
    "uṣṇaghna": ['mw'],
    "uṣṇagu": ['mw'],
    "uṣṇaka": ['ap90', 'mw'],
    "uṣṇakara": ['cae', 'mw'],
    "uṣṇakaṭuka": ['cae'],
    "uṣṇakiraṇa": ['cae', 'mw'],
    "uṣṇakāla": ['mw'],
    "uṣṇakṛt": ['mw'],
    "uṣṇam": ['mw'],
    "uṣṇamahas": ['mw'],
    "uṣṇanadī": ['mw'],
    "uṣṇanaraka": ['mw'],
    "uṣṇapa": ['mw'],
    "uṣṇaphalā": ['mw'],
    "uṣṇaraśmi": ['cae', 'mw'],
    "uṣṇaruci": ['cae', 'mw'],
    "uṣṇasamaya": ['cae', 'mw'],
    "uṣṇasparśavat": ['mw'],
    "uṣṇasundara": ['mw'],
    "uṣṇatva": ['mw'],
    "uṣṇatā": ['ap90', 'cae', 'mw'],
    "uṣṇatīrtha": ['mw'],
    "uṣṇavetālī": ['mw'],
    "uṣṇavidagdhaka": ['mw'],
    "uṣṇavāraṇa": ['mw'],
    "uṣṇavāta": ['mw'],
    "uṣṇavīrya": ['mw'],
    "uṣṇaya": ['mw'],
    "uṣṇaṃkaraṇa": ['mw'],
    "uṣṇaṃkṛtya": ['mw'],
    "uṣṇi": ['bhs', 'mw'],
    "uṣṇig": ['mw'],
    "uṣṇiggarbhā": ['mw'],
    "uṣṇih": ['ap90', 'cae', 'ddsa', 'mw'],
    "uṣṇihā": ['gra', 'mw'],
    "uṣṇikā": ['ap90', 'mw'],
    "uṣṇiman": ['ap90', 'ddsa', 'mw'],
    "uṣṇiṣa": ['bhs'],
    "uṣṇodaka": ['ddsa', 'mw'],
    "uṣṇopagama": ['mw'],
    "uṣṇoṣṇa": ['cae', 'mw'],
    "uṣṇā": ['mw'],
    "uṣṇābhigama": ['mw'],
    "uṣṇābhiprāya": ['mw'],
    "uṣṇābhiprāyin": ['mw'],
    "uṣṇāgama": ['mw'],
    "uṣṇālu": ['ap90', 'cae', 'ddsa', 'mw'],
    "uṣṇānta": ['mw'],
    "uṣṇāsaha": ['mw'],
    "uṣṇāṃśu": ['cae', 'ddsa', 'mw'],
    "uṣṇī": ['mw'],
    "uṣṇībhavati": ['bhs'],
    "uṣṇīgaṃgā": ['ap90'],
    "uṣṇīgaṅga": ['mw'],
    "uṣṇīkṛ": ['cae', 'ddsa', 'mw'],
    "uṣṇīkṛta": ['mw'],
    "uṣṇīnābha": ['mw'],
    "uṣṇīṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "uṣṇīṣabhājana": ['mw'],
    "uṣṇīṣakośasarvadharmaprabhāmaṇḍalamegha": ['bhs'],
    "uṣṇīṣapaṭṭa": ['cae', 'mw'],
    "uṣṇīṣavijaya": ['mw'],
    "uṣṇīṣavijayā": ['bhs', 'mw'],
    "uṣṇīṣaśiraskatā": ['mw'],
    "uṣṇīṣaśobhana": ['bhs'],
    "uṣṇīṣaśrī": ['bhs'],
    "uṣṇīṣaḥ": ['ap90'],
    "uṣṇīṣin": ['ap90', 'mw'],
    "uṣṇīṣārpaṇā": ['mw'],
    "uṣṭa": ['cae', 'mw'],
    "uṣṭra": ['cae', 'ddsa', 'gra', 'mw'],
    "uṣṭrabhakṣikā": ['mw'],
    "uṣṭrabhakṣā": ['mw'],
    "uṣṭradhūmaka": ['bhs'],
    "uṣṭradhūsarapucchikā": ['mw'],
    "uṣṭradhūsarapucchī": ['mw'],
    "uṣṭragrīva": ['mw'],
    "uṣṭrajihva": ['mw'],
    "uṣṭrakarṇika": ['mw'],
    "uṣṭrakhara": ['mw'],
    "uṣṭrakrośin": ['mw'],
    "uṣṭrakāṇḍī": ['mw'],
    "uṣṭraniṣadana": ['mw'],
    "uṣṭrapāda": ['bhs'],
    "uṣṭrapādikā": ['mw'],
    "uṣṭrapāla": ['mw'],
    "uṣṭrasthāna": ['mw'],
    "uṣṭrasādi": ['mw'],
    "uṣṭratva": ['mw'],
    "uṣṭravāhin": ['mw'],
    "uṣṭravāmi": ['mw'],
    "uṣṭravāmīśata": ['mw'],
    "uṣṭrayāna": ['cae', 'mw'],
    "uṣṭraśaśa": ['mw'],
    "uṣṭraśirodhara": ['mw'],
    "uṣṭraḥ": ['ap90'],
    "uṣṭrikā": ['ap90', 'bhs', 'ddsa', 'mw'],
    "uṣṭrākṛti": ['mw'],
    "uṣṭrākṣa": ['mw'],
    "uṣṭrī": ['mw'],
    "uṣṭvā": ['mw'],
    "uṣṭṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "uṭa": ['mw'],
    "uṭaja": ['cae', 'ddsa', 'mw'],
    "uṭaṃ": ['ap90'],
    "uṭh": ['ap90', 'mw'],
    "uṭṭaṅkana": ['mw'],
    "uṭṭaṅkikā": ['bhs'],
    "uṭṭaṅkita": ['cae', 'mw'],
    "uṭṭhaha": ['cped'],
    "uṭṭhahat": ['cped'],
    "uṭṭhahati": ['cped'],
    "uṭṭhahitvā": ['cped'],
    "uṭṭhapesi": ['cped'],
    "uṭṭhapesuṁ": ['cped'],
    "uṭṭhapeti": ['cped'],
    "uṭṭheti": ['cped'],
    "uṭṭhāhaka": ['cped'],
    "uṭṭhāna": ['cped'],
    "uṭṭhānaka": ['cped'],
    "uṭṭhānasampanna": ['cped'],
    "uṭṭhānava": ['cped'],
    "uṭṭhānavat": ['cped'],
    "uṭṭhāpayati": ['cped'],
    "uṭṭhāpesi": ['cped'],
    "uṭṭhāpesuṁ": ['cped'],
    "uṭṭhāpeti": ['cped'],
    "uṭṭhāsi": ['cped'],
    "uṭṭhāta": ['cped'],
    "uṭṭhātar": ['cped'],
    "uṭṭhāya": ['cped'],
    "uṭṭhāyaka": ['cped'],
    "uṭṭīkita": ['mw'],
    "va": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vaar": ['gra'],
    "vabhr": ['ap90', 'mw'],
    "vabhruka": ['mw'],
    "vac": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vaca": ['mw'],
    "vacaka": ['mw'],
    "vacaknu": ['mw'],
    "vacaknuḥ": ['ap90'],
    "vacakru": ['mw'],
    "vacalu": ['mw'],
    "vacaluḥ": ['ap90'],
    "vacana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vacanabhūṣaṇa": ['mw'],
    "vacanagaurava": ['mw'],
    "vacanagocara": ['mw'],
    "vacanagrāhin": ['mw'],
    "vacanakara": ['cae', 'cped', 'ddsa', 'mw'],
    "vacanakkhama": ['cped'],
    "vacanakrama": ['mw'],
    "vacanakāra": ['mw'],
    "vacanakāraka": ['cae'],
    "vacanakārin": ['cae', 'mw'],
    "vacanakṛt": ['cae'],
    "vacanamālikā": ['mw'],
    "vacanamātra": ['mw'],
    "vacananīya": ['cped'],
    "vacanapatha": ['bhs', 'cped'],
    "vacanapaṭu": ['mw'],
    "vacanaracanā": ['mw'],
    "vacanasahāya": ['mw'],
    "vacanasampuṭa": ['mw'],
    "vacanasamuccaya": ['mw'],
    "vacanasaṃgraha": ['mw'],
    "vacanasaṃpraveśa": ['bhs'],
    "vacanasārasaṃgraha": ['mw'],
    "vacanattha": ['cped'],
    "vacanatva": ['mw'],
    "vacanatā": ['mw'],
    "vacanavirodha": ['mw'],
    "vacanaviruddha": ['mw'],
    "vacanavyakti": ['mw'],
    "vacanaśata": ['mw'],
    "vacanaṃ": ['ap90'],
    "vacanesthita": ['mw'],
    "vacanopakrama": ['mw'],
    "vacanopanyāsa": ['cae', 'mw'],
    "vacanābādha": ['mw'],
    "vacanāmagga": ['cped'],
    "vacanānuga": ['mw'],
    "vacanārtha": ['mw'],
    "vacanāvakṣepa": ['cae', 'mw'],
    "vacanāvant": ['cae'],
    "vacanāvat": ['gra', 'mw'],
    "vacanīkṛta": ['mw'],
    "vacanīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vacanīyadoṣa": ['mw'],
    "vacanīyatva": ['mw'],
    "vacanīyatā": ['mw'],
    "vacara": ['mw'],
    "vacaraḥ": ['ap90'],
    "vacas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vacasa": ['ap90', 'cae', 'gra', 'mw'],
    "vacaskara": ['mw'],
    "vacasvin": ['cae', 'ddsa', 'mw'],
    "vacasy": ['cae', 'gra'],
    "vacasya": ['cae', 'mw'],
    "vacasyu": ['cae', 'gra', 'mw'],
    "vacasyā": ['cae', 'gra', 'mw'],
    "vacasāṃpatiḥ": ['ap90'],
    "vacatra": ['mw'],
    "vacaḥ": ['ap90', 'mw'],
    "vacaḥkrama": ['ddsa', 'mw'],
    "vacaṃdā": ['ap90'],
    "vacaṇḍā": ['mw'],
    "vacaṇḍī": ['mw'],
    "vacca": ['cped'],
    "vaccakuṭi": ['cped'],
    "vaccakūpa": ['cped'],
    "vaccamagga": ['cped'],
    "vaccasodhaka": ['cped'],
    "vaccha": ['cped', 'mw'],
    "vacchagiddhinī": ['cped'],
    "vacchaka": ['cped'],
    "vacchala": ['cped'],
    "vacchara": ['cped'],
    "vacchatara": ['cped'],
    "vacchati": ['cped'],
    "vacchikā": ['mw'],
    "vacchiya": ['mw'],
    "vacchācārya": ['mw'],
    "vaci": ['mw'],
    "vaco": ['cped', 'mw'],
    "vacograha": ['mw'],
    "vacohara": ['ddsa', 'mw'],
    "vacomārgātīta": ['mw'],
    "vacovid": ['cae', 'gra', 'mw'],
    "vacoviparilopa": ['mw'],
    "vacoyuj": ['cae', 'gra', 'mw'],
    "vacā": ['cped', 'ddsa', 'mw'],
    "vacācchada": ['mw'],
    "vacācārya": ['mw'],
    "vacārca": ['mw'],
    "vacī": ['bhs', 'cped'],
    "vacībheda": ['cped'],
    "vacīduccarita": ['cped'],
    "vacīgutta": ['cped'],
    "vacīkamma": ['cped'],
    "vacīparama": ['cped'],
    "vacīsamācāra": ['cped'],
    "vacīsaṅkhāra": ['cped'],
    "vacīsucarita": ['cped'],
    "vacīviññatti": ['cped'],
    "vad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vada": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vadabhīkāra": ['mw'],
    "vadaka": ['mw'],
    "vadamāna": ['cped', 'mw'],
    "vadana": ['cae', 'cped', 'ddsa', 'mw'],
    "vadanacchada": ['mw'],
    "vadanadantura": ['mw'],
    "vadanakaṃja": ['mw'],
    "vadanamadirā": ['mw'],
    "vadanamālinya": ['mw'],
    "vadanamāruta": ['cae', 'mw'],
    "vadanapavana": ['cae', 'mw'],
    "vadanapaṅkaja": ['cae', 'mw'],
    "vadanaroga": ['mw'],
    "vadanasaroja": ['mw'],
    "vadanasatyaṇḍatāra": ['bhs'],
    "vadanaśyāmikā": ['mw'],
    "vadanaṃ": ['ap90'],
    "vadanendu": ['mw'],
    "vadanodara": ['cae', 'ddsa', 'mw'],
    "vadanta": ['cped', 'mw'],
    "vadanti": ['mw'],
    "vadantika": ['mw'],
    "vadantī": ['mw'],
    "vadanya": ['ap90', 'mw'],
    "vadanāmaya": ['mw'],
    "vadanāsava": ['mw'],
    "vadanībhū": ['ddsa'],
    "vadara": ['ap90', 'cae', 'mw'],
    "vadarī": ['cae'],
    "vadatha": ['bhs'],
    "vadati": ['cped'],
    "vadaññutā": ['cped'],
    "vadaññū": ['cped'],
    "vadaṃtī": ['ap90'],
    "vaddaka": ['mw'],
    "vaddalikā": ['cped'],
    "vaddha": ['cped'],
    "vaddhaka": ['bhs'],
    "vaddhana": ['cped'],
    "vaddhapaṭikā": ['bhs'],
    "vaddhrī": ['mw'],
    "vaddhāpacāyana": ['cped'],
    "vaddhāpayati": ['bhs'],
    "vaddivāsa": ['ddsa', 'mw'],
    "vadeti": ['cped'],
    "vadh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vadha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vadhabandha": ['cae', 'mw'],
    "vadhabhūmi": ['cae', 'mw'],
    "vadhadaṇḍa": ['cae', 'ddsa', 'mw'],
    "vadhaiṣin": ['cae', 'mw'],
    "vadhajīvin": ['cae', 'mw'],
    "vadhaka": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "vadhakarmādhikārin": ['mw'],
    "vadhakāma": ['mw'],
    "vadhakāmyā": ['cae', 'mw'],
    "vadhakāṅkṣin": ['mw'],
    "vadhakṣama": ['mw'],
    "vadhanigraha": ['cae', 'ddsa', 'mw'],
    "vadhanirṇeka": ['mw'],
    "vadhanā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vadhar": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vadharata": ['mw'],
    "vadhary": ['cae', 'gra'],
    "vadharya": ['ddsa', 'mw'],
    "vadhas": ['cae', 'ddsa'],
    "vadhasna": ['cae', 'ddsa', 'gra', 'mw'],
    "vadhasnu": ['cae', 'gra', 'mw'],
    "vadhasthalī": ['mw'],
    "vadhasthāna": ['mw'],
    "vadhati": ['bhs'],
    "vadhatra": ['cae', 'ddsa', 'gra', 'mw'],
    "vadhatraṃ": ['ap90'],
    "vadhaḥ": ['ap90'],
    "vadhenta": ['cped'],
    "vadhesi": ['cped'],
    "vadheti": ['cped'],
    "vadhika": ['mw'],
    "vadhin": ['mw'],
    "vadhira": ['mw'],
    "vadhita": ['cped'],
    "vadhitra": ['mw'],
    "vadhitraṃ": ['ap90'],
    "vadhitvā": ['cped'],
    "vadhna": ['mw'],
    "vadhodarka": ['mw'],
    "vadhodyata": ['mw'],
    "vadhopāya": ['cae', 'ddsa', 'mw'],
    "vadhra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vadhraka": ['mw'],
    "vadhrayati": ['bhs'],
    "vadhraśva": ['mw'],
    "vadhraṃ": ['ap90'],
    "vadhri": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vadhriaśva": ['gra'],
    "vadhrikā": ['ap90', 'ddsa', 'mw'],
    "vadhrimatī": ['cae', 'ddsa', 'gra', 'mw'],
    "vadhrivāc": ['gra', 'mw'],
    "vadhrya": ['mw'],
    "vadhryaśva": ['gra', 'mw'],
    "vadhryaḥ": ['ap90'],
    "vadhrī": ['bhs', 'mw'],
    "vadhu": ['cae', 'ddsa', 'mw'],
    "vadhukā": ['bhs', 'cped', 'mw'],
    "vadhuyakṣī": ['bhs'],
    "vadhuḥ": ['ap90'],
    "vadhuṭī": ['ap90', 'mw'],
    "vadhvaṭī": ['mw'],
    "vadhvā": ['mw'],
    "vadhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vadhyabhū": ['cae', 'mw'],
    "vadhyabhūmi": ['cae', 'mw'],
    "vadhyacihna": ['mw'],
    "vadhyadiṇḍima": ['mw'],
    "vadhyaghna": ['mw'],
    "vadhyaghātaka": ['mw'],
    "vadhyaghāṭa": ['bhs'],
    "vadhyamālā": ['cae', 'mw'],
    "vadhyaparyāya": ['cae', 'mw'],
    "vadhyapaṭa": ['mw'],
    "vadhyapaṭaha": ['cae', 'mw'],
    "vadhyapuruṣa": ['cae'],
    "vadhyapāla": ['mw'],
    "vadhyapāna": ['bhs'],
    "vadhyasraj": ['mw'],
    "vadhyasthāna": ['cae', 'mw'],
    "vadhyat": ['mw'],
    "vadhyatva": ['mw'],
    "vadhyatā": ['cae', 'mw'],
    "vadhyavāsas": ['mw'],
    "vadhyaśilā": ['mw'],
    "vadhyaḍiṇḍima": ['cae'],
    "vadhyoṣa": ['mw'],
    "vadhyā": ['ap90', 'ddsa', 'mw'],
    "vadhā": ['mw'],
    "vadhārha": ['mw'],
    "vadhāśaṅka": ['mw'],
    "vadhāśaṅkā": ['mw'],
    "vadhāṅgaka": ['mw'],
    "vadhīm": ['ddsa'],
    "vadhū": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vadhūdarśa": ['cae', 'mw'],
    "vadhūdhana": ['mw'],
    "vadhūgṛhapraveśa": ['mw'],
    "vadhūjana": ['cae', 'ddsa', 'mw'],
    "vadhūka": ['mw'],
    "vadhūkumārī": ['bhs'],
    "vadhūkā": ['bhs'],
    "vadhūkāla": ['mw'],
    "vadhūmant": ['cae'],
    "vadhūmat": ['ddsa', 'gra', 'mw'],
    "vadhūpatha": ['cae', 'mw'],
    "vadhūpraveśa": ['mw'],
    "vadhūsarā": ['mw'],
    "vadhūsarākṛtāhvayā": ['mw'],
    "vadhūsaṃyāna": ['cae', 'mw'],
    "vadhūtva": ['mw'],
    "vadhūvara": ['mw'],
    "vadhūvastra": ['mw'],
    "vadhūvāsas": ['mw'],
    "vadhūyakṣiṇī": ['bhs'],
    "vadhūyu": ['cae', 'ddsa', 'gra', 'mw'],
    "vadhūyāna": ['mw'],
    "vadhūḥ": ['ap90'],
    "vadhūṭaśayanaḥ": ['ap90'],
    "vadhūṭikā": ['cae', 'mw'],
    "vadhūṭī": ['ap90', 'cae', 'mw'],
    "vadhūṭīśayana": ['mw'],
    "vadi": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "vaditavya": ['cae', 'ddsa', 'mw'],
    "vaditos": ['mw'],
    "vaditvā": ['cped'],
    "vaditṛ": ['cae', 'mw'],
    "vadiṣṭha": ['cae', 'mw'],
    "vadman": ['cae', 'gra', 'mw'],
    "vadrākara": ['bhs'],
    "vadya": ['ap90', 'bhs', 'ddsa', 'mw'],
    "vadyapakṣa": ['mw'],
    "vadyate": ['bhs'],
    "vadāla": ['mw'],
    "vadālaka": ['mw'],
    "vadālaḥ": ['ap90'],
    "vadālī": ['bhs'],
    "vadāma": ['mw'],
    "vadāmaḥ": ['ap90'],
    "vadānya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vadānyaśreṣṭha": ['mw'],
    "vadāpana": ['cped'],
    "vadāpesi": ['cped'],
    "vadāpeti": ['cped'],
    "vadāpetvā": ['cped'],
    "vadāpita": ['cped'],
    "vadāvada": ['ap90', 'mw'],
    "vadāvadin": ['mw'],
    "vaga": ['bhs'],
    "vagalā": ['mw'],
    "vagalākalpa": ['mw'],
    "vagalāmantrasādhana": ['mw'],
    "vagalāmukhī": ['mw'],
    "vagalāmukhīdīpadāna": ['mw'],
    "vagalāmukhīkavaca": ['mw'],
    "vagalāmukhīpaddhati": ['mw'],
    "vagalāmukhīpañcāṅga": ['mw'],
    "vagalāmukhīprakaraṇa": ['mw'],
    "vagalāmukhīstotra": ['mw'],
    "vagalāpaṭala": ['mw'],
    "vagalāsahasranāman": ['mw'],
    "vagalāvidhāna": ['mw'],
    "vagga": ['cped'],
    "vaggabandhana": ['cped'],
    "vaggiya": ['cped'],
    "vaggu": ['cped'],
    "vagguli": ['cped'],
    "vagguvada": ['cped'],
    "vaghā": ['cae', 'ddsa', 'mw'],
    "vaghāpati": ['mw'],
    "vagnu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vagura": ['bhs'],
    "vagvana": ['cae', 'gra', 'mw'],
    "vagvanu": ['cae', 'gra', 'mw'],
    "vagvanuḥ": ['ap90'],
    "vagāha": ['mw'],
    "vagāhaḥ": ['ap90'],
    "vagāhya": ['mw'],
    "vagūhayati": ['bhs'],
    "vah": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vaha": ['cae', 'ddsa', 'mw'],
    "vahadgu": ['mw'],
    "vahadhyai": ['ddsa', 'mw'],
    "vahala": ['ap90', 'cae', 'ddsa', 'mw'],
    "vahana": ['cae', 'cped', 'ddsa', 'mw'],
    "vahanabhaṅga": ['cae', 'mw'],
    "vahanaka": ['cped'],
    "vahanaṃ": ['ap90'],
    "vahanta": ['cped', 'mw'],
    "vahantī": ['cae', 'mw'],
    "vahanīkṛ": ['ddsa', 'mw'],
    "vahanīya": ['cae', 'mw'],
    "vaharāvin": ['ddsa', 'mw'],
    "vahas": ['mw'],
    "vahat": ['cae', 'gra', 'mw'],
    "vahata": ['mw'],
    "vahataḥ": ['ap90'],
    "vahati": ['bhs', 'cped', 'mw'],
    "vahatiḥ": ['ap90'],
    "vahatu": ['cae', 'ddsa', 'gra', 'mw'],
    "vahatuḥ": ['ap90'],
    "vahatī": ['ap90', 'mw'],
    "vahaḥ": ['ap90'],
    "vahaṃliha": ['ddsa', 'mw'],
    "vahaṃtaḥ": ['ap90'],
    "vahedaka": ['mw'],
    "vaheḍa": ['bhs'],
    "vaheḍukaḥ": ['ap90'],
    "vahi": ['cped', 'mw'],
    "vahikā": ['mw'],
    "vahin": ['cae', 'mw'],
    "vahis": ['ap90', 'mw'],
    "vahita": ['ap90', 'cped'],
    "vahitabba": ['cped'],
    "vahitar": ['cped'],
    "vahitra": ['cae', 'ddsa', 'mw'],
    "vahitrabhaṅga": ['mw'],
    "vahitrakarṇa": ['mw'],
    "vahitraṃ": ['ap90'],
    "vahitvā": ['cped'],
    "vahiṣka": ['ap90'],
    "vahiṣṭha": ['cae', 'gra', 'mw'],
    "vahli": ['mw'],
    "vahlika": ['ap90'],
    "vahman": ['gra'],
    "vahni": ['cae', 'gra', 'mw'],
    "vahnibhaya": ['mw'],
    "vahnibhayada": ['mw'],
    "vahnibhogya": ['mw'],
    "vahnibīja": ['mw'],
    "vahnicakrā": ['mw'],
    "vahnicaya": ['mw'],
    "vahnicūḍa": ['mw'],
    "vahnida": ['mw'],
    "vahnidagdha": ['mw'],
    "vahnidaivata": ['mw'],
    "vahnidamanī": ['mw'],
    "vahnidhauta": ['mw'],
    "vahnidhūmanyāya": ['mw'],
    "vahnidāhasamudbhava": ['mw'],
    "vahnidīpaka": ['mw'],
    "vahnidīpikā": ['mw'],
    "vahnigandha": ['mw'],
    "vahnigarbha": ['mw'],
    "vahnigarbhā": ['mw'],
    "vahnigṛha": ['cae', 'mw'],
    "vahnijvāla": ['mw'],
    "vahnijvālā": ['mw'],
    "vahnijāyā": ['mw'],
    "vahnika": ['mw'],
    "vahnikanyā": ['mw'],
    "vahnikara": ['mw'],
    "vahnikarī": ['mw'],
    "vahnikopa": ['mw'],
    "vahnikoṇa": ['mw'],
    "vahnikumāra": ['mw'],
    "vahnikuṇḍa": ['mw'],
    "vahnikārya": ['mw'],
    "vahnikāṣṭha": ['mw'],
    "vahnikṛt": ['mw'],
    "vahnilakṣaṇa": ['mw'],
    "vahniloha": ['mw'],
    "vahnilohaka": ['mw'],
    "vahniloka": ['mw'],
    "vahnimant": ['cae'],
    "vahnimantha": ['mw'],
    "vahnimat": ['mw'],
    "vahnimattva": ['mw'],
    "vahnimaya": ['cae', 'mw'],
    "vahnimitra": ['mw'],
    "vahnimāraka": ['mw'],
    "vahninetra": ['mw'],
    "vahnināman": ['mw'],
    "vahnināśana": ['mw'],
    "vahninī": ['mw'],
    "vahnipatana": ['cae', 'mw'],
    "vahnipriyā": ['mw'],
    "vahnipurāṇa": ['mw'],
    "vahnipuṣpī": ['mw'],
    "vahnirasa": ['mw'],
    "vahniretas": ['mw'],
    "vahnirohiṇī": ['mw'],
    "vahnisakha": ['mw'],
    "vahnisaṃjñaka": ['mw'],
    "vahnisaṃskāra": ['cae', 'mw'],
    "vahnisphuliṅga": ['cae', 'mw'],
    "vahnisthāna": ['mw'],
    "vahnisuta": ['mw'],
    "vahnisākṣikam": ['mw'],
    "vahnisātkṛ": ['cae', 'mw'],
    "vahnitama": ['cae', 'mw'],
    "vahnitaskarapārthiva": ['mw'],
    "vahnivadhū": ['mw'],
    "vahnivaktrā": ['mw'],
    "vahnivallabha": ['mw'],
    "vahnivallabhā": ['mw'],
    "vahnivarṇa": ['mw'],
    "vahnivat": ['mw'],
    "vahniveśa": ['mw'],
    "vahniśekhara": ['mw'],
    "vahniśikha": ['mw'],
    "vahniśikhara": ['mw'],
    "vahniśikhā": ['cae', 'mw'],
    "vahniśuddha": ['mw'],
    "vahniśālā": ['cae', 'mw'],
    "vahniḥ": ['ap90'],
    "vahniṣtambha": ['mw'],
    "vahnyutpāta": ['mw'],
    "vahnīya": ['mw'],
    "vahnīśvarī": ['mw'],
    "vahuri": ['bhs'],
    "vahya": ['cae', 'ddsa', 'gra', 'mw'],
    "vahyaka": ['cae', 'mw'],
    "vahyakā": ['mw'],
    "vahyaska": ['mw'],
    "vahyaśīvan": ['mw'],
    "vahyaṃ": ['ap90'],
    "vahyeśaya": ['gra', 'mw'],
    "vahyeśayā": ['ddsa'],
    "vahyā": ['mw'],
    "vahā": ['mw'],
    "vahīnara": ['mw'],
    "vahīyas": ['gra', 'mw'],
    "vai": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vaibhagnaka": ['mw'],
    "vaibhakta": ['ddsa', 'mw'],
    "vaibhava": ['cae', 'ddsa', 'mw'],
    "vaibhavaprakāśikā": ['mw'],
    "vaibhavaṃ": ['ap90'],
    "vaibhavika": ['mw'],
    "vaibhaḍi": ['mw'],
    "vaibhiḍiṅgī": ['bhs'],
    "vaibhoja": ['mw'],
    "vaibhra": ['mw'],
    "vaibhraṃ": ['ap90'],
    "vaibhrāja": ['cae', 'ddsa', 'mw'],
    "vaibhrājaka": ['mw'],
    "vaibhrājaloka": ['mw'],
    "vaibhrājaṃ": ['ap90'],
    "vaibhujāgnaka": ['mw'],
    "vaibhājana": ['mw'],
    "vaibhājitra": ['mw'],
    "vaibhājyavādin": ['mw'],
    "vaibhāra": ['mw'],
    "vaibhāragiri": ['mw'],
    "vaibhāraparvata": ['mw'],
    "vaibhātika": ['mw'],
    "vaibhāvara": ['mw'],
    "vaibhāṇḍaki": ['mw'],
    "vaibhāṣika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vaibhāṣya": ['mw'],
    "vaibhīdaka": ['cae', 'mw'],
    "vaibhīta": ['cae', 'mw'],
    "vaibhītaka": ['cae', 'mw'],
    "vaibhīṣaṇa": ['ddsa', 'mw'],
    "vaibhūtika": ['bhs', 'mw'],
    "vaibhūvasa": ['gra', 'mw'],
    "vaibodhika": ['ddsa', 'mw'],
    "vaibodhikaḥ": ['ap90'],
    "vaibudha": ['cae', 'ddsa', 'mw'],
    "vaibādha": ['mw'],
    "vaibādhapraṇutta": ['mw'],
    "vaicakila": ['mw'],
    "vaicakṣaṇya": ['ddsa', 'mw'],
    "vaicakṣaṇyaṃ": ['ap90'],
    "vaicchandasa": ['mw'],
    "vaicchetuka": ['bhs'],
    "vaicikitsa": ['bhs'],
    "vaicitra": ['ddsa', 'mw'],
    "vaicitravīrya": ['mw'],
    "vaicitravīryaka": ['mw'],
    "vaicitravīryin": ['mw'],
    "vaicitrya": ['cae', 'mw'],
    "vaicitryavīrya": ['mw'],
    "vaicitryaṃ": ['ap90'],
    "vaicitrī": ['mw'],
    "vaicittya": ['cae', 'ddsa', 'mw'],
    "vaicittyaṃ": ['ap90'],
    "vaicitya": ['mw'],
    "vaicyuta": ['mw'],
    "vaida": ['ddsa', 'mw'],
    "vaidabhṛtya": ['mw'],
    "vaidabhṛtī": ['mw'],
    "vaidabhṛtīputra": ['mw'],
    "vaidadaśvi": ['gra', 'mw'],
    "vaidagdha": ['ddsa', 'mw'],
    "vaidagdhaka": ['mw'],
    "vaidagdhaṃ": ['ap90'],
    "vaidagdhya": ['mw'],
    "vaidagdhyavat": ['mw'],
    "vaidagdhī": ['cae', 'mw'],
    "vaidala": ['ap90', 'ddsa', 'mw'],
    "vaidalika": ['mw'],
    "vaidalya": ['bhs', 'mw'],
    "vaidambha": ['mw'],
    "vaidanvata": ['mw'],
    "vaidanṛta": ['mw'],
    "vaidarbha": ['cae', 'ddsa', 'mw'],
    "vaidarbhaka": ['mw'],
    "vaidarbharīti": ['mw'],
    "vaidarbhaḥ": ['ap90'],
    "vaidarbhi": ['mw'],
    "vaidarbhī": ['mw'],
    "vaidarbhījananī": ['mw'],
    "vaidarbhīpariṇaya": ['mw'],
    "vaidarvya": ['ddsa', 'mw'],
    "vaidarya": ['bhs'],
    "vaidata": ['mw'],
    "vaidathina": ['gra', 'mw'],
    "vaidaḥ": ['ap90'],
    "vaideha": ['cae', 'ddsa', 'mw'],
    "vaidehaka": ['mw'],
    "vaidehakaparvata": ['bhs'],
    "vaidehakaḥ": ['ap90'],
    "vaidehaḥ": ['ap90'],
    "vaidehi": ['mw'],
    "vaidehika": ['mw'],
    "vaidehikaḥ": ['ap90'],
    "vaidehī": ['bhs', 'mw'],
    "vaidehībandhu": ['mw'],
    "vaidehīmaya": ['mw'],
    "vaidehīpariṇaya": ['mw'],
    "vaidehīputra": ['bhs'],
    "vaideśika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaideśikanivāsin": ['mw'],
    "vaideśikatva": ['mw'],
    "vaideśya": ['mw'],
    "vaideśyaṃ": ['ap90'],
    "vaidha": ['ap90', 'ddsa', 'mw'],
    "vaidhahiṃsāghatimiramārtaṇḍodaya": ['mw'],
    "vaidharmika": ['mw'],
    "vaidharmya": ['cae', 'ddsa', 'mw'],
    "vaidharmyasama": ['mw'],
    "vaidharmyaṃ": ['ap90'],
    "vaidhasa": ['cae', 'ddsa', 'mw'],
    "vaidhatva": ['mw'],
    "vaidhava": ['cae', 'ddsa', 'mw'],
    "vaidhavaḥ": ['ap90'],
    "vaidhaveya": ['cae', 'ddsa', 'mw'],
    "vaidhaveyaḥ": ['ap90'],
    "vaidhavya": ['cae', 'mw'],
    "vaidhavyalakṣaṇopetā": ['mw'],
    "vaidhavyanirṇaya": ['mw'],
    "vaidhavyaveṇī": ['mw'],
    "vaidhavyaṃ": ['ap90'],
    "vaidheya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaidheyatā": ['mw'],
    "vaidhika": ['mw'],
    "vaidhurya": ['cae', 'mw'],
    "vaidhuryaṃ": ['ap90'],
    "vaidhurī": ['ddsa', 'mw'],
    "vaidhyata": ['mw'],
    "vaidhāraya": ['mw'],
    "vaidhātaki": ['mw'],
    "vaidhātra": ['ddsa', 'mw'],
    "vaidhātrī": ['mw'],
    "vaidhūmāgnī": ['mw'],
    "vaidhṛta": ['mw'],
    "vaidhṛtavāsiṣṭha": ['mw'],
    "vaidhṛtaṃ": ['ap90'],
    "vaidhṛti": ['mw'],
    "vaidhṛtijananaśānti": ['mw'],
    "vaidhṛtivyatīpātasaṃkrāntijananaśānti": ['mw'],
    "vaidhṛtiśānti": ['mw'],
    "vaidhṛtya": ['mw'],
    "vaidhṛtā": ['mw'],
    "vaidi": ['mw'],
    "vaidika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaidikacchandaḥprakāśa": ['mw'],
    "vaidikadharmanirūpaṇa": ['mw'],
    "vaidikadurgādimantraprayoga": ['mw'],
    "vaidikakarman": ['mw'],
    "vaidikaprakriyā": ['mw'],
    "vaidikapāśa": ['mw'],
    "vaidikasarvasva": ['mw'],
    "vaidikasiddhānta": ['mw'],
    "vaidikasubodhinī": ['mw'],
    "vaidikasārvabhauma": ['mw'],
    "vaidikatva": ['mw'],
    "vaidikavijaya": ['mw'],
    "vaidikavyayadhvaja": ['mw'],
    "vaidikaśikṣā": ['mw'],
    "vaidikeṣu": ['mw'],
    "vaidikābharaṇa": ['mw'],
    "vaidikācāranirṇaya": ['mw'],
    "vaidikārcanamīmāṃsā": ['mw'],
    "vaidiśa": ['cae', 'ddsa', 'mw'],
    "vaidiśapura": ['mw'],
    "vaidiśya": ['mw'],
    "vaidruma": ['cae', 'ddsa', 'mw'],
    "vaidula": ['mw'],
    "vaidurika": ['mw'],
    "vaidurya": ['mw'],
    "vaiduṣa": ['mw'],
    "vaiduṣya": ['ddsa', 'mw'],
    "vaiduṣī": ['ap90', 'mw'],
    "vaidya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaidyabandhu": ['mw'],
    "vaidyabhūṣaṇa": ['mw'],
    "vaidyabodhasaṃgraha": ['mw'],
    "vaidyacandrodaya": ['mw'],
    "vaidyacikitsā": ['mw'],
    "vaidyacintāmaṇi": ['mw'],
    "vaidyadarpaṇa": ['mw'],
    "vaidyadhanya": ['mw'],
    "vaidyagadādhara": ['mw'],
    "vaidyagaṅgādhara": ['mw'],
    "vaidyahitopadeśa": ['mw'],
    "vaidyajīvadāsa": ['mw'],
    "vaidyajīvana": ['mw'],
    "vaidyaka": ['mw'],
    "vaidyakagranthapattra": ['mw'],
    "vaidyakalpadruma": ['mw'],
    "vaidyakalpataru": ['mw'],
    "vaidyakaparibhāṣā": ['mw'],
    "vaidyakaprayogāmṛta": ['mw'],
    "vaidyakaratnāvalī": ['mw'],
    "vaidyakasarvasva": ['mw'],
    "vaidyakasaṃgraha": ['mw'],
    "vaidyakasāra": ['mw'],
    "vaidyakasārasaṃgraha": ['mw'],
    "vaidyakaustubha": ['mw'],
    "vaidyakayogacandrikā": ['mw'],
    "vaidyakaśāstra": ['mw'],
    "vaidyakaśāstravaiṣṇava": ['mw'],
    "vaidyakaḥ": ['ap90'],
    "vaidyakriyā": ['mw'],
    "vaidyakulatattva": ['mw'],
    "vaidyakutūhala": ['mw'],
    "vaidyakānanta": ['mw'],
    "vaidyamahodadhi": ['mw'],
    "vaidyamanoramā": ['mw'],
    "vaidyamanotsava": ['mw'],
    "vaidyamālikā": ['mw'],
    "vaidyamānin": ['mw'],
    "vaidyamātṛ": ['mw'],
    "vaidyanarasiṃhasena": ['mw'],
    "vaidyanayabodhikā": ['mw'],
    "vaidyanighaṇṭu": ['mw'],
    "vaidyanātha": ['cae', 'mw'],
    "vaidyanāthabhaiṭ": ['mw'],
    "vaidyanāthabhaṭṭa": ['mw'],
    "vaidyanāthadevaśarman": ['mw'],
    "vaidyanāthadīkṣita": ['mw'],
    "vaidyanāthadīkṣitīya": ['mw'],
    "vaidyanāthagāḍagila": ['mw'],
    "vaidyanāthakavi": ['mw'],
    "vaidyanāthaliṅgamāhātmya": ['mw'],
    "vaidyanāthamaithila": ['mw'],
    "vaidyanāthamiśra": ['mw'],
    "vaidyanāthamāhātmya": ['mw'],
    "vaidyanāthapāyaguṇḍa": ['mw'],
    "vaidyanāthasūri": ['mw'],
    "vaidyanāthatīrtha": ['mw'],
    "vaidyanāthavācaspatibhaṭṭācārya": ['mw'],
    "vaidyanāthaśukla": ['mw'],
    "vaidyanāthaśāstrin": ['mw'],
    "vaidyanātheśvara": ['mw'],
    "vaidyanāthīya": ['mw'],
    "vaidyapaddhati": ['mw'],
    "vaidyapradīpa": ['mw'],
    "vaidyaprajñapta": ['mw'],
    "vaidyarahasyapaddhati": ['mw'],
    "vaidyarasamañjarī": ['mw'],
    "vaidyarasaratna": ['mw'],
    "vaidyarasāyana": ['mw'],
    "vaidyaratna": ['mw'],
    "vaidyaratnamālā": ['mw'],
    "vaidyaratnākarabhāṣya": ['mw'],
    "vaidyarāj": ['mw'],
    "vaidyarāja": ['bhs', 'cae', 'mw'],
    "vaidyarājatantra": ['mw'],
    "vaidyasarvasva": ['mw'],
    "vaidyasaṃdehabhañjana": ['mw'],
    "vaidyasaṃgraha": ['mw'],
    "vaidyasaṃkṣiptasāra": ['mw'],
    "vaidyasika": ['mw'],
    "vaidyasiṃhī": ['mw'],
    "vaidyasāra": ['mw'],
    "vaidyasārasaṃgraha": ['mw'],
    "vaidyasāroddhāra": ['mw'],
    "vaidyasūtraṭīkā": ['mw'],
    "vaidyatrivikrama": ['mw'],
    "vaidyatriṃśaṭṭīkā": ['mw'],
    "vaidyavallabha": ['mw'],
    "vaidyavallabhā": ['mw'],
    "vaidyavidyā": ['mw'],
    "vaidyavilāsa": ['mw'],
    "vaidyavinoda": ['mw'],
    "vaidyavācaspati": ['mw'],
    "vaidyavṛnda": ['mw'],
    "vaidyayoga": ['mw'],
    "vaidyaśāstra": ['mw'],
    "vaidyaśāstrasārasaṃgraha": ['mw'],
    "vaidyeśvaramāhātmya": ['mw'],
    "vaidyota": ['mw'],
    "vaidyottama": ['bhs'],
    "vaidyuddhatī": ['mw'],
    "vaidyuta": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaidyutakṛśānu": ['mw'],
    "vaidyā": ['mw'],
    "vaidyādhara": ['cae', 'ddsa', 'mw'],
    "vaidyālaṃkāra": ['mw'],
    "vaidyāmṛta": ['mw'],
    "vaidyāmṛtalaharī": ['mw'],
    "vaidyāni": ['mw'],
    "vaidyāvataṃsa": ['mw'],
    "vaidyāya": ['mw'],
    "vaidyī": ['mw'],
    "vaidāntika": ['mw'],
    "vaidārava": ['mw'],
    "vaidārika": ['mw'],
    "vaidārva": ['mw'],
    "vaidārvya": ['mw'],
    "vaidāyana": ['mw'],
    "vaidī": ['mw'],
    "vaidūrapati": ['mw'],
    "vaidūrya": ['ap90', 'cae', 'mw'],
    "vaigaleya": ['mw'],
    "vaigandhikā": ['mw'],
    "vaighasa": ['mw'],
    "vaighasika": ['mw'],
    "vaighaṭika": ['mw'],
    "vaighātya": ['mw'],
    "vaigrahi": ['mw'],
    "vaigrahika": ['ap90', 'mw'],
    "vaigreya": ['mw'],
    "vaigri": ['mw'],
    "vaiguṇya": ['cae', 'ddsa', 'mw'],
    "vaiguṇyaṃ": ['ap90'],
    "vaihaga": ['cae', 'ddsa', 'mw'],
    "vaihali": ['mw'],
    "vaihati": ['mw'],
    "vaihatī": ['mw'],
    "vaihaṃga": ['mw'],
    "vaihvalya": ['cae', 'ddsa', 'mw'],
    "vaihālī": ['ddsa', 'mw'],
    "vaihāra": ['mw'],
    "vaihārika": ['mw'],
    "vaihārya": ['ap90', 'mw'],
    "vaihāsika": ['mw'],
    "vaihāsikaḥ": ['ap90'],
    "vaihāya": ['bhs'],
    "vaihāyana": ['mw'],
    "vaihāyasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaihāyasagata": ['mw'],
    "vaihāyasam": ['mw'],
    "vaihāyasaṃ": ['bhs'],
    "vaihāyasī": ['mw'],
    "vaihīnari": ['mw'],
    "vaijagdhaka": ['mw'],
    "vaijalabhūpati": ['mw'],
    "vaijaladeva": ['mw'],
    "vaijana": ['mw'],
    "vaijanadeva": ['mw'],
    "vaijanana": ['ddsa', 'mw'],
    "vaijananaṃ": ['ap90'],
    "vaijanya": ['ddsa', 'mw'],
    "vaijara": ['mw'],
    "vaijava": ['mw'],
    "vaijavana": ['ddsa', 'mw'],
    "vaijavāpa": ['mw'],
    "vaijayanta": ['bhs', 'cae', 'ddsa', 'mw'],
    "vaijayanti": ['bhs'],
    "vaijayantika": ['mw'],
    "vaijayantikā": ['cae', 'mw'],
    "vaijayantī": ['mw'],
    "vaijayantīka": ['bhs'],
    "vaijayaṃtaḥ": ['ap90'],
    "vaijayaṃtikaḥ": ['ap90'],
    "vaijayaṃtikā": ['ap90'],
    "vaijayaṃtī": ['ap90'],
    "vaijayi": ['mw'],
    "vaijayika": ['ddsa', 'mw'],
    "vaijayin": ['mw'],
    "vaiji": ['mw'],
    "vaijika": ['ap90', 'mw'],
    "vaijñānaśālika": ['mw'],
    "vaijñānika": ['ap90', 'mw'],
    "vaijāna": ['mw'],
    "vaijāpaka": ['mw'],
    "vaijāpakaka": ['mw'],
    "vaijātya": ['cae', 'ddsa', 'mw'],
    "vaijātyaṃ": ['ap90'],
    "vaikakṣa": ['cae', 'ddsa', 'mw'],
    "vaikakṣaka": ['cae', 'mw'],
    "vaikakṣakaṃ": ['ap90'],
    "vaikakṣaṃ": ['ap90'],
    "vaikakṣika": ['ddsa', 'mw'],
    "vaikakṣya": ['mw'],
    "vaikakṣyaka": ['mw'],
    "vaikalpa": ['mw'],
    "vaikalpaṃ": ['ap90'],
    "vaikalpika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaikalpikatva": ['mw'],
    "vaikalpikatā": ['mw'],
    "vaikalya": ['cae', 'ddsa', 'mw'],
    "vaikalyatā": ['mw'],
    "vaikalyaṃ": ['ap90'],
    "vaikara": ['mw'],
    "vaikarañja": ['mw'],
    "vaikarma": ['mw'],
    "vaikarta": ['cae', 'ddsa', 'mw'],
    "vaikartana": ['cae', 'ddsa', 'mw'],
    "vaikartanakula": ['mw'],
    "vaikartanaḥ": ['ap90'],
    "vaikartaḥ": ['ap90'],
    "vaikarya": ['mw'],
    "vaikarṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "vaikarṇeya": ['mw'],
    "vaikarṇi": ['mw'],
    "vaikarṇāyana": ['mw'],
    "vaikathika": ['mw'],
    "vaikayata": ['mw'],
    "vaikayatavidha": ['mw'],
    "vaikaṃseya": ['mw'],
    "vaikaṅka": ['mw'],
    "vaikaṅkata": ['ddsa', 'mw'],
    "vaikaṭika": ['ddsa', 'mw'],
    "vaikaṭikaḥ": ['ap90'],
    "vaikaṭya": ['mw'],
    "vaikharī": ['ap90', 'mw'],
    "vaikhāna": ['mw'],
    "vaikhānasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaikhānasabhṛgusaṃhitā": ['mw'],
    "vaikhānasamata": ['mw'],
    "vaikhānasasamprokṣaṇa": ['mw'],
    "vaikhānasasaṃhitā": ['mw'],
    "vaikhānasasūtra": ['mw'],
    "vaikhānasatantra": ['mw'],
    "vaikhānasavaiṣṇavāgama": ['mw'],
    "vaikhānasaśrautasūtra": ['mw'],
    "vaikhānasaśāstra": ['mw'],
    "vaikhānasi": ['mw'],
    "vaikhānasācārya": ['mw'],
    "vaikhānasāgama": ['mw'],
    "vaikhānasārcanānavanīta": ['mw'],
    "vaikhānasārādhana": ['mw'],
    "vaikhānasāśrama": ['mw'],
    "vaikhānasī": ['mw'],
    "vaikhānasīyopaniṣad": ['mw'],
    "vaikhāraka": ['mw'],
    "vaiki": ['mw'],
    "vaikira": ['mw'],
    "vaiklava": ['cae', 'ddsa', 'mw'],
    "vaiklavaṃ": ['ap90'],
    "vaiklavya": ['cae', 'mw'],
    "vaiklavyatā": ['mw'],
    "vaikriya": ['ddsa', 'mw'],
    "vaikrānta": ['mw'],
    "vaikrāṃtaṃ": ['ap90'],
    "vaikughāsīya": ['mw'],
    "vaikuṃṭhaḥ": ['ap90'],
    "vaikuṇṭha": ['cae', 'ddsa', 'mw'],
    "vaikuṇṭhabhuvana": ['mw'],
    "vaikuṇṭhacaturdaśī": ['mw'],
    "vaikuṇṭhadīkṣita": ['mw'],
    "vaikuṇṭhadīkṣitīya": ['mw'],
    "vaikuṇṭhadīpikā": ['mw'],
    "vaikuṇṭhadīpikānātha": ['mw'],
    "vaikuṇṭhadīpikānāthācārya": ['mw'],
    "vaikuṇṭhagadya": ['mw'],
    "vaikuṇṭhagati": ['mw'],
    "vaikuṇṭhaloka": ['mw'],
    "vaikuṇṭhapurī": ['mw'],
    "vaikuṇṭhastava": ['mw'],
    "vaikuṇṭhastavavyākhyā": ['mw'],
    "vaikuṇṭhasvarga": ['mw'],
    "vaikuṇṭhatva": ['mw'],
    "vaikuṇṭhavarṇana": ['mw'],
    "vaikuṇṭhavijaya": ['mw'],
    "vaikuṇṭhaviṣṇu": ['mw'],
    "vaikuṇṭhaśiṣya": ['mw'],
    "vaikuṇṭhaśiṣyācārya": ['mw'],
    "vaikuṇṭhā": ['mw'],
    "vaikuṇṭhīya": ['ddsa', 'mw'],
    "vaikuṭyāsīya": ['mw'],
    "vaikāla": ['mw'],
    "vaikālaḥ": ['ap90'],
    "vaikālika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaikālikam": ['mw'],
    "vaikālīna": ['mw'],
    "vaikārika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaikārikabandha": ['mw'],
    "vaikārimata": ['mw'],
    "vaikārya": ['cae', 'mw'],
    "vaikāseya": ['mw'],
    "vaikāyana": ['mw'],
    "vaikṛnta": ['mw'],
    "vaikṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaikṛtarahasya": ['mw'],
    "vaikṛtasarga": ['mw'],
    "vaikṛtatva": ['mw'],
    "vaikṛtavat": ['mw'],
    "vaikṛtavivarta": ['mw'],
    "vaikṛti": ['mw'],
    "vaikṛtika": ['ap90', 'bhs', 'mw'],
    "vaikṛtya": ['cae', 'ddsa', 'mw'],
    "vaikṛtyaṃ": ['ap90'],
    "vaikṛtāpaha": ['mw'],
    "vaikṣa": ['mw'],
    "vaikṣamāṇi": ['mw'],
    "vaila": ['mw'],
    "vailaki": ['mw'],
    "vailakṣaṇya": ['cae', 'ddsa', 'mw'],
    "vailakṣaṇyaṃ": ['ap90'],
    "vailakṣya": ['cae', 'ddsa', 'mw'],
    "vailakṣyavat": ['mw'],
    "vailakṣyaṃ": ['ap90'],
    "vailastha": ['gra', 'mw'],
    "vailasthāna": ['gra', 'mw'],
    "vailasthānaka": ['gra', 'mw'],
    "vailepika": ['mw'],
    "vailiṅgya": ['ddsa', 'mw'],
    "vailmavegarudra": ['bhs'],
    "vailomya": ['ddsa', 'mw'],
    "vailomyaṃ": ['ap90'],
    "vailva": ['ap90', 'mw'],
    "vailābhya": ['mw'],
    "vailāsikā": ['bhs'],
    "vailātya": ['mw'],
    "vaima": ['mw'],
    "vaimacitra": ['bhs'],
    "vaimada": ['ddsa', 'mw'],
    "vaimadyapura": ['bhs'],
    "vaimalya": ['cae', 'ddsa', 'mw'],
    "vaimana": ['mw'],
    "vaimanasya": ['cae', 'ddsa', 'mw'],
    "vaimanasyaṃ": ['ap90'],
    "vaimanya": ['mw'],
    "vaimatika": ['bhs', 'mw'],
    "vaimattāyana": ['mw'],
    "vaimattāyanaka": ['mw'],
    "vaimatya": ['cae', 'ddsa', 'mw'],
    "vaimatyaṃ": ['ap90'],
    "vaimatāyana": ['mw'],
    "vaimatāyanaka": ['mw'],
    "vaimbaki": ['mw'],
    "vaimeya": ['mw'],
    "vaimeyaḥ": ['ap90'],
    "vaimitrā": ['mw'],
    "vaimukhya": ['cae', 'ddsa', 'mw'],
    "vaimukhyaṃ": ['ap90'],
    "vaimukta": ['mw'],
    "vaimuktaṃ": ['ap90'],
    "vaimya": ['mw'],
    "vaimānika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vaimānikatva": ['mw'],
    "vaimātra": ['bhs', 'cae', 'ddsa', 'mw'],
    "vaimātraka": ['cae', 'mw'],
    "vaimātratā": ['bhs', 'mw'],
    "vaimātraḥ": ['ap90'],
    "vaimātreya": ['cae', 'mw'],
    "vaimātreyī": ['mw'],
    "vaimātrya": ['bhs'],
    "vaimātrā": ['ap90'],
    "vaimūlya": ['cae', 'ddsa', 'mw'],
    "vaimūlyatas": ['mw'],
    "vaimūḍhaka": ['ddsa', 'mw'],
    "vaimṛdha": ['mw'],
    "vaimṛdhya": ['mw'],
    "vaina": ['mw'],
    "vainabhṛta": ['mw'],
    "vainada": ['mw'],
    "vainadhṛta": ['mw'],
    "vainadī": ['mw'],
    "vainahotra": ['mw'],
    "vainataka": ['mw'],
    "vainatakaṃ": ['ap90'],
    "vainateya": ['cae', 'ddsa', 'mw'],
    "vainateyaḥ": ['ap90'],
    "vainateyī": ['mw'],
    "vainatya": ['ddsa', 'mw'],
    "vainatīya": ['mw'],
    "vainava": ['mw'],
    "vainayika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vainaṃśina": ['mw'],
    "vaindava": ['mw'],
    "vaindhya": ['cae', 'ddsa', 'mw'],
    "vaineya": ['bhs', 'mw'],
    "vaineyaka": ['bhs'],
    "vaineyika": ['bhs'],
    "vainia": ['gra'],
    "vainra": ['mw'],
    "vainya": ['cae', 'ddsa', 'gra', 'mw'],
    "vainyadatta": ['mw'],
    "vainyasvāmin": ['mw'],
    "vaināyaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaināyakasaṃhitā": ['mw'],
    "vaināyika": ['bhs', 'mw'],
    "vaināyikaḥ": ['ap90'],
    "vaināśa": ['bhs', 'mw'],
    "vaināśika": ['bhs', 'ddsa', 'mw'],
    "vaināśikasamaya": ['mw'],
    "vaināśikatantra": ['mw'],
    "vaināśikaḥ": ['ap90'],
    "vainītaka": ['ap90', 'mw'],
    "vaiparītya": ['cae', 'ddsa', 'mw'],
    "vaiparītyalajjālu": ['mw'],
    "vaiparītyasambandha": ['mw'],
    "vaiparītyaṃ": ['ap90'],
    "vaipathaka": ['mw'],
    "vaipañcaka": ['bhs'],
    "vaipañcamika": ['mw'],
    "vaipañcanika": ['bhs'],
    "vaipañcika": ['bhs'],
    "vaipaścita": ['mw'],
    "vaipaśyata": ['ddsa', 'mw'],
    "vaiphalya": ['cae', 'ddsa', 'mw'],
    "vaiphalyaṃ": ['ap90'],
    "vaiplava": ['mw'],
    "vaipotākhya": ['mw'],
    "vaipraciti": ['mw'],
    "vaipracitta": ['mw'],
    "vaiprakarṣika": ['mw'],
    "vaiprayogika": ['mw'],
    "vaipraśnika": ['mw'],
    "vaipruṣa": ['mw'],
    "vaipulya": ['bhs', 'cae', 'ddsa', 'mw'],
    "vaipulyasūtra": ['mw'],
    "vaipulyaṃ": ['ap90'],
    "vaipuṣpita": ['bhs', 'mw'],
    "vaipādika": ['mw'],
    "vaipākika": ['bhs'],
    "vaipākya": ['bhs'],
    "vaipārṣṇi": ['mw'],
    "vaipātya": ['mw'],
    "vaipāśa": ['mw'],
    "vaipāśaka": ['mw'],
    "vaipāśāyana": ['mw'],
    "vaipāśāyanya": ['mw'],
    "vaira": ['bhs', 'cae', 'ddsa', 'mw'],
    "vairabhāva": ['ddsa', 'mw'],
    "vairadeya": ['cae', 'gra', 'mw'],
    "vairahatya": ['cae', 'mw'],
    "vairaka": ['mw'],
    "vairakara": ['cae', 'mw'],
    "vairakaraṇa": ['mw'],
    "vairakhaṇḍin": ['mw'],
    "vairaki": ['mw'],
    "vairakta": ['mw'],
    "vairaktaṃ": ['ap90'],
    "vairaktya": ['ddsa', 'mw'],
    "vairakāra": ['mw'],
    "vairakāraka": ['mw'],
    "vairakāraṇa": ['mw'],
    "vairakārin": ['cae', 'mw'],
    "vairakāritā": ['mw'],
    "vairakṛt": ['cae', 'mw'],
    "vairalya": ['ddsa', 'mw'],
    "vairalyaṃ": ['ap90'],
    "vairamaṇa": ['bhs', 'ddsa', 'mw'],
    "vairamaṇya": ['bhs', 'mw'],
    "vairamaṇī": ['bhs'],
    "vairambha": ['bhs', 'mw'],
    "vairambhaka": ['bhs', 'mw'],
    "vairambhya": ['bhs'],
    "vairambhyasūtra": ['bhs'],
    "vairaniryātana": ['ddsa', 'mw'],
    "vairantya": ['ddsa', 'mw'],
    "vairantī": ['ddsa', 'mw'],
    "vairapratikriyā": ['mw'],
    "vairapratimocana": ['mw'],
    "vairapratiyātana": ['mw'],
    "vairapratīkāra": ['mw'],
    "vairapuruṣa": ['mw'],
    "vairarakṣin": ['mw'],
    "vairasa": ['cae', 'ddsa', 'mw'],
    "vairaseni": ['ddsa', 'mw'],
    "vairasya": ['cae', 'ddsa', 'mw'],
    "vairasādhana": ['mw'],
    "vairata": ['mw'],
    "vairatha": ['mw'],
    "vairatva": ['mw'],
    "vairatya": ['ddsa', 'mw'],
    "vairatā": ['mw'],
    "vairavant": ['cae'],
    "vairavat": ['mw'],
    "vairaviśuddhi": ['ddsa', 'mw'],
    "vairavrata": ['mw'],
    "vairayātanā": ['cae', 'mw'],
    "vairaśuddhi": ['mw'],
    "vairaṃ": ['ap90'],
    "vairaṃgikaḥ": ['ap90'],
    "vairaṃkara": ['mw'],
    "vairaṅgika": ['ddsa', 'mw'],
    "vairaṇaka": ['mw'],
    "vairaṇyā": ['bhs'],
    "vairaṇī": ['mw'],
    "vairaṇḍeya": ['mw'],
    "vairaṭa": ['mw'],
    "vairaṭikaputra": ['bhs'],
    "vairaṭṭasiṃha": ['bhs'],
    "vairaṭṭī": ['mw'],
    "vairecana": ['mw'],
    "vairecanika": ['mw'],
    "vairekīya": ['mw'],
    "vaireya": ['mw'],
    "vairi": ['mw'],
    "vairika": ['bhs', 'cae'],
    "vairin": ['ap90', 'cae', 'mw'],
    "vairisiṃha": ['mw'],
    "vairitva": ['mw'],
    "vairitā": ['cae', 'ddsa', 'mw'],
    "vairivīra": ['mw'],
    "vairiñca": ['mw'],
    "vairiñcya": ['mw'],
    "vairiṇa": ['gra', 'mw'],
    "vairiṇi": ['mw'],
    "vairocana": ['bhs', 'cae', 'ddsa', 'mw'],
    "vairocanabhadra": ['mw'],
    "vairocanadhvaja": ['bhs'],
    "vairocanadhvajapradīpaśrī": ['bhs'],
    "vairocanagarbha": ['bhs'],
    "vairocanagarbhamahāmegha": ['bhs'],
    "vairocanaketu": ['bhs'],
    "vairocanamuhūrta": ['mw'],
    "vairocananiketana": ['mw'],
    "vairocanaprabhavyūha": ['bhs'],
    "vairocanaprabhaśrī": ['bhs'],
    "vairocanapraṇidhigarbhā": ['bhs'],
    "vairocanapraṇidhijñānaketu": ['bhs'],
    "vairocanapraṇidhānaketudhvaja": ['bhs'],
    "vairocanapraṇidhānanābhiraśmiprabha": ['bhs'],
    "vairocanaratnapadmagarbhaśrīcūḍa": ['bhs'],
    "vairocanaraśmipratimaṇḍita": ['mw'],
    "vairocanaraśmipratimaṇḍitadhvajarāja": ['bhs'],
    "vairocanaraśmipratimaṇḍitā": ['bhs'],
    "vairocanatejaḥśrī": ['bhs'],
    "vairocanavyūhālaṃkāragarbha": ['bhs'],
    "vairocanaśrī": ['bhs'],
    "vairocanaśrīgarbha": ['bhs'],
    "vairocanaśrīgarbharāja": ['bhs'],
    "vairocanaśrītejorāja": ['bhs'],
    "vairocanaḥ": ['ap90'],
    "vairocani": ['mw'],
    "vairocanottarajñānin": ['bhs'],
    "vairocanīya": ['bhs'],
    "vairoci": ['mw'],
    "vairoddhāra": ['mw'],
    "vairodhaka": ['ddsa', 'mw'],
    "vairodhakatva": ['mw'],
    "vairodhika": ['mw'],
    "vairohita": ['mw'],
    "vairohitya": ['mw'],
    "vairoṭyā": ['mw'],
    "vairucanācārya": ['mw'],
    "vairuddhya": ['bhs'],
    "vairā": ['bhs'],
    "vairādhayya": ['mw'],
    "vairāga": ['mw'],
    "vairāgaṃ": ['ap90'],
    "vairāgika": ['mw'],
    "vairāgikaḥ": ['ap90'],
    "vairāgin": ['mw'],
    "vairāgya": ['cae', 'ddsa', 'mw'],
    "vairāgyacandrikā": ['mw'],
    "vairāgyapañcaka": ['mw'],
    "vairāgyapañcāśīti": ['mw'],
    "vairāgyapradīpa": ['mw'],
    "vairāgyaprakaraṇa": ['mw'],
    "vairāgyaratna": ['mw'],
    "vairāgyatā": ['mw'],
    "vairāgyaśataka": ['mw'],
    "vairāgyaṃ": ['ap90'],
    "vairāgyika": ['bhs'],
    "vairāgī": ['mw'],
    "vairāja": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vairājagarbha": ['mw'],
    "vairājaka": ['mw'],
    "vairājapṛṣṭha": ['mw'],
    "vairājya": ['mw'],
    "vairāma": ['mw'],
    "vairāmaka": ['bhs'],
    "vairāmatī": ['mw'],
    "vairāntaka": ['mw'],
    "vairānubandha": ['mw'],
    "vairānubandhin": ['ddsa', 'mw'],
    "vairānubandhitā": ['mw'],
    "vairānṛṇya": ['mw'],
    "vairāroha": ['mw'],
    "vairātaṅka": ['mw'],
    "vairāy": ['cae'],
    "vairāya": ['ddsa', 'mw'],
    "vairāyate": ['ap90'],
    "vairāyita": ['mw'],
    "vairāśaṃsana": ['ddsa', 'mw'],
    "vairāṇaka": ['mw'],
    "vairāṇakīya": ['mw'],
    "vairāṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vairāṭadeśa": ['mw'],
    "vairāṭaka": ['bhs', 'mw'],
    "vairāṭarāja": ['mw'],
    "vairāṭi": ['mw'],
    "vairāṭyā": ['mw'],
    "vairāṭī": ['mw'],
    "vairībhū": ['cae', 'mw'],
    "vairūpa": ['cae', 'ddsa', 'gra', 'mw'],
    "vairūpagarbha": ['mw'],
    "vairūpapṛṣṭha": ['mw'],
    "vairūpya": ['cae', 'ddsa', 'mw'],
    "vairūpyatā": ['mw'],
    "vairūpyaṃ": ['ap90'],
    "vairūpākṣa": ['mw'],
    "vairūṭīputra": ['bhs'],
    "vairḷñca": ['ddsa'],
    "vaisargika": ['mw'],
    "vaisarjana": ['mw'],
    "vaisarjanahomāya": ['mw'],
    "vaisarjanatva": ['mw'],
    "vaisarjanīya": ['mw'],
    "vaisarjina": ['mw'],
    "vaisarpa": ['bhs', 'mw'],
    "vaisarpika": ['mw'],
    "vaisarpya": ['bhs'],
    "vaispaṣṭya": ['cae', 'ddsa', 'mw'],
    "vaisreya": ['mw'],
    "vaistika": ['mw'],
    "vaistārika": ['bhs', 'mw'],
    "vaisvarya": ['cae', 'mw'],
    "vaisādṛśya": ['cae', 'ddsa', 'mw'],
    "vaisāriṇa": ['mw'],
    "vaisāriṇaḥ": ['ap90'],
    "vaisūcana": ['mw'],
    "vaisūcanaṃ": ['ap90'],
    "vaisṛpa": ['mw'],
    "vaitadhṛta": ['mw'],
    "vaitahavya": ['ddsa', 'mw'],
    "vaitahotra": ['mw'],
    "vaitanika": ['ap90', 'mw'],
    "vaitara": ['bhs'],
    "vaitaraṇa": ['ddsa', 'gra', 'mw'],
    "vaitaraṇi": ['mw'],
    "vaitaraṇiḥ": ['ap90'],
    "vaitaraṇī": ['mw'],
    "vaitaraṇīdāna": ['mw'],
    "vaitaraṇīmāhātmya": ['mw'],
    "vaitaraṇīvidhi": ['mw'],
    "vaitaraṇīvratodyāpanavidhi": ['mw'],
    "vaitarika": ['bhs'],
    "vaitasa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vaitasaka": ['mw'],
    "vaitasena": ['mw'],
    "vaitasta": ['ddsa', 'mw'],
    "vaitastika": ['mw'],
    "vaitastya": ['mw'],
    "vaitathya": ['ddsa', 'mw'],
    "vaitathyaprakaraṇa": ['mw'],
    "vaitathyaṃ": ['ap90'],
    "vaitathyopaniṣad": ['mw'],
    "vaitatya": ['ddsa', 'mw'],
    "vaitaṃsika": ['ddsa', 'mw'],
    "vaitaṃsikaḥ": ['ap90'],
    "vaitaṃsikāya": ['mw'],
    "vaitaṃḍikaḥ": ['ap90'],
    "vaitaṇḍika": ['mw'],
    "vaitaṇḍin": ['mw'],
    "vaitaṇḍya": ['mw'],
    "vaitraka": ['ap90', 'mw'],
    "vaitrakīya": ['mw'],
    "vaitrakīyavana": ['mw'],
    "vaitrāsura": ['mw'],
    "vaittapālya": ['mw'],
    "vaitula": ['mw'],
    "vaitulakantha": ['mw'],
    "vaitulya": ['bhs'],
    "vaituṅgakā": ['bhs'],
    "vaituṣika": ['mw'],
    "vaituṣya": ['mw'],
    "vaitāla": ['ddsa', 'mw'],
    "vaitālaki": ['mw'],
    "vaitālapura": ['mw'],
    "vaitālika": ['cae', 'ddsa', 'mw'],
    "vaitālikarṇi": ['mw'],
    "vaitālikarṇikantha": ['mw'],
    "vaitālikavrata": ['mw'],
    "vaitālikaḥ": ['ap90'],
    "vaitālin": ['mw'],
    "vaitālī": ['mw'],
    "vaitālīya": ['cae', 'mw'],
    "vaitāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaitānakuśala": ['cae', 'mw'],
    "vaitānaprāyaścittasūtra": ['mw'],
    "vaitānastha": ['mw'],
    "vaitānasūtra": ['mw'],
    "vaitānika": ['ap90', 'cae', 'mw'],
    "vaitānopāsanā": ['mw'],
    "vaitānya": ['bhs', 'mw'],
    "vaitāyana": ['mw'],
    "vaitāḍhya": ['mw'],
    "vaitṛṣṇya": ['ddsa', 'mw'],
    "vaivadhika": ['ddsa', 'mw'],
    "vaivadhikatā": ['mw'],
    "vaivadhikaḥ": ['ap90'],
    "vaivadhikī": ['mw'],
    "vaivakṣika": ['ddsa', 'mw'],
    "vaivarta": ['mw'],
    "vaivartaka": ['mw'],
    "vaivartaṃ": ['ap90'],
    "vaivarṇa": ['bhs'],
    "vaivarṇika": ['bhs', 'mw'],
    "vaivarṇya": ['cae', 'ddsa', 'mw'],
    "vaivarṇyaṃ": ['ap90'],
    "vaivasvata": ['cae', 'ddsa', 'gra', 'mw'],
    "vaivasvatamanvantara": ['mw'],
    "vaivasvatatīrtha": ['mw'],
    "vaivasvataḥ": ['ap90'],
    "vaivasvatī": ['ap90', 'mw'],
    "vaivasvatīya": ['mw'],
    "vaivaśya": ['ddsa', 'mw'],
    "vaiviktya": ['ddsa', 'mw'],
    "vaivāha": ['cae', 'mw'],
    "vaivāhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaivāhya": ['cae', 'mw'],
    "vaivṛtta": ['mw'],
    "vaiyadhikaraṇya": ['ddsa', 'mw'],
    "vaiyadhikaraṇyaṃ": ['ap90'],
    "vaiyagra": ['mw'],
    "vaiyagraṃ": ['ap90'],
    "vaiyagrya": ['ddsa', 'mw'],
    "vaiyalkaśa": ['mw'],
    "vaiyamaka": ['mw'],
    "vaiyarthya": ['cae', 'ddsa', 'mw'],
    "vaiyarthyaṃ": ['ap90'],
    "vaiyasana": ['mw'],
    "vaiyathita": ['mw'],
    "vaiyavahārika": ['ddsa', 'mw'],
    "vaiyaśana": ['mw'],
    "vaiyaśva": ['gra', 'mw'],
    "vaiyaśvi": ['mw'],
    "vaiyuṣṭa": ['ap90', 'mw'],
    "vaiyya": ['mw'],
    "vaiyyākaraṇa": ['bhs'],
    "vaiyāghra": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaiyāghrapadya": ['mw'],
    "vaiyāghrapadī": ['mw'],
    "vaiyāghrapadīputra": ['mw'],
    "vaiyāghraparicchada": ['mw'],
    "vaiyāghrapād": ['mw'],
    "vaiyāghrapāda": ['mw'],
    "vaiyāghrya": ['mw'],
    "vaiyākaraṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vaiyākaraṇabhārya": ['mw'],
    "vaiyākaraṇabhūṣaṇa": ['mw'],
    "vaiyākaraṇabhūṣaṇasarvasva": ['mw'],
    "vaiyākaraṇabhūṣaṇasaṃgraha": ['mw'],
    "vaiyākaraṇabhūṣaṇasāra": ['mw'],
    "vaiyākaraṇabhūṣaṇopanyāsa": ['mw'],
    "vaiyākaraṇahastin": ['mw'],
    "vaiyākaraṇajīvātu": ['mw'],
    "vaiyākaraṇakhasūci": ['mw'],
    "vaiyākaraṇakoṭipattra": ['mw'],
    "vaiyākaraṇakārikā": ['mw'],
    "vaiyākaraṇamañjūṣā": ['mw'],
    "vaiyākaraṇapadamañjarī": ['mw'],
    "vaiyākaraṇaparibhāṣārūpaśabdārthatarkāmṛta": ['mw'],
    "vaiyākaraṇapāśa": ['mw'],
    "vaiyākaraṇasarvasva": ['mw'],
    "vaiyākaraṇasiddhāntabhūṣaṇa": ['mw'],
    "vaiyākaraṇasiddhāntabhūṣaṇasāra": ['mw'],
    "vaiyākaraṇasiddhāntadīpikā": ['mw'],
    "vaiyākaraṇasiddhāntakaumudī": ['mw'],
    "vaiyākaraṇasiddhāntamañjūṣā": ['mw'],
    "vaiyākaraṇasiddhāntamañjūṣāsāra": ['mw'],
    "vaiyākaraṇasiddhāntarahasya": ['mw'],
    "vaiyākaraṇasiddhāntaratnākara": ['mw'],
    "vaiyākaraṇī": ['mw'],
    "vaiyākhya": ['mw'],
    "vaiyākṛta": ['mw'],
    "vaiyāpada": ['mw'],
    "vaiyāpatya": ['bhs'],
    "vaiyāpṛtyakara": ['mw'],
    "vaiyāsa": ['cae', 'ddsa', 'mw'],
    "vaiyāsaki": ['mw'],
    "vaiyāsava": ['mw'],
    "vaiyāsi": ['mw'],
    "vaiyāsika": ['cae', 'mw'],
    "vaiyāsikamata": ['mw'],
    "vaiyāsikasūtropanyāsa": ['mw'],
    "vaiyāsikaḥ": ['ap90'],
    "vaiyāsikī": ['mw'],
    "vaiyāska": ['mw'],
    "vaiyāta": ['mw'],
    "vaiyātya": ['ddsa', 'mw'],
    "vaiyātyaṃ": ['ap90'],
    "vaiyāvṛtti": ['mw'],
    "vaiyāvṛttikara": ['mw'],
    "vaiyāvṛttya": ['mw'],
    "vaiyāvṛttyakara": ['mw'],
    "vaiyāvṛtya": ['mw'],
    "vaiyāvṛtyakara": ['mw'],
    "vaiśadya": ['cae', 'ddsa', 'mw'],
    "vaiśadyaṃ": ['ap90'],
    "vaiśalya": ['mw'],
    "vaiśalī": ['mw'],
    "vaiśamphalyā": ['mw'],
    "vaiśampāyana": ['ddsa', 'mw'],
    "vaiśampāyananītisaṃgraha": ['mw'],
    "vaiśampāyanasaṃhitā": ['mw'],
    "vaiśampāyanasmṛti": ['mw'],
    "vaiśampāyanīya": ['mw'],
    "vaiśanta": ['cae', 'ddsa', 'gra', 'mw'],
    "vaiśantā": ['mw'],
    "vaiśasa": ['cae', 'ddsa', 'mw'],
    "vaiśasaṃ": ['ap90'],
    "vaiśastra": ['mw'],
    "vaiśastraṃ": ['ap90'],
    "vaiśastya": ['mw'],
    "vaiśasya": ['ddsa', 'mw'],
    "vaiśaṃpāyana": ['cae'],
    "vaiśaṃpāyanaḥ": ['ap90'],
    "vaiśeya": ['mw'],
    "vaiśeṣika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaiśeṣikadarśana": ['mw'],
    "vaiśeṣikaratnamālā": ['mw'],
    "vaiśeṣikasūtra": ['mw'],
    "vaiśeṣikasūtropaskara": ['mw'],
    "vaiśeṣikādiṣaḍdarśanaviśeṣavarṇana": ['mw'],
    "vaiśeṣin": ['mw'],
    "vaiśeṣya": ['cae', 'mw'],
    "vaiśeṣyaṃ": ['ap90'],
    "vaiśika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaiśikha": ['mw'],
    "vaiśikya": ['mw'],
    "vaiśiṣṭa": ['mw'],
    "vaiśiṣṭaṃ": ['ap90'],
    "vaiśiṣṭya": ['cae', 'ddsa', 'mw'],
    "vaiśiṣṭyaṃ": ['ap90'],
    "vaiśleṣika": ['mw'],
    "vaiśmika": ['mw'],
    "vaiśmīya": ['mw'],
    "vaiśramaṇa": ['bhs', 'mw'],
    "vaiśrambhaka": ['mw'],
    "vaiśravaṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "vaiśravaṇarājan": ['bhs'],
    "vaiśravaṇaḥ": ['ap90'],
    "vaiśravaṇodaya": ['mw'],
    "vaiśravaṇālaya": ['mw'],
    "vaiśravaṇānuja": ['mw'],
    "vaiśravaṇāvāsa": ['mw'],
    "vaiśreya": ['mw'],
    "vaiśva": ['cae', 'mw'],
    "vaiśvadaivata": ['mw'],
    "vaiśvadaivika": ['mw'],
    "vaiśvadeva": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaiśvadevabalikarman": ['mw'],
    "vaiśvadevahoma": ['mw'],
    "vaiśvadevaka": ['mw'],
    "vaiśvadevakarman": ['mw'],
    "vaiśvadevakhaṇḍana": ['mw'],
    "vaiśvadevaprayoga": ['mw'],
    "vaiśvadevapūjā": ['mw'],
    "vaiśvadevastut": ['mw'],
    "vaiśvadevata": ['mw'],
    "vaiśvadevavidhi": ['mw'],
    "vaiśvadevika": ['mw'],
    "vaiśvadevya": ['mw'],
    "vaiśvadevādimantravyākhyā": ['mw'],
    "vaiśvadevāgni": ['mw'],
    "vaiśvadevāgnimāruta": ['mw'],
    "vaiśvadevī": ['mw'],
    "vaiśvadha": ['mw'],
    "vaiśvadhainava": ['mw'],
    "vaiśvadhenava": ['mw'],
    "vaiśvadhenavabhakta": ['mw'],
    "vaiśvajanīna": ['mw'],
    "vaiśvajita": ['ddsa', 'mw'],
    "vaiśvajyotiṣa": ['mw'],
    "vaiśvakarmaṇa": ['cae', 'ddsa', 'mw'],
    "vaiśvakathika": ['mw'],
    "vaiśvalopa": ['mw'],
    "vaiśvamanasa": ['mw'],
    "vaiśvamānava": ['mw'],
    "vaiśvamānavabhakta": ['mw'],
    "vaiśvantara": ['mw'],
    "vaiśvarūpa": ['cae', 'ddsa', 'mw'],
    "vaiśvarūpya": ['cae', 'mw'],
    "vaiśvasṛja": ['mw'],
    "vaiśvasṛjacayanaprayoga": ['mw'],
    "vaiśvasṛjaprayoga": ['mw'],
    "vaiśvatari": ['mw'],
    "vaiśvavyacasa": ['mw'],
    "vaiśvaṃtari": ['mw'],
    "vaiśvāmanasa": ['mw'],
    "vaiśvāmitra": ['cae', 'ddsa', 'mw'],
    "vaiśvāmitri": ['mw'],
    "vaiśvāmitrika": ['mw'],
    "vaiśvāmitrī": ['mw'],
    "vaiśvānara": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vaiśvānaradatta": ['mw'],
    "vaiśvānaragupta": ['bhs'],
    "vaiśvānarajyeṣṭha": ['mw'],
    "vaiśvānarajyotis": ['mw'],
    "vaiśvānarakṣāra": ['mw'],
    "vaiśvānaramukha": ['mw'],
    "vaiśvānaranirghoṣa": ['bhs'],
    "vaiśvānarapatha": ['mw'],
    "vaiśvānarapathikṛtapūrvakadarśasthālīpākaprayoga": ['mw'],
    "vaiśvānarapathikṛtasthālīpākaprayoga": ['mw'],
    "vaiśvānaravat": ['mw'],
    "vaiśvānaravidyā": ['mw'],
    "vaiśvānarāyaṇa": ['mw'],
    "vaiśvānarī": ['mw'],
    "vaiśvānarīya": ['mw'],
    "vaiśvāsika": ['ap90', 'ddsa', 'mw'],
    "vaiśvāvasava": ['mw'],
    "vaiśvāvasavya": ['mw'],
    "vaiśvī": ['mw'],
    "vaiśya": ['cae', 'ddsa', 'gra', 'mw'],
    "vaiśyabhadrā": ['mw'],
    "vaiśyabhāva": ['mw'],
    "vaiśyacaritra": ['mw'],
    "vaiśyadhvaṃsin": ['mw'],
    "vaiśyaghna": ['mw'],
    "vaiśyajātīya": ['mw'],
    "vaiśyakanyā": ['mw'],
    "vaiśyakarman": ['mw'],
    "vaiśyakarmapustaka": ['mw'],
    "vaiśyakula": ['mw'],
    "vaiśyapura": ['mw'],
    "vaiśyaputra": ['cae', 'mw'],
    "vaiśyarata": ['mw'],
    "vaiśyasava": ['mw'],
    "vaiśyastoma": ['mw'],
    "vaiśyatva": ['mw'],
    "vaiśyatā": ['cae', 'mw'],
    "vaiśyavat": ['cae'],
    "vaiśyavṛtti": ['mw'],
    "vaiśyayajña": ['mw'],
    "vaiśyayoni": ['mw'],
    "vaiśyaḥ": ['ap90'],
    "vaiśyā": ['ddsa', 'mw'],
    "vaiśyāja": ['cae', 'mw'],
    "vaiśyāntara": ['mw'],
    "vaiśyāputra": ['cae', 'mw'],
    "vaiśyāyanī": ['bhs'],
    "vaiśākha": ['cae', 'ddsa', 'mw'],
    "vaiśākhamāhātmya": ['mw'],
    "vaiśākhamāsavrata": ['mw'],
    "vaiśākhapurāṇa": ['mw'],
    "vaiśākharajju": ['mw'],
    "vaiśākhavadi": ['mw'],
    "vaiśākhaḥ": ['ap90'],
    "vaiśākhin": ['mw'],
    "vaiśākhya": ['mw'],
    "vaiśākhā": ['mw'],
    "vaiśākhī": ['mw'],
    "vaiśāla": ['bhs', 'cae', 'mw'],
    "vaiśālaka": ['mw'],
    "vaiśāleya": ['ddsa', 'mw'],
    "vaiśāleyaka": ['bhs'],
    "vaiśāli": ['mw'],
    "vaiśālika": ['mw'],
    "vaiśālinī": ['mw'],
    "vaiśālya": ['bhs'],
    "vaiśālākṣa": ['mw'],
    "vaiśālāyana": ['mw'],
    "vaiśālī": ['mw'],
    "vaiśālīya": ['mw'],
    "vaiśārada": ['cae', 'ddsa', 'mw'],
    "vaiśāradya": ['bhs', 'cae', 'mw'],
    "vaiśāradyaprāpta": ['bhs'],
    "vaiśāradyavajranārāyaṇasiṃha": ['bhs'],
    "vaiśāradyaṃ": ['ap90'],
    "vaiśāstya": ['bhs'],
    "vaiśāyya": ['mw'],
    "vaiśīputra": ['mw'],
    "vaiśīti": ['mw'],
    "vaiḍava": ['mw'],
    "vaiḍāla": ['ap90', 'mw'],
    "vaiḍūrya": ['cae', 'ddsa', 'mw'],
    "vaiḍūryagarbha": ['bhs'],
    "vaiḍūryakānti": ['mw'],
    "vaiḍūryamaya": ['mw'],
    "vaiḍūryamaṇi": ['mw'],
    "vaiḍūryamaṇivat": ['mw'],
    "vaiḍūryanirbhāsa": ['bhs'],
    "vaiḍūryaprabha": ['bhs', 'mw'],
    "vaiḍūryaśikhara": ['bhs', 'mw'],
    "vaiḍūryaśṛṅga": ['mw'],
    "vaiṃśatika": ['ap90', 'mw'],
    "vaiṅgeya": ['mw'],
    "vaiṅgi": ['mw'],
    "vaiṅgīya": ['mw'],
    "vaiṅki": ['mw'],
    "vaiṇa": ['cae', 'ddsa', 'mw'],
    "vaiṇahotra": ['mw'],
    "vaiṇava": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaiṇavika": ['mw'],
    "vaiṇavikaḥ": ['ap90'],
    "vaiṇavin": ['ap90', 'mw'],
    "vaiṇavī": ['mw'],
    "vaiṇaḥ": ['ap90'],
    "vaiṇeya": ['mw'],
    "vaiṇika": ['ddsa', 'mw'],
    "vaiṇikaḥ": ['ap90'],
    "vaiṇu": ['bhs', 'mw'],
    "vaiṇuka": ['mw'],
    "vaiṇukaḥ": ['ap90'],
    "vaiṇukeya": ['mw'],
    "vaiṇukīya": ['mw'],
    "vaiṇvāṭata": ['bhs'],
    "vaiṇya": ['mw'],
    "vaiṇyadatta": ['mw'],
    "vaiṇāvata": ['mw'],
    "vaiṣadya": ['mw'],
    "vaiṣama": ['ddsa', 'mw'],
    "vaiṣamasthya": ['mw'],
    "vaiṣamika": ['bhs'],
    "vaiṣamya": ['cae', 'mw'],
    "vaiṣamyakaumudī": ['mw'],
    "vaiṣamyaṃ": ['ap90'],
    "vaiṣamyoddhariṇī": ['mw'],
    "vaiṣaya": ['mw'],
    "vaiṣayika": ['ap90', 'ddsa', 'mw'],
    "vaiṣayikī": ['mw'],
    "vaiṣka": ['mw'],
    "vaiṣkira": ['mw'],
    "vaiṣuvat": ['ap90'],
    "vaiṣuvata": ['cae', 'mw'],
    "vaiṣuvatīya": ['mw'],
    "vaiṣvaksenya": ['mw'],
    "vaiṣṇava": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaiṣṇavadharmamīmāṃsā": ['mw'],
    "vaiṣṇavadharmasuradrumamañjari": ['mw'],
    "vaiṣṇavadharmānuṣṭhānapaddhati": ['mw'],
    "vaiṣṇavadhyānaprakāra": ['mw'],
    "vaiṣṇavadāsa": ['mw'],
    "vaiṣṇavadīkṣāpaddhati": ['mw'],
    "vaiṣṇavajyotiṣaśāstra": ['mw'],
    "vaiṣṇavakaraṇa": ['mw'],
    "vaiṣṇavakarṇābharaṇasaṃgraha": ['mw'],
    "vaiṣṇavakutūhala": ['mw'],
    "vaiṣṇavalakṣaṇa": ['mw'],
    "vaiṣṇavamahāsiddhānta": ['mw'],
    "vaiṣṇavamatābjabhāskara": ['mw'],
    "vaiṣṇavanārāyaṇāṣṭākṣaranyāsa": ['mw'],
    "vaiṣṇavapramāṇasaṃgraha": ['mw'],
    "vaiṣṇavapraśnaśāstra": ['mw'],
    "vaiṣṇavapurāṇa": ['mw'],
    "vaiṣṇavasadācāranirṇaya": ['mw'],
    "vaiṣṇavasaṃhitā": ['mw'],
    "vaiṣṇavasiddhāntadīpikā": ['mw'],
    "vaiṣṇavasiddhāntatattva": ['mw'],
    "vaiṣṇavasiddhāntavaijayantī": ['mw'],
    "vaiṣṇavasthānaka": ['mw'],
    "vaiṣṇavatantra": ['mw'],
    "vaiṣṇavatoṣiṇī": ['mw'],
    "vaiṣṇavatva": ['mw'],
    "vaiṣṇavatīrtha": ['mw'],
    "vaiṣṇavavaidyakaśāstra": ['mw'],
    "vaiṣṇavavandanā": ['mw'],
    "vaiṣṇavavardhana": ['mw'],
    "vaiṣṇavavyākaraṇa": ['mw'],
    "vaiṣṇavavāruṇa": ['mw'],
    "vaiṣṇavaśaraṇāgati": ['mw'],
    "vaiṣṇavaśānti": ['mw'],
    "vaiṣṇavaśāstra": ['mw'],
    "vaiṣṇavopayoganirṇaya": ['mw'],
    "vaiṣṇavotsava": ['mw'],
    "vaiṣṇavotsavavidhi": ['mw'],
    "vaiṣṇavya": ['cae', 'mw'],
    "vaiṣṇavābhidhāna": ['mw'],
    "vaiṣṇavācamana": ['mw'],
    "vaiṣṇavācāra": ['mw'],
    "vaiṣṇavācārapaddhati": ['mw'],
    "vaiṣṇavācārasaṃgraha": ['mw'],
    "vaiṣṇavāgama": ['mw'],
    "vaiṣṇavākūtacandrikā": ['mw'],
    "vaiṣṇavāmṛta": ['mw'],
    "vaiṣṇavāyana": ['mw'],
    "vaiṣṇavāṣṭaka": ['mw'],
    "vaiṣṇavī": ['mw'],
    "vaiṣṇavītantra": ['mw'],
    "vaiṣṇugupta": ['mw'],
    "vaiṣṇuta": ['mw'],
    "vaiṣṇuvāruṇa": ['ddsa', 'mw'],
    "vaiṣṇuvṛddhi": ['mw'],
    "vaiṣṇāvaruṇa": ['mw'],
    "vaiṣṭambha": ['mw'],
    "vaiṣṭapa": ['mw'],
    "vaiṣṭapureya": ['mw'],
    "vaiṣṭika": ['bhs', 'mw'],
    "vaiṣṭra": ['mw'],
    "vaiṣṭraḥ": ['ap90'],
    "vaiṣṭubha": ['mw'],
    "vaiṣṭuta": ['mw'],
    "vaiṣṭutaṃ": ['ap90'],
    "vaiṭapa": ['mw'],
    "vaiṭuṣya": ['mw'],
    "vaiṭṭālika": ['mw'],
    "vaj": ['ap90', 'gra', 'mw'],
    "vaja": ['cped', 'ddsa'],
    "vajadvāra": ['cped'],
    "vajahuṇa": ['mw'],
    "vajamāna": ['cped'],
    "vajati": ['cped'],
    "vajaāṇa": ['mw'],
    "vaji": ['bhs', 'cped'],
    "vajira": ['bhs', 'cped'],
    "vajirahattha": ['cped'],
    "vajirapāṇi": ['cped'],
    "vajja": ['cped'],
    "vajjadeva": ['mw'],
    "vajjana": ['cped'],
    "vajjanīya": ['cped'],
    "vajjaṁ": ['cped'],
    "vajjesi": ['cped'],
    "vajjetabba": ['cped'],
    "vajjeti": ['cped'],
    "vajjetuṁ": ['cped'],
    "vajjetvā": ['cped'],
    "vajjha": ['cped'],
    "vajjhabheri": ['cped'],
    "vajjhappatta": ['cped'],
    "vajji": ['bhs'],
    "vajjita": ['cped'],
    "vajjiya": ['cped'],
    "vajjā": ['cped'],
    "vajjī": ['cped'],
    "vajra": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vajrabadha": ['mw'],
    "vajrabhairavī": ['bhs'],
    "vajrabhaṭṭīya": ['mw'],
    "vajrabhāskarī": ['bhs'],
    "vajrabhūmi": ['mw'],
    "vajrabhūmirajas": ['mw'],
    "vajrabhṛkuṭi": ['mw'],
    "vajrabhṛkuṭī": ['bhs'],
    "vajrabhṛt": ['cae', 'gra', 'mw'],
    "vajrabāhu": ['cae', 'gra', 'mw'],
    "vajrabījaka": ['mw'],
    "vajracarcikā": ['bhs'],
    "vajracarman": ['mw'],
    "vajracañcu": ['mw'],
    "vajracchedakaprajñāpāramitā": ['mw'],
    "vajrachedikā": ['bhs'],
    "vajracihna": ['mw'],
    "vajradakṣiṇa": ['cae', 'gra', 'mw'],
    "vajradanta": ['mw'],
    "vajradatta": ['mw'],
    "vajradaśana": ['mw'],
    "vajradaṃṣṭra": ['mw'],
    "vajradaṇḍa": ['mw'],
    "vajradaṇḍaka": ['mw'],
    "vajradeha": ['mw'],
    "vajradehin": ['mw'],
    "vajradehā": ['mw'],
    "vajradeśa": ['mw'],
    "vajradhara": ['bhs', 'cae', 'mw'],
    "vajradharaprabhāva": ['mw'],
    "vajradharā": ['bhs'],
    "vajradhvaja": ['bhs'],
    "vajradhvajasūtra": ['bhs'],
    "vajradhvani": ['mw'],
    "vajradhāra": ['mw'],
    "vajradhāraṇa": ['mw'],
    "vajradhātrī": ['mw'],
    "vajradhātvī": ['mw'],
    "vajradhātvīśvarī": ['bhs', 'mw'],
    "vajradhṛk": ['mw'],
    "vajradru": ['mw'],
    "vajradruma": ['mw'],
    "vajradrumakesaradhvaja": ['bhs', 'mw'],
    "vajradṛḍhanetra": ['bhs', 'mw'],
    "vajragarbha": ['bhs', 'mw'],
    "vajraghoṣa": ['mw'],
    "vajraghāta": ['mw'],
    "vajragir": ['bhs'],
    "vajragopa": ['mw'],
    "vajragupta": ['bhs'],
    "vajragāndhārī": ['bhs'],
    "vajrahasta": ['cae', 'gra', 'mw'],
    "vajrahastā": ['mw'],
    "vajrahūna": ['mw'],
    "vajrahṛdaya": ['mw'],
    "vajrajit": ['mw'],
    "vajrajvalana": ['mw'],
    "vajrajvālā": ['mw'],
    "vajrajvālānalārka": ['bhs'],
    "vajrajñānaparvata": ['bhs'],
    "vajraka": ['bhs', 'mw'],
    "vajrakanda": ['mw'],
    "vajrakandaka": ['mw'],
    "vajrakapāṭamat": ['mw'],
    "vajrakapāṭarasa": ['mw'],
    "vajrakarṇa": ['mw'],
    "vajrakarṣaṇa": ['mw'],
    "vajrakavaca": ['mw'],
    "vajrakaṃ": ['ap90'],
    "vajrakaṅkaṭa": ['mw'],
    "vajrakaṇṭa": ['mw'],
    "vajrakaṇṭaka": ['mw'],
    "vajrakaṇṭakaśālmalī": ['mw'],
    "vajraketu": ['mw'],
    "vajrakuca": ['mw'],
    "vajrakukṣi": ['bhs', 'mw'],
    "vajrakālikā": ['mw'],
    "vajrakālī": ['mw'],
    "vajrakāmā": ['mw'],
    "vajrakīla": ['cae', 'mw'],
    "vajrakīlāya": ['mw'],
    "vajrakīṭa": ['mw'],
    "vajrakūṭa": ['mw'],
    "vajrakṛta": ['mw'],
    "vajrakṣāra": ['mw'],
    "vajralepa": ['cae', 'mw'],
    "vajralepaghaṭita": ['mw'],
    "vajralepāya": ['mw'],
    "vajralepāyamānatva": ['mw'],
    "vajralipi": ['bhs', 'mw'],
    "vajralohaka": ['mw'],
    "vajramati": ['bhs', 'mw'],
    "vajramaya": ['cae', 'mw'],
    "vajramaṇi": ['mw'],
    "vajramaṇḍala": ['bhs'],
    "vajramaṇḍā": ['mw'],
    "vajrameruśikharakūṭāgāradhāraṇī": ['bhs'],
    "vajramitra": ['mw'],
    "vajramukha": ['mw'],
    "vajramukuṭa": ['cae', 'mw'],
    "vajramukuṭīvilāsa": ['mw'],
    "vajramuṣṭi": ['bhs', 'cae', 'mw'],
    "vajramālā": ['bhs', 'mw'],
    "vajramāra": ['mw'],
    "vajramūlī": ['mw'],
    "vajranagara": ['mw'],
    "vajranakha": ['mw'],
    "vajranetra": ['bhs'],
    "vajranirghoṣa": ['mw'],
    "vajraniṣkambha": ['mw'],
    "vajraniṣpeṣa": ['mw'],
    "vajranābha": ['mw'],
    "vajranābhi": ['bhs'],
    "vajranābhīya": ['mw'],
    "vajranārāyaṇaketu": ['bhs'],
    "vajrapadavikramin": ['bhs'],
    "vajrapadmeśvarī": ['bhs'],
    "vajrapadmottara": ['bhs'],
    "vajraparīkṣā": ['mw'],
    "vajrapatana": ['cae', 'mw'],
    "vajrapattrikā": ['mw'],
    "vajrapañjara": ['mw'],
    "vajraprabha": ['mw'],
    "vajraprabhāva": ['mw'],
    "vajrapramardanin": ['bhs'],
    "vajrapramardin": ['bhs'],
    "vajraprastāriṇī": ['mw'],
    "vajraprastāriṇīmantra": ['mw'],
    "vajraprastāvinī": ['mw'],
    "vajraprastāvinīmantra": ['mw'],
    "vajraprākāra": ['mw'],
    "vajraprāya": ['mw'],
    "vajrapura": ['bhs', 'mw'],
    "vajrapuṣpa": ['mw'],
    "vajrapuṣpā": ['mw'],
    "vajrapāda": ['bhs'],
    "vajrapāta": ['cae', 'mw'],
    "vajrapātaduḥsahatara": ['mw'],
    "vajrapātadāruṇa": ['mw'],
    "vajrapātana": ['mw'],
    "vajrapātasadṛśa": ['mw'],
    "vajrapātāya": ['mw'],
    "vajrapāṇi": ['bhs', 'cae', 'mw'],
    "vajrapāṇin": ['mw'],
    "vajrapāṇitva": ['mw'],
    "vajrapāṣāṇa": ['mw'],
    "vajrarada": ['mw'],
    "vajraratha": ['mw'],
    "vajraratnagiritejas": ['bhs'],
    "vajraraudrī": ['bhs'],
    "vajrarājagṛha": ['bhs'],
    "vajrarātra": ['mw'],
    "vajrarūpa": ['mw'],
    "vajrasamutkīrṇa": ['mw'],
    "vajrasamādhi": ['mw'],
    "vajrasamānasāra": ['mw'],
    "vajrasarasvatī": ['bhs'],
    "vajrasattva": ['mw'],
    "vajrasattvātmikā": ['mw'],
    "vajrasaṃghāta": ['bhs', 'mw'],
    "vajrasaṃhanana": ['bhs'],
    "vajrasaṃhata": ['bhs', 'mw'],
    "vajrasaṃsparśa": ['mw'],
    "vajrasena": ['bhs', 'mw'],
    "vajrasiṃha": ['mw'],
    "vajrasthāna": ['mw'],
    "vajrasvāmin": ['mw'],
    "vajrasāgaradhvajamegha": ['bhs'],
    "vajrasāgaragarbhā": ['bhs'],
    "vajrasāra": ['bhs', 'cae', 'mw'],
    "vajrasāramaya": ['mw'],
    "vajrasāramayatva": ['mw'],
    "vajrasārīkṛ": ['cae', 'mw'],
    "vajrasūci": ['mw'],
    "vajrasūcī": ['mw'],
    "vajrasūrya": ['mw'],
    "vajratara": ['mw'],
    "vajratulya": ['mw'],
    "vajratuṇḍa": ['bhs', 'mw'],
    "vajratuṇḍī": ['bhs'],
    "vajratva": ['mw'],
    "vajratā": ['mw'],
    "vajratārā": ['bhs'],
    "vajratīkṣṇa": ['bhs'],
    "vajratīrthamāhātmya": ['mw'],
    "vajravadha": ['mw'],
    "vajravah": ['cae', 'gra', 'mw'],
    "vajravallī": ['mw'],
    "vajravaracandra": ['mw'],
    "vajravarman": ['mw'],
    "vajravega": ['cae', 'mw'],
    "vajravetālī": ['bhs'],
    "vajravidrāviṇī": ['mw'],
    "vajravihata": ['mw'],
    "vajraviṣkambha": ['mw'],
    "vajravyūha": ['mw'],
    "vajravāh": ['cae', 'gra', 'mw'],
    "vajravāraka": ['mw'],
    "vajravārāhikā": ['bhs'],
    "vajravārāhī": ['bhs', 'mw'],
    "vajravījaka": ['mw'],
    "vajravīra": ['mw'],
    "vajravṛkṣa": ['mw'],
    "vajrayoginī": ['bhs', 'mw'],
    "vajrayāna": ['bhs'],
    "vajraśalya": ['mw'],
    "vajraśalyā": ['mw'],
    "vajraśarīra": ['mw'],
    "vajraśrī": ['bhs', 'mw'],
    "vajraśuci": ['mw'],
    "vajraśuddha": ['bhs'],
    "vajraśākhā": ['mw'],
    "vajraśīrṣa": ['mw'],
    "vajraśṛṅkhalikā": ['mw'],
    "vajraśṛṅkhalā": ['bhs', 'mw'],
    "vajraḍāka": ['bhs'],
    "vajraḍākī": ['bhs'],
    "vajraṇakhā": ['mw'],
    "vajraṭa": ['mw'],
    "vajraṭaṅka": ['mw'],
    "vajraṭaṅkīya": ['mw'],
    "vajraṭīka": ['mw'],
    "vajrendra": ['ddsa', 'mw'],
    "vajreśvarī": ['mw'],
    "vajreśvarīkāvya": ['mw'],
    "vajri": ['mw'],
    "vajrijit": ['mw'],
    "vajrikā": ['mw'],
    "vajrin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vajrivas": ['cae', 'ddsa'],
    "vajrivat": ['gra', 'mw'],
    "vajriṇī": ['mw'],
    "vajrodarī": ['mw'],
    "vajrodgata": ['mw'],
    "vajrolī": ['mw'],
    "vajropama": ['bhs'],
    "vajrottarajñānin": ['bhs'],
    "vajrā": ['bhs', 'mw'],
    "vajrābha": ['bhs', 'mw'],
    "vajrābhiṣavaṇa": ['mw'],
    "vajrābhra": ['mw'],
    "vajrābhyāsa": ['mw'],
    "vajrācārya": ['mw'],
    "vajrāditya": ['mw'],
    "vajrāghāta": ['mw'],
    "vajrāhata": ['mw'],
    "vajrāhikā": ['mw'],
    "vajrākara": ['bhs', 'ddsa', 'mw'],
    "vajrākhya": ['mw'],
    "vajrākāra": ['mw'],
    "vajrākṛti": ['mw'],
    "vajrākṣī": ['mw'],
    "vajrāmbujā": ['bhs', 'mw'],
    "vajrānaṅga": ['bhs'],
    "vajrārciḥśrīvatsālaṃkāragarbha": ['bhs'],
    "vajrāsana": ['mw'],
    "vajrāsthi": ['mw'],
    "vajrāsu": ['mw'],
    "vajrāsura": ['mw'],
    "vajrāvālī": ['mw'],
    "vajrāy": ['cae'],
    "vajrāya": ['ddsa', 'mw'],
    "vajrāyudha": ['bhs', 'ddsa', 'mw'],
    "vajrāśani": ['mw'],
    "vajrāśaninipāta": ['mw'],
    "vajrāśanisamasvana": ['mw'],
    "vajrāśanivibhūṣita": ['mw'],
    "vajrāśayogiriśirī": ['bhs'],
    "vajrāṃśu": ['mw'],
    "vajrāṃśuka": ['mw'],
    "vajrāṅga": ['mw'],
    "vajrāṅgī": ['mw'],
    "vajrāṅkita": ['mw'],
    "vajrāṅkuśa": ['bhs', 'mw'],
    "vajrāṅkuśī": ['bhs', 'mw'],
    "vajrāṇḍi": ['mw'],
    "vajrī": ['mw'],
    "vajrībhūta": ['ddsa', 'mw'],
    "vajrīkaraṇa": ['mw'],
    "vak": ['ddsa', 'gra', 'mw'],
    "vaka": ['ap90', 'bhs', 'cped', 'mw'],
    "vakala": ['cae', 'ddsa', 'mw'],
    "vakaraḥ": ['ap90'],
    "vakasuhāṇa": ['mw'],
    "vakerukā": ['mw'],
    "vakh": ['ap90', 'mw'],
    "vakhala": ['bhs'],
    "vakk": ['ap90', 'mw'],
    "vakka": ['cped'],
    "vakkala": ['bhs', 'cped'],
    "vakkali": ['bhs'],
    "vakkalin": ['bhs', 'mw'],
    "vakkalī": ['cped'],
    "vakkasa": ['mw'],
    "vakkhati": ['cped'],
    "vakkula": ['bhs', 'mw'],
    "vakman": ['ap90', 'gra', 'mw'],
    "vakmarājan": ['gra'],
    "vakmarājasatya": ['gra', 'mw'],
    "vakmia": ['gra'],
    "vakmya": ['cae', 'gra', 'mw'],
    "vakra": ['ap90', 'cae', 'ddsa', 'mw'],
    "vakrabhaṇita": ['cae', 'mw'],
    "vakrabhuja": ['mw'],
    "vakrabhāva": ['cae', 'mw'],
    "vakrabuddhi": ['mw'],
    "vakracañcu": ['mw'],
    "vakradala": ['mw'],
    "vakradanta": ['mw'],
    "vakradantībīja": ['mw'],
    "vakradaṃṣṭra": ['mw'],
    "vakradhī": ['mw'],
    "vakradṛś": ['mw'],
    "vakradṛṣṭi": ['mw'],
    "vakraga": ['mw'],
    "vakragamana": ['mw'],
    "vakragandhanibandhakṛt": ['mw'],
    "vakragata": ['mw'],
    "vakragati": ['mw'],
    "vakragrīva": ['mw'],
    "vakragāmin": ['mw'],
    "vakrakaṇṭa": ['mw'],
    "vakrakaṇṭaka": ['mw'],
    "vakrakhaḍga": ['mw'],
    "vakrakhaḍgaka": ['mw'],
    "vakrakīla": ['mw'],
    "vakralāṅgūla": ['mw'],
    "vakrama": ['ap90', 'mw'],
    "vakramati": ['mw'],
    "vakranakra": ['mw'],
    "vakranāla": ['mw'],
    "vakranāsa": ['cae', 'mw'],
    "vakranāsika": ['mw'],
    "vakrapada": ['mw'],
    "vakrapakṣa": ['mw'],
    "vakrapluta": ['mw'],
    "vakrapuccha": ['mw'],
    "vakrapucchika": ['mw'],
    "vakrapura": ['mw'],
    "vakrapuṣpa": ['mw'],
    "vakrapāda": ['cae', 'mw'],
    "vakrarekhā": ['mw'],
    "vakrasaṃstha": ['mw'],
    "vakratodin": ['mw'],
    "vakratu": ['mw'],
    "vakratuṇḍa": ['mw'],
    "vakratuṇḍagaṇanāyakaprakaraṇa": ['mw'],
    "vakratuṇḍapūjāvidhi": ['mw'],
    "vakratuṇḍastavana": ['mw'],
    "vakratuṇḍastotra": ['mw'],
    "vakratuṇḍāṣṭaka": ['mw'],
    "vakratva": ['mw'],
    "vakratā": ['ap90', 'mw'],
    "vakratāla": ['mw'],
    "vakratālī": ['mw'],
    "vakravaktra": ['mw'],
    "vakravākya": ['mw'],
    "vakravāladhi": ['mw'],
    "vakraya": ['mw'],
    "vakrayodhin": ['mw'],
    "vakraśalyā": ['mw'],
    "vakraśṛṅga": ['mw'],
    "vakretara": ['cae', 'ddsa', 'mw'],
    "vakri": ['ap90', 'mw'],
    "vakrima": ['mw'],
    "vakriman": ['ap90', 'cae', 'mw'],
    "vakrin": ['ap90', 'mw'],
    "vakrita": ['ap90', 'cae', 'ddsa', 'mw'],
    "vakrokti": ['cae', 'mw'],
    "vakroktijīvita": ['mw'],
    "vakroktipañcāśikā": ['mw'],
    "vakrolaka": ['cae', 'ddsa', 'mw'],
    "vakroṣṭhi": ['mw'],
    "vakroṣṭhika": ['mw'],
    "vakroṣṭhikā": ['mw'],
    "vakroṣṭhiḥ": ['ap90'],
    "vakrā": ['mw'],
    "vakrāgra": ['mw'],
    "vakrākhya": ['mw'],
    "vakrātapa": ['mw'],
    "vakrāṅga": ['mw'],
    "vakrāṅghri": ['mw'],
    "vakrāṅghrisaṃgrāma": ['mw'],
    "vakrī": ['mw'],
    "vakrībhāva": ['mw'],
    "vakrībhāvaḥ": ['ap90'],
    "vakrībhū": ['ap90', 'mw'],
    "vakrībhūta": ['mw'],
    "vakrīkaraṇa": ['mw'],
    "vakrīkṛ": ['ap90', 'ddsa', 'mw'],
    "vakrīkṛta": ['mw'],
    "vaktave": ['mw'],
    "vaktavya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaktavyahṛdaya": ['mw'],
    "vaktavyatva": ['mw'],
    "vaktavyatā": ['ap90', 'mw'],
    "vaktavyikā": ['bhs'],
    "vakti": ['cae', 'ddsa', 'mw'],
    "vaktos": ['mw'],
    "vaktra": ['bhs', 'cae', 'ddsa', 'mw'],
    "vaktrabhedin": ['mw'],
    "vaktracchada": ['mw'],
    "vaktradala": ['mw'],
    "vaktradaṃṣṭra": ['mw'],
    "vaktradvāra": ['cae', 'mw'],
    "vaktraja": ['mw'],
    "vaktraka": ['mw'],
    "vaktrakhura": ['mw'],
    "vaktraparispanda": ['mw'],
    "vaktrapaṭa": ['mw'],
    "vaktrapaṭṭa": ['mw'],
    "vaktrapāni": ['mw'],
    "vaktraroga": ['mw'],
    "vaktrarogin": ['mw'],
    "vaktraruha": ['mw'],
    "vaktratuṇḍa": ['mw'],
    "vaktratāla": ['mw'],
    "vaktravākya": ['mw'],
    "vaktravāsa": ['mw'],
    "vaktrayodhin": ['mw'],
    "vaktraśodhana": ['mw'],
    "vaktraśodhin": ['mw'],
    "vaktraṃ": ['ap90'],
    "vaktrendu": ['cae', 'mw'],
    "vaktrāmbuja": ['cae', 'mw'],
    "vaktrāsava": ['mw'],
    "vaktu": ['mw'],
    "vaktukāma": ['cae', 'ddsa', 'mw'],
    "vaktumanas": ['mw'],
    "vaktva": ['cae', 'ddsa', 'mw'],
    "vaktṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vaktṛka": ['mw'],
    "vaktṛtva": ['mw'],
    "vaktṛtvaśakti": ['mw'],
    "vaktṛtā": ['mw'],
    "vakula": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "vakuśa": ['mw'],
    "vakva": ['cae', 'ddsa', 'gra', 'mw'],
    "vakvan": ['ap90', 'cae', 'gra', 'mw'],
    "vakvasa": ['mw'],
    "vakā": ['ap90'],
    "vakāra": ['cae', 'ddsa', 'mw'],
    "vakārabheda": ['mw'],
    "vakṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vakṣas": ['ap90', 'cae', 'gra', 'mw'],
    "vakṣasija": ['mw'],
    "vakṣaskāra": ['mw'],
    "vakṣaskārikā": ['mw'],
    "vakṣastaṭāghāta": ['mw'],
    "vakṣatha": ['cae', 'gra', 'mw'],
    "vakṣathaḥ": ['ap90'],
    "vakṣaś": ['mw'],
    "vakṣaśchada": ['mw'],
    "vakṣaḥ": ['mw'],
    "vakṣaḥsammardinī": ['mw'],
    "vakṣaḥstha": ['mw'],
    "vakṣaḥsthala": ['cae', 'ddsa', 'mw'],
    "vakṣaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "vakṣaṇaṃ": ['ap90'],
    "vakṣaṇesthā": ['mw'],
    "vakṣaṇeṣṭhā": ['gra'],
    "vakṣaṇi": ['cae', 'gra', 'mw'],
    "vakṣaṇā": ['cae', 'gra', 'mw'],
    "vakṣi": ['ddsa'],
    "vakṣo": ['mw'],
    "vakṣogrīva": ['mw'],
    "vakṣoja": ['cae', 'ddsa', 'mw'],
    "vakṣojatā": ['mw'],
    "vakṣomaṇi": ['mw'],
    "vakṣomaṇḍalin": ['mw'],
    "vakṣoruh": ['cae', 'mw'],
    "vakṣoruha": ['mw'],
    "vakṣu": ['bhs', 'mw'],
    "vakṣya": ['ddsa'],
    "vakṣyamāṇa": ['mw'],
    "vakṣyamāṇatva": ['mw'],
    "vakṣī": ['ap90', 'cae', 'gra', 'mw'],
    "val": ['ap90', 'cae', 'ddsa', 'mw'],
    "vala": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "valabhi": ['cae', 'ddsa', 'mw'],
    "valabhid": ['cae', 'ddsa', 'mw'],
    "valabhiḥ": ['ap90'],
    "valabhī": ['ap90', 'cae', 'ddsa'],
    "valabhīniveśa": ['mw'],
    "valaga": ['mw'],
    "valagahan": ['mw'],
    "valagin": ['mw'],
    "valagna": ['mw'],
    "valagnaḥ": ['ap90'],
    "valaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "valakeśvaratīrtha": ['mw'],
    "valakrama": ['mw'],
    "valakṣa": ['ap90', 'mw'],
    "valamba": ['mw'],
    "valambha": ['mw'],
    "valana": ['cae', 'ddsa', 'mw'],
    "valanaṃ": ['ap90'],
    "valantikā": ['cae', 'ddsa', 'mw'],
    "valanā": ['mw'],
    "valanāśana": ['mw'],
    "valanāṃśa": ['mw'],
    "valarasā": ['mw'],
    "valasūdana": ['mw'],
    "valavat": ['ddsa', 'mw'],
    "valavṛtraghna": ['cae'],
    "valaya": ['cae', 'cped', 'ddsa', 'mw'],
    "valayavat": ['mw'],
    "valayaḥ": ['ap90'],
    "valayin": ['cae', 'mw'],
    "valayita": ['ap90', 'cae', 'ddsa', 'mw'],
    "valayitṛ": ['mw'],
    "valayā": ['bhs'],
    "valayākāra": ['cped'],
    "valayī": ['mw'],
    "valayībhū": ['mw'],
    "valayīkṛ": ['mw'],
    "valayīkṛta": ['mw'],
    "valayīkṛtavāsuki": ['mw'],
    "valayīkṛtāhi": ['mw'],
    "valañja": ['cped'],
    "valañjana": ['cped'],
    "valañjanaka": ['cped'],
    "valañjenta": ['cped'],
    "valañjesi": ['cped'],
    "valañjetabba": ['cped'],
    "valañjeti": ['cped'],
    "valañjetvā": ['cped'],
    "valañjita": ['cped'],
    "valañjiyamāna": ['cped'],
    "valaṃba": ['ap90'],
    "valaṃruja": ['gra', 'mw'],
    "valbh": ['ap90', 'cae', 'ddsa', 'mw'],
    "valbhana": ['mw'],
    "valbhanaṃ": ['ap90'],
    "valbhita": ['mw'],
    "valg": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "valgaka": ['cae', 'mw'],
    "valgana": ['cae', 'ddsa', 'mw'],
    "valganaṃ": ['ap90'],
    "valganā": ['bhs'],
    "valgita": ['ap90', 'cae', 'mw'],
    "valgitabhrū": ['cae', 'mw'],
    "valgitakaṇṭha": ['mw'],
    "valgu": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "valgudantīsuta": ['mw'],
    "valguja": ['mw'],
    "valgujaṅgha": ['mw'],
    "valgujā": ['mw'],
    "valguka": ['ap90', 'mw'],
    "valgula": ['mw'],
    "valgulaḥ": ['ap90'],
    "valgulikā": ['ap90', 'ddsa', 'mw'],
    "valgulā": ['mw'],
    "valgulī": ['cae', 'mw'],
    "valgunāda": ['mw'],
    "valgupattra": ['mw'],
    "valgupodakī": ['mw'],
    "valgusvara": ['bhs'],
    "valguyā": ['bhs'],
    "valgā": ['ap90', 'cae', 'mw'],
    "valgāmaṭha": ['mw'],
    "valgāṅka": ['mw'],
    "valgūy": ['cae', 'gra'],
    "valgūya": ['mw'],
    "valgūyati": ['ap90'],
    "valh": ['ap90', 'cae', 'ddsa', 'mw'],
    "valhi": ['mw'],
    "valhika": ['ap90'],
    "vali": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "valibha": ['cae', 'mw'],
    "valika": ['cped', 'mw'],
    "valikaśīrṣa": ['bhs'],
    "valikaḥ": ['ap90'],
    "valikāsaṃnāha": ['bhs'],
    "valimant": ['cae'],
    "valimat": ['ap90', 'mw'],
    "valimukha": ['mw'],
    "valina": ['ap90', 'cae', 'ddsa', 'mw'],
    "valira": ['ap90', 'cped', 'mw'],
    "valita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "valitadṛś": ['mw'],
    "valitagrīva": ['mw'],
    "valitaka": ['bhs', 'mw'],
    "valitakaṃdhara": ['mw'],
    "valittaca": ['cped'],
    "valitānana": ['mw'],
    "valitāpāṅga": ['mw'],
    "valivaṇḍa": ['mw'],
    "valiśa": ['mw'],
    "valiśaṃ": ['ap90'],
    "valiśāna": ['mw'],
    "valiḥ": ['ap90'],
    "valk": ['ap90', 'mw'],
    "valka": ['cae', 'ddsa', 'mw'],
    "valkadruma": ['mw'],
    "valkaja": ['mw'],
    "valkala": ['bhs', 'cae', 'mw'],
    "valkalacīrin": ['mw'],
    "valkalakṣetra": ['mw'],
    "valkalakṣetramāhātmya": ['mw'],
    "valkalasaṃvīta": ['mw'],
    "valkalavant": ['cae'],
    "valkalavat": ['mw'],
    "valkalaḥ": ['ap90'],
    "valkalin": ['bhs', 'cae', 'ddsa', 'mw'],
    "valkalodhra": ['mw'],
    "valkalā": ['mw'],
    "valkalājinadhāraṇa": ['mw'],
    "valkalājinasaṃvṛta": ['mw'],
    "valkalājinavāsas": ['cae', 'mw'],
    "valkalāmbaradhāraṇa": ['cae'],
    "valkapattra": ['mw'],
    "valkaphala": ['mw'],
    "valkarodhra": ['mw'],
    "valkataru": ['mw'],
    "valkavat": ['ap90', 'mw'],
    "valkavāsas": ['cae', 'ddsa', 'mw'],
    "valkaḥ": ['ap90'],
    "valkita": ['mw'],
    "valkitaḥ": ['ap90'],
    "valkuta": ['mw'],
    "valkuṭaṃ": ['ap90'],
    "vall": ['ap90', 'mw'],
    "valla": ['cae', 'ddsa', 'mw'],
    "vallabha": ['ap90', 'cae', 'ddsa', 'mw'],
    "vallabhadeva": ['mw'],
    "vallabhadāsa": ['mw'],
    "vallabhadīkṣita": ['mw'],
    "vallabhagaṇi": ['mw'],
    "vallabhajana": ['cae', 'mw'],
    "vallabhajī": ['mw'],
    "vallabhaka": ['bhs', 'mw'],
    "vallabhanṛsiṃha": ['mw'],
    "vallabhapura": ['mw'],
    "vallabhapāla": ['mw'],
    "vallabhapālaka": ['mw'],
    "vallabharājadeva": ['mw'],
    "vallabhasiddhāntaṭīkā": ['mw'],
    "vallabhasvāmin": ['mw'],
    "vallabhatama": ['mw'],
    "vallabhatara": ['mw'],
    "vallabhataratā": ['mw'],
    "vallabhatta": ['cped'],
    "vallabhatva": ['mw'],
    "vallabhatā": ['mw'],
    "vallabhaśakti": ['mw'],
    "vallabhendra": ['mw'],
    "vallabheśvara": ['mw'],
    "vallabhā": ['mw'],
    "vallabhācārya": ['mw'],
    "vallabhācāryavaṃśāvalī": ['mw'],
    "vallabhākhyāna": ['mw'],
    "vallabhānanda": ['mw'],
    "vallabhāyita": ['mw'],
    "vallabhāyitaṃ": ['ap90'],
    "vallabhāṣṭaka": ['mw'],
    "vallabhāṣṭakavivṛti": ['mw'],
    "vallabhī": ['ddsa', 'mw'],
    "vallabrahmasūtrabhāṣya": ['mw'],
    "vallaka": ['bhs', 'mw'],
    "vallakarañja": ['mw'],
    "vallaki": ['cae'],
    "vallakī": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vallamāhātmya": ['mw'],
    "vallana": ['mw'],
    "vallara": ['mw'],
    "vallaraṃ": ['ap90'],
    "vallari": ['cae', 'ddsa', 'mw'],
    "vallariḥ": ['ap90'],
    "vallarī": ['bhs', 'cae', 'cped', 'mw'],
    "vallarīka": ['mw'],
    "vallarīkā": ['mw'],
    "vallava": ['mw'],
    "vallavaḥ": ['ap90'],
    "vallaḥ": ['ap90'],
    "valli": ['cae', 'cped', 'mw'],
    "vallibha": ['cped'],
    "vallidūrvā": ['mw'],
    "vallihāraka": ['cped'],
    "vallija": ['mw'],
    "vallikaṇṭakārikā": ['mw'],
    "valliki": ['bhs'],
    "vallikā": ['mw'],
    "vallikāgra": ['mw'],
    "vallikī": ['mw'],
    "vallimat": ['mw'],
    "vallinī": ['mw'],
    "vallirāṣṭra": ['mw'],
    "vallisūraṇa": ['mw'],
    "vallita": ['bhs'],
    "valliśākaṭapotikā": ['mw'],
    "valliśāstrin": ['mw'],
    "valliḥ": ['ap90'],
    "vallm, vallī": ['ddsa'],
    "valluka": ['bhs'],
    "vallura": ['mw'],
    "valluragṛha": ['bhs'],
    "valluraṃ": ['ap90'],
    "vallyā": ['mw'],
    "vallāpura": ['ddsa', 'mw'],
    "vallāra": ['mw'],
    "vallārī": ['mw'],
    "vallī": ['ap90', 'cae', 'ddsa', 'mw'],
    "vallībadarī": ['mw'],
    "vallīgaḍa": ['mw'],
    "vallīja": ['mw'],
    "vallīkarṇa": ['mw'],
    "vallīmudga": ['mw'],
    "vallīpada": ['mw'],
    "vallīvṛkṣa": ['mw'],
    "vallūra": ['cae', 'cped', 'ddsa', 'mw'],
    "vallūraka": ['mw'],
    "vallūraḥ": ['ap90'],
    "valmika": ['ap90', 'mw'],
    "valmiki": ['mw'],
    "valmī": ['ap90', 'mw'],
    "valmīka": ['cae', 'ddsa', 'mw'],
    "valmīkabhauma": ['mw'],
    "valmīkabhava": ['mw'],
    "valmīkajanman": ['mw'],
    "valmīkalpa": ['mw'],
    "valmīkamātra": ['mw'],
    "valmīkarāśi": ['cae', 'mw'],
    "valmīkasambhavā": ['mw'],
    "valmīkavapā": ['mw'],
    "valmīkaśīrṣa": ['mw'],
    "valmīkaśṛṅga": ['mw'],
    "valmīkaśṛṅgavat": ['mw'],
    "valmīkaḥ": ['ap90'],
    "valmīkāgra": ['cae', 'mw'],
    "valmīkūṭa": ['mw'],
    "valomoṭa": ['bhs'],
    "valva": ['mw'],
    "valvaja": ['mw'],
    "valyul": ['ap90'],
    "valyula": ['mw'],
    "valyūl": ['ap90'],
    "valyūla": ['mw'],
    "valāha": ['bhs'],
    "valāhaka": ['ap90', 'cae', 'cped', 'mw'],
    "valāka": ['ap90', 'mw'],
    "valākin": ['ap90'],
    "valāsaka": ['mw'],
    "valāsakaḥ": ['ap90'],
    "valāṭa": ['mw'],
    "valī": ['cae', 'ddsa', 'mw'],
    "valībhṛt": ['mw'],
    "valīka": ['mw'],
    "valīkaṃ": ['ap90'],
    "valīmant": ['cae'],
    "valīmat": ['mw'],
    "valīmukha": ['cae', 'cped', 'mw'],
    "valīmukhamukha": ['mw'],
    "valīnaka": ['mw'],
    "valīpalita": ['cae', 'mw'],
    "valīvadana": ['cae', 'mw'],
    "valīvardaḥ": ['ap90'],
    "valśa": ['cae', 'ddsa', 'gra', 'mw'],
    "valūka": ['mw'],
    "valūkaḥ": ['ap90'],
    "valūla": ['ap90', 'mw'],
    "vam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vama": ['mw'],
    "vamana": ['cae', 'cped', 'mw'],
    "vamanadravya": ['mw'],
    "vamanakalpa": ['mw'],
    "vamanaṃ": ['ap90'],
    "vamanārthīya": ['mw'],
    "vamanī": ['mw'],
    "vamanīya": ['mw'],
    "vamanīyā": ['ap90', 'mw'],
    "vamathu": ['cae', 'cped', 'ddsa', 'mw'],
    "vamathuḥ": ['ap90'],
    "vamati": ['cped', 'mw'],
    "vamaḥ": ['ap90'],
    "vambh": ['bhs'],
    "vambha": ['mw'],
    "vambhana": ['cped'],
    "vambhanā": ['cped'],
    "vambhenta": ['cped'],
    "vambhesi": ['cped'],
    "vambheti": ['cped'],
    "vambhetvā": ['cped'],
    "vambhita": ['cped'],
    "vambhārava": ['mw'],
    "vambhī": ['cped'],
    "vami": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vamin": ['mw'],
    "vamita": ['cped', 'mw'],
    "vamitavya": ['mw'],
    "vamitvā": ['cped'],
    "vamma": ['cped'],
    "vammesi": ['cped'],
    "vammeti": ['cped'],
    "vammetvā": ['cped'],
    "vammika": ['cped'],
    "vammita": ['cped'],
    "vammāgadeśa": ['mw'],
    "vammī": ['cped'],
    "vamra": ['cae', 'ddsa', 'gra', 'mw'],
    "vamraka": ['cae', 'gra', 'mw'],
    "vamraḥ": ['ap90'],
    "vamrī": ['gra'],
    "vamrīkūṭa": ['mw'],
    "vamuka": ['mw'],
    "vamya": ['mw'],
    "vamyāśānti": ['mw'],
    "vamī": ['ap90', 'cae'],
    "van": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vana": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vanabarbara": ['mw'],
    "vanabarbarikā": ['mw'],
    "vanabarhiṇa": ['mw'],
    "vanabarhiṇatva": ['mw'],
    "vanabhadrikā": ['mw'],
    "vanabhojanaprayoga": ['mw'],
    "vanabhojanapuṇyāhavācanaprayoga": ['mw'],
    "vanabhojanavidhi": ['mw'],
    "vanabhuj": ['mw'],
    "vanabhū": ['cae', 'mw'],
    "vanabhūmi": ['cae', 'mw'],
    "vanabhūṣaṇī": ['mw'],
    "vanabiḍāla": ['mw'],
    "vanabāhyaka": ['mw'],
    "vanabīja": ['mw'],
    "vanabījapūraka": ['mw'],
    "vanacampaka": ['mw'],
    "vanacandana": ['mw'],
    "vanacandrikā": ['mw'],
    "vanacara": ['cae', 'cped', 'mw'],
    "vanacaraka": ['cped'],
    "vanacaravṛtti": ['cae'],
    "vanacarya": ['cae', 'mw'],
    "vanacaryā": ['mw'],
    "vanacchandatā": ['mw'],
    "vanaccheda": ['mw'],
    "vanacchid": ['mw'],
    "vanacchāga": ['mw'],
    "vanacetya": ['cped'],
    "vanacārin": ['cae', 'mw'],
    "vanacārī": ['cped'],
    "vanad": ['gra', 'mw'],
    "vanada": ['bhs', 'mw'],
    "vanadamana": ['mw'],
    "vanadevatā": ['cae', 'cped', 'mw'],
    "vanadhenu": ['mw'],
    "vanadhiti": ['gra', 'mw'],
    "vanadhānya": ['mw'],
    "vanadhārā": ['cae', 'mw'],
    "vanadruma": ['mw'],
    "vanadurga": ['mw'],
    "vanadurgopaniṣad": ['mw'],
    "vanadurgā": ['mw'],
    "vanadurgākalpa": ['mw'],
    "vanadurgāmantra": ['mw'],
    "vanadurgāprayoga": ['mw'],
    "vanadurgātattva": ['mw'],
    "vanadvipa": ['cae', 'mw'],
    "vanadāha": ['cae', 'mw'],
    "vanadāhāgni": ['mw'],
    "vanadāraka": ['mw'],
    "vanadīpa": ['mw'],
    "vanadīyabhaṭṭa": ['mw'],
    "vanaga": ['mw'],
    "vanagahana": ['cae', 'cped', 'mw'],
    "vanagaja": ['cae', 'mw'],
    "vanagajamada": ['mw'],
    "vanagamana": ['cae', 'mw'],
    "vanagava": ['mw'],
    "vanagholī": ['mw'],
    "vanago": ['mw'],
    "vanagocara": ['cae', 'mw'],
    "vanagrahaṇa": ['cae', 'mw'],
    "vanagrahaṇakolāhala": ['mw'],
    "vanagrāhin": ['cae', 'mw'],
    "vanagrāmaka": ['mw'],
    "vanagulma": ['cae', 'mw'],
    "vanagumba": ['cped'],
    "vanagupta": ['mw'],
    "vanahabandi": ['mw'],
    "vanahari": ['ddsa', 'mw'],
    "vanaharidrā": ['mw'],
    "vanahava": ['mw'],
    "vanahoma": ['mw'],
    "vanahutāśana": ['mw'],
    "vanahāsa": ['mw'],
    "vanaikadeśa": ['cae', 'ddsa', 'mw'],
    "vanaja": ['cae', 'mw'],
    "vanajapattrākṣa": ['mw'],
    "vanajyotsnī": ['cae', 'mw'],
    "vanajā": ['mw'],
    "vanajākṣa": ['mw'],
    "vanajāta": ['cae', 'mw'],
    "vanajāyata": ['mw'],
    "vanajīra": ['mw'],
    "vanajīvikā": ['mw'],
    "vanajīvin": ['mw'],
    "vanakacu": ['mw'],
    "vanakadalī": ['mw'],
    "vanakammika": ['cped'],
    "vanakanda": ['mw'],
    "vanakapi": ['cae', 'ddsa', 'mw'],
    "vanakapīvat": ['mw'],
    "vanakarin": ['cae', 'mw'],
    "vanakauśāmbī": ['mw'],
    "vanakaṇā": ['mw'],
    "vanakaṇḍūla": ['mw'],
    "vanakhaṇḍa": ['mw'],
    "vanakodrava": ['mw'],
    "vanakokilaka": ['mw'],
    "vanakoli": ['mw'],
    "vanakrakṣa": ['gra', 'mw'],
    "vanakukkuṭa": ['mw'],
    "vanakusuma": ['mw'],
    "vanakuñjara": ['mw'],
    "vanakāma": ['mw'],
    "vanakārpasi": ['mw'],
    "vanakārpasī": ['mw'],
    "vanakāṣṭhikā": ['mw'],
    "vanalakṣmī": ['mw'],
    "vanalatā": ['cae', 'ddsa', 'mw'],
    "vanalekhā": ['mw'],
    "vanamakṣikā": ['mw'],
    "vanamallikā": ['mw'],
    "vanamallī": ['mw'],
    "vanamethikā": ['mw'],
    "vanamocā": ['mw'],
    "vanamuc": ['mw'],
    "vanamudga": ['mw'],
    "vanamāla": ['mw'],
    "vanamālidāsa": ['mw'],
    "vanamālikā": ['mw'],
    "vanamālikīrtichandomālā": ['mw'],
    "vanamālimiśra": ['mw'],
    "vanamālin": ['mw'],
    "vanamālinī": ['mw'],
    "vanamālā": ['cae', 'mw'],
    "vanamālādhara": ['mw'],
    "vanamālāmiśra": ['mw'],
    "vanamālāmiśrīya": ['mw'],
    "vanamālāstotra": ['mw'],
    "vanamālāvijaya": ['mw'],
    "vanamālīśā": ['mw'],
    "vanamānuṣa": ['mw'],
    "vanamānuṣikā": ['mw'],
    "vanamānuṣī": ['mw'],
    "vanamātaṃga": ['mw'],
    "vanamāya": ['mw'],
    "vanamūla": ['mw'],
    "vanamūlaphala": ['mw'],
    "vanamūrdhajā": ['mw'],
    "vanamūta": ['mw'],
    "vanamṛga": ['cae', 'mw'],
    "vanana": ['mw'],
    "vananaṃ": ['ap90'],
    "vananitya": ['mw'],
    "vananva": ['mw'],
    "vananvat": ['ddsa', 'gra'],
    "vananā": ['cae', 'ddsa', 'gra', 'mw'],
    "vananīya": ['cae', 'ddsa', 'mw'],
    "vanapa": ['cae', 'mw'],
    "vanapallava": ['mw'],
    "vanapannaga": ['ddsa', 'mw'],
    "vanaparvan": ['mw'],
    "vanapattha": ['cped'],
    "vanaphala": ['mw'],
    "vanapippalī": ['mw'],
    "vanappati": ['cped'],
    "vanaprakṣa": ['mw'],
    "vanaprastha": ['mw'],
    "vanapratiṣṭha": ['mw'],
    "vanapraveśa": ['mw'],
    "vanapriya": ['mw'],
    "vanapuṣpa": ['mw'],
    "vanapuṣpamaya": ['mw'],
    "vanapuṣpā": ['mw'],
    "vanapādapa": ['mw'],
    "vanapāla": ['cae', 'mw'],
    "vanapālaka": ['cae', 'mw'],
    "vanapālādhipa": ['mw'],
    "vanapārśva": ['mw'],
    "vanapāṃsula": ['mw'],
    "vanapūraka": ['mw'],
    "vanapūrva": ['mw'],
    "vanar": ['gra', 'mw'],
    "vanara": ['mw'],
    "vanarakṣaka": ['mw'],
    "vanarakṣakā": ['mw'],
    "vanarddhi": ['mw'],
    "vanargu": ['cae', 'ddsa', 'gra', 'mw'],
    "vanarja": ['mw'],
    "vanarsad": ['gra'],
    "vanarāja": ['mw'],
    "vanarāji": ['cae', 'mw'],
    "vanarājya": ['mw'],
    "vanarājī": ['cae', 'mw'],
    "vanarāṣṭaka": ['mw'],
    "vanarāṣṭra": ['mw'],
    "vanarāṣṭraka": ['mw'],
    "vanarṣad": ['gra', 'mw'],
    "vanas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vanasa": ['mw'],
    "vanasad": ['ddsa', 'mw'],
    "vanasampraveśa": ['mw'],
    "vanasamūha": ['mw'],
    "vanasarojinī": ['mw'],
    "vanasaṃkaṭa": ['mw'],
    "vanasaṃnivāsin": ['mw'],
    "vanasaṃśraya": ['mw'],
    "vanasaṇḍa": ['cped'],
    "vanasindhura": ['mw'],
    "vanaspati": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vanaspatikāya": ['mw'],
    "vanaspatisava": ['mw'],
    "vanaspatiyāga": ['mw'],
    "vanaspatiḥ": ['ap90'],
    "vanasraj": ['mw'],
    "vanastamba": ['mw'],
    "vanastha": ['cae', 'mw'],
    "vanasthalī": ['cae', 'mw'],
    "vanasthita": ['mw'],
    "vanasthā": ['mw'],
    "vanasthāna": ['mw'],
    "vanasthāyin": ['mw'],
    "vanasyu": ['gra', 'mw'],
    "vanasyā": ['mw'],
    "vanasāhvayā": ['mw'],
    "vanataraṃgiṇī": ['mw'],
    "vanatha": ['bhs', 'cped'],
    "vanatikta": ['mw'],
    "vanatiktikā": ['mw'],
    "vanatiktā": ['mw'],
    "vanatā": ['bhs'],
    "vanaugha": ['mw'],
    "vanauka": ['mw'],
    "vanaukas": ['cae', 'ddsa', 'mw'],
    "vanauṣadhi": ['cae', 'mw'],
    "vanavahni": ['mw'],
    "vanavallarī": ['mw'],
    "vanavarbara": ['mw'],
    "vanavarbarikā": ['mw'],
    "vanavarhiṇa": ['mw'],
    "vanavartikā": ['mw'],
    "vanavartin": ['mw'],
    "vanavarāha": ['mw'],
    "vanavilāsinī": ['mw'],
    "vanavirodhin": ['mw'],
    "vanaviḍāla": ['mw'],
    "vanavrīhi": ['mw'],
    "vanavāhyaka": ['mw'],
    "vanavāsa": ['cae', 'mw'],
    "vanavāsaka": ['mw'],
    "vanavāsana": ['mw'],
    "vanavāsin": ['bhs', 'cae', 'mw'],
    "vanavāsya": ['mw'],
    "vanavāsī": ['cped', 'mw'],
    "vanavāta": ['mw'],
    "vanavīja": ['mw'],
    "vanavṛntākī": ['mw'],
    "vanavṛtti": ['mw'],
    "vanayamānī": ['mw'],
    "vanayitṛ": ['mw'],
    "vanaśakuni": ['mw'],
    "vanaśikhaṇḍin": ['mw'],
    "vanaśobhana": ['mw'],
    "vanaśvan": ['cae', 'mw'],
    "vanaśūkarī": ['mw'],
    "vanaśūraṇa": ['mw'],
    "vanaśṛṅgāṭa": ['mw'],
    "vanaśṛṅgāṭaka": ['mw'],
    "vanaṃ": ['ap90'],
    "vanaṃkaraṇa": ['gra', 'mw'],
    "vanaṛkṣa": ['mw'],
    "vanaṣad": ['mw'],
    "vanaṣaṇḍa": ['mw'],
    "vand": ['cae', 'ddsa', 'gra', 'mw'],
    "vanda": ['cae', 'gra', 'mw'],
    "vandadhyai": ['cae', 'mw'],
    "vandadvāra": ['mw'],
    "vandadvīra": ['mw'],
    "vandaka": ['bhs', 'cped', 'mw'],
    "vandamāna": ['cped'],
    "vandana": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vandanaka": ['mw'],
    "vandanamālikā": ['mw'],
    "vandanamālā": ['ddsa', 'mw'],
    "vandanaśrut": ['gra', 'mw'],
    "vandanesthā": ['mw'],
    "vandaneṣṭhā": ['gra'],
    "vandanta": ['cped'],
    "vandanā": ['cped', 'mw'],
    "vandanī": ['mw'],
    "vandanīya": ['cae', 'ddsa', 'mw'],
    "vandanīyā": ['mw'],
    "vandatha": ['mw'],
    "vandati": ['cped'],
    "vandhula": ['mw'],
    "vandhur": ['gra', 'mw'],
    "vandhura": ['cae', 'ddsa', 'gra', 'mw'],
    "vandhureṣṭhā": ['gra', 'mw'],
    "vandhurāyu": ['gra', 'mw'],
    "vandhya": ['cae', 'ddsa', 'mw'],
    "vandhyaparvata": ['mw'],
    "vandhyaphala": ['mw'],
    "vandhyaphalatā": ['mw'],
    "vandhyatva": ['mw'],
    "vandhyatā": ['mw'],
    "vandhyā": ['ddsa', 'mw'],
    "vandhyāduhitṛ": ['mw'],
    "vandhyāgarbhadhāraṇavidhi": ['mw'],
    "vandhyākarkaṭakī": ['mw'],
    "vandhyāprakāśa": ['mw'],
    "vandhyāprāyaścittividhi": ['mw'],
    "vandhyāputra": ['mw'],
    "vandhyāroga": ['mw'],
    "vandhyāsuta": ['mw'],
    "vandhyāsūnu": ['mw'],
    "vandhyātanaya": ['mw'],
    "vandhyātva": ['mw'],
    "vandhyātvakārakopadravaharavidhi": ['mw'],
    "vandhyāvalī": ['mw'],
    "vandhyāya": ['mw'],
    "vandhā": ['mw'],
    "vandi": ['cped', 'mw'],
    "vandin": ['cae', 'mw'],
    "vandinīkā": ['mw'],
    "vandinīyā": ['mw'],
    "vandita": ['cped', 'mw'],
    "vanditabba": ['cped'],
    "vanditavya": ['cae', 'mw'],
    "vanditvā": ['cped'],
    "vanditṛ": ['cae', 'gra', 'mw'],
    "vandiya": ['cped'],
    "vandra": ['mw'],
    "vanduśiras": ['bhs'],
    "vandya": ['cae', 'mw'],
    "vandyabhaṭṭīya": ['mw'],
    "vandyaghaṭīyā": ['mw'],
    "vandyatā": ['mw'],
    "vandyā": ['mw'],
    "vandā": ['bhs', 'mw'],
    "vandāka": ['mw'],
    "vandākā": ['mw'],
    "vandākī": ['mw'],
    "vandāpana": ['cped'],
    "vandāpesi": ['cped'],
    "vandāpeti": ['cped'],
    "vandāpetvā": ['cped'],
    "vandāpita": ['cped'],
    "vandāra": ['mw'],
    "vandāru": ['cae', 'gra', 'mw'],
    "vandī": ['mw'],
    "vandīka": ['mw'],
    "vane": ['mw'],
    "vanebilvaka": ['mw'],
    "vanecara": ['ap90', 'cae', 'ddsa', 'mw'],
    "vanecarāgrya": ['mw'],
    "vanejya": ['mw'],
    "vanejā": ['cae', 'gra', 'mw'],
    "vanekiṃśuka": ['mw'],
    "vanekiṃśukāḥ": ['ap90'],
    "vanekṣudrā": ['mw'],
    "vanerāj": ['gra', 'mw'],
    "vanesad": ['mw'],
    "vanesarja": ['mw'],
    "vanevāsin": ['mw'],
    "vaneyu": ['mw'],
    "vaneśaya": ['mw'],
    "vaneṣah": ['gra', 'mw'],
    "vanhi": ['ddsa'],
    "vani": ['cae', 'gra', 'mw'],
    "vanika": ['cped'],
    "vanikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "vanikāvāsa": ['mw'],
    "vanila": ['mw'],
    "vanin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vanina": ['cae', 'gra', 'mw'],
    "vanita": ['ap90', 'mw'],
    "vanitā": ['ap90', 'cae', 'ddsa', 'mw'],
    "vanitābhoginī": ['mw'],
    "vanitādviṣ": ['mw'],
    "vanitāmukha": ['mw'],
    "vanitārājya": ['mw'],
    "vanitāsa": ['mw'],
    "vanitāsakha": ['mw'],
    "vanitāvilāsa": ['mw'],
    "vanitāya": ['mw'],
    "vanitṛ": ['cae', 'mw'],
    "vaniḥ": ['ap90'],
    "vaniṣṇu": ['ap90', 'mw'],
    "vaniṣṭha": ['cae', 'gra', 'mw'],
    "vaniṣṭhu": ['cae', 'ddsa', 'gra', 'mw'],
    "vaniṣṭhusava": ['mw'],
    "vaniṣṭhuḥ": ['ap90'],
    "vannaḥ": ['ap90'],
    "vannā": ['mw'],
    "vanodbhava": ['cae', 'mw'],
    "vanodbhavā": ['mw'],
    "vanoddeśa": ['cae', 'ddsa', 'mw'],
    "vanopala": ['mw'],
    "vanopaplava": ['cae', 'mw'],
    "vanopeta": ['cae', 'mw'],
    "vanorvī": ['mw'],
    "vanotsarga": ['mw'],
    "vanotsāha": ['mw'],
    "vanra": ['mw'],
    "vanta": ['cped'],
    "vantakasāva": ['cped'],
    "vantamala": ['cped'],
    "vantava": ['mw'],
    "vanti": ['mw'],
    "vantṛ": ['cae', 'gra', 'mw'],
    "vanu": ['cae', 'ddsa', 'gra', 'mw'],
    "vanus": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vanuḥ": ['ap90'],
    "vanuṣ": ['cae'],
    "vanuṣa": ['mw'],
    "vanuṣy": ['gra'],
    "vanuṣya": ['ddsa', 'mw'],
    "vanya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vanyadamana": ['mw'],
    "vanyadvipa": ['mw'],
    "vanyanāga": ['cae'],
    "vanyapakṣin": ['mw'],
    "vanyavṛtti": ['cae', 'mw'],
    "vanyebha": ['cae', 'mw'],
    "vanyetara": ['cae', 'ddsa', 'mw'],
    "vanyopodakī": ['mw'],
    "vanyā": ['ap90', 'mw'],
    "vanyānnabhojana": ['mw'],
    "vanyāśana": ['cae', 'mw'],
    "vanyāśrama": ['mw'],
    "vanā": ['ddsa', 'gra', 'mw'],
    "vanābhilāva": ['mw'],
    "vanābjinī": ['mw'],
    "vanācārya": ['mw'],
    "vanādhivāsin": ['mw'],
    "vanāgni": ['ddsa', 'mw'],
    "vanāhira": ['mw'],
    "vanāhiraḥ": ['ap90'],
    "vanāja": ['mw'],
    "vanākampa": ['mw'],
    "vanākhu": ['mw'],
    "vanākhuka": ['mw'],
    "vanālakta": ['mw'],
    "vanālaktaka": ['mw'],
    "vanālaya": ['cae', 'mw'],
    "vanālayajīvin": ['mw'],
    "vanālikā": ['mw'],
    "vanālu": ['mw'],
    "vanālā": ['bhs'],
    "vanālī": ['ddsa', 'mw'],
    "vanāmala": ['mw'],
    "vanāmbikā": ['mw'],
    "vanāmra": ['mw'],
    "vanānta": ['cae', 'mw'],
    "vanāntabhū": ['mw'],
    "vanāntara": ['cae', 'mw'],
    "vanāntaracara": ['mw'],
    "vanāntaracārin": ['mw'],
    "vanāntastha": ['mw'],
    "vanāntasthalī": ['mw'],
    "vanāntavāsin": ['mw'],
    "vanānī": ['bhs'],
    "vanāpaga": ['mw'],
    "vanārcaka": ['mw'],
    "vanārdraka": ['mw'],
    "vanārdrakā": ['mw'],
    "vanāriṣṭā": ['mw'],
    "vanāstika": ['bhs'],
    "vanāyu": ['cae', 'ddsa', 'mw'],
    "vanāyudeśya": ['mw'],
    "vanāyuja": ['mw'],
    "vanāyuḥ": ['ap90'],
    "vanāśa": ['mw'],
    "vanāśrama": ['mw'],
    "vanāśramanivāsin": ['mw'],
    "vanāśramin": ['mw'],
    "vanāśraya": ['cae', 'mw'],
    "vanāṭana": ['mw'],
    "vanāṭu": ['mw'],
    "vanī": ['ap90', 'ddsa', 'mw'],
    "vanīka": ['mw'],
    "vanīkaḥ": ['ap90'],
    "vanīpaka": ['bhs', 'mw'],
    "vanīpakaḥ": ['ap90'],
    "vanīvan": ['cae', 'gra', 'mw'],
    "vanīvāhana": ['cae', 'mw'],
    "vanīvāhita": ['mw'],
    "vanīya": ['mw'],
    "vanīyaka": ['cae', 'ddsa', 'mw'],
    "vanīyakajana": ['mw'],
    "vanīyas": ['ddsa', 'gra', 'mw'],
    "vanīyati": ['ap90'],
    "vap": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vapa": ['cae', 'mw'],
    "vapana": ['cae', 'cped', 'ddsa', 'mw'],
    "vapananirṇaya": ['mw'],
    "vapanaprayoga": ['mw'],
    "vapanavidhi": ['mw'],
    "vapanaṃ": ['ap90'],
    "vapanta": ['cped'],
    "vapanī": ['mw'],
    "vapanīya": ['cae', 'mw'],
    "vapati": ['cped'],
    "vapatra": ['mw'],
    "vapaḥ": ['ap90'],
    "vapi": ['cped'],
    "vapila": ['mw'],
    "vapilaḥ": ['ap90'],
    "vapita": ['cped'],
    "vapitvā": ['cped'],
    "vapodara": ['cae', 'gra', 'mw'],
    "vapoddharaṇa": ['ddsa', 'mw'],
    "vappa": ['cped', 'mw'],
    "vappakāla": ['cped'],
    "vappamaṅgala": ['cped'],
    "vappaṭadevī": ['ddsa', 'mw'],
    "vappiya": ['ddsa', 'mw'],
    "vappiyaka": ['mw'],
    "vappīha": ['mw'],
    "vapra": ['cae', 'ddsa', 'mw'],
    "vapraka": ['mw'],
    "vaprakaḥ": ['ap90'],
    "vaprakriyā": ['cae', 'mw'],
    "vaprakrīḍā": ['cae', 'mw'],
    "vaprakṣetraphala": ['mw'],
    "vapraphala": ['mw'],
    "vapraḥ": ['ap90'],
    "vapri": ['mw'],
    "vapriḥ": ['ap90'],
    "vaprā": ['mw'],
    "vaprābhighāta": ['mw'],
    "vaprāmbhas": ['mw'],
    "vaprāmbhaḥsruti": ['mw'],
    "vaprānata": ['mw'],
    "vaprāntar": ['mw'],
    "vaprāvanī": ['mw'],
    "vaprāvat": ['mw'],
    "vaprī": ['ap90', 'mw'],
    "vaprīvan": ['mw'],
    "vapsas": ['cae', 'ddsa', 'gra', 'mw'],
    "vaptar": ['cae'],
    "vaptavya": ['cae', 'ddsa', 'mw'],
    "vaptṛ": ['ap90', 'cae', 'gra', 'mw'],
    "vaptṛka": ['mw'],
    "vapu": ['cped', 'mw'],
    "vapuna": ['mw'],
    "vapunandana": ['mw'],
    "vapunaḥ": ['ap90'],
    "vapur": ['mw'],
    "vapurdhara": ['ddsa', 'mw'],
    "vapurguṇa": ['mw'],
    "vapurmalasamācita": ['mw'],
    "vapus": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vapussāt": ['mw'],
    "vapuḥ": ['ap90', 'mw'],
    "vapuḥprakarṣa": ['ddsa', 'mw'],
    "vapuḥsrava": ['mw'],
    "vapuṣ": ['mw'],
    "vapuṣa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vapuṣe": ['mw'],
    "vapuṣia": ['gra'],
    "vapuṣmant": ['bhs', 'cae'],
    "vapuṣmat": ['ap90', 'ddsa', 'mw'],
    "vapuṣmata": ['mw'],
    "vapuṣmattā": ['mw'],
    "vapuṣmatī": ['mw'],
    "vapuṣy": ['cae', 'gra'],
    "vapuṣya": ['cae', 'gra', 'mw'],
    "vapuṣyā": ['cae', 'gra', 'mw'],
    "vapuṣā": ['mw'],
    "vapuṣī": ['mw'],
    "vapuṣṭama": ['cae', 'mw'],
    "vapuṣṭamā": ['mw'],
    "vapuṣṭara": ['cae', 'mw'],
    "vapyanīla": ['mw'],
    "vapyaṭadevī": ['mw'],
    "vapā": ['ap90', 'cae', 'gra', 'mw'],
    "vapādhiśrayaṇī": ['mw'],
    "vapāhoma": ['mw'],
    "vapāhuti": ['mw'],
    "vapāka": ['mw'],
    "vapākṛt": ['mw'],
    "vapāmārjana": ['mw'],
    "vapānta": ['mw'],
    "vapāvat": ['gra', 'mw'],
    "vapāśrapaṇī": ['mw'],
    "vapāśravaṇī": ['mw'],
    "vapāṭikā": ['mw'],
    "var": ['ap90'],
    "vara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vara-puññalakkhaṇa": ['cped'],
    "varabāhu": ['bhs'],
    "varabālhīka": ['mw'],
    "varacandana": ['mw'],
    "varacandrikā": ['mw'],
    "varada": ['cae', 'cped', 'ddsa', 'mw'],
    "varadabhaṭṭa": ['mw'],
    "varadacaturthī": ['mw'],
    "varadagaṇapatistotra": ['mw'],
    "varadagaṇeśastotra": ['mw'],
    "varadahasta": ['mw'],
    "varadakṣiṇā": ['mw'],
    "varadamūrti": ['mw'],
    "varadanātha": ['mw'],
    "varadanāthācāryasūnu": ['mw'],
    "varadanāyakasūri": ['mw'],
    "varadarāja": ['mw'],
    "varadarājacampū": ['mw'],
    "varadarājadaṇḍaka": ['mw'],
    "varadarājamahiṣīstotra": ['mw'],
    "varadarājamaṅgala": ['mw'],
    "varadarājamūla": ['mw'],
    "varadarājapañcāśat": ['mw'],
    "varadarājastava": ['mw'],
    "varadarājastotra": ['mw'],
    "varadarājasuprabhāta": ['mw'],
    "varadarājaśataka": ['mw'],
    "varadarājāṣṭaka": ['mw'],
    "varadarājāṣṭottaraśata": ['mw'],
    "varadarājīya": ['mw'],
    "varadarśinī": ['mw'],
    "varadatta": ['mw'],
    "varadaviṣṇusūri": ['mw'],
    "varadhara": ['bhs'],
    "varadharma": ['mw'],
    "varadharmamudrā": ['bhs'],
    "varadharmin": ['mw'],
    "varadharmīkṛ": ['mw'],
    "varadopaniṣaddīpikā": ['mw'],
    "varadruma": ['mw'],
    "varadā": ['mw'],
    "varadācaturthī": ['mw'],
    "varadādhīśayajvan": ['mw'],
    "varadāna": ['cae', 'cped', 'mw'],
    "varadānamaya": ['mw'],
    "varadānika": ['mw'],
    "varadārka": ['mw'],
    "varadāru": ['mw'],
    "varadāruka": ['mw'],
    "varadātantra": ['mw'],
    "varadātu": ['mw'],
    "varadātṛ": ['mw'],
    "varadāyaka": ['mw'],
    "varadāśvas": ['mw'],
    "varaga": ['mw'],
    "varagagaṇā": ['bhs'],
    "varaghaṇṭa": ['mw'],
    "varaghaṇṭikā": ['mw'],
    "varaghaṇṭī": ['mw'],
    "varagātra": ['cae', 'mw'],
    "varahaka": ['mw'],
    "varaja": ['mw'],
    "varajānuka": ['mw'],
    "varaka": ['cae', 'cped', 'ddsa', 'mw'],
    "varakalyāṇa": ['bhs', 'mw'],
    "varakaḥ": ['ap90'],
    "varakratu": ['mw'],
    "varakāṣṭhakā": ['mw'],
    "varakīrti": ['mw'],
    "varala": ['mw'],
    "varalabdha": ['mw'],
    "varalakkhaṇa": ['cped'],
    "varalakṣaṇaśrī": ['bhs'],
    "varalakṣaṇaḥśiri": ['bhs'],
    "varalakṣmīkathā": ['mw'],
    "varalakṣmīmāhātmya": ['mw'],
    "varalakṣmīpūjā": ['mw'],
    "varalakṣmīvrata": ['mw'],
    "varalakṣmīvratakalpa": ['mw'],
    "varalakṣmīvratakathā": ['mw'],
    "varalaḥ": ['ap90'],
    "varalā": ['mw'],
    "varalī": ['mw'],
    "varam": ['ap90', 'ddsa', 'mw'],
    "varamakuṭa": ['bhs'],
    "varambarā": ['mw'],
    "varamukhī": ['mw'],
    "varanimantraṇa": ['mw'],
    "varaniścaya": ['mw'],
    "varanārī": ['mw'],
    "varapakṣa": ['mw'],
    "varapakṣiṇī": ['mw'],
    "varapakṣīya": ['mw'],
    "varaparṇākhya": ['mw'],
    "varapañña": ['cped'],
    "varapaṇḍita": ['mw'],
    "varaphala": ['mw'],
    "varapota": ['mw'],
    "varaprabha": ['bhs', 'mw'],
    "varaprada": ['cae', 'mw'],
    "varapradastava": ['mw'],
    "varapradā": ['mw'],
    "varapradāna": ['mw'],
    "varaprasthāna": ['mw'],
    "varaprārthanā": ['cae', 'mw'],
    "varapuruṣa": ['cae', 'mw'],
    "varapāṇḍya": ['mw'],
    "varapītaka": ['mw'],
    "vararuci": ['cae', 'mw'],
    "vararucikośa": ['mw'],
    "vararucikārikā": ['mw'],
    "vararuciliṅgakārikā": ['mw'],
    "vararuciprākṛtasūtra": ['mw'],
    "vararucivākya": ['mw'],
    "vararūpa": ['bhs', 'mw'],
    "varas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "varasad": ['cae', 'gra', 'mw'],
    "varasampad": ['mw'],
    "varasraj": ['mw'],
    "varastrī": ['cae', 'mw'],
    "varasundarī": ['ddsa', 'mw'],
    "varasurata": ['mw'],
    "varasyā": ['ap90', 'cae', 'gra', 'mw'],
    "varasāna": ['mw'],
    "varasāvitrīcaritra": ['mw'],
    "varatama": ['mw'],
    "varatantu": ['mw'],
    "varatanu": ['cae', 'ddsa', 'mw'],
    "varatanū": ['mw'],
    "varatara": ['cped', 'mw'],
    "varatikta": ['mw'],
    "varatiktaka": ['mw'],
    "varatiktikā": ['mw'],
    "varatkarī": ['mw'],
    "varatoyā": ['mw'],
    "varatraka": ['bhs'],
    "varatrā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "varatrākāṇḍa": ['mw'],
    "varattā": ['cped'],
    "varatvac": ['mw'],
    "varatvaca": ['mw'],
    "varatā": ['mw'],
    "varavaramuni": ['mw'],
    "varavaramuniśataka": ['mw'],
    "varavaraṇa": ['mw'],
    "varavarṇa": ['mw'],
    "varavarṇin": ['cae', 'mw'],
    "varavarṇiṇī": ['mw'],
    "varavastra": ['cae', 'mw'],
    "varavatsalā": ['mw'],
    "varavāhlīka": ['mw'],
    "varavāraṇa": ['mw'],
    "varavāsi": ['mw'],
    "varavṛddha": ['mw'],
    "varavṛta": ['cae', 'mw'],
    "varaya": ['ddsa'],
    "varayitavya": ['cae', 'mw'],
    "varayitavyatva": ['mw'],
    "varayitṛ": ['ap90', 'mw'],
    "varayogya": ['mw'],
    "varayonika": ['mw'],
    "varayoṣit": ['cae', 'mw'],
    "varayu": ['mw'],
    "varayuvati": ['ddsa', 'mw'],
    "varayuvatī": ['mw'],
    "varayātrā": ['mw'],
    "varaśikha": ['gra', 'mw'],
    "varaśreṇī": ['mw'],
    "varaśāpa": ['mw'],
    "varaśīta": ['mw'],
    "varaṁ": ['cped'],
    "varaṃḍaka": ['ap90'],
    "varaṃḍaḥ": ['ap90'],
    "varaṃḍā": ['ap90'],
    "varaṃḍāluḥ": ['ap90'],
    "varaṅganā": ['cped'],
    "varaṇa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "varaṇaka": ['mw'],
    "varaṇamālā": ['mw'],
    "varaṇasī": ['ap90', 'mw'],
    "varaṇaśraj": ['mw'],
    "varaṇaṃ": ['ap90'],
    "varaṇya": ['mw'],
    "varaṇā": ['mw'],
    "varaṇāvatī": ['mw'],
    "varaṇāśī": ['mw'],
    "varaṇīya": ['ddsa', 'mw'],
    "varaṇḍa": ['cae', 'mw'],
    "varaṇḍaka": ['ddsa', 'mw'],
    "varaṇḍalambuka": ['cae', 'mw'],
    "varaṇḍikā": ['bhs'],
    "varaṇḍā": ['mw'],
    "varaṇḍālu": ['mw'],
    "varaṇṭa": ['mw'],
    "varaṭa": ['bhs', 'cae', 'mw'],
    "varaṭaka": ['bhs', 'mw'],
    "varaṭaḥ": ['ap90'],
    "varaṭā": ['ddsa', 'mw'],
    "varaṭī": ['mw'],
    "varaṭṭikā": ['mw'],
    "varc": ['ap90', 'gra', 'mw'],
    "varca": ['mw'],
    "varcadhāna": ['bhs'],
    "varcaghaṭa": ['bhs'],
    "varcala": ['mw'],
    "varcas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "varcasa": ['cae', 'ddsa', 'mw'],
    "varcasin": ['mw'],
    "varcask": ['bhs'],
    "varcaska": ['mw'],
    "varcaskasthāna": ['mw'],
    "varcaskaḥ": ['ap90'],
    "varcasvant": ['cae'],
    "varcasvat": ['mw'],
    "varcasvin": ['ap90', 'cae', 'mw'],
    "varcasya": ['cae', 'mw'],
    "varcasyā": ['mw'],
    "varcaḥkumbhikā": ['bhs'],
    "varcaḥkuṭī": ['bhs'],
    "varcaḥsthāna": ['mw'],
    "varcaṭī": ['ap90', 'mw'],
    "varcin": ['cae', 'ddsa', 'gra', 'mw'],
    "varcita": ['mw'],
    "varco": ['mw'],
    "varcobheda": ['mw'],
    "varcobhedin": ['mw'],
    "varcodhas": ['mw'],
    "varcodhā": ['mw'],
    "varcodā": ['mw'],
    "varcograha": ['mw'],
    "varcomārga": ['bhs', 'mw'],
    "varcovinigraha": ['mw'],
    "varcāhāra": ['bhs'],
    "varcāvasu": ['mw'],
    "varcāya": ['mw'],
    "vardala": ['bhs'],
    "vardalikā": ['bhs'],
    "vardh": ['ap90', 'mw'],
    "vardha": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vardhaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "vardhaki": ['cae', 'mw'],
    "vardhakihasta": ['mw'],
    "vardhakin": ['cae'],
    "vardhakiḥ": ['ap90'],
    "vardhamāla": ['mw'],
    "vardhamāna": ['ap90', 'ddsa', 'mw'],
    "vardhamānadvāra": ['mw'],
    "vardhamānaka": ['bhs', 'mw'],
    "vardhamānakaḥ": ['ap90'],
    "vardhamānamati": ['bhs', 'mw'],
    "vardhamānamiśra": ['mw'],
    "vardhamānaprakriyā": ['mw'],
    "vardhamānaprayoga": ['mw'],
    "vardhamānapura": ['mw'],
    "vardhamānapuradvāra": ['mw'],
    "vardhamānapurīya": ['mw'],
    "vardhamānapūraṇa": ['mw'],
    "vardhamānasvāmin": ['mw'],
    "vardhamānendu": ['mw'],
    "vardhamāneśa": ['ddsa', 'mw'],
    "vardhamānā": ['mw'],
    "vardhamānī": ['mw'],
    "vardhana": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vardhanaka": ['mw'],
    "vardhanasvāmin": ['mw'],
    "vardhanasūri": ['mw'],
    "vardhanaśīla": ['mw'],
    "vardhanikā": ['ap90', 'bhs', 'mw'],
    "vardhanī": ['mw'],
    "vardhanīya": ['bhs', 'cae', 'ddsa', 'mw'],
    "vardhanīyatva": ['mw'],
    "vardhanīyatā": ['mw'],
    "vardhaphala": ['mw'],
    "vardhaya": ['ddsa'],
    "vardhayati": ['bhs'],
    "vardhayitṛ": ['mw'],
    "vardhaḥ": ['ap90'],
    "vardhika": ['bhs'],
    "vardhin": ['mw'],
    "vardhinī": ['cae'],
    "vardhipathaka": ['mw'],
    "vardhita": ['ap90', 'cae', 'ddsa', 'mw'],
    "vardhitavya": ['cae', 'mw'],
    "vardhitṛ": ['cae', 'gra'],
    "vardhiṣṇu": ['ap90', 'cae', 'mw'],
    "vardhma": ['mw'],
    "vardhman": ['mw'],
    "vardhmaroga": ['mw'],
    "vardhmavṛddhyadhikāra": ['mw'],
    "vardhra": ['cae', 'ddsa', 'mw'],
    "vardhrakaṭhina": ['mw'],
    "vardhravyuta": ['mw'],
    "vardhraṃ": ['ap90'],
    "vardhrikā": ['ap90', 'mw'],
    "vardhrī": ['mw'],
    "vardhāpaka": ['mw'],
    "vardhāpana": ['cae', 'ddsa', 'mw'],
    "vardhāpanaka": ['mw'],
    "vardhāpanaprayoga": ['mw'],
    "vardhāpanaṃ": ['ap90'],
    "vardhāpanika": ['mw'],
    "vardhāpaya": ['ddsa'],
    "vardhāpayati": ['bhs'],
    "vardhāpikā": ['mw'],
    "vardhāya": ['mw'],
    "vardhībhavati": ['bhs'],
    "vareja": ['mw'],
    "varendra": ['mw'],
    "varendragati": ['mw'],
    "varendraketu": ['bhs'],
    "varendrī": ['mw'],
    "varey": ['cae', 'gra'],
    "vareya": ['mw'],
    "vareyu": ['cae', 'gra', 'mw'],
    "vareyyaṁ": ['cped'],
    "vareśa": ['cae', 'mw'],
    "vareśvara": ['cae', 'mw'],
    "vareṇ": ['mw'],
    "vareṇa": ['mw'],
    "vareṇia": ['gra'],
    "vareṇiakratu": ['gra'],
    "vareṇuka": ['mw'],
    "vareṇya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vareṇyakratu": ['cae', 'gra', 'mw'],
    "vareṇyaya": ['mw'],
    "vareṇyā": ['mw'],
    "vareṇā": ['mw'],
    "vareṣudhi": ['mw'],
    "varga": ['cae', 'ddsa', 'gra', 'mw'],
    "vargacārin": ['bhs'],
    "vargadvitīya": ['mw'],
    "vargaghana": ['mw'],
    "vargaghanaghāta": ['mw'],
    "vargakarman": ['mw'],
    "vargamūla": ['mw'],
    "vargapada": ['mw'],
    "vargaprakṛti": ['mw'],
    "vargaprathama": ['mw'],
    "vargapraśaṃsin": ['mw'],
    "vargas": ['mw'],
    "vargastha": ['cae', 'mw'],
    "vargavarga": ['mw'],
    "vargavargavarga": ['mw'],
    "vargaya": ['mw'],
    "vargayati": ['ap90'],
    "vargaśas": ['ap90', 'cae', 'mw'],
    "vargaḥ": ['ap90'],
    "vargaṇā": ['ap90', 'mw'],
    "vargin": ['ap90', 'cae', 'mw'],
    "vargottama": ['mw'],
    "vargu": ['bhs'],
    "vargya": ['ap90', 'cae', 'mw'],
    "vargā": ['mw'],
    "vargāntya": ['mw'],
    "vargāṣṭaka": ['mw'],
    "vargīkṛta": ['mw'],
    "vargīya": ['ap90', 'ddsa', 'mw'],
    "vargīṇa": ['ap90', 'mw'],
    "varh": ['ap90', 'gra', 'mw'],
    "varha": ['ap90', 'mw'],
    "varhaṇa": ['ap90'],
    "varhin": ['ap90'],
    "varhis": ['ap90'],
    "varhiṇa": ['ap90'],
    "variman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "varimat": ['gra', 'mw'],
    "varin": ['mw'],
    "varitṛ": ['mw'],
    "varivas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "varivasita": ['ap90', 'mw'],
    "varivaskṛt": ['cae', 'gra', 'mw'],
    "varivasy": ['cae', 'gra'],
    "varivasya": ['ddsa', 'mw'],
    "varivasyita": ['ap90', 'mw'],
    "varivasyā": ['ap90', 'ddsa', 'gra', 'mw'],
    "varivasyārahasya": ['mw'],
    "varivo": ['mw'],
    "varivoda": ['cae', 'mw'],
    "varivodhā": ['cae', 'ddsa', 'gra', 'mw'],
    "varivovid": ['gra', 'mw'],
    "variśī": ['ap90', 'mw'],
    "variṣa": ['mw'],
    "variṣā": ['mw'],
    "variṣāpriya": ['mw'],
    "variṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "variṣṭhaka": ['mw'],
    "variṣṭhāśrama": ['mw'],
    "varja": ['cae', 'ddsa', 'mw'],
    "varjaka": ['ap90', 'mw'],
    "varjam": ['cae', 'mw'],
    "varjana": ['cae', 'mw'],
    "varjanaka": ['bhs'],
    "varjanaṃ": ['ap90'],
    "varjanīya": ['cae', 'mw'],
    "varjayati": ['bhs'],
    "varjayitavya": ['cae', 'mw'],
    "varjayitṛ": ['cae', 'mw'],
    "varjaḥ": ['ap90'],
    "varjaṃ": ['ap90'],
    "varjin": ['mw'],
    "varjita": ['ap90', 'cae', 'mw'],
    "varjya": ['ap90', 'cae', 'mw'],
    "varkara": ['mw'],
    "varkaraḥ": ['ap90'],
    "varkarāṭa": ['mw'],
    "varkarāṭaḥ": ['ap90'],
    "varkarīkuṇḍa": ['mw'],
    "varkika": ['bhs'],
    "varkuṭa": ['mw'],
    "varkuṭaḥ": ['ap90'],
    "varma": ['cae', 'mw'],
    "varmahara": ['ddsa', 'mw'],
    "varmaka": ['mw'],
    "varmakaśā": ['mw'],
    "varmakaṇṭaka": ['mw'],
    "varmakaṣā": ['mw'],
    "varmakānaka": ['bhs'],
    "varmamantra": ['mw'],
    "varman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "varmatī": ['mw'],
    "varmavat": ['mw'],
    "varmaya": ['ddsa', 'mw'],
    "varmaśarman": ['mw'],
    "varmaṇa": ['mw'],
    "varmaṇaḥ": ['ap90'],
    "varmaṇvant": ['cae'],
    "varmaṇvat": ['gra', 'mw'],
    "varmi": ['cae', 'ddsa', 'mw'],
    "varmika": ['ap90', 'mw'],
    "varmimatsya": ['mw'],
    "varmin": ['cae', 'gra', 'mw'],
    "varmita": ['cae', 'ddsa', 'mw'],
    "varmitāṅga": ['mw'],
    "varmiḥ": ['ap90'],
    "varmuṣa": ['mw'],
    "varmāya": ['mw'],
    "varola": ['mw'],
    "varolaḥ": ['ap90'],
    "varolī": ['mw'],
    "varoru": ['cae', 'ddsa', 'mw'],
    "varoṭa": ['mw'],
    "varoṭaḥ": ['ap90'],
    "varpan": ['ap90'],
    "varpas": ['cae', 'ddsa', 'gra', 'mw'],
    "varpaṇīti": ['gra', 'mw'],
    "varpeyu": ['mw'],
    "varph": ['ap90', 'mw'],
    "varphas": ['mw'],
    "varta": ['bhs', 'mw'],
    "vartajanman": ['mw'],
    "vartaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "vartakā": ['ap90', 'bhs', 'mw'],
    "vartakī": ['ap90', 'mw'],
    "vartaloha": ['mw'],
    "vartamāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "vartamānakavi": ['mw'],
    "vartamānakāla": ['mw'],
    "vartamānakālatā": ['mw'],
    "vartamānatva": ['mw'],
    "vartamānatā": ['mw'],
    "vartamānavat": ['mw'],
    "vartamānā": ['mw'],
    "vartamānākṣepa": ['mw'],
    "vartamānī": ['bhs'],
    "vartana": ['ap90', 'cae', 'ddsa', 'mw'],
    "vartanadāna": ['mw'],
    "vartanaka": ['bhs'],
    "vartanatā": ['bhs'],
    "vartanaviniyoga": ['mw'],
    "vartani": ['cae', 'ddsa', 'gra', 'mw'],
    "vartanin": ['mw'],
    "vartaniḥ": ['ap90'],
    "vartanā": ['bhs', 'mw'],
    "vartanābhāva": ['mw'],
    "vartanārthin": ['cae', 'mw'],
    "vartanī": ['mw'],
    "vartanīya": ['ddsa', 'mw'],
    "vartarūka": ['mw'],
    "vartarūkaḥ": ['ap90'],
    "vartas": ['ap90'],
    "vartatīkṣṇa": ['mw'],
    "vartave": ['cae', 'ddsa', 'mw'],
    "vartavya": ['ddsa'],
    "vartaya": ['ddsa'],
    "vartayadhyai": ['mw'],
    "vartaḥ": ['ap90'],
    "varti": ['bhs', 'cae', 'ddsa', 'mw'],
    "vartika": ['mw'],
    "vartikaḥ": ['ap90'],
    "vartikā": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vartin": ['ap90', 'cae', 'ddsa', 'mw'],
    "vartira": ['mw'],
    "vartiraḥ": ['ap90'],
    "vartis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vartita": ['bhs', 'mw'],
    "vartitajanman": ['mw'],
    "vartitaka": ['bhs'],
    "vartitavat": ['mw'],
    "vartitavya": ['cae', 'ddsa', 'mw'],
    "vartitva": ['ddsa', 'mw'],
    "vartitā": ['mw'],
    "vartitārtha": ['bhs'],
    "vartiḥ": ['ap90'],
    "vartiṣyamāṇa": ['mw'],
    "vartiṣṇu": ['ap90', 'mw'],
    "vartma": ['mw'],
    "vartmabandha": ['mw'],
    "vartmada": ['mw'],
    "vartmakarman": ['mw'],
    "vartman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vartmani": ['bhs', 'mw'],
    "vartmaniḥ": ['ap90'],
    "vartmapāta": ['ddsa', 'mw'],
    "vartmapātana": ['mw'],
    "vartmaroga": ['mw'],
    "vartmavibandhaka": ['mw'],
    "vartmaśarkarā": ['mw'],
    "vartmābhihoma": ['mw'],
    "vartmāvabandhaka": ['mw'],
    "vartmāvaroha": ['mw'],
    "vartmāyāsa": ['mw'],
    "vartmīya": ['bhs'],
    "vartra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vartsa": ['mw'],
    "vartsyat": ['mw'],
    "varttavya": ['mw'],
    "varttālī": ['bhs'],
    "varttībhavati": ['bhs'],
    "vartu": ['gra', 'mw'],
    "vartula": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vartulaka": ['bhs'],
    "vartuli": ['bhs', 'mw'],
    "vartulā": ['mw'],
    "vartulākāra": ['mw'],
    "vartulākṛti": ['mw'],
    "vartulākṣa": ['mw'],
    "vartulātantra": ['mw'],
    "vartulī": ['mw'],
    "vartya": ['bhs'],
    "vartī": ['cae', 'ddsa', 'mw'],
    "vartīkṛ": ['mw'],
    "vartīra": ['cae', 'mw'],
    "vartīraḥ": ['ap90'],
    "vartṛ": ['cae', 'gra', 'mw'],
    "varu": ['gra', 'mw'],
    "varuka": ['mw'],
    "varula": ['mw'],
    "varutra": ['mw'],
    "varutraṃ": ['ap90'],
    "varutrī": ['gra'],
    "varutṛ": ['mw'],
    "varuḍa": ['ddsa', 'mw'],
    "varuḍaḥ": ['ap90'],
    "varuḍī": ['mw'],
    "varuṇa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "varuṇabhaṭṭa": ['mw'],
    "varuṇadaiva": ['mw'],
    "varuṇadaivata": ['mw'],
    "varuṇadatta": ['bhs', 'mw'],
    "varuṇadeva": ['bhs', 'cae', 'mw'],
    "varuṇadevatya": ['mw'],
    "varuṇadhrut": ['gra', 'mw'],
    "varuṇagraha": ['mw'],
    "varuṇagrāha": ['mw'],
    "varuṇagṛhapati": ['mw'],
    "varuṇagṛhīta": ['cae', 'mw'],
    "varuṇajapa": ['mw'],
    "varuṇajyeṣṭha": ['mw'],
    "varuṇaka": ['mw'],
    "varuṇakāṣṭhikā": ['mw'],
    "varuṇakṛcchraka": ['mw'],
    "varuṇaloka": ['cae', 'mw'],
    "varuṇamati": ['bhs', 'mw'],
    "varuṇameni": ['cae', 'mw'],
    "varuṇamitra": ['mw'],
    "varuṇapariyatama": ['mw'],
    "varuṇapraghāsa": ['cae', 'mw'],
    "varuṇapraghāsika": ['mw'],
    "varuṇapraśiṣṭa": ['gra', 'mw'],
    "varuṇapriyā": ['mw'],
    "varuṇapuruṣa": ['mw'],
    "varuṇapurāṇa": ['mw'],
    "varuṇapāśa": ['cae', 'mw'],
    "varuṇarāja": ['bhs'],
    "varuṇarājan": ['cae', 'mw'],
    "varuṇasava": ['cae', 'mw'],
    "varuṇasrotasa": ['mw'],
    "varuṇasāman": ['mw'],
    "varuṇatejas": ['mw'],
    "varuṇatva": ['mw'],
    "varuṇatīrtha": ['mw'],
    "varuṇavegā": ['bhs', 'mw'],
    "varuṇavidhi": ['mw'],
    "varuṇaśarman": ['mw'],
    "varuṇaśeṣas": ['gra', 'mw'],
    "varuṇaśrāddha": ['mw'],
    "varuṇaśrāddhavidhi": ['mw'],
    "varuṇaśrī": ['bhs'],
    "varuṇaḥ": ['ap90'],
    "varuṇeśa": ['mw'],
    "varuṇeśadeśa": ['mw'],
    "varuṇeśvaratīrtha": ['mw'],
    "varuṇia": ['gra'],
    "varuṇika": ['mw'],
    "varuṇikā": ['bhs'],
    "varuṇila": ['mw'],
    "varuṇiya": ['mw'],
    "varuṇoda": ['mw'],
    "varuṇopaniṣad": ['mw'],
    "varuṇopapurāṇa": ['mw'],
    "varuṇottama": ['bhs'],
    "varuṇya": ['cae', 'ddsa', 'gra', 'mw'],
    "varuṇā": ['bhs', 'mw'],
    "varuṇādri": ['mw'],
    "varuṇālaya": ['cae', 'ddsa', 'mw'],
    "varuṇānyāḥsāman": ['mw'],
    "varuṇānī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "varuṇāriṣṭakamaya": ['mw'],
    "varuṇātmajā": ['mw'],
    "varuṇāvi": ['mw'],
    "varuṇāvis": ['mw'],
    "varuṇāviḥ": ['ap90'],
    "varuṇāvāsa": ['mw'],
    "varuṇāṅgaruha": ['mw'],
    "varuṭa": ['bhs', 'mw'],
    "varuṭaḥ": ['ap90'],
    "varva": ['mw'],
    "varvara": ['ap90', 'cae', 'mw'],
    "varvaraka": ['ddsa', 'mw'],
    "varvarakaṃ": ['ap90'],
    "varvari": ['mw'],
    "varvarīkaḥ": ['ap90'],
    "varvaṇā": ['ap90', 'mw'],
    "varvaṭa": ['ap90', 'mw'],
    "varvi": ['mw'],
    "varvuraḥ": ['ap90'],
    "varvurika": ['mw'],
    "varvūra": ['mw'],
    "varvūraka": ['mw'],
    "varvūraḥ": ['ap90'],
    "varya": ['ap90', 'cae', 'ddsa', 'mw'],
    "varyā": ['mw'],
    "varā": ['ap90', 'mw'],
    "varābhidha": ['mw'],
    "varābhidhā": ['mw'],
    "varādana": ['mw'],
    "varāgramati": ['bhs'],
    "varāha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "varāhadanta": ['mw'],
    "varāhadat": ['mw'],
    "varāhadatta": ['mw'],
    "varāhadaṃṣṭra": ['mw'],
    "varāhadeva": ['mw'],
    "varāhadevasvāmin": ['mw'],
    "varāhadvādaśī": ['mw'],
    "varāhadvīpa": ['mw'],
    "varāhadānavidhi": ['mw'],
    "varāhaka": ['bhs', 'mw'],
    "varāhakalpa": ['mw'],
    "varāhakanda": ['mw'],
    "varāhakarṇa": ['mw'],
    "varāhakarṇikā": ['mw'],
    "varāhakarṇī": ['mw'],
    "varāhakavaca": ['mw'],
    "varāhakrāntā": ['mw'],
    "varāhakālin": ['mw'],
    "varāhakāntā": ['mw'],
    "varāhamihira": ['ap90', 'cae', 'mw'],
    "varāhamukhī": ['bhs'],
    "varāhamāhātmya": ['mw'],
    "varāhamūla": ['mw'],
    "varāhanāman": ['mw'],
    "varāhanāmāṣṭottaraśata": ['mw'],
    "varāhaparvata": ['mw'],
    "varāhapattrī": ['mw'],
    "varāhapurāṇa": ['mw'],
    "varāhasaṃhitā": ['mw'],
    "varāhasphuṭa": ['mw'],
    "varāhastuti": ['mw'],
    "varāhasvāmin": ['mw'],
    "varāhavadhrī": ['mw'],
    "varāhavapuṣa": ['mw'],
    "varāhavasā": ['mw'],
    "varāhavat": ['mw'],
    "varāhayu": ['gra', 'mw'],
    "varāhayūtha": ['mw'],
    "varāhaśaila": ['mw'],
    "varāhaśṛṅga": ['mw'],
    "varāhaḥ": ['ap90'],
    "varāhikā": ['mw'],
    "varāhopaniṣad": ['mw'],
    "varāhopānah": ['mw'],
    "varāhu": ['cae', 'ddsa', 'gra', 'mw'],
    "varāhuḥ": ['ap90'],
    "varāhādri": ['mw'],
    "varāhāvatāra": ['mw'],
    "varāhāśva": ['mw'],
    "varāhī": ['cped', 'mw'],
    "varājya": ['mw'],
    "varājīvin": ['mw'],
    "varāka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "varākaka": ['mw'],
    "varākāṅkṣin": ['mw'],
    "varāla": ['mw'],
    "varālaka": ['mw'],
    "varālaḥ": ['ap90'],
    "varāli": ['mw'],
    "varālikā": ['bhs', 'mw'],
    "varālā": ['mw'],
    "varālī": ['bhs'],
    "varāmra": ['mw'],
    "varānandabhairavatantra": ['mw'],
    "varānanā": ['cae', 'mw'],
    "varāraka": ['mw'],
    "varārakaṃ": ['ap90'],
    "varāraṇi": ['mw'],
    "varārdhya": ['mw'],
    "varārha": ['cae', 'mw'],
    "varāroha": ['cae', 'ddsa', 'mw'],
    "varārohā": ['cped', 'mw'],
    "varārthin": ['cae', 'mw'],
    "varārthā": ['mw'],
    "varāsana": ['cae', 'mw'],
    "varāte": ['ddsa'],
    "varātisarga": ['ddsa', 'mw'],
    "varāya": ['ddsa', 'mw'],
    "varāśi": ['mw'],
    "varāśiḥ": ['ap90'],
    "varāḍi": ['mw'],
    "varāḍirāga": ['ddsa', 'mw'],
    "varāḍī": ['mw'],
    "varāṅga": ['bhs', 'cae', 'ddsa', 'mw'],
    "varāṅgaka": ['mw'],
    "varāṅganā": ['cae', 'mw'],
    "varāṅgarūpin": ['mw'],
    "varāṅgarūpopeta": ['mw'],
    "varāṅgin": ['mw'],
    "varāṅgī": ['mw'],
    "varāṇa": ['mw'],
    "varāṇasa": ['mw'],
    "varāṇasī": ['ap90', 'ddsa', 'mw'],
    "varāṇaḥ": ['ap90'],
    "varāṭa": ['cae', 'ddsa', 'mw'],
    "varāṭaka": ['cae', 'mw'],
    "varāṭakarajas": ['mw'],
    "varāṭakaḥ": ['ap90'],
    "varāṭaḥ": ['ap90'],
    "varāṭikā": ['ap90', 'mw'],
    "varāṭī": ['mw'],
    "varī": ['ap90', 'mw'],
    "varīdharā": ['mw'],
    "varīdāsa": ['mw'],
    "varīman": ['ap90', 'cae', 'gra', 'mw'],
    "varītākṣa": ['mw'],
    "varītṛ": ['cae', 'ddsa', 'mw'],
    "varīvarda": ['mw'],
    "varīvardaḥ": ['ap90'],
    "varīvṛjat": ['mw'],
    "varīvṛta": ['cae', 'mw'],
    "varīyas": ['ap90', 'ddsa', 'gra', 'mw'],
    "varīyasī": ['mw'],
    "varīyaṃs": ['cae'],
    "varīṣu": ['mw'],
    "varīṣuḥ": ['ap90'],
    "varśman": ['mw'],
    "varūka": ['mw'],
    "varūtha": ['cae', 'ddsa', 'gra', 'mw'],
    "varūthaka": ['mw'],
    "varūthapa": ['mw'],
    "varūthavatī": ['mw'],
    "varūthaśas": ['mw'],
    "varūthaṃ": ['ap90'],
    "varūthia": ['gra'],
    "varūthin": ['ap90', 'cae', 'ddsa', 'mw'],
    "varūthinī": ['mw'],
    "varūthinīpati": ['mw'],
    "varūthya": ['cae', 'ddsa', 'gra', 'mw'],
    "varūthyadeśe": ['mw'],
    "varūthādhipa": ['mw'],
    "varūtri": ['mw'],
    "varūtrī": ['mw'],
    "varūtṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "varṇ": ['ap90', 'mw'],
    "varṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "varṇabhairava": ['mw'],
    "varṇabhedavidhi": ['mw'],
    "varṇabhedinī": ['mw'],
    "varṇabhinna": ['mw'],
    "varṇabhīru": ['mw'],
    "varṇabuddhi": ['mw'],
    "varṇacaura": ['mw'],
    "varṇacitrita": ['cae', 'mw'],
    "varṇacāraka": ['mw'],
    "varṇada": ['mw'],
    "varṇadevatā": ['mw'],
    "varṇadeśanā": ['mw'],
    "varṇadharma": ['cae', 'mw'],
    "varṇadhātu": ['bhs'],
    "varṇadvayamaya": ['mw'],
    "varṇadātrī": ['mw'],
    "varṇadīpikā": ['mw'],
    "varṇadūta": ['mw'],
    "varṇadūṣaka": ['cae', 'mw'],
    "varṇagata": ['mw'],
    "varṇaghanasāriṇī": ['mw'],
    "varṇagrathaṇā": ['mw'],
    "varṇaguru": ['mw'],
    "varṇahīna": ['mw'],
    "varṇaja": ['mw'],
    "varṇajyeṣṭha": ['cae', 'mw'],
    "varṇajyāyas": ['mw'],
    "varṇajyāyaṃs": ['cae'],
    "varṇaka": ['cae', 'ddsa', 'mw'],
    "varṇakacitrita": ['cae', 'mw'],
    "varṇakadaṇḍaka": ['mw'],
    "varṇakadāru": ['mw'],
    "varṇakamaya": ['mw'],
    "varṇakavi": ['mw'],
    "varṇakaḥ": ['ap90'],
    "varṇakita": ['mw'],
    "varṇakrama": ['cae', 'mw'],
    "varṇakramadarpaṇa": ['mw'],
    "varṇakramalakṣaṇa": ['mw'],
    "varṇakramavivaraṇa": ['mw'],
    "varṇakrameṇa": ['mw'],
    "varṇakā": ['mw'],
    "varṇakūpikā": ['mw'],
    "varṇakṛt": ['mw'],
    "varṇalekhikā": ['mw'],
    "varṇalekhā": ['mw'],
    "varṇalīla": ['mw'],
    "varṇamaya": ['mw'],
    "varṇamañcikā": ['mw'],
    "varṇamālā": ['mw'],
    "varṇamālāpraśnagrantha": ['mw'],
    "varṇamātra": ['cae', 'mw'],
    "varṇamātrā": ['mw'],
    "varṇamātṛ": ['mw'],
    "varṇamātṛkā": ['mw'],
    "varṇana": ['cae', 'ddsa', 'mw'],
    "varṇanaṃ": ['ap90'],
    "varṇanā": ['mw'],
    "varṇanātha": ['mw'],
    "varṇanīya": ['bhs', 'cae', 'mw'],
    "varṇaparicaya": ['cae', 'mw'],
    "varṇaparidhvaṃsa": ['ddsa', 'mw'],
    "varṇaparidhvaṃsā": ['mw'],
    "varṇapattra": ['mw'],
    "varṇapaṭala": ['mw'],
    "varṇaprabodha": ['mw'],
    "varṇaprakarṣa": ['mw'],
    "varṇaprakāśa": ['mw'],
    "varṇaprasādana": ['mw'],
    "varṇapuṣpa": ['mw'],
    "varṇapuṣpaka": ['mw'],
    "varṇapuṣpī": ['mw'],
    "varṇapāta": ['mw'],
    "varṇapātra": ['mw'],
    "varṇapāṭha": ['mw'],
    "varṇaratnadīpikā": ['mw'],
    "varṇarekhā": ['mw'],
    "varṇarāśi": ['ddsa', 'mw'],
    "varṇasa": ['mw'],
    "varṇasamāmnāya": ['mw'],
    "varṇasaṃghāta": ['mw'],
    "varṇasaṃghāṭa": ['mw'],
    "varṇasaṃhitā": ['mw'],
    "varṇasaṃhāra": ['mw'],
    "varṇasaṃkara": ['cae', 'mw'],
    "varṇasaṃkarajātimālā": ['mw'],
    "varṇasaṃkaratā": ['mw'],
    "varṇasaṃkarika": ['mw'],
    "varṇasaṃsarga": ['cae', 'mw'],
    "varṇasaṃvarga": ['mw'],
    "varṇasaṃyoga": ['mw'],
    "varṇasi": ['mw'],
    "varṇasiḥ": ['ap90'],
    "varṇasthāna": ['mw'],
    "varṇasvara": ['bhs'],
    "varṇasārabhūtavarṇakrama": ['mw'],
    "varṇasāramaṇi": ['mw'],
    "varṇasūtra": ['mw'],
    "varṇatantramālā": ['mw'],
    "varṇatanu": ['mw'],
    "varṇatarṇaka": ['mw'],
    "varṇatarṇikā": ['mw'],
    "varṇatas": ['mw'],
    "varṇatva": ['mw'],
    "varṇatā": ['cae', 'mw'],
    "varṇatāla": ['mw'],
    "varṇatūli": ['mw'],
    "varṇatūlikā": ['mw'],
    "varṇatūlī": ['mw'],
    "varṇavaikṛta": ['mw'],
    "varṇavarti": ['cae', 'mw'],
    "varṇavartikā": ['cae', 'mw'],
    "varṇavat": ['mw'],
    "varṇavatī": ['ap90', 'mw'],
    "varṇavibhāvin": ['mw'],
    "varṇavikriyā": ['mw'],
    "varṇaviloḍaka": ['mw'],
    "varṇavilāsa": ['mw'],
    "varṇavilāsinī": ['mw'],
    "varṇaviparyaya": ['mw'],
    "varṇaviveka": ['mw'],
    "varṇavyatikrāntā": ['mw'],
    "varṇavyavasthiti": ['mw'],
    "varṇavyavasthā": ['mw'],
    "varṇavādin": ['mw'],
    "varṇavṛtta": ['cae', 'mw'],
    "varṇay": ['cae'],
    "varṇaya": ['ddsa'],
    "varṇayati": ['mw'],
    "varṇayitavya": ['cae', 'ddsa', 'mw'],
    "varṇayitṛ": ['cae'],
    "varṇaśreṣṭha": ['mw'],
    "varṇaśāsana": ['mw'],
    "varṇaḥ": ['ap90'],
    "varṇaṭa": ['ddsa', 'mw'],
    "varṇeśvarī": ['mw'],
    "varṇi": ['mw'],
    "varṇika": ['mw'],
    "varṇikā": ['ap90', 'ddsa', 'mw'],
    "varṇikāparigraha": ['mw'],
    "varṇila": ['mw'],
    "varṇiliṅgin": ['mw'],
    "varṇin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "varṇinī": ['ap90'],
    "varṇita": ['ap90', 'bhs', 'mw'],
    "varṇitavat": ['ddsa', 'mw'],
    "varṇivadha": ['mw'],
    "varṇiṇī": ['mw'],
    "varṇodaka": ['ddsa', 'mw'],
    "varṇodaya": ['mw'],
    "varṇoddhṛti": ['mw'],
    "varṇopaniṣad": ['mw'],
    "varṇopeta": ['mw'],
    "varṇu": ['bhs', 'mw'],
    "varṇuḥ": ['ap90'],
    "varṇya": ['ap90', 'cae', 'ddsa', 'mw'],
    "varṇyasama": ['mw'],
    "varṇā": ['mw'],
    "varṇābhidhāna": ['mw'],
    "varṇādhipa": ['mw'],
    "varṇāgama": ['mw'],
    "varṇāntara": ['mw'],
    "varṇāntaragamana": ['mw'],
    "varṇānuprāsa": ['mw'],
    "varṇānupūrveṇa": ['mw'],
    "varṇānyatva": ['mw'],
    "varṇāpasada": ['mw'],
    "varṇāpeta": ['cae', 'mw'],
    "varṇārha": ['mw'],
    "varṇātmaka": ['ddsa', 'mw'],
    "varṇātman": ['mw'],
    "varṇāvara": ['cae', 'mw'],
    "varṇāśrama": ['cae', 'mw'],
    "varṇāśramadharma": ['mw'],
    "varṇāśramadharmadīpa": ['mw'],
    "varṇāśramaguru": ['mw'],
    "varṇāśramavat": ['mw'],
    "varṇāśramin": ['mw'],
    "varṇāśā": ['mw'],
    "varṇāṅkā": ['mw'],
    "varṇāṭa": ['mw'],
    "varṇāṭaḥ": ['ap90'],
    "varṇībhū": ['mw'],
    "varṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "varṣabhuj": ['mw'],
    "varṣabhāskara": ['mw'],
    "varṣacaryāvarṇana": ['mw'],
    "varṣadaśāphala": ['mw'],
    "varṣadaśāprakaraṇa": ['mw'],
    "varṣadhara": ['cae', 'mw'],
    "varṣadharṣa": ['mw'],
    "varṣadhāra": ['bhs', 'mw'],
    "varṣadhārādhara": ['mw'],
    "varṣadīdhiti": ['mw'],
    "varṣagaṇa": ['mw'],
    "varṣagaṇitapaddhati": ['mw'],
    "varṣaghna": ['mw'],
    "varṣagiri": ['mw'],
    "varṣaika": ['mw'],
    "varṣaja": ['mw'],
    "varṣaka": ['ap90', 'bhs', 'mw'],
    "varṣakara": ['mw'],
    "varṣakarman": ['mw'],
    "varṣakarī": ['mw'],
    "varṣaketu": ['mw'],
    "varṣakośa": ['mw'],
    "varṣakāma": ['mw'],
    "varṣakāmeṣṭi": ['mw'],
    "varṣakārī": ['mw'],
    "varṣakī": ['bhs'],
    "varṣakṛtya": ['mw'],
    "varṣakṛtyakaumudī": ['mw'],
    "varṣakṛtyataraṃga": ['mw'],
    "varṣalambhaka": ['mw'],
    "varṣamahodaya": ['mw'],
    "varṣamaryādāgiri": ['mw'],
    "varṣamañjarī": ['mw'],
    "varṣamedas": ['mw'],
    "varṣamātra": ['mw'],
    "varṣanakṣatrasūcaka": ['mw'],
    "varṣanirṇij": ['cae', 'gra', 'mw'],
    "varṣant": ['cae'],
    "varṣapa": ['mw'],
    "varṣapada": ['mw'],
    "varṣapaddhati": ['mw'],
    "varṣaparvata": ['mw'],
    "varṣapati": ['mw'],
    "varṣapavitra": ['mw'],
    "varṣapaśuprayoga": ['mw'],
    "varṣaphala": ['mw'],
    "varṣaphalapaddhati": ['mw'],
    "varṣaphalarahasya": ['mw'],
    "varṣapradīpa": ['mw'],
    "varṣapratibandha": ['mw'],
    "varṣapraveśa": ['mw'],
    "varṣapriya": ['mw'],
    "varṣaprāvan": ['mw'],
    "varṣapuruṣa": ['mw'],
    "varṣapuṣpa": ['mw'],
    "varṣapuṣpā": ['mw'],
    "varṣapākin": ['mw'],
    "varṣapāta": ['cae', 'mw'],
    "varṣapūga": ['cae', 'mw'],
    "varṣartu": ['mw'],
    "varṣartumāsapakṣāhovelādeśapradeśavat": ['mw'],
    "varṣartuvarṇana": ['mw'],
    "varṣarātra": ['mw'],
    "varṣarātri": ['mw'],
    "varṣasahasra": ['mw'],
    "varṣasahasraka": ['mw'],
    "varṣasahasravṛtta": ['cae'],
    "varṣasahasrika": ['mw'],
    "varṣasahasrin": ['mw'],
    "varṣasahasrāya": ['mw'],
    "varṣasahasrīya": ['mw'],
    "varṣasthāla": ['bhs', 'mw'],
    "varṣat": ['mw'],
    "varṣatantra": ['mw'],
    "varṣatra": ['ddsa', 'mw'],
    "varṣatrāṇa": ['mw'],
    "varṣaugha": ['cae', 'mw'],
    "varṣavalāhaka": ['bhs'],
    "varṣavara": ['cae', 'ddsa', 'mw'],
    "varṣavardhana": ['mw'],
    "varṣavardhāpanavidhāna": ['mw'],
    "varṣavasana": ['mw'],
    "varṣavat": ['mw'],
    "varṣavicāra": ['mw'],
    "varṣavṛddha": ['cae', 'mw'],
    "varṣavṛddhi": ['mw'],
    "varṣavṛddhiprayoga": ['mw'],
    "varṣaya": ['ddsa'],
    "varṣayantī": ['mw'],
    "varṣaśata": ['mw'],
    "varṣaśatavṛtta": ['cae'],
    "varṣaśatin": ['cae', 'mw'],
    "varṣaśatādhika": ['mw'],
    "varṣaḥ": ['ap90'],
    "varṣaṃdhara": ['mw'],
    "varṣaṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "varṣaṇaṃ": ['ap90'],
    "varṣaṇi": ['mw'],
    "varṣaṇiḥ": ['ap90'],
    "varṣaṇī": ['bhs'],
    "varṣeja": ['mw'],
    "varṣeśa": ['mw'],
    "varṣia": ['gra'],
    "varṣika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "varṣiman": ['cae', 'mw'],
    "varṣin": ['cae', 'mw'],
    "varṣita": ['mw'],
    "varṣitaṃ": ['ap90'],
    "varṣitā": ['cae', 'mw'],
    "varṣitṛ": ['cae', 'mw'],
    "varṣiṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "varṣiṣṭhakṣatra": ['gra', 'mw'],
    "varṣma": ['mw'],
    "varṣmala": ['mw'],
    "varṣman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "varṣmaseka": ['mw'],
    "varṣmavat": ['mw'],
    "varṣmavīrya": ['mw'],
    "varṣmaṃ": ['ap90'],
    "varṣmābha": ['mw'],
    "varṣodaka": ['cae'],
    "varṣopala": ['cae', 'ddsa', 'mw'],
    "varṣopanāyikā": ['bhs', 'mw'],
    "varṣoṣita": ['mw'],
    "varṣu": ['mw'],
    "varṣuka": ['ap90', 'cae', 'ddsa', 'mw'],
    "varṣukābda": ['mw'],
    "varṣukāmbuda": ['mw'],
    "varṣya": ['cae', 'ddsa', 'gra', 'mw'],
    "varṣyā": ['mw'],
    "varṣā": ['ap90', 'ddsa', 'mw'],
    "varṣābhava": ['mw'],
    "varṣābhvī": ['mw'],
    "varṣābhū": ['mw'],
    "varṣābīja": ['mw'],
    "varṣācara": ['mw'],
    "varṣāchinnaka": ['bhs'],
    "varṣādhipa": ['mw'],
    "varṣādhipati": ['bhs'],
    "varṣādhṛta": ['mw'],
    "varṣāgama": ['mw'],
    "varṣāghoṣa": ['mw'],
    "varṣāgra": ['bhs'],
    "varṣāhika": ['mw'],
    "varṣāhū": ['cae', 'mw'],
    "varṣājya": ['mw'],
    "varṣākāla": ['cae', 'mw'],
    "varṣākālika": ['mw'],
    "varṣākālīna": ['mw'],
    "varṣākāra": ['bhs', 'mw'],
    "varṣākārā": ['bhs'],
    "varṣālaṅkāyikā": ['mw'],
    "varṣālī": ['mw'],
    "varṣāmada": ['mw'],
    "varṣāmbhaḥpāraṇavrata": ['mw'],
    "varṣāmbu": ['mw'],
    "varṣāmbupravaha": ['mw'],
    "varṣānadī": ['mw'],
    "varṣāprabhañjana": ['mw'],
    "varṣārcis": ['mw'],
    "varṣārdha": ['cae', 'mw'],
    "varṣārha": ['mw'],
    "varṣārātra": ['cae', 'mw'],
    "varṣārātri": ['mw'],
    "varṣāsamaya": ['cae', 'mw'],
    "varṣāsthālī": ['bhs'],
    "varṣāsuja": ['mw'],
    "varṣāvastu": ['mw'],
    "varṣāvasāna": ['mw'],
    "varṣāvasāya": ['mw'],
    "varṣāvāsa": ['bhs', 'mw'],
    "varṣāyuta": ['mw'],
    "varṣāśarad": ['cae', 'mw'],
    "varṣāśāṭī": ['bhs', 'mw'],
    "varṣāśāṭīgopaka": ['mw'],
    "varṣāṃśa": ['mw'],
    "varṣāṃśaka": ['mw'],
    "varṣāṅga": ['mw'],
    "varṣāṅgī": ['mw'],
    "varṣīkā": ['mw'],
    "varṣīya": ['cae', 'mw'],
    "varṣīyas": ['ap90', 'gra', 'mw'],
    "varṣīyaṃs": ['cae'],
    "varṣīṇa": ['mw'],
    "varṣṭṛ": ['cae', 'mw'],
    "vas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vasa": ['bhs', 'cped', 'mw'],
    "vasaga": ['cped'],
    "vasala": ['cped'],
    "vasamāna": ['cped'],
    "vasana": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vasanabhāva": ['cped'],
    "vasanaka": ['cped'],
    "vasanamaya": ['mw'],
    "vasanaparyāya": ['cae', 'mw'],
    "vasanasadman": ['mw'],
    "vasanavant": ['cae'],
    "vasanavat": ['mw'],
    "vasanaṃ": ['ap90'],
    "vasanaṭṭhāna": ['cped'],
    "vasanta": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vasantabandhu": ['cae', 'mw'],
    "vasantabhānu": ['mw'],
    "vasantabhūṣaṇa": ['mw'],
    "vasantadeva": ['mw'],
    "vasantadru": ['mw'],
    "vasantadruma": ['mw'],
    "vasantadūta": ['mw'],
    "vasantadūtī": ['mw'],
    "vasantagandhi": ['bhs', 'mw'],
    "vasantagandhin": ['mw'],
    "vasantaghoṣa": ['mw'],
    "vasantaghoṣin": ['mw'],
    "vasantaja": ['mw'],
    "vasantajā": ['mw'],
    "vasantaka": ['bhs', 'cae', 'mw'],
    "vasantakusama": ['mw'],
    "vasantakusamākara": ['mw'],
    "vasantakāla": ['cae', 'cped', 'mw'],
    "vasantalatikā": ['mw'],
    "vasantalatā": ['mw'],
    "vasantalekhā": ['mw'],
    "vasantamadana": ['mw'],
    "vasantamahotsava": ['cae', 'mw'],
    "vasantamādanī": ['mw'],
    "vasantamālatirasa": ['mw'],
    "vasantamālikā": ['mw'],
    "vasantamāsa": ['mw'],
    "vasantapañcamī": ['mw'],
    "vasantapañcamīprayoga": ['mw'],
    "vasantapañcamīpūjā": ['mw'],
    "vasantapura": ['mw'],
    "vasantapuṣpa": ['cae', 'mw'],
    "vasantartu": ['mw'],
    "vasantarāja": ['mw'],
    "vasantarājacikitsā": ['mw'],
    "vasantasahāya": ['cae', 'mw'],
    "vasantasakha": ['cae', 'mw'],
    "vasantasamaya": ['cae', 'mw'],
    "vasantasamayotsava": ['mw'],
    "vasantasena": ['cae', 'mw'],
    "vasantasenā": ['mw'],
    "vasantatilaka": ['cae', 'mw'],
    "vasantatilakabhāṇa": ['mw'],
    "vasantatilakatantra": ['mw'],
    "vasantavarṇana": ['mw'],
    "vasantavilāsa": ['mw'],
    "vasantavitala": ['mw'],
    "vasantavrata": ['mw'],
    "vasantavraṇa": ['mw'],
    "vasantayodha": ['mw'],
    "vasantayātrā": ['mw'],
    "vasantaśekhara": ['mw'],
    "vasantaśrī": ['cae', 'mw'],
    "vasantaśākhin": ['mw'],
    "vasantikā": ['mw'],
    "vasantotsava": ['cae', 'ddsa', 'mw'],
    "vasantotsavacarita": ['mw'],
    "vasantā": ['cae', 'ddsa', 'mw'],
    "vasantācārya": ['mw'],
    "vasantādhyayana": ['mw'],
    "vasanārṇa": ['mw'],
    "vasanārṇava": ['mw'],
    "vasar": ['mw'],
    "vasarhan": ['ddsa', 'gra', 'mw'],
    "vasatha": ['mw'],
    "vasathaṃ": ['ap90'],
    "vasati": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vasatidruma": ['mw'],
    "vasatiḥ": ['ap90'],
    "vasatī": ['mw'],
    "vasatīvarī": ['ddsa', 'mw'],
    "vasavattaka": ['cped'],
    "vasavattana": ['cped'],
    "vasavattī": ['cped'],
    "vasavi": ['gra'],
    "vasavia": ['gra'],
    "vasavya": ['cae', 'ddsa', 'gra', 'mw'],
    "vasavāna": ['cae', 'ddsa', 'gra', 'mw'],
    "vasayati": ['bhs'],
    "vasaṃtaḥ": ['ap90'],
    "vasaṅgata": ['cped'],
    "vasi": ['cped', 'mw'],
    "vasika": ['bhs', 'mw'],
    "vasin": ['mw'],
    "vasippatta": ['cped'],
    "vasira": ['mw'],
    "vasiraṃ": ['ap90'],
    "vasita": ['ap90', 'mw'],
    "vasitabba": ['cped'],
    "vasitavya": ['mw'],
    "vasituṁ": ['cped'],
    "vasitvā": ['cped'],
    "vasitā": ['bhs', 'cped'],
    "vasitṛ": ['mw'],
    "vasitṛtama": ['mw'],
    "vasiḥ": ['ap90'],
    "vasiṣṭha": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vasiṣṭhabhṛgvatrisama": ['mw'],
    "vasiṣṭhahomaprakāra": ['mw'],
    "vasiṣṭhaka": ['mw'],
    "vasiṣṭhakalpa": ['mw'],
    "vasiṣṭhakaśyapikā": ['mw'],
    "vasiṣṭhaliṅgapurāṇa": ['mw'],
    "vasiṣṭhanihava": ['mw'],
    "vasiṣṭhapramukha": ['mw'],
    "vasiṣṭhaprācī": ['mw'],
    "vasiṣṭhaputra": ['mw'],
    "vasiṣṭhasaṃhitā": ['mw'],
    "vasiṣṭhasaṃsarpa": ['mw'],
    "vasiṣṭhasiddhānta": ['mw'],
    "vasiṣṭhasmṛti": ['mw'],
    "vasiṣṭhatantra": ['mw'],
    "vasiṣṭhatva": ['mw'],
    "vasiṣṭhavat": ['gra', 'mw'],
    "vasiṣṭhayajña": ['mw'],
    "vasiṣṭhaśapha": ['mw'],
    "vasiṣṭhaśikṣā": ['mw'],
    "vasiṣṭhaśilā": ['mw'],
    "vasiṣṭhaśrāddhakalpa": ['mw'],
    "vasiṣṭhaḥ": ['ap90'],
    "vasiṣṭhopapurāṇa": ['mw'],
    "vask": ['ap90', 'mw'],
    "vaska": ['mw'],
    "vaskarāṭikā": ['ap90', 'mw'],
    "vaskaya": ['ap90', 'mw'],
    "vaskayaṇī": ['ap90'],
    "vaskaḥ": ['ap90'],
    "vasman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vasna": ['cae', 'ddsa', 'gra', 'mw'],
    "vasnana": ['mw'],
    "vasnanaṃ": ['ap90'],
    "vasnasā": ['ap90', 'mw'],
    "vasnay": ['gra'],
    "vasnaya": ['mw'],
    "vasnaṃ": ['ap90'],
    "vasnia": ['gra'],
    "vasnika": ['ap90', 'mw'],
    "vasnikā": ['mw'],
    "vasnya": ['cae', 'ddsa', 'gra', 'mw'],
    "vasordhārā": ['mw'],
    "vasordhārāprayoga": ['mw'],
    "vasoṣpati": ['mw'],
    "vasra": ['mw'],
    "vassa": ['cped'],
    "vassagga": ['cped'],
    "vassakāla": ['cped'],
    "vassami": ['cped'],
    "vassamāna": ['cped'],
    "vassana": ['cped'],
    "vassanta": ['cped'],
    "vassati": ['cped'],
    "vassi": ['cped'],
    "vassika": ['cped'],
    "vassikasāṭikā": ['cped'],
    "vassikā": ['cped'],
    "vassita": ['cped'],
    "vassitvā": ['cped'],
    "vassāna": ['cped'],
    "vassāpanaka": ['cped'],
    "vassāpesi": ['cped'],
    "vassāpeti": ['cped'],
    "vassāpetvā": ['cped'],
    "vassāpita": ['cped'],
    "vassūpagata": ['cped'],
    "vast": ['ap90', 'mw'],
    "vasta": ['cae', 'mw'],
    "vastakaṃ": ['ap90'],
    "vastave": ['cae'],
    "vastavya": ['cae', 'ddsa', 'mw'],
    "vastavyatā": ['mw'],
    "vastaṃ": ['ap90'],
    "vasthita": ['cae'],
    "vasti": ['cae', 'ddsa', 'mw'],
    "vastibila": ['mw'],
    "vastikarman": ['mw'],
    "vastikarmāḍhya": ['mw'],
    "vastikośa": ['mw'],
    "vastikuṇḍala": ['mw'],
    "vastikuṇḍalikā": ['mw'],
    "vastimala": ['mw'],
    "vastimūla": ['mw'],
    "vastipīḍā": ['mw'],
    "vastiruj": ['mw'],
    "vastivyāpad": ['mw'],
    "vastiśiras": ['mw'],
    "vastiśodhana": ['mw'],
    "vastiśīrṣa": ['mw'],
    "vastiḥ": ['ap90'],
    "vastra": ['cae', 'ddsa', 'gra', 'mw'],
    "vastrabandha": ['mw'],
    "vastrabhedaka": ['mw'],
    "vastrabhedin": ['mw'],
    "vastrabhūṣaṇa": ['mw'],
    "vastrabhūṣaṇā": ['mw'],
    "vastracchanna": ['mw'],
    "vastrada": ['mw'],
    "vastradaśā": ['mw'],
    "vastradhāraka": ['mw'],
    "vastradhāraṇī": ['mw'],
    "vastradhāvin": ['mw'],
    "vastradā": ['gra', 'mw'],
    "vastradāna": ['mw'],
    "vastradānakathā": ['mw'],
    "vastraghargharī": ['mw'],
    "vastragopana": ['mw'],
    "vastragranthi": ['mw'],
    "vastragṛha": ['mw'],
    "vastraka": ['mw'],
    "vastraknopam": ['mw'],
    "vastrakośa": ['mw'],
    "vastrakuṭṭima": ['mw'],
    "vastramathi": ['gra', 'mw'],
    "vastramukhya": ['mw'],
    "vastranirṇejaka": ['mw'],
    "vastrapa": ['mw'],
    "vastraparidhāna": ['mw'],
    "vastrapañjala": ['mw'],
    "vastrapeśī": ['mw'],
    "vastrapeṭā": ['mw'],
    "vastraputrikā": ['mw'],
    "vastrapūta": ['cae', 'mw'],
    "vastrarajaka": ['mw'],
    "vastrarajanī": ['mw'],
    "vastrarañjana": ['mw'],
    "vastraraṅgā": ['mw'],
    "vastravant": ['cae'],
    "vastravat": ['mw'],
    "vastraveśa": ['mw'],
    "vastraveśman": ['cae', 'mw'],
    "vastraveṣṭita": ['mw'],
    "vastravidyā": ['bhs', 'mw'],
    "vastravilāsa": ['mw'],
    "vastravṛtta": ['cae'],
    "vastraya": ['mw'],
    "vastrayati": ['ap90'],
    "vastrayoni": ['cae', 'mw'],
    "vastrayugala": ['mw'],
    "vastrayugin": ['mw'],
    "vastrayugma": ['mw'],
    "vastraṃ": ['ap90'],
    "vastrotkarṣaṇa": ['mw'],
    "vastrā": ['mw'],
    "vastrādhāraka": ['mw'],
    "vastrāgāra": ['mw'],
    "vastrānta": ['cae', 'mw'],
    "vastrāntara": ['cae', 'mw'],
    "vastrāpahāraka": ['cae', 'mw'],
    "vastrāpahārin": ['mw'],
    "vastrāpathakṣetra": ['mw'],
    "vastrārdha": ['mw'],
    "vastrārdhaprāvṛta": ['mw'],
    "vastrārdhasaṃvīta": ['mw'],
    "vastrārdhasaṃvṛta": ['mw'],
    "vastrāvakarta": ['mw'],
    "vastrāy": ['cae'],
    "vastrāya": ['ddsa', 'mw'],
    "vastrāñcala": ['cae', 'ddsa', 'mw'],
    "vastu": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vastubala": ['mw'],
    "vastubheda": ['mw'],
    "vastubhāva": ['mw'],
    "vastubhūta": ['mw'],
    "vastudharma": ['mw'],
    "vastudharmatva": ['mw'],
    "vastudharmin": ['mw'],
    "vastuhāni": ['mw'],
    "vastujāta": ['mw'],
    "vastuka": ['cae', 'mw'],
    "vastukośa": ['mw'],
    "vastukṛta": ['bhs', 'mw'],
    "vastukṣaṇāt": ['mw'],
    "vastumātra": ['mw'],
    "vastunirdeśa": ['mw'],
    "vastupatita": ['mw'],
    "vastuprativikalpavijñāna": ['bhs'],
    "vastupāla": ['mw'],
    "vastupāṇi": ['mw'],
    "vasturacanā": ['cae', 'mw'],
    "vastusaṃgrahaṇī": ['bhs'],
    "vastusthiti": ['mw'],
    "vastutantra": ['mw'],
    "vastutantratva": ['mw'],
    "vastutas": ['ap90', 'cae', 'mw'],
    "vastutattva": ['mw'],
    "vastutattvaprakāśikā": ['mw'],
    "vastutva": ['mw'],
    "vastutā": ['mw'],
    "vastuvat": ['mw'],
    "vastuvicāra": ['mw'],
    "vastuvidyā": ['bhs'],
    "vastuvijñānaratnakośa": ['mw'],
    "vastuvinimaya": ['mw'],
    "vastuvivarta": ['mw'],
    "vastuvṛtta": ['mw'],
    "vastuśakti": ['mw'],
    "vastuśaktitas": ['mw'],
    "vastuśāsana": ['mw'],
    "vastuśūnya": ['mw'],
    "vastv": ['mw'],
    "vastvabhāva": ['mw'],
    "vastvantara": ['mw'],
    "vasty": ['mw'],
    "vastya": ['ddsa', 'mw'],
    "vastyartham": ['mw'],
    "vastyauṣadha": ['mw'],
    "vastyaṃ": ['ap90'],
    "vastī": ['mw'],
    "vastūkī": ['mw'],
    "vastūpahita": ['mw'],
    "vastūpamā": ['cae', 'mw'],
    "vastūtthāpana": ['mw'],
    "vastūtthāpanā": ['ddsa', 'mw'],
    "vastṛ": ['cae', 'gra', 'mw'],
    "vasu": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vasubandhu": ['bhs', 'mw'],
    "vasubha": ['mw'],
    "vasubhadra": ['bhs'],
    "vasubharita": ['mw'],
    "vasubhaṭṭa": ['mw'],
    "vasubhāga": ['mw'],
    "vasubhūta": ['mw'],
    "vasubhūti": ['bhs', 'cae', 'mw'],
    "vasubhṛdyāna": ['mw'],
    "vasucandra": ['mw'],
    "vasucarita": ['mw'],
    "vasucchidrā": ['mw'],
    "vasuda": ['cae', 'mw'],
    "vasudaiva": ['mw'],
    "vasudaivata": ['mw'],
    "vasudatta": ['bhs', 'cae', 'mw'],
    "vasudattaka": ['mw'],
    "vasudattapura": ['mw'],
    "vasudattā": ['mw'],
    "vasudeva": ['cae', 'mw'],
    "vasudevabhū": ['mw'],
    "vasudevabrahmaprasāda": ['mw'],
    "vasudevajanman": ['mw'],
    "vasudevaputra": ['mw'],
    "vasudevata": ['mw'],
    "vasudevatā": ['mw'],
    "vasudevyā": ['mw'],
    "vasudevā": ['mw'],
    "vasudevātmaja": ['mw'],
    "vasudeya": ['cae', 'gra', 'mw'],
    "vasudhara": ['mw'],
    "vasudharman": ['mw'],
    "vasudharmikā": ['mw'],
    "vasudharā": ['mw'],
    "vasudheya": ['cae', 'mw'],
    "vasudhita": ['mw'],
    "vasudhiti": ['cae', 'gra', 'mw'],
    "vasudhā": ['cae', 'cped', 'ddsa', 'mw'],
    "vasudhādhara": ['cae', 'mw'],
    "vasudhādhava": ['mw'],
    "vasudhādhipa": ['cae', 'mw'],
    "vasudhādhipati": ['cae', 'mw'],
    "vasudhādhipatya": ['mw'],
    "vasudhādhātri": ['mw'],
    "vasudhāgama": ['mw'],
    "vasudhākharjūrikā": ['mw'],
    "vasudhāna": ['cae', 'mw'],
    "vasudhānagara": ['mw'],
    "vasudhānāyaka": ['mw'],
    "vasudhāparipālaka": ['mw'],
    "vasudhāpati": ['cae', 'mw'],
    "vasudhāra": ['cae', 'ddsa', 'mw'],
    "vasudhāreṇu": ['mw'],
    "vasudhāriṇī": ['bhs', 'cae', 'mw'],
    "vasudhārā": ['bhs', 'mw'],
    "vasudhārāmaya": ['mw'],
    "vasudhāsuta": ['mw'],
    "vasudhātala": ['cae', 'mw'],
    "vasudhātama": ['mw'],
    "vasudhātara": ['mw'],
    "vasudhātukārikā": ['mw'],
    "vasudhāvilāsin": ['mw'],
    "vasudā": ['cae', 'gra', 'mw'],
    "vasudāma": ['mw'],
    "vasudāman": ['mw'],
    "vasudāmā": ['mw'],
    "vasudāna": ['cae', 'mw'],
    "vasudāvan": ['cae', 'gra', 'mw'],
    "vasugupta": ['mw'],
    "vasuguptācārya": ['mw'],
    "vasuhaṭṭa": ['mw'],
    "vasuhaṭṭaka": ['mw'],
    "vasuhoma": ['mw'],
    "vasujit": ['cae', 'mw'],
    "vasujyeṣṭha": ['mw'],
    "vasuka": ['mw'],
    "vasukalpa": ['mw'],
    "vasukalpadatta": ['mw'],
    "vasukarṇa": ['mw'],
    "vasukaḥ": ['ap90'],
    "vasukra": ['mw'],
    "vasukrapatnī": ['mw'],
    "vasukīṭa": ['mw'],
    "vasukṛmi": ['mw'],
    "vasukṛt": ['ddsa', 'mw'],
    "vasula": ['mw'],
    "vasulakṣmī": ['cae', 'mw'],
    "vasulakṣmīkalyāṇa": ['mw'],
    "vasulaḥ": ['ap90'],
    "vasumadgaṇa": ['mw'],
    "vasumanas": ['mw'],
    "vasumant": ['cae'],
    "vasumat": ['ap90', 'ddsa', 'gra', 'mw'],
    "vasumata": ['bhs'],
    "vasumati": ['bhs', 'ddsa', 'mw'],
    "vasumatiśrī": ['bhs'],
    "vasumattā": ['cae', 'mw'],
    "vasumatī": ['cped', 'mw'],
    "vasumatīcitrasenāvilāsa": ['mw'],
    "vasumatīcitrasenīya": ['mw'],
    "vasumatīcitrāsana": ['mw'],
    "vasumatīpariṇaya": ['mw'],
    "vasumatīpati": ['mw'],
    "vasumatīpṛṣṭha": ['mw'],
    "vasumatīsūnu": ['mw'],
    "vasumaya": ['cae', 'mw'],
    "vasumekhala": ['mw'],
    "vasumitra": ['bhs', 'cae', 'mw'],
    "vasumitrā": ['bhs'],
    "vasumukha": ['bhs'],
    "vasumukhī": ['bhs'],
    "vasuna": ['mw'],
    "vasunanda": ['mw'],
    "vasunandaka": ['mw'],
    "vasundhara": ['ddsa'],
    "vasundharā": ['cped'],
    "vasunemi": ['mw'],
    "vasunetra": ['mw'],
    "vasunāga": ['mw'],
    "vasunītha": ['cae', 'mw'],
    "vasunīti": ['cae', 'mw'],
    "vasupati": ['cae', 'ddsa', 'gra', 'mw'],
    "vasupatnī": ['gra', 'mw'],
    "vasuprabhā": ['mw'],
    "vasuprada": ['mw'],
    "vasuprāṇa": ['mw'],
    "vasupāla": ['mw'],
    "vasupālita": ['mw'],
    "vasupātṛ": ['mw'],
    "vasupūjyarāj": ['mw'],
    "vasura": ['cae', 'mw'],
    "vasurakṣita": ['mw'],
    "vasuratha": ['mw'],
    "vasuraṇva": ['cae', 'mw'],
    "vasuretas": ['cae', 'mw'],
    "vasurocis": ['gra', 'mw'],
    "vasuruc": ['gra', 'mw'],
    "vasuruci": ['mw'],
    "vasurāja": ['mw'],
    "vasurāta": ['mw'],
    "vasurūpa": ['mw'],
    "vasusampatti": ['mw'],
    "vasusampūrṇa": ['mw'],
    "vasusena": ['mw'],
    "vasusthalī": ['mw'],
    "vasusāra": ['mw'],
    "vasusārā": ['mw'],
    "vasutrāta": ['bhs'],
    "vasutti": ['cae', 'gra', 'mw'],
    "vasutva": ['cae', 'gra', 'mw'],
    "vasutvana": ['cae', 'gra', 'mw'],
    "vasutā": ['cae', 'gra', 'mw'],
    "vasutāti": ['cae', 'gra', 'mw'],
    "vasuvallikā": ['mw'],
    "vasuvan": ['mw'],
    "vasuvana": ['mw'],
    "vasuvani": ['cae', 'ddsa', 'gra', 'mw'],
    "vasuvant": ['cae'],
    "vasuvarmadhara": ['mw'],
    "vasuvat": ['mw'],
    "vasuvid": ['cae', 'gra', 'mw'],
    "vasuvinda": ['mw'],
    "vasuvittama": ['mw'],
    "vasuvrata": ['mw'],
    "vasuvāha": ['mw'],
    "vasuvāhana": ['gra', 'mw'],
    "vasuvīrya": ['mw'],
    "vasuvṛṣṭi": ['mw'],
    "vasuśakti": ['cae', 'mw'],
    "vasuśravas": ['cae', 'gra', 'mw'],
    "vasuśreṣṭha": ['mw'],
    "vasuśruta": ['mw'],
    "vasuśrī": ['bhs', 'mw'],
    "vasuṃdhara": ['bhs', 'cae', 'mw'],
    "vasuṃdhareśā": ['mw'],
    "vasuṃdharā": ['ap90', 'bhs', 'mw'],
    "vasuṃdharābhṛt": ['mw'],
    "vasuṃdharādhara": ['mw'],
    "vasuṃdharādhava": ['mw'],
    "vasuṃdharāpṛṣṭha": ['mw'],
    "vasuṃdharāśunāsīra": ['mw'],
    "vasuṣeṇa": ['cae', 'mw'],
    "vasv": ['mw'],
    "vasvananta": ['mw'],
    "vasvanta": ['mw'],
    "vasvaukasārā": ['ddsa', 'mw'],
    "vasvokasārā": ['mw'],
    "vasvī": ['mw'],
    "vasya": ['mw'],
    "vasyaiṣṭi": ['cae', 'gra', 'mw'],
    "vasyas": ['ddsa', 'gra', 'mw'],
    "vasyasa": ['mw'],
    "vasyati": ['bhs'],
    "vasyaṃs": ['cae'],
    "vasyaṣṭi": ['mw'],
    "vasyobhūya": ['mw'],
    "vasā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vasāchaṭā": ['mw'],
    "vasādanī": ['mw'],
    "vasāgraha": ['mw'],
    "vasāhoma": ['cae', 'mw'],
    "vasāhomahavanī": ['mw'],
    "vasāhomaśeṣa": ['mw'],
    "vasāketu": ['mw'],
    "vasāmaya": ['cae', 'ddsa', 'mw'],
    "vasāmeha": ['mw'],
    "vasāmehin": ['mw'],
    "vasāmūra": ['mw'],
    "vasānuga": ['cped'],
    "vasānuvattī": ['cped'],
    "vasāpesi": ['cped'],
    "vasāpeti": ['cped'],
    "vasāpetvā": ['cped'],
    "vasāpita": ['cped'],
    "vasāpāvan": ['cae', 'mw'],
    "vasāpāyin": ['mw'],
    "vasāra": ['mw'],
    "vasāroha": ['mw'],
    "vasāti": ['ddsa', 'mw'],
    "vasātīya": ['mw'],
    "vasāvaśeṣamalina": ['mw'],
    "vasāvi": ['mw'],
    "vasāvī": ['gra', 'mw'],
    "vasāy": ['cae', 'gra'],
    "vasāḍhya": ['mw'],
    "vasāḍhyaka": ['mw'],
    "vasī": ['cped', 'mw'],
    "vasībhāva": ['cped'],
    "vasībhūta": ['cped'],
    "vasīkata": ['cped'],
    "vasīyas": ['ddsa', 'mw'],
    "vasīyaṃs": ['cae'],
    "vasīyobhūya": ['mw'],
    "vasūdreka": ['mw'],
    "vasūjū": ['gra', 'mw'],
    "vasūka": ['mw'],
    "vasūkaḥ": ['ap90'],
    "vasūmatī": ['mw'],
    "vasūpamāna": ['mw'],
    "vasūrā": ['ap90', 'mw'],
    "vasūttama": ['mw'],
    "vasūy": ['cae', 'gra'],
    "vasūya": ['mw'],
    "vasūyu": ['cae', 'ddsa', 'gra', 'mw'],
    "vasūyā": ['cae', 'ddsa', 'gra', 'mw'],
    "vat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vata": ['ap90', 'cped', 'mw'],
    "vatapada": ['cped'],
    "vataraṇī": ['mw'],
    "vatasamādāna": ['cped'],
    "vatavant": ['cped'],
    "vataṃsa": ['cae', 'ddsa', 'mw'],
    "vataṃsaḥ": ['ap90'],
    "vataṃsita": ['mw'],
    "vataṇḍa": ['mw'],
    "vataṇḍī": ['mw'],
    "vathsara": ['mw'],
    "vati": ['cped', 'mw'],
    "vatika": ['cped'],
    "vatikā": ['cped'],
    "vatkula": ['bhs'],
    "vatkāra": ['ddsa', 'mw'],
    "vatokā": ['ap90', 'mw'],
    "vatsa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vatsabandhā": ['mw'],
    "vatsabhaṭṭi": ['mw'],
    "vatsabhūmi": ['cae', 'mw'],
    "vatsabālaka": ['mw'],
    "vatsacchavī": ['mw'],
    "vatsadanta": ['cae', 'mw'],
    "vatsadevī": ['mw'],
    "vatsaguru": ['mw'],
    "vatsahanu": ['mw'],
    "vatsahāra": ['bhs'],
    "vatsajñu": ['mw'],
    "vatsajānu": ['mw'],
    "vatsaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "vatsakaḥ": ['ap90'],
    "vatsakāmā": ['mw'],
    "vatsala": ['ap90', 'cae', 'ddsa', 'mw'],
    "vatsalatva": ['mw'],
    "vatsalatā": ['mw'],
    "vatsalay": ['cae'],
    "vatsalaya": ['ddsa', 'mw'],
    "vatsalayati": ['ap90'],
    "vatsalāñchana": ['mw'],
    "vatsamitra": ['mw'],
    "vatsamitrā": ['mw'],
    "vatsamukha": ['mw'],
    "vatsanapāt": ['cae', 'mw'],
    "vatsanikānta": ['mw'],
    "vatsanābha": ['mw'],
    "vatsanābhi": ['mw'],
    "vatsapa": ['cae', 'mw'],
    "vatsapati": ['cae', 'mw'],
    "vatsapattana": ['mw'],
    "vatsapracetas": ['gra', 'mw'],
    "vatsapri": ['mw'],
    "vatsaprī": ['mw'],
    "vatsaprīti": ['mw'],
    "vatsaprīya": ['mw'],
    "vatsapāla": ['mw'],
    "vatsapālaka": ['mw'],
    "vatsapālana": ['mw'],
    "vatsapītā": ['mw'],
    "vatsara": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vatsaraphala": ['mw'],
    "vatsaraḥ": ['ap90'],
    "vatsarādi": ['mw'],
    "vatsarāja": ['cae', 'ddsa', 'mw'],
    "vatsarājya": ['mw'],
    "vatsarāntaka": ['mw'],
    "vatsarārṇa": ['mw'],
    "vatsarūpa": ['mw'],
    "vatsasmṛti": ['mw'],
    "vatsatantrī": ['cae', 'mw'],
    "vatsatantī": ['cae', 'mw'],
    "vatsatara": ['cae', 'mw'],
    "vatsataraḥ": ['ap90'],
    "vatsatarārṇa": ['mw'],
    "vatsatva": ['mw'],
    "vatsavant": ['cae'],
    "vatsavaradācārya": ['mw'],
    "vatsavat": ['mw'],
    "vatsavinda": ['mw'],
    "vatsavyūha": ['mw'],
    "vatsavṛddha": ['mw'],
    "vatsaśāla": ['mw'],
    "vatsaśālā": ['mw'],
    "vatsaḥ": ['ap90'],
    "vatsaṇurakatīrtha": ['mw'],
    "vatseśa": ['ddsa', 'mw'],
    "vatseśvara": ['cae', 'mw'],
    "vatsikā": ['ap90', 'ddsa', 'mw'],
    "vatsiman": ['mw'],
    "vatsin": ['ap90', 'cae', 'gra', 'mw'],
    "vatsoddharaṇa": ['mw'],
    "vatsya": ['ddsa', 'mw'],
    "vatsā": ['ddsa', 'mw'],
    "vatsādana": ['mw'],
    "vatsādanī": ['mw'],
    "vatsāhvaya": ['mw'],
    "vatsājīva": ['mw'],
    "vatsākṣī": ['mw'],
    "vatsānusāriṇī": ['mw'],
    "vatsānusṛj": ['mw'],
    "vatsānusṛti": ['mw'],
    "vatsānusṛtā": ['mw'],
    "vatsāra": ['mw'],
    "vatsāsura": ['mw'],
    "vatsāya": ['mw'],
    "vatsīputra": ['mw'],
    "vatsīputrīya": ['mw'],
    "vatsīya": ['mw'],
    "vatsīyabālaka": ['mw'],
    "vatsīyaḥ": ['ap90'],
    "vatta": ['cped'],
    "vattabba": ['cped'],
    "vattaka": ['cped'],
    "vattamāna": ['cped'],
    "vattamānaka": ['cped'],
    "vattamānā": ['cped'],
    "vattana": ['cped'],
    "vattanta": ['cped'],
    "vattanā": ['cped'],
    "vattanī": ['cped'],
    "vattapaṭivatta": ['cped'],
    "vattar": ['cped'],
    "vattasampanna": ['cped'],
    "vattati": ['cped'],
    "vattenta": ['cped'],
    "vattesi": ['cped'],
    "vattetabba": ['cped'],
    "vatteti": ['cped'],
    "vattetu": ['cped'],
    "vattetuṁ": ['cped'],
    "vattetvā": ['cped'],
    "vattha": ['cped'],
    "vatthaguyha": ['cped'],
    "vatthantara": ['cped'],
    "vatthayuga": ['cped'],
    "vatthi": ['cped'],
    "vatthikamma": ['cped'],
    "vatthu": ['cped'],
    "vatthudevatā": ['cped'],
    "vatthugāthā": ['cped'],
    "vatthuka": ['cped'],
    "vatthukata": ['cped'],
    "vatthuvijjā": ['cped'],
    "vatti": ['cped'],
    "vattikā": ['cped'],
    "vattita": ['cped'],
    "vattitabba": ['cped'],
    "vattituṁ": ['cped'],
    "vattitvā": ['cped'],
    "vattula": ['bhs'],
    "vattuśiras": ['bhs'],
    "vattuṁ": ['cped'],
    "vattī": ['cped'],
    "vattībhavati": ['bhs'],
    "vatu": ['ddsa', 'mw'],
    "vatvā": ['cped'],
    "vatāyana": ['mw'],
    "vatū": ['mw'],
    "vatūḥ": ['ap90'],
    "vaudanya": ['mw'],
    "vauddha": ['ap90', 'mw'],
    "vaujhaṭ": ['mw'],
    "vauk": ['mw'],
    "vauli": ['mw'],
    "vauṣaṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "vava": ['mw'],
    "vavatthapesi": ['cped'],
    "vavatthapeti": ['cped'],
    "vavatthapetvā": ['cped'],
    "vavatthesi": ['cped'],
    "vavattheti": ['cped'],
    "vavatthetvā": ['cped'],
    "vavatthita": ['cped'],
    "vavatthāpana": ['cped'],
    "vavatthāpita": ['cped'],
    "vaviṣa": ['bhs'],
    "vavra": ['cae', 'ddsa', 'gra', 'mw'],
    "vavraya": ['mw'],
    "vavrayāmahe": ['gra'],
    "vavri": ['cae', 'ddsa', 'gra', 'mw'],
    "vavrivāsas": ['mw'],
    "vavvola": ['mw'],
    "vavāṅga": ['mw'],
    "vavūla": ['mw'],
    "vay": ['ap90', 'mw'],
    "vaya": ['mw'],
    "vayakalyāṇa": ['cped'],
    "vayakaraṇa": ['cped'],
    "vayam": ['ddsa', 'mw'],
    "vayana": ['bhs', 'mw'],
    "vayanaṃ": ['ap90'],
    "vayappatta": ['cped'],
    "vayas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vayasa": ['cae', 'mw'],
    "vayasin": ['ddsa', 'mw'],
    "vayaska": ['cae', 'mw'],
    "vayaskara": ['mw'],
    "vayaskṛt": ['cae', 'gra', 'mw'],
    "vayassa": ['cped'],
    "vayasvant": ['cae'],
    "vayasvat": ['gra', 'mw'],
    "vayasya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vayasyabhāva": ['mw'],
    "vayasyaka": ['mw'],
    "vayasyakatva": ['mw'],
    "vayasyatva": ['mw'],
    "vayasyikā": ['mw'],
    "vayasyā": ['mw'],
    "vayasānvita": ['cae'],
    "vayat": ['ddsa', 'mw'],
    "vayaḥ": ['ap90', 'mw'],
    "vayaḥpariṇati": ['mw'],
    "vayaḥprakarṣa": ['mw'],
    "vayaḥpramāṇa": ['mw'],
    "vayaḥsama": ['cae', 'mw'],
    "vayaḥsandhi": ['ddsa'],
    "vayaḥsaṃdhi": ['mw'],
    "vayaḥsaṃdhimatī": ['mw'],
    "vayaḥstha": ['cae', 'mw'],
    "vayaḥsthā": ['mw'],
    "vayaḥsthāna": ['mw'],
    "vayaḥsthāpana": ['mw'],
    "vayaḥsukha": ['mw'],
    "vayaḥśata": ['mw'],
    "vayaṭṭha": ['cped'],
    "vayha": ['cped'],
    "vayia": ['gra'],
    "vayitrī": ['cae', 'mw'],
    "vayiyu": ['gra', 'mw'],
    "vayo": ['cped', 'mw'],
    "vayobāla": ['cae', 'mw'],
    "vayodhas": ['ap90', 'cae', 'gra', 'mw'],
    "vayodheya": ['cae', 'gra', 'mw'],
    "vayodhika": ['cae', 'mw'],
    "vayodhā": ['ap90', 'cae', 'gra', 'mw'],
    "vayogata": ['ddsa', 'mw'],
    "vayogate": ['mw'],
    "vayohara": ['cped'],
    "vayohāṇi": ['mw'],
    "vayojū": ['gra', 'mw'],
    "vayonurūpa": ['mw'],
    "vayonādha": ['mw'],
    "vayoraṃgaṃ": ['ap90'],
    "vayorūpasamanvita": ['cae', 'mw'],
    "vayotiga": ['cae', 'mw'],
    "vayotīta": ['mw'],
    "vayovasthā": ['cae', 'mw'],
    "vayovaṅga": ['mw'],
    "vayovidha": ['cae', 'mw'],
    "vayovidyā": ['mw'],
    "vayoviśeṣa": ['mw'],
    "vayovuddha": ['cped'],
    "vayovṛddha": ['cae', 'mw'],
    "vayovṛdh": ['cae', 'gra', 'mw'],
    "vayuna": ['cae', 'ddsa', 'gra', 'mw'],
    "vayunavat": ['gra', 'mw'],
    "vayunaśas": ['gra', 'mw'],
    "vayunaṃ": ['ap90'],
    "vayunā": ['gra', 'mw'],
    "vayunādha": ['mw'],
    "vayunādhā": ['mw'],
    "vayunāvat": ['gra'],
    "vayunāvid": ['cae', 'gra', 'mw'],
    "vayya": ['cae', 'ddsa', 'gra', 'mw'],
    "vayā": ['cae', 'ddsa', 'gra', 'mw'],
    "vayāka": ['mw'],
    "vayākaḥ": ['ap90'],
    "vayākin": ['gra', 'mw'],
    "vayāvat": ['gra', 'mw'],
    "vayī": ['cae', 'ddsa', 'mw'],
    "vañc": ['cae', 'ddsa', 'gra', 'mw'],
    "vañcaka": ['cae', 'cped', 'ddsa', 'mw'],
    "vañcana": ['cae', 'cped', 'ddsa', 'mw'],
    "vañcanacañcutā": ['mw'],
    "vañcanapravaṇa": ['mw'],
    "vañcanatā": ['mw'],
    "vañcanavacana": ['cae'],
    "vañcanavat": ['mw'],
    "vañcanayoga": ['mw'],
    "vañcanika": ['cped'],
    "vañcanā": ['cped', 'mw'],
    "vañcanāmati": ['mw'],
    "vañcanāpaṇḍita": ['mw'],
    "vañcanāpaṇḍitatva": ['mw'],
    "vañcanīya": ['cae', 'ddsa', 'mw'],
    "vañcatha": ['mw'],
    "vañcati": ['mw'],
    "vañcayitavya": ['cae', 'mw'],
    "vañcayitṛ": ['cae', 'mw'],
    "vañcenta": ['cped'],
    "vañcesi": ['cped'],
    "vañceti": ['cped'],
    "vañcetvā": ['cped'],
    "vañcin": ['mw'],
    "vañcita": ['cae', 'cped', 'mw'],
    "vañcitaka": ['bhs', 'mw'],
    "vañcitā": ['mw'],
    "vañcuka": ['mw'],
    "vañcya": ['mw'],
    "vañcūka": ['mw'],
    "vañjarā": ['mw'],
    "vañjha": ['cped'],
    "vañjhā": ['cped'],
    "vañjula": ['cae', 'ddsa', 'mw'],
    "vañjuladruma": ['mw'],
    "vañjulaka": ['mw'],
    "vañjulapriya": ['mw'],
    "vañjulikā": ['mw'],
    "vañjulā": ['mw'],
    "vaś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vaśa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vaśaga": ['cae', 'mw'],
    "vaśagamana": ['cae', 'mw'],
    "vaśagata": ['cae', 'mw'],
    "vaśagatva": ['mw'],
    "vaśagā": ['mw'],
    "vaśagāmin": ['mw'],
    "vaśakara": ['ddsa', 'mw'],
    "vaśakriyā": ['mw'],
    "vaśakā": ['ap90', 'mw'],
    "vaśakāraka": ['mw'],
    "vaśana": ['mw'],
    "vaśanī": ['cae', 'ddsa', 'gra', 'mw'],
    "vaśanīta": ['bhs'],
    "vaśanīya": ['mw'],
    "vaśastha": ['mw'],
    "vaśatamā": ['mw'],
    "vaśatas": ['mw'],
    "vaśatva": ['mw'],
    "vaśatā": ['cae', 'mw'],
    "vaśavartana": ['bhs'],
    "vaśavartin": ['bhs', 'cae', 'mw'],
    "vaśavartiyajñayaśayaṣṭimati": ['bhs'],
    "vaśaṃgama": ['mw'],
    "vaśaṃgata": ['mw'],
    "vaśaṃkara": ['mw'],
    "vaśaṃkarī": ['bhs'],
    "vaśaṃkṛta": ['mw'],
    "vaśaṃvada": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaśaṃvadatva": ['mw'],
    "vaśaṃvadita": ['mw'],
    "vaścika": ['mw'],
    "vaśendriya": ['mw'],
    "vaśendriyatva": ['mw'],
    "vaśetar": ['bhs'],
    "vaśi": ['mw'],
    "vaśibhāva": ['bhs'],
    "vaśika": ['ap90', 'bhs', 'ddsa', 'mw'],
    "vaśikā": ['mw'],
    "vaśiman": ['mw'],
    "vaśin": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vaśinī": ['ap90', 'mw'],
    "vaśiprāpta": ['bhs', 'mw'],
    "vaśira": ['mw'],
    "vaśiraḥ": ['ap90'],
    "vaśirāja": ['bhs'],
    "vaśitar": ['bhs'],
    "vaśitva": ['cae', 'ddsa', 'mw'],
    "vaśitā": ['ap90', 'bhs', 'mw'],
    "vaśitṛ": ['mw'],
    "vaśiḥ": ['ap90'],
    "vaśiṣṭha": ['ap90', 'mw'],
    "vaśmasā": ['mw'],
    "vaśya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaśyaka": ['mw'],
    "vaśyakara": ['mw'],
    "vaśyakarman": ['mw'],
    "vaśyakā": ['ap90', 'mw'],
    "vaśyakārin": ['mw'],
    "vaśyatva": ['mw'],
    "vaśyatā": ['mw'],
    "vaśyā": ['mw'],
    "vaśyāpaka": ['bhs'],
    "vaśyātman": ['cae', 'mw'],
    "vaśā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vaśābhoga": ['mw'],
    "vaśāgata": ['mw'],
    "vaśājāta": ['mw'],
    "vaśāku": ['mw'],
    "vaśālā": ['bhs'],
    "vaśāmakha": ['mw'],
    "vaśāmat": ['mw'],
    "vaśānna": ['cae', 'gra', 'mw'],
    "vaśānuga": ['cae', 'ddsa', 'mw'],
    "vaśāpāyin": ['mw'],
    "vaśāroha": ['mw'],
    "vaśātala": ['mw'],
    "vaśāti": ['mw'],
    "vaśātva": ['mw'],
    "vaśāyita": ['mw'],
    "vaśāyāta": ['mw'],
    "vaśāḍhyaka": ['mw'],
    "vaśī": ['ddsa', 'mw'],
    "vaśībhāva": ['bhs'],
    "vaśībhāvaprāpta": ['bhs'],
    "vaśībhū": ['mw'],
    "vaśībhūta": ['bhs', 'mw'],
    "vaśībhūtā": ['bhs'],
    "vaśīkara": ['ddsa', 'mw'],
    "vaśīkaraprakaraṇa": ['mw'],
    "vaśīkaravārāhī": ['mw'],
    "vaśīkaraṇa": ['cae', 'mw'],
    "vaśīkaraṇaṃ": ['ap90'],
    "vaśīkriyā": ['mw'],
    "vaśīkāra": ['cae', 'mw'],
    "vaśīkṛ": ['cae', 'ddsa', 'mw'],
    "vaśīkṛta": ['mw'],
    "vaśīkṛti": ['mw'],
    "vaśīra": ['mw'],
    "vaḍa": ['bhs'],
    "vaḍaba": ['cae', 'mw'],
    "vaḍabadhenu": ['mw'],
    "vaḍabhi": ['cae', 'mw'],
    "vaḍabhiḥ": ['ap90'],
    "vaḍabhā": ['mw'],
    "vaḍabhī": ['cae', 'mw'],
    "vaḍabin": ['mw'],
    "vaḍabā": ['cae', 'ddsa', 'mw'],
    "vaḍabābhartṛ": ['mw'],
    "vaḍabābhṛta": ['mw'],
    "vaḍabāgni": ['cae', 'mw'],
    "vaḍabāgnimala": ['mw'],
    "vaḍabāhṛta": ['mw'],
    "vaḍabāmukha": ['mw'],
    "vaḍabāmukhī": ['mw'],
    "vaḍabānala": ['cae', 'mw'],
    "vaḍabāratha": ['mw'],
    "vaḍabāsuta": ['mw'],
    "vaḍabāvaktra": ['mw'],
    "vaḍabāvaktrahutabhuj": ['mw'],
    "vaḍahaṃsikā": ['mw'],
    "vaḍahaṃsī": ['mw'],
    "vaḍausaka": ['ddsa', 'mw'],
    "vaḍava": ['mw'],
    "vaḍavā": ['ap90', 'ddsa'],
    "vaḍeru": ['mw'],
    "vaḍi": ['bhs'],
    "vaḍika": ['bhs'],
    "vaḍilaṃ": ['ap90'],
    "vaḍiśa": ['cae', 'ddsa', 'mw'],
    "vaḍra": ['ap90', 'mw'],
    "vaḍā": ['ap90', 'mw'],
    "vaḍḍa": ['bhs'],
    "vaḍḍh": ['mw'],
    "vaḍḍha": ['cped'],
    "vaḍḍhaka": ['cped'],
    "vaḍḍhakī": ['cped'],
    "vaḍḍhamāna": ['cped'],
    "vaḍḍhana": ['cped'],
    "vaḍḍhanaka": ['cped'],
    "vaḍḍhanta": ['cped'],
    "vaḍḍhati": ['cped'],
    "vaḍḍhenta": ['cped'],
    "vaḍḍhesi": ['cped'],
    "vaḍḍheti": ['cped'],
    "vaḍḍhetvā": ['cped'],
    "vaḍḍhi": ['cped'],
    "vaḍḍhita": ['cped'],
    "vaḍḍhitvā": ['cped'],
    "vaḍḍībhavati": ['bhs'],
    "vaḷabāmukha": ['cped'],
    "vaḷavā": ['cped'],
    "vaṁsa": ['cped'],
    "vaṁsaja": ['cped'],
    "vaṁsakāḷīra": ['cped'],
    "vaṁsavaṇṇa": ['cped'],
    "vaṁsika": ['cped'],
    "vaṁsāgata": ['cped'],
    "vaṁsānupālaka": ['cped'],
    "vaṃbhaḥ": ['ap90'],
    "vaṃbhāravaḥ": ['ap90'],
    "vaṃc": ['ap90'],
    "vaṃcaka": ['ap90'],
    "vaṃcanaṃ": ['ap90'],
    "vaṃcathaḥ": ['ap90'],
    "vaṃcatiḥ": ['ap90'],
    "vaṃcita": ['ap90'],
    "vaṃcuka": ['ap90'],
    "vaṃd": ['ap90'],
    "vaṃdakaḥ": ['ap90'],
    "vaṃdanaṃ": ['ap90'],
    "vaṃdanīya": ['ap90'],
    "vaṃdathaḥ": ['ap90'],
    "vaṃdhura": ['ap90'],
    "vaṃdhya": ['ap90'],
    "vaṃdin": ['ap90'],
    "vaṃdraḥ": ['ap90'],
    "vaṃdya": ['ap90'],
    "vaṃdā": ['ap90'],
    "vaṃdāru": ['ap90'],
    "vaṃdī": ['ap90'],
    "vaṃg": ['ap90'],
    "vaṃga": ['ap90'],
    "vaṃgh": ['ap90'],
    "vaṃgāḥ": ['ap90'],
    "vaṃh": ['ap90', 'mw'],
    "vaṃhiṣṭha": ['mw'],
    "vaṃhīyas": ['mw'],
    "vaṃjula": ['ap90'],
    "vaṃk": ['ap90'],
    "vaṃkaḥ": ['ap90'],
    "vaṃkilaḥ": ['ap90'],
    "vaṃkriḥ": ['ap90'],
    "vaṃkṣaṇaṃ": ['ap90'],
    "vaṃkṣuḥ": ['ap90'],
    "vaṃsaga": ['cae', 'ddsa', 'gra', 'mw'],
    "vaṃsagaḥ": ['ap90'],
    "vaṃśa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vaṃśabhava": ['mw'],
    "vaṃśabhojya": ['mw'],
    "vaṃśabhāra": ['mw'],
    "vaṃśabhṛt": ['cae', 'mw'],
    "vaṃśabrāhmaṇa": ['cae', 'mw'],
    "vaṃśabāhya": ['mw'],
    "vaṃśacarita": ['mw'],
    "vaṃśacarmakṛt": ['mw'],
    "vaṃśacchettṛ": ['mw'],
    "vaṃśacintaka": ['mw'],
    "vaṃśadalikā": ['bhs'],
    "vaṃśadalā": ['mw'],
    "vaṃśadhara": ['cae', 'mw'],
    "vaṃśadhānya": ['mw'],
    "vaṃśadhārin": ['mw'],
    "vaṃśadhārā": ['mw'],
    "vaṃśaghaṭikā": ['bhs', 'mw'],
    "vaṃśagoptṛ": ['cae', 'mw'],
    "vaṃśagulma": ['mw'],
    "vaṃśagā": ['mw'],
    "vaṃśahīna": ['mw'],
    "vaṃśaja": ['cae', 'mw'],
    "vaṃśaka": ['cae', 'mw'],
    "vaṃśakapha": ['mw'],
    "vaṃśakara": ['cae', 'ddsa', 'mw'],
    "vaṃśakarmakṛt": ['mw'],
    "vaṃśakarman": ['mw'],
    "vaṃśakarpūrarocanā": ['mw'],
    "vaṃśakarā": ['mw'],
    "vaṃśakaḥ": ['ap90'],
    "vaṃśakaṭhina": ['mw'],
    "vaṃśakramāgata": ['mw'],
    "vaṃśakramāhitagaurava": ['mw'],
    "vaṃśakīrti": ['mw'],
    "vaṃśakṛt": ['cae', 'mw'],
    "vaṃśakṛtya": ['cae', 'mw'],
    "vaṃśakṣaya": ['mw'],
    "vaṃśakṣīrī": ['mw'],
    "vaṃśalakṣmī": ['mw'],
    "vaṃśalocanā": ['mw'],
    "vaṃśalūna": ['mw'],
    "vaṃśamaya": ['cae', 'mw'],
    "vaṃśamūla": ['mw'],
    "vaṃśamūlaka": ['mw'],
    "vaṃśamṛnmaya": ['mw'],
    "vaṃśanartin": ['cae', 'mw'],
    "vaṃśanetra": ['mw'],
    "vaṃśaniśreṇī": ['mw'],
    "vaṃśanālikā": ['mw'],
    "vaṃśanātha": ['mw'],
    "vaṃśanāḍikā": ['mw'],
    "vaṃśanāḍī": ['mw'],
    "vaṃśaparamparā": ['mw'],
    "vaṃśapattra": ['mw'],
    "vaṃśapattraharitāla": ['mw'],
    "vaṃśapattraka": ['mw'],
    "vaṃśapattrapatita": ['mw'],
    "vaṃśapattrī": ['mw'],
    "vaṃśapota": ['mw'],
    "vaṃśapratiṣṭhānakāra": ['mw'],
    "vaṃśapuṣpā": ['mw'],
    "vaṃśapātra": ['mw'],
    "vaṃśapātrakāriṇī": ['mw'],
    "vaṃśapīta": ['mw'],
    "vaṃśapūraka": ['mw'],
    "vaṃśarocanā": ['bhs', 'mw'],
    "vaṃśarāga": ['bhs'],
    "vaṃśarāja": ['mw'],
    "vaṃśarājakula": ['mw'],
    "vaṃśarājyadhara": ['mw'],
    "vaṃśasamācāra": ['mw'],
    "vaṃśastanita": ['mw'],
    "vaṃśastha": ['cae', 'mw'],
    "vaṃśasthavila": ['mw'],
    "vaṃśasthiti": ['mw'],
    "vaṃśastūpa": ['mw'],
    "vaṃśataṇḍula": ['mw'],
    "vaṃśavardhana": ['cae', 'mw'],
    "vaṃśavardhin": ['mw'],
    "vaṃśavartin": ['mw'],
    "vaṃśavarṇa": ['mw'],
    "vaṃśavidāriṇī": ['mw'],
    "vaṃśavistara": ['mw'],
    "vaṃśavitati": ['mw'],
    "vaṃśaviśuddha": ['mw'],
    "vaṃśavṛddhi": ['mw'],
    "vaṃśayava": ['mw'],
    "vaṃśaśalākā": ['mw'],
    "vaṃśaśarkarā": ['mw'],
    "vaṃśaḥ": ['ap90'],
    "vaṃśaṛṣi": ['mw'],
    "vaṃśika": ['ap90', 'mw'],
    "vaṃśikā": ['ap90', 'mw'],
    "vaṃśin": ['mw'],
    "vaṃśivādya": ['mw'],
    "vaṃśodbheda": ['mw'],
    "vaṃśya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vaṃśyā": ['mw'],
    "vaṃśyānucarita": ['mw'],
    "vaṃśā": ['mw'],
    "vaṃśāgata": ['ddsa', 'mw'],
    "vaṃśāgra": ['mw'],
    "vaṃśāhva": ['mw'],
    "vaṃśāntara": ['mw'],
    "vaṃśānucarita": ['mw'],
    "vaṃśānuga": ['mw'],
    "vaṃśānukrama": ['mw'],
    "vaṃśānukīrtana": ['mw'],
    "vaṃśānuvaṃśacarita": ['mw'],
    "vaṃśāvalī": ['mw'],
    "vaṃśāvatī": ['mw'],
    "vaṃśāṅkura": ['mw'],
    "vaṃśī": ['ap90', 'ddsa', 'mw'],
    "vaṃśīdhara": ['mw'],
    "vaṃśīdāsa": ['mw'],
    "vaṃśīgīta": ['mw'],
    "vaṃśīrava": ['mw'],
    "vaṃśīvadana": ['mw'],
    "vaṃśīvādya": ['mw'],
    "vaṃśīya": ['cae', 'ddsa', 'mw'],
    "vaṃḍ": ['ap90'],
    "vaṃḍa": ['ap90'],
    "vaṃḍaraḥ": ['ap90'],
    "vaṃḍāla": ['ap90'],
    "vaṃṭ": ['ap90'],
    "vaṃṭa": ['ap90'],
    "vaṃṭakaḥ": ['ap90'],
    "vaṃṭanaṃ": ['ap90'],
    "vaṃṭh": ['ap90'],
    "vaṃṭha": ['ap90'],
    "vaṃṭharaḥ": ['ap90'],
    "vaṃṭālaḥ": ['ap90'],
    "vaṅg": ['mw'],
    "vaṅga": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vaṅgadattavaidyaka": ['mw'],
    "vaṅgadeśa": ['mw'],
    "vaṅgadāsa": ['mw'],
    "vaṅgaja": ['mw'],
    "vaṅgajīvana": ['mw'],
    "vaṅgaka": ['mw'],
    "vaṅgalipi": ['mw'],
    "vaṅgalā": ['mw'],
    "vaṅgana": ['mw'],
    "vaṅgara": ['mw'],
    "vaṅgasena": ['mw'],
    "vaṅgasenaka": ['mw'],
    "vaṅgaśulbaja": ['mw'],
    "vaṅgerikā": ['mw'],
    "vaṅgeśvararasa": ['mw'],
    "vaṅgh": ['mw'],
    "vaṅgha": ['cae', 'mw'],
    "vaṅgiri": ['mw'],
    "vaṅgulā": ['mw'],
    "vaṅgāla": ['bhs', 'mw'],
    "vaṅgālikā": ['mw'],
    "vaṅgālī": ['mw'],
    "vaṅgāri": ['mw'],
    "vaṅgīya": ['mw'],
    "vaṅgṛda": ['cae', 'gra', 'mw'],
    "vaṅk": ['gra', 'mw'],
    "vaṅka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vaṅkaghasta": ['cped'],
    "vaṅkara": ['mw'],
    "vaṅkasena": ['mw'],
    "vaṅkatā": ['cped'],
    "vaṅkaṭaka": ['ddsa', 'mw'],
    "vaṅkh": ['mw'],
    "vaṅkhara": ['mw'],
    "vaṅkharabhaṇḍīratha": ['mw'],
    "vaṅkila": ['mw'],
    "vaṅkimadāsa": ['mw'],
    "vaṅkiṇī": ['mw'],
    "vaṅkri": ['cae', 'ddsa', 'gra', 'mw'],
    "vaṅku": ['cae', 'ddsa', 'gra', 'mw'],
    "vaṅkya": ['cae', 'mw'],
    "vaṅkā": ['ddsa', 'mw'],
    "vaṅkālakācārya": ['mw'],
    "vaṅkālā": ['ddsa', 'mw'],
    "vaṅkṣaṇa": ['cae', 'ddsa', 'mw'],
    "vaṅkṣu": ['mw'],
    "vaṇ": ['ap90', 'mw'],
    "vaṇa": ['cped', 'mw'],
    "vaṇabandhana": ['cped'],
    "vaṇacolaka": ['cped'],
    "vaṇamukha": ['cped'],
    "vaṇapaṭikamma": ['cped'],
    "vaṇathalagrāma": ['mw'],
    "vaṇaḥ": ['ap90'],
    "vaṇaṭ": ['ddsa'],
    "vaṇi": ['bhs'],
    "vaṇibbaka": ['cped'],
    "vaṇig": ['mw'],
    "vaṇigbandhu": ['mw'],
    "vaṇigbhāva": ['mw'],
    "vaṇiggrāma": ['ddsa', 'mw'],
    "vaṇiggṛha": ['mw'],
    "vaṇigjana": ['cae', 'mw'],
    "vaṇigvaha": ['mw'],
    "vaṇigvīthī": ['mw'],
    "vaṇigvṛtti": ['mw'],
    "vaṇij": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vaṇija": ['bhs', 'mw'],
    "vaṇijaka": ['mw'],
    "vaṇijakaḥ": ['ap90'],
    "vaṇijaḥ": ['ap90'],
    "vaṇijjā": ['cped'],
    "vaṇijya": ['bhs', 'ddsa', 'mw'],
    "vaṇijyaṃ": ['ap90'],
    "vaṇijyā": ['cae', 'mw'],
    "vaṇijā": ['mw'],
    "vaṇik": ['mw'],
    "vaṇika": ['bhs'],
    "vaṇikkarman": ['cae', 'mw'],
    "vaṇikkaṭaka": ['ddsa', 'mw'],
    "vaṇikkriyā": ['mw'],
    "vaṇikpatha": ['cae', 'mw'],
    "vaṇikpuruṣa": ['mw'],
    "vaṇikputra": ['cae', 'mw'],
    "vaṇikpīḍā": ['cae'],
    "vaṇiksuta": ['cae', 'mw'],
    "vaṇiksutā": ['mw'],
    "vaṇiksārtha": ['cae', 'mw'],
    "vaṇiksūnu": ['cae', 'mw'],
    "vaṇiktva": ['mw'],
    "vaṇippatha": ['cped'],
    "vaṇiryatha": ['bhs'],
    "vaṇita": ['cped', 'mw'],
    "vaṇiṅ": ['mw'],
    "vaṇiṅmārga": ['mw'],
    "vaṇālā": ['bhs'],
    "vaṇīpaka": ['bhs'],
    "vaṇḍ": ['mw'],
    "vaṇḍara": ['mw'],
    "vaṇḍāla": ['mw'],
    "vaṇṇa": ['cped'],
    "vaṇṇada": ['cped'],
    "vaṇṇadada": ['cped'],
    "vaṇṇadhātu": ['cped'],
    "vaṇṇadāsī": ['cped'],
    "vaṇṇaka": ['cped'],
    "vaṇṇakasiṇa": ['cped'],
    "vaṇṇanā": ['cped'],
    "vaṇṇanīya": ['cped'],
    "vaṇṇapokkharatā": ['cped'],
    "vaṇṇasampanna": ['cped'],
    "vaṇṇavant": ['cped'],
    "vaṇṇavanta": ['cped'],
    "vaṇṇavādī": ['cped'],
    "vaṇṇenta": ['cped'],
    "vaṇṇesi": ['cped'],
    "vaṇṇetabba": ['cped'],
    "vaṇṇeti": ['cped'],
    "vaṇṇetvā": ['cped'],
    "vaṇṇita": ['cped'],
    "vaṇṇu": ['cped'],
    "vaṇṇupatha": ['cped'],
    "vaṇṇī": ['cped'],
    "vaṇṭ": ['mw'],
    "vaṇṭa": ['cae', 'cped', 'ddsa', 'mw'],
    "vaṇṭaka": ['cped', 'mw'],
    "vaṇṭana": ['ddsa', 'mw'],
    "vaṇṭanīya": ['mw'],
    "vaṇṭh": ['mw'],
    "vaṇṭha": ['cae', 'ddsa', 'mw'],
    "vaṇṭhara": ['mw'],
    "vaṇṭhāla": ['mw'],
    "vaṇṭika": ['cped'],
    "vaṇṭita": ['mw'],
    "vaṇṭāla": ['mw'],
    "vaṣ": ['ap90', 'mw'],
    "vaṣaṭ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vaṣaṭkaraṇa": ['mw'],
    "vaṣaṭkartṛ": ['cae', 'mw'],
    "vaṣaṭkriyā": ['mw'],
    "vaṣaṭkāra": ['cae', 'ddsa', 'mw'],
    "vaṣaṭkārakriyā": ['mw'],
    "vaṣaṭkāranidhana": ['mw'],
    "vaṣaṭkārin": ['cae', 'mw'],
    "vaṣaṭkṛta": ['cae', 'gra', 'mw'],
    "vaṣaṭkṛti": ['cae', 'gra', 'mw'],
    "vaṣaṭkṛtya": ['mw'],
    "vaṣk": ['ap90', 'mw'],
    "vaṣkaya": ['mw'],
    "vaṣkayaḥ": ['ap90'],
    "vaṣkayaṇī": ['ap90'],
    "vaṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "vaṭ": ['ap90', 'ddsa', 'mw'],
    "vaṭa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vaṭaja": ['mw'],
    "vaṭaka": ['cae', 'mw'],
    "vaṭakalikā": ['mw'],
    "vaṭakaḥ": ['ap90'],
    "vaṭakaṇikā": ['mw'],
    "vaṭakaṇīkā": ['mw'],
    "vaṭakaṇīya": ['mw'],
    "vaṭakinī": ['mw'],
    "vaṭakā": ['mw'],
    "vaṭanagara": ['mw'],
    "vaṭapattra": ['mw'],
    "vaṭapattrā": ['mw'],
    "vaṭapattrī": ['mw'],
    "vaṭara": ['ap90', 'mw'],
    "vaṭarukkha": ['cped'],
    "vaṭasāvitrīpūjā": ['mw'],
    "vaṭasāvitrīvrata": ['mw'],
    "vaṭasāvitrīvratakālanirṇaya": ['mw'],
    "vaṭatīrthanātha": ['mw'],
    "vaṭatīrthanāthamahātmya": ['mw'],
    "vaṭavatī": ['mw'],
    "vaṭavāsin": ['mw'],
    "vaṭayakṣiṇītīrtha": ['mw'],
    "vaṭaḥ": ['ap90'],
    "vaṭaṁsaka": ['cped'],
    "vaṭeśa": ['mw'],
    "vaṭeśvara": ['ddsa', 'mw'],
    "vaṭeśvaradatta": ['mw'],
    "vaṭeśvaramāhātmya": ['mw'],
    "vaṭeśvarasiddhānta": ['mw'],
    "vaṭh": ['ap90', 'mw'],
    "vaṭhara": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vaṭi": ['mw'],
    "vaṭibha": ['mw'],
    "vaṭika": ['bhs', 'mw'],
    "vaṭikaḥ": ['ap90'],
    "vaṭikā": ['ap90', 'ddsa', 'mw'],
    "vaṭin": ['ap90', 'mw'],
    "vaṭku": ['mw'],
    "vaṭodakā": ['mw'],
    "vaṭu": ['mw'],
    "vaṭukaḥ": ['ap90'],
    "vaṭuma": ['cped'],
    "vaṭurin": ['ap90'],
    "vaṭuḥ": ['ap90'],
    "vaṭya": ['mw'],
    "vaṭākara": ['mw'],
    "vaṭākaraḥ": ['ap90'],
    "vaṭāku": ['mw'],
    "vaṭāraka": ['ddsa', 'mw'],
    "vaṭārakamaya": ['mw'],
    "vaṭārakā": ['cae'],
    "vaṭāraṇyamāhātmya": ['mw'],
    "vaṭāvīka": ['mw'],
    "vaṭāśraya": ['mw'],
    "vaṭāśvatthavivāha": ['mw'],
    "vaṭī": ['ap90', 'mw'],
    "vaṭūrin": ['gra', 'mw'],
    "vaṭṭ": ['mw'],
    "vaṭṭa": ['bhs', 'cped', 'ddsa', 'mw'],
    "vaṭṭaka": ['mw'],
    "vaṭṭakā": ['cped'],
    "vaṭṭana": ['cped'],
    "vaṭṭanā": ['bhs'],
    "vaṭṭapāsaka": ['bhs'],
    "vaṭṭati": ['cped'],
    "vaṭṭesi": ['cped'],
    "vaṭṭeti": ['cped'],
    "vaṭṭetvā": ['cped'],
    "vaṭṭha": ['cped'],
    "vaṭṭi": ['cped'],
    "vaṭṭikā": ['cped'],
    "vaṭṭita": ['bhs', 'cped'],
    "vaṭṭula": ['cped'],
    "ve": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vebhaḍiṅga": ['bhs'],
    "vebhaṅgiya": ['cped'],
    "vecurāma": ['mw'],
    "vecā": ['ap90', 'mw'],
    "vecārāma": ['mw'],
    "veda": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vedabhāga": ['mw'],
    "vedabhāgādi": ['mw'],
    "vedabhāṣya": ['mw'],
    "vedabhāṣyakāra": ['mw'],
    "vedabrahmacarya": ['cae', 'mw'],
    "vedabrāhmaṇa": ['mw'],
    "vedabāhu": ['mw'],
    "vedabāhya": ['cae', 'mw'],
    "vedabīja": ['mw'],
    "vedacakṣus": ['mw'],
    "vedadakṣiṇā": ['mw'],
    "vedadala": ['mw'],
    "vedadarśana": ['mw'],
    "vedadarśin": ['cae', 'mw'],
    "vedadhara": ['mw'],
    "vedadharma": ['mw'],
    "vedadhvani": ['mw'],
    "vedadhāraṇa": ['mw'],
    "vedadāna": ['mw'],
    "vedadīpa": ['mw'],
    "vedadīpikā": ['mw'],
    "vedadṛṣṭa": ['mw'],
    "vedagaccha": ['bhs'],
    "vedagarbha": ['mw'],
    "vedagarbharāśi": ['mw'],
    "vedagarbhā": ['mw'],
    "vedagarbhāmāhātmya": ['mw'],
    "vedagarbhāpurīmāhātmya": ['mw'],
    "vedagarva": ['mw'],
    "vedagata": ['mw'],
    "vedaghoṣa": ['mw'],
    "vedaguhya": ['mw'],
    "vedaguhyopaniṣad": ['mw'],
    "vedagupta": ['mw'],
    "vedagupti": ['mw'],
    "vedagāmbhīrya": ['mw'],
    "vedagātha": ['mw'],
    "vedagū": ['cped'],
    "vedahīna": ['mw'],
    "vedajananī": ['mw'],
    "vedajña": ['cae', 'mw'],
    "vedajāta": ['cped'],
    "vedaka": ['bhs', 'cped', 'ddsa', 'mw'],
    "vedakartṛ": ['mw'],
    "vedakauleyaka": ['mw'],
    "vedakavisvāmin": ['mw'],
    "vedakumbha": ['mw'],
    "vedakuśala": ['mw'],
    "vedakā": ['mw'],
    "vedakāra": ['mw'],
    "vedakāraṇakāraṇa": ['mw'],
    "vedalakṣaṇa": ['mw'],
    "vedalakṣaṇasūtravṛtti": ['mw'],
    "vedalī": ['bhs'],
    "vedam": ['mw'],
    "vedamantra": ['mw'],
    "vedamantradaṇḍaka": ['mw'],
    "vedamantrānukramaṇikā": ['mw'],
    "vedamantrārthadīpikā": ['mw'],
    "vedamaya": ['mw'],
    "vedamitra": ['mw'],
    "vedamukha": ['mw'],
    "vedamukhya": ['mw'],
    "vedamuṇḍa": ['mw'],
    "vedamuṇḍavadha": ['mw'],
    "vedamāhātmya": ['mw'],
    "vedamāli": ['mw'],
    "vedamātṛ": ['mw'],
    "vedamātṛkā": ['mw'],
    "vedamātṛṭīkā": ['mw'],
    "vedamūla": ['mw'],
    "vedamūrti": ['mw'],
    "vedana": ['cae', 'ddsa', 'gra', 'mw'],
    "vedanaṃ": ['ap90'],
    "vedanidhi": ['mw'],
    "vedanidhitīrtha": ['mw'],
    "vedanighaṇṭu": ['mw'],
    "vedanindaka": ['cae', 'ddsa', 'mw'],
    "vedanindin": ['mw'],
    "vedanindā": ['cae', 'mw'],
    "vedanirghoṣa": ['mw'],
    "vedantagū": ['cped'],
    "vedanā": ['bhs', 'cped', 'mw'],
    "vedanābhinna": ['bhs'],
    "vedanāda": ['mw'],
    "vedanākkhandha": ['cped'],
    "vedanāvat": ['mw'],
    "vedanī": ['ap90', 'mw'],
    "vedanīya": ['mw'],
    "vedanīyatva": ['mw'],
    "vedanīyatā": ['mw'],
    "vedapadadarpaṇa": ['mw'],
    "vedapadastava": ['mw'],
    "vedapatha": ['mw'],
    "vedapathin": ['mw'],
    "vedapaṭhitṛ": ['mw'],
    "vedaphala": ['cae', 'mw'],
    "vedaplāvin": ['mw'],
    "vedapradāna": ['cae', 'mw'],
    "vedaprakāśa": ['mw'],
    "vedapralava": ['mw'],
    "vedaprapad": ['mw'],
    "vedapravāda": ['mw'],
    "vedapuruṣa": ['mw'],
    "vedapuṇya": ['cae', 'mw'],
    "vedapādarāmāyaṇa": ['mw'],
    "vedapādastava": ['mw'],
    "vedapādastotra": ['mw'],
    "vedapādaśivastotra": ['mw'],
    "vedapāraga": ['cae', 'mw'],
    "vedapāragū": ['cped'],
    "vedapārāyaṇavidhi": ['mw'],
    "vedapāṭha": ['mw'],
    "vedapāṭhaka": ['mw'],
    "vedapāṭhin": ['mw'],
    "vedarahasya": ['cae', 'ddsa', 'mw'],
    "vedarakara": ['mw'],
    "vedarakṣaṇa": ['mw'],
    "vedarkara": ['mw'],
    "vedarāta": ['mw'],
    "vedarāśi": ['mw'],
    "vedarāśikṛtastotra": ['mw'],
    "vedas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vedasa": ['cae', 'mw'],
    "vedasamarthana": ['mw'],
    "vedasammata": ['mw'],
    "vedasammita": ['mw'],
    "vedasamāpti": ['mw'],
    "vedasaṃhitā": ['cae', 'ddsa', 'mw'],
    "vedasaṃnyāsa": ['mw'],
    "vedasaṃnyāsika": ['cae', 'mw'],
    "vedasaṃnyāsin": ['mw'],
    "vedasaṃsthita": ['mw'],
    "vedasinī": ['mw'],
    "vedasmṛti": ['mw'],
    "vedasmṛtā": ['mw'],
    "vedasmṛtī": ['mw'],
    "vedasparśa": ['mw'],
    "vedastaraṇa": ['mw'],
    "vedastuti": ['mw'],
    "vedastutikārikā": ['mw'],
    "vedastutilaghūpāya": ['mw'],
    "vedasvāmin": ['mw'],
    "vedasāra": ['mw'],
    "vedasārarahasya": ['mw'],
    "vedasārasahasranāman": ['mw'],
    "vedasāraśivasahasranāman": ['mw'],
    "vedasāraśivastava": ['mw'],
    "vedasāraśivastotra": ['mw'],
    "vedasūktabhāṣya": ['mw'],
    "vedasūtra": ['mw'],
    "vedataijasa": ['mw'],
    "vedatattva": ['cae', 'mw'],
    "vedatattvārtha": ['cae', 'mw'],
    "vedatattvārthavid": ['mw'],
    "vedatattvārthavidvas": ['mw'],
    "vedatraya": ['mw'],
    "vedatrayī": ['mw'],
    "vedatva": ['mw'],
    "vedatā": ['cae', 'gra', 'mw'],
    "vedatātparya": ['mw'],
    "vedatṛṇa": ['mw'],
    "vedavacana": ['mw'],
    "vedavadana": ['mw'],
    "vedavaināśikā": ['mw'],
    "vedavant": ['cae'],
    "vedavat": ['mw'],
    "vedavatī": ['mw'],
    "vedavedāntatattvasāreśālagrāmamāhātmya": ['mw'],
    "vedavedāṅga": ['mw'],
    "vedavedāṅgapāraga": ['cae', 'mw'],
    "vedavedāṅgatattvajña": ['mw'],
    "vedavedāṅgavid": ['cae', 'mw'],
    "vedavedāṅgavigrahin": ['mw'],
    "vedavicāra": ['mw'],
    "vedavid": ['cae', 'mw'],
    "vedavidvas": ['mw'],
    "vedavidvaṃs": ['cae'],
    "vedavidyā": ['cae', 'mw'],
    "vedavidyādhigama": ['mw'],
    "vedavidyādhipa": ['mw'],
    "vedavidyātmaka": ['mw'],
    "vedavidyāvid": ['mw'],
    "vedavidyāvratasnāta": ['mw'],
    "vedavihita": ['mw'],
    "vedavikraya": ['mw'],
    "vedavikrayin": ['mw'],
    "vedavilāsinī": ['mw'],
    "vedaviplāvaka": ['mw'],
    "vedavittva": ['mw'],
    "vedavrata": ['mw'],
    "vedavrataparāyaṇa": ['mw'],
    "vedavratavidhi": ['mw'],
    "vedavratin": ['mw'],
    "vedavyāsa": ['mw'],
    "vedavyāsasvāmin": ['mw'],
    "vedavyāsatīrtha": ['mw'],
    "vedavāda": ['mw'],
    "vedavādarata": ['mw'],
    "vedavādin": ['mw'],
    "vedavāha": ['mw'],
    "vedavāhana": ['mw'],
    "vedavāhya": ['mw'],
    "vedavākya": ['mw'],
    "vedavāsa": ['mw'],
    "vedavṛddha": ['mw'],
    "vedavṛtta": ['mw'],
    "vedaya": ['mw'],
    "vedayajña": ['cae', 'mw'],
    "vedayajñamaya": ['mw'],
    "vedayaṣṭi": ['mw'],
    "vedayita": ['bhs', 'cped'],
    "vedayitavya": ['mw'],
    "vedayitṛ": ['cae', 'ddsa', 'mw'],
    "vedayitṛka": ['bhs'],
    "vedayāna": ['mw'],
    "vedaśabda": ['mw'],
    "vedaśira": ['mw'],
    "vedaśiras": ['mw'],
    "vedaśirobhūṣaṇa": ['mw'],
    "vedaśravas": ['mw'],
    "vedaśruta": ['mw'],
    "vedaśruti": ['mw'],
    "vedaśrī": ['mw'],
    "vedaśākhā": ['mw'],
    "vedaśākhāpraṇayana": ['mw'],
    "vedaśāstra": ['cae', 'mw'],
    "vedaśāstrapurāṇa": ['mw'],
    "vedaśāstrasampanna": ['mw'],
    "vedaśāstravid": ['mw'],
    "vedaśīrṣa": ['mw'],
    "vedaḥ": ['ap90'],
    "vedaṃḍaḥ": ['ap90'],
    "vedaṇḍa": ['mw'],
    "veddhavya": ['mw'],
    "veddhṛ": ['cae', 'ddsa', 'mw'],
    "vedeha": ['cped'],
    "vedehīputta": ['cped'],
    "vedenta": ['cped'],
    "vedesi": ['cped'],
    "vedeti": ['cped'],
    "vedetvā": ['cped'],
    "vedeśa": ['mw'],
    "vedeśabhikṣu": ['mw'],
    "vedeśatīrtha": ['mw'],
    "vedeśvara": ['mw'],
    "vedh": ['mw'],
    "vedha": ['cae', 'cped', 'ddsa', 'mw'],
    "vedhagupta": ['mw'],
    "vedhaka": ['cae', 'mw'],
    "vedhakaḥ": ['ap90'],
    "vedhamaya": ['mw'],
    "vedhamukhya": ['mw'],
    "vedhamukhyaka": ['mw'],
    "vedhamukhyā": ['mw'],
    "vedhana": ['cae', 'cped', 'mw'],
    "vedhanaṃ": ['ap90'],
    "vedhanikā": ['ap90', 'mw'],
    "vedhanī": ['ap90', 'mw'],
    "vedhanīya": ['bhs', 'mw'],
    "vedhas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vedhasa": ['mw'],
    "vedhasaṃ": ['ap90'],
    "vedhastama": ['mw'],
    "vedhasyā": ['cae', 'gra', 'mw'],
    "vedhasī": ['mw'],
    "vedhati": ['bhs', 'cped'],
    "vedhaḥ": ['ap90'],
    "vedhi": ['cped'],
    "vedhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "vedhinī": ['mw'],
    "vedhita": ['ap90', 'cae', 'cped', 'mw'],
    "vedhitva": ['mw'],
    "vedhya": ['bhs', 'cae', 'mw'],
    "vedhyatā": ['mw'],
    "vedhyaṃ": ['ap90'],
    "vedhyā": ['mw'],
    "vedhā": ['mw'],
    "vedhī": ['cped'],
    "vedi": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vedia": ['gra'],
    "vedibhājana": ['mw'],
    "vedijā": ['mw'],
    "vedika": ['mw'],
    "vedikaraṇa": ['mw'],
    "vedikā": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "vedikākrama": ['mw'],
    "vedilakṣaṇa": ['mw'],
    "vediloṣṭa": ['mw'],
    "vedimadhya": ['mw'],
    "vedimatī": ['mw'],
    "vedimekhalā": ['mw'],
    "vedimāna": ['mw'],
    "vedin": ['ap90', 'cae', 'mw'],
    "vedinī": ['mw'],
    "vedipara": ['mw'],
    "vedipratiṣṭha": ['mw'],
    "vedipurīṣa": ['cae', 'ddsa', 'mw'],
    "vedisambhavā": ['mw'],
    "vedisammāna": ['mw'],
    "vedispṛś": ['mw'],
    "vedisādhanaprakāra": ['mw'],
    "vedita": ['ap90', 'bhs', 'cped'],
    "veditabba": ['cped'],
    "veditavya": ['cae', 'mw'],
    "veditva": ['mw'],
    "veditā": ['mw'],
    "veditṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "vedivat": ['mw'],
    "vedivimāna": ['mw'],
    "vediyamāna": ['cped'],
    "vediyati": ['cped'],
    "vediā": ['gra'],
    "vediśroṇi": ['mw'],
    "vediśroṇī": ['mw'],
    "vediḥ": ['ap90'],
    "vediṣad": ['cae', 'gra', 'mw'],
    "vediṣṭha": ['cae', 'gra', 'mw'],
    "vedodaya": ['mw'],
    "vedodita": ['cae', 'mw'],
    "vedokta": ['cae', 'ddsa', 'mw'],
    "vedoktaśivapūjana": ['mw'],
    "vedopabṛṃhaṇa": ['mw'],
    "vedopagrahaṇa": ['mw'],
    "vedopakaraṇa": ['cae', 'mw'],
    "vedopakaraṇasamūha": ['mw'],
    "vedopaniṣad": ['mw'],
    "vedopasthānikā": ['mw'],
    "vedopayāma": ['mw'],
    "veduka": ['cae', 'mw'],
    "vedy": ['mw'],
    "vedya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vedyagni": ['mw'],
    "vedyanta": ['mw'],
    "vedyantara": ['mw'],
    "vedyardha": ['mw'],
    "vedyatva": ['mw'],
    "vedyayā": ['mw'],
    "vedyupoṣaṇa": ['mw'],
    "vedyā": ['cae', 'ddsa', 'gra', 'mw'],
    "vedyākṛti": ['cae', 'mw'],
    "vedyāramitāḥ": ['bhs'],
    "vedyāstaraṇa": ['mw'],
    "vedā": ['mw'],
    "vedābhyāsa": ['cae', 'ddsa', 'mw'],
    "vedācārya": ['mw'],
    "vedādhideva": ['mw'],
    "vedādhigama": ['cae', 'mw'],
    "vedādhipa": ['mw'],
    "vedādhipati": ['mw'],
    "vedādhyakṣa": ['mw'],
    "vedādhyayana": ['cae', 'mw'],
    "vedādhyayin": ['mw'],
    "vedādhyāpaka": ['mw'],
    "vedādhyāpana": ['mw'],
    "vedādhyāya": ['cae', 'mw'],
    "vedādhyāyin": ['cae', 'mw'],
    "vedādi": ['cae', 'mw'],
    "vedādibīja": ['mw'],
    "vedādirūpa": ['mw'],
    "vedādivarṇa": ['mw'],
    "vedāgnyutsādin": ['mw'],
    "vedāgraṇī": ['mw'],
    "vedānadhyayana": ['cae', 'mw'],
    "vedānadhyāya": ['mw'],
    "vedānta": ['cae', 'ddsa', 'mw'],
    "vedāntabhāṣya": ['mw'],
    "vedāntabhūṣaṇa": ['mw'],
    "vedāntacandrikā": ['mw'],
    "vedāntacintāmaṇi": ['mw'],
    "vedāntadeśika": ['mw'],
    "vedāntadiṇḍima": ['mw'],
    "vedāntadīpa": ['mw'],
    "vedāntadīpikā": ['mw'],
    "vedāntaga": ['mw'],
    "vedāntagamya": ['mw'],
    "vedāntagrantha": ['mw'],
    "vedāntajña": ['mw'],
    "vedāntakalpadruma": ['mw'],
    "vedāntakalpalatikā": ['mw'],
    "vedāntakalpalatā": ['mw'],
    "vedāntakalpataru": ['mw'],
    "vedāntakalpatarumañjarī": ['mw'],
    "vedāntakalpataruparimala": ['mw'],
    "vedāntakalpataruparimalakhaṇḍana": ['mw'],
    "vedāntakalpataruṭīkā": ['mw'],
    "vedāntakartṛ": ['mw'],
    "vedāntakataka": ['mw'],
    "vedāntakathāratna": ['mw'],
    "vedāntakaumudī": ['mw'],
    "vedāntakaustubha": ['mw'],
    "vedāntakaustubhaprabhā": ['mw'],
    "vedāntakārikāvali": ['mw'],
    "vedāntakṛt": ['cae', 'mw'],
    "vedāntamanana": ['mw'],
    "vedāntamantraviśrāma": ['mw'],
    "vedāntamaṅgaladīpikā": ['mw'],
    "vedāntamuktāvalī": ['mw'],
    "vedāntamālā": ['mw'],
    "vedāntanayanabhūṣaṇa": ['mw'],
    "vedāntanayanācārya": ['mw'],
    "vedāntanirṇaya": ['mw'],
    "vedāntaniṣṭha": ['mw'],
    "vedāntanyāyamālā": ['mw'],
    "vedāntanyāyaratnāvalībrahmādvaitāmṛtaprakāśikā": ['mw'],
    "vedāntanāmaratnasahasravyākhyāna": ['mw'],
    "vedāntapadārthasaṃgraha": ['mw'],
    "vedāntaparibhāṣā": ['mw'],
    "vedāntaparimala": ['mw'],
    "vedāntapradīpa": ['mw'],
    "vedāntaprakaraṇa": ['mw'],
    "vedāntaprakaraṇavākyāmṛta": ['mw'],
    "vedāntaprakriyā": ['mw'],
    "vedāntapraṇihitadhī": ['mw'],
    "vedāntapārijātasaurabha": ['mw'],
    "vedāntarahasya": ['mw'],
    "vedāntarahasyadīpikā": ['mw'],
    "vedāntarahasyavettṛ": ['mw'],
    "vedāntarakṣā": ['mw'],
    "vedāntaratna": ['mw'],
    "vedāntaratnakośa": ['mw'],
    "vedāntaratnamañjūṣā": ['mw'],
    "vedāntaratnamālā": ['mw'],
    "vedāntaratnatrayaparīkṣā": ['mw'],
    "vedāntaratnākara": ['mw'],
    "vedāntasammatakarmatattva": ['mw'],
    "vedāntasaptasūtra": ['mw'],
    "vedāntasaurabha": ['mw'],
    "vedāntasaṃgraha": ['mw'],
    "vedāntasaṃjñā": ['mw'],
    "vedāntasaṃjñānirūpaṇa": ['mw'],
    "vedāntasaṃjñāprakriyā": ['mw'],
    "vedāntasiddhānta": ['mw'],
    "vedāntasiddhāntabheda": ['mw'],
    "vedāntasiddhāntacandrikā": ['mw'],
    "vedāntasiddhāntadīpikā": ['mw'],
    "vedāntasiddhāntakaumudī": ['mw'],
    "vedāntasiddhāntamuktāvalī": ['mw'],
    "vedāntasiddhāntapradīpa": ['mw'],
    "vedāntasiddhāntaratnāñjali": ['mw'],
    "vedāntasiddhāntasūktimañjarīprakāśa": ['mw'],
    "vedāntasiṃha": ['mw'],
    "vedāntasudhārahasya": ['mw'],
    "vedāntasyamantaka": ['mw'],
    "vedāntasāra": ['cae', 'mw'],
    "vedāntasārapadyamālā": ['mw'],
    "vedāntasārasaṃgraha": ['mw'],
    "vedāntasārasiddhāntatātparya": ['mw'],
    "vedāntasārasāra": ['mw'],
    "vedāntasāraviśrāmopaniṣad": ['mw'],
    "vedāntasāropaniṣad": ['mw'],
    "vedāntasūtra": ['mw'],
    "vedāntasūtramuktāvalī": ['mw'],
    "vedāntasūtravṛttisaṃkṣiptā": ['mw'],
    "vedāntatattva": ['mw'],
    "vedāntatattvabodha": ['mw'],
    "vedāntatattvadīpana": ['mw'],
    "vedāntatattvakaumudī": ['mw'],
    "vedāntatattvamuktāvalī": ['mw'],
    "vedāntatattvasāra": ['mw'],
    "vedāntatattvodaya": ['mw'],
    "vedāntatātparya": ['mw'],
    "vedāntavedin": ['mw'],
    "vedāntavibhāvanā": ['mw'],
    "vedāntavid": ['cae', 'mw'],
    "vedāntavidyā": ['mw'],
    "vedāntavidyāsāgara": ['mw'],
    "vedāntavidyāvijaya": ['mw'],
    "vedāntavijaya": ['mw'],
    "vedāntavijñāna": ['mw'],
    "vedāntavijñānanaukā": ['mw'],
    "vedāntavilāsa": ['mw'],
    "vedāntavivaraṇa": ['mw'],
    "vedāntaviveka": ['mw'],
    "vedāntavivekacūḍāmaṇi": ['mw'],
    "vedāntavāda": ['mw'],
    "vedāntavādin": ['mw'],
    "vedāntavādārtha": ['mw'],
    "vedāntavādāvali": ['mw'],
    "vedāntavāgīśa": ['mw'],
    "vedāntavākya": ['mw'],
    "vedāntavākyacūḍāmaṇi": ['mw'],
    "vedāntavārttika": ['mw'],
    "vedāntavṛtti": ['mw'],
    "vedāntaśataślokī": ['mw'],
    "vedāntaśikhāmaṇi": ['mw'],
    "vedāntaśiromaṇi": ['mw'],
    "vedāntaśrutisārasaṃgraha": ['mw'],
    "vedāntaśāstra": ['mw'],
    "vedāntaśāstrasaṃkṣiptaprakriyā": ['mw'],
    "vedāntaśāstrāmbudhiratna": ['mw'],
    "vedāntibruva": ['mw'],
    "vedāntimahādeva": ['mw'],
    "vedāntin": ['cae', 'ddsa', 'mw'],
    "vedāntopadeśa": ['mw'],
    "vedāntopagata": ['mw'],
    "vedāntopaniṣad": ['mw'],
    "vedāntopanyāsa": ['mw'],
    "vedāntābhihita": ['mw'],
    "vedāntācārya": ['mw'],
    "vedāntācāryacaritra": ['mw'],
    "vedāntācāryadinacaryā": ['mw'],
    "vedāntācāryamaṅgaladvādaśī": ['mw'],
    "vedāntācāryaprapadana": ['mw'],
    "vedāntācāryasaptati": ['mw'],
    "vedāntācāryatārāhārāvalī": ['mw'],
    "vedāntācāryavigrahadhyānapaddhati": ['mw'],
    "vedāntācāryavijaya": ['mw'],
    "vedāntādhikaraṇacintāmaṇi": ['mw'],
    "vedāntādhikaraṇamālā": ['mw'],
    "vedāntāloka": ['mw'],
    "vedāntāmṛta": ['mw'],
    "vedāntāmṛtacidratnacaṣaka": ['mw'],
    "vedāntārtha": ['mw'],
    "vedāntārthasaṃgraha": ['mw'],
    "vedāntārthasārasaṃgraha": ['mw'],
    "vedāntārthavivecanamahābhāṣya": ['mw'],
    "vedāntāvabhṛthapluta": ['mw'],
    "vedānukramaṇikā": ['mw'],
    "vedānusmṛti": ['mw'],
    "vedānuvacana": ['cae', 'mw'],
    "vedāpaya": ['mw'],
    "vedāpayati": ['ap90'],
    "vedāpti": ['mw'],
    "vedāra": ['mw'],
    "vedārambhaprayoga": ['mw'],
    "vedāraḥ": ['ap90'],
    "vedāraṇyamāhātmya": ['mw'],
    "vedārtha": ['cae', 'ddsa', 'mw'],
    "vedārthacandra": ['mw'],
    "vedārthadīpa": ['mw'],
    "vedārthadīpikā": ['mw'],
    "vedārthanighaṇṭu": ['mw'],
    "vedārthapradīpa": ['mw'],
    "vedārthapradīpikā": ['mw'],
    "vedārthaprakāśa": ['mw'],
    "vedārthaprakāśikā": ['mw'],
    "vedārtharatna": ['mw'],
    "vedārthasaṃgraha": ['mw'],
    "vedārthatattvanirṇaya": ['mw'],
    "vedārthavicāra": ['mw'],
    "vedārthavid": ['mw'],
    "vedārthayatna": ['mw'],
    "vedārṇa": ['mw'],
    "vedātman": ['mw'],
    "vedātmana": ['mw'],
    "vedāvatāra": ['mw'],
    "vedāvāpti": ['mw'],
    "vedāyana": ['mw'],
    "vedāśra": ['mw'],
    "vedāśvā": ['mw'],
    "vedāṃśa": ['mw'],
    "vedāṅga": ['cae', 'ddsa', 'mw'],
    "vedāṅgarāya": ['mw'],
    "vedāṅgatva": ['mw'],
    "vedāṅgatīrtha": ['mw'],
    "vedāṅgaśāstra": ['mw'],
    "vedāṅgin": ['mw'],
    "vedī": ['cae', 'cped', 'ddsa', 'mw'],
    "vedīka": ['mw'],
    "vedīyas": ['ddsa', 'gra', 'mw'],
    "vedīyaṃs": ['cae'],
    "vedīśa": ['mw'],
    "vega": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vegadarśin": ['mw'],
    "vegadaṇḍa": ['mw'],
    "vegadhārin": ['bhs'],
    "vegaga": ['mw'],
    "vegaghna": ['mw'],
    "vegajavā": ['bhs', 'mw'],
    "veganāśana": ['mw'],
    "veganāśyanāśakabhāvārtharahasya": ['mw'],
    "vegaparikṣaya": ['mw'],
    "vegarodha": ['mw'],
    "vegarāja": ['mw'],
    "vegarājamati": ['bhs'],
    "vegarājasaṃhitā": ['mw'],
    "vegasampanna": ['mw'],
    "vegasara": ['mw'],
    "vegasarī": ['mw'],
    "vegasāra": ['mw'],
    "vegatara": ['mw'],
    "vegatas": ['mw'],
    "vegavant": ['cae'],
    "vegavat": ['mw'],
    "vegavatstotra": ['mw'],
    "vegavattama": ['mw'],
    "vegavattara": ['mw'],
    "vegavattā": ['mw'],
    "vegavatī": ['mw'],
    "vegavidhāraṇa": ['mw'],
    "vegavirodhin": ['mw'],
    "vegavāhin": ['mw'],
    "vegavāhinī": ['mw'],
    "vegavṛṣṭi": ['mw'],
    "vegaḥ": ['ap90'],
    "vegi": ['mw'],
    "vegihariṇa": ['mw'],
    "vegila": ['mw'],
    "vegin": ['ap90', 'cae', 'mw'],
    "veginī": ['mw'],
    "vegita": ['ap90', 'cae', 'ddsa', 'mw'],
    "vegitva": ['mw'],
    "vegitā": ['mw'],
    "vegodagra": ['cae', 'mw'],
    "vegā": ['bhs'],
    "vegāghāta": ['mw'],
    "vegānila": ['mw'],
    "vegāvataraṇa": ['mw'],
    "veh": ['ap90', 'mw'],
    "vehat": ['ap90', 'cae', 'ddsa', 'mw'],
    "vehl": ['ap90', 'mw'],
    "vehānasa": ['mw'],
    "vehāra": ['ddsa', 'mw'],
    "vehāraḥ": ['ap90'],
    "vehāsa": ['cped'],
    "vehāsagamana": ['cped'],
    "vehāsakuṭi": ['cped'],
    "vehāsaṭṭha": ['cped'],
    "vehāya": ['mw'],
    "vejanavat": ['mw'],
    "vejayanta": ['cped'],
    "vejita": ['mw'],
    "vejja": ['cped'],
    "vejjakamma": ['cped'],
    "vejānī": ['mw'],
    "vekalla": ['cped'],
    "vekallatā": ['cped'],
    "vekaṭa": ['mw'],
    "vekaṭaḥ": ['ap90'],
    "vekuri": ['mw'],
    "vekṣ": ['mw'],
    "vekṣaṇa": ['cae', 'ddsa', 'mw'],
    "vel": ['ap90', 'mw'],
    "vela": ['bhs', 'mw'],
    "velaja": ['mw'],
    "velambaka": ['bhs'],
    "velatiputra": ['bhs'],
    "velava": ['mw'],
    "velaṃ": ['ap90'],
    "velibhukpriya": ['mw'],
    "velikā": ['mw'],
    "vell": ['ap90', 'cae', 'ddsa', 'mw'],
    "vella": ['bhs', 'mw'],
    "vellahala": ['mw'],
    "vellahalaḥ": ['ap90'],
    "vellaja": ['mw'],
    "vellaka": ['mw'],
    "vellana": ['cae', 'ddsa', 'mw'],
    "vellanaṃ": ['ap90'],
    "vellantara": ['mw'],
    "vellanī": ['mw'],
    "vellapurīviṣayagadya": ['mw'],
    "vellaḥ": ['ap90'],
    "velli": ['mw'],
    "vellikā": ['mw'],
    "vellikākhyā": ['mw'],
    "vellita": ['ap90', 'bhs', 'cped', 'mw'],
    "vellitagga": ['cped'],
    "vellitaka": ['mw'],
    "vellitāgra": ['mw'],
    "velliḥ": ['ap90'],
    "vellūra": ['mw'],
    "velormi": ['mw'],
    "velu": ['bhs'],
    "veluva": ['bhs', 'mw'],
    "veluvana": ['bhs'],
    "velā": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "velābala": ['mw'],
    "velācakra": ['bhs'],
    "velādhara": ['mw'],
    "velādri": ['mw'],
    "velāhīna": ['cae', 'mw'],
    "velājala": ['cae', 'mw'],
    "velākula": ['mw'],
    "velākūla": ['ddsa', 'mw'],
    "velāma": ['bhs'],
    "velāmasūtra": ['bhs'],
    "velāmbhas": ['cae', 'mw'],
    "velāmūla": ['mw'],
    "velāna": ['mw'],
    "velānila": ['mw'],
    "velāsalila": ['cae', 'mw'],
    "velāsamudra": ['mw'],
    "velāsikā": ['bhs'],
    "velātaṭa": ['mw'],
    "velātaṭānta": ['mw'],
    "velātiga": ['mw'],
    "velātikkama": ['cped'],
    "velātikrama": ['mw'],
    "velāvali": ['mw'],
    "velāvana": ['mw'],
    "velāvilāsinī": ['mw'],
    "velāvitta": ['mw'],
    "velāvīci": ['mw'],
    "velāya": ['mw'],
    "velāyani": ['mw'],
    "vema": ['cae', 'cped', 'mw'],
    "vemabhūpāla": ['mw'],
    "vemacitra": ['bhs', 'mw'],
    "vemacitrin": ['bhs', 'mw'],
    "vemajjha": ['cped'],
    "vemaka": ['cae', 'mw'],
    "vemakī": ['mw'],
    "veman": ['cae', 'ddsa', 'mw'],
    "vemana": ['mw'],
    "vemanya": ['mw'],
    "vemarāja": ['mw'],
    "vematika": ['cped'],
    "vematta": ['cped'],
    "vemattatā": ['cped'],
    "vemaḥ": ['ap90'],
    "vemānabhairavārya": ['mw'],
    "vemānika": ['cped'],
    "vemānikapeta": ['cped'],
    "vemātika": ['cped'],
    "vemātra": ['bhs'],
    "ven": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vena": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "venayika": ['cped'],
    "veneyya": ['cped'],
    "venia": ['gra'],
    "vennā": ['ap90', 'mw'],
    "venya": ['cae', 'ddsa', 'gra', 'mw'],
    "venā": ['gra', 'mw'],
    "vep": ['ap90', 'cae', 'ddsa', 'mw'],
    "vepa": ['cae', 'gra', 'mw'],
    "vepana": ['cae', 'ddsa', 'mw'],
    "vepanakara": ['mw'],
    "vepanaṃ": ['ap90'],
    "vepas": ['cae', 'ddsa', 'gra', 'mw'],
    "vepathu": ['cae', 'ddsa', 'mw'],
    "vepathubhṛt": ['cae', 'mw'],
    "vepathumant": ['cae'],
    "vepathumat": ['mw'],
    "vepathuparīta": ['mw'],
    "vepathuḥ": ['ap90'],
    "vepita": ['ddsa', 'mw'],
    "vepiṇīyā": ['bhs'],
    "vepiṣṭha": ['cae', 'gra', 'mw'],
    "vepulla": ['cped'],
    "vepullatā": ['cped'],
    "vera": ['cped', 'mw'],
    "verajjaka": ['cped'],
    "veraka": ['mw'],
    "verakaḥ": ['ap90'],
    "veramaṇī": ['cped'],
    "verambhavāta": ['cped'],
    "veraḥ": ['ap90'],
    "veraṁ appeti": ['cped'],
    "veraṭa": ['mw'],
    "veraṭaḥ": ['ap90'],
    "veraṭṭhiputra": ['bhs'],
    "verika": ['cped'],
    "verocana": ['cped'],
    "veruli": ['bhs'],
    "veruliya": ['bhs'],
    "veruḍiṅga": ['bhs'],
    "verācārya": ['mw'],
    "verī": ['cped'],
    "ves": ['ap90', 'ddsa', 'mw'],
    "vesa": ['cped'],
    "vesamma": ['cped'],
    "vesana": ['mw'],
    "vesara": ['cae', 'ddsa', 'mw'],
    "vesaraḥ": ['ap90'],
    "vesarī": ['mw'],
    "vesavāra": ['mw'],
    "vesavāraḥ": ['ap90'],
    "vesiyā": ['cped'],
    "vesma": ['cped'],
    "vessa": ['cped'],
    "vesākha": ['cped'],
    "vesārajja": ['cped'],
    "vesī": ['cped'],
    "veta": ['mw'],
    "vetana": ['cae', 'cped', 'ddsa', 'mw'],
    "vetanabhuj": ['mw'],
    "vetanadāna": ['mw'],
    "vetanajīvin": ['mw'],
    "vetanaka": ['bhs'],
    "vetanaṃ": ['ap90'],
    "vetanika": ['cped'],
    "vetanin": ['ap90', 'mw'],
    "vetanādāna": ['cae', 'mw'],
    "vetaraṇī": ['cped'],
    "vetasa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vetasagṛha": ['mw'],
    "vetasaka": ['mw'],
    "vetasamaya": ['mw'],
    "vetasamālin": ['mw'],
    "vetasaparikṣipta": ['mw'],
    "vetasapattra": ['mw'],
    "vetasapuṣpa": ['mw'],
    "vetasavṛtti": ['cae', 'mw'],
    "vetasaśākhā": ['mw'],
    "vetasaḥ": ['ap90'],
    "vetasikā": ['mw'],
    "vetasinī": ['mw'],
    "vetasu": ['gra', 'mw'],
    "vetasvat": ['ap90', 'mw'],
    "vetasvin": ['mw'],
    "vetasāmla": ['mw'],
    "vetasī": ['ap90', 'mw'],
    "vetayika": ['bhs'],
    "vetaḥ": ['ap90'],
    "vetaṃḍaḥ": ['ap90'],
    "vetaṇḍa": ['cae', 'ddsa', 'mw'],
    "vetaṇḍā": ['mw'],
    "veth": ['ap90', 'mw'],
    "veti": ['cped'],
    "vetra": ['bhs', 'cae', 'ddsa', 'mw'],
    "vetrabhṛt": ['mw'],
    "vetradaṇḍika": ['bhs', 'mw'],
    "vetradhara": ['mw'],
    "vetradharā": ['mw'],
    "vetradhāraka": ['mw'],
    "vetradhārin": ['mw'],
    "vetradhārā": ['cae'],
    "vetragrahaṇa": ['mw'],
    "vetrahan": ['mw'],
    "vetrahasta": ['mw'],
    "vetrakarīra": ['mw'],
    "vetrakāra": ['mw'],
    "vetrakīcakaveṇu": ['mw'],
    "vetrakīya": ['ap90', 'mw'],
    "vetrakīyagṛha": ['mw'],
    "vetrakīyavana": ['mw'],
    "vetrakīyā": ['mw'],
    "vetralatā": ['cae', 'mw'],
    "vetralatācaya": ['mw'],
    "vetralatāmaya": ['mw'],
    "vetramūlaka": ['bhs'],
    "vetranadī": ['bhs', 'mw'],
    "vetraphala": ['mw'],
    "vetrapāṇi": ['mw'],
    "vetravanamāhātmya": ['mw'],
    "vetravant": ['cae'],
    "vetravat": ['mw'],
    "vetravatī": ['ap90', 'bhs', 'mw'],
    "vetravyāsaktahasta": ['mw'],
    "vetrayaṣṭi": ['cae', 'mw'],
    "vetraḥ": ['ap90'],
    "vetrika": ['mw'],
    "vetrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "vetrābhighāta": ['mw'],
    "vetrāghāta": ['mw'],
    "vetrāgra": ['mw'],
    "vetrāmla": ['mw'],
    "vetrāsana": ['cae', 'ddsa', 'mw'],
    "vetrāsanāsīna": ['mw'],
    "vetrāsava": ['mw'],
    "vetrāsura": ['mw'],
    "vetrāvatī": ['mw'],
    "vetrīya": ['mw'],
    "vetta": ['cped'],
    "vettagga": ['cped'],
    "vettalatā": ['cped'],
    "vettavai": ['cae'],
    "vettave": ['cae'],
    "vettṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "vettṛtva": ['mw'],
    "vetā": ['mw'],
    "vetāla": ['cae', 'ddsa', 'mw'],
    "vetālabhaṭṭa": ['mw'],
    "vetālajananī": ['mw'],
    "vetālakarmajña": ['mw'],
    "vetālakavaca": ['mw'],
    "vetālapañcaviṃśati": ['cae', 'mw'],
    "vetālapañcaviṃśatikā": ['cae', 'mw'],
    "vetālapura": ['mw'],
    "vetālarasa": ['mw'],
    "vetālasiddhi": ['mw'],
    "vetālastotra": ['mw'],
    "vetālasādhana": ['mw'],
    "vetālaviṃśati": ['mw'],
    "vetālaḥ": ['ap90'],
    "vetālika": ['bhs', 'cped'],
    "vetālotthāpana": ['mw'],
    "vetālā": ['mw'],
    "vetālākhyāyikā": ['mw'],
    "vetālāsana": ['mw'],
    "vetālī": ['mw'],
    "vetāḍa": ['bhs'],
    "vevacana": ['cped'],
    "vevalaka": ['bhs'],
    "vevara": ['bhs'],
    "vevaṇṇiya": ['cped'],
    "vevidat": ['mw'],
    "vevija": ['cae', 'gra', 'mw'],
    "vevijāna": ['mw'],
    "veviṣat": ['mw'],
    "vevādika": ['bhs'],
    "vevī": ['ap90', 'mw'],
    "veya": ['mw'],
    "veyacchalā": ['mw'],
    "veyagāna": ['mw'],
    "veyyattiya": ['cped'],
    "veyyābādhika": ['cped'],
    "veyyākara": ['cped'],
    "veyyākaraṇa": ['cped'],
    "veyyāvacca": ['cped'],
    "veyyāvatika": ['cped'],
    "veyyāyika": ['cped'],
    "veś": ['mw'],
    "veśa": ['cae', 'ddsa', 'gra', 'mw'],
    "veśabhaginī": ['mw'],
    "veśabhagīna": ['mw'],
    "veśabhāva": ['cae', 'ddsa', 'mw'],
    "veśabhṛt": ['mw'],
    "veśadhara": ['mw'],
    "veśadhārin": ['bhs'],
    "veśadāna": ['mw'],
    "veśaka": ['mw'],
    "veśakaḥ": ['ap90'],
    "veśakula": ['mw'],
    "veśakulastrī": ['mw'],
    "veśana": ['cae', 'ddsa', 'mw'],
    "veśanada": ['mw'],
    "veśanaṃ": ['ap90'],
    "veśanta": ['cae', 'ddsa', 'mw'],
    "veśantā": ['gra', 'mw'],
    "veśanī": ['mw'],
    "veśara": ['mw'],
    "veśaraḥ": ['ap90'],
    "veśas": ['cae', 'ddsa', 'mw'],
    "veśasa": ['mw'],
    "veśasthā": ['mw'],
    "veśastrī": ['mw'],
    "veśatva": ['cae', 'mw'],
    "veśavadhū": ['cae', 'mw'],
    "veśavanitā": ['cae', 'mw'],
    "veśavat": ['mw'],
    "veśavāraḥ": ['ap90'],
    "veśavāsa": ['cae', 'mw'],
    "veśavāṭa": ['mw'],
    "veśayamana": ['mw'],
    "veśayoṣit": ['mw'],
    "veśayuvati": ['mw'],
    "veśaḥ": ['ap90'],
    "veśaṃtaḥ": ['ap90'],
    "veśi": ['mw'],
    "veśia": ['gra'],
    "veśijāta": ['mw'],
    "veśika": ['mw'],
    "veśikā": ['ap90', 'mw'],
    "veśin": ['cae', 'ddsa', 'mw'],
    "veśma": ['mw'],
    "veśmabhū": ['mw'],
    "veśmacaṭaka": ['mw'],
    "veśmadhūma": ['mw'],
    "veśmaka": ['mw'],
    "veśmakaliṅga": ['mw'],
    "veśmakarman": ['mw'],
    "veśmakuliṅga": ['mw'],
    "veśmakūla": ['mw'],
    "veśman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "veśmanakula": ['mw'],
    "veśmasthūṇā": ['mw'],
    "veśmavāsa": ['ddsa', 'mw'],
    "veśmānta": ['mw'],
    "veśobhagya": ['mw'],
    "veśobhagīna": ['mw'],
    "veśvara": ['mw'],
    "veśvaraḥ": ['ap90'],
    "veśya": ['bhs', 'cae', 'mw'],
    "veśyakāminī": ['mw'],
    "veśyastrī": ['cae', 'ddsa', 'mw'],
    "veśyaṃ": ['ap90'],
    "veśyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "veśyācārya": ['mw'],
    "veśyāgamana": ['mw'],
    "veśyāgaṇa": ['mw'],
    "veśyāghaṭaka": ['mw'],
    "veśyāgāmin": ['mw'],
    "veśyāgṛha": ['mw'],
    "veśyājana": ['mw'],
    "veśyājanasamāśraya": ['mw'],
    "veśyājanāśraya": ['mw'],
    "veśyāpati": ['mw'],
    "veśyāpaṇa": ['mw'],
    "veśyāputra": ['cae', 'mw'],
    "veśyātva": ['mw'],
    "veśyāveśman": ['mw'],
    "veśyāvrata": ['mw'],
    "veśyāvāra": ['mw'],
    "veśyāvāsa": ['mw'],
    "veśyāyatta": ['mw'],
    "veśyāyattīkṛ": ['mw'],
    "veśyāśraya": ['mw'],
    "veśyāṅganā": ['cae', 'mw'],
    "veśyāṅganākalpa": ['mw'],
    "veśyāṅganāvṛtti": ['mw'],
    "veśānta": ['mw'],
    "veśāntā": ['cae', 'ddsa', 'mw'],
    "veśāpura": ['mw'],
    "veśī": ['cae', 'ddsa', 'gra', 'mw'],
    "veśījāta": ['mw'],
    "veḍa": ['mw'],
    "veḍaṃ": ['ap90'],
    "veḍhamikā": ['mw'],
    "veḍā": ['ap90', 'mw'],
    "veḷu": ['cped'],
    "veḷuriya": ['cped'],
    "veṃkaṭaḥ": ['ap90'],
    "veṅghara": ['mw'],
    "veṅgi": ['ddsa', 'mw'],
    "veṅgī": ['mw'],
    "veṅka": ['cae', 'mw'],
    "veṅkappa": ['mw'],
    "veṅkappayya": ['mw'],
    "veṅkayya": ['mw'],
    "veṅkaṭa": ['cae', 'ddsa', 'mw'],
    "veṅkaṭabheṭ": ['mw'],
    "veṅkaṭagiri": ['mw'],
    "veṅkaṭagirimāhātmya": ['mw'],
    "veṅkaṭagirinātha": ['mw'],
    "veṅkaṭakavīya": ['mw'],
    "veṅkaṭakṛṣṇa": ['mw'],
    "veṅkaṭakṛṣṇīya": ['mw'],
    "veṅkaṭanātha": ['mw'],
    "veṅkaṭapati": ['mw'],
    "veṅkaṭarāma": ['mw'],
    "veṅkaṭarāya": ['mw'],
    "veṅkaṭaśubhāśāstrin": ['mw'],
    "veṅkaṭeśa": ['mw'],
    "veṅkaṭeśadvādaśanāman": ['mw'],
    "veṅkaṭeśakavaca": ['mw'],
    "veṅkaṭeśamaṅgala": ['mw'],
    "veṅkaṭeśamaṅgalāśāsana": ['mw'],
    "veṅkaṭeśamāhātmya": ['mw'],
    "veṅkaṭeśamālāmantra": ['mw'],
    "veṅkaṭeśanamaskārāṣṭaka": ['mw'],
    "veṅkaṭeśapañcāśat": ['mw'],
    "veṅkaṭeśaprahasana": ['mw'],
    "veṅkaṭeśarahasya": ['mw'],
    "veṅkaṭeśasahasranāman": ['mw'],
    "veṅkaṭeśastotra": ['mw'],
    "veṅkaṭeśasuprabhāta": ['mw'],
    "veṅkaṭeśaśataka": ['mw'],
    "veṅkaṭeśvara": ['mw'],
    "veṅkaṭeśvaracāturbhadrikā": ['mw'],
    "veṅkaṭeśvaramaṅgalastotra": ['mw'],
    "veṅkaṭeśvaramāhātmya": ['mw'],
    "veṅkaṭeśvarasahasranāman": ['mw'],
    "veṅkaṭeśvarastotra": ['mw'],
    "veṅkaṭeśvarīya": ['mw'],
    "veṅkaṭeśāṣṭaka": ['mw'],
    "veṅkaṭeśāṣṭottaraśatanāman": ['mw'],
    "veṅkaṭācala": ['mw'],
    "veṅkaṭācalamāhātmya": ['mw'],
    "veṅkaṭācalasūri": ['mw'],
    "veṅkaṭācaleśa": ['mw'],
    "veṅkaṭācaleśvaramaṅgalāśāsana": ['mw'],
    "veṅkaṭādri": ['mw'],
    "veṅkaṭādrimāhātmya": ['mw'],
    "veṅkaṭādrināthīyagrahatantra": ['mw'],
    "veṇ": ['ap90', 'mw'],
    "veṇa": ['cae', 'cped', 'ddsa', 'mw'],
    "veṇavin": ['mw'],
    "veṇaḥ": ['ap90'],
    "veṇi": ['cae', 'ddsa', 'mw'],
    "veṇika": ['bhs', 'cped', 'mw'],
    "veṇikavāhin": ['mw'],
    "veṇikā": ['ap90', 'mw'],
    "veṇimādhava": ['mw'],
    "veṇin": ['mw'],
    "veṇinī": ['mw'],
    "veṇirāma": ['mw'],
    "veṇivedhanī": ['mw'],
    "veṇivedhinī": ['mw'],
    "veṇiḥ": ['ap90'],
    "veṇu": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "veṇubali": ['cped'],
    "veṇubhāra": ['mw'],
    "veṇubīja": ['mw'],
    "veṇudala": ['cae', 'mw'],
    "veṇudatta": ['mw'],
    "veṇudhma": ['mw'],
    "veṇudāri": ['mw'],
    "veṇudārin": ['ddsa', 'mw'],
    "veṇugopālapratiṣṭhā": ['mw'],
    "veṇugradha": ['mw'],
    "veṇugrāmaka": ['bhs'],
    "veṇugulma": ['bhs', 'mw'],
    "veṇugumba": ['cped'],
    "veṇugīta": ['mw'],
    "veṇuhaya": ['mw'],
    "veṇuhotra": ['mw'],
    "veṇuja": ['mw'],
    "veṇujaṅgha": ['mw'],
    "veṇujāla": ['mw'],
    "veṇuka": ['cae', 'mw'],
    "veṇukarkara": ['mw'],
    "veṇukaṃ": ['ap90'],
    "veṇukā": ['mw'],
    "veṇukāra": ['bhs', 'mw'],
    "veṇukīya": ['mw'],
    "veṇukīyā": ['mw'],
    "veṇumat": ['mw'],
    "veṇumatī": ['mw'],
    "veṇumaya": ['cae', 'mw'],
    "veṇumaṇḍala": ['mw'],
    "veṇumudrā": ['mw'],
    "veṇuna": ['mw'],
    "veṇunaṃ": ['ap90'],
    "veṇunisruti": ['mw'],
    "veṇunṛtyā": ['mw'],
    "veṇupa": ['mw'],
    "veṇupattra": ['mw'],
    "veṇupattraka": ['mw'],
    "veṇupattrikā": ['mw'],
    "veṇupattrī": ['mw'],
    "veṇuvaidala": ['mw'],
    "veṇuvana": ['bhs', 'cped', 'mw'],
    "veṇuvidala": ['cae', 'mw'],
    "veṇuvāda": ['mw'],
    "veṇuvādaka": ['mw'],
    "veṇuvādana": ['mw'],
    "veṇuvādya": ['mw'],
    "veṇuvādyaviśārada": ['mw'],
    "veṇuvīṇādharā": ['mw'],
    "veṇuyava": ['cae', 'mw'],
    "veṇuyavī": ['mw'],
    "veṇuyaṣṭi": ['cae', 'mw'],
    "veṇuśayyā": ['mw'],
    "veṇuḥ": ['ap90'],
    "veṇā": ['ap90', 'mw'],
    "veṇātaṭa": ['cae', 'mw'],
    "veṇī": ['cae', 'cped', 'ddsa', 'mw'],
    "veṇībhūta": ['mw'],
    "veṇīdatta": ['mw'],
    "veṇīdāna": ['mw'],
    "veṇīdāsa": ['mw'],
    "veṇīgamūlaka": ['mw'],
    "veṇīkaraṇa": ['cped'],
    "veṇīkata": ['cped'],
    "veṇīmādhava": ['mw'],
    "veṇīmādhavabandhu": ['mw'],
    "veṇīra": ['mw'],
    "veṇīrāma": ['mw'],
    "veṇīrūpa": ['mw'],
    "veṇīsaṃharaṇa": ['mw'],
    "veṇīsaṃhāra": ['cae', 'mw'],
    "veṇīsaṃvaraṇa": ['mw'],
    "veṇīskandha": ['mw'],
    "veṇīvilāsa": ['mw'],
    "veṇṇā": ['mw'],
    "veṇṭha": ['mw'],
    "veṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "veṣadhara": ['mw'],
    "veṣadhārin": ['cae', 'ddsa', 'mw'],
    "veṣadāna": ['mw'],
    "veṣaka": ['bhs'],
    "veṣakāra": ['mw'],
    "veṣavat": ['mw'],
    "veṣavāra": ['mw'],
    "veṣaśri": ['mw'],
    "veṣaśrī": ['mw'],
    "veṣaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "veṣaṇaṃ": ['ap90'],
    "veṣaṇā": ['ddsa', 'mw'],
    "veṣin": ['bhs', 'mw'],
    "veṣka": ['cae', 'mw'],
    "veṣpa": ['mw'],
    "veṣpaḥ": ['ap90'],
    "veṣya": ['cae', 'mw'],
    "veṣyā": ['ap90'],
    "veṣādhika": ['mw'],
    "veṣānyatva": ['cae', 'mw'],
    "veṣṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "veṣṭa": ['cae', 'mw'],
    "veṣṭaka": ['bhs', 'mw'],
    "veṣṭakaḥ": ['ap90'],
    "veṣṭana": ['cae', 'ddsa', 'mw'],
    "veṣṭanaka": ['mw'],
    "veṣṭanakaḥ": ['ap90'],
    "veṣṭanaveṣṭaka": ['mw'],
    "veṣṭanaṃ": ['ap90'],
    "veṣṭanika": ['mw'],
    "veṣṭanikā": ['bhs'],
    "veṣṭanīya": ['mw'],
    "veṣṭapāla": ['mw'],
    "veṣṭasāra": ['mw'],
    "veṣṭavaṃśa": ['mw'],
    "veṣṭayitavya": ['mw'],
    "veṣṭaḥ": ['ap90'],
    "veṣṭeti": ['bhs'],
    "veṣṭhila": ['bhs'],
    "veṣṭi": ['bhs'],
    "veṣṭita": ['ap90', 'mw'],
    "veṣṭitaka": ['bhs', 'mw'],
    "veṣṭitavya": ['mw'],
    "veṣṭitaśiras": ['mw'],
    "veṣṭitin": ['mw'],
    "veṣṭuka": ['cae', 'mw'],
    "veṣṭya": ['mw'],
    "veṣṭāpayati": ['bhs'],
    "veṣṭāvāra": ['mw'],
    "veṭ": ['cae', 'mw'],
    "veṭa": ['mw'],
    "veṭaka": ['mw'],
    "veṭhaka": ['bhs', 'cped'],
    "veṭhana": ['cped'],
    "veṭhayati": ['bhs'],
    "veṭhenta": ['cped'],
    "veṭhesi": ['cped'],
    "veṭheti": ['cped'],
    "veṭhetvā": ['cped'],
    "veṭhita": ['cped'],
    "veṭhiyamāna": ['cped'],
    "veṭkāra": ['cae', 'mw'],
    "veṭy": ['mw'],
    "veṭā": ['mw'],
    "veṭāvat": ['mw'],
    "veṭī": ['mw'],
    "vi": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "viadhvan": ['gra'],
    "vialkaśā": ['gra'],
    "viati": ['gra'],
    "viayana": ['gra'],
    "viañjana": ['gra'],
    "viaśva": ['gra'],
    "viaśvavat": ['gra'],
    "viaṃsa": ['gra'],
    "vibaddha": ['ap90', 'bhs', 'mw'],
    "vibaddhaka": ['mw'],
    "vibaddhana": ['bhs'],
    "vibaddhayati": ['bhs'],
    "vibala": ['cae', 'mw'],
    "vibalāka": ['mw'],
    "vibandh": ['mw'],
    "vibandha": ['bhs', 'cped', 'ddsa', 'mw'],
    "vibandhahṛt": ['mw'],
    "vibandhana": ['mw'],
    "vibandhu": ['mw'],
    "vibarha": ['mw'],
    "vibaṃdh": ['ap90'],
    "vibaṃdhaḥ": ['ap90'],
    "vibbhamati": ['cped'],
    "vibbhami": ['cped'],
    "vibbhamitvā": ['cped'],
    "vibbhanta": ['cped'],
    "vibbhantaka": ['cped'],
    "vibboka": ['mw'],
    "vibbokaḥ": ['ap90'],
    "vibhagna": ['mw'],
    "vibhaj": ['ap90', 'mw'],
    "vibhaja": ['bhs', 'mw'],
    "vibhajana": ['bhs', 'cped', 'mw'],
    "vibhajanta": ['cped'],
    "vibhajanīya": ['cae', 'mw'],
    "vibhajati": ['bhs', 'cped'],
    "vibhaji": ['cped'],
    "vibhajita": ['cped'],
    "vibhajitar": ['bhs'],
    "vibhajitvā": ['cped'],
    "vibhajja": ['cped'],
    "vibhajjavāda": ['cped'],
    "vibhajjavādī": ['cped'],
    "vibhajya": ['cae', 'mw'],
    "vibhajyapāṭha": ['mw'],
    "vibhajyavyākaraṇa": ['bhs'],
    "vibhajyavāda": ['mw'],
    "vibhajyavādin": ['bhs', 'mw'],
    "vibhakta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vibhaktagātra": ['mw'],
    "vibhaktaja": ['mw'],
    "vibhaktatva": ['mw'],
    "vibhakte": ['mw'],
    "vibhakti": ['cae', 'ddsa', 'mw'],
    "vibhaktika": ['mw'],
    "vibhaktin": ['mw'],
    "vibhaktitattva": ['mw'],
    "vibhaktivivaraṇa": ['mw'],
    "vibhaktiḥ": ['ap90'],
    "vibhaktyarthakārakaprakriyā": ['mw'],
    "vibhaktyarthanirṇaya": ['mw'],
    "vibhaktyarthavicāra": ['mw'],
    "vibhaktātman": ['mw'],
    "vibhaktāvibhaktanirṇaya": ['mw'],
    "vibhaktāṅga": ['bhs'],
    "vibhaktṛ": ['cae', 'ddsa', 'gra', 'mw'],
    "vibhakṣayati": ['bhs'],
    "vibharaṭṭa": ['mw'],
    "vibhartsayati": ['bhs'],
    "vibhasman": ['mw'],
    "vibhasmīkaraṇa": ['mw'],
    "vibhatta": ['cped'],
    "vibhatti": ['cped'],
    "vibhattika": ['cped'],
    "vibhava": ['bhs', 'cae', 'cped', 'mw'],
    "vibhavagandha": ['bhs'],
    "vibhavakṣaya": ['mw'],
    "vibhavamada": ['mw'],
    "vibhavamati": ['mw'],
    "vibhavatas": ['cae', 'mw'],
    "vibhavavant": ['cae'],
    "vibhavavat": ['mw'],
    "vibhavaḥ": ['ap90'],
    "vibhavin": ['cae', 'mw'],
    "vibhaya": ['cae', 'mw'],
    "vibhañj": ['mw'],
    "vibhañjanu": ['cae', 'gra'],
    "vibhaṃgaḥ": ['ap90'],
    "vibhaṃj": ['ap90'],
    "vibhaṅga": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vibhaṅgi": ['mw'],
    "vibhaṅgin": ['mw'],
    "vibhaṅgura": ['mw'],
    "vibhaṇḍaka": ['mw'],
    "vibhaṇḍayati": ['bhs'],
    "vibheda": ['cae', 'mw'],
    "vibhedaka": ['mw'],
    "vibhedana": ['cae', 'mw'],
    "vibhedaḥ": ['ap90'],
    "vibhedika": ['bhs', 'mw'],
    "vibhedin": ['cae', 'mw'],
    "vibhedya": ['mw'],
    "vibhetavya": ['ddsa', 'mw'],
    "vibhettṛ": ['cae', 'mw'],
    "vibhid": ['ap90', 'mw'],
    "vibhida": ['mw'],
    "vibhidā": ['ddsa', 'mw'],
    "vibhindu": ['cae', 'gra', 'mw'],
    "vibhinduka": ['mw'],
    "vibhinna": ['ap90', 'cae', 'cped', 'mw'],
    "vibhinnadarśin": ['mw'],
    "vibhinnadhairya": ['mw'],
    "vibhinnatamisra": ['mw'],
    "vibhinnatva": ['mw'],
    "vibhinnatā": ['mw'],
    "vibhinnaveṣa": ['mw'],
    "vibhinnāṅga": ['mw'],
    "vibhinnīkṛ": ['mw'],
    "vibhitti": ['mw'],
    "vibhoka": ['mw'],
    "vibhram": ['ap90', 'mw'],
    "vibhrama": ['cae', 'mw'],
    "vibhramabhāṣita": ['mw'],
    "vibhramasūtra": ['mw'],
    "vibhramatantra": ['mw'],
    "vibhramati": ['bhs'],
    "vibhramavatī": ['mw'],
    "vibhramaḥ": ['ap90'],
    "vibhramin": ['mw'],
    "vibhramā": ['ap90', 'mw'],
    "vibhramārka": ['mw'],
    "vibhraṃś": ['ap90', 'mw'],
    "vibhraṃśa": ['cae', 'mw'],
    "vibhraṃśayājña": ['mw'],
    "vibhraṃśaḥ": ['ap90'],
    "vibhraṃśin": ['cae', 'mw'],
    "vibhraṃśita": ['ap90', 'mw'],
    "vibhraṃśitajñāna": ['mw'],
    "vibhraṃśitapuṣpapattra": ['mw'],
    "vibhraṣṭa": ['ap90', 'cae', 'mw'],
    "vibhraṣṭaharṣa": ['mw'],
    "vibhraṣṭatimira": ['mw'],
    "vibhraṣṭeṣṭiprayoga": ['mw'],
    "vibhreṣa": ['mw'],
    "vibhru": ['mw'],
    "vibhrāj": ['ap90', 'cae', 'gra', 'mw'],
    "vibhrāja": ['mw'],
    "vibhrājita": ['mw'],
    "vibhrāmaṇa": ['bhs'],
    "vibhrānta": ['cae', 'mw'],
    "vibhrāntamanas": ['mw'],
    "vibhrāntanayana": ['mw'],
    "vibhrāntaśīla": ['mw'],
    "vibhrānti": ['cae', 'mw'],
    "vibhrātṛvya": ['cae', 'ddsa', 'mw'],
    "vibhrāṃta": ['ap90'],
    "vibhrāṃtiḥ": ['ap90'],
    "vibhrāṣṭi": ['gra', 'mw'],
    "vibhu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vibhudatta": ['bhs'],
    "vibhugna": ['bhs', 'mw'],
    "vibhuja": ['mw'],
    "vibhukratu": ['gra', 'mw'],
    "vibhukta": ['mw'],
    "vibhumat": ['gra', 'mw'],
    "vibhupramita": ['mw'],
    "vibhutva": ['cae', 'mw'],
    "vibhutvasamarthana": ['mw'],
    "vibhutā": ['mw'],
    "vibhuvarman": ['mw'],
    "vibhuvarī": ['mw'],
    "vibhva": ['gra', 'mw'],
    "vibhvan": ['cae', 'ddsa', 'gra', 'mw'],
    "vibhvataṣṭa": ['cae', 'gra', 'mw'],
    "vibhvāsah": ['gra', 'mw'],
    "vibhā": ['ap90', 'cae', 'gra', 'mw'],
    "vibhāga": ['cae', 'cped', 'gra', 'mw'],
    "vibhāgabhinna": ['mw'],
    "vibhāgabhāj": ['mw'],
    "vibhāgadharma": ['mw'],
    "vibhāgajña": ['mw'],
    "vibhāgaka": ['mw'],
    "vibhāgakalpanā": ['mw'],
    "vibhāgapattrikā": ['mw'],
    "vibhāgarekhā": ['mw'],
    "vibhāgasāra": ['mw'],
    "vibhāgatas": ['mw'],
    "vibhāgatattvavicāra": ['mw'],
    "vibhāgataḥ": ['ap90'],
    "vibhāgatva": ['mw'],
    "vibhāgavat": ['mw'],
    "vibhāgavattā": ['mw'],
    "vibhāgaśas": ['cae', 'mw'],
    "vibhāgaśaḥ": ['ap90'],
    "vibhāgaḥ": ['ap90'],
    "vibhāgecchu": ['mw'],
    "vibhāgin": ['mw'],
    "vibhāgya": ['mw'],
    "vibhāgīkṛ": ['mw'],
    "vibhāgīya": ['bhs'],
    "vibhāj": ['mw'],
    "vibhājaka": ['ddsa', 'mw'],
    "vibhājakībhūta": ['mw'],
    "vibhājana": ['mw'],
    "vibhājanaṃ": ['ap90'],
    "vibhājayitṛ": ['mw'],
    "vibhājita": ['mw'],
    "vibhājya": ['ap90', 'cae', 'mw'],
    "vibhākara": ['mw'],
    "vibhākaraśarman": ['mw'],
    "vibhānu": ['cae', 'gra', 'mw'],
    "vibhās": ['cae', 'mw'],
    "vibhāsa": ['mw'],
    "vibhāsita": ['mw'],
    "vibhāskara": ['mw'],
    "vibhāsvat": ['mw'],
    "vibhāsā": ['ap90', 'mw'],
    "vibhāt": ['mw'],
    "vibhāta": ['cae', 'cped', 'mw'],
    "vibhātaṃ": ['ap90'],
    "vibhāti": ['cped'],
    "vibhāva": ['cae', 'gra', 'mw'],
    "vibhāvaka": ['ap90', 'mw'],
    "vibhāvan": ['cae', 'gra', 'mw'],
    "vibhāvana": ['cae', 'cped', 'mw'],
    "vibhāvanagandha": ['bhs'],
    "vibhāvanaṃ": ['ap90'],
    "vibhāvanā": ['cped', 'mw'],
    "vibhāvanālaṃkāra": ['mw'],
    "vibhāvanīya": ['cae', 'mw'],
    "vibhāvarī": ['ap90', 'cae', 'mw'],
    "vibhāvarīkānta": ['mw'],
    "vibhāvarīmukha": ['cae', 'mw'],
    "vibhāvarīśa": ['mw'],
    "vibhāvasu": ['cae', 'gra', 'mw'],
    "vibhāvat": ['gra'],
    "vibhāvatva": ['mw'],
    "vibhāvaḥ": ['ap90'],
    "vibhāventa": ['cped'],
    "vibhāvesi": ['cped'],
    "vibhāveti": ['cped'],
    "vibhāvetvā": ['cped'],
    "vibhāvin": ['cae', 'mw'],
    "vibhāvita": ['ap90', 'bhs', 'cped', 'mw'],
    "vibhāvitamati": ['bhs'],
    "vibhāvitatva": ['mw'],
    "vibhāvya": ['cae', 'mw'],
    "vibhāvāyu": ['mw'],
    "vibhāvī": ['cped'],
    "vibhāṇḍa": ['mw'],
    "vibhāṇḍaka": ['mw'],
    "vibhāṇḍikā": ['mw'],
    "vibhāṇḍī": ['mw'],
    "vibhāṣ": ['ap90', 'mw'],
    "vibhāṣati": ['bhs'],
    "vibhāṣita": ['cae', 'mw'],
    "vibhāṣā": ['ap90', 'bhs', 'cae', 'mw'],
    "vibhāṣāvṛtti": ['mw'],
    "vibhī": ['cae', 'mw'],
    "vibhīdaka": ['cae', 'gra', 'mw'],
    "vibhīta": ['cae', 'mw'],
    "vibhītaka": ['cae', 'cped', 'mw'],
    "vibhītakaḥ": ['ap90'],
    "vibhītakaṃ": ['ap90'],
    "vibhītakī": ['ap90', 'cped'],
    "vibhītaḥ": ['ap90'],
    "vibhītaṃ": ['ap90'],
    "vibhītā": ['ap90'],
    "vibhīṣaka": ['ap90', 'mw'],
    "vibhīṣaṇa": ['bhs', 'cae', 'gra', 'mw'],
    "vibhīṣaṇanāmaka": ['cae'],
    "vibhīṣaṇā": ['mw'],
    "vibhīṣaṇābhiṣeka": ['mw'],
    "vibhīṣikā": ['ap90', 'cae', 'mw'],
    "vibhīṣikāsthāna": ['mw'],
    "vibhīṣā": ['mw'],
    "vibhū": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vibhūdāvan": ['mw'],
    "vibhūma": ['mw'],
    "vibhūman": ['cae', 'mw'],
    "vibhūmat": ['mw'],
    "vibhūrasi": ['mw'],
    "vibhūsana": ['cped'],
    "vibhūsesi": ['cped'],
    "vibhūseti": ['cped'],
    "vibhūsetvā": ['cped'],
    "vibhūsita": ['cped'],
    "vibhūsā": ['cped'],
    "vibhūta": ['ap90', 'bhs', 'cped', 'mw'],
    "vibhūtadyumna": ['gra', 'mw'],
    "vibhūtamanas": ['mw'],
    "vibhūtapati": ['bhs'],
    "vibhūtarāti": ['gra', 'mw'],
    "vibhūtaṃgamā": ['bhs', 'mw'],
    "vibhūti": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vibhūtibala": ['mw'],
    "vibhūticandra": ['mw'],
    "vibhūtidhāraṇavidhi": ['mw'],
    "vibhūtidvādaśī": ['mw'],
    "vibhūtigama": ['bhs'],
    "vibhūtigrahaṇa": ['mw'],
    "vibhūtimant": ['cae'],
    "vibhūtimat": ['mw'],
    "vibhūtimādhava": ['mw'],
    "vibhūtimāhātmya": ['mw'],
    "vibhūtiyoga": ['mw'],
    "vibhūtiḥ": ['ap90'],
    "vibhūvas": ['cae', 'mw'],
    "vibhūvasu": ['gra', 'mw'],
    "vibhūṣ": ['ap90', 'mw'],
    "vibhūṣaṇa": ['cae', 'ddsa', 'mw'],
    "vibhūṣaṇadharā": ['bhs'],
    "vibhūṣaṇakalā": ['mw'],
    "vibhūṣaṇavant": ['cae'],
    "vibhūṣaṇavat": ['mw'],
    "vibhūṣaṇaṃ": ['ap90'],
    "vibhūṣaṇodbhāsin": ['mw'],
    "vibhūṣin": ['mw'],
    "vibhūṣita": ['ap90', 'bhs', 'mw'],
    "vibhūṣitā": ['bhs'],
    "vibhūṣitālaṃkārā": ['bhs', 'mw'],
    "vibhūṣitāṅga": ['bhs', 'mw'],
    "vibhūṣā": ['ap90', 'cae', 'mw'],
    "vibhūṣṇu": ['mw'],
    "vibhṛ": ['mw'],
    "vibhṛta": ['ap90', 'mw'],
    "vibhṛtra": ['ddsa', 'gra', 'mw'],
    "vibhṛtvan": ['gra', 'mw'],
    "vibibhitsu": ['mw'],
    "vibila": ['mw'],
    "vibobhuvat": ['mw'],
    "vibodha": ['cae', 'ddsa', 'mw'],
    "vibodhaka": ['bhs'],
    "vibodhana": ['bhs', 'cae', 'gra', 'mw'],
    "vibodhayitavya": ['mw'],
    "vibodhaḥ": ['ap90'],
    "vibodhita": ['bhs', 'mw'],
    "vibrū": ['ap90', 'mw'],
    "vibubhūṣu": ['mw'],
    "vibubhūṣā": ['mw'],
    "vibuddha": ['ap90', 'bhs', 'cae', 'mw'],
    "vibuddhacūta": ['mw'],
    "vibuddhajñānabodhidhvajateja": ['bhs'],
    "vibuddhakamala": ['mw'],
    "vibuddhana": ['bhs'],
    "vibuddhati": ['bhs'],
    "vibuddhi": ['bhs', 'cae', 'mw'],
    "vibudh": ['ap90', 'mw'],
    "vibudha": ['cae', 'ddsa', 'mw'],
    "vibudhaguru": ['mw'],
    "vibudhamati": ['mw'],
    "vibudhanadī": ['mw'],
    "vibudhapati": ['mw'],
    "vibudhapriyā": ['mw'],
    "vibudharañjanī": ['mw'],
    "vibudharipu": ['mw'],
    "vibudharāja": ['cae', 'mw'],
    "vibudharṣabha": ['mw'],
    "vibudhasadman": ['mw'],
    "vibudhasakha": ['mw'],
    "vibudhastrī": ['cae', 'mw'],
    "vibudhataṭinī": ['mw'],
    "vibudhatva": ['mw'],
    "vibudhavidviṣ": ['mw'],
    "vibudhavijaya": ['mw'],
    "vibudhaśatru": ['mw'],
    "vibudhaḥ": ['ap90'],
    "vibudhendra": ['mw'],
    "vibudhetara": ['mw'],
    "vibudheśvara": ['cae', 'mw'],
    "vibudhopadeśa": ['mw'],
    "vibudhyana": ['bhs'],
    "vibudhācārya": ['mw'],
    "vibudhādhipa": ['cae', 'mw'],
    "vibudhādhipati": ['cae', 'mw'],
    "vibudhādhipatya": ['mw'],
    "vibudhāna": ['mw'],
    "vibudhānaḥ": ['ap90'],
    "vibudhānucara": ['cae', 'mw'],
    "vibudhāvāsa": ['mw'],
    "vibuka": ['mw'],
    "vibādh": ['ap90', 'mw'],
    "vibādha": ['cae', 'gra', 'mw'],
    "vibādhaka": ['cped'],
    "vibādhana": ['cped'],
    "vibādhati": ['cped'],
    "vibādhavant": ['cae'],
    "vibādhavat": ['mw'],
    "vibādhā": ['ap90', 'mw'],
    "vibāhu": ['mw'],
    "vibālī": ['cae', 'gra', 'mw'],
    "vibāṇa": ['mw'],
    "vibāṇadhi": ['mw'],
    "vibāṇajya": ['mw'],
    "vibṛh": ['mw'],
    "vibṛṃh": ['mw'],
    "vic": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vicakhnu": ['mw'],
    "vicakhyu": ['mw'],
    "vicakila": ['cae', 'mw'],
    "vicakilamaya": ['mw'],
    "vicakilaḥ": ['ap90'],
    "vicakkhaṇa": ['cped'],
    "vicakra": ['cae', 'ddsa', 'mw'],
    "vicakrama": ['bhs'],
    "vicakramāṇa": ['mw'],
    "vicakropaskaropastha": ['mw'],
    "vicakṣ": ['mw'],
    "vicakṣas": ['ap90', 'mw'],
    "vicakṣaṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vicakṣaṇacanasitavat": ['mw'],
    "vicakṣaṇam": ['mw'],
    "vicakṣaṇammanya": ['mw'],
    "vicakṣaṇatva": ['mw'],
    "vicakṣaṇavat": ['mw'],
    "vicakṣaṇā": ['mw'],
    "vicakṣe": ['cae'],
    "vicakṣu": ['bhs'],
    "vicakṣus": ['ap90', 'cae', 'mw'],
    "vicakṣuṣkaraṇa": ['mw'],
    "vicakṣya": ['mw'],
    "vical": ['ap90', 'mw'],
    "vicala": ['ap90', 'mw'],
    "vicalana": ['mw'],
    "vicalanaṃ": ['ap90'],
    "vicalayati": ['bhs'],
    "vicalita": ['mw'],
    "vicandra": ['mw'],
    "vicar": ['ap90', 'mw'],
    "vicara": ['mw'],
    "vicaramāna": ['cped'],
    "vicaranta": ['cped'],
    "vicarati": ['bhs', 'cped'],
    "vicaraṇa": ['cped', 'mw'],
    "vicaraṇīya": ['cae', 'mw'],
    "vicarcika": ['bhs'],
    "vicarcikā": ['ap90', 'cae', 'mw'],
    "vicarcita": ['ap90', 'mw'],
    "vicarcī": ['cae', 'mw'],
    "vicari": ['cped'],
    "vicarita": ['cae', 'cped', 'mw'],
    "vicaritaṃ": ['ap90'],
    "vicarituṁ": ['cped'],
    "vicaritvā": ['cped'],
    "vicarman": ['mw'],
    "vicarṣaṇa": ['mw'],
    "vicarṣaṇi": ['gra', 'mw'],
    "vicasta": ['bhs'],
    "vicatura": ['mw'],
    "vicaya": ['cae', 'cped', 'mw'],
    "vicayana": ['cae', 'mw'],
    "vicayanaṃ": ['ap90'],
    "vicayaḥ": ['ap90'],
    "vicayiṣṭha": ['gra', 'mw'],
    "vicañcita": ['bhs'],
    "vicaṃkrama": ['bhs'],
    "vicaṣarṇi": ['cae'],
    "vicaṭ": ['mw'],
    "vicaṭana": ['mw'],
    "vicch": ['ap90'],
    "vicchad": ['mw'],
    "vicchanda": ['mw'],
    "vicchandaka": ['mw'],
    "vicchandas": ['ddsa', 'mw'],
    "vicchardaka": ['mw'],
    "vicchardakaḥ": ['ap90'],
    "vicchardana": ['mw'],
    "vicchardanaṃ": ['ap90'],
    "vicchardikā": ['mw'],
    "vicchardita": ['ap90', 'mw'],
    "vicchaṃdaḥ": ['ap90'],
    "viccheda": ['cae', 'cped', 'ddsa', 'mw'],
    "vicchedaka": ['mw'],
    "vicchedakārin": ['cae'],
    "vicchedana": ['cae', 'mw'],
    "vicchedanaṃ": ['ap90'],
    "vicchedanā": ['mw'],
    "vicchedanīya": ['mw'],
    "vicchedaḥ": ['ap90'],
    "vicchedin": ['cae', 'mw'],
    "vicchid": ['ap90', 'mw'],
    "vicchiddaka": ['cped'],
    "vicchidya": ['mw'],
    "vicchika": ['cped'],
    "vicchindamāna": ['cped'],
    "vicchindanta": ['cped'],
    "vicchindati": ['cped'],
    "vicchindi": ['cped'],
    "vicchinditvā": ['cped'],
    "vicchinna": ['ap90', 'cae', 'cped', 'mw'],
    "vicchinnabalikarman": ['mw'],
    "vicchinnadhūmaprasara": ['mw'],
    "vicchinnamadya": ['mw'],
    "vicchinnaprasara": ['mw'],
    "vicchinnatā": ['mw'],
    "vicchinnaśarapātatva": ['mw'],
    "vicchitti": ['cae', 'ddsa', 'mw'],
    "vicchittiḥ": ['ap90'],
    "viccho": ['mw'],
    "vicchur": ['ap90'],
    "vicchuraṇa": ['ddsa', 'mw'],
    "vicchurita": ['ap90', 'mw'],
    "vicchāy": ['mw'],
    "vicchāya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vicchāyatā": ['mw'],
    "vicchāyaya": ['ddsa', 'mw'],
    "vicchāyīkṛ": ['mw'],
    "vicetana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vicetanī": ['mw'],
    "vicetar": ['bhs'],
    "vicetas": ['ap90', 'cae', 'gra', 'mw'],
    "vicetavya": ['mw'],
    "vicetī": ['mw'],
    "vicetṛ": ['cae', 'mw'],
    "viceya": ['cae', 'mw'],
    "viceyatāraka": ['mw'],
    "viceṣṭ": ['ap90', 'mw'],
    "viceṣṭa": ['cae', 'mw'],
    "viceṣṭana": ['cae', 'mw'],
    "viceṣṭita": ['ap90', 'cae', 'mw'],
    "viceṣṭitṛ": ['mw'],
    "viceṣṭā": ['ap90', 'cae', 'mw'],
    "vich": ['mw'],
    "vichandanā": ['bhs'],
    "vichandayati": ['bhs'],
    "vichidra": ['bhs'],
    "vichindika": ['bhs'],
    "vici": ['ap90', 'mw'],
    "vicicīṣā": ['mw'],
    "vicikicchati": ['cped'],
    "vicikicchi": ['cped'],
    "vicikicchita": ['cped'],
    "vicikicchā": ['cped'],
    "vicikila": ['mw'],
    "vicikitsaka": ['bhs'],
    "vicikitsana": ['cae', 'ddsa', 'mw'],
    "vicikitsita": ['bhs'],
    "vicikitsya": ['cae', 'mw'],
    "vicikitsā": ['ap90', 'bhs', 'mw'],
    "vicikitsārthīya": ['mw'],
    "vicilaka": ['mw'],
    "vicinana": ['cped'],
    "vicinanta": ['cped'],
    "vicini": ['cped'],
    "vicinitvā": ['cped'],
    "vicint": ['mw'],
    "vicintacūta": ['bhs'],
    "vicintaka": ['bhs'],
    "vicintana": ['cae', 'mw'],
    "vicintanīya": ['cae', 'mw'],
    "vicintenta": ['cped'],
    "vicintesi": ['cped'],
    "vicinteti": ['cped'],
    "vicintetvā": ['cped'],
    "vicintita": ['cped', 'mw'],
    "vicintitṛ": ['mw'],
    "vicintiya": ['cped'],
    "vicintya": ['cae', 'mw'],
    "vicintā": ['cae', 'mw'],
    "vicinvatka": ['mw'],
    "vicinvatkaḥ": ['ap90'],
    "vicināti": ['cped'],
    "vicit": ['cae', 'mw'],
    "vicita": ['ap90', 'cped', 'mw'],
    "viciti": ['cae', 'mw'],
    "vicitiḥ": ['ap90'],
    "vicitra": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vicitrabhūta": ['bhs'],
    "vicitrabhūṣaṇa": ['bhs', 'mw'],
    "vicitracaritra": ['mw'],
    "vicitracīnāṃśuka": ['mw'],
    "vicitracūta": ['bhs'],
    "vicitradeha": ['mw'],
    "vicitradhvajā": ['bhs'],
    "vicitragātra": ['bhs'],
    "vicitraka": ['mw'],
    "vicitrakatha": ['mw'],
    "vicitrakaḥ": ['ap90'],
    "vicitrakuṇḍalin": ['bhs'],
    "vicitram": ['mw'],
    "vicitramakuṭa": ['bhs'],
    "vicitramauliśrīcūḍa": ['mw'],
    "vicitramālyābharaṇa": ['mw'],
    "vicitrapaśu": ['mw'],
    "vicitrapratibhāṇālaṃkāragarbha": ['bhs'],
    "vicitraraśmijvalanacandra": ['bhs'],
    "vicitrarūpa": ['mw'],
    "vicitrasaṃkrama": ['bhs'],
    "vicitrasiṃha": ['mw'],
    "vicitratva": ['mw'],
    "vicitratā": ['mw'],
    "vicitravarṣin": ['mw'],
    "vicitravāgurocchrāyamaya": ['mw'],
    "vicitravākyapaṭutā": ['mw'],
    "vicitravīrya": ['cae', 'mw'],
    "vicitravīryasū": ['mw'],
    "vicitrayati": ['bhs'],
    "vicitrika": ['bhs'],
    "vicitrita": ['cae', 'ddsa', 'mw'],
    "vicitrā": ['mw'],
    "vicitrālaṃkārasvara": ['bhs', 'mw'],
    "vicitrāpīḍa": ['mw'],
    "vicitrāṅga": ['mw'],
    "vicitta": ['cae', 'cped', 'mw'],
    "vicittaka": ['bhs'],
    "vicittatā": ['mw'],
    "vicitti": ['mw'],
    "vicitvārā": ['mw'],
    "vicitya": ['cae', 'mw'],
    "viciḥ": ['ap90'],
    "viciṃt": ['ap90'],
    "viciṇṇa": ['cped'],
    "vicula": ['mw'],
    "vicumb": ['mw'],
    "vicuṇṇa": ['cped'],
    "vicuṇṇesi": ['cped'],
    "vicuṇṇeti": ['cped'],
    "vicuṇṇetvā": ['cped'],
    "vicuṇṇita": ['cped'],
    "vicyu": ['ap90', 'mw'],
    "vicyuta": ['ap90', 'mw'],
    "vicyuti": ['cae', 'ddsa', 'mw'],
    "vicyutiḥ": ['ap90'],
    "vicācala": ['mw'],
    "vicācalat": ['mw'],
    "vicācali": ['gra', 'mw'],
    "vicākaśat": ['mw'],
    "vicāla": ['mw'],
    "vicālana": ['bhs', 'mw'],
    "vicālin": ['mw'],
    "vicālita": ['mw'],
    "vicālya": ['mw'],
    "vicāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vicārabhū": ['mw'],
    "vicāracintāmaṇi": ['mw'],
    "vicāradṛś": ['mw'],
    "vicārajña": ['mw'],
    "vicāraka": ['bhs', 'cped', 'mw'],
    "vicārakartṛ": ['mw'],
    "vicārakatva": ['mw'],
    "vicārakatā": ['mw'],
    "vicārakaḥ": ['ap90'],
    "vicāramañjarī": ['mw'],
    "vicāramālā": ['mw'],
    "vicāramūḍha": ['mw'],
    "vicāranirṇaya": ['mw'],
    "vicārapara": ['mw'],
    "vicārasthala": ['mw'],
    "vicārasudhākara": ['mw'],
    "vicārasudhārṇava": ['mw'],
    "vicāravant": ['cae'],
    "vicāravat": ['mw'],
    "vicāravid": ['mw'],
    "vicārayati": ['bhs'],
    "vicāraśāstra": ['mw'],
    "vicāraśīla": ['mw'],
    "vicāraḥ": ['ap90'],
    "vicāraṇa": ['cae', 'cped', 'mw'],
    "vicāraṇaṃ": ['ap90'],
    "vicāraṇā": ['ap90', 'cped', 'mw'],
    "vicāraṇīya": ['cae', 'mw'],
    "vicārenta": ['cped'],
    "vicāresi": ['cped'],
    "vicāreti": ['cped'],
    "vicāretvā": ['cped'],
    "vicārikā": ['mw'],
    "vicārin": ['ap90', 'cae', 'gra', 'mw'],
    "vicārita": ['ap90', 'cae', 'cped', 'mw'],
    "vicārokti": ['mw'],
    "vicāru": ['mw'],
    "vicārya": ['cae', 'mw'],
    "vicārārkasaṃgraha": ['mw'],
    "vicārārthasamāgama": ['mw'],
    "vicī": ['mw'],
    "vicīraka": ['bhs'],
    "vicīrin": ['mw'],
    "vicīrṇa": ['ap90', 'mw'],
    "vicūlin": ['mw'],
    "vicūrṇ": ['mw'],
    "vicūrṇana": ['mw'],
    "vicūrṇita": ['mw'],
    "vicūrṇībhū": ['mw'],
    "vicūṣayati": ['bhs'],
    "vicṛt": ['cae', 'gra', 'mw'],
    "vicṛtta": ['mw'],
    "vid": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vida": ['cae', 'ddsa', 'mw'],
    "vidabhṛt": ['mw'],
    "vidad": ['mw'],
    "vidadaśva": ['gra', 'mw'],
    "vidadaṅkṣu": ['ddsa', 'mw'],
    "vidadvasu": ['cae', 'ddsa', 'gra', 'mw'],
    "vidagaṇa": ['mw'],
    "vidagdha": ['ap90', 'cae', 'ddsa', 'mw'],
    "vidagdhabodha": ['mw'],
    "vidagdhacūḍāmaṇi": ['cae', 'mw'],
    "vidagdhaka": ['bhs', 'mw'],
    "vidagdhamukhamaṇḍana": ['mw'],
    "vidagdhamādhava": ['mw'],
    "vidagdhaparivṛddhatā": ['mw'],
    "vidagdhapariṣad": ['mw'],
    "vidagdhatoṣiṇī": ['mw'],
    "vidagdhatva": ['mw'],
    "vidagdhatā": ['ap90', 'cae', 'mw'],
    "vidagdhavacana": ['mw'],
    "vidagdhavaidya": ['mw'],
    "vidagdhā": ['mw'],
    "vidagdhājīrṇa": ['mw'],
    "vidagdhālāpa": ['mw'],
    "vidah": ['mw'],
    "vidahati": ['cped'],
    "vidahi": ['cped'],
    "vidahita": ['cped'],
    "vidahitvā": ['cped'],
    "vidakṣiṇa": ['ddsa', 'mw'],
    "vidal": ['ap90', 'mw'],
    "vidala": ['ap90', 'cae', 'ddsa', 'mw'],
    "vidalana": ['cae', 'mw'],
    "vidalanaṃ": ['ap90'],
    "vidalikā": ['bhs'],
    "vidalita": ['mw'],
    "vidalā": ['mw'],
    "vidalīkaraṇa": ['mw'],
    "vidalīkṛta": ['mw'],
    "vidanta": ['mw'],
    "vidanvat": ['mw'],
    "vidara": ['ddsa', 'mw'],
    "vidaraḥ": ['ap90'],
    "vidaraṇa": ['cae', 'mw'],
    "vidarbha": ['ap90', 'cae', 'ddsa', 'mw'],
    "vidarbhabhū": ['mw'],
    "vidarbhajā": ['mw'],
    "vidarbhanagarī": ['cae', 'mw'],
    "vidarbhapati": ['cae', 'mw'],
    "vidarbharāj": ['mw'],
    "vidarbharāja": ['mw'],
    "vidarbharājadhānī": ['mw'],
    "vidarbharājan": ['cae'],
    "vidarbharājaputrī": ['mw'],
    "vidarbhatanayā": ['mw'],
    "vidarbhayati": ['bhs'],
    "vidarbhaṇa": ['bhs'],
    "vidarbhi": ['mw'],
    "vidarbhā": ['mw'],
    "vidarbhābhimukha": ['mw'],
    "vidarbhādhipa": ['mw'],
    "vidarbhādhiparājadhānī": ['mw'],
    "vidarbhādhipati": ['mw'],
    "vidarbhāḥ": ['ap90'],
    "vidarbhīkauṇḍinya": ['cae', 'mw'],
    "vidarvya": ['mw'],
    "vidarśana": ['bhs'],
    "vidarśanā": ['mw'],
    "vidarśin": ['mw'],
    "vidas": ['mw'],
    "vidasta": ['mw'],
    "vidasya": ['gra', 'mw'],
    "vidatha": ['cae', 'ddsa', 'gra', 'mw'],
    "vidathaḥ": ['ap90'],
    "vidathia": ['gra'],
    "vidathin": ['gra', 'mw'],
    "vidathya": ['cae', 'ddsa', 'gra', 'mw'],
    "vidatra": ['cae', 'gra', 'mw'],
    "vidatriya": ['gra', 'mw'],
    "vidatta": ['mw'],
    "vidatthi": ['cped'],
    "viday": ['mw'],
    "vidaśa": ['mw'],
    "vidaḥ": ['ap90'],
    "vidaṃś": ['mw'],
    "vidaṃśa": ['ddsa', 'mw'],
    "vidaṃśaḥ": ['ap90'],
    "vidaṇḍa": ['mw'],
    "vidaṣṭa": ['mw'],
    "viddasu": ['cped'],
    "viddaṇācārya": ['mw'],
    "viddesa": ['cped'],
    "viddha": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "viddhaka": ['mw'],
    "viddhakarṇa": ['mw'],
    "viddhaparkaṭī": ['mw'],
    "viddhaprajanana": ['mw'],
    "viddhasta": ['cped'],
    "viddhatva": ['mw'],
    "viddhaśālabhañjikā": ['mw'],
    "viddhaṁsaka": ['cped'],
    "viddhaṁsana": ['cped'],
    "viddhaṁsenta": ['cped'],
    "viddhaṁsesi": ['cped'],
    "viddhaṁseti": ['cped'],
    "viddhaṁsetvā": ['cped'],
    "viddhaṁsita": ['cped'],
    "viddhi": ['mw'],
    "viddhāyudha": ['mw'],
    "videgha": ['cae', 'ddsa', 'mw'],
    "videha": ['ap90', 'cae', 'ddsa', 'mw'],
    "videhajā": ['mw'],
    "videhaka": ['mw'],
    "videhakaivalyaprāpti": ['mw'],
    "videhamukti": ['mw'],
    "videhamuktikathana": ['mw'],
    "videhamuktyādikathana": ['mw'],
    "videhanagara": ['mw'],
    "videhanagarī": ['mw'],
    "videhapati": ['mw'],
    "videharāja": ['mw'],
    "videhatva": ['mw'],
    "videhā": ['mw'],
    "videhādhipa": ['mw'],
    "videhādhipati": ['mw'],
    "videsa": ['cped'],
    "videsika": ['cped'],
    "videsī": ['cped'],
    "videva": ['cae', 'mw'],
    "videvam": ['mw'],
    "videvana": ['cae', 'mw'],
    "videya": ['cae', 'mw'],
    "videśa": ['cae', 'ddsa', 'mw'],
    "videśaga": ['mw'],
    "videśagamana": ['mw'],
    "videśagata": ['mw'],
    "videśaja": ['mw'],
    "videśanirata": ['mw'],
    "videśastha": ['mw'],
    "videśavāsa": ['mw'],
    "videśavāsin": ['mw'],
    "videśaḥ": ['ap90'],
    "videśin": ['ap90', 'mw'],
    "videśya": ['mw'],
    "videśīya": ['mw'],
    "vidh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vidha": ['cped', 'ddsa', 'mw'],
    "vidham": ['mw'],
    "vidhama": ['bhs', 'mw'],
    "vidhamacūḍā": ['mw'],
    "vidhamaka": ['cped'],
    "vidhamana": ['bhs', 'cped', 'mw'],
    "vidhamanaka": ['bhs'],
    "vidhamanatā": ['bhs', 'mw'],
    "vidhamati": ['cped'],
    "vidhameti": ['cped'],
    "vidhami": ['cped'],
    "vidhamita": ['cped'],
    "vidhamitar": ['bhs'],
    "vidhamitvā": ['cped'],
    "vidhamā": ['mw'],
    "vidhana": ['cae', 'ddsa', 'mw'],
    "vidhanatā": ['mw'],
    "vidhanus": ['mw'],
    "vidhanuṣka": ['mw'],
    "vidhanvan": ['mw'],
    "vidhanīkṛ": ['mw'],
    "vidharaṇa": ['mw'],
    "vidharaṇī": ['mw'],
    "vidharma": ['cae', 'mw'],
    "vidharman": ['cae', 'gra', 'mw'],
    "vidharmastha": ['mw'],
    "vidharmatas": ['mw'],
    "vidharmika": ['cae', 'mw'],
    "vidharmin": ['cae', 'mw'],
    "vidhartṛ": ['cae', 'gra', 'mw'],
    "vidhas": ['ap90', 'mw'],
    "vidhauta": ['cae', 'mw'],
    "vidhava": ['ddsa', 'gra', 'mw'],
    "vidhavana": ['mw'],
    "vidhavanaṃ": ['ap90'],
    "vidhavatā": ['cae', 'ddsa', 'mw'],
    "vidhavayoṣit": ['mw'],
    "vidhavya": ['mw'],
    "vidhavyaṃ": ['ap90'],
    "vidhavā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vidhavādharma": ['mw'],
    "vidhavāgāmin": ['mw'],
    "vidhavāstrī": ['mw'],
    "vidhavāvedana": ['mw'],
    "vidhavāvivāha": ['mw'],
    "vidhavāvivāhakhaṇḍana": ['mw'],
    "vidhavāvivāhavicāra": ['mw'],
    "vidhaḥ": ['ap90'],
    "vidheya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vidheyajña": ['mw'],
    "vidheyamārga": ['mw'],
    "vidheyapada": ['mw'],
    "vidheyatva": ['mw'],
    "vidheyatā": ['cae', 'mw'],
    "vidheyavartin": ['mw'],
    "vidheyya": ['cped'],
    "vidheyātman": ['cae', 'mw'],
    "vidheyī": ['mw'],
    "vidheyībhūya": ['mw'],
    "vidheyīkṛ": ['cae', 'ddsa'],
    "vidheyīkṛta": ['mw'],
    "vidhi": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vidhibhūṣaṇa": ['mw'],
    "vidhidarśaka": ['mw'],
    "vidhidarśin": ['mw'],
    "vidhideśaka": ['mw'],
    "vidhidvaidha": ['mw'],
    "vidhidṛṣṭa": ['cae', 'ddsa', 'mw'],
    "vidhighna": ['mw'],
    "vidhihīna": ['cae', 'mw'],
    "vidhijña": ['cae', 'mw'],
    "vidhikara": ['ddsa', 'mw'],
    "vidhikṛt": ['mw'],
    "vidhilopa": ['mw'],
    "vidhilopaka": ['mw'],
    "vidhimantrapuraskṛtam": ['cae', 'mw'],
    "vidhinirūpaṇa": ['mw'],
    "vidhiniṣedhatā": ['mw'],
    "vidhinā": ['cped'],
    "vidhiparyāgata": ['mw'],
    "vidhiprasaṅga": ['mw'],
    "vidhiprayoga": ['mw'],
    "vidhiprayukta": ['mw'],
    "vidhiputra": ['mw'],
    "vidhipūrvakam": ['cae', 'mw'],
    "vidhipūrvam": ['cae', 'mw'],
    "vidhirasāyana": ['mw'],
    "vidhirasāyanadūṣaṇa": ['mw'],
    "vidhirasāyanasukhopajīvinī": ['mw'],
    "vidhirasāyanasukhopayoginī": ['mw'],
    "vidhirasāyanavyākhyā": ['mw'],
    "vidhiratna": ['mw'],
    "vidhiratnakṛt": ['mw'],
    "vidhiratnamālā": ['mw'],
    "vidhirūpanirūpaṇa": ['mw'],
    "vidhisudhākara": ['mw'],
    "vidhisvarūpavicāra": ['mw'],
    "vidhisvarūpavādārtha": ['mw'],
    "vidhisāra": ['mw'],
    "vidhitas": ['mw'],
    "vidhitrayaparitrāṇa": ['mw'],
    "vidhitsamāna": ['mw'],
    "vidhitsita": ['ap90', 'mw'],
    "vidhitsu": ['mw'],
    "vidhitsā": ['ap90', 'ddsa', 'mw'],
    "vidhitva": ['mw'],
    "vidhivadhū": ['mw'],
    "vidhivat": ['ap90', 'cae', 'mw'],
    "vidhivaśa": ['cae'],
    "vidhivaśāt": ['mw'],
    "vidhivicāra": ['mw'],
    "vidhivihita": ['mw'],
    "vidhiviparyaya": ['cae', 'mw'],
    "vidhiviveka": ['mw'],
    "vidhivāda": ['mw'],
    "vidhivādavicāra": ['mw'],
    "vidhivādārtha": ['mw'],
    "vidhiyajña": ['cae', 'mw'],
    "vidhiyoga": ['cae', 'mw'],
    "vidhiyogatas": ['mw'],
    "vidhiyogāt": ['mw'],
    "vidhiśoṇitīya": ['mw'],
    "vidhiḥ": ['ap90'],
    "vidhiṣedha": ['mw'],
    "vidhiṣedhatas": ['mw'],
    "vidhmā": ['mw'],
    "vidhmāpana": ['mw'],
    "vidhu": ['cae', 'ddsa', 'gra', 'mw'],
    "vidhudina": ['mw'],
    "vidhugupti": ['mw'],
    "vidhukrānta": ['mw'],
    "vidhukṣaya": ['cae', 'mw'],
    "vidhumaya": ['mw'],
    "vidhumaṇḍala": ['mw'],
    "vidhumukhī": ['mw'],
    "vidhumāsa": ['mw'],
    "vidhunana": ['mw'],
    "vidhunanaṃ": ['ap90'],
    "vidhunayati": ['bhs'],
    "vidhuni": ['cped'],
    "vidhunita": ['cped'],
    "vidhunitvā": ['cped'],
    "vidhunāti": ['cped'],
    "vidhuparidhvaṃsa": ['mw'],
    "vidhupañjara": ['mw'],
    "vidhupriyā": ['mw'],
    "vidhura": ['ap90', 'cae', 'ddsa', 'mw'],
    "vidhuradarśana": ['cae', 'mw'],
    "vidhuram": ['mw'],
    "vidhuratva": ['mw'],
    "vidhuratā": ['cae', 'mw'],
    "vidhuray": ['cae'],
    "vidhuraya": ['ddsa', 'mw'],
    "vidhurita": ['mw'],
    "vidhurā": ['ap90', 'mw'],
    "vidhurīkṛ": ['ddsa'],
    "vidhurīkṛta": ['mw'],
    "vidhuta": ['ap90', 'mw'],
    "vidhutabandhana": ['mw'],
    "vidhutamārtya": ['mw'],
    "vidhutapakṣa": ['mw'],
    "vidhutatriliṅga": ['mw'],
    "vidhuti": ['cae', 'ddsa', 'mw'],
    "vidhutiḥ": ['ap90'],
    "vidhutva": ['ddsa', 'mw'],
    "vidhuvadanā": ['ddsa', 'mw'],
    "vidhuvana": ['mw'],
    "vidhuvanaṃ": ['ap90'],
    "vidhuḥ": ['ap90'],
    "vidhuṃtuda": ['cae', 'mw'],
    "vidhuṃtudaḥ": ['ap90'],
    "vidhvas": ['mw'],
    "vidhvasta": ['ap90', 'cae', 'mw'],
    "vidhvastakavaca": ['mw'],
    "vidhvastanagarāśrama": ['mw'],
    "vidhvastaparaguṇa": ['mw'],
    "vidhvastatā": ['mw'],
    "vidhvastavipaṇāpaṇa": ['mw'],
    "vidhvaṃs": ['ap90', 'mw'],
    "vidhvaṃsa": ['cae', 'ddsa', 'mw'],
    "vidhvaṃsaka": ['mw'],
    "vidhvaṃsana": ['cae', 'mw'],
    "vidhvaṃsaḥ": ['ap90'],
    "vidhvaṃsin": ['ap90', 'cae', 'mw'],
    "vidhvaṃsinī": ['mw'],
    "vidhvaṃsita": ['mw'],
    "vidhy": ['mw'],
    "vidhya": ['mw'],
    "vidhyalaṃkriyā": ['mw'],
    "vidhyalaṃkāra": ['mw'],
    "vidhyanta": ['mw'],
    "vidhyantatva": ['mw'],
    "vidhyaparādha": ['ddsa', 'mw'],
    "vidhyaparādhaprāyaścitta": ['mw'],
    "vidhyaparādhaprāyaścittaprayoga": ['mw'],
    "vidhyaparādhaprāyaścittasūtra": ['mw'],
    "vidhyapāśraya": ['mw'],
    "vidhyati": ['bhs'],
    "vidhyādi": ['mw'],
    "vidhyātmaka": ['cae', 'mw'],
    "vidhā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vidhāna": ['bhs', 'cae', 'cped', 'gra', 'mw'],
    "vidhānaga": ['mw'],
    "vidhānagumpha": ['mw'],
    "vidhānajña": ['mw'],
    "vidhānaka": ['mw'],
    "vidhānakalpa": ['mw'],
    "vidhānakaṃ": ['ap90'],
    "vidhānakhaṇḍa": ['mw'],
    "vidhānamālā": ['mw'],
    "vidhānapārijāta": ['mw'],
    "vidhānarahasya": ['mw'],
    "vidhānaratna": ['mw'],
    "vidhānaratnamālā": ['mw'],
    "vidhānasaptamī": ['mw'],
    "vidhānasārasaṃgraha": ['mw'],
    "vidhānatas": ['mw'],
    "vidhānatilaka": ['mw'],
    "vidhānayukta": ['mw'],
    "vidhānaṃ": ['ap90'],
    "vidhānokta": ['cae', 'mw'],
    "vidhāra": ['gra', 'mw'],
    "vidhāraya": ['mw'],
    "vidhārayitavya": ['mw'],
    "vidhārayitṛ": ['mw'],
    "vidhāraṇa": ['cae', 'mw'],
    "vidhārin": ['cae', 'mw'],
    "vidhātar": ['cped'],
    "vidhātavya": ['cae', 'ddsa', 'mw'],
    "vidhātrāyus": ['mw'],
    "vidhātrī": ['ap90', 'mw'],
    "vidhātā": ['mw'],
    "vidhātṛ": ['ap90', 'cae', 'gra', 'mw'],
    "vidhātṛbhū": ['mw'],
    "vidhātṛkā": ['mw'],
    "vidhātṛvaśāt": ['mw'],
    "vidhāv": ['mw'],
    "vidhāvana": ['cae', 'cped', 'mw'],
    "vidhāvati": ['cped'],
    "vidhāvi": ['cped'],
    "vidhāvita": ['mw'],
    "vidhāvitvā": ['cped'],
    "vidhāvya": ['mw'],
    "vidhāyaka": ['ap90', 'cae', 'cped', 'mw'],
    "vidhāyakatva": ['mw'],
    "vidhāyin": ['cae', 'mw'],
    "vidhī": ['mw'],
    "vidhū": ['ap90', 'mw'],
    "vidhūma": ['cae', 'cped', 'mw'],
    "vidhūme": ['mw'],
    "vidhūmra": ['cae', 'mw'],
    "vidhūna": ['bhs'],
    "vidhūnana": ['cae', 'mw'],
    "vidhūnita": ['ap90', 'mw'],
    "vidhūp": ['mw'],
    "vidhūpa": ['mw'],
    "vidhūpana": ['cped'],
    "vidhūpenta": ['cped'],
    "vidhūpesi": ['cped'],
    "vidhūpeti": ['cped'],
    "vidhūpetvā": ['cped'],
    "vidhūpita": ['cped'],
    "vidhūsara": ['mw'],
    "vidhūta": ['ap90', 'cped', 'ddsa', 'mw'],
    "vidhūtakalmaṣa": ['mw'],
    "vidhūtakeśa": ['mw'],
    "vidhūtanidra": ['mw'],
    "vidhūtapāpman": ['mw'],
    "vidhūtaveśa": ['mw'],
    "vidhūti": ['cae', 'mw'],
    "vidhūtika": ['bhs'],
    "vidhūtiḥ": ['ap90'],
    "vidhṛ": ['ap90', 'mw'],
    "vidhṛta": ['ap90', 'cae', 'mw'],
    "vidhṛti": ['cae', 'ddsa', 'mw'],
    "vidhṛtiḥ": ['ap90'],
    "vidhṛtāyudha": ['mw'],
    "vidhṛṣ": ['mw'],
    "vidhṛṣṭi": ['mw'],
    "vidi": ['ddsa'],
    "vidigdha": ['bhs'],
    "vidikcaṅga": ['mw'],
    "vidisā": ['cped'],
    "vidita": ['ap90', 'cae', 'cped', 'mw'],
    "viditabhakti": ['cae'],
    "viditadharman": ['cae'],
    "viditatta": ['cped'],
    "viditayaśas": ['bhs'],
    "viditā": ['mw'],
    "viditātman": ['cae'],
    "vidiv": ['mw'],
    "vidiś": ['ap90', 'cae', 'ddsa', 'mw'],
    "vidiśā": ['ap90', 'cae', 'mw'],
    "vidman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vidmana": ['mw'],
    "vidmanāpas": ['gra', 'mw'],
    "vido": ['mw'],
    "vidoha": ['mw'],
    "vidoṣa": ['mw'],
    "vidra": ['mw'],
    "vidradha": ['gra', 'mw'],
    "vidradhi": ['mw'],
    "vidradhikā": ['mw'],
    "vidradhināśana": ['mw'],
    "vidradhiḥ": ['ap90'],
    "vidrai": ['mw'],
    "vidrava": ['cae', 'ddsa', 'mw'],
    "vidravaḥ": ['ap90'],
    "vidravaṇa": ['mw'],
    "vidraḥ": ['ap90'],
    "vidraṣṭṛ": ['mw'],
    "vidriya": ['gra', 'mw'],
    "vidru": ['ap90', 'mw'],
    "vidruh": ['mw'],
    "vidruma": ['cae', 'ddsa', 'mw'],
    "vidrumacchavi": ['mw'],
    "vidrumacchāya": ['mw'],
    "vidrumadaṇḍa": ['mw'],
    "vidrumadehalī": ['mw'],
    "vidrumalatā": ['mw'],
    "vidrumamaya": ['mw'],
    "vidrumataṭa": ['mw'],
    "vidrumatā": ['mw'],
    "vidrumavana": ['mw'],
    "vidrumaḥ": ['ap90'],
    "vidruta": ['ap90', 'cae', 'mw'],
    "vidruti": ['mw'],
    "vidrutā": ['mw'],
    "vidrā": ['mw'],
    "vidrāpayati": ['bhs'],
    "vidrāpaṇa": ['bhs'],
    "vidrāva": ['ap90', 'mw'],
    "vidrāvaka": ['mw'],
    "vidrāvaṇa": ['bhs', 'cae', 'mw'],
    "vidrāvaṇaṃ": ['ap90'],
    "vidrāvin": ['cae', 'mw'],
    "vidrāvita": ['ap90', 'mw'],
    "vidrāvya": ['mw'],
    "vidrāyaṇa": ['bhs'],
    "vidrāṇa": ['ap90'],
    "vidu": ['bhs', 'mw'],
    "vidud": ['mw'],
    "vidugga": ['cped'],
    "viduh": ['mw'],
    "vidula": ['ddsa', 'mw'],
    "vidulaḥ": ['ap90'],
    "vidulā": ['mw'],
    "vidupa": ['mw'],
    "vidura": ['ap90', 'cae', 'ddsa', 'mw'],
    "viduranīti": ['mw'],
    "viduraprajāgara": ['mw'],
    "viduratā": ['mw'],
    "vidurā": ['bhs'],
    "vidurāgamanaparvan": ['mw'],
    "vidurākrūravarada": ['mw'],
    "vidus": ['cae', 'ddsa', 'gra', 'mw'],
    "vidutā": ['bhs'],
    "viduḥ": ['ap90'],
    "viduṣ": ['mw'],
    "viduṣaka": ['bhs'],
    "viduṣitara": ['mw'],
    "viduṣkṛta": ['mw'],
    "viduṣmat": ['mw'],
    "viduṣī": ['mw'],
    "viduṣṭa": ['bhs'],
    "viduṣṭara": ['ddsa', 'mw'],
    "vidvac": ['mw'],
    "vidvaccakora": ['mw'],
    "vidvaccittaprasādinī": ['mw'],
    "vidvad": ['mw'],
    "vidvadbhūṣaṇapadyasaṃgraha": ['mw'],
    "vidvaddeśya": ['mw'],
    "vidvaddeśīya": ['mw'],
    "vidvadvallabha": ['mw'],
    "vidvadvinodakāvya": ['mw'],
    "vidvadvinodamañjūṣā": ['mw'],
    "vidvadvivāda": ['mw'],
    "vidvaj": ['mw'],
    "vidvajjana": ['cae', 'ddsa', 'mw'],
    "vidvajjanamadabhañjana": ['mw'],
    "vidvajjanamanoharā": ['mw'],
    "vidvajjanaparisevitā": ['bhs', 'mw'],
    "vidvajjanavallabha": ['mw'],
    "vidvajjanavallabhīya": ['mw'],
    "vidvala": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vidvan": ['mw'],
    "vidvanmanoharā": ['mw'],
    "vidvanmanoramā": ['mw'],
    "vidvanmanorañjinī": ['mw'],
    "vidvanmaṇḍana": ['mw'],
    "vidvanmodataraṃgiṇī": ['mw'],
    "vidvanmodinī": ['mw'],
    "vidvas": ['ap90', 'gra', 'mw'],
    "vidvat": ['mw'],
    "vidvatkalpa": ['mw'],
    "vidvatkaṇṭhapāśa": ['mw'],
    "vidvatprabodhinī": ['mw'],
    "vidvatsaṃnyāsalakṣaṇa": ['mw'],
    "vidvattama": ['mw'],
    "vidvattara": ['mw'],
    "vidvattva": ['mw'],
    "vidvattā": ['cae', 'mw'],
    "vidvaṃs": ['cae'],
    "vidveṣa": ['cae', 'mw'],
    "vidveṣaka": ['cae', 'mw'],
    "vidveṣakarman": ['mw'],
    "vidveṣas": ['gra', 'mw'],
    "vidveṣavīra": ['mw'],
    "vidveṣaḥ": ['ap90'],
    "vidveṣaṇa": ['cae', 'gra', 'mw'],
    "vidveṣaṇaḥ": ['ap90'],
    "vidveṣaṇā": ['bhs'],
    "vidveṣaṇī": ['mw'],
    "vidveṣika": ['bhs'],
    "vidveṣin": ['ap90', 'cae', 'mw'],
    "vidveṣiprabhava": ['mw'],
    "vidveṣitā": ['cae', 'mw'],
    "vidveṣiṇī": ['mw'],
    "vidveṣya": ['cae', 'mw'],
    "vidveṣṭṛ": ['mw'],
    "vidviṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "vidviṣa": ['mw'],
    "vidviṣant": ['cae'],
    "vidviṣat": ['mw'],
    "vidviṣāṇa": ['cae', 'mw'],
    "vidviṣṭa": ['ap90', 'cae', 'mw'],
    "vidviṣṭatā": ['mw'],
    "vidviṣṭi": ['cae'],
    "vidvāṃs": ['bhs', 'ddsa'],
    "vidya": ['cae', 'ddsa', 'gra', 'mw'],
    "vidyamāna": ['ap90', 'mw'],
    "vidyamānakeśa": ['mw'],
    "vidyamānamati": ['mw'],
    "vidyamānatva": ['mw'],
    "vidyamānatā": ['mw'],
    "vidyate": ['bhs'],
    "vidyendrasarasvatī": ['mw'],
    "vidyeśa": ['ddsa', 'mw'],
    "vidyeśatva": ['mw'],
    "vidyeśvara": ['mw'],
    "vidyika": ['mw'],
    "vidyopayoga": ['ddsa', 'mw'],
    "vidyopārjana": ['mw'],
    "vidyopārjanā": ['mw'],
    "vidyopārjita": ['mw'],
    "vidyot": ['mw'],
    "vidyota": ['cae', 'ddsa', 'mw'],
    "vidyotaka": ['cae', 'mw'],
    "vidyotamāna": ['mw'],
    "vidyotana": ['ap90', 'bhs', 'cae', 'mw'],
    "vidyotanī": ['bhs'],
    "vidyotayitavya": ['mw'],
    "vidyotin": ['cae', 'mw'],
    "vidyotpatti": ['mw'],
    "vidyottaratāpinī": ['mw'],
    "vidyotā": ['mw'],
    "vidyuc": ['mw'],
    "vidyuccakra": ['bhs'],
    "vidyucchatru": ['mw'],
    "vidyucchikhā": ['mw'],
    "vidyud": ['mw'],
    "vidyudakṣa": ['mw'],
    "vidyudambhas": ['mw'],
    "vidyuddatta": ['bhs'],
    "vidyuddhasta": ['cae', 'gra', 'mw'],
    "vidyuddhvaja": ['mw'],
    "vidyuddyota": ['mw'],
    "vidyuddyotā": ['mw'],
    "vidyuddāman": ['cae', 'ddsa', 'mw'],
    "vidyudratha": ['gra', 'mw'],
    "vidyudunmeṣa": ['mw'],
    "vidyudvallī": ['mw'],
    "vidyudvarcas": ['mw'],
    "vidyudvarṇā": ['mw'],
    "vidyudvat": ['mw'],
    "vidyuj": ['mw'],
    "vidyujjihva": ['ddsa', 'mw'],
    "vidyujjihvā": ['mw'],
    "vidyujjvāla": ['bhs', 'mw'],
    "vidyujjvālā": ['mw'],
    "vidyul": ['mw'],
    "vidyullakṣaṇa": ['mw'],
    "vidyullatā": ['cae', 'mw'],
    "vidyullekhā": ['cae', 'mw'],
    "vidyullocana": ['mw'],
    "vidyullocanā": ['bhs', 'mw'],
    "vidyun": ['mw'],
    "vidyunmahas": ['cae', 'gra', 'mw'],
    "vidyunman": ['cae'],
    "vidyunmat": ['gra', 'mw'],
    "vidyunmaṇḍalavat": ['mw'],
    "vidyunmukha": ['mw'],
    "vidyunmāla": ['mw'],
    "vidyunmālin": ['cae', 'mw'],
    "vidyunmālā": ['cae', 'mw'],
    "vidyuprabhāsa": ['bhs'],
    "vidyupratiṣṭha": ['bhs'],
    "vidyut": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vidyutaya": ['mw'],
    "vidyutkampa": ['mw'],
    "vidyutkeśa": ['mw'],
    "vidyutkeśin": ['mw'],
    "vidyutparṇā": ['mw'],
    "vidyutpatāka": ['mw'],
    "vidyutprabha": ['bhs', 'mw'],
    "vidyutprabhā": ['bhs', 'mw'],
    "vidyutpradīpa": ['bhs'],
    "vidyutprapatana": ['mw'],
    "vidyutpriya": ['mw'],
    "vidyutpuñja": ['mw'],
    "vidyutpuñjā": ['mw'],
    "vidyutpāta": ['mw'],
    "vidyutsampātam": ['mw'],
    "vidyutsani": ['mw'],
    "vidyutvant": ['cae'],
    "vidyutvat": ['ap90', 'mw'],
    "vidyutya": ['cae', 'mw'],
    "vidyutā": ['bhs', 'mw'],
    "vidyutākṣa": ['mw'],
    "vidyā": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vidyābala": ['cae', 'mw'],
    "vidyābharaṇa": ['mw'],
    "vidyābharaṇī": ['mw'],
    "vidyābhaṭṭa": ['mw'],
    "vidyābhaṭṭapaddhati": ['mw'],
    "vidyābhimāna": ['mw'],
    "vidyābhimānavat": ['mw'],
    "vidyābhyāsa": ['mw'],
    "vidyābhāj": ['mw'],
    "vidyābhīpsin": ['cae', 'mw'],
    "vidyābhūṣaṇa": ['mw'],
    "vidyābhṛt": ['mw'],
    "vidyācakravartin": ['mw'],
    "vidyācaraṇasampanna": ['mw'],
    "vidyācaraṇasaṃpanna": ['bhs'],
    "vidyācaṇa": ['mw'],
    "vidyācit": ['mw'],
    "vidyācuñcu": ['mw'],
    "vidyādala": ['mw'],
    "vidyādaśaka": ['mw'],
    "vidyādevī": ['mw'],
    "vidyādhana": ['cae', 'mw'],
    "vidyādhara": ['bhs', 'cae', 'ddsa', 'mw'],
    "vidyādharacakravartin": ['mw'],
    "vidyādharamahācakravartin": ['cae', 'mw'],
    "vidyādharamahācakravartitā": ['mw'],
    "vidyādharapiṭaka": ['bhs', 'mw'],
    "vidyādhararasa": ['mw'],
    "vidyādharatva": ['mw'],
    "vidyādharatāla": ['mw'],
    "vidyādharayantra": ['mw'],
    "vidyādharendra": ['cae', 'mw'],
    "vidyādharendratva": ['mw'],
    "vidyādharendratā": ['mw'],
    "vidyādharā": ['bhs'],
    "vidyādharābhra": ['mw'],
    "vidyādharādhīśa": ['mw'],
    "vidyādharādhīśatā": ['mw'],
    "vidyādharī": ['ddsa', 'mw'],
    "vidyādharībhū": ['mw'],
    "vidyādharīparijana": ['mw'],
    "vidyādharīvilāsa": ['mw'],
    "vidyādhidevatā": ['mw'],
    "vidyādhigama": ['cae', 'mw'],
    "vidyādhipa": ['mw'],
    "vidyādhipati": ['mw'],
    "vidyādhirāja": ['mw'],
    "vidyādhirājatīrtha": ['mw'],
    "vidyādhirāya": ['mw'],
    "vidyādhra": ['mw'],
    "vidyādhāmamuniśiṣya": ['mw'],
    "vidyādhāra": ['cae', 'mw'],
    "vidyādhīśamuni": ['mw'],
    "vidyādhīśanātha": ['mw'],
    "vidyādhīśasvāmin": ['mw'],
    "vidyādhīśatīrtha": ['mw'],
    "vidyādhīśavaḍeru": ['mw'],
    "vidyādāna": ['mw'],
    "vidyādātṛ": ['mw'],
    "vidyādāyāda": ['mw'],
    "vidyāgama": ['mw'],
    "vidyāgaṇa": ['mw'],
    "vidyāgrahaṇa": ['cae', 'mw'],
    "vidyāguru": ['cae', 'mw'],
    "vidyāgītā": ['mw'],
    "vidyāhīna": ['cae', 'mw'],
    "vidyājambhakavārttika": ['mw'],
    "vidyākalpasūtra": ['mw'],
    "vidyākara": ['mw'],
    "vidyākaramiśramaithila": ['mw'],
    "vidyākarman": ['mw'],
    "vidyākośagṛha": ['mw'],
    "vidyākośasamāśraya": ['mw'],
    "vidyālabdha": ['mw'],
    "vidyālaharī": ['mw'],
    "vidyālaya": ['mw'],
    "vidyālaṃkāra": ['mw'],
    "vidyālaṃkārabhaṭṭācārya": ['mw'],
    "vidyālābha": ['mw'],
    "vidyāmada": ['cae', 'mw'],
    "vidyāmaheśvara": ['mw'],
    "vidyāmandira": ['mw'],
    "vidyāmaya": ['cae', 'mw'],
    "vidyāmaṇi": ['mw'],
    "vidyāmaṇḍalaka": ['mw'],
    "vidyāmaṭha": ['mw'],
    "vidyāmādhava": ['mw'],
    "vidyāmādhavīya": ['mw'],
    "vidyāmāhātmya": ['mw'],
    "vidyāmātrasiddhi": ['mw'],
    "vidyāmātrasiddhitridaśaśāstrakārikā": ['mw'],
    "vidyāmṛtavarṣiṇī": ['mw'],
    "vidyānagara": ['mw'],
    "vidyānanda": ['mw'],
    "vidyānandanibandha": ['mw'],
    "vidyānandanātha": ['mw'],
    "vidyānidhi": ['mw'],
    "vidyānidhitīrtha": ['mw'],
    "vidyānivāsa": ['mw'],
    "vidyānivāsabhaṭṭācārya": ['mw'],
    "vidyānta": ['mw'],
    "vidyāntaga": ['mw'],
    "vidyānulomālipi": ['mw'],
    "vidyānulomāvimiśritalipi": ['bhs'],
    "vidyānupālana": ['mw'],
    "vidyānupālin": ['cae', 'mw'],
    "vidyānusevana": ['mw'],
    "vidyānusevin": ['mw'],
    "vidyānyāsa": ['mw'],
    "vidyānātha": ['mw'],
    "vidyānāthabhaṭṭa": ['mw'],
    "vidyāpaddhati": ['mw'],
    "vidyāpariṇaya": ['mw'],
    "vidyāpati": ['mw'],
    "vidyāpatitva": ['mw'],
    "vidyāphala": ['mw'],
    "vidyāpradāna": ['mw'],
    "vidyāprakāśacikitsā": ['mw'],
    "vidyāpravāda": ['mw'],
    "vidyāprāpti": ['mw'],
    "vidyāpīṭha": ['mw'],
    "vidyārambha": ['mw'],
    "vidyāratna": ['mw'],
    "vidyāratnākara": ['mw'],
    "vidyāraṇya": ['mw'],
    "vidyāraṇyabhāṣya": ['mw'],
    "vidyāraṇyajātaka": ['mw'],
    "vidyāraṇyamūla": ['mw'],
    "vidyāraṇyanārāyaṇīya": ['mw'],
    "vidyāraṇyapañcadaśī": ['mw'],
    "vidyāraṇyasaṃgraha": ['mw'],
    "vidyārcanamañjarī": ['mw'],
    "vidyārjana": ['mw'],
    "vidyārjita": ['mw'],
    "vidyārtha": ['cae', 'mw'],
    "vidyārthadīpikā": ['mw'],
    "vidyārthaprakāśikā": ['mw'],
    "vidyārthin": ['cae', 'mw'],
    "vidyārāja": ['bhs', 'mw'],
    "vidyārāma": ['mw'],
    "vidyārāśi": ['mw'],
    "vidyārṇava": ['mw'],
    "vidyāsadman": ['mw'],
    "vidyāsampradāna": ['mw'],
    "vidyāsnāta": ['mw'],
    "vidyāsnātaka": ['mw'],
    "vidyāsthāna": ['bhs', 'mw'],
    "vidyāsādhana": ['mw'],
    "vidyāsāgara": ['mw'],
    "vidyāsāgarapāra": ['mw'],
    "vidyātas": ['mw'],
    "vidyātva": ['mw'],
    "vidyātīrtha": ['mw'],
    "vidyātīrthaśiṣya": ['mw'],
    "vidyāvadhū": ['mw'],
    "vidyāvallabha": ['mw'],
    "vidyāvant": ['cae'],
    "vidyāvat": ['mw'],
    "vidyāvataṃsa": ['mw'],
    "vidyāvatī": ['mw'],
    "vidyāvayovṛddha": ['cae', 'mw'],
    "vidyāvaṃśa": ['mw'],
    "vidyāvedavratasnāta": ['mw'],
    "vidyāvedavratavat": ['mw'],
    "vidyāveśman": ['mw'],
    "vidyāvid": ['cae', 'mw'],
    "vidyāvihīna": ['mw'],
    "vidyāvikraya": ['mw'],
    "vidyāvilāsa": ['mw'],
    "vidyāvinoda": ['mw'],
    "vidyāviruddha": ['mw'],
    "vidyāviruddhatā": ['mw'],
    "vidyāviśiṣṭa": ['mw'],
    "vidyāviśārada": ['mw'],
    "vidyāviṣayehomavidhi": ['mw'],
    "vidyāvrata": ['mw'],
    "vidyāvrataka": ['mw'],
    "vidyāvratasnāta": ['mw'],
    "vidyāvyasana": ['mw'],
    "vidyāvyavasāya": ['mw'],
    "vidyāvyākhyānamaṇḍapa": ['mw'],
    "vidyāvāgīśa": ['mw'],
    "vidyāvāgīśabhaṭṭācārya": ['mw'],
    "vidyāvṛddha": ['mw'],
    "vidyāśrutasampanna": ['mw'],
    "vidā": ['mw'],
    "vidāha": ['mw'],
    "vidāhaka": ['mw'],
    "vidāhavat": ['mw'],
    "vidāhaḥ": ['ap90'],
    "vidāhin": ['ap90', 'cae', 'mw'],
    "vidāhitva": ['mw'],
    "vidālana": ['cped'],
    "vidālita": ['cped'],
    "vidāna": ['cae', 'ddsa', 'gra', 'mw'],
    "vidānta": ['mw'],
    "vidāra": ['cae', 'ddsa', 'mw'],
    "vidāraka": ['cae', 'mw'],
    "vidārakaḥ": ['ap90'],
    "vidāraḥ": ['ap90'],
    "vidāraṇa": ['cae', 'cped', 'mw'],
    "vidāraṇaḥ": ['ap90'],
    "vidāresi": ['cped'],
    "vidāreti": ['cped'],
    "vidāri": ['mw'],
    "vidārikā": ['mw'],
    "vidārin": ['cae', 'mw'],
    "vidārita": ['cped', 'mw'],
    "vidāruḥ": ['ap90'],
    "vidārva": ['mw'],
    "vidārvya": ['mw'],
    "vidārī": ['mw'],
    "vidārīgandhikā": ['mw'],
    "vidārīgandhā": ['mw'],
    "vidāsin": ['mw'],
    "vidāya": ['mw'],
    "vidāyia": ['gra'],
    "vidāyin": ['mw'],
    "vidāyya": ['ddsa', 'gra', 'mw'],
    "vidāś": ['mw'],
    "vidīdhayu": ['gra', 'mw'],
    "vidīdhiti": ['mw'],
    "vidīdhī": ['mw'],
    "vidīgaya": ['mw'],
    "vidīp": ['mw'],
    "vidīpaka": ['mw'],
    "vidīpita": ['mw'],
    "vidīpta": ['mw'],
    "vidīptatejas": ['mw'],
    "vidīrṇa": ['ap90', 'cae', 'mw'],
    "vidīrṇahṛdaya": ['mw'],
    "vidīrṇamukha": ['mw'],
    "vidū": ['cped', 'mw'],
    "vidūna": ['ap90', 'mw'],
    "vidūra": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vidūrabhūmi": ['mw'],
    "vidūraga": ['mw'],
    "vidūragamana": ['mw'],
    "vidūraja": ['mw'],
    "vidūrajāta": ['mw'],
    "vidūrakramaṇakṣama": ['mw'],
    "vidūram": ['mw'],
    "vidūraratna": ['mw'],
    "vidūrasaṃśrava": ['mw'],
    "vidūratha": ['ddsa', 'mw'],
    "vidūratva": ['mw'],
    "vidūratā": ['cae', 'mw'],
    "vidūravigata": ['mw'],
    "vidūraya": ['ddsa', 'mw'],
    "vidūrodbhāvita": ['mw'],
    "vidūrādri": ['mw'],
    "vidūrībhū": ['mw'],
    "vidūseti": ['cped'],
    "vidūsita": ['cped'],
    "vidūṣa": ['bhs'],
    "vidūṣaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "vidūṣaṇa": ['mw'],
    "vidūṣaṇaka": ['mw'],
    "vidūṣaṇaṃ": ['ap90'],
    "vidūṣaṇā": ['bhs'],
    "vidūṣita": ['mw'],
    "vidṛti": ['cae', 'mw'],
    "vidṛtiḥ": ['ap90'],
    "vidṛś": ['mw'],
    "vidṛṣṭi": ['bhs'],
    "vidṝ": ['ap90', 'mw'],
    "vienas": ['gra'],
    "vieta": ['gra'],
    "vigacchamāna": ['cped'],
    "vigacchanta": ['cped'],
    "vigacchati": ['cped'],
    "vigacchi": ['cped'],
    "vigada": ['cae', 'ddsa', 'gra', 'mw'],
    "vigadita": ['mw'],
    "vigai": ['ap90', 'mw'],
    "vigal": ['ap90', 'mw'],
    "vigalita": ['ap90', 'bhs', 'cped', 'mw'],
    "vigalitabandha": ['mw'],
    "vigalitakeśa": ['mw'],
    "vigalitalajja": ['mw'],
    "vigalitanīvi": ['mw'],
    "vigalitavasana": ['mw'],
    "vigalitaśuc": ['mw'],
    "vigam": ['ap90', 'mw'],
    "vigama": ['bhs', 'cae', 'cped', 'mw'],
    "vigamacandra": ['mw'],
    "vigamana": ['cped'],
    "vigamaḥ": ['ap90'],
    "vigandha": ['cae', 'mw'],
    "vigandhaka": ['bhs', 'mw'],
    "vigandhi": ['cae', 'mw'],
    "vigandhikā": ['mw'],
    "vigara": ['mw'],
    "vigarahati": ['cped'],
    "vigarahi": ['cped'],
    "vigarahitvā": ['cped'],
    "vigaraḥ": ['ap90'],
    "vigarbhā": ['mw'],
    "vigarh": ['ap90', 'mw'],
    "vigarha": ['bhs', 'mw'],
    "vigarhaka": ['bhs'],
    "vigarhaṇa": ['cae', 'mw'],
    "vigarhaṇaṃ": ['ap90'],
    "vigarhaṇīya": ['mw'],
    "vigarhin": ['cae', 'mw'],
    "vigarhita": ['ap90', 'cae', 'mw'],
    "vigarhitācāra": ['mw'],
    "vigarhiṇī": ['mw'],
    "vigarhya": ['cae', 'mw'],
    "vigarhyakathā": ['mw'],
    "vigarhyatā": ['mw'],
    "vigarhā": ['mw'],
    "vigarj": ['mw'],
    "vigarjā": ['mw'],
    "vigata": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vigatabhaya": ['mw'],
    "vigatabhī": ['mw'],
    "vigatacchandatā": ['cped'],
    "vigatadvaṃdva": ['mw'],
    "vigatajvara": ['cae', 'mw'],
    "vigatajñāna": ['mw'],
    "vigatakalmaṣa": ['mw'],
    "vigatakhila": ['cped'],
    "vigataklama": ['mw'],
    "vigatalakṣaṇa": ['mw'],
    "vigatamanyu": ['mw'],
    "vigatanayana": ['mw'],
    "vigatanāsika": ['mw'],
    "vigatapuṃska": ['mw'],
    "vigataraja": ['cped'],
    "vigatareṇu": ['bhs'],
    "vigatarāga": ['mw'],
    "vigatarāgabhūmi": ['bhs'],
    "vigatarāgadhvaja": ['mw'],
    "vigatarājasaṃbhavā": ['bhs'],
    "vigatasaṃkalpa": ['cae', 'mw'],
    "vigatasaṃtrāsa": ['mw'],
    "vigatasneha": ['mw'],
    "vigatasnehasauhṛda": ['mw'],
    "vigataspṛha": ['mw'],
    "vigatatva": ['mw'],
    "vigataśatru": ['bhs'],
    "vigataśoka": ['bhs'],
    "vigataśrīka": ['mw'],
    "vigatoddhava": ['mw'],
    "vigatā": ['mw'],
    "vigatārtavā": ['mw'],
    "vigatāsa": ['cped'],
    "vigatāsava": ['cped'],
    "vigatāsu": ['mw'],
    "vigatāśaṅka": ['mw'],
    "vigatāśoka": ['mw'],
    "vigava": ['bhs'],
    "vigayha": ['cped'],
    "vigaḍita": ['bhs'],
    "vigaṃdhakaḥ": ['ap90'],
    "vigaṇ": ['ap90', 'mw'],
    "vigaṇana": ['ddsa', 'mw'],
    "vigaṇanaṃ": ['ap90'],
    "vigaṇita": ['mw'],
    "vigaṇḍīra": ['mw'],
    "vigdhanta": ['bhs'],
    "viggaha": ['cped'],
    "viggayha": ['cped'],
    "viggāhikakathā": ['cped'],
    "vighana": ['cae', 'gra', 'mw'],
    "vighanatva": ['mw'],
    "vighanaḥ": ['ap90'],
    "vighanendu": ['mw'],
    "vighanin": ['gra', 'mw'],
    "vigharṣaṇa": ['cae', 'mw'],
    "vighasa": ['cae', 'mw'],
    "vighasaḥ": ['ap90'],
    "vighasāśa": ['mw'],
    "vighasāśin": ['cae', 'mw'],
    "vighaṭ": ['ap90', 'mw'],
    "vighaṭana": ['cae', 'ddsa', 'mw'],
    "vighaṭanaṃ": ['ap90'],
    "vighaṭikā": ['ap90', 'mw'],
    "vighaṭita": ['ap90', 'mw'],
    "vighaṭṭ": ['ap90', 'mw'],
    "vighaṭṭa": ['bhs'],
    "vighaṭṭana": ['cae', 'cped', 'mw'],
    "vighaṭṭanaṃ": ['ap90'],
    "vighaṭṭanā": ['mw'],
    "vighaṭṭanīya": ['mw'],
    "vighaṭṭin": ['mw'],
    "vighaṭṭita": ['ap90', 'mw'],
    "vighna": ['cae', 'ddsa', 'mw'],
    "vighnadhvaṃsa": ['mw'],
    "vighnahantṛ": ['mw'],
    "vighnahārin": ['mw'],
    "vighnajit": ['cae', 'mw'],
    "vighnaka": ['mw'],
    "vighnakara": ['cae', 'mw'],
    "vighnakartṛ": ['cae', 'mw'],
    "vighnakārin": ['cae', 'mw'],
    "vighnakṛt": ['cae', 'mw'],
    "vighnaleśa": ['mw'],
    "vighnanāyaka": ['mw'],
    "vighnanāśaka": ['mw'],
    "vighnanāśana": ['mw'],
    "vighnapati": ['cae', 'mw'],
    "vighnapratikriyā": ['mw'],
    "vighnarāj": ['cae', 'mw'],
    "vighnarāja": ['cae', 'ddsa', 'mw'],
    "vighnasiddhi": ['mw'],
    "vighnatantrita": ['mw'],
    "vighnavant": ['cae'],
    "vighnavat": ['mw'],
    "vighnavighāta": ['mw'],
    "vighnavināyaka": ['mw'],
    "vighnay": ['cae'],
    "vighnaya": ['ddsa', 'mw'],
    "vighnayati": ['ap90'],
    "vighnaḥ": ['ap90'],
    "vighneśa": ['cae', 'mw'],
    "vighneśadānavidhi": ['mw'],
    "vighneśakāntā": ['mw'],
    "vighneśavāhana": ['mw'],
    "vighneśvara": ['cae', 'mw'],
    "vighneśvarakavaca": ['mw'],
    "vighneśvarasahasranāman": ['mw'],
    "vighneśvarasaṃhitā": ['mw'],
    "vighneśvarāṣṭottaraśata": ['mw'],
    "vighneśāna": ['mw'],
    "vighneśānakāntā": ['mw'],
    "vighnita": ['ap90', 'mw'],
    "vighnitadṛṣṭipāta": ['mw'],
    "vighnitakarman": ['mw'],
    "vighnitapada": ['mw'],
    "vighnitasamāgamasukha": ['mw'],
    "vighniteccha": ['mw'],
    "vighnādhipa": ['mw'],
    "vighnāntaka": ['bhs', 'mw'],
    "vighnāri": ['bhs'],
    "vighoṣaṇa": ['mw'],
    "vighrā": ['mw'],
    "vighuṣ": ['mw'],
    "vighuṣṭa": ['bhs', 'mw'],
    "vighuṣṭakīrti": ['bhs'],
    "vighuṣṭaśabda": ['bhs'],
    "vighuṭṭha": ['bhs'],
    "vighāsa": ['cped'],
    "vighāsāda": ['cped'],
    "vighāta": ['bhs', 'cae', 'cped', 'mw'],
    "vighātaka": ['cae', 'mw'],
    "vighātana": ['cae', 'mw'],
    "vighātanasiddhi": ['mw'],
    "vighātaḥ": ['ap90'],
    "vighātenta": ['cped'],
    "vighātesi": ['cped'],
    "vighāteti": ['cped'],
    "vighātetvā": ['cped'],
    "vighātin": ['bhs', 'cae', 'mw'],
    "vighātita": ['cped'],
    "vighāṭana": ['bhs', 'cped'],
    "vighāṭayati": ['bhs'],
    "vighāṭesi": ['cped'],
    "vighāṭeti": ['cped'],
    "vighāṭetvā": ['cped'],
    "vighāṭita": ['cped'],
    "vighūrṇ": ['mw'],
    "vighūrṇana": ['cae', 'mw'],
    "vighūrṇita": ['ap90', 'mw'],
    "vighūṇikā": ['mw'],
    "vighṛta": ['cae', 'mw'],
    "vighṛṣṭa": ['ap90', 'cae', 'mw'],
    "viglai": ['mw'],
    "viglāpana": ['mw'],
    "vigna": ['ap90', 'mw'],
    "vigopa": ['mw'],
    "vigopita": ['bhs'],
    "vigra": ['ap90', 'cae', 'gra', 'mw'],
    "vigrah": ['ap90', 'mw'],
    "vigraha": ['cae', 'ddsa', 'mw'],
    "vigrahadhyāna": ['mw'],
    "vigrahagrahaṇa": ['mw'],
    "vigrahapara": ['mw'],
    "vigrahaparigraha": ['mw'],
    "vigrahapāladeva": ['mw'],
    "vigraharāja": ['ddsa', 'mw'],
    "vigrahavant": ['cae'],
    "vigrahavat": ['ap90', 'mw'],
    "vigrahavyāvartanī": ['mw'],
    "vigrahaya": ['ddsa', 'mw'],
    "vigrahaḥ": ['ap90'],
    "vigrahaṇa": ['cae', 'mw'],
    "vigrahecchu": ['mw'],
    "vigrahin": ['cae', 'ddsa', 'mw'],
    "vigrahāvara": ['mw'],
    "vigranth": ['mw'],
    "vigrath": ['mw'],
    "vigrathita": ['mw'],
    "vigrāha": ['mw'],
    "vigrāham": ['mw'],
    "vigrāhayati": ['bhs'],
    "vigrāhika": ['bhs'],
    "vigrāhin": ['bhs'],
    "vigrāhita": ['mw'],
    "vigrāhya": ['mw'],
    "vigrīva": ['ap90', 'ddsa', 'gra', 'mw'],
    "vigulpha": ['cae', 'mw'],
    "vigup": ['mw'],
    "viguṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "viguṇatā": ['mw'],
    "viguṇīkṛ": ['mw'],
    "vigā": ['mw'],
    "vigāh": ['ap90', 'mw'],
    "vigāha": ['cae', 'gra', 'mw'],
    "vigāhamāna": ['cped'],
    "vigāhana": ['bhs', 'cped'],
    "vigāhati": ['cped'],
    "vigāhaḥ": ['ap90'],
    "vigāhetvā": ['cped'],
    "vigāhi": ['cped'],
    "vigāhituṁ": ['cped'],
    "vigāhitvā": ['cped'],
    "vigāhya": ['mw'],
    "vigāman": ['cae', 'gra', 'mw'],
    "vigāna": ['ddsa', 'mw'],
    "vigānaṃ": ['ap90'],
    "vigāthā": ['cae', 'mw'],
    "vigāḍha": ['ap90', 'cae', 'mw'],
    "vigāḍhamanmatha": ['mw'],
    "vigāḍhṛ": ['mw'],
    "vigāḷha": ['cped'],
    "vigīta": ['ap90', 'cae', 'mw'],
    "vigītatva": ['ddsa', 'mw'],
    "vigīti": ['cae', 'mw'],
    "vigītiḥ": ['ap90'],
    "vigūḍha": ['ap90', 'cae', 'mw'],
    "vigūḍhacārin": ['mw'],
    "vigṛhya": ['cae', 'ddsa', 'mw'],
    "vigṛhyagamana": ['mw'],
    "vigṛhyasambhāṣā": ['mw'],
    "vigṛhyavāda": ['mw'],
    "vigṛhyayāna": ['mw'],
    "vigṛhyāsana": ['mw'],
    "vigṛhīta": ['ap90', 'mw'],
    "vigṝ": ['mw'],
    "viha": ['cae', 'ddsa', 'mw'],
    "vihaga": ['cae', 'cped', 'mw'],
    "vihagagādhipa": ['mw'],
    "vihagapati": ['cae', 'mw'],
    "vihagavega": ['mw'],
    "vihagaḥ": ['ap90'],
    "vihagendra": ['cae', 'mw'],
    "vihagendrasampāta": ['mw'],
    "vihagendrasaṃhitā": ['mw'],
    "vihagopaghuṣṭa": ['mw'],
    "vihagālaya": ['mw'],
    "vihalha": ['mw'],
    "vihan": ['ap90', 'mw'],
    "vihanana": ['mw'],
    "vihananaṃ": ['ap90'],
    "vihanati": ['cped'],
    "vihani": ['cped'],
    "vihanitvā": ['cped'],
    "vihantavya": ['mw'],
    "vihantvā": ['cped'],
    "vihantṛ": ['cae', 'gra', 'mw'],
    "vihanyita": ['bhs'],
    "vihara": ['cae', 'mw'],
    "viharamāna": ['cped'],
    "viharanta": ['cped'],
    "viharati": ['bhs', 'cped'],
    "viharaḥ": ['ap90'],
    "viharaṇa": ['cae', 'mw'],
    "viharaṇaṃ": ['ap90'],
    "viharaṇīya": ['mw'],
    "vihari": ['cped'],
    "viharitukāma": ['cped'],
    "viharitvā": ['cped'],
    "vihartṛ": ['ap90', 'cae', 'mw'],
    "vihary": ['mw'],
    "viharyata": ['gra'],
    "viharṣa": ['mw'],
    "viharṣaḥ": ['ap90'],
    "vihas": ['ap90', 'mw'],
    "vihasana": ['mw'],
    "vihasanaṃ": ['ap90'],
    "vihasatikā": ['mw'],
    "vihasita": ['mw'],
    "vihasitikā": ['mw'],
    "vihassati": ['cped'],
    "vihasta": ['ap90', 'cae', 'mw'],
    "vihastatā": ['mw'],
    "vihastita": ['mw'],
    "vihat": ['mw'],
    "vihata": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "vihati": ['cae', 'ddsa', 'mw'],
    "vihatiḥ": ['ap90'],
    "vihava": ['cae', 'gra', 'mw'],
    "vihavya": ['cae', 'mw'],
    "vihavyā": ['mw'],
    "vihavīya": ['mw'],
    "vihaññamāna": ['cped'],
    "vihaññati": ['cped'],
    "vihaññi": ['cped'],
    "vihaṁsu": ['cped'],
    "vihaṃga": ['cae', 'mw'],
    "vihaṃgahan": ['mw'],
    "vihaṃgaka": ['mw'],
    "vihaṃgama": ['cae', 'mw'],
    "vihaṃgamaḥ": ['ap90'],
    "vihaṃgamikā": ['mw'],
    "vihaṃgamā": ['ap90', 'mw'],
    "vihaṃgarāja": ['mw'],
    "vihaṃgavāṭī": ['cae'],
    "vihaṃgaḥ": ['ap90'],
    "vihaṃgikā": ['mw'],
    "vihaṃgārāti": ['mw'],
    "vihaṅga": ['ddsa'],
    "vihaṅgama": ['cped'],
    "vihel": ['mw'],
    "vihesaka": ['cped'],
    "viheseti": ['cped'],
    "vihesiyamāna": ['cped'],
    "vihesā": ['cped'],
    "viheṭh": ['mw'],
    "viheṭha": ['mw'],
    "viheṭhaka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "viheṭhakajātika": ['cped'],
    "viheṭhakaḥ": ['ap90'],
    "viheṭhana": ['bhs', 'cped', 'mw'],
    "viheṭhana-jātika": ['cped'],
    "viheṭhanaka": ['cped'],
    "viheṭhanaṃ": ['ap90'],
    "viheṭhanī": ['bhs'],
    "viheṭhayati": ['bhs'],
    "viheṭhaḥ": ['ap90'],
    "viheṭhenta": ['cped'],
    "viheṭhesi": ['cped'],
    "viheṭheti": ['cped'],
    "viheṭhetvā": ['cped'],
    "viheṭhika": ['bhs'],
    "viheṭhita": ['cped'],
    "viheṭhiyamāna": ['cped'],
    "viheṭhā": ['bhs'],
    "vihita": ['ap90', 'cae', 'cped', 'mw'],
    "vihitadurgaracana": ['mw'],
    "vihitakṣaṇa": ['mw'],
    "vihitapratiṣiddha": ['mw'],
    "vihitapratiṣiddhatva": ['mw'],
    "vihitasena": ['mw'],
    "vihitatva": ['mw'],
    "vihitavat": ['mw'],
    "vihitavṛtti": ['mw'],
    "vihitayajña": ['mw'],
    "vihitendriya": ['mw'],
    "vihiti": ['cae', 'mw'],
    "vihitiḥ": ['ap90'],
    "vihitrima": ['mw'],
    "vihitāgas": ['mw'],
    "vihitāñjali": ['mw'],
    "vihiṁsanta": ['cped'],
    "vihiṁsanā": ['cped'],
    "vihiṁsati": ['cped'],
    "vihiṁsi": ['cped'],
    "vihiṁsitvā": ['cped'],
    "vihiṁsā": ['cped'],
    "vihiṁsāvitakka": ['cped'],
    "vihiṃs": ['mw'],
    "vihiṃsaka": ['cae', 'ddsa', 'mw'],
    "vihiṃsana": ['mw'],
    "vihiṃsatā": ['cae', 'mw'],
    "vihiṃsita": ['mw'],
    "vihiṃsra": ['mw'],
    "vihiṃsā": ['mw'],
    "vihlaṇa": ['mw'],
    "vihmal": ['mw'],
    "vihnu": ['mw'],
    "vihradin": ['mw'],
    "vihru": ['mw'],
    "vihrut": ['cae', 'mw'],
    "vihruta": ['cae', 'mw'],
    "vihu": ['bhs'],
    "vihurch": ['mw'],
    "vihutmat": ['gra', 'mw'],
    "vihutmatī": ['mw'],
    "vihuṇḍana": ['mw'],
    "vihval": ['ap90', 'mw'],
    "vihvala": ['ap90', 'cae', 'ddsa', 'mw'],
    "vihvalacetana": ['mw'],
    "vihvalacetas": ['mw'],
    "vihvalahṛdaya": ['mw'],
    "vihvalalocana": ['mw'],
    "vihvalam": ['mw'],
    "vihvalasālasāṅga": ['mw'],
    "vihvalatanu": ['mw'],
    "vihvalatva": ['mw'],
    "vihvalatā": ['mw'],
    "vihvalita": ['mw'],
    "vihvalitasarvāṅga": ['mw'],
    "vihvalākṣa": ['mw'],
    "vihvalātman": ['mw'],
    "vihvalāṅga": ['mw'],
    "vihvalīkṛta": ['mw'],
    "vihvarita": ['mw'],
    "vihve": ['mw'],
    "vihvāruka": ['mw'],
    "vihvṛ": ['mw'],
    "vihā": ['ap90', 'mw'],
    "vihāna": ['mw'],
    "vihānyā": ['bhs'],
    "vihāpita": ['ap90', 'ddsa', 'mw'],
    "vihāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vihārabhadra": ['mw'],
    "vihārabhūmi": ['mw'],
    "vihāradeśa": ['cae', 'mw'],
    "vihāradāsī": ['cae', 'mw'],
    "vihāragṛha": ['mw'],
    "vihāraka": ['cae', 'mw'],
    "vihārakrīḍāmṛga": ['mw'],
    "vihārakārikā": ['mw'],
    "vihārasthalī": ['cae', 'mw'],
    "vihārasthāna": ['mw'],
    "vihāravana": ['cae', 'mw'],
    "vihāravant": ['cae'],
    "vihāravat": ['mw'],
    "vihāravāpī": ['mw'],
    "vihāravāri": ['cae', 'mw'],
    "vihārayātrā": ['mw'],
    "vihāraśaila": ['cae', 'mw'],
    "vihāraśayana": ['cae', 'mw'],
    "vihāraḥ": ['ap90'],
    "vihāraṇa": ['mw'],
    "vihārika": ['bhs', 'cped'],
    "vihārikā": ['ap90'],
    "vihārin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vihārisiṃha": ['mw'],
    "vihāriṇī": ['mw'],
    "vihāruhā": ['mw'],
    "vihārājira": ['mw'],
    "vihārāvasatha": ['cae', 'mw'],
    "vihārī": ['cped'],
    "vihāsa": ['cae', 'ddsa', 'mw'],
    "vihāsi": ['cped'],
    "vihāya": ['cae', 'cped', 'mw'],
    "vihāyas": ['ap90', 'cae', 'gra', 'mw'],
    "vihāyasa": ['ap90', 'mw'],
    "vihāyasastala": ['mw'],
    "vihāyasaḥsthalī": ['mw'],
    "vihāyasāgāmin": ['mw'],
    "vihīna": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vihīnatilaka": ['mw'],
    "vihīnatā": ['mw'],
    "vihīnavarṇa": ['mw'],
    "vihīnayoni": ['mw'],
    "vihīnita": ['mw'],
    "vihūrch": ['mw'],
    "vihṛ": ['ap90', 'mw'],
    "vihṛdaya": ['cae', 'mw'],
    "vihṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "vihṛtaṣoḍaśī": ['mw'],
    "vihṛti": ['cae', 'mw'],
    "vihṛtiḥ": ['ap90'],
    "vij": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vijaga": ['bhs'],
    "vijagdha": ['mw'],
    "vijagdhaka": ['mw'],
    "vijagha": ['bhs'],
    "vijahana": ['cped'],
    "vijahanatā": ['bhs'],
    "vijahanta": ['cped'],
    "vijahati": ['cped'],
    "vijahayati": ['bhs'],
    "vijahi": ['cped'],
    "vijahita": ['cped'],
    "vijahitabba": ['cped'],
    "vijahitvā": ['cped'],
    "vijala": ['mw'],
    "vijalpa": ['cae', 'mw'],
    "vijalpaḥ": ['ap90'],
    "vijalpita": ['ap90', 'mw'],
    "vijambha": ['bhs'],
    "vijambhanā": ['cped'],
    "vijambhati": ['cped'],
    "vijambhi": ['cped'],
    "vijambhikā": ['cped'],
    "vijambhitvā": ['cped'],
    "vijan": ['ap90', 'mw'],
    "vijana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vijanana": ['mw'],
    "vijananaṃ": ['ap90'],
    "vijanatā": ['mw'],
    "vijanavāta": ['cped'],
    "vijane": ['mw'],
    "vijaneṣu": ['mw'],
    "vijanita": ['mw'],
    "vijanman": ['ap90', 'cae', 'mw'],
    "vijanyā": ['mw'],
    "vijanīkṛ": ['mw'],
    "vijanīkṛta": ['mw'],
    "vijapila": ['mw'],
    "vijapilaṃ": ['ap90'],
    "vijara": ['ap90', 'cae', 'ddsa', 'mw'],
    "vijarjara": ['mw'],
    "vijarjarīkṛ": ['mw'],
    "vijarā": ['mw'],
    "vijavala": ['mw'],
    "vijaya": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vijayabhairava": ['mw'],
    "vijayabhaṭṭārikā": ['mw'],
    "vijayabhāga": ['mw'],
    "vijayabāhu": ['mw'],
    "vijayacandra": ['mw'],
    "vijayacchanda": ['mw'],
    "vijayadatta": ['cae', 'mw'],
    "vijayadaśamī": ['mw'],
    "vijayadaśamīnirṇaya": ['mw'],
    "vijayadaṇḍa": ['cae', 'mw'],
    "vijayadevī": ['mw'],
    "vijayadhvajatīrtha": ['mw'],
    "vijayadundubhi": ['mw'],
    "vijayadundubhitā": ['mw'],
    "vijayadvādaśī": ['mw'],
    "vijayadvādaśīvrata": ['mw'],
    "vijayadvāra": ['mw'],
    "vijayagaṇi": ['mw'],
    "vijayagovindasiṃha": ['mw'],
    "vijayahaṃsagaṇi": ['mw'],
    "vijayaikādaśī": ['mw'],
    "vijayaka": ['mw'],
    "vijayakalpalatā": ['mw'],
    "vijayakaṇṭaka": ['mw'],
    "vijayaketu": ['mw'],
    "vijayakuñjara": ['mw'],
    "vijayakṣetra": ['mw'],
    "vijayakṣetrabhaṭṭāgrahāra": ['mw'],
    "vijayalakṣmī": ['mw'],
    "vijayamahādevī": ['mw'],
    "vijayamalla": ['mw'],
    "vijayamardala": ['mw'],
    "vijayamaṅgaladīpikā": ['mw'],
    "vijayamitra": ['mw'],
    "vijayamādhava": ['mw'],
    "vijayamālikā": ['mw'],
    "vijayamālin": ['mw'],
    "vijayanagara": ['mw'],
    "vijayanandana": ['mw'],
    "vijayanandin": ['mw'],
    "vijayanta": ['mw'],
    "vijayantikā": ['mw'],
    "vijayantī": ['bhs', 'mw'],
    "vijayanātha": ['mw'],
    "vijayapatākā": ['mw'],
    "vijayaphala": ['mw'],
    "vijayaprakoṣṭha": ['mw'],
    "vijayapratyarthin": ['cae', 'mw'],
    "vijayapraśasti": ['mw'],
    "vijayapraśastikāvya": ['mw'],
    "vijayapura": ['mw'],
    "vijayapurakathā": ['mw'],
    "vijayapāla": ['mw'],
    "vijayapārijāta": ['mw'],
    "vijayapūrṇimā": ['mw'],
    "vijayarakṣita": ['mw'],
    "vijayarāghava": ['mw'],
    "vijayarāja": ['mw'],
    "vijayarāma": ['mw'],
    "vijayasaptamī": ['mw'],
    "vijayasena": ['mw'],
    "vijayasenā": ['bhs', 'mw'],
    "vijayasiddhi": ['mw'],
    "vijayasiṃha": ['mw'],
    "vijayastotrabaṭuka": ['mw'],
    "vijayati": ['cped'],
    "vijayatīrtha": ['mw'],
    "vijayavant": ['cae'],
    "vijayavarman": ['cae', 'mw'],
    "vijayavat": ['mw'],
    "vijayavatī": ['mw'],
    "vijayavega": ['mw'],
    "vijayavikrāmin": ['bhs'],
    "vijayavilāsa": ['mw'],
    "vijayayantrakalpa": ['mw'],
    "vijayaśrī": ['bhs', 'mw'],
    "vijayaḍiṇḍima": ['mw'],
    "vijayaḥ": ['ap90'],
    "vijayaṃtaḥ": ['ap90'],
    "vijayendraparābhava": ['mw'],
    "vijayeśa": ['mw'],
    "vijayeśasahasranāman": ['mw'],
    "vijayeśvara": ['mw'],
    "vijayeśvaramāhātmya": ['mw'],
    "vijayi": ['cped'],
    "vijayikṣetra": ['mw'],
    "vijayin": ['ap90', 'cae', 'mw'],
    "vijayina": ['mw'],
    "vijayiṣṭha": ['mw'],
    "vijayollāsa": ['mw'],
    "vijayotsava": ['mw'],
    "vijayā": ['ap90', 'bhs', 'ddsa', 'mw'],
    "vijayābhinandana": ['mw'],
    "vijayābhyupāya": ['mw'],
    "vijayādaśamī": ['mw'],
    "vijayāditya": ['mw'],
    "vijayākalpa": ['mw'],
    "vijayānanda": ['mw'],
    "vijayāparājitāstotra": ['mw'],
    "vijayārahasya": ['mw'],
    "vijayārdha": ['mw'],
    "vijayārtham": ['mw'],
    "vijayārthin": ['mw'],
    "vijayāsaptamī": ['mw'],
    "vijayāṅkā": ['mw'],
    "vijayīndra": ['mw'],
    "vijañjapa": ['mw'],
    "vijaṅgha": ['mw'],
    "vijaṅghākūbara": ['mw'],
    "vijaṭa": ['ddsa', 'mw'],
    "vijaṭana": ['cped'],
    "vijaṭesi": ['cped'],
    "vijaṭeti": ['cped'],
    "vijaṭetvā": ['cped'],
    "vijaṭita": ['cped'],
    "vijaṭāpayati": ['bhs'],
    "vijaṭīkṛ": ['mw'],
    "vijeh": ['mw'],
    "vijenia": ['gra'],
    "vijenya": ['gra', 'mw'],
    "vijetavya": ['cae', 'mw'],
    "vijetṛ": ['cae', 'mw'],
    "vijeya": ['mw'],
    "vijeyavilāsa": ['mw'],
    "vijeṣa": ['gra'],
    "vijeṣakṛt": ['gra', 'mw'],
    "vijharjhara": ['mw'],
    "viji": ['ap90', 'mw'],
    "vijighatsa": ['mw'],
    "vijighāṃsu": ['mw'],
    "vijighṛkṣu": ['mw'],
    "vijigrāhayiṣu": ['mw'],
    "vijigupsati": ['bhs'],
    "vijigīta": ['mw'],
    "vijigīṣa": ['mw'],
    "vijigīṣin": ['mw'],
    "vijigīṣu": ['ap90', 'mw'],
    "vijigīṣutva": ['mw'],
    "vijigīṣutā": ['mw'],
    "vijigīṣā": ['cae', 'ddsa', 'mw'],
    "vijigīṣāvat": ['mw'],
    "vijigīṣāvivarjita": ['mw'],
    "vijigīṣīya": ['mw'],
    "vijihma": ['ap90', 'cae', 'mw'],
    "vijihmatva": ['mw'],
    "vijihmatā": ['mw'],
    "vijihva": ['cae', 'mw'],
    "vijihīrṣu": ['mw'],
    "vijihīrṣā": ['mw'],
    "vijijñāpayiṣā": ['mw'],
    "vijijñāsitavya": ['mw'],
    "vijijñāsu": ['mw'],
    "vijijñāsya": ['mw'],
    "vijijñāsā": ['mw'],
    "vijila": ['mw'],
    "vijilabindu": ['mw'],
    "vijina": ['mw'],
    "vijinaḥ": ['ap90'],
    "vijināti": ['cped'],
    "vijipila": ['mw'],
    "vijita": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "vijitarūpa": ['mw'],
    "vijitasaṅgāma": ['cped'],
    "vijitavant": ['bhs'],
    "vijitavat": ['mw'],
    "vijitendriya": ['cae', 'mw'],
    "vijiti": ['cae', 'mw'],
    "vijitin": ['cae', 'mw'],
    "vijitiḥ": ['ap90'],
    "vijitvara": ['mw'],
    "vijitvaratva": ['mw'],
    "vijitvarā": ['mw'],
    "vijitā": ['bhs'],
    "vijitāmitra": ['mw'],
    "vijitāri": ['mw'],
    "vijitāsana": ['mw'],
    "vijitāsu": ['mw'],
    "vijitātman": ['mw'],
    "vijitāvin": ['bhs'],
    "vijitāvī": ['cped'],
    "vijitāśva": ['mw'],
    "vijitṛ": ['ap90', 'mw'],
    "vijivila": ['mw'],
    "vijja": ['cae', 'ddsa', 'mw'],
    "vijjakā": ['mw'],
    "vijjala": ['cae', 'ddsa', 'mw'],
    "vijjalapura": ['mw'],
    "vijjalaviḍa": ['mw'],
    "vijjalā": ['mw'],
    "vijjamāna": ['cped'],
    "vijjanaṃ": ['ap90'],
    "vijjanta": ['cped'],
    "vijjantarikā": ['cped'],
    "vijjanāman": ['mw'],
    "vijjarāja": ['mw'],
    "vijjati": ['cped'],
    "vijjhamāna": ['cped'],
    "vijjhana": ['cped'],
    "vijjhanta": ['cped'],
    "vijjhati": ['bhs', 'cped'],
    "vijjhi": ['cped'],
    "vijjhitvā": ['cped'],
    "vijjhiya": ['cped'],
    "vijjhāpeti": ['cped'],
    "vijjhāpita": ['cped'],
    "vijjhāyati": ['cped'],
    "vijjhāyi": ['cped'],
    "vijjikā": ['mw'],
    "vijjila": ['ap90'],
    "vijjotamāna": ['cped'],
    "vijjotati": ['cped'],
    "vijjoti": ['cped'],
    "vijjotita": ['cped'],
    "vijju": ['cped'],
    "vijjula": ['mw'],
    "vijjulaṃ": ['ap90'],
    "vijjullatā": ['cped'],
    "vijjutā": ['cped'],
    "vijjā": ['cped', 'mw'],
    "vijjācaraṇa": ['cped'],
    "vijjādhara": ['cped'],
    "vijjākā": ['mw'],
    "vijjāvimutti": ['cped'],
    "vijjāṭṭhāna": ['cped'],
    "vijjūlikā": ['mw'],
    "vijoṣas": ['gra', 'mw'],
    "viju": ['cae', 'mw'],
    "vijugupsaka": ['bhs'],
    "vijugupsanatā": ['bhs'],
    "vijula": ['mw'],
    "vijulaḥ": ['ap90'],
    "vijvara": ['ap90', 'cae', 'mw'],
    "vijya": ['cae', 'mw'],
    "vijña": ['ap90', 'cae', 'ddsa', 'mw'],
    "vijñabuddhi": ['mw'],
    "vijñapana": ['bhs'],
    "vijñapayati": ['bhs'],
    "vijñapta": ['ap90', 'mw'],
    "vijñapti": ['bhs', 'cae', 'mw'],
    "vijñaptika": ['bhs'],
    "vijñaptikā": ['mw'],
    "vijñaptiḥ": ['ap90'],
    "vijñapya": ['mw'],
    "vijñarāja": ['mw'],
    "vijñatva": ['mw'],
    "vijñatā": ['mw'],
    "vijñeya": ['cae', 'mw'],
    "vijñeyatva": ['mw'],
    "vijñin": ['bhs'],
    "vijñu": ['bhs'],
    "vijñā": ['ap90', 'bhs', 'mw'],
    "vijñābhimānin": ['mw'],
    "vijñāna": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vijñānabhairava": ['mw'],
    "vijñānabhairavoddyotasaṃgraha": ['mw'],
    "vijñānabhaṭṭāraka": ['mw'],
    "vijñānabhikṣu": ['mw'],
    "vijñānabhārata": ['mw'],
    "vijñānadeśana": ['mw'],
    "vijñānaghana": ['mw'],
    "vijñānaikaskandhavāda": ['mw'],
    "vijñānaka": ['bhs'],
    "vijñānakanda": ['mw'],
    "vijñānakaumudī": ['mw'],
    "vijñānakevala": ['mw'],
    "vijñānakāya": ['mw'],
    "vijñānakṛtsna": ['mw'],
    "vijñānalalita": ['mw'],
    "vijñānalalitatantra": ['mw'],
    "vijñānalatikā": ['mw'],
    "vijñānamaya": ['cae', 'mw'],
    "vijñānamayakoṣa": ['mw'],
    "vijñānamātṛka": ['mw'],
    "vijñānanaukā": ['mw'],
    "vijñānanā": ['bhs', 'mw'],
    "vijñānapati": ['mw'],
    "vijñānapāda": ['mw'],
    "vijñānasaṃjñāprakaraṇa": ['mw'],
    "vijñānatailagarbha": ['mw'],
    "vijñānataraṃgiṇī": ['mw'],
    "vijñānatā": ['mw'],
    "vijñānatārāvalī": ['mw'],
    "vijñānavant": ['cae'],
    "vijñānavat": ['mw'],
    "vijñānavilāsa": ['mw'],
    "vijñānavinodinīṭīkā": ['mw'],
    "vijñānavāda": ['mw'],
    "vijñānavādin": ['bhs', 'mw'],
    "vijñānayati": ['mw'],
    "vijñānayogin": ['mw'],
    "vijñānaśikṣā": ['mw'],
    "vijñānaśāstra": ['mw'],
    "vijñānaṃ": ['ap90'],
    "vijñāneśvara": ['mw'],
    "vijñāneśvaratantra": ['mw'],
    "vijñāneśvaravārttika": ['mw'],
    "vijñāneśvarīya": ['mw'],
    "vijñānika": ['ap90', 'mw'],
    "vijñānin": ['cae', 'mw'],
    "vijñānitā": ['ddsa', 'mw'],
    "vijñānācārya": ['mw'],
    "vijñānāhāra": ['bhs', 'mw'],
    "vijñānākala": ['mw'],
    "vijñānāmṛta": ['mw'],
    "vijñānānantyāyatana": ['bhs'],
    "vijñānānantyāyatanopaga": ['bhs'],
    "vijñānāntyāyatana": ['mw'],
    "vijñānāstitvamātravādin": ['mw'],
    "vijñānātman": ['mw'],
    "vijñānāśrama": ['mw'],
    "vijñānīya": ['mw'],
    "vijñāpaka": ['bhs', 'mw'],
    "vijñāpakaḥ": ['ap90'],
    "vijñāpana": ['bhs', 'cae', 'mw'],
    "vijñāpanaṃ": ['ap90'],
    "vijñāpanīya": ['bhs', 'cae', 'mw'],
    "vijñāpin": ['mw'],
    "vijñāpita": ['ap90', 'mw'],
    "vijñāpti": ['ap90', 'mw'],
    "vijñāpya": ['cae', 'mw'],
    "vijñāpyaṃ": ['ap90'],
    "vijñāta": ['ap90', 'mw'],
    "vijñātasthālī": ['mw'],
    "vijñātavya": ['cae', 'mw'],
    "vijñātavīrya": ['mw'],
    "vijñāti": ['cae', 'mw'],
    "vijñātārtha": ['mw'],
    "vijñātātman": ['mw'],
    "vijñātṛ": ['cae', 'mw'],
    "vijñāya": ['gra', 'mw'],
    "vijñīpsu": ['mw'],
    "vijāga": ['bhs'],
    "vijāla": ['bhs'],
    "vijāman": ['gra', 'mw'],
    "vijāmi": ['cae', 'gra', 'mw'],
    "vijāmātṛ": ['gra', 'mw'],
    "vijāna": ['mw'],
    "vijānaka": ['mw'],
    "vijānana": ['bhs', 'cped'],
    "vijānanta": ['cped'],
    "vijānat": ['mw'],
    "vijānatā": ['mw'],
    "vijāni": ['cped', 'mw'],
    "vijānitabba": ['cped'],
    "vijānituṁ": ['cped'],
    "vijānitvā": ['cped'],
    "vijāniya": ['cped'],
    "vijānu": ['mw'],
    "vijānuṣas": ['gra'],
    "vijānāti": ['cped'],
    "vijāpayitṛ": ['mw'],
    "vijāta": ['ap90', 'cae', 'cped', 'mw'],
    "vijāti": ['mw'],
    "vijātika": ['cped'],
    "vijātiḥ": ['ap90'],
    "vijātā": ['cped', 'mw'],
    "vijātīya": ['ap90', 'cae', 'mw'],
    "vijāvan": ['cae', 'gra', 'mw'],
    "vijāvatī": ['cae', 'mw'],
    "vijāyamānā": ['cped'],
    "vijāyana": ['cped'],
    "vijāyantī": ['cped'],
    "vijāyati": ['cped'],
    "vijāyi": ['cped'],
    "vijāyinī": ['cped'],
    "vijāyitvā": ['cped'],
    "vijīv": ['mw'],
    "vijīvita": ['mw'],
    "vijṛmbh": ['mw'],
    "vijṛmbha": ['cae', 'mw'],
    "vijṛmbhaka": ['mw'],
    "vijṛmbhaṇa": ['cae', 'mw'],
    "vijṛmbhikā": ['mw'],
    "vijṛmbhin": ['cae', 'mw'],
    "vijṛmbhita": ['cae', 'mw'],
    "vijṛmbhā": ['mw'],
    "vijṛṃbh": ['ap90'],
    "vijṛṃbhaṇaṃ": ['ap90'],
    "vijṛṃbhita": ['ap90'],
    "vika": ['cae', 'mw'],
    "vikaca": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vikacay": ['cae'],
    "vikacaya": ['mw'],
    "vikacaśrī": ['mw'],
    "vikaccha": ['mw'],
    "vikacchapa": ['mw'],
    "vikacita": ['mw'],
    "vikacā": ['mw'],
    "vikacālambā": ['mw'],
    "vikacānana": ['mw'],
    "vikacīkṛ": ['ap90', 'mw'],
    "vikadru": ['mw'],
    "vikakara": ['mw'],
    "vikal": ['ap90'],
    "vikala": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vikalaka": ['cped'],
    "vikalapāṇika": ['mw'],
    "vikalatva": ['mw'],
    "vikalatā": ['mw'],
    "vikalavadha": ['mw'],
    "vikalay": ['cae'],
    "vikalaya": ['mw'],
    "vikalayati": ['ap90'],
    "vikalaṅka": ['mw'],
    "vikalaṅkatā": ['mw'],
    "vikalendriya": ['cae', 'mw'],
    "vikalmaṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vikalpa": ['bhs', 'cae', 'ddsa', 'mw'],
    "vikalpajāla": ['mw'],
    "vikalpaka": ['bhs', 'cae', 'mw'],
    "vikalpana": ['bhs', 'cae', 'mw'],
    "vikalpananīya": ['mw'],
    "vikalpanaṃ": ['ap90'],
    "vikalpasama": ['mw'],
    "vikalpatva": ['mw'],
    "vikalpavant": ['cae'],
    "vikalpavat": ['mw'],
    "vikalpayati": ['bhs'],
    "vikalpayitavya": ['mw'],
    "vikalpaḥ": ['ap90'],
    "vikalpena": ['mw'],
    "vikalpin": ['cae', 'mw'],
    "vikalpita": ['bhs', 'mw'],
    "vikalpitatva": ['mw'],
    "vikalpopahāra": ['mw'],
    "vikalpya": ['mw'],
    "vikalpā": ['bhs'],
    "vikalpānupapatti": ['mw'],
    "vikalpāsaha": ['mw'],
    "vikalpāsahatva": ['mw'],
    "vikalya": ['mw'],
    "vikalā": ['ap90', 'mw'],
    "vikalāṅga": ['mw'],
    "vikalīkaraṇaṃ": ['ap90'],
    "vikalīkṛ": ['ap90', 'cae', 'mw'],
    "vikamp": ['mw'],
    "vikampa": ['mw'],
    "vikampamāna": ['cped'],
    "vikampana": ['bhs', 'cped', 'mw'],
    "vikampati": ['cped'],
    "vikampi": ['cped'],
    "vikampin": ['cae', 'mw'],
    "vikampita": ['cped', 'mw'],
    "vikampitvā": ['cped'],
    "vikantana": ['cped'],
    "vikantati": ['cped'],
    "vikanti": ['cped'],
    "vikantita": ['cped'],
    "vikantitvā": ['cped'],
    "vikapita": ['mw'],
    "vikappa": ['cped'],
    "vikappana": ['cped'],
    "vikappenta": ['cped'],
    "vikappesi": ['cped'],
    "vikappeti": ['cped'],
    "vikappetvā": ['cped'],
    "vikappita": ['cped'],
    "vikapāla": ['mw'],
    "vikara": ['bhs', 'cae', 'mw'],
    "vikaraḥ": ['ap90'],
    "vikaraṇa": ['bhs', 'cae', 'mw'],
    "vikaraṇatva": ['mw'],
    "vikaraṇaḥ": ['ap90'],
    "vikaraṇī": ['mw'],
    "vikari": ['cped'],
    "vikarin": ['bhs'],
    "vikarmakriyā": ['cae', 'mw'],
    "vikarmakṛt": ['mw'],
    "vikarman": ['ap90', 'cae', 'mw'],
    "vikarmanirata": ['mw'],
    "vikarmastha": ['cae', 'mw'],
    "vikarmika": ['ap90', 'mw'],
    "vikarmin": ['cae', 'mw'],
    "vikaroti": ['cped'],
    "vikarta": ['mw'],
    "vikartana": ['bhs', 'cae', 'ddsa', 'mw'],
    "vikartanaḥ": ['ap90'],
    "vikartita": ['mw'],
    "vikarttṛ": ['mw'],
    "vikartṛ": ['cae', 'mw'],
    "vikarya": ['mw'],
    "vikarāla": ['ap90', 'bhs', 'mw'],
    "vikarālamukha": ['mw'],
    "vikarālatā": ['mw'],
    "vikarālin": ['mw'],
    "vikarālā": ['mw'],
    "vikarṇa": ['cae', 'gra', 'mw'],
    "vikarṇaka": ['mw'],
    "vikarṇaḥ": ['ap90'],
    "vikarṇika": ['mw'],
    "vikarṇikā": ['mw'],
    "vikarṇin": ['mw'],
    "vikarṇī": ['mw'],
    "vikarṣa": ['cae', 'mw'],
    "vikarṣaḥ": ['ap90'],
    "vikarṣaṇa": ['cae', 'mw'],
    "vikarṣaṇaḥ": ['ap90'],
    "vikarṣin": ['mw'],
    "vikas": ['ap90', 'mw'],
    "vikasa": ['mw'],
    "vikasana": ['mw'],
    "vikasat": ['mw'],
    "vikasati": ['cped'],
    "vikasaḥ": ['ap90'],
    "vikasi": ['cped'],
    "vikasita": ['ap90', 'cped', 'mw'],
    "vikasitakumudendīvarālokin": ['mw'],
    "vikasitanayanavadanakamala": ['mw'],
    "vikasitavadana": ['mw'],
    "vikasitvā": ['cped'],
    "vikasta": ['mw'],
    "vikasti": ['cae', 'mw'],
    "vikasuka": ['mw'],
    "vikasvara": ['ap90', 'cae', 'mw'],
    "vikasvarūpa": ['mw'],
    "vikasā": ['ap90', 'mw'],
    "vikata": ['cped'],
    "vikathā": ['mw'],
    "vikati": ['cped'],
    "vikatika": ['cped'],
    "vikatth": ['ap90', 'mw'],
    "vikatthaka": ['cped'],
    "vikatthana": ['ap90', 'cae', 'cped', 'mw'],
    "vikatthanatva": ['mw'],
    "vikatthanīya": ['mw'],
    "vikatthati": ['cped'],
    "vikatthi": ['cped'],
    "vikatthin": ['mw'],
    "vikatthita": ['cped', 'mw'],
    "vikatthitvā": ['cped'],
    "vikatthā": ['ap90', 'cae', 'mw'],
    "vikatthī": ['cped'],
    "vikautuka": ['cae', 'ddsa', 'mw'],
    "vikavaca": ['cae', 'mw'],
    "vikaśvara": ['ap90', 'mw'],
    "vikaśyapa": ['mw'],
    "vikaḍḍhate": ['bhs'],
    "vikaṃ": ['ap90'],
    "vikaṃkaṭaḥ": ['ap90'],
    "vikaṃp": ['ap90'],
    "vikaṃpa": ['ap90'],
    "vikaṃpita": ['ap90'],
    "vikaṃsā": ['mw'],
    "vikaṅkata": ['cae', 'ddsa', 'mw'],
    "vikaṅkatā": ['mw'],
    "vikaṅkatīmukha": ['mw'],
    "vikaṅkaṭa": ['mw'],
    "vikaṅkaṭika": ['mw'],
    "vikaṇṭaka": ['mw'],
    "vikaṇṭakapura": ['mw'],
    "vikaṣā": ['ap90'],
    "vikaṭa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vikaṭagrāma": ['mw'],
    "vikaṭaka": ['bhs', 'mw'],
    "vikaṭam": ['mw'],
    "vikaṭamūrti": ['mw'],
    "vikaṭanitambā": ['mw'],
    "vikaṭatva": ['mw'],
    "vikaṭavadana": ['mw'],
    "vikaṭavarman": ['mw'],
    "vikaṭaviṣāṇa": ['mw'],
    "vikaṭaśṛṅga": ['mw'],
    "vikaṭaṃkaṭa": ['bhs'],
    "vikaṭā": ['mw'],
    "vikaṭābha": ['mw'],
    "vikaṭākṛti": ['mw'],
    "vikaṭākṣa": ['cae', 'mw'],
    "vikaṭānana": ['cae', 'mw'],
    "vikaṭāsya": ['bhs'],
    "vikaṭīkṛ": ['ddsa', 'mw'],
    "viketu": ['cae', 'mw'],
    "vikeśa": ['ap90', 'cae', 'mw'],
    "vikeśikā": ['mw'],
    "vikeśī": ['mw'],
    "vikha": ['ap90', 'mw'],
    "vikhala": ['bhs'],
    "vikhan": ['mw'],
    "vikhanana": ['mw'],
    "vikhanas": ['cae', 'mw'],
    "vikhata": ['bhs'],
    "vikhaṃḍita": ['ap90'],
    "vikhaṇḍin": ['mw'],
    "vikhaṇḍita": ['mw'],
    "vikheda": ['cae', 'mw'],
    "vikhid": ['mw'],
    "vikhinna": ['bhs'],
    "vikhra": ['ap90', 'mw'],
    "vikhru": ['ap90', 'mw'],
    "vikhu": ['ap90'],
    "vikhura": ['mw'],
    "vikhuraḥ": ['ap90'],
    "vikhya": ['ap90'],
    "vikhyā": ['ap90', 'mw'],
    "vikhyāpana": ['cae', 'mw'],
    "vikhyāpanaṃ": ['ap90'],
    "vikhyāta": ['ap90', 'bhs', 'cae', 'mw'],
    "vikhyāti": ['cae', 'ddsa', 'mw'],
    "vikhyātiḥ": ['ap90'],
    "vikhāda": ['cae', 'gra', 'mw'],
    "vikhādati": ['bhs'],
    "vikhāditaka": ['bhs', 'mw'],
    "vikhānasa": ['mw'],
    "vikhānasaḥ": ['ap90'],
    "vikhāsā": ['ap90', 'mw'],
    "vikipenta": ['cped'],
    "vikira": ['bhs', 'cae', 'ddsa', 'mw'],
    "vikiramāna": ['cped'],
    "vikiranta": ['cped'],
    "vikirati": ['cped'],
    "vikiraḥ": ['ap90'],
    "vikiraṇa": ['bhs', 'cae', 'cped', 'mw'],
    "vikiraṇaṃ": ['ap90'],
    "vikiri": ['cped'],
    "vikirida": ['mw'],
    "vikiridra": ['mw'],
    "vikiritvā": ['cped'],
    "vikiriḍa": ['mw'],
    "vikirīyati": ['cped'],
    "vikiṇṇa": ['cped'],
    "vikiṇṇakesa": ['cped'],
    "vikiṣku": ['mw'],
    "vikiṭi": ['bhs'],
    "vikka": ['mw'],
    "vikkama": ['cped'],
    "vikkamana": ['cped'],
    "vikkamati": ['cped'],
    "vikkambha": ['cped'],
    "vikkami": ['cped'],
    "vikkandati": ['cped'],
    "vikkanta": ['cped'],
    "vikkaya": ['cped'],
    "vikkayika": ['cped'],
    "vikkaḥ": ['ap90'],
    "vikketar": ['cped'],
    "vikkhambhana": ['cped'],
    "vikkhambhenta": ['cped'],
    "vikkhambhesi": ['cped'],
    "vikkhambheti": ['cped'],
    "vikkhambhetvā": ['cped'],
    "vikkhambhita": ['cped'],
    "vikkhepa": ['cped'],
    "vikkhepaka": ['cped'],
    "vikkhipana": ['cped'],
    "vikkhipanta": ['cped'],
    "vikkhipati": ['cped'],
    "vikkhipi": ['cped'],
    "vikkhipitvā": ['cped'],
    "vikkhitta": ['cped'],
    "vikkhittacitta": ['cped'],
    "vikkhittaka": ['cped'],
    "vikkhobhana": ['cped'],
    "vikkhobhesi": ['cped'],
    "vikkhobheti": ['cped'],
    "vikkhobhetvā": ['cped'],
    "vikkhobhita": ['cped'],
    "vikkhālesi": ['cped'],
    "vikkhāleti": ['cped'],
    "vikkhāletvā": ['cped'],
    "vikkhālita": ['cped'],
    "vikkiṇanta": ['cped'],
    "vikkiṇi": ['cped'],
    "vikkiṇituṁ": ['cped'],
    "vikkiṇitvā": ['cped'],
    "vikkiṇāti": ['cped'],
    "vikkāyika": ['cped'],
    "vikkāyikabhaṇḍa": ['cped'],
    "viklam": ['mw'],
    "viklambhayati": ['bhs'],
    "viklav": ['mw'],
    "viklava": ['ap90', 'cae', 'ddsa', 'mw'],
    "viklavatva": ['mw'],
    "viklavatā": ['mw'],
    "viklavaya": ['mw'],
    "viklavita": ['mw'],
    "viklavānana": ['mw'],
    "viklavī": ['mw'],
    "viklavībhū": ['mw'],
    "viklavīkṛ": ['mw'],
    "vikleda": ['cae', 'mw'],
    "vikledana": ['mw'],
    "vikledaḥ": ['ap90'],
    "vikledīyas": ['mw'],
    "vikleśa": ['mw'],
    "vikleśaḥ": ['ap90'],
    "viklidha": ['mw'],
    "viklindu": ['mw'],
    "viklinna": ['ap90', 'cae', 'mw'],
    "viklinnahṛdaya": ['mw'],
    "viklitti": ['mw'],
    "vikliṣṭa": ['ap90', 'cae', 'mw'],
    "viklānta": ['cae', 'mw'],
    "viklī": ['mw'],
    "vikoka": ['mw'],
    "vikopana": ['cped'],
    "vikopayati": ['bhs'],
    "vikopesi": ['cped'],
    "vikopeti": ['cped'],
    "vikopetvā": ['cped'],
    "vikopita": ['cped'],
    "vikośa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vikram": ['ap90', 'mw'],
    "vikrama": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vikramabhārata": ['mw'],
    "vikramabāhu": ['cae', 'mw'],
    "vikramacandrikā": ['mw'],
    "vikramacarita": ['mw'],
    "vikramacaritra": ['mw'],
    "vikramacaṇḍa": ['mw'],
    "vikramadeva": ['mw'],
    "vikramaka": ['mw'],
    "vikramakarman": ['mw'],
    "vikramakesarin": ['cae', 'mw'],
    "vikramalāñchana": ['mw'],
    "vikramanareśvara": ['mw'],
    "vikramanavaratna": ['mw'],
    "vikramanidhi": ['mw'],
    "vikramapati": ['mw'],
    "vikramapaṭṭana": ['mw'],
    "vikramaprabandha": ['mw'],
    "vikramapura": ['cae', 'mw'],
    "vikramapurī": ['mw'],
    "vikramarddhi": ['mw'],
    "vikramarāja": ['mw'],
    "vikramarājan": ['mw'],
    "vikramasabhā": ['mw'],
    "vikramasena": ['cae', 'mw'],
    "vikramasenacampū": ['mw'],
    "vikramasiṃha": ['cae', 'mw'],
    "vikramasthāna": ['mw'],
    "vikramatuṅga": ['ddsa', 'mw'],
    "vikramaśakti": ['mw'],
    "vikramaśīla": ['mw'],
    "vikramaḥ": ['ap90'],
    "vikramaṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "vikramaṇadharmitva": ['mw'],
    "vikramaṇaṃ": ['ap90'],
    "vikrameśa": ['mw'],
    "vikrameśvara": ['ddsa', 'mw'],
    "vikramin": ['ap90', 'cae', 'ddsa', 'mw'],
    "vikramodaya": ['mw'],
    "vikramopākhyāna": ['mw'],
    "vikramorvaśī": ['cae', 'ddsa', 'mw'],
    "vikramāditya": ['cae', 'mw'],
    "vikramādityacaritra": ['mw'],
    "vikramādityakośa": ['mw'],
    "vikramādityarāja": ['mw'],
    "vikramārjita": ['mw'],
    "vikramārka": ['mw'],
    "vikramārkacarita": ['mw'],
    "vikramārkacaritra": ['mw'],
    "vikramāt": ['mw'],
    "vikramāṅka": ['cae', 'mw'],
    "vikramāṅkadeva": ['cae'],
    "vikramāṅkadevacarita": ['cae'],
    "vikramīya": ['mw'],
    "vikrandati": ['bhs'],
    "vikrasra": ['mw'],
    "vikrasraḥ": ['ap90'],
    "vikraya": ['cae', 'ddsa', 'mw'],
    "vikrayaka": ['cae', 'mw'],
    "vikrayapattra": ['mw'],
    "vikrayaḥ": ['ap90'],
    "vikrayaṇa": ['mw'],
    "vikrayika": ['cae', 'mw'],
    "vikrayikaḥ": ['ap90'],
    "vikrayin": ['cae', 'mw'],
    "vikrayya": ['cae', 'mw'],
    "vikrayānuśaya": ['mw'],
    "vikrayārtham": ['mw'],
    "vikretavya": ['cae', 'mw'],
    "vikreti": ['bhs'],
    "vikretṛ": ['cae', 'mw'],
    "vikreya": ['ap90', 'cae', 'mw'],
    "vikriyopamā": ['cae', 'mw'],
    "vikriyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "vikriḍa": ['mw'],
    "vikriṇati": ['bhs'],
    "vikrodha": ['cae', 'mw'],
    "vikrośa": ['cae', 'mw'],
    "vikrośana": ['cae', 'mw'],
    "vikrośanaṃ": ['ap90'],
    "vikrośayitṛ": ['mw'],
    "vikroṣṭṛ": ['cae', 'mw'],
    "vikruś": ['ap90', 'mw'],
    "vikruṣṭa": ['ap90', 'cae', 'mw'],
    "vikrāma": ['cae', 'mw'],
    "vikrāmin": ['bhs'],
    "vikrānta": ['cae', 'ddsa', 'mw'],
    "vikrāntabhīma": ['mw'],
    "vikrāntadevagati": ['bhs'],
    "vikrāntagati": ['mw'],
    "vikrāntagāmin": ['bhs'],
    "vikrāntaplutam": ['cae'],
    "vikrāntayodhin": ['mw'],
    "vikrāntaśūdraka": ['mw'],
    "vikrānti": ['cae', 'mw'],
    "vikrāntivarman": ['mw'],
    "vikrāntā": ['mw'],
    "vikrāntṛ": ['mw'],
    "vikrāyaka": ['cae', 'ddsa'],
    "vikrāyati": ['bhs'],
    "vikrāyika": ['mw'],
    "vikrāṃta": ['ap90'],
    "vikrāṃtiḥ": ['ap90'],
    "vikrāṃtṛ": ['ap90'],
    "vikrī": ['ap90', 'mw'],
    "vikrīta": ['mw'],
    "vikrītikā": ['bhs'],
    "vikrīya": ['bhs'],
    "vikrīḍ": ['mw'],
    "vikrīḍa": ['cae', 'ddsa', 'mw'],
    "vikrīḍana": ['bhs'],
    "vikrīḍita": ['bhs', 'cae', 'mw'],
    "vikrīḍā": ['mw'],
    "vikrīṇati": ['bhs'],
    "vikta": ['mw'],
    "vikubbana": ['cped'],
    "vikubbati": ['cped'],
    "vikubbi": ['cped'],
    "vikubbita": ['cped'],
    "vikucita": ['mw'],
    "vikughāsa": ['mw'],
    "vikuja": ['mw'],
    "vikujaravīndu": ['mw'],
    "vikukṣi": ['cae', 'ddsa', 'mw'],
    "vikukṣitva": ['mw'],
    "vikulāva": ['cped'],
    "vikumbhāṇḍa": ['mw'],
    "vikup": ['mw'],
    "vikurvati": ['bhs'],
    "vikurvaṇa": ['bhs', 'mw'],
    "vikurvaṇā": ['bhs'],
    "vikurvita": ['bhs', 'mw'],
    "vikurvitaprabha": ['bhs'],
    "vikurvā": ['bhs', 'mw'],
    "vikurvāṇa": ['ap90', 'mw'],
    "vikurvāṇarājaparipṛcchā": ['bhs'],
    "vikurvī": ['bhs'],
    "vikusra": ['mw'],
    "vikusraḥ": ['ap90'],
    "vikusuka": ['mw'],
    "vikutsayate": ['bhs'],
    "vikutsā": ['mw'],
    "vikuñc": ['mw'],
    "vikuñcita": ['cae', 'mw'],
    "vikuñcitabhrūlatam": ['mw'],
    "vikuñcitalalāṭabhṛt": ['mw'],
    "vikuñja": ['mw'],
    "vikuṃṭha": ['ap90'],
    "vikuṃṭhita": ['ap90'],
    "vikuṇita": ['cped'],
    "vikuṇḍala": ['mw'],
    "vikuṇṭha": ['cae', 'mw'],
    "vikuṇṭhana": ['mw'],
    "vikuṇṭhanā": ['mw'],
    "vikuṇṭhita": ['cae', 'mw'],
    "vikuṭyāsa": ['mw'],
    "vikuṭṭanā": ['bhs'],
    "vikākud": ['mw'],
    "vikāla": ['bhs', 'cae', 'cped', 'mw'],
    "vikālabhojana": ['cped'],
    "vikālaka": ['mw'],
    "vikālam": ['mw'],
    "vikālarātrī": ['bhs'],
    "vikālaḥ": ['ap90'],
    "vikālikā": ['ap90', 'mw'],
    "vikāma": ['mw'],
    "vikāra": ['cae', 'cped', 'ddsa', 'mw'],
    "vikārahetu": ['mw'],
    "vikāramaya": ['mw'],
    "vikāratas": ['mw'],
    "vikāratva": ['mw'],
    "vikāravat": ['mw'],
    "vikāraḥ": ['ap90'],
    "vikāraṇa": ['cae', 'mw'],
    "vikārin": ['ap90', 'cae', 'mw'],
    "vikārita": ['ap90', 'ddsa', 'mw'],
    "vikāritva": ['mw'],
    "vikāritā": ['mw'],
    "vikārya": ['cae', 'mw'],
    "vikāsa": ['cae', 'cped', 'mw'],
    "vikāsabhāj": ['mw'],
    "vikāsabhṛt": ['mw'],
    "vikāsaka": ['cae', 'mw'],
    "vikāsana": ['cae', 'mw'],
    "vikāsanaṃ": ['ap90'],
    "vikāsayitṛ": ['cae'],
    "vikāsaḥ": ['ap90'],
    "vikāsesi": ['cped'],
    "vikāseti": ['cped'],
    "vikāsetvā": ['cped'],
    "vikāsin": ['ap90', 'cae', 'mw'],
    "vikāsinīlotpala": ['mw'],
    "vikāsita": ['cped', 'mw'],
    "vikāsitā": ['mw'],
    "vikāś": ['ap90', 'mw'],
    "vikāśa": ['cae', 'mw'],
    "vikāśaka": ['ap90', 'mw'],
    "vikāśana": ['mw'],
    "vikāśanaṃ": ['ap90'],
    "vikāśatva": ['mw'],
    "vikāśatā": ['mw'],
    "vikāśayitṛ": ['cae'],
    "vikāśaḥ": ['ap90'],
    "vikāśin": ['ap90', 'cae', 'mw'],
    "vikāśinī": ['mw'],
    "vikāśita": ['mw'],
    "vikāṅkṣ": ['mw'],
    "vikāṅkṣa": ['mw'],
    "vikāṅkṣin": ['mw'],
    "vikāṅkṣā": ['mw'],
    "vikāṣin": ['mw'],
    "vikīraṇa": ['mw'],
    "vikīrṇa": ['ap90', 'cae', 'mw'],
    "vikīrṇakeśa": ['mw'],
    "vikīrṇamūrdhaja": ['mw'],
    "vikīrṇaroman": ['mw'],
    "vikīrṇasaṃjña": ['mw'],
    "vikūbara": ['cae', 'mw'],
    "vikūj": ['mw'],
    "vikūja": ['cae'],
    "vikūjana": ['cae', 'cped', 'mw'],
    "vikūjanaṃ": ['ap90'],
    "vikūjati": ['cped'],
    "vikūji": ['cped'],
    "vikūjita": ['cae', 'cped', 'mw'],
    "vikūla": ['cped'],
    "vikūṇ": ['mw'],
    "vikūṇana": ['mw'],
    "vikūṇanaṃ": ['ap90'],
    "vikūṇikā": ['ap90', 'mw'],
    "vikūṭa": ['mw'],
    "vikūṭaka": ['bhs'],
    "vikḷp": ['ap90', 'mw'],
    "vikṛ": ['ap90', 'mw'],
    "vikṛnta": ['mw'],
    "vikṛt": ['mw'],
    "vikṛta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vikṛtabuddhi": ['mw'],
    "vikṛtadarśana": ['mw'],
    "vikṛtadaṃṣṭra": ['mw'],
    "vikṛtajananaśāntividhāna": ['mw'],
    "vikṛtajña": ['bhs'],
    "vikṛtalocana": ['mw'],
    "vikṛtamūrdhaja": ['mw'],
    "vikṛtarakta": ['mw'],
    "vikṛtatva": ['mw'],
    "vikṛtavadana": ['mw'],
    "vikṛtaveṣin": ['mw'],
    "vikṛti": ['cae', 'ddsa', 'mw'],
    "vikṛtihautra": ['mw'],
    "vikṛtikaumudī": ['mw'],
    "vikṛtimat": ['mw'],
    "vikṛtipradīpikā": ['mw'],
    "vikṛtiḥ": ['ap90'],
    "vikṛtodara": ['mw'],
    "vikṛttikā": ['mw'],
    "vikṛtā": ['mw'],
    "vikṛtākāra": ['mw'],
    "vikṛtākṛti": ['cae', 'mw'],
    "vikṛtākṣa": ['mw'],
    "vikṛtānana": ['mw'],
    "vikṛtāṅga": ['mw'],
    "vikṛś": ['mw'],
    "vikṛṣ": ['ap90', 'mw'],
    "vikṛṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vikṛṣṭakāla": ['mw'],
    "vikṛṣṭasīmānta": ['mw'],
    "vikṛṣṭā": ['mw'],
    "vikṝ": ['ap90', 'mw'],
    "vikṣar": ['mw'],
    "vikṣara": ['cae', 'mw'],
    "vikṣaraṇa": ['mw'],
    "vikṣata": ['ap90', 'cae', 'ddsa', 'mw'],
    "vikṣaya": ['mw'],
    "vikṣaṇam": ['mw'],
    "vikṣepa": ['bhs', 'cae', 'ddsa', 'mw'],
    "vikṣepadhruva": ['mw'],
    "vikṣepalipi": ['mw'],
    "vikṣepam": ['mw'],
    "vikṣepavṛtta": ['mw'],
    "vikṣepaśakti": ['cae', 'mw'],
    "vikṣepaśaktimat": ['mw'],
    "vikṣepaḥ": ['ap90'],
    "vikṣepaṇa": ['mw'],
    "vikṣepaṇaṃ": ['ap90'],
    "vikṣeptṛ": ['mw'],
    "vikṣepādhipati": ['mw'],
    "vikṣi": ['mw'],
    "vikṣip": ['ap90', 'mw'],
    "vikṣipa": ['bhs'],
    "vikṣipta": ['ap90', 'cae', 'mw'],
    "vikṣiptabhrū": ['mw'],
    "vikṣiptacitta": ['mw'],
    "vikṣiptacittaka": ['bhs'],
    "vikṣiptaka": ['bhs', 'mw'],
    "vikṣiptendriyadhī": ['mw'],
    "vikṣiptikā": ['bhs'],
    "vikṣita": ['mw'],
    "vikṣiṇatka": ['mw'],
    "vikṣobdhos": ['cae'],
    "vikṣobha": ['bhs', 'cae', 'ddsa', 'mw'],
    "vikṣobhaḥ": ['ap90'],
    "vikṣobhaṇa": ['mw'],
    "vikṣobhin": ['mw'],
    "vikṣobhita": ['mw'],
    "vikṣobhitā": ['bhs'],
    "vikṣubdha": ['mw'],
    "vikṣubh": ['ap90', 'mw'],
    "vikṣubhā": ['mw'],
    "vikṣudh": ['mw'],
    "vikṣudra": ['mw'],
    "vikṣuṇṇa": ['mw'],
    "vikṣā": ['mw'],
    "vikṣālita": ['mw'],
    "vikṣāma": ['mw'],
    "vikṣāntam": ['bhs'],
    "vikṣāra": ['mw'],
    "vikṣāva": ['mw'],
    "vikṣāvaḥ": ['ap90'],
    "vikṣīra": ['mw'],
    "vikṣīraḥ": ['ap90'],
    "vikṣīṇa": ['mw'],
    "vikṣīṇaka": ['mw'],
    "vikṣīṇakaḥ": ['ap90'],
    "vil": ['ap90', 'mw'],
    "vila": ['ddsa', 'mw'],
    "vilabdha": ['mw'],
    "vilabdhi": ['mw'],
    "vilabh": ['mw'],
    "vilag": ['ap90', 'mw'],
    "vilagga": ['cped'],
    "vilagita": ['mw'],
    "vilagna": ['ap90', 'cae', 'mw'],
    "vilagnamadhyā": ['mw'],
    "vilagnita": ['bhs'],
    "vilajj": ['ap90', 'mw'],
    "vilajja": ['ap90', 'cae', 'mw'],
    "vilajjita": ['cae', 'mw'],
    "vilakṣ": ['ap90', 'mw'],
    "vilakṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vilakṣatva": ['mw'],
    "vilakṣatā": ['mw'],
    "vilakṣaṇa": ['ap90', 'cae', 'mw'],
    "vilakṣaṇacaturdaśaka": ['mw'],
    "vilakṣaṇajanmaprakāśikā": ['mw'],
    "vilakṣaṇamokṣādhikāra": ['mw'],
    "vilakṣaṇatva": ['mw'],
    "vilakṣaṇatā": ['mw'],
    "vilakṣita": ['ap90', 'cae', 'mw'],
    "vilakṣya": ['mw'],
    "vilakṣīkṛ": ['mw'],
    "vilakṣīkṛta": ['mw'],
    "vilalā": ['mw'],
    "vilamb": ['mw'],
    "vilamba": ['cae', 'mw'],
    "vilambaka": ['mw'],
    "vilambana": ['cae', 'cped', 'mw'],
    "vilambanā": ['mw'],
    "vilambasauparṇa": ['mw'],
    "vilambati": ['cped'],
    "vilambeti": ['cped'],
    "vilambha": ['mw'],
    "vilambi": ['cped'],
    "vilambikā": ['mw'],
    "vilambin": ['cae', 'mw'],
    "vilambita": ['cae', 'cped', 'mw'],
    "vilambitagati": ['mw'],
    "vilambitam": ['mw'],
    "vilambitaphala": ['mw'],
    "vilambitā": ['mw'],
    "vilambya": ['cae', 'mw'],
    "vilambā": ['bhs'],
    "vilap": ['ap90', 'mw'],
    "vilapamāna": ['cped'],
    "vilapana": ['cae', 'mw'],
    "vilapanavinoda": ['mw'],
    "vilapanaṃ": ['ap90'],
    "vilapanta": ['cped'],
    "vilapati": ['cped'],
    "vilapi": ['cped'],
    "vilapita": ['cae', 'mw'],
    "vilapitaṃ": ['ap90'],
    "vilapitvā": ['cped'],
    "vilas": ['ap90', 'mw'],
    "vilasan": ['mw'],
    "vilasana": ['cae', 'mw'],
    "vilasanaṃ": ['ap90'],
    "vilasanmarīci": ['mw'],
    "vilasanmeghaśabda": ['mw'],
    "vilasat": ['ap90', 'mw'],
    "vilasati": ['cped'],
    "vilasatpatāka": ['mw'],
    "vilasatsaudāminī": ['mw'],
    "vilasi": ['cped'],
    "vilasita": ['ap90', 'cae', 'cped', 'mw'],
    "vilaya": ['cae', 'cped', 'mw'],
    "vilayana": ['cae', 'mw'],
    "vilayanaṃ": ['ap90'],
    "vilayaḥ": ['ap90'],
    "vilaṃ": ['ap90'],
    "vilaṃb": ['ap90'],
    "vilaṃbanaṃ": ['ap90'],
    "vilaṃbaḥ": ['ap90'],
    "vilaṃbhaḥ": ['ap90'],
    "vilaṃbikā": ['ap90'],
    "vilaṃbin": ['ap90'],
    "vilaṃbita": ['ap90'],
    "vilaṃgh": ['ap90'],
    "vilaṃghanaṃ": ['ap90'],
    "vilaṃghita": ['ap90'],
    "vilaṅgh": ['mw'],
    "vilaṅghana": ['cae', 'mw'],
    "vilaṅghanā": ['mw'],
    "vilaṅghanīya": ['mw'],
    "vilaṅghati": ['cped'],
    "vilaṅghayitvā": ['mw'],
    "vilaṅgheti": ['cped'],
    "vilaṅghin": ['cae', 'mw'],
    "vilaṅghita": ['cped', 'mw'],
    "vilaṅghitākāśa": ['mw'],
    "vilaṅghya": ['cae', 'mw'],
    "vilaṅghyalakṣaṇa": ['mw'],
    "vilaṅghyatā": ['mw'],
    "vilaṅgita": ['mw'],
    "vilekha": ['bhs', 'cped', 'ddsa', 'mw'],
    "vilekhana": ['bhs', 'mw'],
    "vilekhanaṃ": ['ap90'],
    "vilekhin": ['mw'],
    "vilekhya": ['bhs'],
    "vilekhā": ['mw'],
    "vilepa": ['cae', 'mw'],
    "vilepana": ['cped', 'mw'],
    "vilepanaṃ": ['ap90'],
    "vilepanikā": ['bhs'],
    "vilepanin": ['mw'],
    "vilepanā": ['bhs'],
    "vilepanī": ['ap90', 'mw'],
    "vilepaḥ": ['ap90'],
    "vilepesi": ['cped'],
    "vilepeti": ['cped'],
    "vilepetvā": ['cped'],
    "vilepikā": ['ap90', 'mw'],
    "vilepin": ['cae', 'mw'],
    "vilepita": ['cped'],
    "vilepya": ['mw'],
    "vilepī": ['mw'],
    "viligī": ['mw'],
    "vilih": ['mw'],
    "vilikh": ['ap90', 'mw'],
    "vilikha": ['mw'],
    "vilikhana": ['mw'],
    "vilikhanaṃ": ['ap90'],
    "vilikhati": ['cped'],
    "vilikhita": ['cped', 'mw'],
    "vilimpati": ['cped'],
    "vilimpenta": ['cped'],
    "vilimpesi": ['cped'],
    "vilimpeti": ['cped'],
    "vilimpetvā": ['cped'],
    "vilimpita": ['mw'],
    "vilinātha": ['mw'],
    "vilip": ['ap90', 'mw'],
    "vilipta": ['ap90', 'mw'],
    "viliptikā": ['mw'],
    "viliptā": ['mw'],
    "viliptī": ['mw'],
    "vilisteṅgā": ['mw'],
    "vilitta": ['cped'],
    "viliś": ['mw'],
    "viliṅga": ['ddsa', 'mw'],
    "viliṅgastha": ['mw'],
    "viliṣṭa": ['mw'],
    "viliṣṭabheṣaja": ['mw'],
    "villa": ['ap90', 'mw'],
    "vilobha": ['mw'],
    "vilobhana": ['cae', 'mw'],
    "vilobhanaṃ": ['ap90'],
    "vilobhanīya": ['mw'],
    "vilobhaḥ": ['ap90'],
    "vilobhita": ['mw'],
    "vilocana": ['cae', 'cped', 'mw'],
    "vilocanapatha": ['mw'],
    "vilocanapāta": ['mw'],
    "vilocanaṃ": ['ap90'],
    "vilocanāmbu": ['mw'],
    "vilodita": ['mw'],
    "vilohita": ['ap90', 'bhs', 'mw'],
    "vilohitaka": ['bhs', 'mw'],
    "vilohitā": ['mw'],
    "vilok": ['ap90', 'mw'],
    "viloka": ['ddsa', 'mw'],
    "vilokana": ['cae', 'cped', 'mw'],
    "vilokanaṃ": ['ap90'],
    "vilokanīya": ['mw'],
    "vilokanīyatva": ['mw'],
    "vilokanīyatā": ['mw'],
    "vilokastha": ['mw'],
    "vilokayamāna": ['cped'],
    "vilokenta": ['cped'],
    "vilokesi": ['cped'],
    "viloketi": ['cped'],
    "viloketvā": ['cped'],
    "vilokin": ['cae', 'mw'],
    "vilokinī": ['bhs'],
    "vilokita": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "vilokitamūrdha": ['bhs'],
    "vilokya": ['mw'],
    "vilola": ['ap90', 'cae', 'mw'],
    "vilolahāra": ['mw'],
    "vilolalocana": ['mw'],
    "vilolana": ['mw'],
    "vilolanaṃ": ['ap90'],
    "vilolatva": ['mw'],
    "vilolatā": ['mw'],
    "vilolatāraka": ['mw'],
    "vilolita": ['mw'],
    "vilolitadṛś": ['mw'],
    "vilolupa": ['mw'],
    "viloma": ['ap90', 'cae', 'cped', 'mw'],
    "vilomaja": ['mw'],
    "vilomajihva": ['mw'],
    "vilomajāta": ['mw'],
    "vilomaka": ['mw'],
    "vilomakriyā": ['mw'],
    "vilomakāvya": ['mw'],
    "vilomam": ['mw'],
    "viloman": ['cae', 'mw'],
    "vilomana": ['bhs'],
    "vilomapāṭha": ['mw'],
    "vilomarasana": ['mw'],
    "vilomatrairāśika": ['mw'],
    "vilomatā": ['cped', 'mw'],
    "vilomavarṇa": ['mw'],
    "vilomavidhi": ['mw'],
    "vilomayati": ['bhs'],
    "vilomesi": ['cped'],
    "vilometi": ['cped'],
    "vilometvā": ['cped'],
    "vilomita": ['mw'],
    "vilomotpanna": ['mw'],
    "vilomākṣarakāvya": ['mw'],
    "vilomī": ['ap90', 'mw'],
    "vilopa": ['cae', 'cped', 'mw'],
    "vilopaka": ['cae', 'cped', 'mw'],
    "vilopana": ['cae', 'cped', 'mw'],
    "vilopanaṃ": ['ap90'],
    "vilopaḥ": ['ap90'],
    "vilopin": ['cae', 'mw'],
    "vilopita": ['mw'],
    "viloptṛ": ['cae', 'mw'],
    "vilopya": ['cae', 'mw'],
    "viloḍa": ['mw'],
    "viloḍaka": ['mw'],
    "viloḍana": ['cae', 'mw'],
    "viloḍanaṃ": ['ap90'],
    "viloḍayitṛ": ['mw'],
    "viloḍita": ['ap90', 'mw'],
    "viloḷana": ['cped'],
    "viloḷeti": ['cped'],
    "viloṭa": ['mw'],
    "viloṭaka": ['mw'],
    "viloṭana": ['mw'],
    "viloṭhin": ['cae', 'mw'],
    "vilubh": ['ap90', 'mw'],
    "vilubhita": ['mw'],
    "vilubhitaplava": ['mw'],
    "vilugga": ['cped'],
    "vilujyati": ['bhs'],
    "vilul": ['ap90'],
    "vilulita": ['ap90', 'cae', 'mw'],
    "vilulitālaka": ['mw'],
    "vilumpaka": ['cae', 'mw'],
    "vilup": ['ap90', 'mw'],
    "vilupta": ['ap90', 'mw'],
    "viluptapūrva": ['mw'],
    "viluptasāvitrīka": ['mw'],
    "viluptavitta": ['mw'],
    "viluptī": ['mw'],
    "vilupya": ['mw'],
    "viluta": ['bhs'],
    "vilutta": ['cped'],
    "viluñc": ['mw'],
    "viluñcana": ['mw'],
    "viluḍ": ['ap90', 'mw'],
    "viluṃcanaṃ": ['ap90'],
    "viluṃpakaḥ": ['ap90'],
    "viluṃṭhanaṃ": ['ap90'],
    "viluṇṭ": ['mw'],
    "viluṇṭh": ['mw'],
    "viluṇṭhaka": ['mw'],
    "viluṇṭhana": ['cae', 'mw'],
    "viluṇṭhita": ['mw'],
    "viluṭh": ['mw'],
    "viluṭhita": ['mw'],
    "vilva": ['ap90', 'bhs', 'cae'],
    "vilābha": ['mw'],
    "vilābhiman": ['mw'],
    "vilāla": ['mw'],
    "vilālaḥ": ['ap90'],
    "vilāpa": ['cae', 'cped', 'mw'],
    "vilāpakusumāñjali": ['mw'],
    "vilāpana": ['cae', 'mw'],
    "vilāpayitṛ": ['mw'],
    "vilāpaḥ": ['ap90'],
    "vilāpin": ['cae', 'mw'],
    "vilāpita": ['mw'],
    "vilāsa": ['cae', 'cped', 'ddsa', 'mw'],
    "vilāsabhavana": ['cae', 'mw'],
    "vilāsabhitti": ['mw'],
    "vilāsabāṇa": ['cae', 'mw'],
    "vilāsacāpa": ['cae', 'mw'],
    "vilāsadhanvan": ['cae', 'mw'],
    "vilāsadolā": ['mw'],
    "vilāsagṛha": ['cae', 'mw'],
    "vilāsaka": ['cae', 'mw'],
    "vilāsakodaṇḍa": ['mw'],
    "vilāsakānana": ['mw'],
    "vilāsamandira": ['mw'],
    "vilāsamaya": ['mw'],
    "vilāsamaṇidarpaṇa": ['mw'],
    "vilāsamekhalā": ['mw'],
    "vilāsana": ['mw'],
    "vilāsanaṃ": ['ap90'],
    "vilāsapura": ['mw'],
    "vilāsarasikā": ['mw'],
    "vilāsasadman": ['mw'],
    "vilāsasvāmin": ['mw'],
    "vilāsavasati": ['mw'],
    "vilāsavat": ['mw'],
    "vilāsavatī": ['ap90', 'cae', 'mw'],
    "vilāsaveśman": ['mw'],
    "vilāsavibhavānasa": ['mw'],
    "vilāsavihāra": ['mw'],
    "vilāsavipina": ['mw'],
    "vilāsavātāyana": ['mw'],
    "vilāsaśayyā": ['mw'],
    "vilāsaśīla": ['mw'],
    "vilāsaḥ": ['ap90'],
    "vilāsendragāminī": ['bhs', 'mw'],
    "vilāsikatva": ['cae'],
    "vilāsikā": ['ap90', 'ddsa', 'mw'],
    "vilāsin": ['ap90', 'cae', 'mw'],
    "vilāsinikā": ['mw'],
    "vilāsinī": ['ap90', 'cped', 'mw'],
    "vilāsinījana": ['mw'],
    "vilāsitva": ['mw'],
    "vilāsitā": ['cped', 'mw'],
    "vilāsī": ['cped'],
    "vilāta": ['mw'],
    "vilātavya": ['mw'],
    "vilātiman": ['mw'],
    "vilātā": ['mw'],
    "vilātṛ": ['mw'],
    "vilāyita": ['mw'],
    "vilāṣin": ['mw'],
    "vilī": ['ap90', 'mw'],
    "vilīna": ['ap90', 'cae', 'cped', 'mw'],
    "vilīnaka": ['bhs'],
    "vilīnaṣaṭpada": ['mw'],
    "vilīnākṣaram": ['mw'],
    "vilīva": ['cped'],
    "vilīvakāra": ['cped'],
    "vilīyamāna": ['cped'],
    "vilīyana": ['cped', 'mw'],
    "vilīyati": ['cped'],
    "vilīyi": ['cped'],
    "vilū": ['mw'],
    "vilūna": ['ap90', 'cped', 'mw'],
    "vimabhūpāla": ['mw'],
    "vimad": ['ap90', 'mw'],
    "vimada": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "vimadhya": ['cae', 'gra', 'mw'],
    "vimadhyabhāva": ['mw'],
    "vimadhyama": ['bhs', 'mw'],
    "vimadita": ['mw'],
    "vimadya": ['mw'],
    "vimadīkṛ": ['mw'],
    "vimahant": ['cae'],
    "vimahas": ['cae', 'gra', 'mw'],
    "vimahat": ['mw'],
    "vimahi": ['gra'],
    "vimahī": ['mw'],
    "vimajj": ['mw'],
    "vimajjita": ['mw'],
    "vimajjāntra": ['mw'],
    "vimala": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vimalabhadra": ['mw'],
    "vimalabhāsa": ['bhs', 'mw'],
    "vimalabhūdhara": ['mw'],
    "vimalabodha": ['mw'],
    "vimalabrahmavarya": ['mw'],
    "vimalabuddhi": ['bhs', 'mw'],
    "vimalabāhu": ['bhs'],
    "vimalacakrabhānuprabha": ['bhs'],
    "vimalacandra": ['mw'],
    "vimaladatta": ['bhs', 'mw'],
    "vimaladattā": ['bhs', 'mw'],
    "vimaladharmaparvatajñānaśikharābha": ['bhs'],
    "vimaladhvaja": ['bhs'],
    "vimaladāna": ['mw'],
    "vimalagarbha": ['bhs', 'mw'],
    "vimalagati": ['bhs'],
    "vimalajendra": ['bhs'],
    "vimalaketu": ['bhs'],
    "vimalakirīṭahāravat": ['mw'],
    "vimalakīrti": ['bhs', 'mw'],
    "vimalakīrtinirdeśa": ['bhs'],
    "vimalamakuṭa": ['bhs'],
    "vimalamati": ['cae', 'mw'],
    "vimalamaṇi": ['mw'],
    "vimalamaṇikara": ['mw'],
    "vimalamitra": ['mw'],
    "vimalanetra": ['bhs', 'mw'],
    "vimalanirbhāsa": ['bhs', 'mw'],
    "vimalanirdeśa": ['mw'],
    "vimalanā": ['bhs'],
    "vimalanāthapurāṇa": ['mw'],
    "vimalapiṇḍaka": ['mw'],
    "vimalaprabha": ['bhs', 'mw'],
    "vimalaprabhā": ['bhs', 'mw'],
    "vimalaprabhāsa": ['bhs'],
    "vimalaprabhāsaśrītejorājagarbha": ['bhs', 'mw'],
    "vimalapradīpa": ['bhs', 'mw'],
    "vimalapraśnottaramālā": ['mw'],
    "vimalapura": ['mw'],
    "vimalasambhava": ['mw'],
    "vimalasaṃbhavaprabhā": ['bhs'],
    "vimalasvabhāva": ['mw'],
    "vimalatejas": ['bhs'],
    "vimalatejaḥprabha": ['bhs'],
    "vimalatva": ['mw'],
    "vimalatā": ['mw'],
    "vimalavaktrabhānuprabha": ['bhs'],
    "vimalavatsa": ['bhs'],
    "vimalavegaśrī": ['mw'],
    "vimalavyūha": ['bhs', 'mw'],
    "vimalavāhana": ['mw'],
    "vimalay": ['cae'],
    "vimalaya": ['ddsa', 'mw'],
    "vimalaśikhala": ['bhs'],
    "vimalaśrīgarbha": ['mw'],
    "vimalaśrīmegha": ['bhs'],
    "vimale": ['mw'],
    "vimalendra": ['bhs'],
    "vimaleśvarapuṣkariṇīsaṃgamatīrtha": ['mw'],
    "vimaleśvaratīrtha": ['mw'],
    "vimaliman": ['cae', 'ddsa', 'mw'],
    "vimalita": ['mw'],
    "vimalodakā": ['mw'],
    "vimalodā": ['mw'],
    "vimalogya": ['mw'],
    "vimalorja": ['mw'],
    "vimalottarajñānin": ['bhs'],
    "vimalottarīya": ['bhs'],
    "vimalā": ['bhs', 'mw'],
    "vimalābha": ['bhs'],
    "vimalāditya": ['mw'],
    "vimalādri": ['mw'],
    "vimalāgranetra": ['bhs', 'mw'],
    "vimalākara": ['mw'],
    "vimalānana": ['bhs', 'cae', 'mw'],
    "vimalānanda": ['mw'],
    "vimalānandabhāṣya": ['mw'],
    "vimalānandanātha": ['mw'],
    "vimalāpa": ['mw'],
    "vimalārthaka": ['mw'],
    "vimalātmaka": ['mw'],
    "vimalātman": ['cae', 'mw'],
    "vimalāśoka": ['mw'],
    "vimalāśvā": ['mw'],
    "vimalīkaraṇa": ['cae', 'mw'],
    "viman": ['ap90', 'mw'],
    "vimana": ['cped', 'mw'],
    "vimanas": ['ap90', 'cae', 'gra', 'mw'],
    "vimanaska": ['cae', 'mw'],
    "vimaniman": ['mw'],
    "vimanth": ['mw'],
    "vimanthana": ['mw'],
    "vimanthara": ['mw'],
    "vimantra": ['bhs'],
    "vimanyu": ['ap90', 'cae', 'gra', 'mw'],
    "vimanyuka": ['cae', 'mw'],
    "vimanāya": ['mw'],
    "vimanībhūta": ['mw'],
    "vimanīkṛta": ['ap90', 'mw'],
    "vimarda": ['cae', 'mw'],
    "vimardaka": ['cae', 'mw'],
    "vimardakaḥ": ['ap90'],
    "vimardakārin": ['cae'],
    "vimardakṣama": ['mw'],
    "vimardana": ['cae', 'mw'],
    "vimardanatā": ['bhs'],
    "vimardanaṃ": ['ap90'],
    "vimardaḥ": ['ap90'],
    "vimardin": ['cae', 'mw'],
    "vimardita": ['ap90', 'mw'],
    "vimardottha": ['mw'],
    "vimardārdha": ['mw'],
    "vimarśa": ['cae', 'mw'],
    "vimarśacchedin": ['cae'],
    "vimarśana": ['mw'],
    "vimarśavat": ['mw'],
    "vimarśavādin": ['mw'],
    "vimarśaḥ": ['ap90'],
    "vimarśin": ['cae', 'mw'],
    "vimarśita": ['mw'],
    "vimarśāṅga": ['mw'],
    "vimarṣa": ['cae', 'mw'],
    "vimarṣaḥ": ['ap90'],
    "vimarṣaṇa": ['cae', 'mw'],
    "vimarṣin": ['mw'],
    "vimarṣṭavya": ['cae'],
    "vimastakita": ['mw'],
    "vimata": ['ap90', 'cae', 'mw'],
    "vimath": ['ap90', 'mw'],
    "vimathita": ['mw'],
    "vimathitṛ": ['mw'],
    "vimati": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vimaticchedaka": ['cped'],
    "vimatiman": ['mw'],
    "vimatisamudghātin": ['mw'],
    "vimatisamudghāṭī": ['bhs'],
    "vimatitā": ['mw'],
    "vimativikiraṇa": ['bhs'],
    "vimativikīraṇa": ['mw'],
    "vimatsara": ['ap90', 'cae', 'mw'],
    "vimatsarin": ['mw'],
    "vimatta": ['ap90', 'cae', 'mw'],
    "vimauli": ['mw'],
    "vimauna": ['mw'],
    "vimaya": ['mw'],
    "vimayaḥ": ['ap90'],
    "vimaṁsitvā": ['cped'],
    "vimaṃh": ['mw'],
    "vimaṃth": ['ap90'],
    "vimaṇḍala": ['mw'],
    "vimaṣṭaka": ['bhs'],
    "vimba": ['mw'],
    "vimbaka": ['bhs'],
    "vime": ['mw'],
    "vimegha": ['cae', 'mw'],
    "vimhaya": ['cped'],
    "vimhita": ['cped'],
    "vimhāpaka": ['cped'],
    "vimhāpana": ['cped'],
    "vimhāpesi": ['cped'],
    "vimhāpeti": ['cped'],
    "vimhāpetvā": ['cped'],
    "vimhāpita": ['cped'],
    "vimi": ['mw'],
    "vimita": ['cae', 'mw'],
    "vimithuna": ['mw'],
    "vimiśr": ['mw'],
    "vimiśra": ['ap90', 'bhs', 'cae', 'mw'],
    "vimiśraka": ['mw'],
    "vimiśrita": ['bhs', 'mw'],
    "vimlai": ['mw'],
    "vimlambitvā": ['cped'],
    "vimlāna": ['mw'],
    "vimlāpana": ['mw'],
    "vimlāpanaṃ": ['ap90'],
    "vimocaka": ['cae', 'cped', 'mw'],
    "vimocana": ['cae', 'cped', 'gra', 'mw'],
    "vimocanaṃ": ['ap90'],
    "vimocanī": ['mw'],
    "vimocanīya": ['mw'],
    "vimocenta": ['cped'],
    "vimocesi": ['cped'],
    "vimoceti": ['cped'],
    "vimocetvā": ['cped'],
    "vimocita": ['cped', 'mw'],
    "vimocya": ['cae', 'mw'],
    "vimogha": ['bhs', 'mw'],
    "vimoha": ['cae', 'mw'],
    "vimohada": ['mw'],
    "vimohaka": ['mw'],
    "vimohana": ['ap90', 'cae', 'mw'],
    "vimohesi": ['cped'],
    "vimoheti": ['cped'],
    "vimohetvā": ['cped'],
    "vimohin": ['cae', 'mw'],
    "vimohita": ['cped', 'mw'],
    "vimoka": ['cae', 'ddsa', 'mw'],
    "vimokam": ['mw'],
    "vimokkha": ['cped'],
    "vimoktavya": ['bhs', 'cae', 'mw'],
    "vimoktṛ": ['cae', 'mw'],
    "vimokya": ['mw'],
    "vimokṣ": ['mw'],
    "vimokṣa": ['bhs', 'cae', 'mw'],
    "vimokṣacandra": ['bhs'],
    "vimokṣaka": ['mw'],
    "vimokṣakarā": ['bhs', 'mw'],
    "vimokṣaḥ": ['ap90'],
    "vimokṣaṇa": ['cae', 'mw'],
    "vimokṣaṇaṃ": ['ap90'],
    "vimokṣin": ['cae', 'mw'],
    "vimokṣā": ['bhs'],
    "vimrad": ['mw'],
    "vimrakṣayati": ['bhs'],
    "vimrit": ['mw'],
    "vimuc": ['ap90', 'cae', 'gra', 'mw'],
    "vimuca": ['mw'],
    "vimuccana": ['cped'],
    "vimuccati": ['cped'],
    "vimucci": ['cped'],
    "vimuccitvā": ['cped'],
    "vimuda": ['bhs', 'mw'],
    "vimudra": ['ap90', 'mw'],
    "vimudraṇa": ['mw'],
    "vimugdha": ['ap90', 'cae', 'mw'],
    "vimuh": ['ap90', 'mw'],
    "vimukha": ['ap90', 'cae', 'cped', 'mw'],
    "vimukhatva": ['mw'],
    "vimukhatā": ['mw'],
    "vimukhay": ['cae'],
    "vimukhaya": ['mw'],
    "vimukhin": ['mw'],
    "vimukhita": ['mw'],
    "vimukhitva": ['mw'],
    "vimukhitā": ['mw'],
    "vimukhī": ['mw'],
    "vimukhībhāva": ['cae', 'mw'],
    "vimukhībhū": ['mw'],
    "vimukhīkaraṇa": ['mw'],
    "vimukhīkṛ": ['cae', 'mw'],
    "vimukhīkṛta": ['mw'],
    "vimukta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vimuktaghoṣa": ['bhs'],
    "vimuktaka": ['bhs'],
    "vimuktakaṇṭha": ['mw'],
    "vimuktakaṇṭham": ['cae', 'mw'],
    "vimuktakeśa": ['mw'],
    "vimuktamaunam": ['cae', 'mw'],
    "vimuktapragraha": ['mw'],
    "vimuktasena": ['mw'],
    "vimuktatā": ['mw'],
    "vimuktaśāpa": ['mw'],
    "vimukti": ['bhs', 'cae', 'mw'],
    "vimukticandra": ['bhs', 'mw'],
    "vimuktimahiman": ['mw'],
    "vimuktipatha": ['mw'],
    "vimuktiḥ": ['ap90'],
    "vimuktācārya": ['mw'],
    "vimutta": ['cped'],
    "vimutti": ['cped'],
    "vimuttirasa": ['cped'],
    "vimuttisukha": ['cped'],
    "vimuñcanta": ['cped'],
    "vimuñcati": ['bhs', 'cped'],
    "vimuñci": ['cped'],
    "vimuñcita": ['cped'],
    "vimuñcitvā": ['cped'],
    "vimuñja": ['mw'],
    "vimā": ['mw'],
    "vimālābha": ['bhs'],
    "vimāna": ['bhs', 'cae', 'cped', 'gra', 'mw'],
    "vimānacyuta": ['mw'],
    "vimānacārin": ['mw'],
    "vimānagamana": ['mw'],
    "vimānaka": ['mw'],
    "vimānalakṣaṇa": ['mw'],
    "vimānamāhātmya": ['mw'],
    "vimānana": ['cae', 'cped', 'mw'],
    "vimānanirvyūha": ['mw'],
    "vimānanā": ['ap90'],
    "vimānapeta": ['cped'],
    "vimānaprabhutā": ['mw'],
    "vimānapratima": ['mw'],
    "vimānapāla": ['mw'],
    "vimānarāja": ['mw'],
    "vimānarājan": ['bhs'],
    "vimānastha": ['mw'],
    "vimānasthāna": ['mw'],
    "vimānasuddhipūjā": ['mw'],
    "vimānatva": ['mw'],
    "vimānatā": ['mw'],
    "vimānavat": ['mw'],
    "vimānavatthu": ['cped'],
    "vimānavidyā": ['mw'],
    "vimānayitavya": ['cae'],
    "vimānayāna": ['mw'],
    "vimānaḥ": ['ap90'],
    "vimānesi": ['cped'],
    "vimāneti": ['cped'],
    "vimānetvā": ['cped'],
    "vimānita": ['ap90', 'cped', 'mw'],
    "vimānuṣa": ['mw'],
    "vimānya": ['cae', 'mw'],
    "vimānī": ['gra'],
    "vimānīkṛ": ['mw'],
    "vimārga": ['cae', 'mw'],
    "vimārgadṛṣṭi": ['mw'],
    "vimārgaga": ['mw'],
    "vimārgagāmin": ['mw'],
    "vimārgaprasthita": ['mw'],
    "vimārgastha": ['mw'],
    "vimārgaḥ": ['ap90'],
    "vimārgaṇa": ['mw'],
    "vimārgaṇaṃ": ['ap90'],
    "vimārjana": ['cae', 'mw'],
    "vimātavya": ['mw'],
    "vimātha": ['cae', 'mw'],
    "vimāthaḥ": ['ap90'],
    "vimāthin": ['cae', 'mw'],
    "vimātra": ['mw'],
    "vimātratā": ['bhs', 'mw'],
    "vimātrya": ['bhs'],
    "vimātṛ": ['ap90', 'cae', 'mw'],
    "vimātṛja": ['mw'],
    "vimāya": ['gra', 'mw'],
    "vimāṃsa": ['cae', 'ddsa', 'mw'],
    "vimāṃsaḥ": ['ap90'],
    "vimāṇḍavya": ['mw'],
    "vimūla": ['cae', 'ddsa', 'mw'],
    "vimūlana": ['mw'],
    "vimūrchana": ['mw'],
    "vimūrchita": ['bhs', 'cae', 'mw'],
    "vimūrdhaja": ['mw'],
    "vimūrta": ['mw'],
    "vimūḍha": ['ap90', 'cae', 'mw'],
    "vimūḍhabhāva": ['cae', 'mw'],
    "vimūḍhacetas": ['mw'],
    "vimūḍhadhī": ['mw'],
    "vimūḍhaka": ['mw'],
    "vimūḍhasaṃjña": ['mw'],
    "vimūḍhātman": ['mw'],
    "vimṛd": ['ap90', 'mw'],
    "vimṛdh": ['cae', 'gra', 'mw'],
    "vimṛdha": ['cae', 'mw'],
    "vimṛdita": ['mw'],
    "vimṛditadhvaja": ['mw'],
    "vimṛdvat": ['mw'],
    "vimṛga": ['mw'],
    "vimṛgvan": ['mw'],
    "vimṛgvarī": ['cae'],
    "vimṛgya": ['ddsa'],
    "vimṛj": ['mw'],
    "vimṛtyu": ['cae', 'mw'],
    "vimṛś": ['ap90', 'mw'],
    "vimṛśa": ['cae', 'mw'],
    "vimṛśita": ['mw'],
    "vimṛśya": ['cae', 'mw'],
    "vimṛśyakārin": ['mw'],
    "vimṛṣ": ['mw'],
    "vimṛṣṭa": ['ap90', 'bhs', 'mw'],
    "vimṛṣṭarāga": ['mw'],
    "vimṛṣṭāntarāṃsa": ['mw'],
    "vinad": ['ap90', 'mw'],
    "vinada": ['cae', 'mw'],
    "vinadaḥ": ['ap90'],
    "vinaddha": ['bhs', 'cae', 'cped', 'mw'],
    "vinadin": ['mw'],
    "vinadā": ['mw'],
    "vinadī": ['mw'],
    "vinaga": ['bhs'],
    "vinagna": ['bhs', 'mw'],
    "vinam": ['ap90', 'mw'],
    "vinamana": ['mw'],
    "vinamanaṃ": ['ap90'],
    "vinamate": ['bhs'],
    "vinamita": ['mw'],
    "vinamra": ['ap90', 'cae', 'mw'],
    "vinamraka": ['mw'],
    "vinamrakaṃ": ['ap90'],
    "vinamrakaṃdhara": ['mw'],
    "vinand": ['mw'],
    "vinandhana": ['cped'],
    "vinandhati": ['cped'],
    "vinandhi": ['cped'],
    "vinandhitvā": ['cped'],
    "vinard": ['mw'],
    "vinardin": ['cae', 'mw'],
    "vinardita": ['bhs'],
    "vinarditarāja": ['bhs'],
    "vinasa": ['ap90', 'cae', 'mw'],
    "vinassamāna": ['cped'],
    "vinassana": ['cped'],
    "vinassanta": ['cped'],
    "vinassati": ['cped'],
    "vinassi": ['cped'],
    "vinassitvā": ['cped'],
    "vinata": ['ap90', 'cae', 'cped', 'mw'],
    "vinataka": ['bhs', 'mw'],
    "vinatakāya": ['mw'],
    "vinatam": ['mw'],
    "vinatatā": ['mw'],
    "vinati": ['cae', 'mw'],
    "vinatiḥ": ['ap90'],
    "vinatodara": ['mw'],
    "vinatā": ['ap90', 'cped', 'mw'],
    "vinatānana": ['mw'],
    "vinatānanda": ['mw'],
    "vinatāsuta": ['mw'],
    "vinatāsūnu": ['mw'],
    "vinatātanayā": ['mw'],
    "vinatāśva": ['mw'],
    "vinaya": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vinayabhāj": ['mw'],
    "vinayadatta": ['cae', 'mw'],
    "vinayadeva": ['mw'],
    "vinayadhara": ['bhs', 'cped'],
    "vinayagrāhin": ['mw'],
    "vinayajyotis": ['mw'],
    "vinayakarman": ['mw'],
    "vinayakṣudraka": ['bhs', 'mw'],
    "vinayakṣudrakavastu": ['mw'],
    "vinayamaya": ['mw'],
    "vinayana": ['cae', 'cped', 'mw'],
    "vinayanandin": ['mw'],
    "vinayanaṃ": ['ap90'],
    "vinayanā": ['bhs'],
    "vinayapattra": ['mw'],
    "vinayapiṭaka": ['bhs', 'cped', 'mw'],
    "vinayapradhāna": ['mw'],
    "vinayapramāthin": ['mw'],
    "vinayarāma": ['mw'],
    "vinayastha": ['mw'],
    "vinayasundara": ['mw'],
    "vinayasvāminī": ['mw'],
    "vinayasāgara": ['mw'],
    "vinayasūtra": ['mw'],
    "vinayatā": ['mw'],
    "vinayavallī": ['mw'],
    "vinayavastu": ['bhs', 'mw'],
    "vinayavat": ['mw'],
    "vinayavatī": ['mw'],
    "vinayavibhaṅga": ['bhs', 'mw'],
    "vinayavibhāṣāśāstra": ['mw'],
    "vinayavijaya": ['mw'],
    "vinayavāc": ['mw'],
    "vinayavādī": ['cped'],
    "vinayayogin": ['mw'],
    "vinayaśrī": ['mw'],
    "vinayaṃdhara": ['mw'],
    "vinayin": ['cae'],
    "vinayokti": ['mw'],
    "vinayā": ['mw'],
    "vinayādidhara": ['mw'],
    "vinayāditya": ['mw'],
    "vinayādityapura": ['mw'],
    "vinayānvita": ['mw'],
    "vinayāvanata": ['mw'],
    "vinaś": ['ap90', 'mw'],
    "vinaśana": ['cae', 'ddsa', 'mw'],
    "vinaśanakṣetra": ['mw'],
    "vinaśanaṃ": ['ap90'],
    "vinaśvara": ['cae', 'mw'],
    "vinaśvaratva": ['mw'],
    "vinaśvaratā": ['mw'],
    "vinaḷīkata": ['cped'],
    "vinaṃgṛsa": ['gra'],
    "vinaṃśin": ['mw'],
    "vinaṅgṛsa": ['mw'],
    "vinaṣṭa": ['ap90', 'cae', 'mw'],
    "vinaṣṭacakṣus": ['mw'],
    "vinaṣṭadharma": ['mw'],
    "vinaṣṭadṛṣṭi": ['mw'],
    "vinaṣṭaka": ['mw'],
    "vinaṣṭatejas": ['mw'],
    "vinaṣṭi": ['cae', 'mw'],
    "vinaṣṭiḥ": ['ap90'],
    "vinaṣṭopajīvin": ['mw'],
    "vinaṭana": ['ddsa', 'mw'],
    "vinaṭṭha": ['cped'],
    "vind": ['ddsa', 'gra', 'mw'],
    "vinda": ['cae', 'ddsa', 'mw'],
    "vindaka": ['cped', 'mw'],
    "vindamāna": ['cped'],
    "vindanta": ['cped'],
    "vindati": ['cped'],
    "vindatvat": ['mw'],
    "vindatvatī": ['mw'],
    "vindh": ['mw'],
    "vindha": ['mw'],
    "vindhaculaka": ['mw'],
    "vindhaka": ['bhs'],
    "vindhapattra": ['mw'],
    "vindhasa": ['mw'],
    "vindhati": ['bhs'],
    "vindhya": ['cae', 'ddsa', 'mw'],
    "vindhyaculika": ['mw'],
    "vindhyagiri": ['cae', 'mw'],
    "vindhyaka": ['mw'],
    "vindhyakailāsavāsinī": ['mw'],
    "vindhyakandara": ['mw'],
    "vindhyaketu": ['mw'],
    "vindhyakūṭa": ['mw'],
    "vindhyakūṭaka": ['mw'],
    "vindhyakūṭana": ['mw'],
    "vindhyamauleya": ['mw'],
    "vindhyamūlika": ['mw'],
    "vindhyanilayā": ['mw'],
    "vindhyanivāsin": ['mw'],
    "vindhyapara": ['mw'],
    "vindhyaparvata": ['cae', 'mw'],
    "vindhyapulika": ['mw'],
    "vindhyapālaka": ['mw'],
    "vindhyasena": ['mw'],
    "vindhyastha": ['mw'],
    "vindhyavana": ['cae', 'mw'],
    "vindhyavarman": ['mw'],
    "vindhyavat": ['mw'],
    "vindhyavāsaka": ['mw'],
    "vindhyavāsin": ['cae', 'mw'],
    "vindhyavāsinī": ['mw'],
    "vindhyavāsinīdaśaka": ['mw'],
    "vindhyaśaila": ['mw'],
    "vindhyaśakti": ['mw'],
    "vindhyeśvarīprasāda": ['mw'],
    "vindhyā": ['mw'],
    "vindhyācala": ['mw'],
    "vindhyācalavāsinī": ['mw'],
    "vindhyādhivāsinī": ['mw'],
    "vindhyādri": ['mw'],
    "vindhyādrivāsinī": ['mw'],
    "vindhyāntavāsin": ['mw'],
    "vindhyāri": ['mw'],
    "vindhyāvali": ['mw'],
    "vindhyāvalisuta": ['mw'],
    "vindhyāvalī": ['mw'],
    "vindhyāvalīputra": ['mw'],
    "vindhyāvalīsuta": ['mw'],
    "vindhyāya": ['ddsa', 'mw'],
    "vindhyāṭavī": ['cae', 'mw'],
    "vindi": ['cped'],
    "vindita": ['cped'],
    "vinditabba": ['cped'],
    "vinditvā": ['cped'],
    "vindiya": ['cped'],
    "vindiyamāna": ['cped'],
    "vindu": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vindusāra": ['bhs'],
    "vinemidaśana": ['mw'],
    "vinenta": ['cped'],
    "vinesi": ['cped'],
    "vinetabba": ['cped'],
    "vinetar": ['cped'],
    "vineti": ['cped'],
    "vinetra": ['cae', 'mw'],
    "vinetvā": ['cped'],
    "vinetṛ": ['ap90', 'cae', 'mw'],
    "vineya": ['bhs', 'cae', 'mw'],
    "vineyajana": ['cped'],
    "vineyya": ['cped'],
    "vini": ['cped'],
    "vinibaddha": ['bhs', 'cped'],
    "vinibadhyate": ['bhs'],
    "vinibandha": ['bhs', 'cped', 'mw'],
    "vinibandhana": ['bhs'],
    "vinibandhayati": ['bhs'],
    "vinibarhaṇa": ['mw'],
    "vinibarhin": ['mw'],
    "vinibbhoga": ['cped'],
    "vinibbhujati": ['cped'],
    "vinibbhuji": ['cped'],
    "vinibbhujitvā": ['cped'],
    "vinibhāga": ['bhs'],
    "vinicchakathā": ['cped'],
    "vinicchasālā": ['cped'],
    "vinicchaya": ['cped'],
    "vinicchaṭṭhāna": ['cped'],
    "vinicchenta": ['cped'],
    "vinicchesi": ['cped'],
    "viniccheti": ['cped'],
    "vinicchetvā": ['cped'],
    "vinicchinana": ['cped'],
    "vinicchini": ['cped'],
    "vinicchinitvā": ['cped'],
    "vinicchināti": ['cped'],
    "vinicchita": ['cped'],
    "vinid": ['mw'],
    "vinidhvas": ['mw'],
    "vinidhvasta": ['mw'],
    "vinidhvaṃs": ['mw'],
    "vinidhā": ['mw'],
    "vinidhāya": ['cped'],
    "vinidhṛ": ['mw'],
    "vinidra": ['ap90', 'cae', 'mw'],
    "vinidratva": ['mw'],
    "vinidratā": ['mw'],
    "vinigad": ['mw'],
    "vinigamaka": ['mw'],
    "vinigamanā": ['mw'],
    "vinigata": ['bhs'],
    "vinigaḍa": ['ap90', 'mw'],
    "viniggata": ['cped'],
    "vinighna": ['mw'],
    "vinighnat": ['mw'],
    "vinighūrṇita": ['mw'],
    "vinigrah": ['ap90', 'mw'],
    "vinigraha": ['cae', 'mw'],
    "vinigrahaḥ": ['ap90'],
    "vinigrahārtha": ['mw'],
    "vinigrahārthīya": ['mw'],
    "vinigrantha": ['bhs'],
    "vinigrāhya": ['mw'],
    "viniguh": ['mw'],
    "vinigūhita": ['mw'],
    "vinigūhitṛ": ['mw'],
    "vinihan": ['mw'],
    "vinihata": ['ap90', 'mw'],
    "vinihita": ['cae', 'mw'],
    "vinihitadṛṣṭi": ['mw'],
    "vinihitamanas": ['mw'],
    "vinihitātman": ['mw'],
    "vinihnu": ['mw'],
    "vinihnuta": ['mw'],
    "vinij": ['mw'],
    "vinikarttavya": ['mw'],
    "vinikaṣaṇa": ['mw'],
    "viniketa": ['mw'],
    "vinikocana": ['mw'],
    "vinikāra": ['mw'],
    "vinikīrṇa": ['ap90', 'mw'],
    "vinikṛ": ['mw'],
    "vinikṛntana": ['mw'],
    "vinikṛt": ['mw'],
    "vinikṛta": ['mw'],
    "vinikṛtta": ['mw'],
    "vinikṝ": ['ap90', 'mw'],
    "vinikṣ": ['mw'],
    "vinikṣaṇa": ['mw'],
    "vinikṣepa": ['ddsa', 'mw'],
    "vinikṣepaḥ": ['ap90'],
    "vinikṣepya": ['mw'],
    "vinikṣip": ['ap90', 'mw'],
    "vinikṣipta": ['mw'],
    "vinimagna": ['mw'],
    "vinimaya": ['cae', 'cped', 'mw'],
    "vinimayaḥ": ['ap90'],
    "vinimeṣa": ['cae', 'mw'],
    "vinimeṣaḥ": ['ap90'],
    "vinimeṣaṇa": ['mw'],
    "vinimitta": ['mw'],
    "vinimiśra": ['bhs'],
    "vinimmutta": ['cped'],
    "vinimocesi": ['cped'],
    "vinimoceti": ['cped'],
    "vinimocetvā": ['cped'],
    "vinimocita": ['cped'],
    "vinimīlana": ['cae', 'mw'],
    "vinimīlita": ['mw'],
    "vinimīlitekṣaṇa": ['mw'],
    "vinind": ['mw'],
    "vininda": ['cae', 'mw'],
    "vinindaka": ['cae', 'mw'],
    "vinindā": ['mw'],
    "vinipat": ['ap90', 'mw'],
    "vinipatita": ['mw'],
    "vinipaṭ": ['mw'],
    "vinipāta": ['bhs', 'cae', 'cped', 'mw'],
    "vinipātagata": ['mw'],
    "vinipātaka": ['mw'],
    "vinipātana": ['mw'],
    "vinipātapratikriyā": ['mw'],
    "vinipātapratīkāra": ['mw'],
    "vinipātatika": ['cped'],
    "vinipātayati": ['bhs'],
    "vinipātaśaṃsin": ['mw'],
    "vinipātaḥ": ['ap90'],
    "vinipāteti": ['cped'],
    "vinipātin": ['mw'],
    "vinipātita": ['mw'],
    "vinipīḍ": ['mw'],
    "vinirbandha": ['mw'],
    "vinirbaṃdhaḥ": ['ap90'],
    "vinirbhagna": ['mw'],
    "vinirbhagnanayana": ['mw'],
    "vinirbharts": ['mw'],
    "vinirbhaya": ['mw'],
    "vinirbheda": ['bhs'],
    "vinirbhedana": ['bhs'],
    "vinirbhid": ['mw'],
    "vinirbhinna": ['mw'],
    "vinirbhoga": ['bhs', 'mw'],
    "vinirbhuj": ['mw'],
    "vinirbhāga": ['bhs'],
    "vinirbāhu": ['mw'],
    "vinirbānu": ['mw'],
    "vinirdagdha": ['mw'],
    "vinirdah": ['mw'],
    "vinirdahana": ['mw'],
    "vinirdahanī": ['mw'],
    "vinirdeśya": ['mw'],
    "vinirdhuta": ['mw'],
    "vinirdhū": ['mw'],
    "vinirdhūta": ['mw'],
    "vinirdiś": ['mw'],
    "vinirdiṣṭa": ['mw'],
    "vinirgam": ['ap90', 'mw'],
    "vinirgama": ['cae', 'ddsa', 'mw'],
    "vinirgamaḥ": ['ap90'],
    "vinirgata": ['mw'],
    "vinirgati": ['mw'],
    "vinirghoṣa": ['mw'],
    "vinirhata": ['mw'],
    "vinirhṛ": ['mw'],
    "vinirjaya": ['cae', 'mw'],
    "vinirjayaḥ": ['ap90'],
    "vinirji": ['ap90', 'mw'],
    "vinirjita": ['mw'],
    "vinirjñā": ['mw'],
    "vinirlikh": ['mw'],
    "vinirmala": ['mw'],
    "vinirmanth": ['mw'],
    "vinirmath": ['mw'],
    "vinirmita": ['ap90', 'mw'],
    "vinirmiti": ['mw'],
    "vinirmitsu": ['mw'],
    "vinirmokṣa": ['mw'],
    "vinirmokṣaṇatā": ['bhs'],
    "vinirmuc": ['ap90', 'mw'],
    "vinirmucya": ['bhs'],
    "vinirmukta": ['cae', 'mw'],
    "vinirmukti": ['mw'],
    "vinirmuktiḥ": ['ap90'],
    "vinirmā": ['ap90', 'mw'],
    "vinirmātṛ": ['mw'],
    "vinirmāṇa": ['cae', 'mw'],
    "vinirmūḍha": ['mw'],
    "vinirmūḍhapratijña": ['mw'],
    "vinirodha": ['mw'],
    "vinirodhin": ['mw'],
    "vinirvam": ['mw'],
    "vinirvarṇ": ['mw'],
    "vinirvṛt": ['ap90'],
    "vinirvṛtta": ['cae', 'mw'],
    "viniryat": ['mw'],
    "viniryuj": ['mw'],
    "viniryā": ['mw'],
    "viniryāta": ['mw'],
    "viniryāṇa": ['cae', 'mw'],
    "vinirṇaya": ['cae', 'mw'],
    "vinirṇayaḥ": ['ap90'],
    "vinirṇī": ['ap90', 'mw'],
    "vinirṇīta": ['mw'],
    "vinismṛta": ['mw'],
    "vinistap": ['mw'],
    "vinisūd": ['mw'],
    "vinisṛta": ['mw'],
    "vinivaraṇa": ['bhs'],
    "vinivartaka": ['ddsa', 'mw'],
    "vinivartana": ['cae', 'mw'],
    "vinivartayitar": ['bhs'],
    "vinivarti": ['bhs', 'mw'],
    "vinivartin": ['mw'],
    "vinivartita": ['mw'],
    "vinivaṭṭesi": ['cped'],
    "vinivaṭṭeti": ['cped'],
    "vinivaṭṭetvā": ['cped'],
    "vinivaṭṭita": ['cped'],
    "vinivedana": ['mw'],
    "vinivedita": ['mw'],
    "viniveśa": ['cae', 'mw'],
    "viniveśana": ['mw'],
    "viniveśaḥ": ['ap90'],
    "viniveśin": ['mw'],
    "viniveśita": ['mw'],
    "viniveṭhama": ['cped'],
    "viniveṭhesi": ['cped'],
    "viniveṭheti": ['cped'],
    "viniveṭhetvā": ['cped'],
    "viniveṭhita": ['cped'],
    "vinivid": ['ap90', 'mw'],
    "vinividdha": ['cped'],
    "vinivijjha": ['cped'],
    "vinivijjhana": ['cped'],
    "vinivijjhati": ['cped'],
    "vinivijjhi": ['cped'],
    "vinivijjhitvā": ['cped'],
    "viniviś": ['ap90', 'mw'],
    "viniviṣṭa": ['cae', 'mw'],
    "vinivāraṇa": ['cae', 'mw'],
    "vinivārita": ['mw'],
    "vinivārya": ['mw'],
    "vinivṛ": ['ap90', 'mw'],
    "vinivṛt": ['ap90', 'mw'],
    "vinivṛtta": ['ap90', 'cae', 'mw'],
    "vinivṛttakāma": ['mw'],
    "vinivṛttaśāpa": ['mw'],
    "vinivṛtti": ['cae', 'mw'],
    "vinivṛttiḥ": ['ap90'],
    "viniyam": ['ap90', 'mw'],
    "viniyama": ['mw'],
    "viniyamaḥ": ['ap90'],
    "viniyamya": ['mw'],
    "viniyata": ['ap90', 'mw'],
    "viniyatacetas": ['mw'],
    "viniyatāhāra": ['mw'],
    "viniyoga": ['cae', 'mw'],
    "viniyogamālā": ['mw'],
    "viniyogasatkriyā": ['mw'],
    "viniyogasaṃgraha": ['mw'],
    "viniyogaḥ": ['ap90'],
    "viniyojana": ['bhs'],
    "viniyojita": ['mw'],
    "viniyojya": ['mw'],
    "viniyoktavya": ['mw'],
    "viniyoktṛ": ['mw'],
    "viniyuj": ['ap90', 'mw'],
    "viniyukta": ['ap90', 'mw'],
    "viniyuktātman": ['mw'],
    "viniśam": ['mw'],
    "viniścala": ['cae', 'mw'],
    "viniścar": ['mw'],
    "viniścaya": ['bhs', 'cae', 'ddsa', 'mw'],
    "viniścayajña": ['mw'],
    "viniścayaḥ": ['ap90'],
    "viniści": ['ap90', 'mw'],
    "viniścita": ['cae', 'mw'],
    "viniścitam": ['mw'],
    "viniścitārtha": ['mw'],
    "viniścāyin": ['mw'],
    "viniśrita": ['bhs'],
    "viniśvas": ['mw'],
    "viniśvasita": ['mw'],
    "viniśvāsa": ['mw'],
    "viniśvāsaḥ": ['ap90'],
    "viniḥkampa": ['mw'],
    "viniḥsaraṇa": ['mw'],
    "viniḥsṛ": ['mw'],
    "viniḥsṛptāhuti": ['mw'],
    "viniḥsṛta": ['mw'],
    "viniḥsṛti": ['bhs', 'mw'],
    "viniḥsṛṣṭa": ['mw'],
    "viniḥśvas": ['mw'],
    "viniṣad": ['mw'],
    "viniṣkampa": ['mw'],
    "viniṣkram": ['mw'],
    "viniṣkriya": ['mw'],
    "viniṣkrānta": ['mw'],
    "viniṣkṛ": ['mw'],
    "viniṣpat": ['mw'],
    "viniṣpatita": ['mw'],
    "viniṣpaṭ": ['mw'],
    "viniṣpeṣa": ['mw'],
    "viniṣpeṣaḥ": ['ap90'],
    "viniṣpiṣ": ['mw'],
    "viniṣpiṣṭa": ['mw'],
    "viniṣpādya": ['mw'],
    "viniṣpāta": ['mw'],
    "viniṣpīḍ": ['mw'],
    "viniṣūdita": ['mw'],
    "viniṣṭan": ['mw'],
    "viniṣṭapta": ['mw'],
    "viniṣṭha": ['bhs'],
    "viniṣṭhiv": ['mw'],
    "vinna": ['ap90', 'cae', 'ddsa', 'mw'],
    "vinnakaḥ": ['ap90'],
    "vinnapa": ['mw'],
    "vinnibhaṭṭa": ['mw'],
    "vinnā": ['mw'],
    "vinoda": ['cae', 'cped', 'ddsa', 'mw'],
    "vinodakallola": ['mw'],
    "vinodamañjari": ['mw'],
    "vinodana": ['bhs', 'cae', 'cped', 'mw'],
    "vinodanatā": ['mw'],
    "vinodanaśata": ['mw'],
    "vinodanaṃ": ['ap90'],
    "vinodarasika": ['mw'],
    "vinodaraṅga": ['mw'],
    "vinodasthāṇa": ['mw'],
    "vinodavat": ['mw'],
    "vinodaḥ": ['ap90'],
    "vinodesi": ['cped'],
    "vinodetar": ['cped'],
    "vinodeti": ['cped'],
    "vinodetvā": ['cped'],
    "vinodin": ['cae', 'mw'],
    "vinodita": ['cped', 'mw'],
    "vinodāpapādin": ['mw'],
    "vinodārtham": ['mw'],
    "vinodāya": ['mw'],
    "vinokti": ['ddsa', 'mw'],
    "vinta": ['mw'],
    "vinu": ['mw'],
    "vinud": ['ap90', 'cae', 'gra', 'mw'],
    "vinunna": ['mw'],
    "vinutti": ['cae', 'mw'],
    "vinyas": ['ap90', 'mw'],
    "vinyasana": ['mw'],
    "vinyasta": ['ap90', 'mw'],
    "vinyastaka": ['bhs'],
    "vinyasya": ['mw'],
    "vinyaya": ['ddsa', 'mw'],
    "vinyāka": ['mw'],
    "vinyāsa": ['cae', 'mw'],
    "vinyāsarekhā": ['mw'],
    "vinyāsaḥ": ['ap90'],
    "vinyāsita": ['bhs'],
    "vinā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vinābhava": ['ddsa', 'mw'],
    "vinābhāva": ['cped', 'mw'],
    "vinābhāvam": ['mw'],
    "vinābhāvika": ['bhs'],
    "vinābhāvin": ['mw'],
    "vinābhāvya": ['mw'],
    "vinābhūta": ['mw'],
    "vinābhūtvā": ['mw'],
    "vinābhūya": ['mw'],
    "vinādayati": ['bhs'],
    "vinādin": ['mw'],
    "vinādita": ['mw'],
    "vināha": ['bhs', 'mw'],
    "vināhaḥ": ['ap90'],
    "vināka": ['bhs'],
    "vinākaroti": ['cped'],
    "vinākṛta": ['mw'],
    "vinākṛtya": ['mw'],
    "vināla": ['mw'],
    "vināma": ['cped', 'ddsa', 'mw'],
    "vināmaka": ['mw'],
    "vināmana": ['cped'],
    "vināmaḥ": ['ap90'],
    "vināmesi": ['cped'],
    "vināmeti": ['cped'],
    "vināmetvā": ['cped'],
    "vināmikā": ['mw'],
    "vināmita": ['cped', 'mw'],
    "vinānyonyam": ['mw'],
    "vināruhā": ['mw'],
    "vinārāśaṃsa": ['mw'],
    "vināsa": ['cped', 'mw'],
    "vināsadaśana": ['mw'],
    "vināsaka": ['ap90', 'cped', 'mw'],
    "vināsana": ['cped'],
    "vināsanta": ['cped'],
    "vināsenta": ['cped'],
    "vināsesi": ['cped'],
    "vināseti": ['cped'],
    "vināsetvā": ['cped'],
    "vināsika": ['ap90', 'mw'],
    "vināsikā": ['mw'],
    "vināsita": ['cped'],
    "vinātha": ['cae', 'mw'],
    "vināti": ['cped'],
    "vināvāsa": ['mw'],
    "vināyaka": ['bhs', 'cae', 'cped', 'mw'],
    "vināyakabhaṭṭa": ['mw'],
    "vināyakabhojanavarṇanā": ['mw'],
    "vināyakacarita": ['mw'],
    "vināyakacaturthī": ['mw'],
    "vināyakacaturthīvrata": ['mw'],
    "vināyakadvādaśanāmastotra": ['mw'],
    "vināyakamāhātmya": ['mw'],
    "vināyakapaṇḍita": ['mw'],
    "vināyakapurāṇa": ['mw'],
    "vināyakapūjāvidhi": ['mw'],
    "vināyakasahasranāman": ['mw'],
    "vināyakasaṃhitā": ['mw'],
    "vināyakasnapanacaturthī": ['mw'],
    "vināyakastavarāja": ['mw'],
    "vināyakavratakalpa": ['mw'],
    "vināyakavratapūjā": ['mw'],
    "vināyakaśānti": ['mw'],
    "vināyakaśāntipaddhati": ['mw'],
    "vināyakaśāntiprayoga": ['mw'],
    "vināyakaśāntisaṃgraha": ['mw'],
    "vināyakaḥ": ['ap90'],
    "vināyakotpatti": ['mw'],
    "vināyakāvatāravarṇana": ['mw'],
    "vināyakāvirbhāva": ['mw'],
    "vināyikā": ['ap90', 'mw'],
    "vināśa": ['cae', 'ddsa', 'mw'],
    "vināśadharman": ['mw'],
    "vināśahetu": ['mw'],
    "vināśaka": ['cae', 'mw'],
    "vināśakṛt": ['mw'],
    "vināśana": ['cae', 'mw'],
    "vināśanaṃ": ['ap90'],
    "vināśasambhava": ['mw'],
    "vināśayitṛ": ['mw'],
    "vināśaḥ": ['ap90'],
    "vināśin": ['cae', 'mw'],
    "vināśita": ['mw'],
    "vināśitva": ['mw'],
    "vināśonmukha": ['mw'],
    "vināśya": ['cae', 'mw'],
    "vināśyatva": ['mw'],
    "vināśānta": ['mw'],
    "vināḍa": ['mw'],
    "vināḍikā": ['ddsa', 'mw'],
    "vināḍiḥ": ['ap90'],
    "vināḍī": ['mw'],
    "vināṭa": ['cae', 'mw'],
    "vinī": ['ap90', 'mw'],
    "vinīla": ['mw'],
    "vinīlabandhana": ['mw'],
    "vinīlaka": ['bhs', 'mw'],
    "vinīta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vinītadatta": ['mw'],
    "vinītadeva": ['bhs', 'mw'],
    "vinītaka": ['mw'],
    "vinītakaṃ": ['ap90'],
    "vinītamati": ['mw'],
    "vinītaprabha": ['mw'],
    "vinītasattva": ['mw'],
    "vinītasena": ['mw'],
    "vinītatva": ['mw'],
    "vinītatā": ['mw'],
    "vinītaveṣa": ['mw'],
    "vinītaveṣābharaṇa": ['mw'],
    "vinīteśvara": ['bhs', 'mw'],
    "vinīti": ['cae', 'mw'],
    "vinītiḥ": ['ap90'],
    "vinītātman": ['cae', 'mw'],
    "vinītāśva": ['mw'],
    "vinīvaraṇa": ['bhs', 'cped', 'mw'],
    "vinīvi": ['mw'],
    "vinīya": ['mw'],
    "vinīyaḥ": ['ap90'],
    "vinṛt": ['mw'],
    "viodana": ['gra'],
    "vioman": ['gra'],
    "viomasad": ['gra'],
    "vip": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vipa": ['mw'],
    "vipac": ['ap90', 'mw'],
    "vipaccamāna": ['cped'],
    "vipaccati": ['cped'],
    "vipacci": ['cped'],
    "vipad": ['ap90', 'cae', 'mw'],
    "vipaddaśā": ['mw'],
    "vipadgata": ['mw'],
    "vipadgrasta": ['mw'],
    "vipadma": ['mw'],
    "vipadrahita": ['mw'],
    "vipaduddharaṇa": ['mw'],
    "vipaduddhāra": ['mw'],
    "vipadumaka": ['mw'],
    "vipadyukta": ['mw'],
    "vipadā": ['ap90', 'mw'],
    "vipadāka": ['bhs'],
    "vipadākrānta": ['mw'],
    "vipadī": ['mw'],
    "vipajjana": ['cped'],
    "vipajjati": ['cped'],
    "vipajji": ['cped'],
    "vipakka": ['cped'],
    "vipakkha": ['cped'],
    "vipakkhasevaka": ['cped'],
    "vipakkhika": ['cped'],
    "vipaktavya": ['mw'],
    "vipaktrima": ['ap90', 'mw'],
    "vipakva": ['ap90', 'cae', 'ddsa', 'mw'],
    "vipakṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vipakṣabhāva": ['cae', 'mw'],
    "vipakṣapāta": ['mw'],
    "vipakṣaramaṇī": ['mw'],
    "vipakṣas": ['cae', 'gra', 'mw'],
    "vipakṣatas": ['mw'],
    "vipakṣatva": ['mw'],
    "vipakṣatā": ['ap90', 'mw'],
    "vipakṣaya": ['mw'],
    "vipakṣaśūla": ['mw'],
    "vipakṣika": ['bhs'],
    "vipakṣākrānta": ['mw'],
    "vipakṣīkṛ": ['ddsa', 'mw'],
    "vipakṣīya": ['cae', 'mw'],
    "vipala": ['mw'],
    "vipalaṃ": ['ap90'],
    "vipallattha": ['cped'],
    "vipallāsa": ['cped'],
    "vipalyay": ['mw'],
    "vipalyaṅg": ['mw'],
    "vipalāy": ['mw'],
    "vipalāyana": ['mw'],
    "vipalāyanaṃ": ['ap90'],
    "vipalāyin": ['mw'],
    "vipalāyita": ['mw'],
    "vipalāśa": ['mw'],
    "vipan": ['mw'],
    "vipanna": ['ap90', 'cae', 'cped', 'mw'],
    "vipannadeha": ['mw'],
    "vipannadiṭṭhī": ['cped'],
    "vipannadīdhiti": ['mw'],
    "vipannaga": ['mw'],
    "vipannaka": ['mw'],
    "vipannakṛtya": ['mw'],
    "vipannasīla": ['cped'],
    "vipannatā": ['mw'],
    "vipannāpatyā": ['mw'],
    "vipannārtha": ['mw'],
    "vipanyayā": ['cae', 'mw'],
    "vipanyu": ['cae', 'gra', 'mw'],
    "vipanyā": ['cae', 'gra', 'mw'],
    "vipare": ['mw'],
    "viparibhraṃśa": ['mw'],
    "viparicchinna": ['mw'],
    "viparicchinnamūla": ['mw'],
    "viparidhā": ['mw'],
    "viparidhāna": ['mw'],
    "viparidhāv": ['mw'],
    "viparidhāvaka": ['mw'],
    "viparidru": ['mw'],
    "viparigata": ['bhs'],
    "viparigā": ['mw'],
    "vipariharaṇa": ['mw'],
    "viparihāra": ['mw'],
    "viparihṛ": ['mw'],
    "viparikram": ['mw'],
    "viparikrāmam": ['mw'],
    "viparikrānta": ['mw'],
    "viparilopa": ['mw'],
    "viparilupta": ['mw'],
    "viparimlāna": ['mw'],
    "viparimuc": ['mw'],
    "viparipat": ['mw'],
    "viparitap": ['mw'],
    "viparivartana": ['mw'],
    "viparivartanaṃ": ['ap90'],
    "viparivartanī": ['mw'],
    "viparivartita": ['mw'],
    "viparivartitādhara": ['mw'],
    "viparivatsara": ['mw'],
    "viparivattana": ['cped'],
    "viparivattati": ['cped'],
    "viparivatti": ['cped'],
    "viparivattita": ['cped'],
    "viparivṛt": ['ap90', 'mw'],
    "viparivṛtti": ['mw'],
    "vipariyesa": ['cped'],
    "vipariyāya": ['cped'],
    "vipariṇam": ['ap90', 'mw'],
    "vipariṇamana": ['mw'],
    "vipariṇamanaṃ": ['ap90'],
    "vipariṇamayitavya": ['mw'],
    "vipariṇata": ['cped', 'mw'],
    "vipariṇāma": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vipariṇāmesi": ['cped'],
    "vipariṇāmeti": ['cped'],
    "vipariṇāmin": ['mw'],
    "vipariṇāmita": ['cped'],
    "vipariṇīta": ['mw'],
    "viparokṣa": ['bhs'],
    "viparus": ['mw'],
    "viparva": ['gra', 'mw'],
    "viparvan": ['mw'],
    "viparya": ['bhs', 'mw'],
    "viparyak": ['mw'],
    "viparyas": ['ap90', 'mw'],
    "viparyasta": ['ap90', 'cae', 'mw'],
    "viparyastamanaśceṣṭa": ['mw'],
    "viparyastaputrā": ['mw'],
    "viparyastatā": ['mw'],
    "viparyata": ['bhs'],
    "viparyaya": ['cae', 'ddsa', 'mw'],
    "viparyayaḥ": ['ap90'],
    "viparyaye": ['mw'],
    "viparyayena": ['mw'],
    "viparyayāt": ['mw'],
    "viparyāsa": ['bhs', 'cae', 'mw'],
    "viparyāsam": ['mw'],
    "viparyāsaḥ": ['ap90'],
    "viparyāsopamā": ['cae', 'mw'],
    "viparyāvṛt": ['mw'],
    "viparyāya": ['bhs', 'mw'],
    "viparyāyaḥ": ['ap90'],
    "viparyāṇa": ['ddsa', 'mw'],
    "viparyāṇīkṛta": ['mw'],
    "viparyūh": ['mw'],
    "viparākrama": ['mw'],
    "viparī": ['ap90', 'mw'],
    "viparīta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "viparītabodha": ['mw'],
    "viparītabuddhi": ['mw'],
    "viparītacetas": ['mw'],
    "viparītacitta": ['mw'],
    "viparītagati": ['mw'],
    "viparītagrahaprakaraṇa": ['mw'],
    "viparītaka": ['mw'],
    "viparītakara": ['mw'],
    "viparītakartṛ": ['mw'],
    "viparītakrīḍā": ['mw'],
    "viparītakārin": ['mw'],
    "viparītalakṣaṇā": ['mw'],
    "viparītamallataila": ['mw'],
    "viparītamati": ['mw'],
    "viparītapathyā": ['mw'],
    "viparītapratyaṅgirā": ['mw'],
    "viparītarata": ['mw'],
    "viparītatva": ['mw'],
    "viparītatā": ['ap90', 'mw'],
    "viparītavat": ['mw'],
    "viparītavṛtti": ['mw'],
    "viparītottara": ['mw'],
    "viparītā": ['cped', 'mw'],
    "viparītādi": ['mw'],
    "viparītākhyānakī": ['mw'],
    "viparītānta": ['mw'],
    "viparītāyana": ['mw'],
    "viparītāyanagata": ['mw'],
    "viparṇa": ['mw'],
    "viparṇaka": ['mw'],
    "vipas": ['cae', 'ddsa', 'gra', 'mw'],
    "vipassaka": ['cped'],
    "vipassanā": ['cped'],
    "vipassanādhura": ['cped'],
    "vipassanāñāṇa": ['cped'],
    "vipassati": ['cped'],
    "vipassi": ['cped'],
    "vipassitvā": ['cped'],
    "vipassī": ['cped'],
    "vipat": ['mw'],
    "vipatha": ['bhs', 'cae', 'cped', 'mw'],
    "vipathagati": ['mw'],
    "vipathagāmin": ['mw'],
    "vipathavāha": ['mw'],
    "vipathaya": ['mw'],
    "vipathayamaka": ['mw'],
    "vipathayuga": ['mw'],
    "vipathaḥ": ['ap90'],
    "vipathi": ['cae', 'gra', 'mw'],
    "vipathāvapātaparatā": ['mw'],
    "vipatita": ['mw'],
    "vipatitaloman": ['mw'],
    "vipatkara": ['mw'],
    "vipatkarī": ['mw'],
    "vipatkāla": ['mw'],
    "vipatman": ['gra', 'mw'],
    "vipatna": ['mw'],
    "vipatphala": ['mw'],
    "vipatsāgara": ['mw'],
    "vipatti": ['cae', 'cped', 'mw'],
    "vipattikara": ['mw'],
    "vipattikāla": ['mw'],
    "vipattirahita": ['mw'],
    "vipattiyukta": ['mw'],
    "vipattiḥ": ['ap90'],
    "vipatāka": ['mw'],
    "vipavana": ['mw'],
    "vipavya": ['mw'],
    "vipaya": ['ddsa'],
    "vipayas": ['mw'],
    "vipañcanaka": ['bhs', 'mw'],
    "vipañcaya": ['mw'],
    "vipañcika": ['bhs', 'mw'],
    "vipañcikā": ['bhs', 'mw'],
    "vipañcita": ['bhs'],
    "vipañcitajña": ['bhs'],
    "vipañcī": ['cae', 'mw'],
    "vipaś": ['mw'],
    "vipaści": ['mw'],
    "vipaścin": ['bhs'],
    "vipaścit": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vipaścita": ['mw'],
    "vipaśu": ['mw'],
    "vipaśvin": ['mw'],
    "vipaśyaka": ['bhs'],
    "vipaśyana": ['mw'],
    "vipaśyanā": ['bhs'],
    "vipaśyin": ['bhs', 'mw'],
    "vipaḍumaka": ['bhs'],
    "vipaṃcikā": ['ap90'],
    "vipaṃsayati": ['bhs'],
    "vipaṇ": ['ap90', 'mw'],
    "vipaṇa": ['cae', 'mw'],
    "vipaṇana": ['cae', 'mw'],
    "vipaṇaḥ": ['ap90'],
    "vipaṇi": ['cae', 'mw'],
    "vipaṇigata": ['cae', 'mw'],
    "vipaṇijīvikā": ['mw'],
    "vipaṇijīvin": ['mw'],
    "vipaṇimadhyaga": ['mw'],
    "vipaṇin": ['ap90', 'mw'],
    "vipaṇipatha": ['mw'],
    "vipaṇisthapaṇya": ['mw'],
    "vipaṇiḥ": ['ap90'],
    "vipaṇāpaṇavat": ['mw'],
    "vipaṇḍaka": ['bhs'],
    "vipaṇḍita": ['bhs'],
    "vipaṭ": ['ap90', 'mw'],
    "vipaṭh": ['mw'],
    "vipaṭmaka": ['bhs'],
    "vipaṭumaka": ['bhs'],
    "vipha": ['mw'],
    "viphal": ['mw'],
    "viphala": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "viphalapreraṇa": ['mw'],
    "viphalatva": ['cae', 'mw'],
    "viphalatā": ['cae', 'mw'],
    "viphalaya": ['mw'],
    "viphalaśrama": ['mw'],
    "viphalaśramatva": ['mw'],
    "viphalpha": ['mw'],
    "viphalārambha": ['mw'],
    "viphalāśa": ['mw'],
    "viphalī": ['mw'],
    "viphalībhaviṣṇu": ['mw'],
    "viphalībhaviṣṇutva": ['mw'],
    "viphalībhaviṣṇutā": ['mw'],
    "viphalībhū": ['ap90', 'mw'],
    "viphalībhūta": ['mw'],
    "viphalīkaraṇa": ['mw'],
    "viphalīkṛ": ['ap90', 'cae', 'mw'],
    "viphalīkṛta": ['mw'],
    "viphalīkṛtayatna": ['mw'],
    "viphāṇṭa": ['mw'],
    "vipina": ['cae', 'cped', 'ddsa', 'mw'],
    "vipinatilaka": ['mw'],
    "vipinaukas": ['mw'],
    "vipinaṃ": ['ap90'],
    "vipināya": ['mw'],
    "vipipāna": ['mw'],
    "vipiś": ['mw'],
    "vipiśita": ['mw'],
    "vipiṣṭī": ['mw'],
    "vipiṭṭhikatvā": ['cped'],
    "viplava": ['cae', 'ddsa', 'mw'],
    "viplavatas": ['mw'],
    "viplavaḥ": ['ap90'],
    "viplavin": ['mw'],
    "viplavāṭṭahāsa": ['mw'],
    "viplu": ['ap90', 'mw'],
    "vipluta": ['ap90', 'cae', 'mw'],
    "viplutabhāṣin": ['mw'],
    "viplutalocana": ['mw'],
    "viplutanetra": ['mw'],
    "viplutayoni": ['mw'],
    "vipluti": ['mw'],
    "vipluṣ": ['ap90', 'cae', 'mw'],
    "vipluṣṭa": ['mw'],
    "viplāva": ['mw'],
    "viplāvaka": ['mw'],
    "viplāvana": ['mw'],
    "viplāvaḥ": ['ap90'],
    "viplāvin": ['mw'],
    "viplāvita": ['mw'],
    "vipodhā": ['ddsa', 'gra', 'mw'],
    "vipothita": ['mw'],
    "vippa": ['cped'],
    "vippahīna": ['cped'],
    "vippajahati": ['cped'],
    "vippajahi": ['cped'],
    "vippakata": ['cped'],
    "vippakirati": ['cped'],
    "vippakiri": ['cped'],
    "vippakiritvā": ['cped'],
    "vippakiṇṇa": ['cped'],
    "vippakula": ['cped'],
    "vippakāra": ['cped'],
    "vippalapati": ['cped'],
    "vippalapi": ['cped'],
    "vippalujjati": ['cped'],
    "vippalāpa": ['cped'],
    "vippamuttu": ['cped'],
    "vippasanna": ['cped'],
    "vippasīdati": ['cped'],
    "vippasīdi": ['cped'],
    "vippavasati": ['cped'],
    "vippavasi": ['cped'],
    "vippavuttha": ['cped'],
    "vippavāsa": ['cped'],
    "vippayoga": ['cped'],
    "vippayoganta": ['cped'],
    "vippayutta": ['cped'],
    "vippaṭipajjati": ['cped'],
    "vippaṭipajji": ['cped'],
    "vippaṭipanna": ['cped'],
    "vippaṭipatti": ['cped'],
    "vippaṭisāra": ['cped'],
    "vippaṭisārī": ['cped'],
    "vipphandana": ['cped'],
    "vipphandati": ['cped'],
    "vipphandi": ['cped'],
    "vipphandita": ['cped'],
    "vipphanditvā": ['cped'],
    "vipphuliṅga": ['cped'],
    "vipphuranta": ['cped'],
    "vipphurati": ['cped'],
    "vipphuraṇa": ['cped'],
    "vipphuri": ['cped'],
    "vipphurita": ['cped'],
    "vipphālita": ['cped'],
    "vipphāra": ['cped'],
    "vipphārika": ['cped'],
    "vipphārita": ['cped'],
    "vipra": ['cae', 'ddsa', 'gra', 'mw'],
    "viprabandhu": ['mw'],
    "viprabhāva": ['mw'],
    "viprabodhita": ['mw'],
    "viprabuddha": ['mw'],
    "vipracchanna": ['mw'],
    "viprach": ['mw'],
    "vipracint": ['mw'],
    "vipracit": ['mw'],
    "vipracita": ['mw'],
    "vipracitta": ['mw'],
    "vipracitti": ['mw'],
    "vipracūḍāmaṇi": ['mw'],
    "vipradaha": ['mw'],
    "vipradamana": ['mw'],
    "vipradeva": ['mw'],
    "vipradharṣa": ['mw'],
    "vipradhāv": ['mw'],
    "vipradru": ['mw'],
    "vipradruta": ['mw'],
    "vipraduh": ['mw'],
    "vipraduṣṭa": ['ap90', 'cae', 'mw'],
    "vipraduṣṭabhāva": ['mw'],
    "vipragam": ['mw'],
    "vipraghāta": ['bhs'],
    "vipraghātika": ['bhs'],
    "vipragīta": ['mw'],
    "vipraharṣa": ['bhs'],
    "viprahata": ['mw'],
    "viprahā": ['mw'],
    "viprahāṇa": ['mw'],
    "viprahīna": ['cae'],
    "viprahīṇa": ['ap90', 'cae', 'mw'],
    "viprajana": ['mw'],
    "viprajitti": ['cae', 'mw'],
    "viprajūta": ['gra', 'mw'],
    "viprajūti": ['mw'],
    "vipraka": ['mw'],
    "viprakampya": ['bhs'],
    "viprakanyā": ['mw'],
    "viprakartṛ": ['mw'],
    "viprakarṣa": ['cae', 'ddsa', 'mw'],
    "viprakarṣaḥ": ['ap90'],
    "viprakramati": ['bhs'],
    "viprakramaṇa": ['bhs'],
    "viprakuṇḍa": ['mw'],
    "viprakāra": ['cae', 'mw'],
    "viprakāraḥ": ['ap90'],
    "viprakārin": ['mw'],
    "viprakāśa": ['mw'],
    "viprakāṣṭha": ['mw'],
    "viprakīrṇa": ['ap90', 'cae', 'mw'],
    "viprakīrṇaikapārśva": ['mw'],
    "viprakīrṇaśiroruha": ['mw'],
    "viprakḷpti": ['mw'],
    "viprakṛ": ['ap90', 'mw'],
    "viprakṛt": ['mw'],
    "viprakṛta": ['ap90', 'bhs', 'mw'],
    "viprakṛti": ['cae', 'mw'],
    "viprakṛtiḥ": ['ap90'],
    "viprakṛṣ": ['ap90', 'mw'],
    "viprakṛṣṭa": ['ap90', 'cae', 'mw'],
    "viprakṛṣṭaka": ['ap90', 'mw'],
    "viprakṛṣṭatva": ['mw'],
    "viprakṛṣṭāntara": ['cae', 'mw'],
    "vipralabdha": ['ap90', 'mw'],
    "vipralabdham": ['mw'],
    "vipralabdhā": ['mw'],
    "vipralabdhṛ": ['mw'],
    "vipralabh": ['ap90', 'mw'],
    "vipralabhya": ['mw'],
    "vipralambaka": ['mw'],
    "vipralambha": ['cae', 'mw'],
    "vipralambhaka": ['cae', 'mw'],
    "vipralambhakatva": ['mw'],
    "vipralambhana": ['mw'],
    "vipralambhayati": ['bhs'],
    "vipralambhayitṛka": ['cae'],
    "vipralambhin": ['cae', 'mw'],
    "vipralap": ['ap90', 'mw'],
    "vipralapita": ['mw'],
    "vipralapta": ['mw'],
    "vipralaptaṃ": ['ap90'],
    "vipralaya": ['mw'],
    "vipralayaḥ": ['ap90'],
    "vipralaṃbhanaṃ": ['ap90'],
    "vipralaṃbhaḥ": ['ap90'],
    "vipralobhin": ['mw'],
    "vipraloka": ['mw'],
    "vipralopa": ['bhs', 'mw'],
    "vipralopin": ['bhs', 'mw'],
    "vipraloḍita": ['mw'],
    "vipralubh": ['mw'],
    "vipralumpaka": ['cae', 'mw'],
    "vipralup": ['mw'],
    "vipralupta": ['ap90', 'mw'],
    "vipralāpa": ['mw'],
    "vipralāpaḥ": ['ap90'],
    "vipralāpin": ['mw'],
    "vipralīna": ['mw'],
    "vipralūna": ['mw'],
    "vipramanas": ['mw'],
    "vipramanman": ['gra', 'mw'],
    "vipramatta": ['mw'],
    "vipramaṭha": ['mw'],
    "vipramocya": ['mw'],
    "vipramoha": ['mw'],
    "vipramohita": ['mw'],
    "vipramokṣa": ['mw'],
    "vipramokṣaṇa": ['mw'],
    "vipramuc": ['ap90', 'mw'],
    "vipramuh": ['mw'],
    "vipramukta": ['ap90', 'cae', 'mw'],
    "vipramuktabhaya": ['mw'],
    "vipramuṣita": ['bhs'],
    "vipramādayati": ['bhs'],
    "vipramādin": ['mw'],
    "vipramāthin": ['ddsa', 'mw'],
    "vipramūḍha": ['bhs'],
    "vipranaṣṭa": ['ap90', 'cae', 'mw'],
    "vipranaṣṭaka": ['bhs'],
    "vipranaṣṭaviśeṣaka": ['mw'],
    "viprapañca": ['bhs'],
    "viprapriya": ['mw'],
    "vipraputra": ['cae', 'ddsa', 'mw'],
    "viprapāta": ['ddsa', 'mw'],
    "viprarājia": ['gra'],
    "viprarājya": ['gra', 'mw'],
    "viprarṣabha": ['cae', 'mw'],
    "viprarṣi": ['cae', 'mw'],
    "viprasamāgama": ['mw'],
    "viprasanna": ['bhs', 'mw'],
    "viprasevā": ['mw'],
    "viprasthita": ['mw'],
    "viprasthā": ['mw'],
    "viprasva": ['cae', 'mw'],
    "viprasāraṇa": ['mw'],
    "viprasātkṛ": ['ddsa', 'mw'],
    "viprasīdati": ['bhs'],
    "viprasṛ": ['mw'],
    "viprasṛp": ['mw'],
    "viprasṛta": ['mw'],
    "vipratama": ['mw'],
    "viprath": ['mw'],
    "viprathita": ['mw'],
    "vipratibaddha": ['bhs'],
    "vipratibandha": ['bhs'],
    "vipratibhā": ['mw'],
    "vipratihīna": ['bhs'],
    "vipratikāra": ['mw'],
    "vipratikāraḥ": ['ap90'],
    "vipratikūla": ['ddsa', 'mw'],
    "vipratikṛ": ['mw'],
    "vipratikṛta": ['mw'],
    "vipratikṛṣati": ['bhs'],
    "vipratilambha": ['bhs'],
    "vipratipad": ['ap90', 'mw'],
    "vipratipadya": ['mw'],
    "vipratipadyate": ['bhs'],
    "vipratipanna": ['ap90', 'bhs', 'cae', 'mw'],
    "vipratipannabuddhi": ['mw'],
    "vipratipatti": ['bhs', 'cae', 'mw'],
    "vipratipattiḥ": ['ap90'],
    "vipratipratyanīka": ['mw'],
    "vipratisāra": ['bhs', 'mw'],
    "vipratisāravant": ['bhs'],
    "vipratisāravat": ['mw'],
    "vipratisāraḥ": ['ap90'],
    "vipratisārin": ['bhs', 'mw'],
    "vipratiṣedha": ['cae', 'mw'],
    "vipratiṣedhaḥ": ['ap90'],
    "vipratiṣiddha": ['cae', 'mw'],
    "vipratiṣiddham": ['mw'],
    "vipratva": ['cae', 'ddsa', 'mw'],
    "vipratyanīka": ['bhs', 'mw'],
    "vipratyanīya": ['bhs'],
    "vipratyanīyaka": ['bhs', 'mw'],
    "vipratyaya": ['cae', 'mw'],
    "vipratyayanīya": ['bhs'],
    "vipratā": ['cae', 'ddsa', 'mw'],
    "vipratāpasa": ['cae', 'mw'],
    "vipratāraka": ['mw'],
    "vipratārita": ['mw'],
    "vipratīpa": ['cae', 'ddsa', 'mw'],
    "vipratīsāra": ['mw'],
    "vipratīsāraḥ": ['ap90'],
    "vipravacas": ['gra', 'mw'],
    "vipravad": ['mw'],
    "vipravas": ['ap90', 'mw'],
    "vipravasati": ['bhs'],
    "vipravasita": ['mw'],
    "vipravat": ['cae', 'mw'],
    "vipraveśa": ['bhs'],
    "vipraveśati": ['bhs'],
    "vipraviddha": ['mw'],
    "vipravitti": ['mw'],
    "vipravraj": ['mw'],
    "vipravrājin": ['ddsa'],
    "vipravrājinī": ['mw'],
    "vipravācana": ['mw'],
    "vipravāda": ['mw'],
    "vipravādana": ['bhs'],
    "vipravādayati": ['bhs'],
    "vipravāhas": ['cae', 'gra', 'mw'],
    "vipravāhayati": ['bhs'],
    "vipravāsa": ['bhs', 'cae', 'mw'],
    "vipravāsana": ['cae', 'mw'],
    "vipravāsanaṃ": ['ap90'],
    "vipravāsaḥ": ['ap90'],
    "vipravāsita": ['mw'],
    "vipravāti": ['bhs'],
    "vipravīra": ['cae', 'ddsa', 'gra', 'mw'],
    "viprayoga": ['cae', 'mw'],
    "viprayogaḥ": ['ap90'],
    "viprayogin": ['mw'],
    "viprayojita": ['mw'],
    "viprayuj": ['ap90', 'mw'],
    "viprayukta": ['ap90', 'mw'],
    "viprayāsa": ['bhs'],
    "viprayāta": ['mw'],
    "viprayāṇa": ['mw'],
    "vipraśastaka": ['mw'],
    "vipraśeṣita": ['mw'],
    "vipraśna": ['cae', 'ddsa', 'mw'],
    "vipraśnika": ['cae', 'mw'],
    "vipraśnikā": ['ap90', 'mw'],
    "vipraḥ": ['ap90'],
    "vipraṇaś": ['ap90', 'mw'],
    "vipraṇaṣṭaka": ['bhs'],
    "vipraṇāśa": ['mw'],
    "vipraṇāśayati": ['bhs'],
    "vipraṇī": ['mw'],
    "vipre": ['mw'],
    "viprekṣ": ['mw'],
    "viprekṣaṇa": ['mw'],
    "viprekṣita": ['mw'],
    "viprekṣitṛ": ['mw'],
    "vipreman": ['cae', 'ddsa', 'mw'],
    "viprendra": ['cae', 'ddsa', 'mw'],
    "vipreta": ['mw'],
    "vipriya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vipriyakara": ['mw'],
    "vipriyakārin": ['mw'],
    "vipriyatva": ['mw'],
    "vipriyaṃkara": ['mw'],
    "viproṣita": ['ap90', 'cae', 'mw'],
    "viproṣitabhartṛkā": ['mw'],
    "viproṣitakumāra": ['mw'],
    "viproṣya": ['mw'],
    "vipru": ['mw'],
    "vipruta": ['cae', 'mw'],
    "vipruḍḍhoma": ['mw'],
    "vipruṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "vipruṣa": ['mw'],
    "vipruṣmat": ['mw'],
    "viprā": ['mw'],
    "viprādhipa": ['ddsa', 'mw'],
    "viprādhipamukhā": ['mw'],
    "viprānumadita": ['mw'],
    "viprāpavāda": ['cae', 'mw'],
    "viprāpaṇa": ['mw'],
    "viprāpta": ['mw'],
    "viprāvamanyaka": ['mw'],
    "viprāṣika": ['mw'],
    "vipsā": ['ap90', 'mw'],
    "vipula": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vipulabuddhi": ['bhs', 'mw'],
    "vipulacchāya": ['mw'],
    "vipuladharmādhimuktisaṃbhavateja": ['bhs'],
    "vipuladravya": ['mw'],
    "vipulagrīva": ['mw'],
    "vipulaguṇajyotiḥprabha": ['bhs'],
    "vipulahṛdaya": ['mw'],
    "vipulajaghanā": ['mw'],
    "vipulaka": ['mw'],
    "vipulakīrti": ['bhs'],
    "vipulamahājñānaraśmirāja": ['bhs'],
    "vipulamati": ['bhs', 'mw'],
    "vipulaprajña": ['mw'],
    "vipulapārśva": ['bhs', 'mw'],
    "vipularasa": ['mw'],
    "vipulaskandha": ['mw'],
    "vipulasravā": ['mw'],
    "vipulatara": ['mw'],
    "vipulatarāṃsa": ['bhs'],
    "vipulatta": ['cped'],
    "vipulatva": ['mw'],
    "vipulatā": ['cae', 'cped', 'mw'],
    "vipulaujas": ['mw'],
    "vipulavrata": ['mw'],
    "vipulaya": ['mw'],
    "vipulayaśa": ['bhs'],
    "vipulaśroṇi": ['mw'],
    "vipulaśroṇībhara": ['mw'],
    "vipulekṣaṇa": ['mw'],
    "vipulināmburuha": ['mw'],
    "vipuloja": ['bhs'],
    "vipuloraska": ['mw'],
    "vipulā": ['ap90', 'bhs', 'mw'],
    "vipulādhimuktisaṃbhavatejas": ['bhs'],
    "vipulārthabhogavat": ['mw'],
    "vipulāyatākṣa": ['mw'],
    "vipulāśravā": ['mw'],
    "vipulībhāva": ['mw'],
    "vipulīkṛ": ['mw'],
    "vipura": ['mw'],
    "vipuruṣa": ['mw'],
    "vipurībhū": ['mw'],
    "vipurīṣa": ['mw'],
    "viputh": ['mw'],
    "viputra": ['mw'],
    "vipuṃsaka": ['mw'],
    "vipuṃsī": ['ddsa', 'mw'],
    "vipuṇya": ['bhs'],
    "vipuṣpa": ['cae', 'mw'],
    "vipuṣpayati": ['bhs'],
    "vipuṣṭa": ['ap90', 'cae', 'mw'],
    "vipuṣṭi": ['mw'],
    "vipuṭa": ['mw'],
    "vipā": ['mw'],
    "vipācana": ['bhs'],
    "vipācayati": ['bhs'],
    "vipādana": ['mw'],
    "vipādanaṃ": ['ap90'],
    "vipādanīya": ['mw'],
    "vipādikā": ['ap90', 'mw'],
    "vipādita": ['mw'],
    "vipāditavya": ['mw'],
    "vipādya": ['mw'],
    "vipāka": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vipākadoṣa": ['mw'],
    "vipākadāruṇa": ['mw'],
    "vipākakaṭuka": ['mw'],
    "vipākakāla": ['mw'],
    "vipākana": ['bhs'],
    "vipākatīvra": ['mw'],
    "vipākavisphūrjathu": ['mw'],
    "vipākaśas": ['bhs'],
    "vipākaśruta": ['mw'],
    "vipākaḥ": ['ap90'],
    "vipākin": ['cae', 'mw'],
    "vipākya": ['bhs'],
    "vipāla": ['cae', 'mw'],
    "vipāna": ['cae', 'mw'],
    "vipāpa": ['cae', 'mw'],
    "vipāpman": ['cae', 'mw'],
    "vipāpā": ['mw'],
    "vipārśva": ['mw'],
    "vipāsa": ['bhs'],
    "vipāta": ['mw'],
    "vipātaka": ['mw'],
    "vipātana": ['mw'],
    "vipāś": ['ap90', 'cae', 'gra', 'mw'],
    "vipāśa": ['cae', 'mw'],
    "vipāśana": ['cae', 'mw'],
    "vipāśaya": ['mw'],
    "vipāśin": ['cae', 'mw'],
    "vipāśā": ['mw'],
    "vipāṃsula": ['mw'],
    "vipāṃḍu": ['ap90'],
    "vipāṇḍava": ['mw'],
    "vipāṇḍu": ['cae', 'mw'],
    "vipāṇḍura": ['cae', 'mw'],
    "vipāṇḍutā": ['mw'],
    "vipāṭa": ['cae', 'mw'],
    "vipāṭaka": ['bhs', 'mw'],
    "vipāṭala": ['cae', 'mw'],
    "vipāṭalanetra": ['mw'],
    "vipāṭana": ['mw'],
    "vipāṭanaṃ": ['ap90'],
    "vipāṭchutudrī": ['mw'],
    "vipāṭha": ['cae', 'mw'],
    "vipāṭhaḥ": ['ap90'],
    "vipāṭhā": ['mw'],
    "vipāṭita": ['mw'],
    "vipīta": ['mw'],
    "vipītavat": ['mw'],
    "vipīḍam": ['ddsa', 'mw'],
    "vipū": ['mw'],
    "vipūjana": ['mw'],
    "vipūtika": ['bhs'],
    "vipūya": ['mw'],
    "vipūyaka": ['bhs', 'mw'],
    "vipūyaḥ": ['ap90'],
    "vipṛc": ['gra', 'mw'],
    "vipṛccham": ['cae', 'ddsa', 'mw'],
    "vipṛkta": ['mw'],
    "vipṛkvat": ['gra', 'mw'],
    "vipṛtha": ['mw'],
    "vipṛthu": ['mw'],
    "vipṛṣṭa": ['mw'],
    "vipṛṣṭhībhavati": ['bhs'],
    "vipṛṣṭhībhū": ['mw'],
    "vipṛṣṭhīkaroti": ['bhs'],
    "virac": ['ap90', 'mw'],
    "viracana": ['mw'],
    "viracanaṃ": ['ap90'],
    "viracanā": ['cae'],
    "viracayati": ['cped'],
    "viracayi": ['cped'],
    "viracayitavya": ['mw'],
    "viraci": ['cped'],
    "viracita": ['ap90', 'cped', 'mw'],
    "viracitapada": ['mw'],
    "viracitavapus": ['mw'],
    "viracitavāc": ['mw'],
    "viracitokti": ['mw'],
    "viracitā": ['mw'],
    "virad": ['mw'],
    "virada": ['mw'],
    "viraddha": ['cped'],
    "viraga": ['bhs', 'mw'],
    "virah": ['mw'],
    "viraha": ['cae', 'cped', 'mw'],
    "virahaguṇita": ['mw'],
    "virahaja": ['mw'],
    "virahajanita": ['mw'],
    "virahajvara": ['mw'],
    "virahavirasa": ['mw'],
    "virahavyāpad": ['mw'],
    "virahaśayana": ['mw'],
    "virahaḥ": ['ap90'],
    "virahin": ['ap90', 'cae', 'mw'],
    "virahita": ['ap90', 'cae', 'cped', 'mw'],
    "virahitāt": ['bhs', 'mw'],
    "virahiṇī": ['ap90', 'mw'],
    "virahiṇīmanovinoda": ['mw'],
    "virahotkaṇṭhikā": ['mw'],
    "virahotsuka": ['mw'],
    "virahādhigama": ['mw'],
    "virahānala": ['mw'],
    "virahārta": ['mw'],
    "virahāvasthā": ['mw'],
    "virahīkṛ": ['mw'],
    "viraja": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "virajadhvaja": ['bhs'],
    "virajaloka": ['mw'],
    "virajana": ['mw'],
    "virajaprabha": ['bhs', 'mw'],
    "virajas": ['ap90', 'bhs', 'cae', 'mw'],
    "virajaska": ['cae', 'mw'],
    "virajaskaraṇa": ['mw'],
    "virajaskā": ['ap90'],
    "virajastamas": ['mw'],
    "virajastejaḥsvara": ['bhs', 'mw'],
    "virajastejombarabhūṣaṇa": ['mw'],
    "virajaḥprabha": ['bhs', 'mw'],
    "virajeśvarī": ['mw'],
    "virajjamāna": ['cped'],
    "virajjana": ['cped'],
    "virajjati": ['cped'],
    "virajjhati": ['cped'],
    "virajjhi": ['cped'],
    "virajjhitvā": ['cped'],
    "virajji": ['cped'],
    "virajjitvā": ['cped'],
    "virajomaṇḍala": ['bhs'],
    "virajottarajñānin": ['bhs'],
    "virajovatī": ['bhs'],
    "virajā": ['mw'],
    "virajākṣa": ['mw'],
    "virajākṣetra": ['mw'],
    "virajī": ['mw'],
    "virajībhū": ['ap90', 'mw'],
    "virajībhūta": ['mw'],
    "virajīkṛ": ['ap90', 'mw'],
    "virajīkṛta": ['mw'],
    "virakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "viraktabhāva": ['mw'],
    "viraktacitta": ['mw'],
    "viraktahṛdaya": ['mw'],
    "viraktaprakṛti": ['mw'],
    "virakti": ['cae', 'mw'],
    "viraktimat": ['mw'],
    "viraktiratnāvali": ['mw'],
    "viraktiḥ": ['ap90'],
    "viraktāsarvasva": ['mw'],
    "virakṣ": ['mw'],
    "virakṣas": ['mw'],
    "virakṣastama": ['mw'],
    "virakṣastā": ['mw'],
    "virala": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "viralabhakti": ['mw'],
    "viraladravā": ['mw'],
    "viraladruma": ['mw'],
    "viralajānuka": ['mw'],
    "viralam": ['mw'],
    "viralapārśvaga": ['mw'],
    "viralapātaka": ['mw'],
    "viralasasyayuta": ['mw'],
    "viralatā": ['mw'],
    "viraletara": ['mw'],
    "viralikā": ['bhs', 'mw'],
    "viralita": ['ddsa', 'mw'],
    "viralāgata": ['mw'],
    "viralātapacohavi": ['mw'],
    "viralāy": ['cae'],
    "viralāya": ['mw'],
    "viralāṅguli": ['mw'],
    "viralī": ['bhs'],
    "viralīkṛ": ['mw'],
    "viram": ['ap90', 'mw'],
    "virama": ['cae', 'mw'],
    "viramana": ['cped'],
    "viramanta": ['cped'],
    "viramati": ['cped'],
    "viramaḥ": ['ap90'],
    "viramaṇa": ['mw'],
    "virami": ['cped'],
    "viramita": ['mw'],
    "viramitvā": ['cped'],
    "virapś": ['mw'],
    "virapśa": ['cae', 'gra', 'mw'],
    "virapśin": ['cae', 'gra', 'mw'],
    "viras": ['mw'],
    "virasa": ['ap90', 'cae', 'ddsa', 'mw'],
    "virasam": ['mw'],
    "virasatva": ['mw'],
    "virasānanatva": ['mw'],
    "virasāsyatva": ['mw'],
    "virasībhāva": ['mw'],
    "virasībhū": ['mw'],
    "virasīkṛ": ['mw'],
    "virata": ['ap90', 'cae', 'cped', 'mw'],
    "virataprasaṅga": ['mw'],
    "viratatva": ['mw'],
    "viratha": ['mw'],
    "virathya": ['mw'],
    "virathyā": ['mw'],
    "virathībhū": ['mw'],
    "virathībhūta": ['mw'],
    "virathīkaraṇa": ['mw'],
    "virathīkṛ": ['mw'],
    "virathīkṛta": ['mw'],
    "virati": ['cae', 'cped', 'mw'],
    "viratiḥ": ['ap90'],
    "viratta": ['cped'],
    "viratāśaya": ['mw'],
    "virava": ['cae', 'cped', 'gra', 'mw'],
    "viravana": ['cped'],
    "viravanta": ['cped'],
    "viravati": ['cped'],
    "viravi": ['cped'],
    "viravitvā": ['cped'],
    "virañca": ['mw'],
    "virañcana": ['mw'],
    "virañci": ['mw'],
    "virañcita": ['bhs'],
    "virañcya": ['mw'],
    "virañj": ['mw'],
    "virañjanīya": ['mw'],
    "virañjita": ['mw'],
    "viraśima": ['cae'],
    "viraśmi": ['mw'],
    "viraḍa": ['bhs'],
    "viraṃcaḥ": ['ap90'],
    "viraṃj": ['ap90'],
    "viraṅga": ['mw'],
    "viraṇ": ['mw'],
    "viraṇa": ['gra', 'mw'],
    "viraṇaṃ": ['ap90'],
    "viraṭa": ['mw'],
    "viraṭaḥ": ['ap90'],
    "virebhita": ['mw'],
    "virecaka": ['mw'],
    "virecana": ['mw'],
    "virecanadravya": ['mw'],
    "virecanaṃ": ['ap90'],
    "virecayati": ['bhs'],
    "virecesi": ['cped'],
    "vireceti": ['cped'],
    "virecin": ['mw'],
    "virecita": ['ap90', 'cped', 'mw'],
    "virecya": ['mw'],
    "vireka": ['cped', 'ddsa', 'mw'],
    "virekaḥ": ['ap90'],
    "virepas": ['mw'],
    "virepha": ['mw'],
    "virephas": ['mw'],
    "virephaḥ": ['ap90'],
    "viribdha": ['mw'],
    "viribdhaḥ": ['ap90'],
    "viribhita": ['mw'],
    "viric": ['mw'],
    "viriccamāna": ['cped'],
    "viriccati": ['cped'],
    "virikta": ['cae', 'mw'],
    "virikti": ['mw'],
    "viriphita": ['mw'],
    "viriraṃsā": ['mw'],
    "viritta": ['cped'],
    "viriya": ['bhs', 'cped'],
    "viriyabala": ['cped'],
    "viriyasamatā": ['cped'],
    "viriyavant": ['cped'],
    "viriyindriya": ['cped'],
    "viriyārambha": ['cped'],
    "viriñca": ['cae', 'ddsa', 'mw'],
    "viriñcana": ['mw'],
    "viriñcatā": ['mw'],
    "viriñci": ['cae', 'mw'],
    "viriñcigola": ['mw'],
    "viriñcinātha": ['mw'],
    "viriñcināthīya": ['mw'],
    "viriñcipādaśuddha": ['mw'],
    "viriñcya": ['mw'],
    "viriṃcaḥ": ['ap90'],
    "viriṃciḥ": ['ap90'],
    "viriṣṭa": ['mw'],
    "virocamāna": ['cped'],
    "virocana": ['bhs', 'cae', 'cped', 'mw'],
    "virocanasuta": ['mw'],
    "virocanavadha": ['mw'],
    "virocanaḥ": ['ap90'],
    "virocanā": ['mw'],
    "virocati": ['cped'],
    "virocesi": ['cped'],
    "viroceti": ['cped'],
    "virocetvā": ['cped'],
    "viroci": ['cped'],
    "virocita": ['cped'],
    "virocitvā": ['cped'],
    "virociṣṇu": ['cae', 'mw'],
    "viroddhavya": ['cae', 'mw'],
    "viroddhṛ": ['mw'],
    "virodha": ['cae', 'cped', 'mw'],
    "virodhabhañjanī": ['mw'],
    "virodhabhāj": ['mw'],
    "virodhaka": ['cae', 'mw'],
    "virodhakriyā": ['mw'],
    "virodhakāraka": ['mw'],
    "virodhakṛt": ['cae', 'mw'],
    "virodhana": ['cae', 'cped', 'mw'],
    "virodhanaṃ": ['ap90'],
    "virodhaparihāra": ['mw'],
    "virodhaphala": ['mw'],
    "virodhavarūthinī": ['mw'],
    "virodhavarūthinībhañjinī": ['mw'],
    "virodhavarūthinīnirodha": ['mw'],
    "virodhavat": ['mw'],
    "virodhavāda": ['mw'],
    "virodhaśamana": ['mw'],
    "virodhaḥ": ['ap90'],
    "virodhesi": ['cped'],
    "virodheti": ['cped'],
    "virodhetvā": ['cped'],
    "virodhi": ['mw'],
    "virodhigrantha": ['mw'],
    "virodhin": ['ap90', 'cae', 'mw'],
    "virodhinirodha": ['mw'],
    "virodhinī": ['mw'],
    "virodhipuruṣakāra": ['mw'],
    "virodhita": ['cped', 'mw'],
    "virodhitva": ['mw'],
    "virodhitā": ['cae', 'mw'],
    "virodhivicāra": ['mw'],
    "virodhiyodha": ['mw'],
    "virodhoddhāra": ['mw'],
    "virodhokti": ['cae', 'mw'],
    "virodhopamā": ['cae', 'mw'],
    "virodhya": ['mw'],
    "virodhābhāsa": ['mw'],
    "virodhācarana": ['mw'],
    "virodhālaṃkāra": ['mw'],
    "virodhī": ['mw'],
    "viroga": ['cae', 'mw'],
    "viroha": ['cae', 'mw'],
    "virohaḥ": ['ap90'],
    "virohaṇa": ['cae', 'mw'],
    "virohaṇaṃ": ['ap90'],
    "virohin": ['mw'],
    "virohita": ['mw'],
    "virojana": ['mw'],
    "viroka": ['cae', 'ddsa', 'gra', 'mw'],
    "virokaḥ": ['ap90'],
    "virokin": ['cae', 'gra', 'mw'],
    "virolayati": ['bhs'],
    "virolita": ['mw'],
    "viropaṇa": ['cae', 'mw'],
    "viropaṇaṃ": ['ap90'],
    "viropita": ['mw'],
    "viropitavraṇa": ['mw'],
    "viroṣa": ['mw'],
    "viru": ['ap90', 'mw'],
    "viruc": ['ap90', 'mw'],
    "viruca": ['mw'],
    "virud": ['mw'],
    "viruda": ['mw'],
    "virudadhvaja": ['mw'],
    "virudamaṇimālā": ['mw'],
    "virudaḥ": ['ap90'],
    "viruddha": ['ap90', 'cae', 'cped', 'mw'],
    "viruddhabhojana": ['mw'],
    "viruddhabhuj": ['mw'],
    "viruddhadhī": ['mw'],
    "viruddhagranthapūrvapakṣarahasya": ['mw'],
    "viruddhagrantharahasya": ['mw'],
    "viruddhalakṣaṇa": ['mw'],
    "viruddham": ['mw'],
    "viruddhamatikārin": ['mw'],
    "viruddhamatikāritā": ['mw'],
    "viruddhamatikṛt": ['mw'],
    "viruddhaprasaṅga": ['mw'],
    "viruddhapūrvapakṣagranthaṭīkā": ['mw'],
    "viruddhapūrvapakṣagranthāloka": ['mw'],
    "viruddhasambandhanīya": ['mw'],
    "viruddhasiddhāntagrantharahasya": ['mw'],
    "viruddhasiddhāntagranthaṭīkā": ['mw'],
    "viruddhasiddhāntagranthāloka": ['mw'],
    "viruddhatva": ['mw'],
    "viruddhatā": ['cped', 'mw'],
    "viruddhaśaṃsana": ['mw'],
    "viruddhokti": ['mw'],
    "viruddhopakrama": ['mw'],
    "viruddhopakramatva": ['mw'],
    "viruddhācaraṇa": ['mw'],
    "viruddhānna": ['mw'],
    "viruddhārtha": ['mw'],
    "viruddhārthadīpika": ['mw'],
    "viruddhārthatā": ['mw'],
    "viruddhāśana": ['mw'],
    "virudh": ['ap90', 'mw'],
    "virudita": ['mw'],
    "viruditaṃ": ['ap90'],
    "virudra": ['gra', 'mw'],
    "virudāvali": ['mw'],
    "virugṇa": ['ap90', 'mw'],
    "viruh": ['ap90', 'mw'],
    "viruj": ['mw'],
    "viruja": ['cae', 'mw'],
    "virujjhanta": ['cped'],
    "virujjhati": ['cped'],
    "virujjhi": ['cped'],
    "virujjhitvā": ['cped'],
    "virukmant": ['cae'],
    "virukmat": ['ap90', 'gra', 'mw'],
    "virukta": ['bhs'],
    "virupākṣa": ['bhs'],
    "viruta": ['ap90', 'bhs', 'cae', 'mw'],
    "viruti": ['cae', 'mw'],
    "viruḍhaka": ['bhs'],
    "viruṣ": ['mw'],
    "viruṣṭa": ['cae', 'mw'],
    "virā": ['mw'],
    "virāddha": ['ap90', 'mw'],
    "virāddhṛ": ['cae', 'mw'],
    "virādh": ['ap90', 'mw'],
    "virādha": ['cae', 'mw'],
    "virādhagupta": ['mw'],
    "virādhahan": ['mw'],
    "virādhana": ['cae', 'mw'],
    "virādhanaṃ": ['ap90'],
    "virādhanā": ['cped', 'mw'],
    "virādhaya": ['mw'],
    "virādhaḥ": ['ap90'],
    "virādhesi": ['cped'],
    "virādheti": ['cped'],
    "virādhetvā": ['cped'],
    "virādhita": ['cped'],
    "virādhya": ['mw'],
    "virādhāna": ['mw'],
    "virāga": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "virāgatā": ['cped', 'mw'],
    "virāgavant": ['cae'],
    "virāgavat": ['mw'],
    "virāgaviṣabhṛt": ['mw'],
    "virāgaya": ['mw'],
    "virāgayati": ['bhs'],
    "virāgaḥ": ['ap90'],
    "virāgaṇa": ['bhs'],
    "virāgin": ['cae', 'mw'],
    "virāgita": ['mw'],
    "virāgārha": ['mw'],
    "virāgī": ['cped'],
    "virāj": ['ap90', 'cae', 'gra', 'mw'],
    "virāja": ['ap90', 'cae', 'mw'],
    "virājamāna": ['cped'],
    "virājana": ['mw'],
    "virājati": ['cped'],
    "virājesi": ['cped'],
    "virājeti": ['cped'],
    "virājetvā": ['cped'],
    "virāji": ['cped'],
    "virājin": ['cae', 'mw'],
    "virājita": ['ap90', 'cped', 'mw'],
    "virājya": ['cae', 'mw'],
    "virājñī": ['cae', 'mw'],
    "virāla": ['ap90', 'mw'],
    "virāma": ['cae', 'mw'],
    "virāmaka": ['mw'],
    "virāmatā": ['mw'],
    "virāmaḥ": ['ap90'],
    "virāmaṇa": ['mw'],
    "virātaka": ['mw'],
    "virātra": ['cae', 'mw'],
    "virāva": ['cae', 'cped', 'mw'],
    "virāvaḥ": ['ap90'],
    "virāvaṇa": ['cae', 'mw'],
    "virāvin": ['ap90', 'cae', 'mw'],
    "virāvita": ['mw'],
    "virāviṇī": ['mw'],
    "virāvṛtta": ['mw'],
    "virāḍ": ['mw'],
    "virāḍaṣṭama": ['mw'],
    "virāḍdeha": ['mw'],
    "virāḍrūpā": ['mw'],
    "virāḍvarṇa": ['mw'],
    "virāṇin": ['ap90', 'mw'],
    "virāṣah": ['gra', 'mw'],
    "virāṣāh": ['gra'],
    "virāṭ": ['mw'],
    "virāṭa": ['ap90', 'cae', 'mw'],
    "virāṭaja": ['mw'],
    "virāṭajā": ['mw'],
    "virāṭaka": ['mw'],
    "virāṭakaḥ": ['ap90'],
    "virāṭanagara": ['mw'],
    "virāṭaparvan": ['mw'],
    "virāṭaḥ": ['ap90'],
    "virāṭkrama": ['mw'],
    "virāṭkāmā": ['mw'],
    "virāṭkṣetra": ['mw'],
    "virāṭpūrvā": ['mw'],
    "virāṭsthānā": ['mw'],
    "virāṭsu": ['mw'],
    "virāṭsuta": ['mw'],
    "virāṭsvarāja": ['mw'],
    "virāṭsvarūpa": ['mw'],
    "virāṭtva": ['mw'],
    "virūhana": ['cped'],
    "virūhanta": ['cped'],
    "virūhanā": ['cped'],
    "virūhati": ['cped'],
    "virūhi": ['cped'],
    "virūhitvā": ['cped'],
    "virūja": ['mw'],
    "virūkṣa": ['cae', 'ddsa', 'mw'],
    "virūkṣakodrava": ['mw'],
    "virūkṣaṇa": ['mw'],
    "virūkṣaṇaṃ": ['ap90'],
    "virūkṣaṇīya": ['mw'],
    "virūkṣita": ['mw'],
    "virūpa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "virūpacakṣus": ['mw'],
    "virūpaka": ['ap90', 'cae', 'mw'],
    "virūpakaraṇa": ['mw'],
    "virūpakkha": ['cped'],
    "virūparūpa": ['mw'],
    "virūpatas": ['mw'],
    "virūpatā": ['cped', 'mw'],
    "virūpavat": ['gra'],
    "virūpay": ['cae'],
    "virūpaya": ['ddsa'],
    "virūpaśakti": ['mw'],
    "virūpaśarman": ['mw'],
    "virūpin": ['ap90', 'mw'],
    "virūpā": ['bhs', 'mw'],
    "virūpākṣa": ['bhs', 'cae', 'mw'],
    "virūpākṣapañcākṣarī": ['mw'],
    "virūpākṣapañcāśat": ['mw'],
    "virūpāśva": ['mw'],
    "virūḍha": ['ap90', 'bhs', 'cae', 'mw'],
    "virūḍhabhūmi": ['bhs'],
    "virūḍhabodha": ['mw'],
    "virūḍhaka": ['bhs', 'mw'],
    "virūḍhatṛṇāṅkura": ['mw'],
    "virūḍhi": ['bhs', 'mw'],
    "virūḷha": ['cped'],
    "virūḷhi": ['cped'],
    "vis": ['ap90', 'mw'],
    "visa": ['ap90', 'cped'],
    "visabhāga": ['bhs', 'cped', 'mw'],
    "visabhāgatā": ['mw'],
    "visada": ['bhs', 'cped'],
    "visadabhāva": ['cped'],
    "visadakiriyā": ['cped'],
    "visadatā": ['cped'],
    "visadṛś": ['mw'],
    "visadṛśa": ['ddsa', 'gra', 'mw'],
    "visadṛśaphala": ['mw'],
    "visadṛśaphalatā": ['mw'],
    "visahamāna": ['cped'],
    "visahati": ['cped'],
    "visahi": ['cped'],
    "visakaṇṭaka": ['cped'],
    "visala": ['ap90'],
    "visalla": ['cped'],
    "visalya": ['cae', 'mw'],
    "visalyaka": ['mw'],
    "visama": ['cped'],
    "visama-cakkhula": ['cped'],
    "visambharā": ['mw'],
    "visambhoga": ['mw'],
    "visammūḍha": ['mw'],
    "visamāpti": ['mw'],
    "visandati": ['bhs'],
    "visaparya": ['mw'],
    "visappana": ['cped'],
    "visapīta": ['cped'],
    "visara": ['bhs', 'cae', 'ddsa', 'mw'],
    "visaraḥ": ['ap90'],
    "visaraṇa": ['mw'],
    "visaraṇā": ['bhs'],
    "visarga": ['cae', 'ddsa', 'gra', 'mw'],
    "visargacumbana": ['mw'],
    "visargalupta": ['mw'],
    "visargaḥ": ['ap90'],
    "visargika": ['mw'],
    "visargin": ['mw'],
    "visarjana": ['cae', 'ddsa', 'gra', 'mw'],
    "visarjanaṃ": ['ap90'],
    "visarjanī": ['mw'],
    "visarjanīya": ['ap90', 'cae', 'mw'],
    "visarjayati": ['bhs'],
    "visarjayitar": ['bhs'],
    "visarjayitavya": ['mw'],
    "visarjayitṛ": ['mw'],
    "visarjikā": ['mw'],
    "visarjita": ['ap90', 'mw'],
    "visarjya": ['mw'],
    "visarman": ['cae', 'gra', 'mw'],
    "visarpa": ['cae', 'mw'],
    "visarpacikitsā": ['mw'],
    "visarpaghna": ['mw'],
    "visarpakhinnavigraha": ['mw'],
    "visarpaḥ": ['ap90'],
    "visarpaṇa": ['cae', 'mw'],
    "visarpaṇaṃ": ['ap90'],
    "visarpaṇī": ['mw'],
    "visarpi": ['mw'],
    "visarpikā": ['mw'],
    "visarpin": ['cae', 'mw'],
    "visarpiḥ": ['ap90'],
    "visarpiṇī": ['mw'],
    "visarukkha": ['cped'],
    "visasalla": ['cped'],
    "visata": ['cped'],
    "visatta": ['cped'],
    "visattikā": ['cped'],
    "visaukhya": ['ddsa', 'mw'],
    "visaurabha": ['mw'],
    "visavejja": ['cped'],
    "visaya": ['cped'],
    "visayha": ['cped'],
    "visañña": ['cped'],
    "visaññī": ['cped'],
    "visaṁkhita": ['cped'],
    "visaṁkhāra": ['cped'],
    "visaṁkita": ['cped'],
    "visaṁsaṭṭha": ['cped'],
    "visaṁvāda": ['cped'],
    "visaṁvādaka": ['cped'],
    "visaṁvādana": ['cped'],
    "visaṁvādenta": ['cped'],
    "visaṁvādesi": ['cped'],
    "visaṁvādeti": ['cped'],
    "visaṁvādetvā": ['cped'],
    "visaṁvādita": ['cped'],
    "visaṁyoga": ['cped'],
    "visaṁyutta": ['cped'],
    "visaṃbhavati": ['bhs'],
    "visaṃcārin": ['mw'],
    "visaṃdhi": ['bhs', 'cae', 'mw'],
    "visaṃdhika": ['mw'],
    "visaṃdhiḥ": ['ap90'],
    "visaṃdṛśa": ['cae'],
    "visaṃgata": ['ap90', 'mw'],
    "visaṃhata": ['mw'],
    "visaṃjña": ['ap90', 'cae', 'mw'],
    "visaṃjñin": ['bhs'],
    "visaṃjñita": ['cae', 'mw'],
    "visaṃjñāgati": ['mw'],
    "visaṃjñāvati": ['bhs'],
    "visaṃjñāvatī": ['mw'],
    "visaṃkaṭa": ['ap90', 'mw'],
    "visaṃkula": ['mw'],
    "visaṃnāha": ['cae', 'mw'],
    "visaṃpādayati": ['bhs'],
    "visaṃsarpin": ['mw'],
    "visaṃskāra": ['bhs'],
    "visaṃskṛta": ['bhs'],
    "visaṃsthita": ['bhs', 'mw'],
    "visaṃsthitasaṃcara": ['mw'],
    "visaṃsthula": ['cae', 'mw'],
    "visaṃvad": ['ap90', 'mw'],
    "visaṃvāda": ['cae', 'ddsa', 'mw'],
    "visaṃvādaka": ['mw'],
    "visaṃvādana": ['mw'],
    "visaṃvādanatā": ['bhs'],
    "visaṃvādaḥ": ['ap90'],
    "visaṃvādin": ['ap90', 'cae', 'mw'],
    "visaṃvādita": ['mw'],
    "visaṃvāditā": ['mw'],
    "visaṃyoga": ['bhs', 'mw'],
    "visaṃyogaḥ": ['ap90'],
    "visaṃyojana": ['bhs'],
    "visaṃyojanaka": ['bhs'],
    "visaṃyukta": ['ap90', 'mw'],
    "visaṃyuta": ['bhs'],
    "visaṃśaya": ['ddsa', 'mw'],
    "visaṃśayam": ['mw'],
    "visaṃṣṭhula": ['ap90', 'cae', 'mw'],
    "visaṃṣṭhulagamana": ['mw'],
    "visaṭa": ['cped'],
    "visecaka": ['mw'],
    "visesa": ['cped'],
    "visesabhāgiya": ['cped'],
    "visesagāmī": ['cped'],
    "visesaka": ['cped'],
    "visesana": ['cped'],
    "visesato": ['cped'],
    "viseseti": ['cped'],
    "visesetvā": ['cped'],
    "visesita": ['cped'],
    "visesitabba": ['cped'],
    "visesiya": ['cped'],
    "visesādhigama": ['cped'],
    "visesī": ['cped'],
    "visibbesi": ['cped'],
    "visibbeti": ['cped'],
    "visibbetvā": ['cped'],
    "visic": ['ddsa', 'mw'],
    "visidh": ['mw'],
    "visikhā": ['cped'],
    "visikā": ['bhs'],
    "visila": ['ap90'],
    "visinī": ['ap90'],
    "visira": ['mw'],
    "visismāpayiṣu": ['mw'],
    "visismārayiṣu": ['mw'],
    "visiṭṭha": ['cped'],
    "visiṭṭhatara": ['cped'],
    "viskambh": ['mw'],
    "viskanna": ['mw'],
    "viskanttṛ": ['mw'],
    "viskhal": ['mw'],
    "viskhalita": ['mw'],
    "viskumbhu": ['mw'],
    "vismaraṇa": ['cae', 'mw'],
    "vismaraṇaṃ": ['ap90'],
    "vismaraṇīya": ['mw'],
    "vismartavya": ['mw'],
    "vismarya": ['mw'],
    "vismaya": ['cae', 'ddsa', 'mw'],
    "vismayaharṣamūla": ['mw'],
    "vismayakara": ['mw'],
    "vismayakārin": ['mw'],
    "vismayana": ['mw'],
    "vismayanīya": ['cae', 'mw'],
    "vismayavat": ['mw'],
    "vismayaviṣādavat": ['mw'],
    "vismayaḥ": ['ap90'],
    "vismayaṃgama": ['ap90', 'mw'],
    "vismayaṃkara": ['mw'],
    "vismayin": ['cae', 'mw'],
    "vismayotphullanayana": ['mw'],
    "vismayākula": ['mw'],
    "vismayānvita": ['cae', 'mw'],
    "vismayāviṣṭa": ['mw'],
    "vismera": ['ap90', 'cae', 'mw'],
    "vismi": ['ap90', 'mw'],
    "vismita": ['ap90', 'cae', 'mw'],
    "vismitamānasa": ['mw'],
    "vismiti": ['mw'],
    "vismitiḥ": ['ap90'],
    "vismitānana": ['mw'],
    "vismāpaka": ['cae', 'mw'],
    "vismāpana": ['ap90', 'cae', 'mw'],
    "vismāpanā": ['bhs'],
    "vismāpanīya": ['mw'],
    "vismāpayanīya": ['mw'],
    "vismāpin": ['mw'],
    "vismārita": ['mw'],
    "vismṛ": ['ap90', 'mw'],
    "vismṛta": ['ap90', 'cae', 'mw'],
    "vismṛtapūrvasaṃskāra": ['mw'],
    "vismṛtasaṃskāra": ['mw'],
    "vismṛtavat": ['mw'],
    "vismṛti": ['cae', 'mw'],
    "vismṛtiḥ": ['ap90'],
    "visnapayati": ['bhs'],
    "visodhana": ['cped'],
    "visodhenta": ['cped'],
    "visodhesi": ['cped'],
    "visodheti": ['cped'],
    "visodhetvā": ['cped'],
    "visodhita": ['cped'],
    "visodhiya": ['cped'],
    "visoka": ['cped'],
    "visoma": ['ddsa', 'mw'],
    "visosenta": ['cped'],
    "visosesi": ['cped'],
    "visoseti": ['cped'],
    "visosetvā": ['cped'],
    "visosita": ['cped'],
    "visota": ['bhs'],
    "visoḍha": ['cae', 'mw'],
    "vispand": ['mw'],
    "vispanda": ['mw'],
    "vispandita": ['bhs', 'mw'],
    "vispardh": ['mw'],
    "vispardhin": ['cae'],
    "vispardhā": ['cae', 'mw'],
    "visparśati": ['bhs'],
    "vispaṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vispaṣṭam": ['mw'],
    "vispaṣṭatā": ['mw'],
    "vispaṣṭārtha": ['cae', 'mw'],
    "vispaṣṭī": ['mw'],
    "vispaṣṭīkaraṇa": ['mw'],
    "vispaṣṭīkṛ": ['mw'],
    "visphal": ['mw'],
    "visphar": ['mw'],
    "visphoraka": ['mw'],
    "visphorya": ['mw'],
    "visphoṭa": ['cae', 'mw'],
    "visphoṭaka": ['bhs', 'mw'],
    "visphoṭana": ['mw'],
    "visphoṭaḥ": ['ap90'],
    "visphoṭikā": ['mw'],
    "visphul": ['mw'],
    "visphuliṃgaḥ": ['ap90'],
    "visphuliṅga": ['mw'],
    "visphuliṅgaka": ['mw'],
    "visphuliṅgā": ['mw'],
    "visphur": ['ap90', 'mw'],
    "visphura": ['mw'],
    "visphuraṇa": ['mw'],
    "visphurita": ['ap90', 'mw'],
    "visphuritavya": ['mw'],
    "visphuritaśastra": ['mw'],
    "visphuritekṣaṇa": ['mw'],
    "visphuritādhara": ['mw'],
    "visphurj": ['ap90', 'mw'],
    "visphuṭ": ['mw'],
    "visphuṭa": ['mw'],
    "visphuṭita": ['mw'],
    "visphuṭīkṛta": ['mw'],
    "visphāla": ['mw'],
    "visphāra": ['cae', 'ddsa', 'mw'],
    "visphāraka": ['mw'],
    "visphāraḥ": ['ap90'],
    "visphāraṇa": ['mw'],
    "visphārita": ['ap90', 'cae', 'mw'],
    "visphāy": ['mw'],
    "visphīta": ['mw'],
    "visphūrj": ['mw'],
    "visphūrja": ['cae', 'mw'],
    "visphūrjana": ['mw'],
    "visphūrjathu": ['mw'],
    "visphūrjathuprakhya": ['mw'],
    "visphūrjathuḥ": ['ap90'],
    "visphūrjita": ['bhs', 'mw'],
    "visphūrjitaṃ": ['ap90'],
    "vispṛ": ['mw'],
    "vispṛkka": ['mw'],
    "visra": ['cae', 'ddsa', 'mw'],
    "visrabdha": ['ap90'],
    "visragandha": ['cae', 'mw'],
    "visragandhi": ['mw'],
    "visragandhin": ['cae'],
    "visragandhā": ['mw'],
    "visraka": ['mw'],
    "visrambh": ['mw'],
    "visras": ['gra', 'mw'],
    "visrasas": ['cae'],
    "visrasta": ['ap90', 'cae', 'mw'],
    "visrastabandhana": ['mw'],
    "visrastacetas": ['mw'],
    "visrastahāra": ['mw'],
    "visrastakusumasraj": ['mw'],
    "visrastapauṃsna": ['mw'],
    "visrastasragvibhūṣaṇa": ['mw'],
    "visrastavasana": ['mw'],
    "visrastaśiroruhāmbara": ['mw'],
    "visrastāṅga": ['mw'],
    "visrasya": ['mw'],
    "visrasā": ['ap90', 'mw'],
    "visratva": ['mw'],
    "visratā": ['mw'],
    "visrava": ['cae', 'mw'],
    "visravanmiśra": ['mw'],
    "visravaḥ": ['ap90'],
    "visravaṇa": ['mw'],
    "visraṃ": ['ap90'],
    "visraṃs": ['ap90', 'mw'],
    "visraṃsa": ['ddsa', 'mw'],
    "visraṃsajā": ['mw'],
    "visraṃsana": ['ap90', 'mw'],
    "visraṃsaḥ": ['ap90'],
    "visraṃsikā": ['mw'],
    "visraṃsin": ['mw'],
    "visraṃsita": ['mw'],
    "visraṃsitakeśabandhana": ['mw'],
    "visraṃsitasitāṃśuka": ['mw'],
    "visraṃsraṃsana": ['mw'],
    "visri": ['mw'],
    "visrotas": ['bhs', 'mw'],
    "visru": ['ap90', 'mw'],
    "visruh": ['gra', 'mw'],
    "visruta": ['mw'],
    "visruti": ['cae', 'mw'],
    "visrutiḥ": ['ap90'],
    "visrā": ['mw'],
    "visrāva": ['mw'],
    "visrāvaṇa": ['mw'],
    "visrāvaṇaṃ": ['ap90'],
    "visrāvita": ['mw'],
    "visrāvitavya": ['mw'],
    "visrāvya": ['mw'],
    "visrāvyatā": ['mw'],
    "vissagandha": ['cped'],
    "vissagga": ['cped'],
    "vissajjaka": ['cped'],
    "vissajjana": ['cped'],
    "vissajjanaka": ['cped'],
    "vissajjanīya": ['cped'],
    "vissajjenta": ['cped'],
    "vissajjesi": ['cped'],
    "vissajjeti": ['cped'],
    "vissajjetvā": ['cped'],
    "vissajjitabba": ['cped'],
    "vissajjiya": ['cped'],
    "vissamanta": ['cped'],
    "vissamati": ['cped'],
    "vissamitvā": ['cped'],
    "vissanda": ['cped'],
    "vissandamāna": ['cped'],
    "vissandana": ['cped'],
    "vissandati": ['cped'],
    "vissandi": ['cped'],
    "vissandita": ['cped'],
    "vissanditvā": ['cped'],
    "vissanta": ['cped'],
    "vissara": ['cped'],
    "vissarati": ['cped'],
    "vissari": ['cped'],
    "vissarita": ['cped'],
    "vissaritvā": ['cped'],
    "vissasanta": ['cped'],
    "vissasasi": ['cped'],
    "vissasati": ['cped'],
    "vissasitvā": ['cped'],
    "vissattha": ['cped'],
    "vissaṭṭha": ['cped'],
    "vissaṭṭhi": ['cped'],
    "vissuta": ['cped'],
    "vissāsa": ['cped'],
    "vissāsaka": ['cped'],
    "vissāsanīya": ['cped'],
    "vissāsika": ['cped'],
    "vissāsāsi": ['cped'],
    "vista": ['cae', 'ddsa', 'mw'],
    "vistan": ['mw'],
    "vistara": ['bhs', 'cae', 'ddsa', 'mw'],
    "vistarabhīru": ['mw'],
    "vistarakeṇa": ['mw'],
    "vistaratarakeṇa": ['mw'],
    "vistaratas": ['mw'],
    "vistarati": ['bhs'],
    "vistaratā": ['mw'],
    "vistaraśas": ['mw'],
    "vistaraśaṅkā": ['mw'],
    "vistaraḥ": ['ap90'],
    "vistaraṇī": ['mw'],
    "vistaraṇīya": ['mw'],
    "vistareṇa": ['mw'],
    "vistarā": ['mw'],
    "vistarāt": ['mw'],
    "vistarīṃkaroti": ['bhs'],
    "visthita": ['bhs'],
    "visthā": ['ap90'],
    "visthāna": ['mw'],
    "visthāpayati": ['bhs'],
    "vistāra": ['cae', 'ddsa', 'mw'],
    "vistāraḥ": ['ap90'],
    "vistāraṇa": ['mw'],
    "vistārika": ['bhs'],
    "vistārikā": ['mw'],
    "vistārin": ['cae', 'mw'],
    "vistārita": ['mw'],
    "vistāriṇī": ['mw'],
    "vistīraṇa": ['bhs'],
    "vistīrṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "vistīrṇabheda": ['bhs', 'mw'],
    "vistīrṇajānu": ['mw'],
    "vistīrṇakarṇa": ['mw'],
    "vistīrṇalalāṭā": ['bhs', 'mw'],
    "vistīrṇatva": ['mw'],
    "vistīrṇatā": ['mw'],
    "vistīrṇavatī": ['bhs', 'mw'],
    "vistṛ": ['ap90', 'mw'],
    "vistṛta": ['ap90', 'cae', 'mw'],
    "vistṛtam": ['mw'],
    "vistṛti": ['mw'],
    "vistṛtiḥ": ['ap90'],
    "vistṝ": ['mw'],
    "visubhati": ['bhs'],
    "visuddha": ['cped'],
    "visuddhatta": ['cped'],
    "visuddhatā": ['cped'],
    "visuddhi": ['cped'],
    "visuddhideva": ['cped'],
    "visuddhimagga": ['cped'],
    "visuhṛd": ['mw'],
    "visujjhamāna": ['cped'],
    "visujjhati": ['cped'],
    "visujjhi": ['cped'],
    "visujjhitvā": ['cped'],
    "visukalpa": ['mw'],
    "visukha": ['ddsa', 'mw'],
    "visukṛt": ['mw'],
    "visukṛta": ['mw'],
    "visuta": ['mw'],
    "visuṁ": ['cped'],
    "visuṁkaraṇa": ['cped'],
    "visuṁkatvā": ['cped'],
    "visvan": ['mw'],
    "visvap": ['mw'],
    "visvapna": ['mw'],
    "visvapnaj": ['mw'],
    "visvara": ['ap90', 'cae', 'mw'],
    "visvaram": ['mw'],
    "visvāda": ['mw'],
    "visvāpana": ['bhs'],
    "visyand": ['mw'],
    "visyanda": ['cae'],
    "visyandaka": ['mw'],
    "visyandin": ['mw'],
    "visāda": ['cped'],
    "visākhā": ['cped'],
    "visāla": ['cped'],
    "visālakkhī": ['cped'],
    "visālatta": ['cped'],
    "visālatā": ['cped'],
    "visāmagrī": ['mw'],
    "visāra": ['cae', 'ddsa', 'gra', 'mw'],
    "visārada": ['cped'],
    "visārathi": ['cae', 'mw'],
    "visārathihayadhvaja": ['mw'],
    "visāraḥ": ['ap90'],
    "visārin": ['ap90', 'cae', 'mw'],
    "visārita": ['mw'],
    "visāritā": ['mw'],
    "visāritāṅga": ['mw'],
    "visāriṇī": ['bhs', 'mw'],
    "visārī": ['mw'],
    "visāta": ['bhs'],
    "visāṇa": ['cped'],
    "visāṇamaya": ['cped'],
    "visīdana": ['cped'],
    "visīdati": ['cped'],
    "visīdi": ['cped'],
    "visīvana": ['cped'],
    "visīventa": ['cped'],
    "visīvesi": ['cped'],
    "visīveti": ['cped'],
    "visūcana": ['mw'],
    "visūcikā": ['ap90', 'cped', 'mw'],
    "visūcī": ['mw'],
    "visūka": ['cped'],
    "visūkadassana": ['cped'],
    "visūraṇa": ['cae', 'mw'],
    "visūraṇaṃ": ['ap90'],
    "visūrita": ['mw'],
    "visūritaṃ": ['ap90'],
    "visūritā": ['mw'],
    "visūrya": ['mw'],
    "visūta": ['mw'],
    "visūtr": ['mw'],
    "visūtra": ['ddsa', 'mw'],
    "visūtratā": ['mw'],
    "visūtraṇa": ['mw'],
    "visṛ": ['ap90', 'mw'],
    "visṛj": ['ap90', 'mw'],
    "visṛjya": ['mw'],
    "visṛmara": ['ap90', 'mw'],
    "visṛp": ['ap90', 'mw'],
    "visṛpas": ['cae'],
    "visṛt": ['cae', 'ddsa', 'gra', 'mw'],
    "visṛta": ['ap90', 'bhs', 'cae', 'mw'],
    "visṛtabhūṣaṇa": ['mw'],
    "visṛtaguṇa": ['mw'],
    "visṛtvara": ['ap90', 'cae', 'mw'],
    "visṛṣṭa": ['ap90', 'bhs', 'mw'],
    "visṛṣṭabhūmi": ['mw'],
    "visṛṣṭadhena": ['gra', 'mw'],
    "visṛṣṭarāti": ['gra', 'mw'],
    "visṛṣṭavat": ['mw'],
    "visṛṣṭavāc": ['mw'],
    "visṛṣṭi": ['cae', 'gra', 'mw'],
    "visṛṣṭiḥ": ['ap90'],
    "visṛṣṭātman": ['mw'],
    "vitacchesi": ['cped'],
    "vitaccheti": ['cped'],
    "vitacchikā": ['cped'],
    "vitacchitā": ['cped'],
    "vitadbhāṣaṇa": ['mw'],
    "vitadru": ['mw'],
    "vitadruḥ": ['ap90'],
    "vitakka": ['cped'],
    "vitakkana": ['cped'],
    "vitakkenta": ['cped'],
    "vitakkesi": ['cped'],
    "vitakketi": ['cped'],
    "vitakketvā": ['cped'],
    "vitakkita": ['cped'],
    "vitakṣ": ['mw'],
    "vitala": ['cae', 'mw'],
    "vitalaloka": ['mw'],
    "vitalaṃ": ['ap90'],
    "vitamas": ['ap90', 'cae', 'mw'],
    "vitamaska": ['cae', 'mw'],
    "vitamaskatā": ['mw'],
    "vitan": ['ap90', 'mw'],
    "vitana": ['mw'],
    "vitanati": ['bhs'],
    "vitani": ['cped'],
    "vitanitṛ": ['mw'],
    "vitanoti": ['cped'],
    "vitantasāyia": ['gra'],
    "vitantasāyya": ['gra', 'mw'],
    "vitantrī": ['mw'],
    "vitantu": ['mw'],
    "vitanu": ['ap90', 'cae', 'mw'],
    "vitap": ['ap90', 'mw'],
    "vitapana": ['bhs'],
    "vitara": ['cae', 'mw'],
    "vitaram": ['cae', 'gra', 'mw'],
    "vitarati": ['bhs', 'cped'],
    "vitaraṇa": ['cae', 'cped', 'gra', 'mw'],
    "vitaraṇaṃ": ['ap90'],
    "vitaraṇācārya": ['mw'],
    "vitarddhiḥ": ['ap90'],
    "vitardi": ['cae', 'mw'],
    "vitardikā": ['cae', 'mw'],
    "vitardiḥ": ['ap90'],
    "vitari": ['cped'],
    "vitarita": ['cped'],
    "vitaritṛ": ['mw'],
    "vitark": ['ap90', 'mw'],
    "vitarka": ['cae', 'mw'],
    "vitarkapadavī": ['mw'],
    "vitarkavat": ['mw'],
    "vitarkaḥ": ['ap90'],
    "vitarkaṇa": ['mw'],
    "vitarkaṇaṃ": ['ap90'],
    "vitarkita": ['mw'],
    "vitarkya": ['cae', 'mw'],
    "vitarturam": ['gra', 'mw'],
    "vitarām": ['cae', 'mw'],
    "vitasta": ['mw'],
    "vitastadatta": ['mw'],
    "vitasti": ['cae', 'ddsa', 'mw'],
    "vitastideśya": ['mw'],
    "vitastiḥ": ['ap90'],
    "vitastā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vitastādri": ['mw'],
    "vitastākhya": ['mw'],
    "vitastāmāhātmya": ['mw'],
    "vitastāpurī": ['mw'],
    "vitastātva": ['mw'],
    "vitata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vitatadhanvan": ['mw'],
    "vitatam": ['mw'],
    "vitatatva": ['mw'],
    "vitatavapus": ['mw'],
    "vitatha": ['ap90', 'cae', 'cped', 'mw'],
    "vitathamaryāda": ['mw'],
    "vitathaprayatna": ['mw'],
    "vitathatā": ['mw'],
    "vitathavāc": ['mw'],
    "vitathavādin": ['mw'],
    "vitathaya": ['mw'],
    "vitathayati": ['ap90'],
    "vitathya": ['ap90', 'mw'],
    "vitathābhiniveśa": ['cae', 'mw'],
    "vitathābhiniveśavat": ['mw'],
    "vitathīkṛ": ['mw'],
    "vitati": ['cae', 'mw'],
    "vitatiḥ": ['ap90'],
    "vitatkaraṇa": ['mw'],
    "vitatotsava": ['mw'],
    "vitatya": ['mw'],
    "vitatādhvara": ['mw'],
    "vitatāyudha": ['mw'],
    "vitatī": ['mw'],
    "vitatīkaraṇā": ['mw'],
    "vitatīkṛ": ['mw'],
    "vitaḍ": ['mw'],
    "vitaṃsa": ['mw'],
    "vitaṃsayati": ['bhs'],
    "vitaṃsaḥ": ['ap90'],
    "vitaṃtrī": ['ap90'],
    "vitaṃtuḥ": ['ap90'],
    "vitaṃḍaḥ": ['ap90'],
    "vitaṃḍā": ['ap90'],
    "vitaṇḍa": ['mw'],
    "vitaṇḍaka": ['mw'],
    "vitaṇḍakasmṛti": ['mw'],
    "vitaṇḍana": ['bhs'],
    "vitaṇḍavāda": ['cped'],
    "vitaṇḍavādī": ['cped'],
    "vitaṇḍā": ['ddsa', 'mw'],
    "vitaṇḍātva": ['mw'],
    "vitaṣṭa": ['cae', 'mw'],
    "vith": ['ap90', 'mw'],
    "vithak": ['mw'],
    "vithura": ['cae', 'ddsa', 'gra', 'mw'],
    "vithuraḥ": ['ap90'],
    "vithury": ['cae', 'gra'],
    "vithurya": ['mw'],
    "vithyā": ['mw'],
    "vithāpita": ['bhs'],
    "vithūtistotra": ['mw'],
    "viti": ['mw'],
    "vitilaka": ['mw'],
    "vitimira": ['cae', 'mw'],
    "vitire": ['mw'],
    "vitiṇṇa": ['cped'],
    "vitkoṭikā": ['bhs', 'mw'],
    "vitolā": ['mw'],
    "vitoya": ['cae', 'mw'],
    "vitramantrā": ['bhs'],
    "vitrapa": ['ddsa', 'mw'],
    "vitras": ['ap90', 'mw'],
    "vitrasta": ['mw'],
    "vitrastaka": ['mw'],
    "vitribhalagnaka": ['mw'],
    "vitruḍ": ['mw'],
    "vitrāsa": ['cae', 'mw'],
    "vitrāsana": ['cae', 'mw'],
    "vitrāsayitukāma": ['mw'],
    "vitrāsaḥ": ['ap90'],
    "vitrāsita": ['mw'],
    "vitrāsitavihaṃgama": ['mw'],
    "vitsana": ['mw'],
    "vitsanaḥ": ['ap90'],
    "vitt": ['ap90', 'mw'],
    "vitta": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vittada": ['mw'],
    "vittadha": ['mw'],
    "vittadugdha": ['mw'],
    "vittadā": ['mw'],
    "vittagoptṛ": ['mw'],
    "vittahīna": ['cae', 'mw'],
    "vittaiṣaṇā": ['mw'],
    "vittaja": ['mw'],
    "vittajāni": ['gra', 'mw'],
    "vittaka": ['ddsa', 'mw'],
    "vittakāma": ['cae', 'mw'],
    "vittakāmyā": ['mw'],
    "vittamaya": ['cae', 'mw'],
    "vittamātrā": ['mw'],
    "vittanicaya": ['mw'],
    "vittanātha": ['cae', 'mw'],
    "vittapa": ['cae', 'mw'],
    "vittapapurī": ['cae'],
    "vittapati": ['cae', 'mw'],
    "vittapeṭā": ['mw'],
    "vittapeṭī": ['mw'],
    "vittapurī": ['mw'],
    "vittapāla": ['cae', 'mw'],
    "vittarakṣin": ['mw'],
    "vittarddhi": ['mw'],
    "vittasaṃcaya": ['mw'],
    "vittavant": ['cae'],
    "vittavardhana": ['cae', 'mw'],
    "vittavat": ['ap90', 'mw'],
    "vittavivardhin": ['cae', 'mw'],
    "vittaśāṭhya": ['mw'],
    "vittehā": ['mw'],
    "vitteśa": ['cae', 'ddsa', 'mw'],
    "vitteśapatana": ['mw'],
    "vitteśvara": ['cae', 'mw'],
    "vittha": ['cped'],
    "vitthambhana": ['cped'],
    "vitthambhesi": ['cped'],
    "vitthambheti": ['cped'],
    "vitthambhetvā": ['cped'],
    "vitthambhita": ['cped'],
    "vittharaka": ['bhs'],
    "vitthata": ['cped'],
    "vitthinna": ['cped'],
    "vitthāra": ['cped'],
    "vitthārakathā": ['cped'],
    "vitthārato": ['cped'],
    "vitthārenta": ['cped'],
    "vitthāresi": ['cped'],
    "vitthāreti": ['cped'],
    "vitthāretvā": ['cped'],
    "vitthārika": ['cped'],
    "vitthārita": ['cped'],
    "vitthārīyati": ['cped'],
    "vitthāti": ['cped'],
    "vitti": ['cae', 'cped', 'ddsa', 'mw'],
    "vittiḥ": ['ap90'],
    "vittoka": ['mw'],
    "vittā": ['mw'],
    "vittāgama": ['cae', 'mw'],
    "vittāppati": ['cae', 'mw'],
    "vittāpti": ['mw'],
    "vittārtha": ['mw'],
    "vittāyana": ['mw'],
    "vittāḍhya": ['mw'],
    "vitud": ['mw'],
    "vituda": ['mw'],
    "vitudana": ['cped'],
    "vitudati": ['cped'],
    "vitudi": ['cped'],
    "vitudutvā": ['cped'],
    "vitula": ['mw'],
    "vitunna": ['cped', 'mw'],
    "vitunnaka": ['mw'],
    "vitunnakaṃ": ['ap90'],
    "vitunnaṃ": ['ap90'],
    "vitunnā": ['mw'],
    "viturṇa": ['bhs'],
    "vituṅgabhāga": ['mw'],
    "vituṣa": ['cae', 'mw'],
    "vituṣīkaraṇa": ['mw'],
    "vituṣīkṛ": ['mw'],
    "vituṣṭa": ['ap90', 'mw'],
    "vitvakṣaṇa": ['gra', 'mw'],
    "vityaja": ['mw'],
    "vitāla": ['mw'],
    "vitālī": ['mw'],
    "vitāmasa": ['cae', 'mw'],
    "vitāna": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "vitānaka": ['cae', 'mw'],
    "vitānakalpa": ['mw'],
    "vitānakaḥ": ['ap90'],
    "vitānamūlaka": ['mw'],
    "vitānavant": ['cae'],
    "vitānavat": ['mw'],
    "vitānā": ['mw'],
    "vitānāy": ['cae'],
    "vitānāya": ['mw'],
    "vitānāyate": ['ap90'],
    "vitānī": ['mw'],
    "vitānībhū": ['mw'],
    "vitānībhūta": ['mw'],
    "vitānīkṛ": ['ap90', 'mw'],
    "vitāra": ['cae', 'mw'],
    "vitārin": ['gra', 'mw'],
    "vitīrṇa": ['ap90', 'cae', 'mw'],
    "vitīrṇatara": ['mw'],
    "vitūstaya": ['mw'],
    "vitṛd": ['mw'],
    "vitṛp": ['mw'],
    "vitṛpta": ['mw'],
    "vitṛptaka": ['mw'],
    "vitṛptakāma": ['mw'],
    "vitṛtīya": ['mw'],
    "vitṛṇa": ['cae', 'mw'],
    "vitṛṇṇa": ['mw'],
    "vitṛṣ": ['cae', 'mw'],
    "vitṛṣa": ['cae', 'mw'],
    "vitṛṣṇa": ['ap90', 'cae', 'mw'],
    "vitṛṣṇatva": ['mw'],
    "vitṛṣṇatā": ['mw'],
    "vitṛṣṇā": ['cae', 'mw'],
    "vitṝ": ['ap90', 'mw'],
    "viuṣ": ['gra'],
    "viuṣṭi": ['gra'],
    "viva": ['ddsa', 'mw'],
    "vivac": ['mw'],
    "vivacana": ['cae'],
    "vivacca": ['cped'],
    "vivad": ['ap90', 'mw'],
    "vivadamāna": ['cped'],
    "vivadana": ['cae', 'cped', 'mw'],
    "vivadanta": ['cped'],
    "vivadati": ['cped'],
    "vivadh": ['mw'],
    "vivadha": ['cae', 'mw'],
    "vivadhaḥ": ['ap90'],
    "vivadhika": ['mw'],
    "vivadhikaḥ": ['ap90'],
    "vivadi": ['cped'],
    "vivadita": ['mw'],
    "vivaditavya": ['mw'],
    "vivaditvā": ['cped'],
    "vivadiṣu": ['cae'],
    "vivadiṣṇu": ['mw'],
    "vivaga": ['bhs'],
    "vivah": ['ap90', 'mw'],
    "vivaha": ['mw'],
    "vivahati": ['bhs'],
    "vivahaḥ": ['ap90'],
    "vivajjana": ['cped'],
    "vivajjenta": ['cped'],
    "vivajjesi": ['cped'],
    "vivajjeti": ['cped'],
    "vivajjetvā": ['cped'],
    "vivajjita": ['cped'],
    "vivajjiya": ['cped'],
    "vivaktṛ": ['ddsa', 'mw'],
    "vivaktṛtva": ['mw'],
    "vivakvant": ['cae'],
    "vivakvat": ['gra', 'mw'],
    "vivakṣase": ['gra', 'mw'],
    "vivakṣaṇa": ['cae', 'gra', 'mw'],
    "vivakṣita": ['ap90', 'cae', 'mw'],
    "vivakṣitatva": ['mw'],
    "vivakṣitavya": ['mw'],
    "vivakṣitā": ['mw'],
    "vivakṣu": ['ap90', 'cae', 'mw'],
    "vivakṣā": ['ap90', 'cae', 'mw'],
    "vivakṣārtham": ['mw'],
    "vivakṣāvaśāt": ['mw'],
    "vival": ['mw'],
    "vivala": ['mw'],
    "vivalg": ['mw'],
    "vivalita": ['mw'],
    "vivana": ['bhs'],
    "vivandiṣu": ['mw'],
    "vivandiṣā": ['mw'],
    "vivara": ['bhs', 'cae', 'cped', 'gra', 'mw'],
    "vivaradarśaka": ['mw'],
    "vivaramāna": ['cped'],
    "vivaranta": ['cped'],
    "vivaranālikā": ['mw'],
    "vivarati": ['cped'],
    "vivaraṃ": ['ap90'],
    "vivaraṇa": ['bhs', 'cae', 'cped', 'mw'],
    "vivaraṇabhāvaprakāśikā": ['mw'],
    "vivaraṇacatuḥsūtrī": ['mw'],
    "vivaraṇadarpaṇa": ['mw'],
    "vivaraṇakārikābhāṣya": ['mw'],
    "vivaraṇaprameyasaṃgraha": ['mw'],
    "vivaraṇaprasthāna": ['mw'],
    "vivaraṇaratna": ['mw'],
    "vivaraṇasaṃgraha": ['mw'],
    "vivaraṇasārasaṃgraha": ['mw'],
    "vivaraṇatattvadīpana": ['mw'],
    "vivaraṇavraṇa": ['mw'],
    "vivaraṇaṃ": ['ap90'],
    "vivaraṇopanyāsa": ['mw'],
    "vivarcas": ['cae', 'mw'],
    "vivarcika": ['bhs'],
    "vivardh": ['mw'],
    "vivardhana": ['cae', 'mw'],
    "vivardhanaṃ": ['ap90'],
    "vivardhanīya": ['mw'],
    "vivardhayitar": ['bhs'],
    "vivardhayiṣu": ['mw'],
    "vivardhin": ['cae', 'mw'],
    "vivardhita": ['ap90', 'mw'],
    "vivaresad": ['mw'],
    "vivari": ['cped'],
    "vivarituṁ": ['cped'],
    "vivaritvā": ['cped'],
    "vivariṣu": ['mw'],
    "vivarjaka": ['mw'],
    "vivarjana": ['cae', 'mw'],
    "vivarjanaṃ": ['ap90'],
    "vivarjanā": ['bhs'],
    "vivarjanīya": ['cae', 'mw'],
    "vivarjita": ['ap90', 'cae', 'mw'],
    "vivarmadhvajajīvita": ['mw'],
    "vivarman": ['mw'],
    "vivarmāyudhavāhana": ['mw'],
    "vivarta": ['bhs', 'cae', 'gra', 'mw'],
    "vivartakalpa": ['mw'],
    "vivartana": ['bhs', 'cae', 'gra', 'mw'],
    "vivartananṛtya": ['mw'],
    "vivartanaṃ": ['ap90'],
    "vivartanī": ['bhs'],
    "vivartanīya": ['bhs'],
    "vivartati": ['bhs'],
    "vivartavāda": ['mw'],
    "vivartaḥ": ['ap90'],
    "vivartin": ['cae', 'mw'],
    "vivartita": ['ap90', 'mw'],
    "vivartiya": ['bhs'],
    "vivartman": ['mw'],
    "vivaruṇa": ['mw'],
    "vivarya": ['bhs'],
    "vivarānuga": ['mw'],
    "vivarūtha": ['mw'],
    "vivarṇ": ['mw'],
    "vivarṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "vivarṇabhāva": ['mw'],
    "vivarṇaka": ['bhs'],
    "vivarṇamaṇīkṛta": ['mw'],
    "vivarṇatā": ['mw'],
    "vivarṇavadana": ['cae', 'mw'],
    "vivarṇayati": ['bhs'],
    "vivarṇayitavya": ['mw'],
    "vivarṇita": ['mw'],
    "vivarṣaṇa": ['mw'],
    "vivas": ['ap90', 'mw'],
    "vivasana": ['ap90', 'cae', 'mw'],
    "vivastra": ['cae', 'mw'],
    "vivastratā": ['mw'],
    "vivasvadvāta": ['mw'],
    "vivasvan": ['cae', 'gra', 'mw'],
    "vivasvant": ['cae'],
    "vivasvat": ['ap90', 'gra', 'mw'],
    "vivasvatsmṛti": ['mw'],
    "vivasvatsuta": ['cae', 'mw'],
    "vivasvatī": ['mw'],
    "vivasāna": ['cped'],
    "vivat": ['mw'],
    "vivata": ['bhs'],
    "vivatsa": ['cae', 'mw'],
    "vivatsu": ['cae', 'mw'],
    "vivatsā": ['ap90', 'mw'],
    "vivavri": ['cae', 'gra', 'mw'],
    "vivayana": ['cae', 'mw'],
    "vivañciṣu": ['mw'],
    "vivaśa": ['ap90', 'cae', 'mw'],
    "vivaśatā": ['mw'],
    "vivaśīkṛ": ['mw'],
    "vivaśīkṛta": ['mw'],
    "vivaṃciṣu": ['ap90'],
    "vivaṃśa": ['mw'],
    "vivaṇṇa": ['cped'],
    "vivaṇṇesi": ['cped'],
    "vivaṇṇeti": ['cped'],
    "vivaṇṇetvā": ['cped'],
    "vivaṇṇita": ['cped'],
    "vivaṭa": ['bhs', 'cped'],
    "vivaṭa-nakkhata": ['cped'],
    "vivaṭacchada": ['cped'],
    "vivaṭṭa": ['cped'],
    "vivaṭṭakappa": ['cped'],
    "vivaṭṭana": ['cped'],
    "vivaṭṭati": ['cped'],
    "vivaṭṭesi": ['cped'],
    "vivaṭṭeti": ['cped'],
    "vivaṭṭetvā": ['cped'],
    "vivaṭṭi": ['cped'],
    "vivaṭṭita": ['cped'],
    "vivaṭṭitvā": ['cped'],
    "vive": ['mw'],
    "vivecaka": ['cae', 'mw'],
    "vivecakatva": ['mw'],
    "vivecakatā": ['mw'],
    "vivecana": ['cae', 'cped', 'mw'],
    "vivecanaṃ": ['ap90'],
    "vivecanīkroḍapattra": ['mw'],
    "vivecanīya": ['mw'],
    "vivecayati": ['bhs'],
    "vivecesi": ['cped'],
    "viveceti": ['cped'],
    "vivecetvā": ['cped'],
    "vivecita": ['cped', 'mw'],
    "vivecya": ['mw'],
    "vivedayiṣu": ['mw'],
    "vivedha": ['cped'],
    "vivejita": ['mw'],
    "viveka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vivekabhraṣṭa": ['mw'],
    "vivekabhāj": ['mw'],
    "vivekacandrodaya": ['mw'],
    "vivekacūḍāmaṇi": ['mw'],
    "vivekadhairyāśraya": ['mw'],
    "vivekadīpaka": ['mw'],
    "vivekadṛśvan": ['mw'],
    "vivekadṛśvatva": ['mw'],
    "vivekaja": ['mw'],
    "vivekajña": ['cae', 'mw'],
    "vivekajñāna": ['mw'],
    "vivekakaumudī": ['mw'],
    "vivekakhyāti": ['mw'],
    "vivekamakaranda": ['mw'],
    "vivekamantharatā": ['mw'],
    "vivekamañjarī": ['mw'],
    "vivekamārtaṇḍa": ['mw'],
    "vivekapadavī": ['mw'],
    "vivekaparipanthin": ['mw'],
    "vivekaphala": ['mw'],
    "vivekarahita": ['mw'],
    "vivekasaṃgraha": ['mw'],
    "vivekasindhu": ['mw'],
    "vivekasāra": ['mw'],
    "vivekasārasindhu": ['mw'],
    "vivekasāravarṇana": ['mw'],
    "vivekatilaka": ['mw'],
    "vivekatā": ['mw'],
    "vivekavat": ['mw'],
    "vivekaviguṇa": ['mw'],
    "vivekavilāsa": ['mw'],
    "vivekaviraha": ['mw'],
    "vivekaviśada": ['mw'],
    "vivekaviśrānta": ['cae', 'mw'],
    "vivekaśataka": ['mw'],
    "vivekaśloka": ['mw'],
    "vivekaḥ": ['ap90'],
    "vivekin": ['ap90', 'mw'],
    "vivekitva": ['mw'],
    "vivekitā": ['cae', 'ddsa', 'mw'],
    "vivekodaya": ['mw'],
    "vivektavya": ['mw'],
    "vivektṛ": ['ap90', 'cae', 'mw'],
    "vivektṛtva": ['mw'],
    "vivekāmṛta": ['mw'],
    "vivekārtham": ['mw'],
    "vivekārṇava": ['mw'],
    "vivekāñjana": ['mw'],
    "vivekāśrama": ['mw'],
    "vivell": ['mw'],
    "viven": ['mw'],
    "vivena": ['gra', 'mw'],
    "vivesatā": ['cped'],
    "vivesesi": ['cped'],
    "vivevidat": ['mw'],
    "viveṣṭ": ['mw'],
    "viveṣṭati": ['bhs'],
    "viveṣṭita": ['mw'],
    "vivibhaktika": ['mw'],
    "vivibhaktikatva": ['mw'],
    "vivic": ['ap90', 'mw'],
    "vivici": ['gra', 'mw'],
    "vivicīṣṭi": ['mw'],
    "vivid": ['mw'],
    "vividha": ['ap90', 'cae', 'mw'],
    "vividhabhaṅgīka": ['mw'],
    "vividhacitra": ['mw'],
    "vividham": ['mw'],
    "vividharūpadhṛt": ['mw'],
    "vividhavidhiprayogasaṃgraha": ['mw'],
    "vividhaśāstragoṣṭhī": ['mw'],
    "vividhopalabhūṣita": ['mw'],
    "vividhopeta": ['mw'],
    "vividhāgama": ['cae', 'mw'],
    "vividhātman": ['mw'],
    "vividhāyudha": ['cae'],
    "vividivas": ['mw'],
    "vividiṣu": ['mw'],
    "vividiṣā": ['mw'],
    "vividvas": ['mw'],
    "vividyut": ['mw'],
    "vivigna": ['ap90', 'cae', 'mw'],
    "vivihan": ['mw'],
    "vivikta": ['ap90', 'cae', 'ddsa', 'mw'],
    "viviktabhāva": ['mw'],
    "viviktacarita": ['mw'],
    "viviktacetas": ['mw'],
    "viviktadṛṣṭi": ['mw'],
    "viviktaga": ['mw'],
    "viviktanāman": ['mw'],
    "viviktasevin": ['cae', 'mw'],
    "viviktatarka": ['mw'],
    "viviktatva": ['mw'],
    "viviktatā": ['mw'],
    "viviktavarṇa": ['mw'],
    "viviktaśaraṇa": ['mw'],
    "vivikti": ['cae', 'mw'],
    "viviktāsana": ['cae', 'mw'],
    "viviktīkṛta": ['mw'],
    "vivikvas": ['mw'],
    "vivikṣ": ['mw'],
    "vivikṣu": ['cae', 'mw'],
    "vivindhya": ['mw'],
    "vivip": ['mw'],
    "vivipāta": ['bhs'],
    "vivitsu": ['mw'],
    "vivitsā": ['mw'],
    "vivitta": ['cped'],
    "vivitti": ['mw'],
    "vivittā": ['cped'],
    "vivivadha": ['mw'],
    "viviś": ['mw'],
    "viviśa": ['mw'],
    "viviṃśa": ['mw'],
    "viviṃśati": ['mw'],
    "viviṣā": ['mw'],
    "viviṣṭi": ['mw'],
    "vivoḍhṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "vivrata": ['cae', 'ddsa', 'gra', 'mw'],
    "vivraśc": ['mw'],
    "vivvoka": ['ap90', 'mw'],
    "vivyadh": ['mw'],
    "vivyathita": ['mw'],
    "vivyādhin": ['mw'],
    "vivā": ['mw'],
    "vivāc": ['cae', 'gra', 'mw'],
    "vivācana": ['cae', 'gra', 'mw'],
    "vivācas": ['mw'],
    "vivācayati": ['bhs'],
    "vivācya": ['mw'],
    "vivāda": ['cae', 'cped', 'mw'],
    "vivādabhaṅgārṇava": ['mw'],
    "vivādabhīru": ['mw'],
    "vivādacandra": ['mw'],
    "vivādacandrikā": ['mw'],
    "vivādacintāmaṇi": ['mw'],
    "vivādaka": ['bhs', 'cped'],
    "vivādakalpataru": ['mw'],
    "vivādakaumudī": ['mw'],
    "vivādanirṇaya": ['mw'],
    "vivādapada": ['cae', 'mw'],
    "vivādapariccheda": ['mw'],
    "vivādaratnākara": ['mw'],
    "vivādasaukhya": ['mw'],
    "vivādasaṃvādabhū": ['mw'],
    "vivādasetu": ['mw'],
    "vivādasindhu": ['mw'],
    "vivādasārārṇava": ['mw'],
    "vivādatattvadīpa": ['mw'],
    "vivādatāṇḍava": ['mw'],
    "vivādavāridhi": ['mw'],
    "vivādayati": ['bhs'],
    "vivādaśamana": ['mw'],
    "vivādaḥ": ['ap90'],
    "vivādikasaṃjñā": ['bhs'],
    "vivādin": ['ap90', 'cae', 'mw'],
    "vivādādhyāsita": ['mw'],
    "vivādānavasara": ['mw'],
    "vivādānugata": ['mw'],
    "vivādārthin": ['cae', 'mw'],
    "vivādārṇavabhañjana": ['mw'],
    "vivādārṇavabhaṅga": ['mw'],
    "vivādārṇavasetu": ['mw'],
    "vivādāspada": ['mw'],
    "vivādāspadībhūta": ['mw'],
    "vivādī": ['cped'],
    "vivāha": ['bhs', 'cae', 'cped', 'mw'],
    "vivāhabhūṣaṇa": ['mw'],
    "vivāhacaturthika": ['mw'],
    "vivāhacaturthīkarman": ['mw'],
    "vivāhacatuṣṭaya": ['mw'],
    "vivāhadvirāgamanapaddhati": ['mw'],
    "vivāhadīkṣā": ['mw'],
    "vivāhadīkṣātilaka": ['mw'],
    "vivāhadīkṣāvidhi": ['mw'],
    "vivāhagṛha": ['mw'],
    "vivāhahoma": ['mw'],
    "vivāhahomavidhi": ['mw'],
    "vivāhahomopayuktāmantra": ['mw'],
    "vivāhakarman": ['mw'],
    "vivāhakarmapaddhati": ['mw'],
    "vivāhakāla": ['mw'],
    "vivāhakāma": ['mw'],
    "vivāhakārikā": ['mw'],
    "vivāhamaṅgala": ['cped'],
    "vivāhamelavāṇīvidhi": ['mw'],
    "vivāhanepathya": ['cae', 'mw'],
    "vivāhanīyā": ['mw'],
    "vivāhapaddhati": ['mw'],
    "vivāhapaṭaha": ['cae', 'mw'],
    "vivāhapaṭala": ['mw'],
    "vivāhaprakaraṇa": ['mw'],
    "vivāhaprakaraṇaṭīkā": ['mw'],
    "vivāhaprayoga": ['mw'],
    "vivāharatna": ['mw'],
    "vivāhasamaya": ['mw'],
    "vivāhasambandha": ['mw'],
    "vivāhasaukhya": ['mw'],
    "vivāhasiddhāntarahasya": ['mw'],
    "vivāhasthāna": ['mw'],
    "vivāhatattva": ['mw'],
    "vivāhatattvadīpikā": ['mw'],
    "vivāhaveṣa": ['cae', 'mw'],
    "vivāhavidhi": ['mw'],
    "vivāhavṛndāvana": ['mw'],
    "vivāhayajña": ['mw'],
    "vivāhayitavya": ['mw'],
    "vivāhaḥ": ['ap90'],
    "vivāhecchu": ['mw'],
    "vivāhin": ['mw'],
    "vivāhita": ['ap90', 'mw'],
    "vivāhotsava": ['mw'],
    "vivāhya": ['cae', 'mw'],
    "vivāhyaḥ": ['ap90'],
    "vivāhādikarmaṇāmprayoga": ['mw'],
    "vivāhāgni": ['mw'],
    "vivāhārtha": ['mw'],
    "vivāka": ['cae', 'ddsa', 'mw'],
    "vivākaḥ": ['ap90'],
    "vivākya": ['mw'],
    "vivālayiṣu": ['mw'],
    "vivāna": ['mw'],
    "vivāra": ['mw'],
    "vivārayiṣu": ['mw'],
    "vivāraḥ": ['ap90'],
    "vivārin": ['mw'],
    "vivās": ['cae', 'gra'],
    "vivāsa": ['cae', 'mw'],
    "vivāsakaraṇa": ['mw'],
    "vivāsakāle": ['mw'],
    "vivāsana": ['cae', 'mw'],
    "vivāsanavat": ['mw'],
    "vivāsas": ['cae', 'mw'],
    "vivāsayitṛ": ['mw'],
    "vivāsaḥ": ['ap90'],
    "vivāsita": ['ap90', 'mw'],
    "vivāsya": ['cae', 'mw'],
    "vivāta": ['mw'],
    "vivāśa": ['mw'],
    "vivīta": ['ddsa', 'mw'],
    "vivītabhartṛ": ['mw'],
    "vivītaḥ": ['ap90'],
    "vivīvadha": ['mw'],
    "vivīvetvā": ['cped'],
    "vivṛ": ['ap90', 'mw'],
    "vivṛddha": ['ap90', 'cae', 'mw'],
    "vivṛddhamatsara": ['mw'],
    "vivṛddhi": ['cae', 'mw'],
    "vivṛddhibhāj": ['mw'],
    "vivṛddhida": ['cae', 'mw'],
    "vivṛddhikara": ['mw'],
    "vivṛddhiḥ": ['ap90'],
    "vivṛdh": ['ap90', 'mw'],
    "vivṛdhat": ['mw'],
    "vivṛh": ['mw'],
    "vivṛha": ['mw'],
    "vivṛhat": ['mw'],
    "vivṛj": ['ap90', 'mw'],
    "vivṛkta": ['ap90', 'mw'],
    "vivṛktā": ['mw'],
    "vivṛkṇa": ['mw'],
    "vivṛt": ['ap90', 'mw'],
    "vivṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "vivṛtabhāva": ['cae', 'mw'],
    "vivṛtadvāra": ['mw'],
    "vivṛtam": ['mw'],
    "vivṛtapauruṣa": ['cae', 'mw'],
    "vivṛtasmayana": ['mw'],
    "vivṛtasnāna": ['mw'],
    "vivṛtatā": ['mw'],
    "vivṛtavat": ['mw'],
    "vivṛti": ['cae', 'mw'],
    "vivṛtivimarśinī": ['mw'],
    "vivṛtiḥ": ['ap90'],
    "vivṛtokti": ['mw'],
    "vivṛtsitṛ": ['mw'],
    "vivṛtta": ['ap90', 'cae', 'mw'],
    "vivṛttadaṃṣṭra": ['mw'],
    "vivṛttavadana": ['mw'],
    "vivṛtti": ['cae', 'mw'],
    "vivṛttipūrva": ['mw'],
    "vivṛttiḥ": ['ap90'],
    "vivṛttyabhiprāya": ['mw'],
    "vivṛttā": ['mw'],
    "vivṛttākṣa": ['cae', 'mw'],
    "vivṛttāsya": ['mw'],
    "vivṛttāṅga": ['cae', 'mw'],
    "vivṛtā": ['bhs', 'mw'],
    "vivṛtākṣa": ['mw'],
    "vivṛtānana": ['mw'],
    "vivṛtānanatva": ['mw'],
    "vivṛtāsya": ['mw'],
    "vivṛṇ": ['mw'],
    "vivṛṣ": ['mw'],
    "viya": ['bhs', 'cped'],
    "viyac": ['mw'],
    "viyaccara": ['mw'],
    "viyaccārin": ['mw'],
    "viyad": ['mw'],
    "viyadbhūti": ['mw'],
    "viyadgata": ['mw'],
    "viyadgati": ['mw'],
    "viyadgaṅgā": ['mw'],
    "viyadvyāpin": ['mw'],
    "viyam": ['ap90', 'mw'],
    "viyama": ['mw'],
    "viyamaḥ": ['ap90'],
    "viyan": ['mw'],
    "viyanmadhyahaṃsa": ['mw'],
    "viyanmaya": ['mw'],
    "viyanmaṇi": ['mw'],
    "viyant": ['cae'],
    "viyantṛ": ['mw'],
    "viyat": ['ap90', 'ddsa', 'mw'],
    "viyata": ['cae', 'mw'],
    "viyatam": ['mw'],
    "viyati": ['mw'],
    "viyatiḥ": ['ap90'],
    "viyatpatha": ['mw'],
    "viyatpatākā": ['mw'],
    "viyatstha": ['mw'],
    "viyatta": ['cped'],
    "viyava": ['mw'],
    "viyaṅga": ['mw'],
    "viyodha": ['mw'],
    "viyoga": ['cae', 'cped', 'ddsa', 'mw'],
    "viyogabhāj": ['mw'],
    "viyogabāhya": ['mw'],
    "viyogapura": ['mw'],
    "viyogatas": ['mw'],
    "viyogatā": ['mw'],
    "viyogavant": ['cae'],
    "viyogaḥ": ['ap90'],
    "viyogin": ['ap90', 'cae', 'mw'],
    "viyoginī": ['ap90', 'mw'],
    "viyogitā": ['cae', 'mw'],
    "viyogāvaha": ['mw'],
    "viyogāvasāna": ['mw'],
    "viyogāvasānatva": ['mw'],
    "viyogāya": ['mw'],
    "viyogīkaraṇa": ['mw'],
    "viyojana": ['cae', 'mw'],
    "viyojanīya": ['cae', 'mw'],
    "viyojita": ['ap90', 'mw'],
    "viyojya": ['cae', 'mw'],
    "viyoni": ['cae', 'mw'],
    "viyonija": ['mw'],
    "viyonijanman": ['mw'],
    "viyonijanmādhyāya": ['mw'],
    "viyoniḥ": ['ap90'],
    "viyonī": ['cae'],
    "viyotṛ": ['gra', 'mw'],
    "viyu": ['ap90', 'mw'],
    "viyugala": ['mw'],
    "viyuj": ['ap90', 'mw'],
    "viyukta": ['ap90', 'cae', 'mw'],
    "viyuktatā": ['mw'],
    "viyuta": ['ap90', 'cae', 'mw'],
    "viyuti": ['mw'],
    "viyutā": ['mw'],
    "viyutārthaka": ['mw'],
    "viyā": ['mw'],
    "viyākaroti": ['bhs'],
    "viyākaṁsu": ['cped'],
    "viyāma": ['ap90', 'mw'],
    "viyāsa": ['mw'],
    "viyāta": ['ap90', 'mw'],
    "viyātatā": ['ddsa', 'mw'],
    "viyātiman": ['mw'],
    "viyāṅga": ['mw'],
    "viyūbha": ['bhs'],
    "viyūha": ['bhs'],
    "viyūhana": ['bhs', 'cped'],
    "viyūhati": ['bhs', 'cped'],
    "viyūhi": ['cped'],
    "viyūhita": ['cped'],
    "viyūhitvā": ['cped'],
    "viyūhā": ['bhs'],
    "viyūtha": ['mw'],
    "viyūḷha": ['cped'],
    "viyūṣka": ['mw'],
    "viñilavindu": ['mw'],
    "viñjamara": ['mw'],
    "viñjolī": ['mw'],
    "viñjāmara": ['mw'],
    "viññatta": ['cped'],
    "viññatti": ['cped'],
    "viññeyya": ['cped'],
    "viññuppasattha": ['cped'],
    "viññutā": ['cped'],
    "viññāpaka": ['cped'],
    "viññāpana": ['cped'],
    "viññāpaya": ['cped'],
    "viññāpenta": ['cped'],
    "viññāpesi": ['cped'],
    "viññāpetar": ['cped'],
    "viññāpeti": ['cped'],
    "viññāpetvā": ['cped'],
    "viññāpita": ['cped'],
    "viññāta": ['cped'],
    "viññātabba": ['cped'],
    "viññātar": ['cped'],
    "viññāya": ['cped'],
    "viññāyati": ['cped'],
    "viññāyi": ['cped'],
    "viññāṇa": ['cped'],
    "viññāṇadhātu": ['cped'],
    "viññāṇaka": ['cped'],
    "viññāṇakkhandha": ['cped'],
    "viññāṇaṭṭhiti": ['cped'],
    "viññū": ['cped'],
    "viānaśi": ['gra'],
    "viś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "viśa": ['ddsa', 'mw'],
    "viśabda": ['mw'],
    "viśabdana": ['mw'],
    "viśabdita": ['mw'],
    "viśada": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "viśadam": ['mw'],
    "viśadanarakaraṅkāya": ['mw'],
    "viśadaprabha": ['mw'],
    "viśadaprajña": ['mw'],
    "viśadatā": ['mw'],
    "viśaday": ['cae'],
    "viśadaya": ['mw'],
    "viśadita": ['mw'],
    "viśadānana": ['mw'],
    "viśadātman": ['mw'],
    "viśadāya": ['mw'],
    "viśadīkṛ": ['cae', 'mw'],
    "viśakala": ['mw'],
    "viśakalita": ['mw'],
    "viśala": ['mw'],
    "viśalabhamarut": ['mw'],
    "viśalya": ['ap90', 'cae', 'mw'],
    "viśalyaghna": ['mw'],
    "viśalyakaraṇa": ['cae', 'mw'],
    "viśalyakaraṇī": ['mw'],
    "viśalyakṛt": ['mw'],
    "viśalyaprāṇahara": ['mw'],
    "viśalyasambhava": ['mw'],
    "viśalyaya": ['mw'],
    "viśalyā": ['mw'],
    "viśalyāsaṃgama": ['mw'],
    "viśalyīkṛta": ['bhs'],
    "viśalā": ['mw'],
    "viśam": ['mw'],
    "viśambhala": ['mw'],
    "viśampa": ['mw'],
    "viśana": ['cae', 'mw'],
    "viśapha": ['mw'],
    "viśapta": ['mw'],
    "viśara": ['cae', 'mw'],
    "viśarada": ['mw'],
    "viśaraḥ": ['ap90'],
    "viśaraṇa": ['mw'],
    "viśardhita": ['mw'],
    "viśarāru": ['cae', 'mw'],
    "viśarārutā": ['mw'],
    "viśarīka": ['cae', 'mw'],
    "viśas": ['ap90', 'mw'],
    "viśasana": ['cae', 'gra', 'mw'],
    "viśasanaṃ": ['ap90'],
    "viśasi": ['mw'],
    "viśasita": ['mw'],
    "viśasitṛ": ['cae', 'mw'],
    "viśasta": ['ap90', 'mw'],
    "viśasti": ['mw'],
    "viśastra": ['ap90', 'cae', 'mw'],
    "viśastratva": ['mw'],
    "viśastṛ": ['ap90', 'cae', 'gra', 'mw'],
    "viśaujas": ['mw'],
    "viśaya": ['cae', 'ddsa', 'mw'],
    "viśayavat": ['mw'],
    "viśayaḥ": ['ap90'],
    "viśayin": ['mw'],
    "viśayitva": ['mw'],
    "viśaṃ": ['ap90'],
    "viśaṃk": ['ap90'],
    "viśaṃka": ['ap90'],
    "viśaṃkaṭa": ['ap90'],
    "viśaṃs": ['mw'],
    "viśaṅk": ['mw'],
    "viśaṅka": ['cae', 'ddsa', 'mw'],
    "viśaṅkam": ['mw'],
    "viśaṅkanīya": ['mw'],
    "viśaṅkayā": ['mw'],
    "viśaṅkaṭa": ['cae', 'ddsa', 'mw'],
    "viśaṅkaṭam": ['mw'],
    "viśaṅkin": ['cae', 'mw'],
    "viśaṅkita": ['cae', 'mw'],
    "viśaṅkya": ['cae', 'mw'],
    "viśaṅkā": ['cae', 'mw'],
    "viścakadra": ['mw'],
    "viścakadraḥ": ['ap90'],
    "viścakadrākarṣa": ['mw'],
    "viśeṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "viśeṣabhāga": ['mw'],
    "viśeṣabhāvanā": ['mw'],
    "viśeṣabhūtapariśiṣṭa": ['mw'],
    "viśeṣadharma": ['mw'],
    "viśeṣadṛśya": ['mw'],
    "viśeṣagamana": ['bhs'],
    "viśeṣagarhaṇīya": ['mw'],
    "viśeṣaguṇa": ['mw'],
    "viśeṣagāmin": ['bhs'],
    "viśeṣagāmitā": ['bhs'],
    "viśeṣajña": ['cae', 'mw'],
    "viśeṣajñānavādārtha": ['mw'],
    "viśeṣaka": ['ap90', 'cae', 'mw'],
    "viśeṣakacchedya": ['mw'],
    "viśeṣakaraṇa": ['cae', 'mw'],
    "viśeṣakṛt": ['mw'],
    "viśeṣalakṣaṇa": ['mw'],
    "viśeṣalakṣaṇāṭīkā": ['mw'],
    "viśeṣaliṅga": ['mw'],
    "viśeṣamati": ['bhs', 'mw'],
    "viśeṣamaṇḍana": ['cae', 'mw'],
    "viśeṣamitra": ['bhs', 'mw'],
    "viśeṣanirukti": ['mw'],
    "viśeṣaniruktikroḍa": ['mw'],
    "viśeṣaniruktiprakāśa": ['mw'],
    "viśeṣaniruktiṭīkā": ['mw'],
    "viśeṣaniruktyāloka": ['mw'],
    "viśeṣaniyama": ['mw'],
    "viśeṣapadārtha": ['mw'],
    "viśeṣapatanīya": ['mw'],
    "viśeṣapramāṇa": ['mw'],
    "viśeṣapratipatti": ['mw'],
    "viśeṣapratiṣedha": ['mw'],
    "viśeṣaramaṇīya": ['mw'],
    "viśeṣastha": ['mw'],
    "viśeṣatas": ['ap90', 'cae', 'ddsa', 'mw'],
    "viśeṣatva": ['mw'],
    "viśeṣavacana": ['mw'],
    "viśeṣavant": ['cae'],
    "viśeṣavat": ['mw'],
    "viśeṣavid": ['cae', 'mw'],
    "viśeṣavidhi": ['mw'],
    "viśeṣavidvas": ['mw'],
    "viśeṣavikramaruci": ['mw'],
    "viśeṣavyāpti": ['mw'],
    "viśeṣavyāptirahasya": ['mw'],
    "viśeṣavāda": ['mw'],
    "viśeṣavādaṭīkā": ['mw'],
    "viśeṣavādin": ['mw'],
    "viśeṣay": ['cae'],
    "viśeṣayati": ['bhs'],
    "viśeṣaśālin": ['mw'],
    "viśeṣaśārṅgadhara": ['mw'],
    "viśeṣaśāstra": ['mw'],
    "viśeṣaṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "viśeṣaṇadvayavaiyarthya": ['mw'],
    "viśeṣaṇajñānavādārtha": ['mw'],
    "viśeṣaṇakhaṇḍana": ['mw'],
    "viśeṣaṇamātraprayoga": ['mw'],
    "viśeṣaṇapada": ['mw'],
    "viśeṣaṇatrayavaiyarthya": ['mw'],
    "viśeṣaṇatva": ['mw'],
    "viśeṣaṇatā": ['mw'],
    "viśeṣaṇatāsambandha": ['mw'],
    "viśeṣaṇavarga": ['mw'],
    "viśeṣaṇavat": ['mw'],
    "viśeṣaṇaviśeṣyabhāva": ['mw'],
    "viśeṣaṇaviśeṣyatā": ['mw'],
    "viśeṣaṇaśeṣaṇīya": ['mw'],
    "viśeṣaṇīkṛ": ['mw'],
    "viśeṣena": ['mw'],
    "viśeṣikā": ['mw'],
    "viśeṣin": ['cae', 'mw'],
    "viśeṣita": ['ap90', 'mw'],
    "viśeṣocchvasita": ['mw'],
    "viśeṣoddeśa": ['mw'],
    "viśeṣodgata": ['bhs'],
    "viśeṣokti": ['mw'],
    "viśeṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "viśeṣyaka": ['mw'],
    "viśeṣyatva": ['mw'],
    "viśeṣyatā": ['mw'],
    "viśeṣyatāvāda": ['mw'],
    "viśeṣādhigama": ['bhs'],
    "viśeṣāmṛta": ['mw'],
    "viśeṣārtha": ['mw'],
    "viśeṣārthabodhikā": ['mw'],
    "viśeṣārtham": ['mw'],
    "viśeṣārthaprakāśikā": ['mw'],
    "viśeṣārthin": ['mw'],
    "viśeṣārthitā": ['mw'],
    "viśeṣāt": ['mw'],
    "viśeṣātideśa": ['mw'],
    "viśeṣāvasyakaniryukti": ['mw'],
    "viśia": ['gra'],
    "viśikha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "viśikhaśreṇī": ['mw'],
    "viśikhin": ['bhs'],
    "viśikhā": ['ap90', 'mw'],
    "viśikhāntara": ['mw'],
    "viśikhānupraveśana": ['mw'],
    "viśikhānupraveśanīya": ['mw'],
    "viśikhāvalī": ['mw'],
    "viśikhāśraya": ['mw'],
    "viśikā": ['mw'],
    "viśikṣ": ['mw'],
    "viśikṣu": ['cae', 'gra', 'mw'],
    "viśipa": ['mw'],
    "viśipaṃ": ['ap90'],
    "viśipriya": ['mw'],
    "viśira": ['mw'],
    "viśiras": ['cae', 'mw'],
    "viśiraska": ['mw'],
    "viśis": ['cae', 'mw'],
    "viśita": ['ap90', 'mw'],
    "viśiñj": ['mw'],
    "viśiśipra": ['gra', 'mw'],
    "viśiśnyā": ['mw'],
    "viśiśnā": ['mw'],
    "viśiśramiṣu": ['mw'],
    "viśiśāsiṣat": ['mw'],
    "viśiśāsiṣu": ['cae', 'mw'],
    "viśiṣ": ['ap90', 'mw'],
    "viśiṣya": ['mw'],
    "viśiṣṭa": ['ap90', 'bhs', 'cae', 'mw'],
    "viśiṣṭabuddhi": ['mw'],
    "viśiṣṭacandra": ['bhs'],
    "viśiṣṭacārin": ['mw'],
    "viśiṣṭacāritra": ['bhs', 'mw'],
    "viśiṣṭakula": ['mw'],
    "viśiṣṭaliṅga": ['mw'],
    "viśiṣṭatama": ['mw'],
    "viśiṣṭatara": ['mw'],
    "viśiṣṭatva": ['mw'],
    "viśiṣṭatā": ['ap90', 'mw'],
    "viśiṣṭavaiśiṣṭya": ['mw'],
    "viśiṣṭavaiśiṣṭyabodha": ['mw'],
    "viśiṣṭavaiśiṣṭyabodharahasya": ['mw'],
    "viśiṣṭavaiśiṣṭyabodhavicāra": ['mw'],
    "viśiṣṭavaiśiṣṭyabodhavicārarahasya": ['mw'],
    "viśiṣṭavaiśiṣṭyajñānavādārtha": ['mw'],
    "viśiṣṭavaiśiṣṭyāvagāhivādārtha": ['mw'],
    "viśiṣṭavarṇa": ['cae', 'mw'],
    "viśiṣṭayukta": ['mw'],
    "viśiṣṭopamā": ['mw'],
    "viśiṣṭādvaita": ['mw'],
    "viśiṣṭādvaitabhāṣya": ['mw'],
    "viśiṣṭādvaitacandrikā": ['mw'],
    "viśiṣṭādvaitasamarthana": ['mw'],
    "viśiṣṭādvaitasiddhānta": ['mw'],
    "viśiṣṭādvaitavijayavāda": ['mw'],
    "viśiṣṭādvaitavādin": ['mw'],
    "viśiṣṭādvaitavādārtha": ['mw'],
    "viśiṣṭī": ['mw'],
    "viślath": ['mw'],
    "viślatha": ['ap90', 'cae', 'ddsa', 'mw'],
    "viślathita": ['mw'],
    "viślathāṅga": ['mw'],
    "viślathāṅgam": ['mw'],
    "viśleṣa": ['cae', 'mw'],
    "viśleṣajāti": ['mw'],
    "viśleṣasūtra": ['mw'],
    "viśleṣaḥ": ['ap90'],
    "viśleṣaṇa": ['cae', 'mw'],
    "viśleṣin": ['cae', 'mw'],
    "viśleṣita": ['ap90', 'mw'],
    "viśleṣitavakṣas": ['mw'],
    "viśliṣ": ['ap90', 'mw'],
    "viśliṣṭa": ['ap90', 'cae', 'mw'],
    "viśliṣṭatara": ['mw'],
    "viśloka": ['mw'],
    "viśna": ['mw'],
    "viśnaḥ": ['ap90'],
    "viśobhagīna": ['mw'],
    "viśobhita": ['mw'],
    "viśodha": ['bhs'],
    "viśodhaka": ['bhs'],
    "viśodhana": ['cae', 'mw'],
    "viśodhanaṃ": ['ap90'],
    "viśodhanī": ['mw'],
    "viśodhanīya": ['mw'],
    "viśodhayitar": ['bhs'],
    "viśodheya": ['bhs'],
    "viśodhin": ['mw'],
    "viśodhinī": ['mw'],
    "viśodhinībīja": ['mw'],
    "viśodhita": ['mw'],
    "viśodhitva": ['mw'],
    "viśodhya": ['ap90', 'mw'],
    "viśoka": ['ap90', 'cae', 'ddsa', 'mw'],
    "viśokadeva": ['mw'],
    "viśokadvādaśī": ['mw'],
    "viśokakoṭa": ['mw'],
    "viśokaparvan": ['mw'],
    "viśokasaptamī": ['mw'],
    "viśokatā": ['mw'],
    "viśokaṣaṣṭhī": ['mw'],
    "viśokā": ['mw'],
    "viśokīkṛ": ['mw'],
    "viśoviśīya": ['mw'],
    "viśoṇita": ['mw'],
    "viśoṣa": ['cae', 'mw'],
    "viśoṣaṇa": ['cae', 'mw'],
    "viśoṣaṇaṃ": ['ap90'],
    "viśoṣin": ['cae', 'mw'],
    "viśoṣita": ['mw'],
    "viśpalā": ['cae', 'gra', 'mw'],
    "viśpalāvasu": ['gra', 'mw'],
    "viśpati": ['cae', 'ddsa', 'gra', 'mw'],
    "viśpatnī": ['cae', 'gra', 'mw'],
    "viśrabdha": ['ap90', 'cae', 'mw'],
    "viśrabdhakārya": ['cae', 'mw'],
    "viśrabdham": ['mw'],
    "viśrabdhanavoḍhā": ['mw'],
    "viśrabdhapralāpin": ['cae', 'mw'],
    "viśrabdhasupta": ['cae', 'mw'],
    "viśrabdhatva": ['mw'],
    "viśrabdhatā": ['mw'],
    "viśram": ['ap90', 'mw'],
    "viśrama": ['cae', 'mw'],
    "viśramaḥ": ['ap90'],
    "viśramaṇa": ['mw'],
    "viśrambh": ['mw'],
    "viśrambha": ['cae', 'mw'],
    "viśrambhabhṛtya": ['mw'],
    "viśrambhagarbhakathā": ['cae', 'mw'],
    "viśrambhakathita": ['mw'],
    "viśrambhakathā": ['cae', 'mw'],
    "viśrambhasaṃkathā": ['mw'],
    "viśrambhasaṃsupta": ['mw'],
    "viśrambhatā": ['mw'],
    "viśrambhavat": ['mw'],
    "viśrambhaṇa": ['cae', 'mw'],
    "viśrambhaṇīya": ['mw'],
    "viśrambheṇa": ['mw'],
    "viśrambhika": ['bhs'],
    "viśrambhin": ['cae', 'mw'],
    "viśrambhitavya": ['mw'],
    "viśrambhālāpa": ['cae', 'mw'],
    "viśrambhāt": ['mw'],
    "viśramita": ['mw'],
    "viśrath": ['mw'],
    "viśravas": ['ap90', 'cae', 'mw'],
    "viśravaṇa": ['bhs', 'mw'],
    "viśraya": ['mw'],
    "viśrayaḥ": ['ap90'],
    "viśrayin": ['mw'],
    "viśraṃbh": ['ap90'],
    "viśraṃbhaḥ": ['ap90'],
    "viśraṃbhaṇaṃ": ['ap90'],
    "viśraṃbhin": ['ap90'],
    "viśraṇ": ['ap90', 'mw'],
    "viśraṇana": ['mw'],
    "viśraṇanaṃ": ['ap90'],
    "viśreṇayati": ['bhs'],
    "viśreṇīkṛtvā": ['bhs'],
    "viśri": ['mw'],
    "viśrita": ['mw'],
    "viśrotasikā": ['mw'],
    "viśru": ['mw'],
    "viśruta": ['ap90', 'cae', 'ddsa', 'mw'],
    "viśrutadeva": ['mw'],
    "viśrutavat": ['mw'],
    "viśrutaśrī": ['bhs'],
    "viśruti": ['cae', 'mw'],
    "viśrutiḥ": ['ap90'],
    "viśrutābhijana": ['mw'],
    "viśrāma": ['cae', 'mw'],
    "viśrāmabhū": ['cae', 'mw'],
    "viśrāmasthāna": ['cae', 'mw'],
    "viśrāmaveśman": ['mw'],
    "viśrāmayati": ['bhs'],
    "viśrāmaḥ": ['ap90'],
    "viśrāmaṇa": ['mw'],
    "viśrāmātmaja": ['mw'],
    "viśrānta": ['cae', 'mw'],
    "viśrāntakarṇayugala": ['mw'],
    "viśrāntakatha": ['mw'],
    "viśrāntanyāsa": ['mw'],
    "viśrāntapuṣpodgama": ['mw'],
    "viśrāntavaira": ['mw'],
    "viśrāntavidyādhara": ['mw'],
    "viśrāntavidyāvinoda": ['mw'],
    "viśrāntavigrahakatha": ['mw'],
    "viśrāntavilāsa": ['mw'],
    "viśrānti": ['cae', 'mw'],
    "viśrāntibhūmi": ['mw'],
    "viśrāntikṛt": ['mw'],
    "viśrāntimat": ['mw'],
    "viśrāntivarman": ['mw'],
    "viśrātas": ['bhs'],
    "viśrāva": ['mw'],
    "viśrāvaḥ": ['ap90'],
    "viśrāvaṇa": ['mw'],
    "viśrāṃta": ['ap90'],
    "viśrāṃtiḥ": ['ap90'],
    "viśrāṇana": ['mw'],
    "viśrāṇika": ['mw'],
    "viśrāṇita": ['mw'],
    "viśrīkṛ": ['ddsa', 'mw'],
    "viśubh": ['mw'],
    "viśuddha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "viśuddhabhāva": ['cae', 'mw'],
    "viśuddhabuddhi": ['bhs'],
    "viśuddhacārin": ['bhs'],
    "viśuddhacāritra": ['bhs', 'mw'],
    "viśuddhadhiṣaṇa": ['mw'],
    "viśuddhadhī": ['mw'],
    "viśuddhadhīra": ['mw'],
    "viśuddhagātratā": ['mw'],
    "viśuddhakaraṇa": ['mw'],
    "viśuddhamanas": ['mw'],
    "viśuddhamati": ['bhs'],
    "viśuddhamugdha": ['mw'],
    "viśuddhanandin": ['bhs'],
    "viśuddhanetratā": ['mw'],
    "viśuddhanetrābhā": ['bhs'],
    "viśuddhaprakṛti": ['mw'],
    "viśuddhapārṣṇi": ['mw'],
    "viśuddharasadīpikā": ['mw'],
    "viśuddhasattva": ['mw'],
    "viśuddhasattvapradhāna": ['mw'],
    "viśuddhasattvavijñāna": ['mw'],
    "viśuddhasiṃha": ['mw'],
    "viśuddhasvaranirghoṣā": ['bhs', 'mw'],
    "viśuddhatva": ['mw'],
    "viśuddhatā": ['mw'],
    "viśuddhavaṃśya": ['mw'],
    "viśuddhaviṣayajyotirvikaraṇa": ['bhs'],
    "viśuddheśvaratantra": ['mw'],
    "viśuddhi": ['cae', 'ddsa', 'mw'],
    "viśuddhicakra": ['mw'],
    "viśuddhidarpaṇa": ['mw'],
    "viśuddhimat": ['mw'],
    "viśuddhinetra": ['bhs'],
    "viśuddhiḥ": ['ap90'],
    "viśuddhātman": ['cae', 'mw'],
    "viśudh": ['ap90', 'mw'],
    "viśuka": ['mw'],
    "viśunthalavaṇa": ['mw'],
    "viśuṇḍi": ['mw'],
    "viśuṣ": ['mw'],
    "viśuṣka": ['cae', 'mw'],
    "viśuṣkatva": ['mw'],
    "viśva": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "viśvabandhu": ['mw'],
    "viśvabhadra": ['mw'],
    "viśvabharas": ['cae', 'gra', 'mw'],
    "viśvabhartṛ": ['mw'],
    "viśvabhava": ['mw'],
    "viśvabhaṇḍa": ['mw'],
    "viśvabheṣaja": ['cae', 'gra', 'mw'],
    "viśvabhojana": ['mw'],
    "viśvabhojas": ['cae', 'gra', 'mw'],
    "viśvabhrāj": ['gra', 'mw'],
    "viśvabhuj": ['bhs', 'cae', 'mw'],
    "viśvabhujā": ['mw'],
    "viśvabhānu": ['cae', 'gra', 'mw'],
    "viśvabhāva": ['mw'],
    "viśvabhāvana": ['mw'],
    "viśvabhū": ['bhs', 'mw'],
    "viśvabhūta": ['mw'],
    "viśvabhṛt": ['cae', 'mw'],
    "viśvabodha": ['mw'],
    "viśvabudbuda": ['mw'],
    "viśvabīja": ['mw'],
    "viśvacakra": ['mw'],
    "viśvacakradānavidhi": ['mw'],
    "viśvacakrātman": ['mw'],
    "viśvacakṣa": ['mw'],
    "viśvacakṣas": ['cae', 'gra', 'mw'],
    "viśvacakṣaṇa": ['cae', 'mw'],
    "viśvacakṣus": ['cae', 'mw'],
    "viśvacamatkṛti": ['mw'],
    "viśvacandra": ['mw'],
    "viśvacarṣaṇi": ['cae', 'gra', 'mw'],
    "viśvacyavas": ['mw'],
    "viśvadaiva": ['mw'],
    "viśvadaivata": ['mw'],
    "viśvadarśata": ['cae', 'gra', 'mw'],
    "viśvadatta": ['mw'],
    "viśvadaṃṣṭra": ['mw'],
    "viśvadeva": ['cae', 'gra', 'mw'],
    "viśvadevabhakta": ['mw'],
    "viśvadevadīkṣitīya": ['mw'],
    "viśvadevanetra": ['mw'],
    "viśvadevatā": ['mw'],
    "viśvadevavat": ['mw'],
    "viśvadevia": ['gra'],
    "viśvadeviāvat": ['gra'],
    "viśvadevya": ['cae', 'gra', 'mw'],
    "viśvadevyāvat": ['gra', 'mw'],
    "viśvadevā": ['mw'],
    "viśvadha": ['cae', 'gra', 'mw'],
    "viśvadhara": ['mw'],
    "viśvadharaṇa": ['mw'],
    "viśvadhena": ['cae', 'gra', 'mw'],
    "viśvadhenu": ['mw'],
    "viśvadhenā": ['mw'],
    "viśvadhā": ['cae', 'gra', 'mw'],
    "viśvadhāman": ['cae', 'mw'],
    "viśvadhāra": ['mw'],
    "viśvadhārin": ['mw'],
    "viśvadhāriṇī": ['mw'],
    "viśvadhātṛ": ['mw'],
    "viśvadhāyas": ['cae', 'gra', 'mw'],
    "viśvadhṛk": ['cae', 'mw'],
    "viśvadhṛt": ['cae', 'mw'],
    "viśvadohas": ['cae', 'gra', 'mw'],
    "viśvadryañc": ['mw'],
    "viśvadāni": ['mw'],
    "viśvadānīm": ['cae', 'gra', 'mw'],
    "viśvadānīṃ": ['ap90'],
    "viśvadāsā": ['mw'],
    "viśvadāva": ['cae', 'mw'],
    "viśvadāvan": ['cae', 'mw'],
    "viśvadāvya": ['cae', 'mw'],
    "viśvadīpa": ['mw'],
    "viśvadṛś": ['cae', 'mw'],
    "viśvadṛṣṭa": ['cae', 'gra', 'mw'],
    "viśvaga": ['mw'],
    "viśvagandha": ['mw'],
    "viśvagandhi": ['mw'],
    "viśvagandhā": ['mw'],
    "viśvagarbha": ['mw'],
    "viśvagata": ['mw'],
    "viśvagaśva": ['mw'],
    "viśvaggati": ['mw'],
    "viśvagjyotis": ['mw'],
    "viśvagocara": ['mw'],
    "viśvagoptṛ": ['mw'],
    "viśvagotra": ['mw'],
    "viśvagotrya": ['mw'],
    "viśvagranthi": ['mw'],
    "viśvagudh": ['mw'],
    "viśvaguru": ['mw'],
    "viśvaguṇādarśa": ['mw'],
    "viśvagūrta": ['cae', 'gra', 'mw'],
    "viśvagūrti": ['cae', 'gra', 'mw'],
    "viśvagūrṇa": ['mw'],
    "viśvaha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "viśvahartṛ": ['mw'],
    "viśvaharyaka": ['mw'],
    "viśvaharyata": ['mw'],
    "viśvahetu": ['mw'],
    "viśvahā": ['gra', 'mw'],
    "viśvaikasāra": ['ddsa', 'mw'],
    "viśvajana": ['mw'],
    "viśvajanman": ['mw'],
    "viśvajanya": ['cae', 'gra', 'mw'],
    "viśvajanīna": ['mw'],
    "viśvajanīnavṛtti": ['mw'],
    "viśvajanīya": ['mw'],
    "viśvajayin": ['mw'],
    "viśvajicchilpa": ['mw'],
    "viśvajidatirātrapaddhati": ['mw'],
    "viśvajinva": ['cae', 'gra', 'mw'],
    "viśvajit": ['cae', 'gra', 'mw'],
    "viśvajyotis": ['mw'],
    "viśvajyotiṣa": ['mw'],
    "viśvajīva": ['mw'],
    "viśvajū": ['cae', 'gra', 'mw'],
    "viśvaka": ['ddsa', 'gra', 'mw'],
    "viśvakadru": ['mw'],
    "viśvakadrākarṣa": ['mw'],
    "viśvakarma": ['gra', 'mw'],
    "viśvakarmajā": ['mw'],
    "viśvakarmamāhātmya": ['mw'],
    "viśvakarman": ['cae', 'gra', 'mw'],
    "viśvakarmaprakāśa": ['mw'],
    "viśvakarmapurāṇa": ['mw'],
    "viśvakarmapurāṇasaṃgraha": ['mw'],
    "viśvakarmasiddhānta": ['mw'],
    "viśvakarmasutā": ['mw'],
    "viśvakarmaśāstrin": ['mw'],
    "viśvakarmeśa": ['mw'],
    "viśvakarmeśvaraliṅga": ['mw'],
    "viśvakarmīya": ['mw'],
    "viśvakarmīyaśilpa": ['mw'],
    "viśvakartṛ": ['mw'],
    "viśvakartṛtva": ['mw'],
    "viśvakathā": ['mw'],
    "viśvaketu": ['mw'],
    "viśvakośa": ['mw'],
    "viśvaksena": ['mw'],
    "viśvakāraka": ['mw'],
    "viśvakāru": ['mw'],
    "viśvakārya": ['mw'],
    "viśvakāya": ['mw'],
    "viśvakāyā": ['mw'],
    "viśvakṛt": ['cae', 'mw'],
    "viśvakṛta": ['mw'],
    "viśvakṛṣṭi": ['cae', 'gra', 'mw'],
    "viśvakṣaya": ['mw'],
    "viśvakṣiti": ['mw'],
    "viśvaliṅga": ['mw'],
    "viśvalocana": ['mw'],
    "viśvalopa": ['mw'],
    "viśvamadā": ['mw'],
    "viśvamaha": ['mw'],
    "viśvamahas": ['gra', 'mw'],
    "viśvamahat": ['mw'],
    "viśvamaheśvara": ['mw'],
    "viśvamaheśvaramatācāra": ['mw'],
    "viśvamanas": ['cae', 'gra', 'mw'],
    "viśvamanus": ['gra', 'mw'],
    "viśvamaya": ['mw'],
    "viśvambhara": ['mw'],
    "viśvambharaka": ['mw'],
    "viśvambharakulāya": ['mw'],
    "viśvambharamaithilopādhyāya": ['mw'],
    "viśvambharavāstuśāstra": ['mw'],
    "viśvambharaśāstra": ['mw'],
    "viśvambhari": ['mw'],
    "viśvambharopaniṣad": ['mw'],
    "viśvambharā": ['mw'],
    "viśvambharābhuj": ['mw'],
    "viśvambharādhipa": ['mw'],
    "viśvambharādhīśvara": ['mw'],
    "viśvambharāputra": ['mw'],
    "viśvamedinī": ['mw'],
    "viśvamejaya": ['cae', 'gra', 'mw'],
    "viśvaminva": ['cae', 'gra', 'mw'],
    "viśvamitra": ['bhs', 'mw'],
    "viśvamohana": ['mw'],
    "viśvamukhī": ['mw'],
    "viśvamānava": ['mw'],
    "viśvamānuṣa": ['gra', 'mw'],
    "viśvamātā": ['bhs'],
    "viśvamātṛ": ['mw'],
    "viśvamātṛkā": ['mw'],
    "viśvamūrti": ['cae', 'mw'],
    "viśvamūrtimat": ['mw'],
    "viśvanagara": ['mw'],
    "viśvananda": ['mw'],
    "viśvanara": ['mw'],
    "viśvanighaṇṭu": ['mw'],
    "viśvanābha": ['mw'],
    "viśvanābhi": ['mw'],
    "viśvanāman": ['cae', 'mw'],
    "viśvanātha": ['cae', 'mw'],
    "viśvanāthabhaṭṭa": ['mw'],
    "viśvanāthacaritra": ['mw'],
    "viśvanāthadeva": ['mw'],
    "viśvanāthadevaprakāśa": ['mw'],
    "viśvanāthakavirāja": ['mw'],
    "viśvanāthanagarī": ['mw'],
    "viśvanāthanagarīstotra": ['mw'],
    "viśvanāthanyāyālaṃkāra": ['mw'],
    "viśvanāthanārāyaṇa": ['mw'],
    "viśvanāthapañcānana": ['mw'],
    "viśvanāthapurī": ['mw'],
    "viśvanāthasena": ['mw'],
    "viśvanāthasiṃha": ['mw'],
    "viśvanāthasiṃhadeva": ['mw'],
    "viśvanāthastotra": ['mw'],
    "viśvanāthasūri": ['mw'],
    "viśvanāthatājaka": ['mw'],
    "viśvanāthatīrtha": ['mw'],
    "viśvanāthopādhyāya": ['mw'],
    "viśvanāthācārya": ['mw'],
    "viśvanāthāśrama": ['mw'],
    "viśvanāthāṣṭaka": ['mw'],
    "viśvanāthīya": ['mw'],
    "viśvapad": ['mw'],
    "viśvapadmā": ['bhs'],
    "viśvapakṣa": ['mw'],
    "viśvaparṇī": ['mw'],
    "viśvapati": ['mw'],
    "viśvapeśas": ['cae', 'gra', 'mw'],
    "viśvapiś": ['cae', 'gra', 'mw'],
    "viśvaprabodha": ['mw'],
    "viśvapradīpa": ['mw'],
    "viśvaprakāśa": ['mw'],
    "viśvaprakāśapaddhati": ['mw'],
    "viśvaprī": ['mw'],
    "viśvapsan": ['mw'],
    "viśvapsnia": ['gra'],
    "viśvapsnya": ['cae', 'gra', 'mw'],
    "viśvapsnyāya": ['mw'],
    "viśvapsu": ['cae', 'gra', 'mw'],
    "viśvapsā": ['mw'],
    "viśvapuṣ": ['gra', 'mw'],
    "viśvapā": ['mw'],
    "viśvapācaka": ['mw'],
    "viśvapādaśirogrīva": ['mw'],
    "viśvapāla": ['mw'],
    "viśvapātṛ": ['mw'],
    "viśvapāvana": ['mw'],
    "viśvapāvanī": ['mw'],
    "viśvapāṇi": ['mw'],
    "viśvapūjita": ['mw'],
    "viśvapūjitā": ['mw'],
    "viśvapūjya": ['mw'],
    "viśvaratha": ['mw'],
    "viśvaretas": ['mw'],
    "viśvarocana": ['mw'],
    "viśvaruci": ['mw'],
    "viśvarucī": ['mw'],
    "viśvarādhas": ['mw'],
    "viśvarāj": ['mw'],
    "viśvarūpa": ['cae', 'gra', 'mw'],
    "viśvarūpadarśana": ['mw'],
    "viśvarūpadeva": ['mw'],
    "viśvarūpadhara": ['mw'],
    "viśvarūpagaṇakamunīśvara": ['mw'],
    "viśvarūpaka": ['mw'],
    "viśvarūpakeśava": ['mw'],
    "viśvarūpamaya": ['mw'],
    "viśvarūpanibandha": ['mw'],
    "viśvarūpasamuccaya": ['mw'],
    "viśvarūpatama": ['mw'],
    "viśvarūpatīrtha": ['mw'],
    "viśvarūpavat": ['mw'],
    "viśvarūpikā": ['mw'],
    "viśvarūpin": ['mw'],
    "viśvarūpiṇī": ['mw'],
    "viśvarūpā": ['mw'],
    "viśvarūpācārya": ['mw'],
    "viśvarūpī": ['gra', 'mw'],
    "viśvas": ['ap90', 'mw'],
    "viśvasaha": ['ddsa', 'mw'],
    "viśvasahā": ['mw'],
    "viśvasahāya": ['mw'],
    "viśvasakha": ['cae', 'mw'],
    "viśvasambhava": ['mw'],
    "viśvasamplava": ['mw'],
    "viśvasana": ['mw'],
    "viśvasanīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "viśvasanīyatva": ['mw'],
    "viśvasanīyatā": ['mw'],
    "viśvasattama": ['cae', 'mw'],
    "viśvasaubhaga": ['cae', 'gra', 'mw'],
    "viśvasaṃhāra": ['mw'],
    "viśvasaṃvanana": ['mw'],
    "viśvasena": ['mw'],
    "viśvasenarāj": ['mw'],
    "viśvasita": ['mw'],
    "viśvasitavya": ['mw'],
    "viśvasiṃha": ['mw'],
    "viśvasphaṭika": ['mw'],
    "viśvasphārṇi": ['mw'],
    "viśvasphāṇi": ['mw'],
    "viśvasphāṭi": ['mw'],
    "viśvasphīṇi": ['mw'],
    "viśvasphūrji": ['mw'],
    "viśvasphūrti": ['mw'],
    "viśvaspṛś": ['mw'],
    "viśvasraṣṭṛ": ['mw'],
    "viśvasta": ['ap90', 'cae', 'ddsa', 'mw'],
    "viśvastaghātaka": ['mw'],
    "viśvastaghātin": ['mw'],
    "viśvastam": ['mw'],
    "viśvastavat": ['mw'],
    "viśvastavañcaka": ['mw'],
    "viśvasthā": ['mw'],
    "viśvastā": ['mw'],
    "viśvasuvid": ['gra', 'mw'],
    "viśvasvāmin": ['mw'],
    "viśvasāhva": ['mw'],
    "viśvasāhvan": ['mw'],
    "viśvasākṣin": ['mw'],
    "viśvasāman": ['gra', 'mw'],
    "viśvasāra": ['mw'],
    "viśvasāraka": ['mw'],
    "viśvasū": ['cae', 'mw'],
    "viśvasūtradhṛk": ['mw'],
    "viśvasṛj": ['cae', 'mw'],
    "viśvasṛt": ['mw'],
    "viśvasṛṣṭi": ['mw'],
    "viśvatanu": ['mw'],
    "viśvatas": ['ap90', 'cae', 'gra', 'mw'],
    "viśvataspad": ['gra', 'mw'],
    "viśvataspād": ['gra'],
    "viśvataspāṇi": ['mw'],
    "viśvataspṛtha": ['mw'],
    "viśvataś": ['mw'],
    "viśvataścakṣus": ['gra', 'mw'],
    "viśvatha": ['mw'],
    "viśvathā": ['ap90', 'cae', 'gra', 'mw'],
    "viśvato": ['mw'],
    "viśvatobāhu": ['gra', 'mw'],
    "viśvatodhī": ['gra', 'mw'],
    "viśvatodāvan": ['mw'],
    "viśvatohasta": ['mw'],
    "viśvatomukha": ['cae', 'gra', 'mw'],
    "viśvatomukham": ['mw'],
    "viśvatovīrya": ['mw'],
    "viśvatoya": ['mw'],
    "viśvatra": ['cae', 'gra', 'mw'],
    "viśvatraya": ['mw'],
    "viśvatryarcas": ['mw'],
    "viśvatur": ['cae', 'gra', 'mw'],
    "viśvaturāṣah": ['mw'],
    "viśvatūrti": ['cae', 'gra', 'mw'],
    "viśvatṛpta": ['mw'],
    "viśvauhī": ['mw'],
    "viśvaujas": ['cae', 'ddsa', 'gra', 'mw'],
    "viśvauṣadha": ['mw'],
    "viśvavada": ['mw'],
    "viśvavah": ['mw'],
    "viśvavajrā": ['bhs'],
    "viśvavani": ['mw'],
    "viśvavapari": ['mw'],
    "viśvavarman": ['mw'],
    "viśvavarṇa": ['bhs'],
    "viśvavasu": ['mw'],
    "viśvavat": ['mw'],
    "viśvavayas": ['mw'],
    "viśvaveda": ['mw'],
    "viśvavedas": ['cae', 'gra', 'mw'],
    "viśvavibhāvana": ['mw'],
    "viśvavid": ['cae', 'gra', 'mw'],
    "viśvavidhāyin": ['mw'],
    "viśvavidvas": ['mw'],
    "viśvavijayin": ['mw'],
    "viśvavikhyāta": ['mw'],
    "viśvavinna": ['mw'],
    "viśvavistā": ['mw'],
    "viśvavisārin": ['mw'],
    "viśvaviśruta": ['mw'],
    "viśvaviśva": ['mw'],
    "viśvavyacas": ['cae', 'gra', 'mw'],
    "viśvavyāpaka": ['mw'],
    "viśvavyāpin": ['mw'],
    "viśvavyāpti": ['mw'],
    "viśvavāc": ['mw'],
    "viśvavājin": ['mw'],
    "viśvavāra": ['cae', 'gra', 'mw'],
    "viśvavāria": ['gra'],
    "viśvavārya": ['cae', 'gra', 'mw'],
    "viśvavārā": ['mw'],
    "viśvavāsa": ['mw'],
    "viśvavṛkṣa": ['mw'],
    "viśvavṛtti": ['mw'],
    "viśvayaśas": ['mw'],
    "viśvayoni": ['cae', 'mw'],
    "viśvayu": ['mw'],
    "viśvayuḥ": ['ap90'],
    "viśvañc": ['mw'],
    "viśvaśambhu": ['mw'],
    "viśvaśambhumuni": ['mw'],
    "viśvaśambhū": ['gra', 'mw'],
    "viśvaśardhas": ['gra', 'mw'],
    "viśvaśarman": ['mw'],
    "viśvaśaṃbhū": ['cae'],
    "viśvaścandra": ['cae', 'gra', 'mw'],
    "viśvaśraddhājñānabala": ['mw'],
    "viśvaśruṣṭi": ['gra', 'mw'],
    "viśvaśrī": ['cae', 'mw'],
    "viśvaśuc": ['cae', 'gra', 'mw'],
    "viśvaśuci": ['mw'],
    "viśvaśārada": ['mw'],
    "viśvaḍākinī": ['bhs'],
    "viśvaṃbhara": ['ap90', 'cae'],
    "viśvaṃbharakulāya": ['cae'],
    "viśvaṃkara": ['mw'],
    "viśvaṃkaraḥ": ['ap90'],
    "viśvaṃtara": ['bhs', 'mw'],
    "viśvebhojas": ['mw'],
    "viśvedeva": ['ddsa', 'mw'],
    "viśvedevā": ['mw'],
    "viśvedevṛ": ['mw'],
    "viśvekṣitṛ": ['mw'],
    "viśvevedas": ['mw'],
    "viśveśa": ['cae', 'ddsa', 'mw'],
    "viśveśitṛ": ['mw'],
    "viśveśvara": ['cae', 'mw'],
    "viśveśvarabhaṭṭa": ['mw'],
    "viśveśvaradaivajña": ['mw'],
    "viśveśvaradatta": ['mw'],
    "viśveśvaradattamiśra": ['mw'],
    "viśveśvarakālī": ['mw'],
    "viśveśvaraliṅga": ['mw'],
    "viśveśvaramiśra": ['mw'],
    "viśveśvaramāhātmya": ['mw'],
    "viśveśvaranātha": ['mw'],
    "viśveśvaranīrājana": ['mw'],
    "viśveśvarapaddhati": ['mw'],
    "viśveśvarapattana": ['mw'],
    "viśveśvarapaṇḍita": ['mw'],
    "viśveśvarapūjyapāda": ['mw'],
    "viśveśvarasarasvatī": ['mw'],
    "viśveśvarasaṃhitā": ['mw'],
    "viśveśvarasmṛti": ['mw'],
    "viśveśvarasthāna": ['mw'],
    "viśveśvarastutipārijāta": ['mw'],
    "viśveśvarasūnu": ['mw'],
    "viśveśvaratantra": ['mw'],
    "viśveśvaratīrtha": ['mw'],
    "viśveśvaravedapādastava": ['mw'],
    "viśveśvarācārya": ['mw'],
    "viśveśvarāmbumuni": ['mw'],
    "viśveśvarānandasarasvatī": ['mw'],
    "viśveśvarāśrama": ['mw'],
    "viśveśvarī": ['mw'],
    "viśveśvarīpaddhati": ['mw'],
    "viśveśvarīya": ['mw'],
    "viśveśā": ['mw'],
    "viśvi": ['mw'],
    "viśvit": ['mw'],
    "viśviā": ['gra'],
    "viśvoddhāratantra": ['mw'],
    "viśvyā": ['cae', 'gra', 'mw'],
    "viśvā": ['cae', 'mw'],
    "viśvābhirakṣaṇa": ['mw'],
    "viśvābhū": ['gra', 'mw'],
    "viśvāc": ['gra'],
    "viśvācārya": ['mw'],
    "viśvācī": ['cae', 'ddsa', 'mw'],
    "viśvād": ['cae', 'gra', 'mw'],
    "viśvādarśa": ['mw'],
    "viśvādarśasmṛti": ['mw'],
    "viśvādhipa": ['cae', 'mw'],
    "viśvādhiṣṭhāna": ['mw'],
    "viśvādhāra": ['mw'],
    "viśvādhāyas": ['ap90', 'mw'],
    "viśvāhā": ['cae', 'ddsa', 'gra', 'mw'],
    "viśvājina": ['mw'],
    "viśvākṣa": ['mw'],
    "viśvāmitra": ['bhs', 'cae', 'gra', 'mw'],
    "viśvāmitrajamadagni": ['gra', 'mw'],
    "viśvāmitrakalpa": ['mw'],
    "viśvāmitrakalpataru": ['mw'],
    "viśvāmitranadī": ['mw'],
    "viśvāmitrapriya": ['mw'],
    "viśvāmitrapura": ['mw'],
    "viśvāmitrapurī": ['mw'],
    "viśvāmitrapurīya": ['mw'],
    "viśvāmitrarāśi": ['mw'],
    "viśvāmitrasaṃhitā": ['mw'],
    "viśvāmitrasmṛti": ['mw'],
    "viśvāmitrasṛṣṭi": ['mw'],
    "viśvāmitraḥ": ['ap90'],
    "viśvāmitrā": ['mw'],
    "viśvāmṛta": ['mw'],
    "viśvānandanātha": ['mw'],
    "viśvānara": ['cae', 'gra', 'mw'],
    "viśvānaraḥ": ['ap90'],
    "viśvānna": ['mw'],
    "viśvāntara": ['mw'],
    "viśvāpsu": ['gra', 'mw'],
    "viśvāpuṣ": ['gra', 'mw'],
    "viśvārāj": ['ap90', 'mw'],
    "viśvāsa": ['cae', 'ddsa', 'mw'],
    "viśvāsabhaṅga": ['cae', 'mw'],
    "viśvāsabhūmi": ['mw'],
    "viśvāsadevī": ['mw'],
    "viśvāsaghāta": ['cae', 'mw'],
    "viśvāsaghātaka": ['mw'],
    "viśvāsaghātin": ['mw'],
    "viśvāsah": ['cae', 'gra', 'mw'],
    "viśvāsahantṛ": ['mw'],
    "viśvāsahartṛ": ['mw'],
    "viśvāsaikabhū": ['mw'],
    "viśvāsaikasāra": ['mw'],
    "viśvāsajanman": ['mw'],
    "viśvāsakāraka": ['mw'],
    "viśvāsakāraṇa": ['mw'],
    "viśvāsakārya": ['cae', 'mw'],
    "viśvāsakṛt": ['mw'],
    "viśvāsamaya": ['mw'],
    "viśvāsana": ['cae', 'ddsa', 'mw'],
    "viśvāsanaṃ": ['ap90'],
    "viśvāsanārtham": ['mw'],
    "viśvāsaparama": ['mw'],
    "viśvāsaprada": ['mw'],
    "viśvāsapratipanna": ['mw'],
    "viśvāsapātra": ['cae', 'ddsa', 'mw'],
    "viśvāsarāya": ['mw'],
    "viśvāsasthāna": ['cae', 'mw'],
    "viśvāsaḥ": ['ap90'],
    "viśvāsika": ['cae', 'mw'],
    "viśvāsikatara": ['mw'],
    "viśvāsin": ['cae', 'ddsa', 'mw'],
    "viśvāsita": ['mw'],
    "viśvāsojjhitadhī": ['mw'],
    "viśvāsopagama": ['mw'],
    "viśvāsya": ['cae', 'mw'],
    "viśvāsyatara": ['mw'],
    "viśvāsāh": ['gra'],
    "viśvātithi": ['ddsa', 'mw'],
    "viśvātmaka": ['mw'],
    "viśvātman": ['cae', 'mw'],
    "viśvātmanas": ['mw'],
    "viśvātīta": ['mw'],
    "viśvāvarta": ['mw'],
    "viśvāvasu": ['cae', 'gra', 'mw'],
    "viśvāvasumantra": ['mw'],
    "viśvāvasuḥ": ['ap90'],
    "viśvāvat": ['mw'],
    "viśvāvatī": ['mw'],
    "viśvāvaṭva": ['mw'],
    "viśvāvāsa": ['mw'],
    "viśvāyana": ['mw'],
    "viśvāyu": ['cae', 'gra', 'mw'],
    "viśvāyupoṣas": ['gra', 'mw'],
    "viśvāyus": ['mw'],
    "viśvāyuvepas": ['gra', 'mw'],
    "viśvāṅga": ['cae', 'mw'],
    "viśvāṅgya": ['mw'],
    "viśvāṇḍa": ['mw'],
    "viśya": ['cae', 'ddsa', 'gra', 'mw'],
    "viśyāparṇa": ['ddsa', 'mw'],
    "viśākha": ['bhs', 'cae', 'ddsa', 'mw'],
    "viśākhadatta": ['ap90', 'cae', 'mw'],
    "viśākhadeva": ['bhs', 'mw'],
    "viśākhaja": ['mw'],
    "viśākhaka": ['mw'],
    "viśākhala": ['ap90', 'mw'],
    "viśākhamāhātmya": ['mw'],
    "viśākhavat": ['mw'],
    "viśākhayūpa": ['mw'],
    "viśākhaḥ": ['ap90'],
    "viśākhikā": ['mw'],
    "viśākhikādaṇḍa": ['mw'],
    "viśākhila": ['mw'],
    "viśākhā": ['ap90', 'bhs', 'mw'],
    "viśākhī": ['mw'],
    "viśāla": ['ap90', 'cae', 'mw'],
    "viśālabuddhi": ['bhs'],
    "viśālada": ['bhs'],
    "viśāladatta": ['mw'],
    "viśāladā": ['mw'],
    "viśālagrāma": ['mw'],
    "viśālaka": ['mw'],
    "viśālakula": ['mw'],
    "viśālakulasambhava": ['mw'],
    "viśālalocana": ['cae'],
    "viśālalocanā": ['mw'],
    "viśālam": ['mw'],
    "viśālanagara": ['mw'],
    "viśālanayanatā": ['mw'],
    "viśālanetra": ['bhs', 'cae', 'mw'],
    "viśālanetrī": ['mw'],
    "viśālanetrīsādhana": ['mw'],
    "viśālapattra": ['mw'],
    "viśālaphalaka": ['mw'],
    "viśālaprabha": ['bhs'],
    "viśālapurī": ['mw'],
    "viśālatailagarbha": ['mw'],
    "viśālatva": ['mw'],
    "viśālatvac": ['mw'],
    "viśālatā": ['ap90', 'cae', 'mw'],
    "viśālavarman": ['mw'],
    "viśālavijaya": ['mw'],
    "viśālaya": ['mw'],
    "viśālika": ['mw'],
    "viśālikā": ['mw'],
    "viśālila": ['mw'],
    "viśāliya": ['mw'],
    "viśālā": ['bhs', 'mw'],
    "viśālākṣa": ['bhs', 'cae', 'mw'],
    "viśālākṣī": ['mw'],
    "viśālākṣīmāhātmya": ['mw'],
    "viśālī": ['mw'],
    "viśālīya": ['mw'],
    "viśāpa": ['mw'],
    "viśāra": ['bhs'],
    "viśārada": ['ap90', 'bhs', 'cae', 'mw'],
    "viśāradatva": ['mw'],
    "viśāradiman": ['mw'],
    "viśāradya": ['bhs'],
    "viśāradā": ['mw'],
    "viśārayati": ['bhs'],
    "viśāraṇa": ['mw'],
    "viśāraṇaṃ": ['ap90'],
    "viśās": ['mw'],
    "viśāstṛ": ['mw'],
    "viśāta": ['bhs'],
    "viśātana": ['cae', 'mw'],
    "viśātanaṃ": ['ap90'],
    "viśātaya": ['mw'],
    "viśāya": ['mw'],
    "viśāyaka": ['mw'],
    "viśāyaḥ": ['ap90'],
    "viśāyin": ['mw'],
    "viśāṃpati": ['bhs'],
    "viśī": ['mw'],
    "viśīla": ['ap90', 'cae', 'mw'],
    "viśīrya": ['mw'],
    "viśīrṇa": ['ap90', 'cae', 'mw'],
    "viśīrṇadhāra": ['mw'],
    "viśīrṇajīrṇavasana": ['mw'],
    "viśīrṇamūrti": ['mw'],
    "viśīrṇaparṇa": ['mw'],
    "viśīrṇapaṅkti": ['mw'],
    "viśīrṇatā": ['mw'],
    "viśīrṣan": ['cae', 'mw'],
    "viśīta": ['mw'],
    "viśūla": ['ap90', 'cae', 'mw'],
    "viśūnya": ['cae', 'ddsa', 'mw'],
    "viśṛdh": ['mw'],
    "viśṛṃkhala": ['ap90'],
    "viśṛṅga": ['cae', 'mw'],
    "viśṛṅkhala": ['cae', 'ddsa', 'mw'],
    "viśṛṅkhalam": ['mw'],
    "viśṝ": ['ap90', 'mw'],
    "viḍ": ['ap90', 'mw'],
    "viḍa": ['cae', 'ddsa', 'mw'],
    "viḍagandha": ['mw'],
    "viḍalavaṇa": ['mw'],
    "viḍamb": ['mw'],
    "viḍamba": ['cae', 'ddsa', 'mw'],
    "viḍambaka": ['bhs', 'cae', 'mw'],
    "viḍambana": ['cae', 'mw'],
    "viḍambanīya": ['mw'],
    "viḍambin": ['cae', 'mw'],
    "viḍambita": ['bhs', 'mw'],
    "viḍambiteśvara": ['mw'],
    "viḍambya": ['mw'],
    "viḍaujas": ['ap90', 'cae', 'ddsa', 'mw'],
    "viḍaṃ": ['ap90'],
    "viḍaṃb": ['ap90'],
    "viḍaṃbanaṃ": ['ap90'],
    "viḍaṃbaḥ": ['ap90'],
    "viḍaṃbita": ['ap90'],
    "viḍaṃga": ['ap90'],
    "viḍaṅga": ['mw'],
    "viḍaṅgikā": ['bhs'],
    "viḍbandha": ['mw'],
    "viḍbhava": ['mw'],
    "viḍbhaṅga": ['mw'],
    "viḍbheda": ['mw'],
    "viḍbhedin": ['mw'],
    "viḍbhid": ['mw'],
    "viḍbhojin": ['mw'],
    "viḍbhuj": ['cae', 'ddsa', 'mw'],
    "viḍga": ['ddsa'],
    "viḍgandha": ['mw'],
    "viḍghāta": ['mw'],
    "viḍgraha": ['mw'],
    "viḍhḍhala": ['mw'],
    "viḍināthakavi": ['mw'],
    "viḍja": ['cae', 'mw'],
    "viḍlavaṇa": ['mw'],
    "viḍojas": ['ap90', 'cae', 'ddsa', 'mw'],
    "viḍu": ['mw'],
    "viḍula": ['mw'],
    "viḍulaḥ": ['ap90'],
    "viḍvarāha": ['cae', 'mw'],
    "viḍvighāta": ['mw'],
    "viḍāla": ['ap90'],
    "viḍāraka": ['mw'],
    "viḍārakaḥ": ['ap90'],
    "viḍāyatanīya": ['mw'],
    "viḍīna": ['mw'],
    "viḍīnaka": ['mw'],
    "viḍīnaṃ": ['ap90'],
    "viḍūraja": ['mw'],
    "viḍūrajaṃ": ['ap90'],
    "viḍḍa": ['mw'],
    "viḍḍasiṃha": ['ddsa', 'mw'],
    "viḥ": ['ap90'],
    "viḥkṛndhikā": ['mw'],
    "viṃbaka": ['ap90'],
    "viṃbaḥ": ['ap90'],
    "viṃbaṭaḥ": ['ap90'],
    "viṃbikā": ['ap90'],
    "viṃbuḥ": ['ap90'],
    "viṃbā": ['ap90'],
    "viṃdhyaḥ": ['ap90'],
    "viṃdu": ['ap90'],
    "viṃjoli": ['ap90'],
    "viṃjāmaraṃ": ['ap90'],
    "viṃkhaḥ": ['ap90'],
    "viṃvara": ['bhs'],
    "viṃśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "viṃśacchlokī": ['mw'],
    "viṃśadbāhu": ['mw'],
    "viṃśaja": ['mw'],
    "viṃśaka": ['ap90', 'cae', 'mw'],
    "viṃśat": ['cae', 'mw'],
    "viṃśati": ['cae', 'ddsa', 'gra', 'mw'],
    "viṃśatibhuja": ['mw'],
    "viṃśatibhāga": ['mw'],
    "viṃśatibāhu": ['mw'],
    "viṃśatidvija": ['mw'],
    "viṃśatika": ['ap90', 'cae'],
    "viṃśatikīna": ['mw'],
    "viṃśatima": ['cae', 'mw'],
    "viṃśatipa": ['mw'],
    "viṃśatismṛti": ['mw'],
    "viṃśatistotra": ['mw'],
    "viṃśatisāhasra": ['mw'],
    "viṃśatitama": ['ap90', 'cae', 'mw'],
    "viṃśatitaulika": ['mw'],
    "viṃśativarga": ['bhs'],
    "viṃśativarṣadeśīya": ['mw'],
    "viṃśatividha": ['mw'],
    "viṃśativārṣika": ['mw'],
    "viṃśatiśata": ['cae', 'mw'],
    "viṃśatiḥ": ['ap90'],
    "viṃśaty": ['mw'],
    "viṃśatyadhipati": ['mw'],
    "viṃśatyakṣara": ['mw'],
    "viṃśatyaṅguli": ['mw'],
    "viṃśatīśa": ['mw'],
    "viṃśatīśin": ['mw'],
    "viṃśin": ['ap90', 'cae', 'ddsa', 'mw'],
    "viṃśāṃśa": ['cae', 'mw'],
    "viṅka": ['mw'],
    "viṅkha": ['mw'],
    "viṇ": ['mw'],
    "viṇmūtra": ['cae', 'ddsa', 'mw'],
    "viṇḍa": ['bhs'],
    "viṇṭ": ['mw'],
    "viṇṭaka": ['mw'],
    "viṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "viṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "viṣabhadrikā": ['mw'],
    "viṣabhadrā": ['mw'],
    "viṣabhakṣaṇa": ['mw'],
    "viṣabhiṣaj": ['mw'],
    "viṣabhujaṃga": ['mw'],
    "viṣabhṛt": ['mw'],
    "viṣad": ['ap90', 'mw'],
    "viṣada": ['mw'],
    "viṣadantaka": ['mw'],
    "viṣadarśanamṛtyuka": ['mw'],
    "viṣadaṃṣṭrā": ['mw'],
    "viṣadaṇḍa": ['mw'],
    "viṣadhara": ['cae', 'mw'],
    "viṣadharanilaya": ['mw'],
    "viṣadharmā": ['mw'],
    "viṣadhāna": ['mw'],
    "viṣadhātrī": ['mw'],
    "viṣadigdha": ['cae', 'mw'],
    "viṣadoṣahara": ['mw'],
    "viṣadruma": ['cae', 'mw'],
    "viṣadviṣā": ['mw'],
    "viṣadāyaka": ['cae', 'mw'],
    "viṣadāyin": ['cae', 'mw'],
    "viṣadūṣaṇa": ['cae', 'mw'],
    "viṣaghaṭikā": ['mw'],
    "viṣaghaṭikājananaśānti": ['mw'],
    "viṣaghna": ['cae', 'mw'],
    "viṣaghnikā": ['mw'],
    "viṣaghnī": ['mw'],
    "viṣaghā": ['mw'],
    "viṣaghāta": ['cae', 'mw'],
    "viṣaghātaka": ['mw'],
    "viṣaghātin": ['mw'],
    "viṣagiri": ['mw'],
    "viṣagranthi": ['mw'],
    "viṣah": ['ap90', 'mw'],
    "viṣaha": ['mw'],
    "viṣahan": ['cae', 'mw'],
    "viṣahantṛ": ['mw'],
    "viṣahara": ['cae', 'mw'],
    "viṣaharacikitsā": ['mw'],
    "viṣaharamantraprayoga": ['mw'],
    "viṣaharamantrauṣadha": ['mw'],
    "viṣaheti": ['mw'],
    "viṣahya": ['ap90', 'cae', 'ddsa', 'mw'],
    "viṣahā": ['mw'],
    "viṣahīna": ['mw'],
    "viṣahṛdaya": ['mw'],
    "viṣaja": ['cae', 'mw'],
    "viṣajadruma": ['ddsa'],
    "viṣajala": ['mw'],
    "viṣajihva": ['cae', 'mw'],
    "viṣajit": ['mw'],
    "viṣajjita": ['mw'],
    "viṣajuṣṭa": ['mw'],
    "viṣajvara": ['mw'],
    "viṣakanda": ['mw'],
    "viṣakanyakā": ['cae', 'mw'],
    "viṣakanyā": ['cae', 'mw'],
    "viṣakaṇṭakinī": ['mw'],
    "viṣakaṇṭha": ['mw'],
    "viṣakhā": ['mw'],
    "viṣakta": ['ap90', 'cae', 'mw'],
    "viṣaktatva": ['mw'],
    "viṣakti": ['bhs'],
    "viṣaktikā": ['bhs'],
    "viṣakumbha": ['cae', 'mw'],
    "viṣakāṣṭha": ['mw'],
    "viṣakṛmi": ['cae', 'mw'],
    "viṣakṛminyāya": ['mw'],
    "viṣakṛta": ['cae', 'mw'],
    "viṣala": ['mw'],
    "viṣalatā": ['mw'],
    "viṣalaḍḍuka": ['mw'],
    "viṣalaḥ": ['ap90'],
    "viṣalāṅgala": ['mw'],
    "viṣalāṇṭā": ['mw'],
    "viṣalāṭā": ['mw'],
    "viṣama": ['ap90', 'cae', 'ddsa', 'mw'],
    "viṣamabhojana": ['mw'],
    "viṣamabāṇa": ['mw'],
    "viṣamabāṇalīlā": ['mw'],
    "viṣamacakravāla": ['mw'],
    "viṣamacaturaśra": ['mw'],
    "viṣamacaturbhuja": ['mw'],
    "viṣamacatuṣkoṇa": ['mw'],
    "viṣamacchada": ['mw'],
    "viṣamacchāyā": ['mw'],
    "viṣamadhātu": ['mw'],
    "viṣamadṛṣṭi": ['mw'],
    "viṣamagata": ['mw'],
    "viṣamajvara": ['mw'],
    "viṣamajvarāntakalauha": ['mw'],
    "viṣamajvarāṅkuśalauha": ['mw'],
    "viṣamaka": ['mw'],
    "viṣamakarman": ['mw'],
    "viṣamakarṇa": ['mw'],
    "viṣamakhāta": ['mw'],
    "viṣamakriya": ['mw'],
    "viṣamakriyatva": ['mw'],
    "viṣamakāla": ['mw'],
    "viṣamalakṣmī": ['mw'],
    "viṣamam": ['mw'],
    "viṣamamaya": ['mw'],
    "viṣamanayana": ['mw'],
    "viṣamanetra": ['mw'],
    "viṣamantra": ['mw'],
    "viṣamapada": ['mw'],
    "viṣamapadavṛtti": ['mw'],
    "viṣamapalāśa": ['mw'],
    "viṣamapāda": ['mw'],
    "viṣamarca": ['mw'],
    "viṣamardanikā": ['mw'],
    "viṣamardanī": ['mw'],
    "viṣamardinī": ['mw'],
    "viṣamarāga": ['mw'],
    "viṣamarāgatā": ['mw'],
    "viṣamarūpya": ['mw'],
    "viṣamaspṛhā": ['mw'],
    "viṣamastha": ['cae', 'mw'],
    "viṣamasthita": ['cae'],
    "viṣamasāhasa": ['mw'],
    "viṣamatribhuja": ['mw'],
    "viṣamatva": ['cae', 'mw'],
    "viṣamatā": ['bhs'],
    "viṣamavibhāga": ['mw'],
    "viṣamavilocana": ['mw'],
    "viṣamaviśikha": ['mw'],
    "viṣamavyākhyā": ['mw'],
    "viṣamavyāptika": ['mw'],
    "viṣamavṛtta": ['cae', 'mw'],
    "viṣamaya": ['cae', 'ddsa', 'mw'],
    "viṣamañjarī": ['mw'],
    "viṣamaśara": ['ddsa', 'mw'],
    "viṣamaśiṣṭa": ['mw'],
    "viṣamaśiṣṭatva": ['mw'],
    "viṣamaślokavyākhyā": ['mw'],
    "viṣamaślokaṭīkā": ['mw'],
    "viṣamaśāyin": ['mw'],
    "viṣamaśīla": ['cae', 'mw'],
    "viṣamekṣaṇa": ['ddsa', 'mw'],
    "viṣameṇa": ['mw'],
    "viṣameṣu": ['cae', 'mw'],
    "viṣamita": ['ap90', 'ddsa', 'mw'],
    "viṣamonnata": ['mw'],
    "viṣamopala": ['mw'],
    "viṣamuc": ['ddsa', 'mw'],
    "viṣamuṣṭi": ['mw'],
    "viṣamuṣṭika": ['mw'],
    "viṣamāditya": ['mw'],
    "viṣamākṣa": ['mw'],
    "viṣamānna": ['mw'],
    "viṣamārthadīpikā": ['mw'],
    "viṣamāvatāra": ['mw'],
    "viṣamāya": ['ddsa', 'mw'],
    "viṣamāyudha": ['cae', 'ddsa', 'mw'],
    "viṣamāśana": ['mw'],
    "viṣamāśaya": ['mw'],
    "viṣamī": ['mw'],
    "viṣamībhāva": ['mw'],
    "viṣamībhū": ['ap90', 'mw'],
    "viṣamīkṛ": ['cae', 'mw'],
    "viṣamīya": ['mw'],
    "viṣamṛtyu": ['mw'],
    "viṣanimitta": ['mw'],
    "viṣanud": ['mw'],
    "viṣanāśaka": ['mw'],
    "viṣanāśana": ['mw'],
    "viṣanāśin": ['mw'],
    "viṣanāśinī": ['mw'],
    "viṣanāḍī": ['mw'],
    "viṣanāḍījananaśānti": ['mw'],
    "viṣapannaga": ['mw'],
    "viṣaparvan": ['mw'],
    "viṣaparṇī": ['mw'],
    "viṣapattrikā": ['mw'],
    "viṣapradigdha": ['mw'],
    "viṣaprastha": ['mw'],
    "viṣaprayoga": ['mw'],
    "viṣapuccha": ['mw'],
    "viṣapuṣpa": ['mw'],
    "viṣapuṣpaka": ['mw'],
    "viṣapuṭa": ['mw'],
    "viṣapādapa": ['mw'],
    "viṣapīta": ['mw'],
    "viṣarasa": ['cae', 'ddsa', 'mw'],
    "viṣaroga": ['mw'],
    "viṣarūpā": ['mw'],
    "viṣasaṃyoga": ['mw'],
    "viṣasecana": ['mw'],
    "viṣasūcaka": ['mw'],
    "viṣasṛkvan": ['mw'],
    "viṣatantra": ['mw'],
    "viṣataru": ['cae', 'ddsa', 'mw'],
    "viṣatindu": ['mw'],
    "viṣatinduka": ['mw'],
    "viṣatulya": ['mw'],
    "viṣatva": ['mw'],
    "viṣatvara": ['mw'],
    "viṣatā": ['cae', 'mw'],
    "viṣauṣadhī": ['mw'],
    "viṣavaidya": ['cae', 'mw'],
    "viṣavairiṇī": ['mw'],
    "viṣavallarī": ['mw'],
    "viṣavalli": ['mw'],
    "viṣavallī": ['mw'],
    "viṣavant": ['cae'],
    "viṣavat": ['gra', 'mw'],
    "viṣavega": ['cae', 'mw'],
    "viṣavidhāna": ['mw'],
    "viṣavidyā": ['cae', 'mw'],
    "viṣavimuktātman": ['mw'],
    "viṣaviṭapin": ['cae', 'mw'],
    "viṣavyavasthā": ['mw'],
    "viṣavṛkṣa": ['cae', 'mw'],
    "viṣavṛkṣanyāya": ['mw'],
    "viṣaya": ['bhs', 'cae', 'ddsa', 'mw'],
    "viṣayacandrikā": ['mw'],
    "viṣayagrāma": ['mw'],
    "viṣayaiṣin": ['mw'],
    "viṣayajña": ['mw'],
    "viṣayajñāna": ['mw'],
    "viṣayaka": ['ap90', 'ddsa', 'mw'],
    "viṣayakarman": ['mw'],
    "viṣayakatva": ['mw'],
    "viṣayakāma": ['mw'],
    "viṣayalaukikapratyakṣakāryakāraṇabhāvarahasya": ['mw'],
    "viṣayalolupa": ['mw'],
    "viṣayanihnuti": ['mw'],
    "viṣayanirati": ['mw'],
    "viṣayaparāṅmukha": ['cae', 'mw'],
    "viṣayapathaka": ['mw'],
    "viṣayapati": ['mw'],
    "viṣayaprasaṅga": ['mw'],
    "viṣayapratyabhijñāna": ['mw'],
    "viṣayapravaṇa": ['mw'],
    "viṣayasaptamī": ['mw'],
    "viṣayasaṅga": ['cae', 'mw'],
    "viṣayasaṅgaja": ['mw'],
    "viṣayasneha": ['mw'],
    "viṣayaspṛhā": ['mw'],
    "viṣayasukha": ['mw'],
    "viṣayatva": ['mw'],
    "viṣayatā": ['mw'],
    "viṣayatārahasya": ['mw'],
    "viṣayatāvāda": ['mw'],
    "viṣayatāvādaṭippaṇa": ['mw'],
    "viṣayatāvādārtha": ['mw'],
    "viṣayatīrṇa": ['bhs'],
    "viṣayavant": ['cae'],
    "viṣayavartin": ['mw'],
    "viṣayavat": ['mw'],
    "viṣayavicāra": ['mw'],
    "viṣayaviṣayin": ['mw'],
    "viṣayavāda": ['mw'],
    "viṣayavākyadīpikā": ['mw'],
    "viṣayavākyasaṃgraha": ['mw'],
    "viṣayavāsin": ['cae', 'mw'],
    "viṣayaḥ": ['ap90'],
    "viṣayika": ['mw'],
    "viṣayin": ['ap90', 'cae', 'ddsa', 'mw'],
    "viṣayitva": ['mw'],
    "viṣayoparama": ['mw'],
    "viṣayopasevā": ['cae', 'mw'],
    "viṣayābhilāṣa": ['mw'],
    "viṣayābhimukhīkṛti": ['mw'],
    "viṣayābhirati": ['mw'],
    "viṣayādhikṛta": ['mw'],
    "viṣayādhipati": ['mw'],
    "viṣayājñāna": ['mw'],
    "viṣayānanda": ['mw'],
    "viṣayānantara": ['mw'],
    "viṣayānta": ['cae', 'mw'],
    "viṣayārha": ['mw'],
    "viṣayāsakta": ['mw'],
    "viṣayāsaktamanas": ['mw'],
    "viṣayāsakti": ['mw'],
    "viṣayāsiddhadīpikā": ['mw'],
    "viṣayātmaka": ['cae', 'mw'],
    "viṣayāyin": ['ap90', 'mw'],
    "viṣayī": ['mw'],
    "viṣayībhū": ['mw'],
    "viṣayībhūta": ['mw'],
    "viṣayīkaraṇa": ['cae', 'ddsa', 'mw'],
    "viṣayīkṛ": ['cae', 'mw'],
    "viṣayīkṛta": ['mw'],
    "viṣayīya": ['mw'],
    "viṣañj": ['mw'],
    "viṣaśālūka": ['mw'],
    "viṣaśūka": ['mw'],
    "viṣaśṛṅgin": ['mw'],
    "viṣaṃ": ['ap90'],
    "viṣaṃj": ['ap90'],
    "viṣaṃḍaṃ": ['ap90'],
    "viṣaṅga": ['cae', 'mw'],
    "viṣaṅgin": ['ddsa', 'mw'],
    "viṣaṇa": ['ddsa'],
    "viṣaṇi": ['mw'],
    "viṣaṇḍa": ['mw'],
    "viṣaṇṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "viṣaṇṇabhāva": ['mw'],
    "viṣaṇṇacetas": ['mw'],
    "viṣaṇṇamanas": ['mw'],
    "viṣaṇṇamukha": ['mw'],
    "viṣaṇṇarūpa": ['cae', 'mw'],
    "viṣaṇṇatva": ['mw'],
    "viṣaṇṇatā": ['mw'],
    "viṣaṇṇavadana": ['cae', 'mw'],
    "viṣaṇṇātman": ['mw'],
    "viṣaṭa": ['bhs'],
    "viṣev": ['mw'],
    "viṣic": ['mw'],
    "viṣikta": ['mw'],
    "viṣin": ['cae', 'mw'],
    "viṣita": ['cae', 'ddsa', 'mw'],
    "viṣitastuka": ['cae', 'gra', 'mw'],
    "viṣitastupa": ['mw'],
    "viṣiv": ['mw'],
    "viṣk": ['ap90', 'mw'],
    "viṣka": ['ddsa', 'mw'],
    "viṣkabdha": ['mw'],
    "viṣkabhita": ['mw'],
    "viṣkadya": ['bhs'],
    "viṣkambh": ['mw'],
    "viṣkambha": ['cae', 'ddsa', 'mw'],
    "viṣkambhaka": ['cae', 'mw'],
    "viṣkambhakakāṣṭha": ['mw'],
    "viṣkambhaparvata": ['mw'],
    "viṣkambhate": ['bhs'],
    "viṣkambhavat": ['mw'],
    "viṣkambhaṇa": ['bhs', 'mw'],
    "viṣkambhikā": ['mw'],
    "viṣkambhin": ['bhs', 'mw'],
    "viṣkambhita": ['bhs', 'mw'],
    "viṣkambhārdha": ['mw'],
    "viṣkanda": ['mw'],
    "viṣkandha": ['cae', 'mw'],
    "viṣkandhadūṣaṇa": ['mw'],
    "viṣkanttṛ": ['mw'],
    "viṣkara": ['mw'],
    "viṣkaṃbh": ['ap90'],
    "viṣkaṃbhaka": ['ap90'],
    "viṣkaṃbhaḥ": ['ap90'],
    "viṣkaṃbhin": ['ap90'],
    "viṣkaṃbhita": ['ap90'],
    "viṣkaṃd": ['ap90'],
    "viṣkaṃdaḥ": ['ap90'],
    "viṣkira": ['cae', 'ddsa', 'mw'],
    "viṣkirarasa": ['mw'],
    "viṣkiraḥ": ['ap90'],
    "viṣkumbh": ['mw'],
    "viṣo": ['mw'],
    "viṣoddhāra": ['mw'],
    "viṣolbaṇa": ['cae', 'mw'],
    "viṣpanda": ['mw'],
    "viṣpardhas": ['cae', 'gra', 'mw'],
    "viṣpardhā": ['mw'],
    "viṣpaś": ['cae', 'ddsa', 'gra', 'mw'],
    "viṣpaṃd": ['ap90'],
    "viṣpaṃdaḥ": ['ap90'],
    "viṣphar": ['mw'],
    "viṣphuliṅga": ['cae', 'ddsa', 'gra', 'mw'],
    "viṣphuliṅgaka": ['mw'],
    "viṣphur": ['mw'],
    "viṣphāla": ['mw'],
    "viṣphāraḥ": ['ap90'],
    "viṣpita": ['ddsa', 'gra', 'mw'],
    "viṣpuliṅgaka": ['gra', 'mw'],
    "viṣpṛ": ['mw'],
    "viṣu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "viṣudruh": ['gra', 'mw'],
    "viṣudruha": ['mw'],
    "viṣupa": ['mw'],
    "viṣupada": ['mw'],
    "viṣupaṃ": ['ap90'],
    "viṣupta": ['cae', 'mw'],
    "viṣurūpa": ['cae', 'ddsa', 'gra', 'mw'],
    "viṣuva": ['ddsa', 'mw'],
    "viṣuvacchāyā": ['mw'],
    "viṣuvad": ['mw'],
    "viṣuvadbhā": ['mw'],
    "viṣuvaddeśa": ['mw'],
    "viṣuvaddina": ['mw'],
    "viṣuvaddivasa": ['mw'],
    "viṣuvadina": ['mw'],
    "viṣuvadvalaya": ['mw'],
    "viṣuvadvṛtta": ['mw'],
    "viṣuvan": ['mw'],
    "viṣuvanmaṇḍala": ['mw'],
    "viṣuvant": ['cae'],
    "viṣuvarekhā": ['mw'],
    "viṣuvasamaya": ['mw'],
    "viṣuvasaṃkrānti": ['mw'],
    "viṣuvat": ['ap90', 'ddsa', 'mw'],
    "viṣuvatka": ['mw'],
    "viṣuvatprabhā": ['mw'],
    "viṣuvatpūrṇaśitāṃśu": ['mw'],
    "viṣuvatsaṃkrānti": ['cae', 'mw'],
    "viṣuvatstoma": ['mw'],
    "viṣuvaṃ": ['ap90'],
    "viṣuṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "viṣuṇak": ['cae', 'gra', 'mw'],
    "viṣuṇe": ['mw'],
    "viṣva": ['ap90', 'gra', 'mw'],
    "viṣvac": ['ap90', 'gra'],
    "viṣvadriac": ['gra'],
    "viṣvadryac": ['ap90', 'gra'],
    "viṣvadryak": ['mw'],
    "viṣvadryañc": ['cae', 'ddsa', 'mw'],
    "viṣvadryaṃc": ['ap90'],
    "viṣvadrīcīna": ['mw'],
    "viṣvag": ['mw'],
    "viṣvagaiḍa": ['mw'],
    "viṣvagavekṣaṇa": ['mw'],
    "viṣvagañcana": ['mw'],
    "viṣvagaśva": ['mw'],
    "viṣvaggamanavant": ['cae'],
    "viṣvaggamanavat": ['mw'],
    "viṣvaggata": ['mw'],
    "viṣvaggati": ['mw'],
    "viṣvagjyotis": ['mw'],
    "viṣvaglopa": ['mw'],
    "viṣvagviluptacchada": ['mw'],
    "viṣvagvāta": ['mw'],
    "viṣvagvāyu": ['mw'],
    "viṣvagvṛta": ['mw'],
    "viṣvagvṛtti": ['cae'],
    "viṣvagyuj": ['mw'],
    "viṣvagāyat": ['mw'],
    "viṣvak": ['ddsa', 'mw'],
    "viṣvakkaca": ['mw'],
    "viṣvaksama": ['mw'],
    "viṣvaksena": ['cae', 'mw'],
    "viṣvaksenakāntā": ['mw'],
    "viṣvaksenapriyā": ['mw'],
    "viṣvaksenasaṃhitā": ['mw'],
    "viṣvaksenā": ['mw'],
    "viṣvaktana": ['cae'],
    "viṣvam": ['mw'],
    "viṣvan": ['mw'],
    "viṣvañc": ['cae', 'ddsa', 'mw'],
    "viṣvañj": ['mw'],
    "viṣvaṇa": ['mw'],
    "viṣvaṇana": ['mw'],
    "viṣvaṇanaṃ": ['ap90'],
    "viṣvāc": ['gra', 'mw'],
    "viṣvāṇa": ['mw'],
    "viṣya": ['ap90', 'mw'],
    "viṣyand": ['mw'],
    "viṣyanda": ['cae', 'mw'],
    "viṣyandaka": ['mw'],
    "viṣyandana": ['cae', 'ddsa', 'mw'],
    "viṣyandin": ['mw'],
    "viṣyaṃd": ['ap90'],
    "viṣyaṃdaḥ": ['ap90'],
    "viṣyaṇṇa": ['cae', 'mw'],
    "viṣā": ['ap90', 'mw'],
    "viṣābhāvā": ['mw'],
    "viṣād": ['cae', 'mw'],
    "viṣāda": ['cae', 'ddsa', 'mw'],
    "viṣādajanaka": ['mw'],
    "viṣādakṛt": ['mw'],
    "viṣādana": ['cae', 'mw'],
    "viṣādanī": ['mw'],
    "viṣādavant": ['cae'],
    "viṣādavat": ['mw'],
    "viṣādaḥ": ['ap90'],
    "viṣādin": ['ap90', 'cae', 'ddsa', 'mw'],
    "viṣādita": ['mw'],
    "viṣāditva": ['mw'],
    "viṣāditā": ['mw'],
    "viṣādārtavadana": ['mw'],
    "viṣāgni": ['cae', 'ddsa', 'mw'],
    "viṣāgnipa": ['mw'],
    "viṣāgraja": ['mw'],
    "viṣākta": ['cae', 'mw'],
    "viṣālu": ['ap90', 'mw'],
    "viṣāmṛta": ['mw'],
    "viṣāmṛtamaya": ['mw'],
    "viṣānala": ['cae', 'mw'],
    "viṣānana": ['mw'],
    "viṣānna": ['cae', 'mw'],
    "viṣāntaka": ['mw'],
    "viṣāpaha": ['cae', 'mw'],
    "viṣāpaharaṇa": ['mw'],
    "viṣāpahā": ['mw'],
    "viṣāpahāra": ['mw'],
    "viṣāpahāradaṇḍa": ['mw'],
    "viṣāpahārastotra": ['mw'],
    "viṣāpavādin": ['mw'],
    "viṣāpavādinī": ['mw'],
    "viṣāra": ['mw'],
    "viṣāraḥ": ['ap90'],
    "viṣāri": ['mw'],
    "viṣārāti": ['mw'],
    "viṣāsahi": ['cae', 'gra', 'mw'],
    "viṣāsahivrata": ['mw'],
    "viṣāstra": ['mw'],
    "viṣāsvāda": ['cae', 'ddsa', 'mw'],
    "viṣāsya": ['mw'],
    "viṣāsyā": ['mw'],
    "viṣātakī": ['mw'],
    "viṣāy": ['cae'],
    "viṣāya": ['ddsa', 'mw'],
    "viṣāyin": ['mw'],
    "viṣāyudha": ['mw'],
    "viṣāyudhīya": ['mw'],
    "viṣāṅganā": ['mw'],
    "viṣāṅkura": ['mw'],
    "viṣāṇa": ['cae', 'ddsa', 'mw'],
    "viṣāṇabhūta": ['mw'],
    "viṣāṇaka": ['mw'],
    "viṣāṇakośa": ['mw'],
    "viṣāṇakā": ['mw'],
    "viṣāṇavant": ['cae'],
    "viṣāṇavat": ['mw'],
    "viṣāṇaḥ": ['ap90'],
    "viṣāṇikā": ['mw'],
    "viṣāṇin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "viṣāṇitva": ['mw'],
    "viṣāṇollikhitaskandha": ['mw'],
    "viṣāṇonnāmitaskandha": ['mw'],
    "viṣāṇā": ['ddsa'],
    "viṣāṇānta": ['mw'],
    "viṣāṇī": ['mw'],
    "viṣībhū": ['ddsa'],
    "viṣībhūta": ['mw'],
    "viṣū": ['mw'],
    "viṣūcaka": ['mw'],
    "viṣūci": ['mw'],
    "viṣūcikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "viṣūcita": ['bhs'],
    "viṣūcī": ['cae', 'ddsa', 'mw'],
    "viṣūcīna": ['cae', 'ddsa', 'gra', 'mw'],
    "viṣūcīnakaraṇa": ['mw'],
    "viṣūcīnāgra": ['mw'],
    "viṣūkuh": ['mw'],
    "viṣūvant": ['cae'],
    "viṣūvat": ['gra', 'mw'],
    "viṣūvṛt": ['cae', 'gra', 'mw'],
    "viṣṇa": ['mw'],
    "viṣṇu": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "viṣṇubha": ['mw'],
    "viṣṇubhakta": ['mw'],
    "viṣṇubhaktalakṣaṇa": ['mw'],
    "viṣṇubhakti": ['mw'],
    "viṣṇubhakticandrodaya": ['mw'],
    "viṣṇubhaktikalpalatā": ['mw'],
    "viṣṇubhaktilatā": ['mw'],
    "viṣṇubhaktimāhātmya": ['mw'],
    "viṣṇubhaktiprabandha": ['mw'],
    "viṣṇubhaktirahasya": ['mw'],
    "viṣṇubhaktistuti": ['mw'],
    "viṣṇubhujaṃga": ['mw'],
    "viṣṇubhujaṃgastotra": ['mw'],
    "viṣṇubhujaṃgī": ['mw'],
    "viṣṇubhāgavatapurāṇa": ['mw'],
    "viṣṇubrahmamaheśvaradānaprayoga": ['mw'],
    "viṣṇucakra": ['cae', 'mw'],
    "viṣṇucandra": ['mw'],
    "viṣṇucitta": ['mw'],
    "viṣṇucittīya": ['mw'],
    "viṣṇudaivata": ['mw'],
    "viṣṇudaivatya": ['mw'],
    "viṣṇudaivatyā": ['mw'],
    "viṣṇudatta": ['cae', 'mw'],
    "viṣṇudattaka": ['mw'],
    "viṣṇudattāgnihotrin": ['mw'],
    "viṣṇudeva": ['mw'],
    "viṣṇudevatya": ['mw'],
    "viṣṇudevārādhya": ['mw'],
    "viṣṇudharma": ['mw'],
    "viṣṇudharmamīmāṃsā": ['mw'],
    "viṣṇudharman": ['mw'],
    "viṣṇudharmottara": ['mw'],
    "viṣṇudhyānastotrādi": ['mw'],
    "viṣṇudhārā": ['mw'],
    "viṣṇudviṣ": ['mw'],
    "viṣṇudvādaśanāmastotra": ['mw'],
    "viṣṇudvīpa": ['bhs', 'mw'],
    "viṣṇudāsa": ['mw'],
    "viṣṇugaṅgā": ['mw'],
    "viṣṇugola": ['mw'],
    "viṣṇugopavarman": ['mw'],
    "viṣṇugranthi": ['mw'],
    "viṣṇugupta": ['cae', 'mw'],
    "viṣṇuguptaka": ['mw'],
    "viṣṇuguptasiddhānta": ['mw'],
    "viṣṇugāthā": ['mw'],
    "viṣṇugāyatrī": ['mw'],
    "viṣṇugūḍha": ['mw'],
    "viṣṇugūḍhasvāmin": ['mw'],
    "viṣṇugūḍhārtha": ['mw'],
    "viṣṇugṛha": ['mw'],
    "viṣṇuhari": ['mw'],
    "viṣṇuhitā": ['mw'],
    "viṣṇuhāradeva": ['mw'],
    "viṣṇuhṛdaya": ['mw'],
    "viṣṇuhṛdayastotra": ['mw'],
    "viṣṇuja": ['mw'],
    "viṣṇujāmala": ['mw'],
    "viṣṇujāmātṛ": ['mw'],
    "viṣṇukanda": ['mw'],
    "viṣṇukaraṇa": ['mw'],
    "viṣṇukavaca": ['mw'],
    "viṣṇukośala": ['mw'],
    "viṣṇukrama": ['cae', 'ddsa', 'mw'],
    "viṣṇukramīya": ['mw'],
    "viṣṇukrānta": ['mw'],
    "viṣṇukrānti": ['mw'],
    "viṣṇukrāntā": ['mw'],
    "viṣṇukutūhala": ['mw'],
    "viṣṇukāntī": ['mw'],
    "viṣṇukāntītīrtha": ['mw'],
    "viṣṇukāñcī": ['mw'],
    "viṣṇukṣetra": ['mw'],
    "viṣṇulaharī": ['mw'],
    "viṣṇuliṅgī": ['mw'],
    "viṣṇuloka": ['mw'],
    "viṣṇulā": ['bhs'],
    "viṣṇumahiman": ['mw'],
    "viṣṇumahimnaḥstava": ['mw'],
    "viṣṇumandira": ['mw'],
    "viṣṇumantra": ['mw'],
    "viṣṇumantravidhānādi": ['mw'],
    "viṣṇumantraviśeṣa": ['mw'],
    "viṣṇumat": ['mw'],
    "viṣṇumatī": ['mw'],
    "viṣṇumaya": ['cae', 'mw'],
    "viṣṇumitra": ['cae', 'mw'],
    "viṣṇumukha": ['cae', 'mw'],
    "viṣṇumāhātmya": ['mw'],
    "viṣṇumāhātmyapaddhati": ['mw'],
    "viṣṇumānasa": ['mw'],
    "viṣṇumāyā": ['mw'],
    "viṣṇunadī": ['mw'],
    "viṣṇunyaṅga": ['mw'],
    "viṣṇunāmamāhātmyasaṃgraha": ['mw'],
    "viṣṇunāmaratnastotra": ['mw'],
    "viṣṇunīrājana": ['mw'],
    "viṣṇupada": ['cae', 'mw'],
    "viṣṇupadagiri": ['mw'],
    "viṣṇupadatīrtha": ['mw'],
    "viṣṇupadaśrāddha": ['mw'],
    "viṣṇupaddhati": ['mw'],
    "viṣṇupadyutpatti": ['mw'],
    "viṣṇupadī": ['mw'],
    "viṣṇupadīcakra": ['mw'],
    "viṣṇuparāyaṇa": ['mw'],
    "viṣṇuparṇikā": ['mw'],
    "viṣṇupati": ['mw'],
    "viṣṇupatnī": ['cae', 'mw'],
    "viṣṇupañcaka": ['mw'],
    "viṣṇupañcakavratakathā": ['mw'],
    "viṣṇupañjara": ['mw'],
    "viṣṇupañjarastotra": ['mw'],
    "viṣṇupañjarayantravidhi": ['mw'],
    "viṣṇupratimāsamprokṣaṇavidhi": ['mw'],
    "viṣṇupratiṣṭhā": ['mw'],
    "viṣṇupratiṣṭhāpaddhati": ['mw'],
    "viṣṇupriyā": ['mw'],
    "viṣṇuprīti": ['mw'],
    "viṣṇuprītivāda": ['mw'],
    "viṣṇupur": ['mw'],
    "viṣṇupura": ['mw'],
    "viṣṇupurāṇa": ['cae', 'mw'],
    "viṣṇupurāṇaka": ['mw'],
    "viṣṇupurī": ['mw'],
    "viṣṇuputra": ['mw'],
    "viṣṇupādādikeśāntastuti": ['mw'],
    "viṣṇupūjana": ['mw'],
    "viṣṇupūjā": ['mw'],
    "viṣṇupūjādīpikā": ['mw'],
    "viṣṇupūjākrama": ['mw'],
    "viṣṇupūjāmantra": ['mw'],
    "viṣṇupūjāpaddhati": ['mw'],
    "viṣṇupūjāvidhi": ['mw'],
    "viṣṇupūjāvidhāna": ['mw'],
    "viṣṇurahasya": ['mw'],
    "viṣṇuratha": ['mw'],
    "viṣṇurāja": ['mw'],
    "viṣṇurāma": ['mw'],
    "viṣṇurāmasiddhāntavāgīśa": ['mw'],
    "viṣṇurāta": ['mw'],
    "viṣṇurūpa": ['cae'],
    "viṣṇusahasranāmabhāṣya": ['mw'],
    "viṣṇusahasranāmakathana": ['mw'],
    "viṣṇusahasranāman": ['mw'],
    "viṣṇusahasranāmastotra": ['mw'],
    "viṣṇusamuccaya": ['mw'],
    "viṣṇusaras": ['mw'],
    "viṣṇusarastīrtha": ['mw'],
    "viṣṇusarvajana": ['mw'],
    "viṣṇusarvajña": ['mw'],
    "viṣṇusaṃhitā": ['mw'],
    "viṣṇusiddhānta": ['mw'],
    "viṣṇusiddhāntalīlāvatī": ['mw'],
    "viṣṇusiṃha": ['mw'],
    "viṣṇusmṛti": ['mw'],
    "viṣṇustava": ['mw'],
    "viṣṇustavarāja": ['mw'],
    "viṣṇustotra": ['mw'],
    "viṣṇustuti": ['mw'],
    "viṣṇusvarūpadhyānādivarṇana": ['mw'],
    "viṣṇusvāmin": ['mw'],
    "viṣṇusūkta": ['mw'],
    "viṣṇusūtra": ['mw'],
    "viṣṇutaila": ['mw'],
    "viṣṇutantra": ['mw'],
    "viṣṇutarpaṇa": ['mw'],
    "viṣṇutarpaṇavidhi": ['mw'],
    "viṣṇutattva": ['mw'],
    "viṣṇutattvanirṇaya": ['mw'],
    "viṣṇutattvarahasya": ['mw'],
    "viṣṇutattvarahasyakhaṇḍana": ['mw'],
    "viṣṇutattvasaṃhitā": ['mw'],
    "viṣṇutithi": ['mw'],
    "viṣṇutoṣiṇī": ['mw'],
    "viṣṇutriśatī": ['mw'],
    "viṣṇutulyaparākrama": ['mw'],
    "viṣṇutva": ['mw'],
    "viṣṇutātparyanirṇaya": ['mw'],
    "viṣṇutīrtha": ['mw'],
    "viṣṇutīrthīyavyākhyāna": ['mw'],
    "viṣṇuvallabha": ['mw'],
    "viṣṇuvallabhā": ['mw'],
    "viṣṇuvant": ['cae'],
    "viṣṇuvardhana": ['mw'],
    "viṣṇuvarman": ['mw'],
    "viṣṇuvarṇanadhyānādi": ['mw'],
    "viṣṇuvat": ['gra', 'mw'],
    "viṣṇuvigrahaśaṃsanastotra": ['mw'],
    "viṣṇuvijaya": ['mw'],
    "viṣṇuvratakalpa": ['mw'],
    "viṣṇuvāhana": ['mw'],
    "viṣṇuvāhya": ['mw'],
    "viṣṇuvṛddha": ['mw'],
    "viṣṇuvṛddhasahasranāmastotra": ['mw'],
    "viṣṇuyantraprakaraṇa": ['mw'],
    "viṣṇuyaśas": ['mw'],
    "viṣṇuyāga": ['mw'],
    "viṣṇuyāgaprayoga": ['mw'],
    "viṣṇuyāmala": ['mw'],
    "viṣṇuyāmalatantra": ['mw'],
    "viṣṇuyāmila": ['mw'],
    "viṣṇuśakti": ['mw'],
    "viṣṇuśarmadīkṣita": ['mw'],
    "viṣṇuśarmamiśra": ['mw'],
    "viṣṇuśarman": ['cae', 'mw'],
    "viṣṇuśatanāmastotra": ['mw'],
    "viṣṇuśayanabodhadina": ['mw'],
    "viṣṇuśilā": ['mw'],
    "viṣṇuśruta": ['mw'],
    "viṣṇuśrāddha": ['mw'],
    "viṣṇuśrāddhapaddhati": ['mw'],
    "viṣṇuśṛṅkhala": ['mw'],
    "viṣṇuḥ": ['ap90'],
    "viṣṇuṛkṣa": ['mw'],
    "viṣṇuṣaṭpadī": ['mw'],
    "viṣṇv": ['mw'],
    "viṣṇvanusthita": ['mw'],
    "viṣṇvanuṣṭhita": ['mw'],
    "viṣṇvatikrama": ['mw'],
    "viṣṇvavatāra": ['mw'],
    "viṣṇvaṅgiras": ['mw'],
    "viṣṇvaṣṭottaraśatanāman": ['mw'],
    "viṣṇvādidevatāpūjāprakāra": ['mw'],
    "viṣṇvāvaraṇapūjā": ['mw'],
    "viṣṇāpū": ['gra', 'mw'],
    "viṣṇūpādhyāya": ['mw'],
    "viṣṇūtsava": ['mw'],
    "viṣṇūttara": ['mw'],
    "viṣṇūvaruṇa": ['mw'],
    "viṣṇūya": ['mw'],
    "viṣṭ": ['cae', 'ddsa', 'gra', 'mw'],
    "viṣṭa": ['cae', 'ddsa', 'mw'],
    "viṣṭaanta": ['gra'],
    "viṣṭabdha": ['ap90', 'cae', 'mw'],
    "viṣṭabdhacaraṇa": ['mw'],
    "viṣṭabdhagātra": ['mw'],
    "viṣṭabdhatā": ['mw'],
    "viṣṭabdhi": ['mw'],
    "viṣṭabdhājīrṇa": ['mw'],
    "viṣṭabdhākṣa": ['mw'],
    "viṣṭabha": ['mw'],
    "viṣṭabhita": ['mw'],
    "viṣṭakarṇa": ['mw'],
    "viṣṭambh": ['mw'],
    "viṣṭambha": ['cae', 'ddsa', 'gra', 'mw'],
    "viṣṭambhakara": ['mw'],
    "viṣṭambhana": ['cae', 'mw'],
    "viṣṭambhayiṣu": ['mw'],
    "viṣṭambhin": ['cae', 'mw'],
    "viṣṭambhita": ['mw'],
    "viṣṭan": ['mw'],
    "viṣṭap": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "viṣṭapa": ['ddsa', 'gra', 'mw'],
    "viṣṭapahārin": ['mw'],
    "viṣṭapatraya": ['mw'],
    "viṣṭapaḥ": ['ap90'],
    "viṣṭape": ['mw'],
    "viṣṭapura": ['mw'],
    "viṣṭara": ['cae', 'ddsa', 'mw'],
    "viṣṭarabhāj": ['mw'],
    "viṣṭarastha": ['mw'],
    "viṣṭaraśrava": ['mw'],
    "viṣṭaraśravas": ['mw'],
    "viṣṭaraḥ": ['ap90'],
    "viṣṭarottara": ['mw'],
    "viṣṭarāśva": ['mw'],
    "viṣṭatva": ['ddsa', 'mw'],
    "viṣṭaṃbh": ['ap90'],
    "viṣṭaṃbhaḥ": ['ap90'],
    "viṣṭaṃbhin": ['ap90'],
    "viṣṭhala": ['mw'],
    "viṣṭhalaṃ": ['ap90'],
    "viṣṭhapana": ['bhs'],
    "viṣṭhihati": ['bhs'],
    "viṣṭhita": ['cae', 'ddsa', 'mw'],
    "viṣṭhā": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "viṣṭhābhū": ['mw'],
    "viṣṭhābhūdāraka": ['mw'],
    "viṣṭhākaraṇa": ['mw'],
    "viṣṭhāsāt": ['mw'],
    "viṣṭhāvrājin": ['mw'],
    "viṣṭi": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "viṣṭibhis": ['mw'],
    "viṣṭikara": ['mw'],
    "viṣṭikṛt": ['mw'],
    "viṣṭir": ['cae', 'gra', 'mw'],
    "viṣṭiḥ": ['ap90'],
    "viṣṭu": ['mw'],
    "viṣṭubh": ['mw'],
    "viṣṭuta": ['cae', 'mw'],
    "viṣṭuti": ['cae', 'mw'],
    "viṣṭā": ['ap90', 'mw'],
    "viṣṭānta": ['gra'],
    "viṣṭāra": ['cae', 'ddsa', 'gra', 'mw'],
    "viṣṭārabṛhatī": ['mw'],
    "viṣṭārapaṅkti": ['cae', 'mw'],
    "viṣṭārin": ['cae', 'mw'],
    "viṣṭāva": ['mw'],
    "viṣṭī": ['mw'],
    "viṣṭīmin": ['mw'],
    "viṭ": ['ap90', 'mw'],
    "viṭa": ['cae', 'ddsa', 'mw'],
    "viṭabhūta": ['mw'],
    "viṭaka": ['mw'],
    "viṭakā": ['mw'],
    "viṭakāntā": ['mw'],
    "viṭalavaṇa": ['mw'],
    "viṭamākṣika": ['mw'],
    "viṭapa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "viṭapaka": ['mw'],
    "viṭapaśas": ['mw'],
    "viṭapaḥ": ['ap90'],
    "viṭapeṭaka": ['mw'],
    "viṭapimṛga": ['mw'],
    "viṭapin": ['ap90', 'cae', 'ddsa', 'mw'],
    "viṭapriya": ['mw'],
    "viṭaputra": ['mw'],
    "viṭapī": ['cped'],
    "viṭavallabhā": ['mw'],
    "viṭavṛtta": ['mw'],
    "viṭaḥ": ['ap90'],
    "viṭaṃkaka": ['ap90'],
    "viṭaṃkaḥ": ['ap90'],
    "viṭaṃkita": ['ap90'],
    "viṭaṅka": ['cae', 'cped', 'ddsa', 'mw'],
    "viṭaṅkapura": ['mw'],
    "viṭaṅkita": ['cae', 'mw'],
    "viṭcara": ['mw'],
    "viṭhala": ['mw'],
    "viṭhapana": ['bhs'],
    "viṭhapayati": ['bhs'],
    "viṭhara": ['mw'],
    "viṭharaḥ": ['ap90'],
    "viṭhaṃka": ['ap90'],
    "viṭhaṅka": ['mw'],
    "viṭhobā": ['mw'],
    "viṭhṭhalaḥ": ['ap90'],
    "viṭi": ['mw'],
    "viṭikaṇṭhīrava": ['mw'],
    "viṭiḥ": ['ap90'],
    "viṭka": ['mw'],
    "viṭkhadira": ['mw'],
    "viṭkula": ['ddsa', 'mw'],
    "viṭkārikā": ['mw'],
    "viṭkṛmi": ['mw'],
    "viṭpati": ['cae', 'mw'],
    "viṭpaṇya": ['cae', 'mw'],
    "viṭsaṅga": ['mw'],
    "viṭsārikā": ['mw'],
    "viṭsārī": ['mw'],
    "viṭāśraya": ['mw'],
    "viṭāṭikā": ['mw'],
    "viṭśūdra": ['mw'],
    "viṭśūla": ['mw'],
    "viṭṭhala": ['mw'],
    "viṭṭhalakavaca": ['mw'],
    "viṭṭhalamiśra": ['mw'],
    "viṭṭhalasahasranāman": ['mw'],
    "viṭṭhalastavarāja": ['mw'],
    "viṭṭhalasūnu": ['mw'],
    "viṭṭhalaḥ": ['ap90'],
    "viṭṭhaleśa": ['mw'],
    "viṭṭhaleśvara": ['mw'],
    "viṭṭhalopādhyāyapattra": ['mw'],
    "viṭṭhalācāryasūnu": ['mw'],
    "viṭṭhalāṣṭottaraśata": ['mw'],
    "viṭṭhalīpaddhati": ['mw'],
    "viṭṭāleti": ['bhs'],
    "vlag": ['cae', 'ddsa', 'gra', 'mw'],
    "vlekṣ": ['ap90', 'mw'],
    "vleṣka": ['cae', 'mw'],
    "vleṣkahata": ['mw'],
    "vlī": ['ap90', 'cae', 'ddsa', 'mw'],
    "vlīna": ['mw'],
    "vo": ['cped'],
    "voc": ['mw'],
    "voca": ['ddsa'],
    "vocchijjati": ['cped'],
    "vocchijji": ['cped'],
    "vocchijjitvā": ['cped'],
    "vocchinna": ['cped'],
    "voda": ['ap90', 'mw'],
    "vodaka": ['cped'],
    "vodapana": ['cped'],
    "vodapanā": ['cped'],
    "vodapesi": ['cped'],
    "vodapeti": ['cped'],
    "vodra": ['mw'],
    "vodāla": ['mw'],
    "vodālaḥ": ['ap90'],
    "vodāna": ['cped'],
    "voharanta": ['cped'],
    "voharati": ['cped'],
    "vohari": ['cped'],
    "voharita": ['cped'],
    "voharitvā": ['cped'],
    "vohariyamāna": ['cped'],
    "vohittha": ['mw'],
    "vohāra": ['cped'],
    "vohārika": ['cped'],
    "vohārikāmacca": ['cped'],
    "vokiṇṇa": ['cped'],
    "vokkamati": ['cped'],
    "vokkami": ['cped'],
    "vokkamitvā": ['cped'],
    "vokkamma": ['cped'],
    "vokkanta": ['cped'],
    "vokkanti": ['cped'],
    "vokkāṇa": ['bhs', 'mw'],
    "vokāra": ['cped'],
    "vola": ['mw'],
    "volaka": ['mw'],
    "volakaḥ": ['ap90'],
    "volaḥ": ['ap90'],
    "vollāha": ['mw'],
    "vollāhaḥ": ['ap90'],
    "vollāsaka": ['ddsa', 'mw'],
    "voloketi": ['cped'],
    "vol̤have": ['mw'],
    "vomissaka": ['cped'],
    "vonthādevī": ['mw'],
    "vopadeva": ['cae', 'ddsa', 'mw'],
    "vopadevaśataka": ['mw'],
    "vopasamati": ['bhs'],
    "vopula": ['mw'],
    "vopālita": ['mw'],
    "vopālitasiṃha": ['mw'],
    "vora": ['mw'],
    "voraka": ['mw'],
    "vorakaḥ": ['ap90'],
    "vorapaṭṭi": ['mw'],
    "vorasiddhi": ['mw'],
    "vorava": ['mw'],
    "voraṭa": ['mw'],
    "voraṭaḥ": ['ap90'],
    "voropana": ['cped'],
    "voropenta": ['cped'],
    "voropesi": ['cped'],
    "voropeti": ['cped'],
    "voropetvā": ['cped'],
    "voropita": ['cped'],
    "vorukhāna": ['mw'],
    "voruvāṇa": ['mw'],
    "vosita": ['cped'],
    "vossagga": ['cped'],
    "vossajana": ['cped'],
    "vossajati": ['cped'],
    "vossaji": ['cped'],
    "vossajitvā": ['cped'],
    "vossajja": ['cped'],
    "vossaṭṭha": ['cped'],
    "vosārayati": ['bhs'],
    "votthapana": ['cped'],
    "voḍa": ['mw'],
    "voḍha": ['ddsa', 'mw'],
    "voḍhave": ['mw'],
    "voḍhavya": ['cae', 'ddsa', 'mw'],
    "voḍhavyā": ['mw'],
    "voḍhu": ['mw'],
    "voḍhṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "voḍra": ['cae', 'mw'],
    "voḍraḥ": ['ap90'],
    "voḍrī": ['ap90', 'mw'],
    "voḷhum": ['ddsa'],
    "voṃṭaḥ": ['ap90'],
    "voṇṭa": ['bhs', 'mw'],
    "voṭā": ['mw'],
    "vra": ['mw'],
    "vrad": ['cae', 'ddsa', 'gra', 'mw'],
    "vradhna": ['ap90', 'mw'],
    "vrahman": ['ap90', 'mw'],
    "vraiha": ['mw'],
    "vraiheya": ['ap90', 'mw'],
    "vraihika": ['mw'],
    "vraihimatya": ['mw'],
    "vraj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vraja": ['cae', 'ddsa', 'gra', 'mw'],
    "vrajabhaktivilāsa": ['mw'],
    "vrajabhāṣā": ['mw'],
    "vrajabhū": ['mw'],
    "vrajabhūṣaṇa": ['mw'],
    "vrajabhūṣaṇakavi": ['mw'],
    "vrajabhūṣaṇamiśra": ['mw'],
    "vrajaka": ['mw'],
    "vrajakaḥ": ['ap90'],
    "vrajakiśora": ['mw'],
    "vrajakṣit": ['mw'],
    "vrajalāla": ['mw'],
    "vrajamaṇḍala": ['mw'],
    "vrajamohana": ['mw'],
    "vrajana": ['cae', 'gra', 'mw'],
    "vrajanavanāgaracandrikā": ['mw'],
    "vrajanaṃ": ['ap90'],
    "vrajanātha": ['cae', 'mw'],
    "vrajanāthabhaṭṭa": ['mw'],
    "vrajapaddhati": ['mw'],
    "vrajarāja": ['mw'],
    "vrajarājadīkṣita": ['mw'],
    "vrajarājagosvāmin": ['mw'],
    "vrajarājaśukla": ['mw'],
    "vrajarāmā": ['mw'],
    "vrajaspati": ['mw'],
    "vrajastrī": ['cae', 'mw'],
    "vrajasundarī": ['cae', 'ddsa', 'mw'],
    "vrajatattva": ['mw'],
    "vrajaukas": ['mw'],
    "vrajavadhū": ['mw'],
    "vrajavallabha": ['mw'],
    "vrajavanitā": ['mw'],
    "vrajavara": ['mw'],
    "vrajavihāra": ['mw'],
    "vrajavilāsa": ['mw'],
    "vrajavilāsastava": ['mw'],
    "vrajayuvati": ['mw'],
    "vrajaḥ": ['ap90'],
    "vrajendra": ['mw'],
    "vrajendracarita": ['mw'],
    "vrajeśvara": ['mw'],
    "vrajin": ['cae', 'gra', 'mw'],
    "vrajita": ['mw'],
    "vrajoparodham": ['mw'],
    "vrajya": ['cae', 'mw'],
    "vrajyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "vrajyāmālā": ['mw'],
    "vrajyāvat": ['mw'],
    "vrajājira": ['mw'],
    "vrajāvāsa": ['mw'],
    "vrajāṅgana": ['mw'],
    "vrajāṅganā": ['cae', 'mw'],
    "vrakṣas": ['mw'],
    "vrand": ['gra', 'mw'],
    "vrandin": ['cae', 'ddsa', 'gra', 'mw'],
    "vraska": ['gra', 'mw'],
    "vrata": ['cae', 'ddsa', 'gra', 'mw'],
    "vratabandhapaddhati": ['mw'],
    "vratabhakṣaṇa": ['mw'],
    "vratabhaṅga": ['mw'],
    "vratabhikṣā": ['mw'],
    "vratabhṛt": ['cae', 'mw'],
    "vratacarya": ['mw'],
    "vratacaryā": ['cae', 'mw'],
    "vratacārin": ['cae', 'gra', 'mw'],
    "vratacāritā": ['mw'],
    "vratacārya": ['mw'],
    "vratacūḍāmaṇi": ['mw'],
    "vratadaṇḍin": ['mw'],
    "vratadhara": ['mw'],
    "vratadhāraṇa": ['mw'],
    "vratadhārin": ['mw'],
    "vratadugdha": ['mw'],
    "vratadughā": ['mw'],
    "vrataduh": ['mw'],
    "vratadāna": ['ddsa', 'mw'],
    "vratagrahaṇa": ['cae', 'ddsa', 'mw'],
    "vratahāni": ['mw'],
    "vrataka": ['mw'],
    "vratakalpa": ['mw'],
    "vratakalpadruma": ['mw'],
    "vratakamalākara": ['mw'],
    "vratakaumudī": ['mw'],
    "vratakhaṇḍa": ['mw'],
    "vratakośa": ['mw'],
    "vratakālanirṇaya": ['mw'],
    "vratakālaviveka": ['mw'],
    "vratalopa": ['cae', 'mw'],
    "vratalopana": ['mw'],
    "vratalupta": ['mw'],
    "vratamayūkha": ['mw'],
    "vratamaṇḍala": ['bhs'],
    "vratamiśra": ['mw'],
    "vratamālā": ['mw'],
    "vratamīmāṃsā": ['cae', 'mw'],
    "vratanimitta": ['mw'],
    "vratanirṇaya": ['mw'],
    "vratanī": ['gra', 'mw'],
    "vratapada": ['bhs'],
    "vratapakṣa": ['mw'],
    "vratapati": ['cae', 'mw'],
    "vratapatnī": ['mw'],
    "vratapañjī": ['mw'],
    "vrataprada": ['mw'],
    "vratapradāna": ['mw'],
    "vrataprakāśa": ['mw'],
    "vratapratiṣṭhā": ['mw'],
    "vratapratiṣṭhāprayoga": ['mw'],
    "vratapustaka": ['mw'],
    "vratapā": ['cae', 'gra', 'mw'],
    "vratapāraṇa": ['cae', 'mw'],
    "vratapāraṇā": ['mw'],
    "vrataratnāvalī": ['mw'],
    "vrataruci": ['cae', 'mw'],
    "vratarāja": ['mw'],
    "vratasahyādri": ['mw'],
    "vratasampādana": ['mw'],
    "vratasampāta": ['mw'],
    "vratasamudra": ['bhs'],
    "vratasamāpana": ['mw'],
    "vratasamāyana": ['mw'],
    "vratasaṃgraha": ['mw'],
    "vratasaṃpādana": ['cae'],
    "vratasaṃrakṣaṇa": ['mw'],
    "vratasnāna": ['mw'],
    "vratasnāta": ['mw'],
    "vratasnātaka": ['mw'],
    "vratastha": ['cae', 'mw'],
    "vratasthita": ['cae', 'mw'],
    "vratasāra": ['mw'],
    "vratatattva": ['mw'],
    "vratati": ['cae', 'ddsa', 'gra', 'mw'],
    "vratativalaya": ['mw'],
    "vratatiḥ": ['ap90'],
    "vratavaikalya": ['mw'],
    "vratavallī": ['mw'],
    "vratavant": ['cae'],
    "vratavat": ['mw'],
    "vratavidhi": ['mw'],
    "vratavisarga": ['mw'],
    "vratavisarjana": ['mw'],
    "vratavisarjanīyopayoga": ['mw'],
    "vratavivekabhāskara": ['mw'],
    "vrataya": ['mw'],
    "vratayati": ['ap90'],
    "vratayitavya": ['mw'],
    "vrataśayyāgṛha": ['mw'],
    "vrataśeṣa": ['mw'],
    "vrataśrapaṇa": ['mw'],
    "vrataśānti": ['mw'],
    "vrataḥ": ['ap90'],
    "vrateyu": ['mw'],
    "vrateśa": ['cae', 'mw'],
    "vratia": ['gra'],
    "vratika": ['mw'],
    "vratin": ['ap90', 'cae', 'ddsa', 'mw'],
    "vratinī": ['mw'],
    "vratoddyota": ['mw'],
    "vratodyāpana": ['mw'],
    "vratodyāpanakaumudī": ['mw'],
    "vratodyāpanavidhi": ['mw'],
    "vratopaha": ['mw'],
    "vratopanayana": ['mw'],
    "vratopasad": ['mw'],
    "vratopavāsa": ['mw'],
    "vratopavāsasaṃgraha": ['mw'],
    "vratopeta": ['mw'],
    "vratopoha": ['mw'],
    "vratopāyana": ['mw'],
    "vratopāyanavat": ['mw'],
    "vratopāyanīya": ['mw'],
    "vratya": ['cae', 'gra', 'mw'],
    "vratācaraṇa": ['mw'],
    "vratācāra": ['mw'],
    "vratādeśa": ['cae', 'mw'],
    "vratādeśana": ['mw'],
    "vratādeśanavisarga": ['mw'],
    "vratādāna": ['cae', 'mw'],
    "vratādānīya": ['mw'],
    "vratārka": ['mw'],
    "vratātipatti": ['mw'],
    "vratāvalī": ['mw'],
    "vratāvalīkalpa": ['mw'],
    "vratāvṛtti": ['mw'],
    "vratāśa": ['mw'],
    "vrayas": ['cae', 'gra', 'mw'],
    "vraśc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vraścana": ['cae', 'ddsa', 'mw'],
    "vraścanaprabhava": ['mw'],
    "vraścanaḥ": ['ap90'],
    "vraḍhiman": ['mw'],
    "vraṇ": ['ap90', 'mw'],
    "vraṇa": ['bhs', 'cae', 'ddsa', 'mw'],
    "vraṇabhṛt": ['mw'],
    "vraṇacikitsā": ['mw'],
    "vraṇacintaka": ['mw'],
    "vraṇadhūpana": ['mw'],
    "vraṇadviṣ": ['mw'],
    "vraṇaghnagajadānavidhi": ['mw'],
    "vraṇaghnaratnadānavidhi": ['mw'],
    "vraṇaghnī": ['mw'],
    "vraṇagranthi": ['mw'],
    "vraṇaha": ['mw'],
    "vraṇahā": ['mw'],
    "vraṇahṛt": ['mw'],
    "vraṇajitā": ['mw'],
    "vraṇaketughnī": ['mw'],
    "vraṇakārin": ['mw'],
    "vraṇakṛt": ['mw'],
    "vraṇamaya": ['mw'],
    "vraṇana": ['cae', 'mw'],
    "vraṇapaṭṭa": ['mw'],
    "vraṇapaṭṭaka": ['mw'],
    "vraṇapaṭṭikā": ['mw'],
    "vraṇasaṃrohaṇa": ['mw'],
    "vraṇasāmānyakarmaprakāśa": ['mw'],
    "vraṇatā": ['mw'],
    "vraṇavant": ['cae'],
    "vraṇavastu": ['mw'],
    "vraṇavat": ['ddsa', 'mw'],
    "vraṇavedanā": ['mw'],
    "vraṇaviropaṇa": ['cae', 'mw'],
    "vraṇay": ['cae'],
    "vraṇaya": ['ddsa'],
    "vraṇayita": ['mw'],
    "vraṇayukta": ['cae', 'mw'],
    "vraṇayuktatva": ['mw'],
    "vraṇaśodhana": ['mw'],
    "vraṇaśoṣin": ['mw'],
    "vraṇaḥ": ['ap90'],
    "vraṇila": ['cae', 'mw'],
    "vraṇin": ['cae', 'ddsa', 'mw'],
    "vraṇita": ['ap90', 'mw'],
    "vraṇitahṛdaya": ['cae', 'mw'],
    "vraṇotsata": ['bhs'],
    "vraṇya": ['mw'],
    "vraṇāri": ['mw'],
    "vraṇāsrāva": ['mw'],
    "vraṇāyāma": ['mw'],
    "vraṇīya": ['mw'],
    "vraṣṭavya": ['mw'],
    "vreśī": ['mw'],
    "vriś": ['cae', 'ddsa', 'gra', 'mw'],
    "vruḍ": ['ap90', 'cae', 'ddsa', 'mw'],
    "vruḍita": ['mw'],
    "vrā": ['cae', 'ddsa', 'gra', 'mw'],
    "vrācaḍa": ['mw'],
    "vrācaṭa": ['mw'],
    "vrādh": ['cae', 'ddsa', 'gra', 'mw'],
    "vrāja": ['cae', 'gra', 'mw'],
    "vrājabāhu": ['mw'],
    "vrājam": ['mw'],
    "vrājapati": ['gra', 'mw'],
    "vrājaḥ": ['ap90'],
    "vrāji": ['mw'],
    "vrājika": ['mw'],
    "vrājin": ['mw'],
    "vrājiḥ": ['ap90'],
    "vrāta": ['cae', 'ddsa', 'gra', 'mw'],
    "vrātabhṛta": ['mw'],
    "vrātajīvana": ['mw'],
    "vrātamaya": ['mw'],
    "vrātapata": ['mw'],
    "vrātapateṣṭiprayoga": ['mw'],
    "vrātapati": ['cae', 'mw'],
    "vrātapatīya": ['mw'],
    "vrātasāha": ['gra', 'mw'],
    "vrātaḥ": ['ap90'],
    "vrātika": ['mw'],
    "vrātya": ['cae', 'ddsa', 'mw'],
    "vrātyabhāva": ['mw'],
    "vrātyabruva": ['mw'],
    "vrātyacaraṇa": ['mw'],
    "vrātyacaryā": ['mw'],
    "vrātyadhana": ['mw'],
    "vrātyagaṇa": ['mw'],
    "vrātyastoma": ['mw'],
    "vrātyatva": ['mw'],
    "vrātyatā": ['mw'],
    "vrātyayajña": ['mw'],
    "vrātyayājaka": ['mw'],
    "vrātyaḥ": ['ap90'],
    "vrātyā": ['mw'],
    "vrātīna": ['ap90', 'cae', 'mw'],
    "vrāṇa": ['cae', 'gra', 'mw'],
    "vrāṇika": ['bhs'],
    "vrī": ['ap90', 'mw'],
    "vrīhi": ['cae', 'ddsa', 'mw'],
    "vrīhibheda": ['mw'],
    "vrīhidrauṇika": ['mw'],
    "vrīhidroṇa": ['mw'],
    "vrīhika": ['mw'],
    "vrīhikaṅka": ['mw'],
    "vrīhikāñcana": ['mw'],
    "vrīhila": ['mw'],
    "vrīhimant": ['cae'],
    "vrīhimat": ['mw'],
    "vrīhimata": ['mw'],
    "vrīhimatī": ['mw'],
    "vrīhimaya": ['cae', 'mw'],
    "vrīhimukha": ['mw'],
    "vrīhin": ['cae', 'ddsa', 'mw'],
    "vrīhiparṇī": ['mw'],
    "vrīhirājika": ['mw'],
    "vrīhivelā": ['mw'],
    "vrīhivāpa": ['mw'],
    "vrīhivāpin": ['mw'],
    "vrīhiyava": ['cae', 'mw'],
    "vrīhiśarāva": ['mw'],
    "vrīhiśreṣṭha": ['mw'],
    "vrīhiḥ": ['ap90'],
    "vrīhy": ['mw'],
    "vrīhyagāra": ['mw'],
    "vrīhyapūpa": ['cae', 'mw'],
    "vrīhyurvarā": ['cae', 'mw'],
    "vrīhyāgrayaṇa": ['mw'],
    "vrīlana": ['mw'],
    "vrīlasa": ['mw'],
    "vrīs": ['ap90', 'mw'],
    "vrīḍ": ['ap90', 'cae', 'ddsa', 'mw'],
    "vrīḍa": ['cae', 'ddsa', 'mw'],
    "vrīḍana": ['mw'],
    "vrīḍanaṃ": ['ap90'],
    "vrīḍaḥ": ['ap90'],
    "vrīḍita": ['ap90', 'mw'],
    "vrīḍā": ['mw'],
    "vrīḍādāna": ['mw'],
    "vrīḍānata": ['mw'],
    "vrīḍānvita": ['mw'],
    "vrīḍāvant": ['cae'],
    "vrīḍāvat": ['mw'],
    "vrīḍāyuj": ['mw'],
    "vrīṇa": ['mw'],
    "vrūs": ['ap90', 'mw'],
    "vuccamāna": ['cped'],
    "vuccati": ['bhs', 'cped'],
    "vuddha": ['cped'],
    "vuddhi": ['bhs', 'cped'],
    "vuddhippatta": ['cped'],
    "vuhnā": ['mw'],
    "vuhyati": ['bhs'],
    "vuka": ['mw'],
    "vukka": ['bhs'],
    "vukta": ['bhs'],
    "vundh": ['mw'],
    "vupakaṭṭha": ['cped'],
    "vus": ['ap90'],
    "vusita": ['cped'],
    "vusitabhāva": ['cped'],
    "vusitatta": ['cped'],
    "vussati": ['cped'],
    "vusta": ['bhs'],
    "vutta": ['bhs', 'cped'],
    "vuttappakāra": ['cped'],
    "vuttappakārena": ['cped'],
    "vuttasira": ['cped'],
    "vuttavādī": ['cped'],
    "vuttha": ['cped'],
    "vutti": ['cped'],
    "vuttika": ['cped'],
    "vuttitā": ['cped'],
    "vuttī": ['cped'],
    "vuvūrṣu": ['ap90'],
    "vuyhamāna": ['cped'],
    "vuyhana": ['cped'],
    "vuyhati": ['cped'],
    "vuyhi": ['cped'],
    "vuḍ": ['mw'],
    "vuḍita": ['mw'],
    "vuḍḍha": ['cped'],
    "vuḍḍhatara": ['cped'],
    "vuḍḍhi": ['cped'],
    "vuṃg": ['ap90'],
    "vuṃṭ": ['ap90'],
    "vuṅg": ['mw'],
    "vuṇṭ": ['mw'],
    "vuṭṭha": ['cped'],
    "vuṭṭhahanta": ['cped'],
    "vuṭṭhahati": ['cped'],
    "vuṭṭhahi": ['cped'],
    "vuṭṭhahitvā": ['cped'],
    "vuṭṭhi": ['cped'],
    "vuṭṭhika": ['cped'],
    "vuṭṭhita": ['cped'],
    "vuṭṭhāpesi": ['cped'],
    "vuṭṭhāpeti": ['cped'],
    "vuṭṭhāpetvā": ['cped'],
    "vuṭṭhāpita": ['cped'],
    "vuṭṭhāsi": ['cped'],
    "vuṭṭhāti": ['cped'],
    "vuṭṭhāya": ['cped'],
    "vy": ['mw'],
    "vya": ['ap90', 'mw'],
    "vyabhicar": ['ap90', 'mw'],
    "vyabhicaraṇa": ['ddsa', 'mw'],
    "vyabhicāra": ['cae', 'mw'],
    "vyabhicārabhāva": ['mw'],
    "vyabhicārakṛt": ['mw'],
    "vyabhicāranirūpaṇakhaṇḍa": ['mw'],
    "vyabhicāratas": ['mw'],
    "vyabhicāratva": ['mw'],
    "vyabhicāratā": ['mw'],
    "vyabhicāravat": ['mw'],
    "vyabhicāravivarjita": ['mw'],
    "vyabhicāraḥ": ['ap90'],
    "vyabhicāri": ['mw'],
    "vyabhicāribhāva": ['mw'],
    "vyabhicārin": ['ap90', 'cae', 'mw'],
    "vyabhicāritva": ['mw'],
    "vyabhicāritā": ['mw'],
    "vyabhicāriṇī": ['ap90', 'mw'],
    "vyabhicārādapi": ['bhs'],
    "vyabhicārārtham": ['mw'],
    "vyabhihāsa": ['mw'],
    "vyabhimāna": ['mw'],
    "vyabhra": ['cae', 'ddsa', 'mw'],
    "vyabhraja": ['mw'],
    "vyabhre": ['mw'],
    "vyabhīcāra": ['mw'],
    "vyabhīcāraḥ": ['ap90'],
    "vyabhīmāna": ['mw'],
    "vyac": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vyacas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vyacaskāma": ['mw'],
    "vyacasvant": ['cae'],
    "vyacasvat": ['gra', 'mw'],
    "vyaccha": ['mw'],
    "vyaciṣṭha": ['cae', 'gra', 'mw'],
    "vyad": ['mw'],
    "vyadh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vyadha": ['cae', 'ddsa', 'mw'],
    "vyadhana": ['cae', 'mw'],
    "vyadhati": ['bhs'],
    "vyadhaḥ": ['ap90'],
    "vyadhika": ['mw'],
    "vyadhikaraṇa": ['cae', 'ddsa', 'mw'],
    "vyadhikaraṇadharmāvacchinnavāda": ['mw'],
    "vyadhikaraṇadharmāvacchinnābhāva": ['mw'],
    "vyadhikaraṇadharmāvacchinnābhāvakroḍa": ['mw'],
    "vyadhikaraṇadharmāvacchinnābhāvapariṣkāra": ['mw'],
    "vyadhikaraṇadharmāvacchinnābhāvaprakāśa": ['mw'],
    "vyadhikaraṇadharmāvacchinnābhāvarahasya": ['mw'],
    "vyadhikaraṇadharmāvacchinnābhāvaṭīkā": ['mw'],
    "vyadhikaraṇapada": ['mw'],
    "vyadhikaraṇaṃ": ['ap90'],
    "vyadhikaraṇābhāva": ['mw'],
    "vyadhikṣepa": ['mw'],
    "vyadhva": ['cae', 'mw'],
    "vyadhvan": ['bhs', 'cae', 'gra', 'mw'],
    "vyadhvara": ['cae', 'mw'],
    "vyadhvaḥ": ['ap90'],
    "vyadhya": ['mw'],
    "vyadhyasira": ['mw'],
    "vyadhyaḥ": ['ap90'],
    "vyadhā": ['mw'],
    "vyadvara": ['cae', 'mw'],
    "vyadya": ['mw'],
    "vyaggha": ['cped'],
    "vyagghusabha": ['cped'],
    "vyagra": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vyagrahasta": ['mw'],
    "vyagram": ['mw'],
    "vyagramanas": ['mw'],
    "vyagrapuraṃdhrivarga": ['mw'],
    "vyagratva": ['mw'],
    "vyagratā": ['mw'],
    "vyagraya": ['mw'],
    "vyah": ['mw'],
    "vyahan": ['mw'],
    "vyahna": ['mw'],
    "vyailaba": ['mw'],
    "vyaj": ['ddsa', 'mw'],
    "vyaja": ['mw'],
    "vyajana": ['cae', 'ddsa', 'mw'],
    "vyajanacāmara": ['mw'],
    "vyajanaka": ['mw'],
    "vyajanakriyā": ['mw'],
    "vyajanaṃ": ['ap90'],
    "vyajanin": ['mw'],
    "vyajanī": ['mw'],
    "vyajanībhū": ['mw'],
    "vyajanīkṛ": ['mw'],
    "vyajaḥ": ['ap90'],
    "vyakta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vyaktabhuj": ['mw'],
    "vyaktadarśana": ['mw'],
    "vyaktadṛṣṭārtha": ['mw'],
    "vyaktagandhā": ['mw'],
    "vyaktagaṇita": ['mw'],
    "vyaktakṛtya": ['mw'],
    "vyaktalakṣman": ['mw'],
    "vyaktalavaṇa": ['mw'],
    "vyaktam": ['mw'],
    "vyaktamaya": ['mw'],
    "vyaktamāricika": ['mw'],
    "vyaktarasa": ['mw'],
    "vyaktarasatā": ['mw'],
    "vyaktaromodgamatva": ['mw'],
    "vyaktarāśi": ['mw'],
    "vyaktarūpa": ['mw'],
    "vyaktarūpin": ['mw'],
    "vyaktatva": ['mw'],
    "vyaktatā": ['mw'],
    "vyaktatāraka": ['mw'],
    "vyaktavikrama": ['mw'],
    "vyaktavāc": ['mw'],
    "vyaktaya": ['mw'],
    "vyakti": ['cae', 'ddsa', 'mw'],
    "vyaktitva": ['mw'],
    "vyaktitā": ['mw'],
    "vyaktiviveka": ['mw'],
    "vyaktiḥ": ['ap90'],
    "vyaktodita": ['mw'],
    "vyaktāvadhūta": ['mw'],
    "vyaktī": ['mw'],
    "vyaktībhāva": ['mw'],
    "vyaktībhū": ['ap90', 'mw'],
    "vyaktīkaraṇa": ['ddsa', 'mw'],
    "vyaktīkṛ": ['ap90', 'ddsa', 'mw'],
    "vyakṛḍa": ['mw'],
    "vyakṣ": ['mw'],
    "vyakṣa": ['mw'],
    "vyalaṃkaroti": ['bhs'],
    "vyalkaśa": ['mw'],
    "vyalkaśā": ['cae', 'ddsa', 'gra', 'mw'],
    "vyalīka": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyalīkam": ['mw'],
    "vyalīkaniḥśvāsa": ['mw'],
    "vyalīkatva": ['mw'],
    "vyalīkatā": ['mw'],
    "vyamha": ['cped'],
    "vyamla": ['mw'],
    "vyamlatā": ['mw'],
    "vyan": ['mw'],
    "vyanta": ['cae', 'mw'],
    "vyantara": ['cae', 'ddsa', 'mw'],
    "vyantarapaṅkti": ['mw'],
    "vyantarām": ['cae', 'mw'],
    "vyantarī": ['mw'],
    "vyantikatvā": ['cped'],
    "vyantībhavati": ['bhs', 'cped'],
    "vyantībhavi": ['cped'],
    "vyantībhāva": ['bhs', 'cped', 'mw'],
    "vyantībhūta": ['cped'],
    "vyantīhoti": ['cped'],
    "vyantīkari": ['cped'],
    "vyantīkaritvā": ['cped'],
    "vyantīkaroti": ['bhs', 'cped'],
    "vyantīkata": ['cped'],
    "vyantīkṛ": ['mw'],
    "vyanudhā": ['mw'],
    "vyanunad": ['mw'],
    "vyanunāda": ['mw'],
    "vyanunādaḥ": ['ap90'],
    "vyanusṛ": ['mw'],
    "vyanvārabh": ['mw'],
    "vyanvārambhaṇa": ['mw'],
    "vyap": ['ap90', 'mw'],
    "vyapadahyati": ['bhs'],
    "vyapadeśa": ['bhs', 'cae', 'mw'],
    "vyapadeśaka": ['mw'],
    "vyapadeśate": ['bhs'],
    "vyapadeśavant": ['cae'],
    "vyapadeśavat": ['mw'],
    "vyapadeśaḥ": ['ap90'],
    "vyapadeśin": ['cae', 'mw'],
    "vyapadeśya": ['mw'],
    "vyapadeśārtham": ['mw'],
    "vyapadeṣṭṛ": ['ap90', 'mw'],
    "vyapadiś": ['ap90', 'mw'],
    "vyapadiṣṭa": ['ap90', 'mw'],
    "vyapadṛś": ['mw'],
    "vyapagacchati": ['cped'],
    "vyapagam": ['ap90', 'mw'],
    "vyapagama": ['mw'],
    "vyapagamaḥ": ['ap90'],
    "vyapagami": ['cped'],
    "vyapagata": ['ap90', 'cped', 'mw'],
    "vyapagatakhiladoṣa": ['bhs'],
    "vyapagatakhilamalapratighoṣa": ['bhs'],
    "vyapagataraśmivat": ['mw'],
    "vyapagatatilakagātratā": ['mw'],
    "vyapagataśuc": ['mw'],
    "vyapahan": ['mw'],
    "vyapahā": ['mw'],
    "vyapahṛ": ['mw'],
    "vyapakarṣa": ['ddsa', 'mw'],
    "vyapakram": ['mw'],
    "vyapakṛṣ": ['ap90', 'mw'],
    "vyapakṛṣṭa": ['ap90', 'bhs', 'mw'],
    "vyapalokayati": ['bhs'],
    "vyapamuc": ['mw'],
    "vyapamūrdhan": ['mw'],
    "vyapanaya": ['cae', 'mw'],
    "vyapanayana": ['mw'],
    "vyapanaś": ['mw'],
    "vyapaneya": ['mw'],
    "vyapanud": ['mw'],
    "vyapanutti": ['cae', 'mw'],
    "vyapanī": ['mw'],
    "vyapanīta": ['mw'],
    "vyaparopaṇa": ['cae', 'mw'],
    "vyaparopaṇaṃ": ['ap90'],
    "vyaparopita": ['mw'],
    "vyaparudh": ['mw'],
    "vyaparuh": ['ap90', 'mw'],
    "vyapasaṃsarati": ['bhs'],
    "vyapasaṃsṛ": ['mw'],
    "vyapasphur": ['mw'],
    "vyapasphuraṇa": ['mw'],
    "vyapasāraṇa": ['mw'],
    "vyapasṛ": ['mw'],
    "vyapasṛj": ['mw'],
    "vyapasṛp": ['mw'],
    "vyapatrap": ['ap90', 'mw'],
    "vyapatrapa": ['ap90', 'mw'],
    "vyapatrapā": ['mw'],
    "vyapatrāpin": ['bhs'],
    "vyapatrāpya": ['bhs', 'mw'],
    "vyapavah": ['mw'],
    "vyapavarga": ['mw'],
    "vyapavartanaṃ": ['ap90'],
    "vyapaviddha": ['cae', 'mw'],
    "vyapaviddhabṛśīmaṭha": ['mw'],
    "vyapavṛj": ['mw'],
    "vyapavṛkta": ['mw'],
    "vyapavṛt": ['ap90', 'mw'],
    "vyapayā": ['mw'],
    "vyapayāna": ['cae', 'mw'],
    "vyapayāta": ['mw'],
    "vyape": ['ap90', 'mw'],
    "vyapekṣ": ['ap90', 'mw'],
    "vyapekṣa": ['ap90', 'mw'],
    "vyapekṣaka": ['mw'],
    "vyapekṣaṇa": ['mw'],
    "vyapekṣaṇaṃ": ['ap90'],
    "vyapekṣaṇīya": ['mw'],
    "vyapekṣita": ['ap90', 'mw'],
    "vyapekṣya": ['mw'],
    "vyapekṣā": ['ap90', 'cae', 'mw'],
    "vyapeta": ['ap90', 'cae', 'mw'],
    "vyapetabhaya": ['mw'],
    "vyapetabhī": ['mw'],
    "vyapetadhairya": ['mw'],
    "vyapetaghṛṇa": ['mw'],
    "vyapetaharṣa": ['mw'],
    "vyapetakalmaṣa": ['mw'],
    "vyapetamadamatsara": ['mw'],
    "vyapoh": ['ap90', 'mw'],
    "vyapoha": ['cae', 'mw'],
    "vyapohaka": ['mw'],
    "vyapohanastotra": ['mw'],
    "vyapohastava": ['mw'],
    "vyapohaḥ": ['ap90'],
    "vyapohya": ['mw'],
    "vyapoḍha": ['ap90', 'mw'],
    "vyapoḍhābhra": ['mw'],
    "vyapāhṛ": ['mw'],
    "vyapākṛta": ['mw'],
    "vyapākṛti": ['mw'],
    "vyapākṛtiḥ": ['ap90'],
    "vyapākṛṣ": ['mw'],
    "vyapānud": ['mw'],
    "vyapāya": ['cae', 'ddsa', 'mw'],
    "vyapāyaḥ": ['ap90'],
    "vyapāśraya": ['cae', 'mw'],
    "vyapāśrayaḥ": ['ap90'],
    "vyapāśri": ['mw'],
    "vyapāśrita": ['mw'],
    "vyard": ['mw'],
    "vyardhuka": ['cae', 'mw'],
    "vyarka": ['mw'],
    "vyarpaṇā": ['bhs', 'mw'],
    "vyartha": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyarthaka": ['ap90', 'mw'],
    "vyarthakatva": ['mw'],
    "vyarthakatā": ['mw'],
    "vyartham": ['mw'],
    "vyarthanāmaka": ['mw'],
    "vyarthanāman": ['mw'],
    "vyarthatva": ['mw'],
    "vyarthatā": ['cae', 'mw'],
    "vyarthaya": ['mw'],
    "vyarthayatna": ['mw'],
    "vyarthībhū": ['mw'],
    "vyarthīkṛ": ['mw'],
    "vyarṇa": ['mw'],
    "vyarṇṇa": ['mw'],
    "vyas": ['ap90', 'ddsa', 'mw'],
    "vyasana": ['cae', 'cped', 'ddsa', 'mw'],
    "vyasanabrahmacārin": ['mw'],
    "vyasanakāla": ['mw'],
    "vyasanamahārṇava": ['mw'],
    "vyasanaprahārin": ['mw'],
    "vyasanaprasāritakara": ['mw'],
    "vyasanaprāpti": ['mw'],
    "vyasanarakṣin": ['mw'],
    "vyasanasaṃsthita": ['mw'],
    "vyasanavat": ['mw'],
    "vyasanavāgurā": ['mw'],
    "vyasanaṃ": ['ap90'],
    "vyasani": ['mw'],
    "vyasanin": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyasanitva": ['mw'],
    "vyasanitā": ['mw'],
    "vyasanodaya": ['ddsa', 'mw'],
    "vyasanotsava": ['mw'],
    "vyasanāgama": ['mw'],
    "vyasanākrāntatva": ['mw'],
    "vyasanānantaram": ['mw'],
    "vyasanānvita": ['mw'],
    "vyasanāpluta": ['mw'],
    "vyasanāpāta": ['mw'],
    "vyasanārta": ['mw'],
    "vyasanātibhāra": ['mw'],
    "vyasanātyaya": ['mw'],
    "vyasanāvāpa": ['mw'],
    "vyasanīkṛ": ['mw'],
    "vyasanīya": ['mw'],
    "vyasi": ['cae', 'ddsa', 'mw'],
    "vyaskandaka": ['bhs'],
    "vyasta": ['ap90', 'cae', 'mw'],
    "vyastakeśa": ['cae', 'mw'],
    "vyastam": ['mw'],
    "vyastanyāsa": ['mw'],
    "vyastapada": ['mw'],
    "vyastapuccha": ['mw'],
    "vyastarātriṃdiva": ['mw'],
    "vyastatrairāśika": ['mw'],
    "vyastatva": ['mw'],
    "vyastatā": ['mw'],
    "vyastavidhi": ['mw'],
    "vyastavṛtti": ['mw'],
    "vyasthaka": ['cae', 'mw'],
    "vyastikā": ['bhs', 'mw'],
    "vyastikākṛta": ['mw'],
    "vyastāra": ['mw'],
    "vyastāraḥ": ['ap90'],
    "vyasu": ['ap90', 'cae', 'mw'],
    "vyasutva": ['mw'],
    "vyath": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vyatha": ['mw'],
    "vyathaka": ['ap90', 'ddsa', 'mw'],
    "vyathana": ['cae', 'mw'],
    "vyathanaṃ": ['ap90'],
    "vyathanīya": ['mw'],
    "vyathati": ['cped'],
    "vyathayitṛ": ['cae', 'mw'],
    "vyathi": ['cae', 'cped', 'gra', 'mw'],
    "vyathin": ['mw'],
    "vyathis": ['cae', 'gra', 'mw'],
    "vyathita": ['ap90', 'cae', 'cped', 'mw'],
    "vyathitavya": ['mw'],
    "vyathiṣa": ['mw'],
    "vyathya": ['mw'],
    "vyathyayas": ['mw'],
    "vyathā": ['ap90', 'cae', 'mw'],
    "vyathākara": ['mw'],
    "vyathākrānta": ['mw'],
    "vyathākula": ['mw'],
    "vyathānvita": ['mw'],
    "vyathārahita": ['mw'],
    "vyathātura": ['mw'],
    "vyathāvat": ['mw'],
    "vyati": ['cae', 'ddsa', 'gra', 'mw'],
    "vyatibheda": ['mw'],
    "vyatibhindati": ['bhs'],
    "vyatibhinna": ['mw'],
    "vyatibhā": ['mw'],
    "vyatibhū": ['mw'],
    "vyaticar": ['mw'],
    "vyaticumbita": ['mw'],
    "vyaticāra": ['mw'],
    "vyatigam": ['mw'],
    "vyatigata": ['mw'],
    "vyatigā": ['mw'],
    "vyatihan": ['mw'],
    "vyatihas": ['mw'],
    "vyatihiṃs": ['mw'],
    "vyatihāra": ['bhs', 'cae', 'mw'],
    "vyatihāraḥ": ['ap90'],
    "vyatihṛ": ['mw'],
    "vyatijalp": ['mw'],
    "vyatiji": ['mw'],
    "vyatikara": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyatikaravant": ['cae'],
    "vyatikaravat": ['mw'],
    "vyatikarita": ['ap90', 'cae', 'mw'],
    "vyatikram": ['ap90', 'mw'],
    "vyatikrama": ['cae', 'mw'],
    "vyatikramaḥ": ['ap90'],
    "vyatikramaṇa": ['cae', 'mw'],
    "vyatikramin": ['mw'],
    "vyatikrānta": ['cae', 'mw'],
    "vyatikrānti": ['mw'],
    "vyatikrāṃta": ['ap90'],
    "vyatikāśati": ['bhs'],
    "vyatikīrṇa": ['ap90', 'mw'],
    "vyatikṛ": ['mw'],
    "vyatikṛta": ['mw'],
    "vyatikṝ": ['ap90', 'mw'],
    "vyatikṣepa": ['mw'],
    "vyatilaṅghin": ['mw'],
    "vyatilokayati": ['bhs'],
    "vyatilū": ['mw'],
    "vyatimarśa": ['mw'],
    "vyatimarśam": ['mw'],
    "vyatimiśra": ['cae', 'mw'],
    "vyatimoha": ['mw'],
    "vyatimūḍha": ['mw'],
    "vyatinamati": ['bhs'],
    "vyatinī": ['mw'],
    "vyatipatati": ['bhs'],
    "vyatipaṭh": ['mw'],
    "vyatipāka": ['mw'],
    "vyatipāta": ['mw'],
    "vyatipātajananaśānti": ['mw'],
    "vyatipātaprakaraṇa": ['mw'],
    "vyatipātavratakalpa": ['mw'],
    "vyatipātin": ['bhs'],
    "vyatirecana": ['mw'],
    "vyatireka": ['cae', 'mw'],
    "vyatirekatas": ['mw'],
    "vyatirekavyāpti": ['mw'],
    "vyatirekaḥ": ['ap90'],
    "vyatireke": ['mw'],
    "vyatirekeṇa": ['mw'],
    "vyatireki": ['mw'],
    "vyatirekiliṅga": ['mw'],
    "vyatirekin": ['ap90', 'mw'],
    "vyatirekipūrvapakṣarahasya": ['mw'],
    "vyatirekirahasya": ['mw'],
    "vyatirekisiddhāntarahasya": ['mw'],
    "vyatirekyudāharaṇa": ['mw'],
    "vyatirekālaṃkāra": ['mw'],
    "vyatirekāt": ['mw'],
    "vyatirekāvalī": ['mw'],
    "vyatiric": ['ap90', 'mw'],
    "vyatirikta": ['ap90', 'cae', 'mw'],
    "vyatiriktaka": ['mw'],
    "vyatiriktam": ['mw'],
    "vyatiriktatva": ['mw'],
    "vyatiriktatā": ['mw'],
    "vyatirocate": ['bhs'],
    "vyatiropita": ['mw'],
    "vyatiruh": ['mw'],
    "vyatirā": ['mw'],
    "vyatisaṃcarati": ['bhs'],
    "vyatisaṃdah": ['mw'],
    "vyatisaṃkrama": ['bhs'],
    "vyatisev": ['mw'],
    "vyatisārayati": ['bhs'],
    "vyatisṛ": ['mw'],
    "vyatisṛp": ['mw'],
    "vyatitan": ['mw'],
    "vyatitṝ": ['mw'],
    "vyativah": ['mw'],
    "vyatividdha": ['mw'],
    "vyativraj": ['mw'],
    "vyativṛt": ['mw'],
    "vyatiyu": ['ap90', 'mw'],
    "vyatiyā": ['mw'],
    "vyatiyāta": ['mw'],
    "vyatiśaṅkita": ['mw'],
    "vyatiśī": ['mw'],
    "vyatiśṝ": ['mw'],
    "vyatiṣajya": ['mw'],
    "vyatiṣakta": ['ap90', 'cae', 'mw'],
    "vyatiṣañj": ['mw'],
    "vyatiṣañjita": ['mw'],
    "vyatiṣaṃgaḥ": ['ap90'],
    "vyatiṣaṃj": ['ap90'],
    "vyatiṣaṅga": ['mw'],
    "vyatiṣaṅgam": ['mw'],
    "vyatiṣaṅgavat": ['mw'],
    "vyatiṣaṅgin": ['mw'],
    "vyatiṣikta": ['mw'],
    "vyatta": ['cped'],
    "vyattara": ['cped'],
    "vyattā": ['cped'],
    "vyatyas": ['ap90', 'mw'],
    "vyatyasta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vyatyaya": ['cae', 'ddsa', 'mw'],
    "vyatyayaga": ['mw'],
    "vyatyayaḥ": ['ap90'],
    "vyatyāsa": ['cae', 'mw'],
    "vyatyāsam": ['mw'],
    "vyatyāsaḥ": ['ap90'],
    "vyatyūh": ['mw'],
    "vyatī": ['ap90', 'mw'],
    "vyatīhā": ['mw'],
    "vyatīhāra": ['mw'],
    "vyatīhāraḥ": ['ap90'],
    "vyatīkāra": ['mw'],
    "vyatīkṣā": ['mw'],
    "vyatīpāta": ['mw'],
    "vyatīpātaḥ": ['ap90'],
    "vyatīta": ['ap90', 'cae', 'mw'],
    "vyatītakāla": ['ddsa', 'mw'],
    "vyavabhakṣ": ['mw'],
    "vyavabhās": ['mw'],
    "vyavabhāsate": ['bhs'],
    "vyavabhāsita": ['mw'],
    "vyavaccheda": ['cae', 'ddsa', 'mw'],
    "vyavacchedaka": ['mw'],
    "vyavacchedakatva": ['mw'],
    "vyavacchedana": ['bhs'],
    "vyavacchedavidyā": ['mw'],
    "vyavacchedaḥ": ['ap90'],
    "vyavacchedya": ['cae', 'mw'],
    "vyavacchid": ['ap90', 'mw'],
    "vyavacchinna": ['ap90', 'mw'],
    "vyavacāra": ['bhs'],
    "vyavacārayati": ['bhs'],
    "vyavacārayitavya": ['mw'],
    "vyavacāraṇa": ['bhs'],
    "vyavadahyati": ['bhs'],
    "vyavadai": ['mw'],
    "vyavadheya": ['mw'],
    "vyavadhi": ['cae', 'mw'],
    "vyavadhiḥ": ['ap90'],
    "vyavadhā": ['ap90', 'mw'],
    "vyavadhāna": ['cae', 'mw'],
    "vyavadhānavat": ['mw'],
    "vyavadhānaṃ": ['ap90'],
    "vyavadhānena": ['mw'],
    "vyavadhāraṇa": ['mw'],
    "vyavadhātavya": ['mw'],
    "vyavadhāv": ['mw'],
    "vyavadhāyaka": ['ap90', 'mw'],
    "vyavadhāyika": ['mw'],
    "vyavadhū": ['mw'],
    "vyavadhūta": ['mw'],
    "vyavadhṛ": ['mw'],
    "vyavadiśati": ['bhs'],
    "vyavado": ['mw'],
    "vyavadru": ['mw'],
    "vyavadā": ['mw'],
    "vyavadāna": ['bhs', 'mw'],
    "vyavadāraprāpaṇa": ['mw'],
    "vyavadāta": ['mw'],
    "vyavadāyate": ['bhs'],
    "vyavadīrṇa": ['mw'],
    "vyavagam": ['mw'],
    "vyavagata": ['bhs'],
    "vyavagrāham": ['mw'],
    "vyavagāh": ['mw'],
    "vyavagāḍha": ['mw'],
    "vyavagāḍhavat": ['mw'],
    "vyavagṛhīta": ['mw'],
    "vyavaharaṇa": ['mw'],
    "vyavahartavya": ['cae', 'mw'],
    "vyavahartṛ": ['ap90', 'cae', 'mw'],
    "vyavahasati": ['bhs'],
    "vyavahita": ['ap90', 'cae', 'mw'],
    "vyavahriyamāṇa": ['mw'],
    "vyavahriyamāṇatva": ['mw'],
    "vyavahāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "vyavahāracamatkāra": ['mw'],
    "vyavahāracandrodaya": ['mw'],
    "vyavahāracintāmaṇi": ['mw'],
    "vyavahāradarpaṇa": ['mw'],
    "vyavahāradarśana": ['cae', 'mw'],
    "vyavahāradaśaślokī": ['mw'],
    "vyavahāradaśā": ['mw'],
    "vyavahāradraṣṭṛ": ['mw'],
    "vyavahāradīdhiti": ['mw'],
    "vyavahāradīpikā": ['mw'],
    "vyavahārajña": ['mw'],
    "vyavahāraka": ['bhs', 'cae', 'mw'],
    "vyavahārakalpataru": ['mw'],
    "vyavahārakamalākara": ['mw'],
    "vyavahārakaḥ": ['ap90'],
    "vyavahārakāla": ['mw'],
    "vyavahārakāṇḍa": ['mw'],
    "vyavahāralakṣaṇa": ['mw'],
    "vyavahāram": ['mw'],
    "vyavahāramahodaya": ['mw'],
    "vyavahāramayūkha": ['mw'],
    "vyavahāramādhava": ['mw'],
    "vyavahāramālikā": ['mw'],
    "vyavahāramālā": ['mw'],
    "vyavahāramārga": ['mw'],
    "vyavahāramātṛkā": ['mw'],
    "vyavahāranirṇaya": ['mw'],
    "vyavahārapada": ['cae', 'mw'],
    "vyavahāraparibhāṣā": ['mw'],
    "vyavahārapariśiṣṭa": ['mw'],
    "vyavahārapradīpa": ['mw'],
    "vyavahārapradīpikā": ['mw'],
    "vyavahāraprakāśa": ['mw'],
    "vyavahāraprāpta": ['mw'],
    "vyavahārapāda": ['mw'],
    "vyavahāraratna": ['mw'],
    "vyavahāraratnamālā": ['mw'],
    "vyavahāraratnākara": ['mw'],
    "vyavahārasamuccaya": ['mw'],
    "vyavahārasaukhya": ['mw'],
    "vyavahārasthiti": ['cae', 'mw'],
    "vyavahārasthāna": ['cae', 'mw'],
    "vyavahārasāra": ['mw'],
    "vyavahārasāroddhāra": ['mw'],
    "vyavahāratantra": ['cae'],
    "vyavahāratas": ['mw'],
    "vyavahāratattva": ['mw'],
    "vyavahāratilaka": ['mw'],
    "vyavahāratva": ['mw'],
    "vyavahāravant": ['cae'],
    "vyavahāravat": ['mw'],
    "vyavahāravidhi": ['cae', 'mw'],
    "vyavahāraviṣaya": ['mw'],
    "vyavahārayitavya": ['mw'],
    "vyavahāraśataka": ['mw'],
    "vyavahāraḥ": ['ap90'],
    "vyavahārika": ['ap90', 'bhs', 'mw'],
    "vyavahārikā": ['ap90', 'mw'],
    "vyavahārin": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyavahāritā": ['mw'],
    "vyavahāroccaya": ['mw'],
    "vyavahārya": ['ap90', 'cae', 'mw'],
    "vyavahārābhiśasta": ['mw'],
    "vyavahārāloka": ['mw'],
    "vyavahārārthasmṛtisārasamuccaya": ['mw'],
    "vyavahārārthasāra": ['mw'],
    "vyavahārārthin": ['cae', 'mw'],
    "vyavahārāsana": ['mw'],
    "vyavahārāyogya": ['mw'],
    "vyavahārāṃśa": ['mw'],
    "vyavahārāṅga": ['mw'],
    "vyavahārāṅgasmṛtisarvasva": ['mw'],
    "vyavahāsa": ['mw'],
    "vyavahṛ": ['ap90', 'mw'],
    "vyavahṛt": ['mw'],
    "vyavahṛta": ['mw'],
    "vyavahṛti": ['cae', 'mw'],
    "vyavahṛtitattva": ['mw'],
    "vyavahṛtiḥ": ['ap90'],
    "vyavakalana": ['mw'],
    "vyavakalanaṃ": ['ap90'],
    "vyavakalita": ['mw'],
    "vyavakiraṇā": ['bhs', 'mw'],
    "vyavakrośana": ['mw'],
    "vyavakrośanaṃ": ['ap90'],
    "vyavakīrṇa": ['bhs', 'mw'],
    "vyavakṛṣ": ['mw'],
    "vyavakṛṣṭa": ['bhs'],
    "vyavakṝ": ['mw'],
    "vyavalambin": ['bhs', 'mw'],
    "vyavalokana": ['bhs', 'mw'],
    "vyavalokayati": ['bhs'],
    "vyavalokita": ['bhs', 'mw'],
    "vyavalī": ['mw'],
    "vyavamuc": ['mw'],
    "vyavana": ['bhs', 'mw'],
    "vyavanī": ['mw'],
    "vyavapad": ['mw'],
    "vyavapariṇāma": ['bhs'],
    "vyavaruh": ['mw'],
    "vyavasad": ['mw'],
    "vyavasanatā": ['bhs'],
    "vyavasarga": ['bhs', 'mw'],
    "vyavaseya": ['mw'],
    "vyavasita": ['ap90', 'cae', 'mw'],
    "vyavasiti": ['mw'],
    "vyavaso": ['ap90', 'mw'],
    "vyavasraṃs": ['mw'],
    "vyavasraṃsa": ['mw'],
    "vyavasru": ['mw'],
    "vyavasta": ['bhs', 'mw'],
    "vyavasthita": ['ap90', 'bhs', 'cae', 'mw'],
    "vyavasthitatva": ['mw'],
    "vyavasthitavibhāṣā": ['mw'],
    "vyavasthitavikalpa": ['mw'],
    "vyavasthitaviṣaya": ['mw'],
    "vyavasthiti": ['ap90', 'cae', 'mw'],
    "vyavasthā": ['ap90', 'cae', 'mw'],
    "vyavasthādarpaṇa": ['mw'],
    "vyavasthāna": ['bhs', 'cae', 'mw'],
    "vyavasthānaprajñapti": ['bhs', 'mw'],
    "vyavasthānaṃ": ['ap90'],
    "vyavasthāpaka": ['ap90', 'mw'],
    "vyavasthāpakatva": ['mw'],
    "vyavasthāpakavasthāpya": ['mw'],
    "vyavasthāpana": ['mw'],
    "vyavasthāpanaṃ": ['ap90'],
    "vyavasthāpanīya": ['mw'],
    "vyavasthāpattra": ['mw'],
    "vyavasthāpita": ['ap90', 'mw'],
    "vyavasthāprakāśa": ['mw'],
    "vyavasthāpya": ['mw'],
    "vyavasthāratnamālā": ['mw'],
    "vyavasthārṇava": ['mw'],
    "vyavasthāsetu": ['mw'],
    "vyavasthāsārasaṃcaya": ['mw'],
    "vyavasthāsārasaṃgraha": ['mw'],
    "vyavasthātikrama": ['mw'],
    "vyavasthātivartana": ['mw'],
    "vyavasthātivartin": ['mw'],
    "vyavasthātṛ": ['mw'],
    "vyavastubh": ['mw'],
    "vyavastṛ": ['mw'],
    "vyavasāda": ['bhs'],
    "vyavasāya": ['cae', 'mw'],
    "vyavasāyabuddhi": ['mw'],
    "vyavasāyadvitīya": ['mw'],
    "vyavasāyavant": ['cae'],
    "vyavasāyavartin": ['mw'],
    "vyavasāyavat": ['mw'],
    "vyavasāyaḥ": ['ap90'],
    "vyavasāyin": ['ap90', 'cae', 'mw'],
    "vyavasāyātmaka": ['cae', 'mw'],
    "vyavasṛj": ['mw'],
    "vyavasṛp": ['mw'],
    "vyavatiṣṭhamāna": ['mw'],
    "vyavavad": ['mw'],
    "vyavavadya": ['mw'],
    "vyavavid": ['mw'],
    "vyavavlī": ['mw'],
    "vyavaśad": ['mw'],
    "vyavaścut": ['mw'],
    "vyavaśāda": ['mw'],
    "vyave": ['ap90', 'mw'],
    "vyavedhātṛ": ['mw'],
    "vyaveta": ['ap90', 'mw'],
    "vyavetatva": ['mw'],
    "vyavānin": ['mw'],
    "vyavāya": ['cae', 'ddsa', 'mw'],
    "vyavāyaḥ": ['ap90'],
    "vyavāyin": ['ap90', 'cae', 'mw'],
    "vyavāyitva": ['mw'],
    "vyay": ['ap90', 'cae', 'mw'],
    "vyaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyayabhavana": ['mw'],
    "vyayagata": ['mw'],
    "vyayaguṇa": ['cae', 'mw'],
    "vyayagṛha": ['mw'],
    "vyayaka": ['mw'],
    "vyayakara": ['mw'],
    "vyayakaraṇa": ['cae', 'mw'],
    "vyayakaraṇaka": ['cae', 'mw'],
    "vyayakarman": ['cae', 'mw'],
    "vyayakṛta": ['cae'],
    "vyayamāna": ['mw'],
    "vyayana": ['cae', 'ddsa', 'gra', 'mw'],
    "vyayanaṃ": ['ap90'],
    "vyayaparāṅmukha": ['mw'],
    "vyayasaha": ['mw'],
    "vyayasahiṣṇu": ['mw'],
    "vyayasthāna": ['mw'],
    "vyayavat": ['ddsa', 'mw'],
    "vyayaśālin": ['mw'],
    "vyayaśīla": ['mw'],
    "vyayi": ['mw'],
    "vyayin": ['mw'],
    "vyayita": ['ap90', 'mw'],
    "vyayitavya": ['mw'],
    "vyayitva": ['mw'],
    "vyayitā": ['mw'],
    "vyayo": ['cped'],
    "vyayī": ['mw'],
    "vyayībhūta": ['mw'],
    "vyayīkaraṇa": ['mw'],
    "vyayīkṛ": ['ddsa', 'mw'],
    "vyayīkṛta": ['mw'],
    "vyañc": ['mw'],
    "vyañcana": ['mw'],
    "vyañcanavat": ['mw'],
    "vyañj": ['mw'],
    "vyañjaka": ['cae', 'ddsa', 'mw'],
    "vyañjakatva": ['mw'],
    "vyañjakārtha": ['mw'],
    "vyañjana": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vyañjanaguṇa": ['mw'],
    "vyañjanahārikā": ['mw'],
    "vyañjanakāra": ['mw'],
    "vyañjanasaṃdhi": ['mw'],
    "vyañjanasaṃgama": ['mw'],
    "vyañjanasaṃnipāta": ['mw'],
    "vyañjanasthāne": ['mw'],
    "vyañjanika": ['mw'],
    "vyañjanodaya": ['mw'],
    "vyañjanopadha": ['mw'],
    "vyañjanā": ['mw'],
    "vyañjanāvṛtti": ['mw'],
    "vyañjayati": ['cped'],
    "vyañjayi": ['cped'],
    "vyañjijiṣu": ['mw'],
    "vyañjita": ['cped', 'mw'],
    "vyañjitajña": ['bhs'],
    "vyañjitavṛttibheda": ['mw'],
    "vyaś": ['ap90', 'mw'],
    "vyaśana": ['mw'],
    "vyaśva": ['cae', 'ddsa', 'gra', 'mw'],
    "vyaśvait": ['ddsa'],
    "vyaśvasārathyāyudha": ['mw'],
    "vyaśvavat": ['gra', 'mw'],
    "vyaḍa": ['mw'],
    "vyaḍambaka": ['mw'],
    "vyaḍambana": ['mw'],
    "vyaḍaṃbakaḥ": ['ap90'],
    "vyaḍḍa": ['ddsa', 'mw'],
    "vyaḥ": ['ap90'],
    "vyaṃga": ['ap90'],
    "vyaṃgayati": ['ap90'],
    "vyaṃgitā": ['ap90'],
    "vyaṃgulaṃ": ['ap90'],
    "vyaṃgya": ['ap90'],
    "vyaṃj": ['ap90'],
    "vyaṃjaka": ['ap90'],
    "vyaṃjanaṃ": ['ap90'],
    "vyaṃjanā": ['ap90'],
    "vyaṃjita": ['ap90'],
    "vyaṃs": ['ap90', 'mw'],
    "vyaṃsa": ['cae', 'ddsa', 'gra', 'mw'],
    "vyaṃsaka": ['bhs', 'mw'],
    "vyaṃsakaḥ": ['ap90'],
    "vyaṃsana": ['cae', 'mw'],
    "vyaṃsanaṃ": ['ap90'],
    "vyaṃsanīya": ['mw'],
    "vyaṃsayati": ['bhs'],
    "vyaṃsayitavya": ['cae', 'ddsa', 'mw'],
    "vyaṃsita": ['mw'],
    "vyaṃtaraḥ": ['ap90'],
    "vyaṃśa": ['mw'],
    "vyaṃśaka": ['ap90', 'mw'],
    "vyaṃśuka": ['mw'],
    "vyaṃśukaḥ": ['ap90'],
    "vyaṅga": ['cae', 'ddsa', 'mw'],
    "vyaṅgatva": ['mw'],
    "vyaṅgatā": ['mw'],
    "vyaṅgay": ['cae'],
    "vyaṅgaya": ['ddsa', 'mw'],
    "vyaṅgin": ['cae', 'mw'],
    "vyaṅgita": ['mw'],
    "vyaṅgitaikeṣaṇa": ['mw'],
    "vyaṅgula": ['mw'],
    "vyaṅgulīkṛ": ['mw'],
    "vyaṅguṣṭha": ['mw'],
    "vyaṅgya": ['cae', 'ddsa', 'mw'],
    "vyaṅgyokti": ['mw'],
    "vyaṅgyārthadīpikā": ['mw'],
    "vyaṅgyārthakaumudī": ['mw'],
    "vyaṅgāra": ['ddsa', 'mw'],
    "vyaṅgāre": ['cae', 'mw'],
    "vyaṅgārin": ['mw'],
    "vyaṅgārtha": ['mw'],
    "vyaṅgārthadīpinī": ['mw'],
    "vyaṅgīkṛ": ['mw'],
    "vyaṅkaṭa": ['mw'],
    "vyaṅkuśa": ['mw'],
    "vyaṣṭaka": ['mw'],
    "vyaṣṭakā": ['mw'],
    "vyaṣṭha": ['mw'],
    "vyaṣṭi": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyaṣṭisamaṣṭitā": ['cae', 'mw'],
    "vyaṣṭyabhiprāya": ['mw'],
    "vye": ['ap90', 'mw'],
    "vyeka": ['mw'],
    "vyeman": ['mw'],
    "vyemāna": ['mw'],
    "vyenas": ['cae', 'ddsa', 'gra', 'mw'],
    "vyenī": ['mw'],
    "vyeta": ['gra'],
    "vyodana": ['gra', 'mw'],
    "vyokas": ['cae', 'mw'],
    "vyokāra": ['ddsa', 'mw'],
    "vyokāraḥ": ['ap90'],
    "vyoma": ['mw'],
    "vyomacara": ['cae', 'mw'],
    "vyomacārin": ['cae', 'mw'],
    "vyomacāripura": ['mw'],
    "vyomadeva": ['mw'],
    "vyomadhvani": ['mw'],
    "vyomadhāraṇa": ['mw'],
    "vyomadhūma": ['mw'],
    "vyomaga": ['cae', 'ddsa', 'mw'],
    "vyomagamanī": ['mw'],
    "vyomagaṅgā": ['mw'],
    "vyomaguṇa": ['mw'],
    "vyomagāmin": ['cae', 'mw'],
    "vyomaikāntavihārin": ['mw'],
    "vyomaka": ['bhs', 'mw'],
    "vyomakeśa": ['mw'],
    "vyomakeśin": ['mw'],
    "vyomamadhye": ['mw'],
    "vyomamañjara": ['mw'],
    "vyomamaṇḍala": ['mw'],
    "vyomamudgara": ['mw'],
    "vyomamāya": ['mw'],
    "vyomamṛga": ['mw'],
    "vyoman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vyomanāsikā": ['mw'],
    "vyomapañcaka": ['mw'],
    "vyomapuṣpa": ['mw'],
    "vyomapāda": ['mw'],
    "vyomaratna": ['mw'],
    "vyomasad": ['cae', 'gra', 'mw'],
    "vyomasambhavā": ['mw'],
    "vyomasarit": ['mw'],
    "vyomaspṛś": ['cae', 'mw'],
    "vyomastha": ['mw'],
    "vyomasthalī": ['mw'],
    "vyomavallikā": ['mw'],
    "vyomavartman": ['mw'],
    "vyomavatī": ['mw'],
    "vyomavistṛta": ['mw'],
    "vyomavyāpin": ['ddsa', 'mw'],
    "vyomayāna": ['mw'],
    "vyomaśabda": ['mw'],
    "vyomaśivācārya": ['mw'],
    "vyomin": ['mw'],
    "vyomnika": ['mw'],
    "vyomodaka": ['mw'],
    "vyomābha": ['mw'],
    "vyomādhipa": ['mw'],
    "vyomākhya": ['mw'],
    "vyomānta": ['mw'],
    "vyomāri": ['mw'],
    "vyoṣa": ['cae', 'mw'],
    "vyoṣaṃ": ['ap90'],
    "vyoṣita": ['bhs'],
    "vyu": ['mw'],
    "vyubj": ['mw'],
    "vyuccar": ['ap90', 'mw'],
    "vyuccaraṇaṃ": ['ap90'],
    "vyuccha": ['ddsa'],
    "vyucchat": ['mw'],
    "vyuccheda": ['mw'],
    "vyucchettṛ": ['mw'],
    "vyucchid": ['mw'],
    "vyucchinna": ['mw'],
    "vyucchitti": ['cae', 'mw'],
    "vyucchittiḥ": ['ap90'],
    "vyucya": ['cae', 'mw'],
    "vyud": ['mw'],
    "vyuda": ['cae', 'mw'],
    "vyudaka": ['cae', 'mw'],
    "vyudas": ['ap90', 'mw'],
    "vyudasta": ['ap90', 'mw'],
    "vyuddhāv": ['mw'],
    "vyuddhṛ": ['mw'],
    "vyudgranthana": ['mw'],
    "vyudita": ['ap90', 'mw'],
    "vyudāhāra": ['bhs'],
    "vyudāsa": ['cae', 'mw'],
    "vyudāsaḥ": ['ap90'],
    "vyudūh": ['mw'],
    "vyukṣ": ['mw'],
    "vyund": ['mw'],
    "vyundana": ['cae', 'mw'],
    "vyunmiśra": ['mw'],
    "vyupa": ['mw'],
    "vyupadeśa": ['mw'],
    "vyupadeśaḥ": ['ap90'],
    "vyupadiṣṭa": ['bhs'],
    "vyupadrava": ['mw'],
    "vyupajāpa": ['mw'],
    "vyupakāra": ['mw'],
    "vyupanāmayati": ['bhs'],
    "vyupanī": ['mw'],
    "vyupaparīkṣate": ['bhs'],
    "vyupaparīkṣaṇa": ['bhs'],
    "vyupapatti": ['bhs', 'mw'],
    "vyuparam": ['mw'],
    "vyuparama": ['cae', 'mw'],
    "vyuparamam": ['mw'],
    "vyuparamaḥ": ['ap90'],
    "vyuparata": ['mw'],
    "vyupaskara": ['mw'],
    "vyupasthāna": ['bhs'],
    "vyupatoda": ['mw'],
    "vyupaviś": ['mw'],
    "vyupavīta": ['mw'],
    "vyupayuj": ['mw'],
    "vyupaśam": ['mw'],
    "vyupaśama": ['bhs', 'cae', 'mw'],
    "vyupaśamana": ['bhs'],
    "vyupaśamaḥ": ['ap90'],
    "vyupaśānta": ['bhs', 'mw'],
    "vyupaśānti": ['bhs'],
    "vyupe": ['mw'],
    "vyupta": ['mw'],
    "vyuptajaṭākalāpa": ['mw'],
    "vyuptakeśa": ['mw'],
    "vyupāram": ['mw'],
    "vyupās": ['mw'],
    "vyuta": ['cae', 'mw'],
    "vyuti": ['mw'],
    "vyutkaṇṭhaśa": ['bhs'],
    "vyutkhaṇḍaśaḥ": ['bhs'],
    "vyutkram": ['ap90', 'mw'],
    "vyutkrama": ['cae', 'mw'],
    "vyutkramaḥ": ['ap90'],
    "vyutkramaṇa": ['mw'],
    "vyutkrānta": ['mw'],
    "vyutkrāntadharma": ['mw'],
    "vyutkrāntajīvita": ['mw'],
    "vyutkrāntaka": ['bhs'],
    "vyutkrāntakasamāpatti": ['mw'],
    "vyutkrāntarajas": ['mw'],
    "vyutkrāntavartman": ['mw'],
    "vyutkrāntā": ['mw'],
    "vyutkrāṃta": ['ap90'],
    "vyutpad": ['ap90', 'mw'],
    "vyutpadyati": ['bhs'],
    "vyutpanna": ['ap90', 'cae', 'mw'],
    "vyutpatti": ['cae', 'mw'],
    "vyutpattidīpikā": ['mw'],
    "vyutpattimat": ['mw'],
    "vyutpattipakṣe": ['mw'],
    "vyutpattirahasya": ['mw'],
    "vyutpattirahita": ['mw'],
    "vyutpattiratnākara": ['mw'],
    "vyutpattivāda": ['mw'],
    "vyutpattivādakroḍapattra": ['mw'],
    "vyutpattivādaparyāyapattra": ['mw'],
    "vyutpattivādapattra": ['mw'],
    "vyutpattivādarahasya": ['mw'],
    "vyutpattivādaṭīkā": ['mw'],
    "vyutpattivādārtha": ['mw'],
    "vyutpattiḥ": ['ap90'],
    "vyutpitsu": ['mw'],
    "vyutpādaka": ['mw'],
    "vyutpādana": ['mw'],
    "vyutpādya": ['mw'],
    "vyutsad": ['mw'],
    "vyutsarga": ['mw'],
    "vyutseka": ['mw'],
    "vyutsic": ['mw'],
    "vyutsṛj": ['mw'],
    "vyutsṛp": ['mw'],
    "vyutta": ['ap90', 'mw'],
    "vyutthita": ['cae', 'mw'],
    "vyutthitacitta": ['mw'],
    "vyutthitacittendriya": ['mw'],
    "vyutthitacittāśva": ['mw'],
    "vyutthā": ['ap90', 'mw'],
    "vyutthāna": ['cae', 'mw'],
    "vyutthānaṃ": ['ap90'],
    "vyutthāpana": ['bhs'],
    "vyutthāpita": ['mw'],
    "vyutthātavya": ['mw'],
    "vyuttiṣṭhati": ['bhs'],
    "vyuttras": ['mw'],
    "vyuttṝ": ['mw'],
    "vyuṣ": ['cae', 'gra', 'mw'],
    "vyuṣasa": ['mw'],
    "vyuṣita": ['cae', 'mw'],
    "vyuṣitāśva": ['mw'],
    "vyuṣṭa": ['ap90', 'cae', 'mw'],
    "vyuṣṭatrirātra": ['mw'],
    "vyuṣṭi": ['cae', 'gra', 'mw'],
    "vyuṣṭimant": ['cae'],
    "vyuṣṭimat": ['mw'],
    "vyuṣṭitrirātra": ['mw'],
    "vyuṣṭiḥ": ['ap90'],
    "vyā": ['cae', 'ddsa', 'gra'],
    "vyābhagna": ['mw'],
    "vyābhaṅgī": ['cped'],
    "vyābhram": ['mw'],
    "vyābhugna": ['cae', 'mw'],
    "vyābhyukṣī": ['ap90', 'mw'],
    "vyābhāṣ": ['mw'],
    "vyābhāṣaka": ['mw'],
    "vyābhāṣaṇa": ['mw'],
    "vyābhāṣita": ['mw'],
    "vyābādh": ['mw'],
    "vyābādha": ['bhs', 'mw'],
    "vyābādhati": ['bhs'],
    "vyābādhesi": ['cped'],
    "vyābādheti": ['cped'],
    "vyābādhetvā": ['cped'],
    "vyābādhika": ['bhs'],
    "vyābādhita": ['cped'],
    "vyācakṣ": ['mw'],
    "vyācikhyāsita": ['mw'],
    "vyācikhyāsitagrantha": ['mw'],
    "vyācikhyāsu": ['mw'],
    "vyācint": ['mw'],
    "vyādeśa": ['cae', 'mw'],
    "vyādha": ['cae', 'cped', 'ddsa', 'mw'],
    "vyādhabhīta": ['mw'],
    "vyādhagīti": ['mw'],
    "vyādhaka": ['cae', 'mw'],
    "vyādhatā": ['mw'],
    "vyādhaḥ": ['ap90'],
    "vyādhi": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vyādhibahula": ['cae', 'mw'],
    "vyādhibhaya": ['mw'],
    "vyādhidharmin": ['mw'],
    "vyādhidurbhikṣapīḍita": ['mw'],
    "vyādhighna": ['mw'],
    "vyādhighāta": ['mw'],
    "vyādhigrasta": ['mw'],
    "vyādhihantṛ": ['mw'],
    "vyādhika": ['bhs'],
    "vyādhikara": ['mw'],
    "vyādhin": ['ap90', 'cae', 'mw'],
    "vyādhinigraha": ['mw'],
    "vyādhinirjaya": ['mw'],
    "vyādhiprajñāyate": ['bhs'],
    "vyādhipīḍita": ['mw'],
    "vyādhirahita": ['mw'],
    "vyādhiripu": ['mw'],
    "vyādhisamuddeśīya": ['mw'],
    "vyādhisaṃghavimardana": ['mw'],
    "vyādhisiddhāñjana": ['mw'],
    "vyādhisindhu": ['mw'],
    "vyādhisthāna": ['mw'],
    "vyādhita": ['ap90', 'cped', 'mw'],
    "vyādhivardhaka": ['mw'],
    "vyādhiyukta": ['mw'],
    "vyādhiḥ": ['ap90'],
    "vyādhmātaka": ['bhs', 'mw'],
    "vyādhuta": ['mw'],
    "vyādhy": ['mw'],
    "vyādhya": ['mw'],
    "vyādhyargala": ['mw'],
    "vyādhyupaśama": ['mw'],
    "vyādhyārta": ['cae', 'mw'],
    "vyādhā": ['mw'],
    "vyādhāma": ['mw'],
    "vyādhāmaḥ": ['ap90'],
    "vyādhāya": ['ddsa', 'mw'],
    "vyādhī": ['cae', 'mw'],
    "vyādhū": ['mw'],
    "vyādhūta": ['ap90', 'mw'],
    "vyādita": ['mw'],
    "vyāditāsya": ['mw'],
    "vyādiś": ['ap90', 'mw'],
    "vyādiśa": ['mw'],
    "vyādiśaḥ": ['ap90'],
    "vyādiṣṭa": ['mw'],
    "vyādā": ['ap90', 'mw'],
    "vyādāna": ['cae', 'ddsa', 'mw'],
    "vyādānaṃ": ['ap90'],
    "vyādāya": ['mw'],
    "vyādāyasvāpin": ['mw'],
    "vyādīp": ['mw'],
    "vyādīrgha": ['ddsa', 'mw'],
    "vyādīrṇa": ['mw'],
    "vyādīrṇāsya": ['mw'],
    "vyādṛś": ['mw'],
    "vyāghatika": ['bhs'],
    "vyāghaṭṭana": ['mw'],
    "vyāghaṭṭanaṃ": ['ap90'],
    "vyāghaṭṭanā": ['mw'],
    "vyāghaṭṭita": ['mw'],
    "vyāghra": ['cae', 'ddsa', 'mw'],
    "vyāghrabala": ['bhs', 'mw'],
    "vyāghrabhaṭa": ['mw'],
    "vyāghrabhūti": ['mw'],
    "vyāghracarmamaya": ['mw'],
    "vyāghracarman": ['cae', 'mw'],
    "vyāghradala": ['mw'],
    "vyāghradatta": ['mw'],
    "vyāghradaṃṣṭra": ['mw'],
    "vyāghragaṇa": ['mw'],
    "vyāghragiri": ['mw'],
    "vyāghragrīva": ['mw'],
    "vyāghrajambhana": ['mw'],
    "vyāghraka": ['mw'],
    "vyāghraketu": ['mw'],
    "vyāghraloman": ['cae', 'mw'],
    "vyāghramukha": ['mw'],
    "vyāghramārin": ['mw'],
    "vyāghranakha": ['bhs', 'mw'],
    "vyāghranakhaka": ['mw'],
    "vyāghranāyaka": ['mw'],
    "vyāghrapad": ['mw'],
    "vyāghrapada": ['mw'],
    "vyāghrapadya": ['bhs', 'mw'],
    "vyāghraparākrama": ['mw'],
    "vyāghrapatsmṛti": ['mw'],
    "vyāghrapratīka": ['mw'],
    "vyāghrapuccha": ['mw'],
    "vyāghrapucchaka": ['mw'],
    "vyāghrapura": ['mw'],
    "vyāghrapuṣpi": ['mw'],
    "vyāghrapād": ['mw'],
    "vyāghrapāda": ['mw'],
    "vyāghrapādasmṛti": ['mw'],
    "vyāghrapādastotra": ['mw'],
    "vyāghrarāja": ['mw'],
    "vyāghrarūpā": ['mw'],
    "vyāghrasena": ['mw'],
    "vyāghrasevaka": ['mw'],
    "vyāghrasmṛti": ['mw'],
    "vyāghratala": ['mw'],
    "vyāghratva": ['mw'],
    "vyāghratā": ['mw'],
    "vyāghravadhū": ['mw'],
    "vyāghravaktra": ['mw'],
    "vyāghravaktrā": ['mw'],
    "vyāghraśvan": ['mw'],
    "vyāghraśveta": ['mw'],
    "vyāghraḥ": ['ap90'],
    "vyāghreśvara": ['mw'],
    "vyāghriṇī": ['mw'],
    "vyāghrya": ['cae', 'mw'],
    "vyāghrā": ['mw'],
    "vyāghrādanī": ['mw'],
    "vyāghrādinī": ['mw'],
    "vyāghrājina": ['mw'],
    "vyāghrākṣa": ['mw'],
    "vyāghrāsya": ['mw'],
    "vyāghrāsyā": ['mw'],
    "vyāghrāṇa": ['mw'],
    "vyāghrāṭa": ['mw'],
    "vyāghrī": ['ddsa', 'mw'],
    "vyāghrījātaka": ['bhs'],
    "vyāghuṣ": ['mw'],
    "vyāghuṣṭa": ['mw'],
    "vyāghuṭ": ['mw'],
    "vyāghuṭana": ['mw'],
    "vyāghāraṇa": ['cae', 'mw'],
    "vyāghārita": ['mw'],
    "vyāghāta": ['cae', 'mw'],
    "vyāghātaka": ['ap90', 'mw'],
    "vyāghātaḥ": ['ap90'],
    "vyāghātima": ['mw'],
    "vyāghātin": ['mw'],
    "vyāghūrṇ": ['mw'],
    "vyāghūrṇita": ['mw'],
    "vyāghṛ": ['mw'],
    "vyāhan": ['ap90', 'mw'],
    "vyāhanasya": ['mw'],
    "vyāhantavya": ['mw'],
    "vyāharati": ['bhs', 'cped'],
    "vyāharaṇa": ['cae', 'mw'],
    "vyāharaṇaṃ": ['ap90'],
    "vyāhari": ['cped'],
    "vyāharitvā": ['cped'],
    "vyāhartavya": ['mw'],
    "vyāhata": ['ap90', 'mw'],
    "vyāhatatva": ['mw'],
    "vyāhati": ['mw'],
    "vyāhaṭa": ['cped'],
    "vyāhita": ['cae'],
    "vyāhruti": ['mw'],
    "vyāhve": ['mw'],
    "vyāhāra": ['bhs', 'cae', 'mw'],
    "vyāhāramaya": ['mw'],
    "vyāhāraḥ": ['ap90'],
    "vyāhārin": ['cae', 'mw'],
    "vyāhāva": ['mw'],
    "vyāhāvam": ['mw'],
    "vyāhāvaḥ": ['ap90'],
    "vyāhṛ": ['ap90', 'mw'],
    "vyāhṛta": ['ap90', 'cae', 'mw'],
    "vyāhṛtasaṃdeśa": ['mw'],
    "vyāhṛti": ['cae', 'mw'],
    "vyāhṛtipūrvaka": ['mw'],
    "vyāhṛtitraya": ['mw'],
    "vyāhṛtiḥ": ['ap90'],
    "vyāja": ['cae', 'ddsa', 'mw'],
    "vyājabhānujit": ['mw'],
    "vyājaguru": ['mw'],
    "vyājahata": ['mw'],
    "vyājahaṃsāvalī": ['mw'],
    "vyājakheda": ['mw'],
    "vyājamaya": ['cae', 'mw'],
    "vyājanidrita": ['mw'],
    "vyājanindā": ['cae', 'mw'],
    "vyājapūrva": ['mw'],
    "vyājasakhī": ['mw'],
    "vyājastuti": ['cae', 'mw'],
    "vyājasupta": ['cae', 'ddsa', 'mw'],
    "vyājatapodhana": ['mw'],
    "vyājaviṣṇu": ['mw'],
    "vyājavyavahāra": ['mw'],
    "vyājay": ['cae'],
    "vyājaya": ['ddsa', 'mw'],
    "vyājaḥ": ['ap90'],
    "vyājihma": ['mw'],
    "vyājokti": ['mw'],
    "vyājābhiprāya": ['mw'],
    "vyājāhvaya": ['mw'],
    "vyājī": ['mw'],
    "vyājīkaraṇa": ['mw'],
    "vyājīkṛ": ['mw'],
    "vyājṛmbh": ['mw'],
    "vyākaraṇa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vyākaraṇadurghaṭodghāṭa": ['mw'],
    "vyākaraṇadīpa": ['mw'],
    "vyākaraṇadīpavyākaraṇa": ['mw'],
    "vyākaraṇadīpikā": ['mw'],
    "vyākaraṇaka": ['mw'],
    "vyākaraṇakaustubha": ['mw'],
    "vyākaraṇakauṇḍinya": ['mw'],
    "vyākaraṇakhaṇḍana": ['mw'],
    "vyākaraṇamahābhāṣya": ['mw'],
    "vyākaraṇamūla": ['mw'],
    "vyākaraṇaprakriyā": ['mw'],
    "vyākaraṇasaṃgraha": ['mw'],
    "vyākaraṇasiddha": ['mw'],
    "vyākaraṇasāra": ['mw'],
    "vyākaraṇatraya": ['mw'],
    "vyākaraṇavādagrantha": ['mw'],
    "vyākaraṇaḍhuṇḍhikā": ['mw'],
    "vyākaraṇaṃ": ['ap90'],
    "vyākaraṇottara": ['mw'],
    "vyākaraṇāgama": ['mw'],
    "vyākaraṇātmaka": ['mw'],
    "vyākari": ['cped'],
    "vyākaritvā": ['cped'],
    "vyākariyamāna": ['cped'],
    "vyākaroti": ['bhs', 'cped'],
    "vyākartṛ": ['mw'],
    "vyākartṛtva": ['mw'],
    "vyākarṣaṇa": ['mw'],
    "vyākata": ['cped'],
    "vyākhyeya": ['mw'],
    "vyākhyā": ['ap90', 'cae', 'mw'],
    "vyākhyāgamya": ['mw'],
    "vyākhyākusumāvalī": ['mw'],
    "vyākhyākṛt": ['mw'],
    "vyākhyāmṛta": ['mw'],
    "vyākhyāna": ['cae', 'mw'],
    "vyākhyānamālā": ['mw'],
    "vyākhyānanda": ['mw'],
    "vyākhyānaprakriyā": ['mw'],
    "vyākhyānaratnāvalī": ['mw'],
    "vyākhyānavivaraṇa": ['mw'],
    "vyākhyānay": ['cae'],
    "vyākhyānaya": ['mw'],
    "vyākhyānayogya": ['mw'],
    "vyākhyānaśālā": ['mw'],
    "vyākhyānaṃ": ['ap90'],
    "vyākhyāparimala": ['mw'],
    "vyākhyāpradīpa": ['mw'],
    "vyākhyāratnāvalī": ['mw'],
    "vyākhyāsi": ['cped'],
    "vyākhyāsthāna": ['mw'],
    "vyākhyāsudhā": ['mw'],
    "vyākhyāsvara": ['mw'],
    "vyākhyāsāra": ['mw'],
    "vyākhyāta": ['ap90', 'cped', 'mw'],
    "vyākhyātavya": ['cae', 'mw'],
    "vyākhyāti": ['cped'],
    "vyākhyātrī": ['mw'],
    "vyākhyātṛ": ['ap90', 'cae', 'mw'],
    "vyākhyāyikā": ['mw'],
    "vyākhyāyukti": ['mw'],
    "vyākhyāśloka": ['mw'],
    "vyākoca": ['mw'],
    "vyākopa": ['mw'],
    "vyākopayati": ['bhs'],
    "vyākośa": ['ap90', 'cae', 'mw'],
    "vyākośakohanada": ['mw'],
    "vyākośakohanadatā": ['mw'],
    "vyākośīkṛ": ['mw'],
    "vyākoṣa": ['ap90'],
    "vyākriyā": ['mw'],
    "vyākrośa": ['cae', 'mw'],
    "vyākrośaka": ['mw'],
    "vyākruś": ['mw'],
    "vyākula": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vyākulacetas": ['mw'],
    "vyākulacitta": ['mw'],
    "vyākuladhruva": ['mw'],
    "vyākulahṛdaya": ['mw'],
    "vyākulalocana": ['mw'],
    "vyākulam": ['mw'],
    "vyākulamanas": ['mw'],
    "vyākulamānasa": ['mw'],
    "vyākulamūrdhaja": ['mw'],
    "vyākulatva": ['mw'],
    "vyākulatā": ['mw'],
    "vyākulaveṣṭana": ['mw'],
    "vyākulay": ['cae'],
    "vyākulaya": ['ddsa', 'mw'],
    "vyākulayati": ['ap90'],
    "vyākulendriya": ['mw'],
    "vyākulika": ['bhs'],
    "vyākulita": ['ap90', 'mw'],
    "vyākulitacetana": ['mw'],
    "vyākulitahṛdaya": ['mw'],
    "vyākulitamanas": ['mw'],
    "vyākulitendriya": ['mw'],
    "vyākulitin": ['mw'],
    "vyākulitāntarātman": ['mw'],
    "vyākulālāpa": ['ddsa', 'mw'],
    "vyākulī": ['mw'],
    "vyākulībhū": ['ap90', 'mw'],
    "vyākulībhūta": ['mw'],
    "vyākulīkṛ": ['ap90', 'cae', 'mw'],
    "vyākulīkṛta": ['ddsa', 'mw'],
    "vyākutsanā": ['bhs'],
    "vyākuñcita": ['mw'],
    "vyākāra": ['mw'],
    "vyākāradīpikā": ['mw'],
    "vyākāraḥ": ['ap90'],
    "vyākīrṇa": ['ap90', 'mw'],
    "vyākīrṇakeśara": ['mw'],
    "vyākīrṇamālyakavara": ['mw'],
    "vyākīrṇārcis": ['mw'],
    "vyākūta": ['mw'],
    "vyākūti": ['mw'],
    "vyākūtiḥ": ['ap90'],
    "vyākṛ": ['ap90', 'mw'],
    "vyākṛta": ['ap90', 'mw'],
    "vyākṛti": ['bhs', 'cae', 'ddsa', 'mw'],
    "vyākṛtiḥ": ['ap90'],
    "vyākṛṣ": ['mw'],
    "vyākṛṣṭa": ['mw'],
    "vyākṣepa": ['cae', 'mw'],
    "vyākṣepaḥ": ['ap90'],
    "vyākṣepin": ['cae', 'mw'],
    "vyākṣip": ['ap90', 'mw'],
    "vyākṣipta": ['ap90', 'mw'],
    "vyākṣiptahṛdaya": ['mw'],
    "vyākṣiptamanas": ['mw'],
    "vyākṣobha": ['mw'],
    "vyākṣobhaḥ": ['ap90'],
    "vyāla": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyālabala": ['mw'],
    "vyāladaṃṣṭra": ['mw'],
    "vyāladaṃṣṭraka": ['mw'],
    "vyāladreṣkāṇa": ['mw'],
    "vyālagandhā": ['mw'],
    "vyālagrāha": ['cae', 'mw'],
    "vyālagrāhin": ['mw'],
    "vyālagrāhiṇī": ['mw'],
    "vyālagrīva": ['mw'],
    "vyālajihvā": ['mw'],
    "vyālaka": ['bhs', 'mw'],
    "vyālakaraja": ['mw'],
    "vyālakaḥ": ['ap90'],
    "vyālakhaḍga": ['mw'],
    "vyālamb": ['mw'],
    "vyālamba": ['cae', 'ddsa', 'mw'],
    "vyālambahasta": ['mw'],
    "vyālambin": ['cae', 'mw'],
    "vyālamṛga": ['cae', 'mw'],
    "vyālanakha": ['mw'],
    "vyālapattrā": ['mw'],
    "vyālapraharaṇa": ['mw'],
    "vyālapāṇija": ['mw'],
    "vyālarūpa": ['mw'],
    "vyālatama": ['mw'],
    "vyālatva": ['mw'],
    "vyālavala": ['mw'],
    "vyālavarga": ['mw'],
    "vyālavat": ['mw'],
    "vyālaśikṣā": ['mw'],
    "vyālaṃbaḥ": ['ap90'],
    "vyāli": ['mw'],
    "vyālikh": ['mw'],
    "vyālola": ['ap90', 'cae', 'mw'],
    "vyālolakuntalakalāpavat": ['mw'],
    "vyālolana": ['mw'],
    "vyāloḍita": ['mw'],
    "vyālup": ['mw'],
    "vyālāyudha": ['mw'],
    "vyālī": ['mw'],
    "vyālībhūta": ['mw'],
    "vyālīna": ['ap90', 'mw'],
    "vyālīya": ['mw'],
    "vyālūna": ['mw'],
    "vyāl̤i": ['cae', 'mw'],
    "vyāma": ['cae', 'cped', 'ddsa', 'mw'],
    "vyāmaka": ['bhs'],
    "vyāmamātra": ['mw'],
    "vyāmana": ['mw'],
    "vyāmaprabhā": ['bhs'],
    "vyāmarśa": ['mw'],
    "vyāmarṣa": ['mw'],
    "vyāmarṣaḥ": ['ap90'],
    "vyāmaḥ": ['ap90'],
    "vyāmiśra": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyāmiśratā": ['mw'],
    "vyāmiśre": ['mw'],
    "vyāmoha": ['cae', 'mw'],
    "vyāmohaka": ['bhs'],
    "vyāmohavidrāvana": ['mw'],
    "vyāmohaḥ": ['ap90'],
    "vyāmohin": ['mw'],
    "vyāmohita": ['mw'],
    "vyāmohitacitta": ['mw'],
    "vyāmoka": ['mw'],
    "vyāmotsaṅga": ['bhs'],
    "vyāmuc": ['mw'],
    "vyāmuh": ['mw'],
    "vyāmya": ['mw'],
    "vyāmīl": ['mw'],
    "vyāmūḍha": ['cae', 'mw'],
    "vyāmṛṣṭa": ['mw'],
    "vyāmṛṣṭatilaka": ['mw'],
    "vyāna": ['cae', 'ddsa', 'mw'],
    "vyānabhṛt": ['mw'],
    "vyānaddha": ['mw'],
    "vyānadā": ['cae', 'mw'],
    "vyānadṛh": ['mw'],
    "vyānam": ['mw'],
    "vyānamra": ['cae', 'mw'],
    "vyānamrīkṛ": ['mw'],
    "vyānata": ['mw'],
    "vyānatakaraṇa": ['mw'],
    "vyānataṃ": ['ap90'],
    "vyānaśi": ['cae', 'gra', 'mw'],
    "vyānaśin": ['mw'],
    "vyānaḥ": ['ap90'],
    "vyānodāna": ['cae', 'mw'],
    "vyānī": ['mw'],
    "vyāp": ['ap90', 'mw'],
    "vyāpad": ['ap90', 'cae', 'mw'],
    "vyāpadyate": ['bhs'],
    "vyāpajjanā": ['cped'],
    "vyāpajjati": ['cped'],
    "vyāpajji": ['cped'],
    "vyāpaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vyāpakanyāsa": ['mw'],
    "vyāpakatva": ['mw'],
    "vyāpakatā": ['mw'],
    "vyāpakatāvādārtha": ['mw'],
    "vyāpalaṇḍikā": ['mw'],
    "vyāpana": ['ddsa', 'mw'],
    "vyāpanaṃ": ['ap90'],
    "vyāpanna": ['ap90', 'bhs', 'cped', 'mw'],
    "vyāpannacitta": ['mw'],
    "vyāpanīya": ['mw'],
    "vyāparita": ['mw'],
    "vyāpatti": ['cae', 'ddsa', 'mw'],
    "vyāpattiḥ": ['ap90'],
    "vyāpenta": ['cped'],
    "vyāpesi": ['cped'],
    "vyāpeti": ['cped'],
    "vyāpetvā": ['cped'],
    "vyāpi": ['mw'],
    "vyāpikā": ['mw'],
    "vyāpin": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyāpita": ['cae', 'cped', 'mw'],
    "vyāpitva": ['cae', 'mw'],
    "vyāpta": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyāptatama": ['mw'],
    "vyāpti": ['cae', 'mw'],
    "vyāptigraha": ['mw'],
    "vyāptigrahopāya": ['mw'],
    "vyāptigrahopāyapūrvapakṣaprakāśa": ['mw'],
    "vyāptigrahopāyarahasya": ['mw'],
    "vyāptigrahopāyaṭippaṇī": ['mw'],
    "vyāptijñāna": ['mw'],
    "vyāptikarman": ['mw'],
    "vyāptilakṣaṇa": ['mw'],
    "vyāptimant": ['cae'],
    "vyāptimat": ['mw'],
    "vyāptimattva": ['mw'],
    "vyāptinirūpaṇa": ['mw'],
    "vyāptiniścaya": ['mw'],
    "vyāptipariṣkāra": ['mw'],
    "vyāptipañcaka": ['mw'],
    "vyāptipañcakarahasya": ['mw'],
    "vyāptipañcakaṭīkā": ['mw'],
    "vyāptipūrvapakṣaprakāśa": ['mw'],
    "vyāptipūrvapakṣarahasya": ['mw'],
    "vyāptivāda": ['mw'],
    "vyāptivādakroḍa": ['mw'],
    "vyāptivādakroḍapattra": ['mw'],
    "vyāptivādaprakāśa": ['mw'],
    "vyāptivādarahasya": ['mw'],
    "vyāptiḥ": ['ap90'],
    "vyāpty": ['mw'],
    "vyāptyanugama": ['mw'],
    "vyāptyanugamaprakāśa": ['mw'],
    "vyāptyanugamarahasya": ['mw'],
    "vyāptyanugamavādārtha": ['mw'],
    "vyāptyanugamāloka": ['mw'],
    "vyāptāntara": ['mw'],
    "vyāpva": ['mw'],
    "vyāpya": ['ap90', 'cae', 'mw'],
    "vyāpyamāna": ['mw'],
    "vyāpyatva": ['mw'],
    "vyāpyatvaṃ": ['ap90'],
    "vyāpyatā": ['mw'],
    "vyāpāda": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vyāpādaka": ['ap90', 'mw'],
    "vyāpādana": ['cae', 'mw'],
    "vyāpādanīya": ['mw'],
    "vyāpādanīyatā": ['mw'],
    "vyāpādayitavya": ['mw'],
    "vyāpādaḥ": ['ap90'],
    "vyāpādeti": ['cped'],
    "vyāpādita": ['ap90', 'mw'],
    "vyāpāditavat": ['mw'],
    "vyāpādya": ['mw'],
    "vyāpāra": ['cae', 'cped', 'mw'],
    "vyāpāraka": ['mw'],
    "vyāpārakāraka": ['mw'],
    "vyāpārakārin": ['mw'],
    "vyāpārarodhin": ['mw'],
    "vyāpāravat": ['mw'],
    "vyāpāravattā": ['mw'],
    "vyāpāraḥ": ['ap90'],
    "vyāpāraṇa": ['mw'],
    "vyāpārin": ['ap90', 'cae', 'mw'],
    "vyāpārita": ['ap90', 'cped'],
    "vyāpāta": ['mw'],
    "vyāpīta": ['cae', 'mw'],
    "vyāpṛ": ['ap90', 'mw'],
    "vyāpṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyāpṛti": ['cae', 'mw'],
    "vyāpṛtiḥ": ['ap90'],
    "vyārabdha": ['mw'],
    "vyāroṣa": ['bhs', 'mw'],
    "vyārta": ['bhs', 'mw'],
    "vyāsa": ['cae', 'ddsa', 'mw'],
    "vyāsabhāṣyavyākhyā": ['mw'],
    "vyāsacaritra": ['mw'],
    "vyāsadarśanaprakāra": ['mw'],
    "vyāsadatti": ['mw'],
    "vyāsadeva": ['mw'],
    "vyāsadāsa": ['mw'],
    "vyāsagadya": ['mw'],
    "vyāsagaṇapati": ['mw'],
    "vyāsagiri": ['mw'],
    "vyāsagītā": ['mw'],
    "vyāsajati": ['bhs'],
    "vyāsajya": ['mw'],
    "vyāsajyaceta": ['mw'],
    "vyāsajyavṛtti": ['mw'],
    "vyāsakeśava": ['mw'],
    "vyāsakta": ['ap90', 'mw'],
    "vyāsakūṭa": ['mw'],
    "vyāsamātṛ": ['mw'],
    "vyāsamūrti": ['mw'],
    "vyāsanābha": ['mw'],
    "vyāsanārāyaṇa": ['mw'],
    "vyāsaparipṛcchā": ['bhs', 'mw'],
    "vyāsaprabhākara": ['mw'],
    "vyāsapūjanasaṃhitā": ['mw'],
    "vyāsapūjā": ['mw'],
    "vyāsapūjāpaddhati": ['mw'],
    "vyāsapūjāvidhi": ['mw'],
    "vyāsarāja": ['mw'],
    "vyāsasadānandajī": ['mw'],
    "vyāsasamāsa": ['mw'],
    "vyāsasamāsatas": ['ddsa', 'mw'],
    "vyāsasamāsin": ['mw'],
    "vyāsasiddhānta": ['mw'],
    "vyāsasmṛti": ['mw'],
    "vyāsasthalī": ['mw'],
    "vyāsastuti": ['mw'],
    "vyāsasū": ['mw'],
    "vyāsasūtra": ['mw'],
    "vyāsasūtrabhāṣya": ['mw'],
    "vyāsasūtracandrikā": ['mw'],
    "vyāsasūtrasaṃgati": ['mw'],
    "vyāsasūtravyākhyā": ['mw'],
    "vyāsasūtravṛtti": ['mw'],
    "vyāsasūtraśaṃkarabhāṣya": ['mw'],
    "vyāsatas": ['mw'],
    "vyāsatryambaka": ['mw'],
    "vyāsatta": ['cped'],
    "vyāsatulasī": ['mw'],
    "vyāsatva": ['mw'],
    "vyāsatātparyanirṇaya": ['mw'],
    "vyāsatīrtha": ['mw'],
    "vyāsavana": ['mw'],
    "vyāsavarya": ['mw'],
    "vyāsavatsa": ['mw'],
    "vyāsaviṭṭhala": ['mw'],
    "vyāsayati": ['mw'],
    "vyāsañj": ['mw'],
    "vyāsaśataka": ['mw'],
    "vyāsaśikṣā": ['mw'],
    "vyāsaśukasaṃvāda": ['mw'],
    "vyāsaḥ": ['ap90'],
    "vyāsaṃgaḥ": ['ap90'],
    "vyāsaṃj": ['ap90'],
    "vyāsaṅga": ['cae', 'ddsa', 'mw'],
    "vyāsaṅgin": ['mw'],
    "vyāsecana": ['cped'],
    "vyāsedha": ['cae', 'ddsa', 'mw'],
    "vyāsedhaḥ": ['ap90'],
    "vyāseka": ['bhs', 'mw'],
    "vyāseśvara": ['mw'],
    "vyāsic": ['mw'],
    "vyāsiddha": ['ap90', 'mw'],
    "vyāsidh": ['mw'],
    "vyāskandaka": ['bhs'],
    "vyāsthā": ['mw'],
    "vyāsuki": ['mw'],
    "vyāsācala": ['mw'],
    "vyāsācārya": ['mw'],
    "vyāsādipañcasiddhānta": ['mw'],
    "vyāsādritaraṃgiṇī": ['mw'],
    "vyāsāraṇya": ['mw'],
    "vyāsāśrama": ['mw'],
    "vyāsāṣṭaka": ['mw'],
    "vyāsīya": ['mw'],
    "vyāsṛ": ['mw'],
    "vyāsṛj": ['mw'],
    "vyātan": ['mw'],
    "vyātta": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyāttānana": ['cae', 'mw'],
    "vyāttāsya": ['mw'],
    "vyātyukṣī": ['ap90', 'ddsa', 'mw'],
    "vyāvabhāṣī": ['mw'],
    "vyāvacarcī": ['mw'],
    "vyāvacorī": ['mw'],
    "vyāvadhati": ['bhs'],
    "vyāvahati": ['bhs'],
    "vyāvahārika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyāvahārikatva": ['mw'],
    "vyāvahārikatvakhaṇḍana": ['mw'],
    "vyāvahārikatvakhaṇḍanasāra": ['mw'],
    "vyāvahārya": ['mw'],
    "vyāvahārī": ['ap90', 'mw'],
    "vyāvahāsī": ['ap90', 'mw'],
    "vyāvakalana": ['mw'],
    "vyāvakalanaṃ": ['ap90'],
    "vyāvakalita": ['mw'],
    "vyāvakrośī": ['ap90', 'mw'],
    "vyāvalg": ['mw'],
    "vyāvalgita": ['ap90', 'mw'],
    "vyāvap": ['mw'],
    "vyāvarga": ['mw'],
    "vyāvarta": ['mw'],
    "vyāvartaka": ['ap90', 'cae', 'mw'],
    "vyāvartakatva": ['mw'],
    "vyāvartakatā": ['mw'],
    "vyāvartana": ['bhs', 'cae', 'mw'],
    "vyāvartanaṃ": ['ap90'],
    "vyāvartanīya": ['mw'],
    "vyāvartaḥ": ['ap90'],
    "vyāvartita": ['mw'],
    "vyāvartya": ['mw'],
    "vyāvarṇ": ['mw'],
    "vyāvaṭa": ['cped'],
    "vyāviddha": ['mw'],
    "vyāviddham": ['mw'],
    "vyāvidha": ['mw'],
    "vyāvivṛtsu": ['ddsa', 'mw'],
    "vyāviś": ['mw'],
    "vyāvyadh": ['mw'],
    "vyāvādha": ['bhs', 'mw'],
    "vyāvṛ": ['ap90', 'mw'],
    "vyāvṛj": ['mw'],
    "vyāvṛt": ['ap90', 'cae', 'mw'],
    "vyāvṛta": ['ap90', 'mw'],
    "vyāvṛti": ['mw'],
    "vyāvṛtiḥ": ['ap90'],
    "vyāvṛtkāma": ['mw'],
    "vyāvṛtsu": ['mw'],
    "vyāvṛtta": ['ap90', 'cae', 'mw'],
    "vyāvṛttabuddhi": ['mw'],
    "vyāvṛttacetas": ['mw'],
    "vyāvṛttadeha": ['mw'],
    "vyāvṛttagati": ['mw'],
    "vyāvṛttakautūhala": ['mw'],
    "vyāvṛttasarvendriyārtha": ['mw'],
    "vyāvṛttatva": ['mw'],
    "vyāvṛttaśiras": ['mw'],
    "vyāvṛttendriya": ['mw'],
    "vyāvṛtti": ['cae', 'mw'],
    "vyāvṛttitva": ['mw'],
    "vyāvṛttiḥ": ['ap90'],
    "vyāvṛttātman": ['mw'],
    "vyāvṛtya": ['mw'],
    "vyāyacchana": ['mw'],
    "vyāyam": ['ap90', 'mw'],
    "vyāyata": ['ap90', 'cae', 'mw'],
    "vyāyatam": ['mw'],
    "vyāyatapātam": ['mw'],
    "vyāyatapātin": ['mw'],
    "vyāyatatva": ['mw'],
    "vyāyatatvaṃ": ['ap90'],
    "vyāyatatā": ['mw'],
    "vyāyoga": ['cae', 'mw'],
    "vyāyogaḥ": ['ap90'],
    "vyāyojima": ['mw'],
    "vyāyudha": ['cae', 'mw'],
    "vyāyuj": ['mw'],
    "vyāyuka": ['cae', 'mw'],
    "vyāyukta": ['bhs'],
    "vyāyāma": ['cae', 'mw'],
    "vyāyāmabhūmi": ['cae', 'mw'],
    "vyāyāmakalaha": ['mw'],
    "vyāyāmakarśita": ['mw'],
    "vyāyāmaprayoga": ['mw'],
    "vyāyāmavat": ['mw'],
    "vyāyāmavid": ['mw'],
    "vyāyāmavidyā": ['mw'],
    "vyāyāmaśālā": ['cae', 'mw'],
    "vyāyāmaśīla": ['mw'],
    "vyāyāmaḥ": ['ap90'],
    "vyāyāmika": ['ap90', 'mw'],
    "vyāyāmin": ['mw'],
    "vyāyāsayati": ['bhs'],
    "vyāśraya": ['mw'],
    "vyāśā": ['mw'],
    "vyāḍa": ['bhs', 'cae', 'ddsa', 'mw'],
    "vyāḍayakṣa": ['bhs', 'mw'],
    "vyāḍaḥ": ['ap90'],
    "vyāḍi": ['cae', 'ddsa', 'mw'],
    "vyāḍiparibhāṣā": ['mw'],
    "vyāḍiśikṣā": ['mw'],
    "vyāḍiśālā": ['mw'],
    "vyāḍiḥ": ['ap90'],
    "vyāḍyā": ['mw'],
    "vyāḍāyudha": ['mw'],
    "vyāḍīya": ['mw'],
    "vyāḍīyaparibhāṣāvṛtti": ['mw'],
    "vyāṅgi": ['mw'],
    "vyūdhnī": ['mw'],
    "vyūh": ['ap90', 'ddsa', 'mw'],
    "vyūha": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vyūhabhaṅga": ['mw'],
    "vyūhabheda": ['mw'],
    "vyūhaka": ['mw'],
    "vyūhamati": ['bhs', 'mw'],
    "vyūhana": ['cae', 'ddsa', 'mw'],
    "vyūhanaṃ": ['ap90'],
    "vyūhapārṣṇi": ['mw'],
    "vyūhapṛṣṭha": ['mw'],
    "vyūharacanā": ['mw'],
    "vyūharāja": ['bhs', 'mw'],
    "vyūharājendrā": ['bhs', 'mw'],
    "vyūhaḥ": ['ap90'],
    "vyūhita": ['mw'],
    "vyūhā": ['bhs'],
    "vyūhāntara": ['mw'],
    "vyūhīkṛ": ['mw'],
    "vyūka": ['mw'],
    "vyūl̤ha": ['mw'],
    "vyūl̤hacchandas": ['mw'],
    "vyūrdhvabhāj": ['mw'],
    "vyūrṇu": ['mw'],
    "vyūta": ['ap90', 'cae', 'mw'],
    "vyūti": ['mw'],
    "vyūtiḥ": ['ap90'],
    "vyūḍha": ['ap90', 'cae', 'ddsa', 'mw'],
    "vyūḍhacchandas": ['mw'],
    "vyūḍhajānu": ['mw'],
    "vyūḍhakaṅkaṭa": ['mw'],
    "vyūḍhanavarātra": ['mw'],
    "vyūḍhi": ['mw'],
    "vyūḍhiḥ": ['ap90'],
    "vyūḍhoras": ['mw'],
    "vyūḍhoraska": ['cae', 'mw'],
    "vyūḍhoru": ['mw'],
    "vyūḍhā": ['cae'],
    "vyūḍhāhīnadvādaśāhapariśiṣṭa": ['mw'],
    "vyūḍhāhīnadvādaśāhaprayoga": ['mw'],
    "vyūḷha": ['cped'],
    "vyṛ": ['mw'],
    "vyṛch": ['mw'],
    "vyṛddha": ['ap90', 'cae', 'mw'],
    "vyṛddhabhāj": ['mw'],
    "vyṛddhi": ['cae', 'ddsa', 'mw'],
    "vyṛddhiḥ": ['ap90'],
    "vyṛdh": ['mw'],
    "vyṛṣ": ['mw'],
    "vā": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vā pana": ['cped'],
    "vābhaṭa": ['mw'],
    "vābhi": ['cae', 'mw'],
    "vāc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vāca": ['mw'],
    "vācaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vācakalakṣakavyañjakatva": ['mw'],
    "vācakamukhya": ['mw'],
    "vācakapada": ['cae', 'mw'],
    "vācakatva": ['mw'],
    "vācakatā": ['mw'],
    "vācaknavī": ['ddsa', 'mw'],
    "vācakācārya": ['mw'],
    "vācakūṭī": ['mw'],
    "vācam": ['mw'],
    "vācaminva": ['mw'],
    "vācamīṅkhaya": ['gra', 'mw'],
    "vācana": ['cae', 'cped', 'ddsa', 'mw'],
    "vācanaka": ['cped', 'mw'],
    "vācanakaṃ": ['ap90'],
    "vācanaṃ": ['ap90'],
    "vācanika": ['ap90', 'mw'],
    "vācanopāsikāvimokṣa": ['bhs'],
    "vācanā": ['mw'],
    "vācas": ['mw'],
    "vācasika": ['cped'],
    "vācaspata": ['mw'],
    "vācaspati": ['cae', 'ddsa', 'mw'],
    "vācaspatibhaṭṭācārya": ['mw'],
    "vācaspatigovinda": ['mw'],
    "vācaspatikalpataru": ['mw'],
    "vācaspatimiśra": ['mw'],
    "vācaspativallabha": ['mw'],
    "vācaspatiḥ": ['ap90'],
    "vācaspatya": ['ddsa', 'mw'],
    "vācaspatyaṃ": ['ap90'],
    "vācasāmpati": ['mw'],
    "vācayitṛ": ['mw'],
    "vācaśravas": ['mw'],
    "vācaḥ": ['ap90'],
    "vācaṃ": ['mw'],
    "vācaṃniyama": ['mw'],
    "vācaṃyama": ['ap90', 'cae', 'ddsa', 'mw'],
    "vācaṃyamatva": ['mw'],
    "vācchalya": ['mw'],
    "vācchā": ['ddsa'],
    "vācenta": ['cped'],
    "vācesi": ['cped'],
    "vācetabba": ['cped'],
    "vācetar": ['cped'],
    "vāceti": ['cped'],
    "vācetvā": ['cped'],
    "vāchoka": ['mw'],
    "vācika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vācikahāraka": ['mw'],
    "vācikapattra": ['mw'],
    "vācikapraśna": ['mw'],
    "vācikā": ['bhs'],
    "vācin": ['ap90', 'cae', 'mw'],
    "vācita": ['cped'],
    "vācitva": ['mw'],
    "vāco": ['mw'],
    "vācoyukti": ['ap90', 'ddsa', 'mw'],
    "vācoyuktipaṭu": ['mw'],
    "vācuggata": ['cped'],
    "vācya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vācyacitra": ['ddsa', 'mw'],
    "vācyaliṅga": ['mw'],
    "vācyaliṅgaka": ['mw'],
    "vācyaliṅgatva": ['mw'],
    "vācyatva": ['mw'],
    "vācyatā": ['ap90', 'mw'],
    "vācyavajra": ['mw'],
    "vācyavarjita": ['mw'],
    "vācyavat": ['mw'],
    "vācyavācakabhāva": ['mw'],
    "vācyavācakatva": ['mw'],
    "vācyavācakatā": ['mw'],
    "vācyārtha": ['cae', 'ddsa', 'mw'],
    "vācyārthatva": ['mw'],
    "vācyāya": ['ddsa', 'mw'],
    "vācyāyana": ['mw'],
    "vācā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vācākarman": ['mw'],
    "vācākarmīṇa": ['mw'],
    "vācāla": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vācālanā": ['ddsa', 'mw'],
    "vācālatva": ['mw'],
    "vācālatā": ['mw'],
    "vācālay": ['cae'],
    "vācālaya": ['ddsa', 'mw'],
    "vācāmātra": ['cae'],
    "vācāmātraka": ['cae'],
    "vācānurakkhī": ['cped'],
    "vācārambhaṇa": ['cae', 'ddsa', 'mw'],
    "vācāsahāya": ['ddsa', 'mw'],
    "vācāstena": ['gra', 'mw'],
    "vācāviruddha": ['mw'],
    "vācāvṛddha": ['mw'],
    "vācāvṛtta": ['mw'],
    "vācāyana": ['mw'],
    "vācāṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vācāṭatā": ['mw'],
    "vācī": ['mw'],
    "vāda": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vādacañcu": ['mw'],
    "vādada": ['mw'],
    "vādagrantha": ['mw'],
    "vādaka": ['cped', 'mw'],
    "vādakalpaka": ['mw'],
    "vādakara": ['mw'],
    "vādakartṛ": ['mw'],
    "vādakathā": ['mw'],
    "vādakautūhala": ['mw'],
    "vādakaḥ": ['ap90'],
    "vādakkhitta": ['cped'],
    "vādakutūhala": ['mw'],
    "vādakāma": ['cped'],
    "vādakṛt": ['mw'],
    "vādala": ['mw'],
    "vādalaḥ": ['ap90'],
    "vādamahārṇava": ['mw'],
    "vādamañjarī": ['mw'],
    "vādana": ['cae', 'cped', 'ddsa', 'mw'],
    "vādanadaṇḍa": ['mw'],
    "vādanaka": ['mw'],
    "vādanakṣatramālikā": ['mw'],
    "vādanakṣatramālāsūryodaya": ['mw'],
    "vādanapariccheda": ['mw'],
    "vādanaṃ": ['ap90'],
    "vādanīya": ['mw'],
    "vādapariccheda": ['mw'],
    "vādapatha": ['cped'],
    "vādaphakkikā": ['mw'],
    "vādaprativāda": ['mw'],
    "vādara": ['ap90', 'mw'],
    "vādarata": ['mw'],
    "vādaratnāvalī": ['mw'],
    "vādaraṃgaḥ": ['ap90'],
    "vādaraṅga": ['mw'],
    "vādarāyaṇa": ['ap90'],
    "vādasaṃgraha": ['mw'],
    "vādasudhākara": ['mw'],
    "vādasudhāṭīkāratnāvalī": ['mw'],
    "vādasādhana": ['mw'],
    "vādataraṃgiṇī": ['mw'],
    "vādavatī": ['mw'],
    "vādavivāda": ['mw'],
    "vādavāda": ['mw'],
    "vādavādin": ['mw'],
    "vādayuddha": ['cae', 'ddsa', 'mw'],
    "vādayuddhapradhāna": ['mw'],
    "vādaḍiṇḍima": ['mw'],
    "vādaḥ": ['ap90'],
    "vādaṁ āropeti": ['cped'],
    "vādeti": ['cped'],
    "vādgala": ['mw'],
    "vādh": ['ap90', 'mw'],
    "vādhaula": ['mw'],
    "vādhava": ['mw'],
    "vādhavaka": ['mw'],
    "vādhin": ['mw'],
    "vādhriaśva": ['gra'],
    "vādhriya": ['mw'],
    "vādhryaśva": ['gra', 'mw'],
    "vādhryaśvi": ['mw'],
    "vādhrīṇasa": ['cae', 'ddsa', 'mw'],
    "vādhrīṇasaka": ['mw'],
    "vādhrīṇasaḥ": ['ap90'],
    "vādhukya": ['mw'],
    "vādhukyaṃ": ['ap90'],
    "vādhula": ['mw'],
    "vādhyoṣāyaṇa": ['mw'],
    "vādhāvata": ['mw'],
    "vādhū": ['mw'],
    "vādhūkyaṃ": ['ap90'],
    "vādhūla": ['mw'],
    "vādhūleya": ['mw'],
    "vādhūna": ['mw'],
    "vādhūya": ['cae', 'ddsa', 'gra', 'mw'],
    "vādi": ['ap90', 'mw'],
    "vādibhīkarācārya": ['mw'],
    "vādibhūṣaṇa": ['mw'],
    "vādicandra": ['mw'],
    "vādighaṭamudgara": ['mw'],
    "vādika": ['cae', 'ddsa', 'mw'],
    "vādikaraṇakhaṇḍana": ['mw'],
    "vādikhaṇḍana": ['mw'],
    "vādin": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vādinī": ['mw'],
    "vādira": ['mw'],
    "vādirāj": ['bhs', 'mw'],
    "vādirāja": ['mw'],
    "vādisiṃha": ['bhs', 'mw'],
    "vādita": ['ap90', 'cae', 'cped', 'mw'],
    "vāditarjana": ['mw'],
    "vāditavya": ['cae', 'mw'],
    "vāditra": ['cae', 'mw'],
    "vāditragaṇa": ['mw'],
    "vāditralaguḍa": ['mw'],
    "vāditravat": ['mw'],
    "vāditraṃ": ['ap90'],
    "vāditva": ['mw'],
    "vādivinoda": ['mw'],
    "vādivāgīśvara": ['mw'],
    "vādiśa": ['bhs', 'mw'],
    "vādiśaḥ": ['ap90'],
    "vādiśrīvallabha": ['mw'],
    "vāduli": ['mw'],
    "vādya": ['cae', 'ddsa', 'mw'],
    "vādyabhaṇḍa": ['mw'],
    "vādyabhaṇḍamukha": ['mw'],
    "vādyabhāṇḍa": ['bhs'],
    "vādyadhara": ['mw'],
    "vādyadhyāya": ['mw'],
    "vādyaka": ['mw'],
    "vādyakara": ['mw'],
    "vādyakāra": ['bhs'],
    "vādyamaṇḍa": ['mw'],
    "vādyamāna": ['mw'],
    "vādyanirghoṣa": ['mw'],
    "vādyavādakasāmagrī": ['mw'],
    "vādyaṃ": ['ap90'],
    "vādyoka": ['mw'],
    "vādādrikuliśa": ['mw'],
    "vādāla": ['mw'],
    "vādāma": ['mw'],
    "vādānuvāda": ['mw'],
    "vādānya": ['mw'],
    "vādārtha": ['mw'],
    "vādārthacūḍāmaṇi": ['mw'],
    "vādārthadīpikā": ['mw'],
    "vādārthakhaṇḍana": ['mw'],
    "vādāvalī": ['mw'],
    "vādāyana": ['mw'],
    "vādī": ['cped'],
    "vādībhasiṃha": ['mw'],
    "vādīndra": ['mw'],
    "vādīvara": ['cped'],
    "vādīśvara": ['mw'],
    "vāg": ['mw'],
    "vāgadhipa": ['ddsa', 'mw'],
    "vāganta": ['mw'],
    "vāgapahāraka": ['cae', 'mw'],
    "vāgapeta": ['mw'],
    "vāgara": ['mw'],
    "vāgaraḥ": ['ap90'],
    "vāgartha": ['mw'],
    "vāgasi": ['mw'],
    "vāgatīta": ['mw'],
    "vāgbaddha": ['mw'],
    "vāgbali": ['mw'],
    "vāgbandhana": ['cae', 'mw'],
    "vāgbhaṅga": ['mw'],
    "vāgbhaṭa": ['cae', 'mw'],
    "vāgbhaṭakośa": ['mw'],
    "vāgbhaṭasūtrasthāna": ['mw'],
    "vāgbhaṭaśārīrasthāna": ['mw'],
    "vāgbhaṭālaṃkāra": ['mw'],
    "vāgbhaṭṭa": ['mw'],
    "vāgbhaṭṭamaṇḍana": ['mw'],
    "vāgbhūṣanakāvya": ['mw'],
    "vāgbhṛt": ['mw'],
    "vāgbrāhmaṇa": ['mw'],
    "vāgdaivatya": ['cae', 'mw'],
    "vāgdala": ['mw'],
    "vāgdaridra": ['mw'],
    "vāgdatta": ['mw'],
    "vāgdattā": ['mw'],
    "vāgdaṇḍa": ['cae', 'mw'],
    "vāgdaṇḍaja": ['cae'],
    "vāgdaṇḍajā": ['mw'],
    "vāgdaṇḍaka": ['mw'],
    "vāgdevatya": ['mw'],
    "vāgdevatā": ['cae', 'mw'],
    "vāgdevatāguru": ['mw'],
    "vāgdevatāka": ['mw'],
    "vāgdevatāstava": ['mw'],
    "vāgdevī": ['cae', 'mw'],
    "vāgdevīkula": ['mw'],
    "vāgdoṣa": ['mw'],
    "vāgdurukta": ['mw'],
    "vāgduṣṭa": ['cae', 'mw'],
    "vāgdvāra": ['mw'],
    "vāgdā": ['mw'],
    "vāgdāna": ['mw'],
    "vāgdānaprayoga": ['mw'],
    "vāgghastavat": ['mw'],
    "vāgguda": ['cae', 'ddsa', 'mw'],
    "vāgguli": ['mw'],
    "vāggulika": ['mw'],
    "vāggumpha": ['mw'],
    "vāgguṇa": ['mw'],
    "vāghat": ['cae', 'ddsa', 'gra', 'mw'],
    "vāghella": ['mw'],
    "vāgindra": ['mw'],
    "vāgjyotis": ['mw'],
    "vāgjāla": ['mw'],
    "vāgmanasa": ['mw'],
    "vāgmin": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāgmitva": ['mw'],
    "vāgmitā": ['cae', 'mw'],
    "vāgmāyana": ['mw'],
    "vāgmūla": ['mw'],
    "vāgoyāna": ['mw'],
    "vāgrodha": ['mw'],
    "vāgu": ['mw'],
    "vāguji": ['mw'],
    "vāgujī": ['mw'],
    "vāguli": ['mw'],
    "vāgura": ['mw'],
    "vāguri": ['ddsa', 'mw'],
    "vāgurika": ['cae', 'cped', 'ddsa', 'mw'],
    "vāgurikaḥ": ['ap90'],
    "vāgurā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vāgurāvṛtti": ['cae', 'mw'],
    "vāgusa": ['mw'],
    "vāguttara": ['mw'],
    "vāguñjāra": ['mw'],
    "vāguṇa": ['mw'],
    "vāgvada": ['mw'],
    "vāgvajra": ['mw'],
    "vāgvant": ['cae'],
    "vāgvat": ['mw'],
    "vāgvatītīrṭhayātrāprakāśa": ['mw'],
    "vāgvaṭa": ['mw'],
    "vāgvibhava": ['mw'],
    "vāgvid": ['cae', 'mw'],
    "vāgvidagdha": ['cae', 'mw'],
    "vāgvidagdhatā": ['mw'],
    "vāgvidagdhā": ['mw'],
    "vāgvidheya": ['mw'],
    "vāgvilāsa": ['mw'],
    "vāgvilāsin": ['mw'],
    "vāgvin": ['cae', 'mw'],
    "vāgviniḥsṛta": ['mw'],
    "vāgvipruṣa": ['mw'],
    "vāgvirodha": ['mw'],
    "vāgvisarga": ['cae', 'mw'],
    "vāgvisarjana": ['mw'],
    "vāgvistara": ['mw'],
    "vāgvyavahāra": ['cae', 'mw'],
    "vāgvyaya": ['mw'],
    "vāgvyāpāra": ['cae', 'mw'],
    "vāgvāda": ['mw'],
    "vāgvādinī": ['mw'],
    "vāgvādinīstotra": ['mw'],
    "vāgvīra": ['cae', 'mw'],
    "vāgvīrya": ['cae', 'mw'],
    "vāgvīṇa": ['mw'],
    "vāgya": ['ap90', 'mw'],
    "vāgyajña": ['mw'],
    "vāgyama": ['mw'],
    "vāgyamana": ['mw'],
    "vāgyata": ['cae', 'ddsa', 'mw'],
    "vāgyatas": ['mw'],
    "vāgyoga": ['mw'],
    "vāgyuddha": ['mw'],
    "vāgyāma": ['mw'],
    "vāgā": ['ap90', 'mw'],
    "vāgādipitrya": ['mw'],
    "vāgālambana": ['mw'],
    "vāgāru": ['ap90', 'mw'],
    "vāgātman": ['mw'],
    "vāgāyana": ['mw'],
    "vāgāśani": ['mw'],
    "vāgāśaniḥ": ['ap90'],
    "vāgāśīrdatta": ['mw'],
    "vāgāḍambara": ['mw'],
    "vāgīśa": ['bhs', 'cae', 'mw'],
    "vāgīśatva": ['mw'],
    "vāgīśatīrtha": ['mw'],
    "vāgīśvara": ['bhs', 'cae', 'mw'],
    "vāgīśvarakīrti": ['mw'],
    "vāgīśvarastotra": ['mw'],
    "vāgīśvarī": ['mw'],
    "vāgīśvarīdatta": ['mw'],
    "vāgīśvarīstotra": ['mw'],
    "vāgīśā": ['mw'],
    "vāgḍambara": ['mw'],
    "vāgṛṣabha": ['cae', 'mw'],
    "vāgṛṣabhatva": ['mw'],
    "vāh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vāha": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vāhabhraṃs": ['mw'],
    "vāhabhraṃś": ['mw'],
    "vāhadviṣat": ['mw'],
    "vāhaka": ['cae', 'cped', 'ddsa', 'mw'],
    "vāhakatva": ['mw'],
    "vāhakaḥ": ['ap90'],
    "vāhalā": ['mw'],
    "vāhana": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vāhanakāra": ['bhs', 'mw'],
    "vāhanakāraśālā": ['mw'],
    "vāhanapa": ['mw'],
    "vāhanaprajñapti": ['bhs', 'mw'],
    "vāhanatva": ['mw'],
    "vāhanatā": ['mw'],
    "vāhanaśreṣṭha": ['mw'],
    "vāhanaṃ": ['ap90'],
    "vāhanika": ['mw'],
    "vāhanā": ['ddsa', 'mw'],
    "vāhanāgāra": ['bhs'],
    "vāhanāyudha": ['cae'],
    "vāhanī": ['mw'],
    "vāhanībhū": ['mw'],
    "vāhanīkṛ": ['mw'],
    "vāhanīya": ['mw'],
    "vāharipu": ['mw'],
    "vāhas": ['ap90', 'cae', 'gra', 'mw'],
    "vāhasa": ['cae', 'mw'],
    "vāhasaḥ": ['ap90'],
    "vāhasā": ['cped'],
    "vāhataka": ['cae', 'mw'],
    "vāhatva": ['mw'],
    "vāhavāraṇa": ['mw'],
    "vāhayati": ['bhs'],
    "vāhaśreṣṭha": ['mw'],
    "vāhaṭa": ['mw'],
    "vāheti": ['cped'],
    "vāheyika": ['mw'],
    "vāhi": ['mw'],
    "vāhika": ['bhs', 'mw'],
    "vāhikaḥ": ['ap90'],
    "vāhikā": ['bhs'],
    "vāhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāhinī": ['ap90', 'cped', 'mw'],
    "vāhinīka": ['mw'],
    "vāhinīniveśa": ['mw'],
    "vāhinīpati": ['cae', 'mw'],
    "vāhinīśa": ['cae', 'mw'],
    "vāhita": ['mw'],
    "vāhitaka": ['bhs'],
    "vāhitaṃ": ['ap90'],
    "vāhittha": ['mw'],
    "vāhittthaṃ": ['ap90'],
    "vāhitva": ['mw'],
    "vāhitā": ['mw'],
    "vāhitṛ": ['cae', 'mw'],
    "vāhiṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "vāhli": ['cae', 'mw'],
    "vāhlika": ['cae'],
    "vāhlikaḥ": ['ap90'],
    "vāhliḥ": ['ap90'],
    "vāhlāyana": ['mw'],
    "vāhlīka": ['ap90', 'mw'],
    "vāhlīkaḥ": ['ap90'],
    "vāhlīkī": ['mw'],
    "vāhna": ['mw'],
    "vāhneya": ['mw'],
    "vāhuka": ['ap90'],
    "vāhuli": ['mw'],
    "vāhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāhyaka": ['mw'],
    "vāhyakāyani": ['mw'],
    "vāhyakī": ['mw'],
    "vāhyanaya": ['mw'],
    "vāhyaska": ['mw'],
    "vāhyaskāyana": ['mw'],
    "vāhyatva": ['mw'],
    "vāhyā": ['mw'],
    "vāhyālī": ['mw'],
    "vāhyālībhū": ['mw'],
    "vāhyāyani": ['mw'],
    "vāhyāśva": ['mw'],
    "vāhādura": ['mw'],
    "vāhāvalī": ['mw'],
    "vāhī": ['cped'],
    "vāhīka": ['ap90', 'cae', 'mw'],
    "vāhīvah": ['mw'],
    "vāhūka": ['mw'],
    "vāja": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vājabandhu": ['gra', 'mw'],
    "vājabastya": ['mw'],
    "vājabharman": ['gra', 'mw'],
    "vājabharmīya": ['mw'],
    "vājabhojin": ['mw'],
    "vājabhṛt": ['mw'],
    "vājacandra": ['mw'],
    "vājadraviṇas": ['gra', 'mw'],
    "vājadā": ['cae', 'gra', 'mw'],
    "vājadāvan": ['cae', 'gra', 'mw'],
    "vājadāvarī": ['mw'],
    "vājagandhia": ['gra'],
    "vājagandhya": ['mw'],
    "vājajaṭhara": ['gra', 'mw'],
    "vājajit": ['cae', 'mw'],
    "vājajiti": ['mw'],
    "vājajityā": ['mw'],
    "vājakarman": ['mw'],
    "vājakarmīya": ['mw'],
    "vājakṛtya": ['gra', 'mw'],
    "vājambhara": ['gra', 'mw'],
    "vājapastia": ['gra'],
    "vājapastya": ['gra', 'mw'],
    "vājapati": ['cae', 'ddsa', 'gra', 'mw'],
    "vājapatnī": ['gra', 'mw'],
    "vājapeya": ['cae', 'mw'],
    "vājapeyagraha": ['mw'],
    "vājapeyahautra": ['mw'],
    "vājapeyahotṛsaptaka": ['mw'],
    "vājapeyaka": ['mw'],
    "vājapeyakratorudgātṛprayoga": ['mw'],
    "vājapeyakḷpti": ['mw'],
    "vājapeyapaddhati": ['mw'],
    "vājapeyaprayoga": ['mw'],
    "vājapeyarahasya": ['mw'],
    "vājapeyarājasūya": ['mw'],
    "vājapeyasarvapṛṣṭhāptoryāmaudgātraprayoga": ['mw'],
    "vājapeyastomaprayoga": ['mw'],
    "vājapeyasāman": ['mw'],
    "vājapeyaudgātraprayoga": ['mw'],
    "vājapeyayājin": ['mw'],
    "vājapeyayūpa": ['mw'],
    "vājapeyika": ['mw'],
    "vājapeyin": ['mw'],
    "vājapeyya": ['cped'],
    "vājapeyādisaṃśayanirṇaya": ['mw'],
    "vājapeyārcika": ['mw'],
    "vājapeyārcikaprayoga": ['mw'],
    "vājapeśas": ['cae', 'gra', 'mw'],
    "vājapramahas": ['gra', 'mw'],
    "vājaprasavya": ['mw'],
    "vājaprasavīya": ['mw'],
    "vājaprasavīyahoma": ['mw'],
    "vājaprasuta": ['mw'],
    "vājaprasūta": ['gra'],
    "vājapya": ['mw'],
    "vājapyāyana": ['mw'],
    "vājapīta": ['mw'],
    "vājaratna": ['cae', 'ddsa', 'gra', 'mw'],
    "vājaratnāyana": ['mw'],
    "vājasana": ['mw'],
    "vājasaneya": ['cae', 'mw'],
    "vājasaneyabrāhmaṇa": ['mw'],
    "vājasaneyagṛhyasūtra": ['mw'],
    "vājasaneyaka": ['mw'],
    "vājasaneyapariśiṣṭanigama": ['mw'],
    "vājasaneyasaṃhitā": ['mw'],
    "vājasaneyaśākhā": ['mw'],
    "vājasaneyaḥ": ['ap90'],
    "vājasaneyi": ['mw'],
    "vājasaneyibrāhmaṇa": ['cae', 'mw'],
    "vājasaneyibrāhmaṇopaniṣad": ['mw'],
    "vājasaneyin": ['ap90', 'cae', 'mw'],
    "vājasaneyiprātiśākhya": ['mw'],
    "vājasaneyisaṃhitopaniṣad": ['mw'],
    "vājasaneyisaṃhitā": ['mw'],
    "vājasaneyiśākhā": ['mw'],
    "vājasani": ['cae', 'ddsa', 'gra', 'mw'],
    "vājasaṃnyasta": ['mw'],
    "vājasrajākṣa": ['mw'],
    "vājasrava": ['mw'],
    "vājasravas": ['mw'],
    "vājasā": ['cae', 'gra', 'mw'],
    "vājasāman": ['mw'],
    "vājasāta": ['cae', 'mw'],
    "vājasāti": ['ddsa', 'gra', 'mw'],
    "vājasṛt": ['cae', 'gra', 'mw'],
    "vājavant": ['cae'],
    "vājavat": ['gra', 'mw'],
    "vājavata": ['mw'],
    "vājavatāyani": ['mw'],
    "vājavāla": ['mw'],
    "vājay": ['cae', 'gra'],
    "vājaya": ['ddsa', 'mw'],
    "vājayu": ['cae', 'ddsa', 'gra', 'mw'],
    "vājaśrava": ['cae', 'mw'],
    "vājaśravas": ['cae', 'gra', 'mw'],
    "vājaśravasa": ['cae'],
    "vājaśruta": ['cae', 'gra', 'mw'],
    "vājaḥ": ['ap90'],
    "vājaṃbhara": ['cae'],
    "vājebhis": ['mw'],
    "vājedhyā": ['mw'],
    "vāji": ['mw'],
    "vājibha": ['mw'],
    "vājibhakṣya": ['mw'],
    "vājibhojana": ['mw'],
    "vājibhū": ['mw'],
    "vājibhūmi": ['ddsa', 'mw'],
    "vājibhṛt": ['mw'],
    "vājidaitya": ['mw'],
    "vājidanta": ['mw'],
    "vājidantaka": ['mw'],
    "vājigandhā": ['mw'],
    "vājigrīva": ['mw'],
    "vājikeśa": ['mw'],
    "vājimat": ['mw'],
    "vājimedha": ['cae', 'mw'],
    "vājimeṣa": ['mw'],
    "vājin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vājina": ['cae', 'ddsa', 'gra', 'mw'],
    "vājinabrāhmaṇa": ['mw'],
    "vājinaṃ": ['ap90'],
    "vājineya": ['cae', 'gra', 'mw'],
    "vājinī": ['mw'],
    "vājinīrājanavidhi": ['mw'],
    "vājinīvant": ['cae'],
    "vājinīvasu": ['cae', 'gra', 'mw'],
    "vājinīvat": ['ddsa', 'gra', 'mw'],
    "vājipakṣin": ['mw'],
    "vājipīta": ['mw'],
    "vājipṛṣṭha": ['mw'],
    "vājiratna": ['mw'],
    "vājirāja": ['mw'],
    "vājirūpadhara": ['cae'],
    "vājita": ['mw'],
    "vājitva": ['mw'],
    "vājitā": ['mw'],
    "vājivega": ['cae', 'mw'],
    "vājiviṣṭhā": ['mw'],
    "vājivāhana": ['mw'],
    "vājivāraṇaśālā": ['mw'],
    "vājiyojaka": ['mw'],
    "vājiśatru": ['mw'],
    "vājiśiras": ['mw'],
    "vājiśālā": ['mw'],
    "vājreya": ['mw'],
    "vājya": ['mw'],
    "vājāpya": ['mw'],
    "vājī": ['cped', 'mw'],
    "vājīkara": ['ap90', 'mw'],
    "vājīkaraṇa": ['ddsa', 'mw'],
    "vājīkaraṇatantra": ['mw'],
    "vājīkaraṇaṃ": ['ap90'],
    "vājīkaraṇādhikāra": ['mw'],
    "vājīkriyā": ['mw'],
    "vājīkārya": ['mw'],
    "vājīkṛ": ['mw'],
    "vājīvidhāna": ['mw'],
    "vāk": ['mw'],
    "vāka": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vākacīra": ['cped'],
    "vākalarāśi": ['mw'],
    "vākamaya": ['cped'],
    "vākarā": ['cped'],
    "vākaṃ": ['ap90'],
    "vākcakṣus": ['cae', 'mw'],
    "vākcapala": ['cae', 'mw'],
    "vākchala": ['mw'],
    "vākchalya": ['mw'],
    "vākchalānvita": ['mw'],
    "vākcit": ['mw'],
    "vākcāpalya": ['mw'],
    "vākina": ['mw'],
    "vākinakāyani": ['mw'],
    "vākini": ['mw'],
    "vākinī": ['mw'],
    "vākkalaha": ['ddsa', 'mw'],
    "vākkalividhvaṃsanagaganakalpa": ['bhs'],
    "vākkaraṇa": ['cped'],
    "vākkeli": ['mw'],
    "vākkelī": ['mw'],
    "vākkoka": ['mw'],
    "vākkīra": ['mw'],
    "vākkūṭa": ['mw'],
    "vākkṣata": ['cae', 'mw'],
    "vākopavāka": ['mw'],
    "vākovākya": ['cae', 'ddsa', 'mw'],
    "vākpatha": ['cae', 'mw'],
    "vākpati": ['cae', 'mw'],
    "vākpatirāja": ['mw'],
    "vākpatirājadeva": ['mw'],
    "vākpativāra": ['mw'],
    "vākpatya": ['mw'],
    "vākpatīya": ['mw'],
    "vākpavitra": ['mw'],
    "vākpaṭu": ['cae', 'mw'],
    "vākpaṭutva": ['mw'],
    "vākpaṭutā": ['mw'],
    "vākpracodana": ['mw'],
    "vākpracodanāt": ['mw'],
    "vākpradā": ['mw'],
    "vākpralāpa": ['mw'],
    "vākprasārikāma": ['mw'],
    "vākprasārin": ['mw'],
    "vākpratoda": ['mw'],
    "vākpravadiṣu": ['mw'],
    "vākpraśasta": ['mw'],
    "vākpuṣpa": ['mw'],
    "vākpuṣṭā": ['mw'],
    "vākpuṣṭāṭavī": ['mw'],
    "vākpā": ['mw'],
    "vākpāruṣya": ['cae', 'mw'],
    "vākpāṭava": ['mw'],
    "vākpāṭavanirukti": ['mw'],
    "vākpūta": ['mw'],
    "vāksaṃvara": ['cae', 'mw'],
    "vāksaṃyama": ['cae', 'mw'],
    "vāksaṅga": ['mw'],
    "vāksiddha": ['mw'],
    "vākstambha": ['mw'],
    "vāksāra": ['mw'],
    "vāksāyaka": ['mw'],
    "vāktvaca": ['mw'],
    "vāktviṣa": ['mw'],
    "vāku": ['mw'],
    "vākucī": ['mw'],
    "vākula": ['ap90', 'mw'],
    "vākya": ['cae', 'cped', 'ddsa', 'mw'],
    "vākyabheda": ['mw'],
    "vākyabhedavāda": ['mw'],
    "vākyacandrikā": ['mw'],
    "vākyacheda": ['bhs'],
    "vākyadhṛk": ['mw'],
    "vākyadīpikā": ['mw'],
    "vākyagarbhita": ['mw'],
    "vākyagraha": ['mw'],
    "vākyahāriṇī": ['mw'],
    "vākyakara": ['mw'],
    "vākyakaraṇasiddhānta": ['mw'],
    "vākyakaṇṭha": ['mw'],
    "vākyakhaṇḍana": ['mw'],
    "vākyakāra": ['mw'],
    "vākyamañjarī": ['mw'],
    "vākyamālā": ['mw'],
    "vākyanuda": ['bhs'],
    "vākyapada": ['mw'],
    "vākyapaddhati": ['mw'],
    "vākyapadī": ['mw'],
    "vākyapadīya": ['cae', 'mw'],
    "vākyapañcādhyāyī": ['mw'],
    "vākyaprabandha": ['mw'],
    "vākyapradīpa": ['mw'],
    "vākyaprakaraṇa": ['mw'],
    "vākyaprakāśa": ['mw'],
    "vākyaprayoga": ['mw'],
    "vākyapūraṇa": ['mw'],
    "vākyaracanā": ['mw'],
    "vākyaratna": ['mw'],
    "vākyasaṃcāra": ['mw'],
    "vākyasaṃgraha": ['mw'],
    "vākyasaṃkīrṇa": ['mw'],
    "vākyasaṃyoga": ['mw'],
    "vākyasiddhāntastotra": ['mw'],
    "vākyasphoṭa": ['mw'],
    "vākyastha": ['mw'],
    "vākyasthita": ['mw'],
    "vākyasudhā": ['mw'],
    "vākyasvara": ['mw'],
    "vākyasāra": ['mw'],
    "vākyasārathi": ['mw'],
    "vākyatas": ['mw'],
    "vākyatattva": ['mw'],
    "vākyatva": ['ddsa', 'mw'],
    "vākyatā": ['mw'],
    "vākyavajra": ['mw'],
    "vākyavajraviṣama": ['mw'],
    "vākyavara": ['mw'],
    "vākyavinyāsa": ['mw'],
    "vākyavivaraṇa": ['mw'],
    "vākyaviśeṣa": ['mw'],
    "vākyaviśārada": ['mw'],
    "vākyavāda": ['mw'],
    "vākyavṛtti": ['mw'],
    "vākyavṛttiprakāśikā": ['mw'],
    "vākyavṛttivyākhyā": ['mw'],
    "vākyaśalākā": ['mw'],
    "vākyaśeṣa": ['mw'],
    "vākyaśeṣatva": ['mw'],
    "vākyaśruti": ['mw'],
    "vākyaṃ": ['ap90'],
    "vākyopacāra": ['mw'],
    "vākyādhyāhāra": ['ddsa', 'mw'],
    "vākyālaṃkāra": ['mw'],
    "vākyālāpa": ['mw'],
    "vākyāmṛta": ['mw'],
    "vākyārtha": ['cae', 'mw'],
    "vākyārthabodha": ['mw'],
    "vākyārthacandrikā": ['mw'],
    "vākyārthadarpaṇa": ['mw'],
    "vākyārthadīpikā": ['mw'],
    "vākyārthaviveka": ['mw'],
    "vākyārthopamā": ['cae', 'mw'],
    "vākyāḍambara": ['mw'],
    "vākārakṛt": ['mw'],
    "vākāṭaka": ['mw'],
    "vākśalya": ['ddsa', 'mw'],
    "vākśalākā": ['mw'],
    "vākśasta": ['mw'],
    "vākśavahū": ['mw'],
    "vākṣasad": ['mw'],
    "vāla": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vālabandha": ['mw'],
    "vālabandhana": ['mw'],
    "vālabhid": ['mw'],
    "vāladhi": ['cped', 'ddsa', 'mw'],
    "vāladhipriya": ['mw'],
    "vāladhāna": ['cae', 'mw'],
    "vāladāman": ['mw'],
    "vālagga": ['cped'],
    "vālaggamatta": ['cped'],
    "vālahasta": ['mw'],
    "vālaja": ['mw'],
    "vālaka": ['ap90', 'bhs', 'mw'],
    "vālakambala": ['cped'],
    "vālakeśī": ['mw'],
    "vālakhilya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vālakhilyagrantha": ['mw'],
    "vālakhilyasaṃhitā": ['mw'],
    "vālakhilyaśastra": ['mw'],
    "vālakhilyeśvaratīrtha": ['mw'],
    "vālakhilyā": ['mw'],
    "vālakhilyāśrama": ['mw'],
    "vālakūrcāla": ['mw'],
    "vālamaya": ['cae', 'mw'],
    "vālamiga": ['cped'],
    "vālammadeśa": ['mw'],
    "vālamātra": ['mw'],
    "vālamūlaka": ['mw'],
    "vālamṛga": ['mw'],
    "vālana": ['mw'],
    "vālanāṭaka": ['mw'],
    "vālapriya": ['mw'],
    "vālapriyatva": ['mw'],
    "vālaputra": ['mw'],
    "vālapāśaka": ['mw'],
    "vālapāśyā": ['cae', 'mw'],
    "vālatuṣa": ['mw'],
    "vālauyapathaka": ['mw'],
    "vālava": ['mw'],
    "vālavarti": ['mw'],
    "vālavedhin": ['bhs'],
    "vālavedhī": ['cped'],
    "vālavyajana": ['cae', 'mw'],
    "vālavyajanībhū": ['mw'],
    "vālavyañjana": ['bhs'],
    "vālavāsas": ['cae', 'mw'],
    "vālavāya": ['mw'],
    "vālavāyaja": ['mw'],
    "vālavījanī": ['cped'],
    "vālavījya": ['mw'],
    "vālaśollaka": ['bhs'],
    "vālaṇḍupaka": ['cped'],
    "vāleya": ['ap90', 'mw'],
    "vālgavya": ['mw'],
    "vālgavyāyanī": ['mw'],
    "vālguda": ['cae', 'mw'],
    "vālguka": ['mw'],
    "vāli": ['bhs', 'mw'],
    "vālihantṛ": ['mw'],
    "vālika": ['mw'],
    "vālikantāra": ['cped'],
    "vālikhila": ['bhs'],
    "vālikhilla": ['mw'],
    "vālikhilya": ['mw'],
    "vālikā": ['bhs', 'cped', 'mw'],
    "vālikājya": ['mw'],
    "vālikājyavidha": ['mw'],
    "vālikānagara": ['bhs'],
    "vālikāyana": ['mw'],
    "vālin": ['cae', 'ddsa', 'mw'],
    "vālinī": ['mw'],
    "vālipulina": ['cped'],
    "vālipuñja": ['cped'],
    "vālisambhava": ['mw'],
    "vāliśikha": ['mw'],
    "vāliḥ": ['ap90'],
    "vālka": ['ap90', 'cae', 'ddsa', 'mw'],
    "vālkala": ['ap90', 'bhs', 'mw'],
    "vālkali": ['bhs'],
    "vālkalī": ['mw'],
    "vāllabhya": ['cae', 'ddsa', 'mw'],
    "vāllabhyaṃ": ['ap90'],
    "vālmīka": ['cae', 'ddsa', 'mw'],
    "vālmīkabhauma": ['mw'],
    "vālmīkaḥ": ['ap90'],
    "vālmīki": ['cae', 'ddsa', 'mw'],
    "vālmīkicarita": ['mw'],
    "vālmīkihṛdaya": ['mw'],
    "vālmīkisūtra": ['mw'],
    "vālmīkitātparyataraṇi": ['mw'],
    "vālmīkiśikṣā": ['mw'],
    "vālmīkīya": ['mw'],
    "vālu": ['mw'],
    "vāluka": ['cae', 'ddsa', 'mw'],
    "vālukantāra": ['cped'],
    "vālukela": ['mw'],
    "vālukeśvara": ['mw'],
    "vālukeśvaratīrtha": ['mw'],
    "vāluki": ['mw'],
    "vālukin": ['mw'],
    "vālukā": ['ap90', 'cped', 'ddsa', 'mw'],
    "vālukābdhi": ['mw'],
    "vālukācaityakrīḍā": ['mw'],
    "vālukādi": ['mw'],
    "vālukāgaḍa": ['mw'],
    "vālukāmaya": ['cae', 'mw'],
    "vālukāmbhas": ['mw'],
    "vālukāmbudhi": ['cae', 'mw'],
    "vālukāprabhā": ['mw'],
    "vālukārṇava": ['cae', 'mw'],
    "vālukātmikā": ['mw'],
    "vālukātva": ['mw'],
    "vālukāyantra": ['mw'],
    "vālukī": ['mw'],
    "vālukṣa": ['bhs'],
    "vālupulina": ['cped'],
    "vālupuñja": ['cped'],
    "vāluṅka": ['mw'],
    "vāluṅkī": ['mw'],
    "vālvaṅgiri": ['mw'],
    "vālā": ['mw'],
    "vālāgra": ['mw'],
    "vālāgrapotikā": ['mw'],
    "vālāha": ['bhs', 'mw'],
    "vālāhaka": ['bhs'],
    "vālākṣaṇa": ['bhs'],
    "vālākṣī": ['mw'],
    "vālāvitu": ['ddsa', 'mw'],
    "vālī": ['mw'],
    "vālūka": ['mw'],
    "vālūkā": ['mw'],
    "vām": ['cae', 'ddsa', 'gra', 'mw'],
    "vāma": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vāmabhrū": ['ddsa', 'mw'],
    "vāmabhāj": ['cae', 'gra', 'mw'],
    "vāmabhāṣin": ['mw'],
    "vāmabhṛt": ['mw'],
    "vāmabhṛttva": ['mw'],
    "vāmacūla": ['mw'],
    "vāmacūḍa": ['mw'],
    "vāmadatta": ['mw'],
    "vāmadattā": ['mw'],
    "vāmadeva": ['cae', 'gra', 'mw'],
    "vāmadevaguhya": ['mw'],
    "vāmadevaratha": ['mw'],
    "vāmadevasaṃhitā": ['mw'],
    "vāmadevya": ['mw'],
    "vāmadevyavidyā": ['mw'],
    "vāmadevī": ['mw'],
    "vāmadhvaja": ['mw'],
    "vāmadṛś": ['cae', 'mw'],
    "vāmadṛṣṭi": ['cae', 'mw'],
    "vāmagupta": ['bhs'],
    "vāmahasta": ['mw'],
    "vāmaikavṛtti": ['mw'],
    "vāmaikavṛttitva": ['mw'],
    "vāmajuṣṭa": ['mw'],
    "vāmajāta": ['gra', 'mw'],
    "vāmaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vāmakakṣāyaṇa": ['mw'],
    "vāmakaṭistha": ['mw'],
    "vāmakeśvarasaṃhitā": ['mw'],
    "vāmakeśvaratantra": ['mw'],
    "vāmakirīṭin": ['mw'],
    "vāmakukṣi": ['mw'],
    "vāmalocana": ['cae', 'ddsa', 'mw'],
    "vāmalocanā": ['cae', 'mw'],
    "vāmalūra": ['ddsa', 'mw'],
    "vāmalūraḥ": ['ap90'],
    "vāmam": ['mw'],
    "vāmamoṣa": ['mw'],
    "vāmamārga": ['mw'],
    "vāmamārgin": ['mw'],
    "vāman": ['mw'],
    "vāmana": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vāmanacitracaritra": ['mw'],
    "vāmanadatta": ['mw'],
    "vāmanadeva": ['mw'],
    "vāmanadvādaśī": ['mw'],
    "vāmanadvādaśīkathā": ['mw'],
    "vāmanadvādaśīvrata": ['mw'],
    "vāmanajayantīvrata": ['mw'],
    "vāmanajātaka": ['mw'],
    "vāmanaka": ['cped', 'mw'],
    "vāmanakārikā": ['mw'],
    "vāmananighaṇṭu": ['mw'],
    "vāmanaprādurbhāva": ['mw'],
    "vāmanapurāṇa": ['mw'],
    "vāmanarūpin": ['mw'],
    "vāmanastava": ['mw'],
    "vāmanasvāmin": ['mw'],
    "vāmanasūkta": ['mw'],
    "vāmanasūtravṛtti": ['mw'],
    "vāmanata": ['mw'],
    "vāmanatanu": ['mw'],
    "vāmanatattva": ['mw'],
    "vāmanatva": ['mw'],
    "vāmanatā": ['mw'],
    "vāmanavrata": ['mw'],
    "vāmanavṛtti": ['mw'],
    "vāmanavṛttiṭīkā": ['mw'],
    "vāmanayanā": ['cae', 'ddsa', 'mw'],
    "vāmanebhī": ['mw'],
    "vāmanendrasvāmin": ['mw'],
    "vāmanetra": ['mw'],
    "vāmanetrā": ['mw'],
    "vāmanikā": ['ap90', 'mw'],
    "vāmanopapurāṇa": ['mw'],
    "vāmanā": ['mw'],
    "vāmanākṛti": ['mw'],
    "vāmanānanda": ['mw'],
    "vāmanānvaya": ['mw'],
    "vāmanāvatāra": ['mw'],
    "vāmanāvatārakathana": ['mw'],
    "vāmanāśrama": ['ddsa', 'mw'],
    "vāmanī": ['ap90', 'ddsa', 'mw'],
    "vāmanībhūta": ['mw'],
    "vāmanīkṛ": ['ddsa'],
    "vāmanīkṛta": ['mw'],
    "vāmanīti": ['gra', 'mw'],
    "vāmanītva": ['mw'],
    "vāmanīya": ['mw'],
    "vāmapassa": ['cped'],
    "vāmapārśva": ['mw'],
    "vāmaratha": ['mw'],
    "vāmarathya": ['mw'],
    "vāmarin": ['mw'],
    "vāmastha": ['mw'],
    "vāmasvabhāva": ['mw'],
    "vāmatantra": ['mw'],
    "vāmatas": ['cae', 'mw'],
    "vāmatva": ['mw'],
    "vāmatā": ['mw'],
    "vāmayā": ['mw'],
    "vāmaśiva": ['mw'],
    "vāmaśīla": ['cae', 'mw'],
    "vāmekṣaṇā": ['ddsa', 'mw'],
    "vāmetara": ['cae', 'mw'],
    "vāmikā": ['ap90', 'mw'],
    "vāmila": ['ap90', 'mw'],
    "vāmin": ['cae', 'ddsa', 'mw'],
    "vāminī": ['mw'],
    "vāmneya": ['mw'],
    "vāmnī": ['mw'],
    "vāmoru": ['mw'],
    "vāmorū": ['cae', 'mw'],
    "vāmra": ['mw'],
    "vāmya": ['cae', 'ddsa', 'mw'],
    "vāmā": ['ap90', 'ddsa', 'mw'],
    "vāmācāra": ['mw'],
    "vāmācārin": ['mw'],
    "vāmāgama": ['mw'],
    "vāmākṣi": ['mw'],
    "vāmākṣī": ['cae', 'ddsa', 'mw'],
    "vāmānuka": ['bhs'],
    "vāmāpīḍana": ['mw'],
    "vāmārambha": ['cae', 'mw'],
    "vāmārcanacandrikā": ['mw'],
    "vāmārcis": ['mw'],
    "vāmāvacara": ['mw'],
    "vāmāvarta": ['mw'],
    "vāmī": ['ap90', 'ddsa', 'mw'],
    "vāmīkṛ": ['mw'],
    "vāmīratha": ['mw'],
    "vāmīyabhāṣya": ['mw'],
    "vāmūrū": ['cped'],
    "vāna": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vānadaṇḍa": ['mw'],
    "vānaka": ['mw'],
    "vānakauśāmbeya": ['mw'],
    "vānala": ['mw'],
    "vānalaḥ": ['ap90'],
    "vānamantara": ['mw'],
    "vānaprastha": ['cae', 'ddsa', 'mw'],
    "vānaprasthadharma": ['mw'],
    "vānaprasthaḥ": ['ap90'],
    "vānaprasthya": ['mw'],
    "vānaprasthāśrama": ['mw'],
    "vānara": ['cae', 'cped', 'ddsa', 'mw'],
    "vānaradhvaja": ['mw'],
    "vānaraketana": ['mw'],
    "vānaraketu": ['mw'],
    "vānarapriya": ['mw'],
    "vānararāja": ['mw'],
    "vānaravīramāhātmya": ['mw'],
    "vānaraḥ": ['ap90'],
    "vānarendra": ['mw'],
    "vānareśvaratīrtha": ['mw'],
    "vānarinda": ['cped'],
    "vānaryaṣṭaka": ['mw'],
    "vānarāghāta": ['mw'],
    "vānarākhya": ['mw'],
    "vānarākṣa": ['mw'],
    "vānarāpasada": ['mw'],
    "vānarāsya": ['mw'],
    "vānarī": ['cped', 'mw'],
    "vānaspatya": ['cae', 'ddsa', 'mw'],
    "vānaspatyaḥ": ['ap90'],
    "vānava": ['mw'],
    "vānavāsaka": ['mw'],
    "vānavāsikā": ['mw'],
    "vānavāsya": ['mw'],
    "vānavāsī": ['ddsa', 'mw'],
    "vānavāsīmāhātmya": ['mw'],
    "vāndana": ['mw'],
    "vāneya": ['cae', 'ddsa', 'mw'],
    "vāneyapuṣpa": ['mw'],
    "vāneyaṃ": ['ap90'],
    "vānika": ['mw'],
    "vānta": ['cae', 'ddsa', 'mw'],
    "vāntavṛṣṭi": ['mw'],
    "vānte": ['mw'],
    "vānti": ['cae', 'ddsa', 'mw'],
    "vāntida": ['mw'],
    "vāntidā": ['mw'],
    "vāntihṛt": ['mw'],
    "vāntikṛt": ['mw'],
    "vāntiśodhanī": ['mw'],
    "vāntāda": ['mw'],
    "vāntānna": ['cae', 'mw'],
    "vāntāśin": ['cae', 'mw'],
    "vāntī": ['mw'],
    "vāntībhāva": ['bhs', 'mw'],
    "vāntīkaroti": ['bhs'],
    "vāntīkṛ": ['mw'],
    "vānya": ['mw'],
    "vānyā": ['ap90', 'cae', 'mw'],
    "vānā": ['ap90', 'mw'],
    "vānārasī": ['bhs'],
    "vānāvāsya": ['mw'],
    "vānāyu": ['cae', 'ddsa', 'mw'],
    "vānāyuja": ['mw'],
    "vānāyuḥ": ['ap90'],
    "vānīra": ['cae', 'ddsa', 'mw'],
    "vānīragṛha": ['mw'],
    "vānīraja": ['mw'],
    "vānīraka": ['mw'],
    "vānīrakaḥ": ['ap90'],
    "vānīraḥ": ['ap90'],
    "vānīya": ['mw'],
    "vāpa": ['cae', 'ddsa', 'mw'],
    "vāpadaṇḍa": ['mw'],
    "vāpaka": ['mw'],
    "vāpana": ['cae', 'mw'],
    "vāpanaṃ": ['ap90'],
    "vāpayati": ['bhs'],
    "vāpaḥ": ['ap90'],
    "vāpi": ['cped', 'mw'],
    "vāpibhūmi": ['bhs'],
    "vāpikā": ['cae', 'mw'],
    "vāpima": ['mw'],
    "vāpin": ['mw'],
    "vāpita": ['ap90', 'cped', 'mw'],
    "vāpiḥ": ['ap90'],
    "vāpuṣa": ['cae', 'gra', 'mw'],
    "vāpya": ['cae', 'ddsa', 'mw'],
    "vāpyutsarga": ['mw'],
    "vāpyāya": ['mw'],
    "vāpyāyamānaḥ": ['bhs'],
    "vāpī": ['cae', 'ddsa', 'mw'],
    "vāpīha": ['mw'],
    "vāpījala": ['cae', 'mw'],
    "vāpīka": ['mw'],
    "vāpīkūpataḍāgādipaddhati": ['mw'],
    "vāpīkūpataṭākaśānti": ['mw'],
    "vāpīvistīrṇa": ['cae', 'mw'],
    "vār": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vāra": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vārabuṣā": ['mw'],
    "vārabāṇa": ['cae', 'mw'],
    "vārabṛṣā": ['mw'],
    "vāradhāna": ['mw'],
    "vāraka": ['ap90', 'cped', 'ddsa', 'mw'],
    "vārakanyakā": ['cae', 'ddsa', 'mw'],
    "vārakeṇa": ['mw'],
    "vārakin": ['ap90', 'mw'],
    "vārakīra": ['mw'],
    "vāralaka": ['mw'],
    "vāralā": ['ap90', 'mw'],
    "vāralīka": ['mw'],
    "vāramatha": ['mw'],
    "vāramukhya": ['cae', 'mw'],
    "vāramukhyā": ['mw'],
    "vāranibandhana": ['bhs'],
    "vāranārī": ['cae', 'ddsa', 'mw'],
    "vārapāśi": ['mw'],
    "vārapāśya": ['mw'],
    "vāraruca": ['mw'],
    "vārarāmā": ['mw'],
    "vārasevā": ['mw'],
    "vārastrī": ['mw'],
    "vārasundarī": ['mw'],
    "vāratantava": ['mw'],
    "vāratantavīya": ['mw'],
    "vāratra": ['mw'],
    "vāratraka": ['bhs', 'mw'],
    "vāratraṃ": ['ap90'],
    "vāratrā": ['mw'],
    "vāravadhū": ['cae', 'mw'],
    "vāravanitā": ['cae', 'mw'],
    "vāravant": ['cae'],
    "vāravantīya": ['mw'],
    "vāravat": ['gra', 'mw'],
    "vāravatī": ['bhs'],
    "vāravilāsinī": ['cae', 'mw'],
    "vāravāla": ['mw'],
    "vāravāli": ['bhs'],
    "vāravāraṇa": ['mw'],
    "vāravāsi": ['mw'],
    "vāravāsya": ['mw'],
    "vāravāṇa": ['mw'],
    "vāravāṇi": ['mw'],
    "vāraya": ['ddsa'],
    "vārayamāna": ['cped'],
    "vārayati": ['bhs'],
    "vārayitavya": ['cae', 'mw'],
    "vārayitṛ": ['mw'],
    "vārayoga": ['mw'],
    "vārayoṣit": ['cae', 'mw'],
    "vārayuvati": ['cae', 'ddsa', 'mw'],
    "vāraḥ": ['ap90'],
    "vāraṃgaḥ": ['ap90'],
    "vāraṃkaḥ": ['ap90'],
    "vāraṃvāraṃ": ['ap90'],
    "vāraṅga": ['cae', 'ddsa', 'mw'],
    "vāraṅka": ['mw'],
    "vāraṇa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vāraṇabusā": ['mw'],
    "vāraṇahasta": ['mw'],
    "vāraṇakara": ['mw'],
    "vāraṇakesara": ['mw'],
    "vāraṇakṛcchra": ['mw'],
    "vāraṇapuṣpa": ['mw'],
    "vāraṇasthala": ['mw'],
    "vāraṇasāhvaya": ['cae', 'mw'],
    "vāraṇasī": ['ap90', 'mw'],
    "vāraṇavallabhā": ['mw'],
    "vāraṇaveśa": ['mw'],
    "vāraṇaśālā": ['cae', 'mw'],
    "vāraṇendra": ['mw'],
    "vāraṇāhvaya": ['mw'],
    "vāraṇānana": ['ddsa', 'mw'],
    "vāraṇāvata": ['cae', 'mw'],
    "vāraṇāvataka": ['mw'],
    "vāraṇāvataḥ": ['ap90'],
    "vāraṇī": ['mw'],
    "vāraṇīya": ['cae', 'ddsa', 'mw'],
    "vāraṭa": ['mw'],
    "vāraṭaṃ": ['ap90'],
    "vāraṭā": ['mw'],
    "vārbaṭa": ['mw'],
    "vārbhaṭa": ['mw'],
    "vārca": ['mw'],
    "vārcalīya": ['mw'],
    "vārda": ['cae', 'ddsa', 'mw'],
    "vārdala": ['bhs', 'mw'],
    "vārdara": ['mw'],
    "vārddha": ['mw'],
    "vārddhaka": ['cae', 'ddsa', 'mw'],
    "vārddhakabhāva": ['cae', 'mw'],
    "vārddhakaṃ": ['ap90'],
    "vārddhakya": ['ddsa', 'mw'],
    "vārddhakyaṃ": ['ap90'],
    "vārddhakṣatri": ['mw'],
    "vārddhakṣemi": ['mw'],
    "vārddhukaṃ": ['ap90'],
    "vārddhuṣa": ['cae', 'ddsa', 'mw'],
    "vārddhuṣi": ['cae', 'mw'],
    "vārddhuṣika": ['cae', 'mw'],
    "vārddhuṣin": ['cae', 'mw'],
    "vārddhuṣiḥ": ['ap90'],
    "vārddhuṣya": ['mw'],
    "vārddhuṣyaṃ": ['ap90'],
    "vārddhuṣī": ['cae', 'mw'],
    "vārddhya": ['mw'],
    "vārddhāyana": ['mw'],
    "vārdhanī": ['cae', 'mw'],
    "vārdheya": ['mw'],
    "vārdhi": ['cae', 'ddsa', 'mw'],
    "vārdhibhava": ['mw'],
    "vārdhiphena": ['mw'],
    "vārdhra": ['mw'],
    "vārdhrakaṭhinika": ['mw'],
    "vārdhraṃ": ['ap90'],
    "vārdhrāṇasa": ['cae', 'ddsa', 'mw'],
    "vārdhrī": ['ddsa'],
    "vārdhrīnasa": ['mw'],
    "vārdhrīṇasa": ['cae', 'mw'],
    "vārdhrīṇasaḥ": ['ap90'],
    "vārdhārā": ['mw'],
    "vārdālikā": ['mw'],
    "vārdālī": ['mw'],
    "vārdālīvat": ['mw'],
    "vārendra": ['mw'],
    "vārendrī": ['mw'],
    "vārenta": ['cped'],
    "vāretabba": ['cped'],
    "vāreti": ['cped'],
    "vāretvā": ['cped'],
    "vārevṛta": ['cae', 'mw'],
    "vāreyya": ['cped'],
    "vāreṃdrī": ['ap90'],
    "vāreṇyāyani": ['mw'],
    "vārgara": ['mw'],
    "vārghaṭīyantracakra": ['mw'],
    "vārha": ['ap90'],
    "vārhadatha": ['ap90'],
    "vārhadrathi": ['ap90'],
    "vārhaspana": ['ap90'],
    "vārhaspata": ['mw'],
    "vārhaspatya": ['ap90'],
    "vārhat": ['mw'],
    "vārhiṇa": ['ap90'],
    "vāri": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vāria": ['gra'],
    "vāribadara": ['mw'],
    "vāribadarā": ['mw'],
    "vāribandhana": ['mw'],
    "vāribhava": ['mw'],
    "vāribindu": ['cae', 'mw'],
    "vāribālaka": ['mw'],
    "vāribīja": ['mw'],
    "vāricara": ['cae', 'mw'],
    "vāricatvara": ['mw'],
    "vāricāmana": ['mw'],
    "vāricārin": ['cae', 'mw'],
    "vārida": ['cae', 'cped', 'mw'],
    "vāridhara": ['cae', 'cped', 'mw'],
    "vāridhi": ['cae', 'mw'],
    "vāridhānī": ['cae', 'mw'],
    "vāridhāpayanta": ['mw'],
    "vāridhāra": ['mw'],
    "vāridhārā": ['cae', 'mw'],
    "vāridra": ['mw'],
    "vāridurga": ['mw'],
    "vāridāgama": ['mw'],
    "vāridānta": ['mw'],
    "vārigarbha": ['mw'],
    "vārigarbhodara": ['cae', 'mw'],
    "vārigocara": ['cped'],
    "vārija": ['cae', 'cped', 'mw'],
    "vārijākṣa": ['mw'],
    "vārijākṣacaritra": ['mw'],
    "vārijāta": ['mw'],
    "vārijāvan": ['mw'],
    "vārijīvaka": ['mw'],
    "vārika": ['bhs', 'mw'],
    "vārikarpūra": ['mw'],
    "vārikarṇikā": ['mw'],
    "vārikaṇṭaka": ['mw'],
    "vārikheḍagrāma": ['mw'],
    "vārikośa": ['ddsa', 'mw'],
    "vārikrimi": ['mw'],
    "vārikubja": ['mw'],
    "vārikubjaka": ['mw'],
    "vārikūṭa": ['mw'],
    "vārileśa": ['mw'],
    "vāriloman": ['mw'],
    "vārimagga": ['cped'],
    "vārimant": ['cae'],
    "vārimasi": ['mw'],
    "vārimat": ['mw'],
    "vārimaya": ['cae', 'mw'],
    "vārimuc": ['cae', 'mw'],
    "vārimūlī": ['mw'],
    "vārin": ['mw'],
    "vārinidhi": ['cae', 'mw'],
    "vārinātha": ['mw'],
    "vāripa": ['mw'],
    "vāriparṇī": ['mw'],
    "vāripatha": ['cae', 'mw'],
    "vāripathika": ['mw'],
    "vāripathopajīvin": ['cae', 'mw'],
    "vāripiṇḍa": ['mw'],
    "vāripravāha": ['mw'],
    "vāripraśnī": ['mw'],
    "vāripālikā": ['mw'],
    "vāripūra": ['mw'],
    "vāripūrvam": ['mw'],
    "vāripūrṇī": ['mw'],
    "vāripṛśnī": ['mw'],
    "vārira": ['mw'],
    "vāriratha": ['mw'],
    "vāriruha": ['mw'],
    "vārirāja": ['cae', 'mw'],
    "vārirārava": ['mw'],
    "vārirāśi": ['cae', 'mw'],
    "vārisambhava": ['mw'],
    "vārisaṃbhava": ['cae'],
    "vārisaṃjña": ['mw'],
    "vārisena": ['mw'],
    "vāristha": ['cae', 'mw'],
    "vārisāgara": ['mw'],
    "vārisāmya": ['mw'],
    "vārisāra": ['mw'],
    "vārita": ['cped', 'mw'],
    "vāritaraṃga": ['cae', 'mw'],
    "vāritas": ['cae', 'mw'],
    "vāritaskara": ['mw'],
    "vāritavāma": ['mw'],
    "vāriti": ['cae', 'mw'],
    "vāritra": ['bhs', 'mw'],
    "vāritrā": ['mw'],
    "vāritta": ['cped'],
    "vārivadana": ['mw'],
    "vārivaha": ['cae', 'mw'],
    "vārivallabhā": ['mw'],
    "vārivara": ['mw'],
    "vārivarṇaka": ['mw'],
    "vārivihāra": ['cae', 'mw'],
    "vārivindī": ['mw'],
    "vārivāha": ['cae', 'cped', 'mw'],
    "vārivāhajāla": ['mw'],
    "vārivāhaka": ['cae', 'mw'],
    "vārivāhana": ['mw'],
    "vārivāhin": ['cae', 'mw'],
    "vārivālaka": ['mw'],
    "vārivāraṇa": ['mw'],
    "vārivāsa": ['mw'],
    "vāriyamāna": ['cped'],
    "vāriyantra": ['cae', 'mw'],
    "vāriyoginī": ['bhs'],
    "vāriśa": ['mw'],
    "vāriśaya": ['mw'],
    "vāriśukti": ['mw'],
    "vāriṣeṇa": ['mw'],
    "vāriṣeṇya": ['mw'],
    "vāriṣeṇācārya": ['mw'],
    "vārjinīvata": ['mw'],
    "vārjyaka": ['mw'],
    "vārka": ['mw'],
    "vārkabandhavika": ['mw'],
    "vārkagrāhika": ['mw'],
    "vārkajambha": ['mw'],
    "vārkakhaṇḍi": ['mw'],
    "vārkaleya": ['mw'],
    "vārkali": ['mw'],
    "vārkarūpya": ['mw'],
    "vārkavañcaka": ['mw'],
    "vārkeṇya": ['mw'],
    "vārkeṇī": ['mw'],
    "vārkāria": ['gra'],
    "vārkāruṇīputra": ['mw'],
    "vārkārya": ['mw'],
    "vārkāryā": ['cae'],
    "vārkṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vārkṣya": ['ap90', 'mw'],
    "vārkṣyāyaṇī": ['mw'],
    "vārkṣāyaṇa": ['mw'],
    "vārkṣī": ['mw'],
    "vārmateya": ['mw'],
    "vārmateyaka": ['mw'],
    "vārmaṇa": ['mw'],
    "vārmaṇaṃ": ['ap90'],
    "vārmika": ['mw'],
    "vārmikya": ['mw'],
    "vārmikāyaṇi": ['mw'],
    "vārmiṇa": ['mw'],
    "vārmuc": ['cae', 'ddsa', 'mw'],
    "vārrāśi": ['mw'],
    "vārtaka": ['mw'],
    "vārtamānika": ['ddsa', 'mw'],
    "vārtana": ['mw'],
    "vārtantavīya": ['mw'],
    "vārtanākṣa": ['mw'],
    "vārtika": ['mw'],
    "vārtikā": ['ap90', 'mw'],
    "vārtra": ['mw'],
    "vārtraghna": ['cae', 'ddsa', 'mw'],
    "vārtraghnaḥ": ['ap90'],
    "vārtrahatya": ['cae', 'gra', 'mw'],
    "vārtratura": ['mw'],
    "vārtta": ['ap90', 'cae', 'ddsa', 'mw'],
    "vārttataraka": ['mw'],
    "vārttaya": ['ddsa', 'mw'],
    "vārttika": ['ap90', 'cae', 'ddsa', 'mw'],
    "vārttikakāra": ['mw'],
    "vārttikakāśikā": ['mw'],
    "vārttikakṛt": ['mw'],
    "vārttikapāṭha": ['mw'],
    "vārttikasāra": ['mw'],
    "vārttikasārasaṃgraha": ['mw'],
    "vārttikasāravyākhyā": ['mw'],
    "vārttikasūtrika": ['mw'],
    "vārttikatātparyaśuddhi": ['mw'],
    "vārttikatātparyaṭīkā": ['mw'],
    "vārttikayojanā": ['mw'],
    "vārttikaṭippana": ['mw'],
    "vārttikendra": ['mw'],
    "vārttikā": ['mw'],
    "vārttikābharaṇa": ['mw'],
    "vārttikāhya": ['mw'],
    "vārttā": ['ap90', 'mw'],
    "vārttāhara": ['cae', 'mw'],
    "vārttāhartṛ": ['cae', 'mw'],
    "vārttāhāra": ['cae', 'mw'],
    "vārttāhārin": ['cae', 'mw'],
    "vārttāhāriṇī": ['mw'],
    "vārttāka": ['ddsa', 'mw'],
    "vārttākarman": ['cae', 'mw'],
    "vārttākaśākaṭa": ['mw'],
    "vārttākaśākina": ['mw'],
    "vārttākin": ['mw'],
    "vārttāku": ['mw'],
    "vārttāmālā": ['mw'],
    "vārttāmātra": ['mw'],
    "vārttāmātrāvabodhana": ['mw'],
    "vārttāmūla": ['mw'],
    "vārttānujīvin": ['ddsa', 'mw'],
    "vārttānukarṣaka": ['mw'],
    "vārttānuyoga": ['mw'],
    "vārttāpati": ['mw'],
    "vārttārambha": ['mw'],
    "vārttāvaha": ['mw'],
    "vārttāvaśeṣa": ['mw'],
    "vārttāvyatikara": ['mw'],
    "vārttāvṛtti": ['mw'],
    "vārttāyana": ['mw'],
    "vārttāyanaḥ": ['ap90'],
    "vārttāśin": ['mw'],
    "vārttībhavati": ['bhs'],
    "vārtāka": ['mw'],
    "vārtākaḥ": ['ap90'],
    "vārtātaveya": ['mw'],
    "vārtīka": ['mw'],
    "vārtīra": ['mw'],
    "vāru": ['mw'],
    "vāruka": ['cae', 'mw'],
    "vāruḍa": ['mw'],
    "vāruḍaka": ['mw'],
    "vāruḍaki": ['mw'],
    "vāruḥ": ['ap90'],
    "vāruṃḍaḥ": ['ap90'],
    "vāruṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vāruṇakarman": ['mw'],
    "vāruṇapaddhati": ['mw'],
    "vāruṇapraghāsika": ['mw'],
    "vāruṇapāśaka": ['mw'],
    "vāruṇatīrtha": ['mw'],
    "vāruṇendra": ['mw'],
    "vāruṇeśvaratīrtha": ['mw'],
    "vāruṇi": ['cae', 'ddsa', 'mw'],
    "vāruṇiḥ": ['ap90'],
    "vāruṇopapurāṇa": ['mw'],
    "vāruṇya": ['mw'],
    "vāruṇyupaniṣad": ['mw'],
    "vāruṇānī": ['mw'],
    "vāruṇī": ['ap90', 'bhs', 'cped', 'mw'],
    "vāruṇīvallabha": ['mw'],
    "vāruṇīśa": ['mw'],
    "vāruṇḍa": ['mw'],
    "vāruṇḍī": ['mw'],
    "vāruṭha": ['mw'],
    "vāruṭhaḥ": ['ap90'],
    "vārvara": ['mw'],
    "vārvatī": ['mw'],
    "vārvaṇā": ['ap90', 'mw'],
    "vārvaṭa": ['mw'],
    "vārvāha": ['cae', 'ddsa', 'mw'],
    "vāry": ['mw'],
    "vārya": ['cae', 'ddsa', 'gra', 'mw'],
    "vāryanilāśana": ['cae'],
    "vāryavṛta": ['mw'],
    "vāryayana": ['mw'],
    "vāryaṃ": ['ap90'],
    "vāryoka": ['mw'],
    "vāryokas": ['cae', 'mw'],
    "vāryudbhava": ['mw'],
    "vāryupajīvin": ['ddsa', 'mw'],
    "vāryāmalaka": ['mw'],
    "vārā": ['mw'],
    "vārāha": ['ap90', 'cae', 'ddsa', 'mw'],
    "vārāhadvādaśī": ['mw'],
    "vārāhaka": ['mw'],
    "vārāhakalpa": ['mw'],
    "vārāhakanda": ['mw'],
    "vārāhakarṇī": ['mw'],
    "vārāhamantra": ['mw'],
    "vārāhamāhātmya": ['mw'],
    "vārāhapattrī": ['mw'],
    "vārāhaprayogavidhi": ['mw'],
    "vārāhapurāṇa": ['mw'],
    "vārāhasaṃhitā": ['mw'],
    "vārāhatīrtha": ['mw'],
    "vārāhatīrthamāhātmya": ['mw'],
    "vārāhyanugrahāṣṭaka": ['mw'],
    "vārāhyā": ['mw'],
    "vārāhāṅgī": ['mw'],
    "vārāhī": ['ap90', 'mw'],
    "vārāhīkanda": ['mw'],
    "vārāhīnigrahāṣṭaka": ['mw'],
    "vārāhīpraśna": ['mw'],
    "vārāhīputra": ['mw'],
    "vārāhīsahasranāmastotra": ['mw'],
    "vārāhīstotra": ['mw'],
    "vārāhītantra": ['mw'],
    "vārāhīya": ['mw'],
    "vārālikā": ['mw'],
    "vārāsana": ['mw'],
    "vārāvaskandin": ['mw'],
    "vārāyaṇīya": ['bhs'],
    "vārāṃnidhiḥ": ['ap90'],
    "vārāṅganā": ['cae', 'mw'],
    "vārāṇaseya": ['bhs', 'mw'],
    "vārāṇasī": ['ap90', 'cae', 'ddsa', 'mw'],
    "vārāṇasīdarpaṇa": ['mw'],
    "vārāṇasīmāhātmya": ['mw'],
    "vārāṇasīya": ['bhs'],
    "vārāṇasīśvara": ['mw'],
    "vārāṭaki": ['mw'],
    "vārāṭakīya": ['mw'],
    "vārī": ['ap90', 'ddsa', 'mw'],
    "vārīy": ['cae'],
    "vārīya": ['ddsa', 'mw'],
    "vārīśa": ['mw'],
    "vārīṭa": ['mw'],
    "vārīṭaḥ": ['ap90'],
    "vārśa": ['mw'],
    "vārūḍhā": ['mw'],
    "vārḍhya": ['mw'],
    "vārṇa": ['ddsa', 'mw'],
    "vārṇaka": ['mw'],
    "vārṇakya": ['mw'],
    "vārṇava": ['mw'],
    "vārṇavaka": ['mw'],
    "vārṇavāśin": ['bhs'],
    "vārṇika": ['mw'],
    "vārṇikaḥ": ['ap90'],
    "vārṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vārṣabha": ['mw'],
    "vārṣabhāṇavī": ['mw'],
    "vārṣada": ['mw'],
    "vārṣadaṃśa": ['mw'],
    "vārṣagaṇa": ['mw'],
    "vārṣagaṇya": ['mw'],
    "vārṣagaṇīputra": ['mw'],
    "vārṣaka": ['mw'],
    "vārṣakīpraśna": ['mw'],
    "vārṣala": ['ddsa', 'mw'],
    "vārṣali": ['mw'],
    "vārṣaparvaṇa": ['cae', 'ddsa', 'mw'],
    "vārṣaparvaṇī": ['mw'],
    "vārṣasahasrika": ['mw'],
    "vārṣaśatika": ['mw'],
    "vārṣaṃdhara": ['mw'],
    "vārṣika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vārṣikapraśna": ['mw'],
    "vārṣikodaka": ['mw'],
    "vārṣikya": ['cae', 'mw'],
    "vārṣikā": ['bhs'],
    "vārṣikī": ['bhs', 'mw'],
    "vārṣilā": ['ap90', 'mw'],
    "vārṣmaṇa": ['mw'],
    "vārṣuka": ['ap90', 'mw'],
    "vārṣyāyaṇi": ['mw'],
    "vārṣyāyaṇīya": ['mw'],
    "vārṣāgira": ['gra', 'mw'],
    "vārṣāhara": ['mw'],
    "vārṣāharottara": ['mw'],
    "vārṣāharādya": ['mw'],
    "vārṣākapa": ['ddsa', 'mw'],
    "vārṣāyaṇi": ['mw'],
    "vārṣāyaṇīputra": ['mw'],
    "vārṣī": ['mw'],
    "vārṣṇa": ['cae', 'ddsa', 'mw'],
    "vārṣṇeya": ['cae', 'ddsa', 'mw'],
    "vārṣṇeyasahita": ['mw'],
    "vārṣṇeyasārathi": ['mw'],
    "vārṣṇeyaḥ": ['ap90'],
    "vārṣṇeyī": ['mw'],
    "vārṣṇi": ['mw'],
    "vārṣṇika": ['mw'],
    "vārṣṇivṛddha": ['mw'],
    "vārṣṇya": ['mw'],
    "vārṣṭihavya": ['mw'],
    "vārṣṭya": ['mw'],
    "vās": ['ap90', 'ddsa', 'mw'],
    "vāsa": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vāsabhavana": ['cae', 'mw'],
    "vāsabhūmi": ['cae', 'mw'],
    "vāsacuṇṇa": ['cped'],
    "vāsadhūpi": ['mw'],
    "vāsadhṛk": ['mw'],
    "vāsageha": ['cae', 'mw'],
    "vāsagṛha": ['cae', 'ddsa', 'mw'],
    "vāsaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāsakarṇī": ['mw'],
    "vāsakasajjikā": ['mw'],
    "vāsakasajjā": ['mw'],
    "vāsamuli": ['mw'],
    "vāsana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vāsanastha": ['mw'],
    "vāsanaṃ": ['ap90'],
    "vāsanta": ['cae', 'ddsa', 'mw'],
    "vāsantaka": ['mw'],
    "vāsantika": ['cae', 'ddsa', 'mw'],
    "vāsantikā": ['mw'],
    "vāsantikāpariṇaya": ['mw'],
    "vāsantī": ['bhs', 'mw'],
    "vāsantīkusuma": ['mw'],
    "vāsantīpūjā": ['mw'],
    "vāsanā": ['ap90', 'cped', 'mw'],
    "vāsanābhāṣya": ['mw'],
    "vāsanāmaya": ['cae', 'mw'],
    "vāsanāmayatva": ['mw'],
    "vāsanātattvabodhikā": ['mw'],
    "vāsanāvārttika": ['mw'],
    "vāsanāvāsudevasyetipadyavyākhyā": ['mw'],
    "vāsanīya": ['cae', 'ddsa', 'mw'],
    "vāsaparyaya": ['ddsa', 'mw'],
    "vāsaprāsāda": ['mw'],
    "vāsapuṣpi": ['mw'],
    "vāsapuṣpā": ['mw'],
    "vāsapādapa": ['cae'],
    "vāsara": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vāsarakanyakā": ['mw'],
    "vāsarakṛt": ['mw'],
    "vāsarakṛtya": ['mw'],
    "vāsaramaṇi": ['mw'],
    "vāsarasaṅga": ['mw'],
    "vāsaraḥ": ['ap90'],
    "vāsareśa": ['mw'],
    "vāsarin": ['bhs'],
    "vāsarā": ['mw'],
    "vāsarādhīśa": ['mw'],
    "vāsarī": ['mw'],
    "vāsas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vāsasajjā": ['mw'],
    "vāsastevi": ['mw'],
    "vāsata": ['mw'],
    "vāsataḥ": ['ap90'],
    "vāsateya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāsateyī": ['mw'],
    "vāsatāmbūla": ['mw'],
    "vāsatīvara": ['ddsa', 'mw'],
    "vāsaukas": ['mw'],
    "vāsava": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vāsavacāpa": ['mw'],
    "vāsavadatta": ['mw'],
    "vāsavadatteya": ['mw'],
    "vāsavadattika": ['mw'],
    "vāsavadattā": ['bhs', 'cae', 'mw'],
    "vāsavadattākhyāyikā": ['mw'],
    "vāsavadiś": ['cae', 'mw'],
    "vāsavagrāma": ['bhs', 'mw'],
    "vāsavagrāmaka": ['mw'],
    "vāsavagrāmīyaka": ['bhs'],
    "vāsavaja": ['cae', 'mw'],
    "vāsavata": ['mw'],
    "vāsaveya": ['mw'],
    "vāsaveśman": ['cae', 'ddsa', 'mw'],
    "vāsaveśvaratīrtha": ['mw'],
    "vāsavi": ['cae', 'mw'],
    "vāsavopama": ['mw'],
    "vāsavāvaraja": ['mw'],
    "vāsavāvāsa": ['mw'],
    "vāsavāśā": ['cae', 'mw'],
    "vāsavī": ['ap90', 'mw'],
    "vāsavṛkṣa": ['mw'],
    "vāsay": ['cae'],
    "vāsaya": ['ddsa'],
    "vāsayaṣṭi": ['cae', 'ddsa', 'mw'],
    "vāsayitavya": ['cae', 'mw'],
    "vāsayitṛ": ['ddsa', 'mw'],
    "vāsayoga": ['cae', 'mw'],
    "vāsaḥ": ['ap90', 'mw'],
    "vāsaḥkhaṇḍa": ['cae', 'ddsa', 'mw'],
    "vāsaḥkuṭī": ['mw'],
    "vāsaḥpalpūlī": ['mw'],
    "vāsaḥśata": ['mw'],
    "vāsaṁ kappeti": ['cped'],
    "vāsaṁ upagacchati": ['cped'],
    "vāsaṃta": ['ap90'],
    "vāsaṃtika": ['ap90'],
    "vāsaṭṭhāna": ['cped'],
    "vāsesi": ['cped'],
    "vāseti": ['cped'],
    "vāsetvā": ['cped'],
    "vāsi": ['cped', 'mw'],
    "vāsijaṭa": ['cped'],
    "vāsika": ['cped', 'mw'],
    "vāsikā": ['mw'],
    "vāsila": ['mw'],
    "vāsin": ['bhs', 'cae', 'ddsa', 'mw'],
    "vāsināyani": ['mw'],
    "vāsinī": ['cped', 'mw'],
    "vāsiphala": ['cped'],
    "vāsita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vāsitaka": ['cped'],
    "vāsitavāsana": ['bhs'],
    "vāsitā": ['ap90', 'bhs', 'mw'],
    "vāsiḥ": ['ap90'],
    "vāsiṣumpha": ['mw'],
    "vāsiṣṭa": ['mw'],
    "vāsiṣṭha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vāsiṣṭhalaiṅga": ['mw'],
    "vāsiṣṭhalaiṅgya": ['mw'],
    "vāsiṣṭhanavagrahapaddhati": ['mw'],
    "vāsiṣṭharāmāyaṇa": ['mw'],
    "vāsiṣṭhasiddhānta": ['mw'],
    "vāsiṣṭhasmṛti": ['mw'],
    "vāsiṣṭhasāra": ['mw'],
    "vāsiṣṭhasūtra": ['mw'],
    "vāsiṣṭhatātparyaprakāśa": ['mw'],
    "vāsiṣṭhavivaraṇa": ['mw'],
    "vāsiṣṭhaśikṣā": ['mw'],
    "vāsiṣṭhika": ['mw'],
    "vāsiṣṭhikavācaspati": ['mw'],
    "vāsiṣṭhottararāmāyaṇa": ['mw'],
    "vāsiṣṭhāyani": ['mw'],
    "vāsiṣṭhī": ['mw'],
    "vāskala": ['mw'],
    "vāso": ['mw'],
    "vāsobhṛt": ['mw'],
    "vāsoda": ['cae', 'ddsa', 'mw'],
    "vāsodghātikā": ['bhs'],
    "vāsodā": ['cae', 'gra', 'mw'],
    "vāsovāya": ['gra', 'mw'],
    "vāsoyuga": ['mw'],
    "vāspa": ['ap90', 'mw'],
    "vāspeya": ['mw'],
    "vāspeyaḥ": ['ap90'],
    "vāsra": ['mw'],
    "vāsrā": ['ddsa', 'mw'],
    "vāsta": ['ap90', 'mw'],
    "vāstava": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāstavatva": ['mw'],
    "vāstave": ['mw'],
    "vāstavika": ['ap90', 'mw'],
    "vāstavoṣā": ['mw'],
    "vāstavya": ['ap90', 'cae', 'mw'],
    "vāstavā": ['ap90'],
    "vāsteya": ['ap90', 'mw'],
    "vāstha": ['bhs'],
    "vāstikaṃ": ['ap90'],
    "vāstoṣpati": ['cae', 'ddsa', 'mw'],
    "vāstoṣpatisūkta": ['mw'],
    "vāstoṣpatiḥ": ['ap90'],
    "vāstoṣpatya": ['mw'],
    "vāstoṣpatīya": ['mw'],
    "vāstra": ['ap90', 'mw'],
    "vāstu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vāstua": ['gra'],
    "vāstubandhana": ['cae', 'mw'],
    "vāstucakra": ['mw'],
    "vāstucandrikā": ['mw'],
    "vāstudeva": ['cae', 'mw'],
    "vāstudevatā": ['mw'],
    "vāstuha": ['mw'],
    "vāstuhoma": ['mw'],
    "vāstuja": ['mw'],
    "vāstujñāna": ['cae', 'mw'],
    "vāstuka": ['mw'],
    "vāstukalpa": ['mw'],
    "vāstukarman": ['cae', 'mw'],
    "vāstukaśākaṭa": ['mw'],
    "vāstukaśākina": ['mw'],
    "vāstukāla": ['mw'],
    "vāstukī": ['mw'],
    "vāstukīrṇa": ['mw'],
    "vāstulakṣaṇa": ['mw'],
    "vāstumadhya": ['cae', 'mw'],
    "vāstumaya": ['mw'],
    "vāstumañjarī": ['mw'],
    "vāstumaṇḍana": ['mw'],
    "vāstunara": ['mw'],
    "vāstunirmāṇa": ['mw'],
    "vāstupa": ['mw'],
    "vāstupaddhati": ['mw'],
    "vāstuparīkṣā": ['mw'],
    "vāstupaśya": ['mw'],
    "vāstupradīpa": ['mw'],
    "vāstuprakaraṇa": ['mw'],
    "vāstuprakāśa": ['mw'],
    "vāstupraveśapaddhati": ['mw'],
    "vāstuprayoga": ['mw'],
    "vāstupraśamana": ['mw'],
    "vāstupuruṣa": ['mw'],
    "vāstupuruṣavidhi": ['mw'],
    "vāstupāla": ['mw'],
    "vāstupūjana": ['mw'],
    "vāstupūjanapaddhati": ['mw'],
    "vāstupūjāvidhi": ['mw'],
    "vāstusampādana": ['mw'],
    "vāstusamuccaya": ['mw'],
    "vāstusanatkumāra": ['mw'],
    "vāstusaukhya": ['mw'],
    "vāstusaṃgraha": ['mw'],
    "vāstusaṃhitā": ['mw'],
    "vāstusaṃśamana": ['mw'],
    "vāstusaṃśamanīya": ['mw'],
    "vāstusthāpana": ['mw'],
    "vāstusāra": ['mw'],
    "vāstutattva": ['mw'],
    "vāstuvicāra": ['mw'],
    "vāstuvidhi": ['mw'],
    "vāstuvidhāna": ['cae', 'mw'],
    "vāstuvidya": ['mw'],
    "vāstuvidyā": ['bhs', 'cae', 'mw'],
    "vāstuvidyākuśala": ['mw'],
    "vāstuvijñānaphalādeśa": ['mw'],
    "vāstuvyākhyāna": ['mw'],
    "vāstuyāga": ['mw'],
    "vāstuyāgavidhestattva": ['mw'],
    "vāstuyāgavidhitattva": ['mw'],
    "vāstuśamana": ['mw'],
    "vāstuśiromaṇi": ['mw'],
    "vāstuśāka": ['mw'],
    "vāstuśānti": ['mw'],
    "vāstuśāntipaddhati": ['mw'],
    "vāstuśāntiprayoga": ['mw'],
    "vāstuśāntyādi": ['mw'],
    "vāstuśāstra": ['mw'],
    "vāstuṛcaka": ['mw'],
    "vāstva": ['cae', 'gra', 'mw'],
    "vāstvamaya": ['mw'],
    "vāstvya": ['mw'],
    "vāstūka": ['mw'],
    "vāstūpaśama": ['mw'],
    "vāstūpaśamana": ['mw'],
    "vāstūpaśamapaddhati": ['mw'],
    "vāsu": ['mw'],
    "vāsubha": ['mw'],
    "vāsubhadra": ['mw'],
    "vāsudeva": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "vāsudevadvādaśākṣarī": ['mw'],
    "vāsudevajyotis": ['mw'],
    "vāsudevajñāna": ['mw'],
    "vāsudevaka": ['mw'],
    "vāsudevamahārādhana": ['mw'],
    "vāsudevamanana": ['mw'],
    "vāsudevamaya": ['mw'],
    "vāsudevapriya": ['mw'],
    "vāsudevapriyaṃkarī": ['mw'],
    "vāsudevapuṇyāha": ['mw'],
    "vāsudevapūjā": ['mw'],
    "vāsudevarahasya": ['mw'],
    "vāsudevasahasranāman": ['mw'],
    "vāsudevasena": ['mw'],
    "vāsudevastotra": ['mw'],
    "vāsudevasuta": ['mw'],
    "vāsudevatīrtha": ['mw'],
    "vāsudevavargya": ['mw'],
    "vāsudevavargīṇa": ['mw'],
    "vāsudevavijaya": ['mw'],
    "vāsudevaḥ": ['ap90'],
    "vāsudevendra": ['mw'],
    "vāsudevendraśiṣya": ['mw'],
    "vāsudevopaniṣad": ['mw'],
    "vāsudevānandīcampū": ['mw'],
    "vāsudevānubhava": ['mw'],
    "vāsudevāśrama": ['mw'],
    "vāsudevī": ['mw'],
    "vāsuka": ['mw'],
    "vāsukeya": ['mw'],
    "vāsukeyasvasṛ": ['mw'],
    "vāsuki": ['cae', 'ddsa', 'mw'],
    "vāsukihrada": ['mw'],
    "vāsukija": ['mw'],
    "vāsukiḥ": ['ap90'],
    "vāsukra": ['mw'],
    "vāsukī": ['mw'],
    "vāsumanda": ['mw'],
    "vāsumata": ['mw'],
    "vāsundhareya": ['ddsa'],
    "vāsupura": ['mw'],
    "vāsupūjya": ['mw'],
    "vāsurā": ['ap90', 'mw'],
    "vāsurāyaṇīya": ['mw'],
    "vāsuḥ": ['ap90'],
    "vāsuṃdhareya": ['mw'],
    "vāsuṃdhareyī": ['mw'],
    "vāsya": ['mw'],
    "vāsāgāra": ['ddsa', 'mw'],
    "vāsākhaṇḍakuṣmāṇḍaka": ['mw'],
    "vāsārtham": ['cae'],
    "vāsāta": ['mw'],
    "vāsātaka": ['mw'],
    "vāsātya": ['cae', 'mw'],
    "vāsāyanika": ['mw'],
    "vāsī": ['cped', 'ddsa', 'mw'],
    "vāsīcandanakalpa": ['bhs'],
    "vāsīphala": ['mw'],
    "vāsū": ['cae', 'ddsa', 'mw'],
    "vāsūḥ": ['ap90'],
    "vāt": ['mw'],
    "vāta": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vātabahula": ['mw'],
    "vātabalāsa": ['mw'],
    "vātabhakṣa": ['cae', 'mw'],
    "vātabhrajas": ['mw'],
    "vātacada": ['mw'],
    "vātacakra": ['mw'],
    "vātacodita": ['gra', 'mw'],
    "vātadhrājigati": ['mw'],
    "vātadhvaja": ['mw'],
    "vātagajāṅkuśa": ['mw'],
    "vātagaṇḍa": ['mw'],
    "vātagaṇḍā": ['mw'],
    "vātaghna": ['mw'],
    "vātaghnatvādinirṇaya": ['mw'],
    "vātaghnī": ['mw'],
    "vātaghātaka": ['cped'],
    "vātagopa": ['mw'],
    "vātagraha": ['mw'],
    "vātagrasta": ['mw'],
    "vātagulma": ['mw'],
    "vātagulmavat": ['mw'],
    "vātagulmin": ['mw'],
    "vātagāmin": ['mw'],
    "vātahan": ['mw'],
    "vātahara": ['mw'],
    "vātahata": ['mw'],
    "vātahoma": ['mw'],
    "vātahuḍā": ['mw'],
    "vātaikabhakṣa": ['ddsa', 'mw'],
    "vātaja": ['mw'],
    "vātajava": ['bhs', 'cped', 'mw'],
    "vātajit": ['mw'],
    "vātajvara": ['mw'],
    "vātajvarapratīkāra": ['mw'],
    "vātajā": ['mw'],
    "vātajāma": ['mw'],
    "vātajūta": ['cae', 'gra', 'mw'],
    "vātajūti": ['mw'],
    "vātaka": ['mw'],
    "vātakalākalā": ['mw'],
    "vātakalākalīya": ['mw'],
    "vātakapiṇḍaka": ['mw'],
    "vātakara": ['ddsa', 'mw'],
    "vātakarman": ['mw'],
    "vātakaḥ": ['ap90'],
    "vātakaṇṭaka": ['mw'],
    "vātakeli": ['mw'],
    "vātaketu": ['mw'],
    "vātakhuḍakā": ['mw'],
    "vātakhuḍā": ['mw'],
    "vātaki": ['mw'],
    "vātakin": ['ap90', 'mw'],
    "vātakopana": ['mw'],
    "vātakumbha": ['mw'],
    "vātakuṇḍalikā": ['mw'],
    "vātakuṇḍalī": ['mw'],
    "vātakya": ['mw'],
    "vātakṛt": ['mw'],
    "vātakṣobha": ['mw'],
    "vātala": ['ap90', 'cae', 'ddsa', 'mw'],
    "vātalamaṇḍalī": ['mw'],
    "vātalā": ['mw'],
    "vātamaja": ['mw'],
    "vātamajaḥ": ['ap90'],
    "vātamaya": ['mw'],
    "vātamaṇḍalikā": ['cped'],
    "vātamaṇḍalī": ['bhs', 'mw'],
    "vātameha": ['mw'],
    "vātamṛga": ['mw'],
    "vātanāman": ['mw'],
    "vātanāśana": ['mw'],
    "vātaparyāya": ['mw'],
    "vātapati": ['mw'],
    "vātapatnī": ['mw'],
    "vātapaṇḍa": ['mw'],
    "vātapaṭa": ['mw'],
    "vātaphullāntra": ['mw'],
    "vātapitta": ['mw'],
    "vātapittaja": ['mw'],
    "vātapittajaśūla": ['mw'],
    "vātapittajvara": ['mw'],
    "vātapittaka": ['mw'],
    "vātapotha": ['mw'],
    "vātapothaka": ['mw'],
    "vātaprabala": ['mw'],
    "vātaprakopa": ['mw'],
    "vātaprameha": ['mw'],
    "vātapramehacikitsā": ['mw'],
    "vātapramī": ['gra', 'mw'],
    "vātapratoda": ['bhs'],
    "vātaputra": ['bhs', 'mw'],
    "vātapālita": ['mw'],
    "vātapāna": ['cped', 'mw'],
    "vātapāta": ['mw'],
    "vātapū": ['mw'],
    "vātara": ['ap90', 'mw'],
    "vātarajju": ['mw'],
    "vātarakta": ['mw'],
    "vātaraktaghna": ['mw'],
    "vātaraktāri": ['mw'],
    "vātaratha": ['mw'],
    "vātaraśana": ['gra', 'mw'],
    "vātaraṃha": ['mw'],
    "vātaraṃhas": ['cae', 'gra', 'mw'],
    "vātaraṅga": ['mw'],
    "vātarddhi": ['mw'],
    "vātardi": ['mw'],
    "vātarecaka": ['mw'],
    "vātareṇusuvarṇa": ['mw'],
    "vātaroga": ['cped', 'mw'],
    "vātarogaharaprāyaścitta": ['mw'],
    "vātarogin": ['mw'],
    "vātarāyaṇa": ['mw'],
    "vātarāyaṇaḥ": ['ap90'],
    "vātarāyaṇīya": ['mw'],
    "vātarūpā": ['mw'],
    "vātarūṣa": ['mw'],
    "vātasaha": ['mw'],
    "vātasakha": ['mw'],
    "vātasaṃcāra": ['mw'],
    "vātaskandha": ['mw'],
    "vātasuta": ['mw'],
    "vātasvana": ['cae', 'ddsa', 'gra', 'mw'],
    "vātasvanas": ['cae', 'gra'],
    "vātasārathi": ['mw'],
    "vātatejas": ['mw'],
    "vātathuḍā": ['mw'],
    "vātatrāṇa": ['mw'],
    "vātatviṣ": ['cae', 'gra', 'mw'],
    "vātatūla": ['mw'],
    "vātavaha": ['mw'],
    "vātavahaka": ['mw'],
    "vātavairin": ['mw'],
    "vātavalāhaka": ['bhs'],
    "vātavarṣa": ['cae', 'mw'],
    "vātavasti": ['mw'],
    "vātavat": ['ddsa', 'mw'],
    "vātavata": ['mw'],
    "vātavega": ['cped', 'mw'],
    "vātaveṭaka": ['mw'],
    "vātavikāra": ['mw'],
    "vātavikārin": ['mw'],
    "vātavuṭṭhi": ['cped'],
    "vātavya": ['cae', 'mw'],
    "vātavyādhi": ['cae', 'mw'],
    "vātavyādhicikitsā": ['mw'],
    "vātavyādhikarmaprakāśa": ['mw'],
    "vātavyādhinidāna": ['mw'],
    "vātavṛddhi": ['mw'],
    "vātavṛṣṭi": ['mw'],
    "vātaya": ['ddsa', 'mw'],
    "vātayantra": ['mw'],
    "vātayantravimānaka": ['ddsa', 'mw'],
    "vātayati": ['ap90'],
    "vātayāna": ['bhs', 'mw'],
    "vātaścika": ['ddsa', 'mw'],
    "vātaśleṣmajvara": ['mw'],
    "vātaśoṇita": ['mw'],
    "vātaśoṇitaka": ['mw'],
    "vātaśoṇitin": ['mw'],
    "vātaśukratva": ['mw'],
    "vātaśīrṣa": ['mw'],
    "vātaśūla": ['mw'],
    "vātaṃdhama": ['mw'],
    "vātaṇḍa": ['mw'],
    "vātaṇḍya": ['mw'],
    "vātaṇḍyāyanī": ['mw'],
    "vātaṇḍī": ['mw'],
    "vāterita": ['cped'],
    "vāteśvaratīrtha": ['mw'],
    "vāteṣu": ['mw'],
    "vāti": ['cped', 'mw'],
    "vātiga": ['mw'],
    "vātigagama": ['mw'],
    "vātigaṃgaṇa": ['mw'],
    "vātika": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vātikakhaṇḍa": ['mw'],
    "vātikapiṇḍaka": ['mw'],
    "vātikaṣaṇḍa": ['mw'],
    "vātiḥ": ['ap90'],
    "vātiṅgaṇa": ['cped'],
    "vātodarin": ['mw'],
    "vātoka": ['mw'],
    "vātona": ['mw'],
    "vātonā": ['mw'],
    "vātopadhūta": ['gra', 'mw'],
    "vātopajūta": ['mw'],
    "vātopaspṛṣṭa": ['cae'],
    "vātopasṛṣṭa": ['mw'],
    "vātormī": ['cae', 'mw'],
    "vātottha": ['mw'],
    "vātsa": ['mw'],
    "vātsabandha": ['mw'],
    "vātsabandhavid": ['mw'],
    "vātsaka": ['mw'],
    "vātsakaṃ": ['ap90'],
    "vātsalya": ['cae', 'ddsa', 'mw'],
    "vātsalyabandhin": ['mw'],
    "vātsalyatā": ['mw'],
    "vātsalyaṃ": ['ap90'],
    "vātsapra": ['mw'],
    "vātsapreya": ['mw'],
    "vātsaprīya": ['mw'],
    "vātsaśāla": ['mw'],
    "vātsi": ['ddsa', 'mw'],
    "vātsiḥ": ['ap90'],
    "vātsoddharaṇa": ['mw'],
    "vātsya": ['cae', 'ddsa', 'mw'],
    "vātsyagulmaka": ['mw'],
    "vātsyakhaṇḍa": ['mw'],
    "vātsyāyana": ['cae', 'mw'],
    "vātsyāyanabhāṣya": ['mw'],
    "vātsyāyanasūtra": ['mw'],
    "vātsyāyanasūtrasāra": ['mw'],
    "vātsyāyanaḥ": ['ap90'],
    "vātsyāyani": ['mw'],
    "vātsyāyanīya": ['mw'],
    "vātsyī": ['mw'],
    "vātsāyana": ['mw'],
    "vātsī": ['mw'],
    "vātsīmāṇḍavīputra": ['mw'],
    "vātsīputra": ['bhs', 'mw'],
    "vātsīputrīya": ['bhs', 'mw'],
    "vātsīya": ['mw'],
    "vātula": ['ap90', 'cae', 'ddsa', 'mw'],
    "vātulabhedādikatantra": ['mw'],
    "vātulaśuddhāgama": ['mw'],
    "vātuli": ['mw'],
    "vātuliḥ": ['ap90'],
    "vātulānaka": ['mw'],
    "vātuṣkāra": ['bhs'],
    "vātya": ['mw'],
    "vātyaupamya": ['mw'],
    "vātyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "vātyācakra": ['mw'],
    "vātyāya": ['ddsa', 'mw'],
    "vātābhihata": ['cped'],
    "vātābhra": ['mw'],
    "vātābādha": ['cped'],
    "vātāda": ['mw'],
    "vātādhipa": ['mw'],
    "vātādhvan": ['mw'],
    "vātāgara": ['mw'],
    "vātāgarīya": ['mw'],
    "vātāgra": ['mw'],
    "vātāgravedikā": ['bhs'],
    "vātāhata": ['mw'],
    "vātāhatanau": ['mw'],
    "vātāhati": ['cae', 'mw'],
    "vātāhaṭa": ['cped'],
    "vātāhāra": ['mw'],
    "vātājira": ['mw'],
    "vātākhya": ['mw'],
    "vātālī": ['cae', 'mw'],
    "vātāma": ['mw'],
    "vātāmodā": ['mw'],
    "vātānulomana": ['mw'],
    "vātānulomin": ['mw'],
    "vātānuvṛttane": ['bhs'],
    "vātāpaha": ['mw'],
    "vātāparjanya": ['gra', 'mw'],
    "vātāpi": ['cae', 'gra', 'mw'],
    "vātāpia": ['gra'],
    "vātāpidviṣ": ['mw'],
    "vātāpihan": ['mw'],
    "vātāpisūdana": ['mw'],
    "vātāpiḥ": ['ap90'],
    "vātāpya": ['gra', 'mw'],
    "vātāpī": ['mw'],
    "vātāri": ['mw'],
    "vātāritaṇḍulā": ['mw'],
    "vātāsaha": ['mw'],
    "vātāsparśārgaḍāni": ['bhs'],
    "vātāsra": ['mw'],
    "vātāsṛj": ['mw'],
    "vātātapa": ['bhs', 'cped'],
    "vātātapika": ['mw'],
    "vātātisāra": ['mw'],
    "vātātmaja": ['cae', 'ddsa', 'mw'],
    "vātātmaka": ['mw'],
    "vātātman": ['mw'],
    "vātāvalī": ['cae', 'ddsa', 'mw'],
    "vātāvant": ['cae'],
    "vātāvat": ['mw'],
    "vātāvata": ['ddsa', 'mw'],
    "vātāyana": ['cae', 'cped', 'mw'],
    "vātāyanacchidrarajas": ['mw'],
    "vātāyanagata": ['mw'],
    "vātāyanarajas": ['bhs', 'mw'],
    "vātāyanastha": ['mw'],
    "vātāyu": ['mw'],
    "vātāśa": ['cae', 'mw'],
    "vātāśin": ['cae', 'mw'],
    "vātāśva": ['cae', 'mw'],
    "vātāṇḍa": ['bhs', 'mw'],
    "vātāṣṭhīlā": ['mw'],
    "vātāṭa": ['mw'],
    "vātī": ['mw'],
    "vātīka": ['mw'],
    "vātīkāra": ['mw'],
    "vātīkṛta": ['mw'],
    "vātīkṛtanāśana": ['mw'],
    "vātīya": ['ap90', 'mw'],
    "vātūla": ['ap90', 'cae', 'ddsa', 'mw'],
    "vātūlasūtra": ['mw'],
    "vātūlībhrama": ['mw'],
    "vātṛ": ['ap90', 'mw'],
    "vāva": ['cae', 'ddsa', 'mw'],
    "vāvacana": ['cae', 'ddsa'],
    "vāvadūka": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāvadūkatva": ['mw'],
    "vāvadūkatā": ['mw'],
    "vāvadūkya": ['mw'],
    "vāvahi": ['cae', 'gra', 'mw'],
    "vāvala": ['mw'],
    "vāvalla": ['mw'],
    "vāvara": ['mw'],
    "vāvasāna": ['ddsa', 'mw'],
    "vāvaya": ['mw'],
    "vāvayaḥ": ['ap90'],
    "vāvaśat": ['mw'],
    "vāvaśāna": ['cae', 'ddsa', 'mw'],
    "vāvuṭa": ['mw'],
    "vāvuṭaḥ": ['ap90'],
    "vāvāta": ['cae', 'ddsa', 'gra', 'mw'],
    "vāvātā": ['mw'],
    "vāvātṛ": ['cae', 'gra', 'mw'],
    "vāvṛddha": ['mw'],
    "vāvṛdhadhyai": ['mw'],
    "vāvṛdhenya": ['mw'],
    "vāvṛt": ['ap90', 'mw'],
    "vāvṛtta": ['ap90', 'mw'],
    "vāya": ['ddsa', 'gra', 'mw'],
    "vāyadaṇḍa": ['mw'],
    "vāyaka": ['cae', 'mw'],
    "vāyakaḥ": ['ap90'],
    "vāyamanta": ['cped'],
    "vāyamati": ['cped'],
    "vāyami": ['cped'],
    "vāyamitvā": ['cped'],
    "vāyamāna": ['cped'],
    "vāyana": ['bhs', 'cped', 'mw'],
    "vāyanaka": ['mw'],
    "vāyanakriyā": ['mw'],
    "vāyanaṃ": ['ap90'],
    "vāyanin": ['mw'],
    "vāyanta": ['cped'],
    "vāyarajju": ['mw'],
    "vāyasa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vāyasajaṅghā": ['mw'],
    "vāyasapīlu": ['mw'],
    "vāyasarutalipi": ['bhs'],
    "vāyasatuṇḍa": ['mw'],
    "vāyasatīra": ['mw'],
    "vāyasatīrīya": ['mw'],
    "vāyasavidyika": ['mw'],
    "vāyasavidyā": ['mw'],
    "vāyasaśānti": ['mw'],
    "vāyasaḥ": ['ap90'],
    "vāyasekṣuka": ['mw'],
    "vāyaska": ['mw'],
    "vāyasolikā": ['mw'],
    "vāyasolī": ['mw'],
    "vāyasādanī": ['mw'],
    "vāyasāhvā": ['mw'],
    "vāyasāntaka": ['mw'],
    "vāyasāri": ['cped', 'mw'],
    "vāyasārāti": ['mw'],
    "vāyasī": ['mw'],
    "vāyasībhūta": ['mw'],
    "vāyasīkṛ": ['cae', 'ddsa'],
    "vāyasīkṛta": ['mw'],
    "vāyata": ['ddsa', 'gra', 'mw'],
    "vāyati": ['cped'],
    "vāyava": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāyavya": ['cae', 'gra', 'mw'],
    "vāyavyapurāṇa": ['mw'],
    "vāyavyā": ['bhs'],
    "vāyavī": ['mw'],
    "vāyavīsaṃhitā": ['mw'],
    "vāyavīya": ['ap90', 'mw'],
    "vāyavīyasaṃhitā": ['mw'],
    "vāyavīyatantra": ['mw'],
    "vāyaḥ": ['ap90'],
    "vāyeti": ['cped'],
    "vāyi": ['cped'],
    "vāyia": ['gra'],
    "vāyibhūmi": ['bhs'],
    "vāyima": ['cped'],
    "vāyin": ['mw'],
    "vāyita": ['bhs', 'cped'],
    "vāyitvā": ['cped'],
    "vāyo": ['cped'],
    "vāyodhasa": ['mw'],
    "vāyodhātu": ['cped'],
    "vāyokasiṇa": ['cped'],
    "vāyorvida": ['mw'],
    "vāyosāvitra": ['mw'],
    "vāyovida": ['mw'],
    "vāyovidyika": ['mw'],
    "vāyoyānī": ['mw'],
    "vāyu": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vāyubala": ['mw'],
    "vāyubhakṣa": ['cae', 'mw'],
    "vāyubhakṣaka": ['cae', 'mw'],
    "vāyubhakṣaṇa": ['mw'],
    "vāyubhakṣya": ['cae', 'mw'],
    "vāyubhojana": ['mw'],
    "vāyubhuj": ['mw'],
    "vāyubhāratīstotra": ['mw'],
    "vāyubhūta": ['cae', 'mw'],
    "vāyubhūti": ['mw'],
    "vāyubīja": ['mw'],
    "vāyucakra": ['mw'],
    "vāyuciti": ['mw'],
    "vāyudaivata": ['mw'],
    "vāyudaivatya": ['mw'],
    "vāyudatta": ['mw'],
    "vāyudattaka": ['mw'],
    "vāyudattamaya": ['mw'],
    "vāyudattarūpya": ['mw'],
    "vāyudatteya": ['mw'],
    "vāyudeva": ['mw'],
    "vāyudhāraṇa": ['mw'],
    "vāyudhātu": ['mw'],
    "vāyudiś": ['mw'],
    "vāyudvāra": ['mw'],
    "vāyudāra": ['mw'],
    "vāyudāru": ['mw'],
    "vāyudīpta": ['mw'],
    "vāyugadya": ['mw'],
    "vāyugati": ['mw'],
    "vāyugaṇḍa": ['mw'],
    "vāyughna": ['mw'],
    "vāyugocara": ['ddsa', 'mw'],
    "vāyugopa": ['gra', 'mw'],
    "vāyugopā": ['mw'],
    "vāyugranthi": ['mw'],
    "vāyugrasta": ['mw'],
    "vāyugulma": ['mw'],
    "vāyugīta": ['cae', 'mw'],
    "vāyuhan": ['mw'],
    "vāyuhīna": ['mw'],
    "vāyuja": ['mw'],
    "vāyujvāla": ['mw'],
    "vāyujāta": ['mw'],
    "vāyuka": ['mw'],
    "vāyuketu": ['mw'],
    "vāyukeśa": ['gra', 'mw'],
    "vāyukoṇa": ['mw'],
    "vāyukṛtsna": ['mw'],
    "vāyulakṣaṇa": ['mw'],
    "vāyuloka": ['mw'],
    "vāyumant": ['cae'],
    "vāyumarullipi": ['mw'],
    "vāyumat": ['mw'],
    "vāyumaya": ['cae', 'mw'],
    "vāyumaṇḍala": ['mw'],
    "vāyumaṇḍalavat": ['bhs'],
    "vāyumārga": ['mw'],
    "vāyuna": ['mw'],
    "vāyunandana": ['mw'],
    "vāyunighna": ['mw'],
    "vāyunivṛtti": ['mw'],
    "vāyunānātva": ['mw'],
    "vāyuparamāṇu": ['mw'],
    "vāyupatha": ['mw'],
    "vāyupañcaka": ['mw'],
    "vāyuphala": ['mw'],
    "vāyupracyuta": ['mw'],
    "vāyupratyakṣavicāra": ['mw'],
    "vāyupratyakṣavāda": ['mw'],
    "vāyupraṇetra": ['mw'],
    "vāyupura": ['mw'],
    "vāyupurāṇa": ['cae', 'mw'],
    "vāyuputra": ['cae', 'mw'],
    "vāyuputrāya": ['mw'],
    "vāyuputrāyita": ['mw'],
    "vāyupūta": ['mw'],
    "vāyura": ['cae', 'mw'],
    "vāyuretas": ['mw'],
    "vāyuroṣā": ['mw'],
    "vāyurugṇa": ['mw'],
    "vāyurujā": ['mw'],
    "vāyusakha": ['mw'],
    "vāyusakhi": ['mw'],
    "vāyusama": ['cae', 'mw'],
    "vāyusambhava": ['mw'],
    "vāyusambhavā": ['mw'],
    "vāyusavitra": ['mw'],
    "vāyusavitṛ": ['mw'],
    "vāyusaṃhitā": ['mw'],
    "vāyuskandha": ['mw'],
    "vāyustuti": ['mw'],
    "vāyusuta": ['mw'],
    "vāyusūnu": ['cae', 'mw'],
    "vāyutanaya": ['mw'],
    "vāyutejas": ['mw'],
    "vāyutva": ['mw'],
    "vāyuvalanapañcataraṃgiṇīmāhātmya": ['mw'],
    "vāyuvartman": ['mw'],
    "vāyuvat": ['cae', 'mw'],
    "vāyuvega": ['cae', 'mw'],
    "vāyuvegaka": ['cae', 'mw'],
    "vāyuvegasama": ['mw'],
    "vāyuvegayaśas": ['mw'],
    "vāyuvegin": ['cae', 'mw'],
    "vāyuvegā": ['bhs', 'mw'],
    "vāyuvyā": ['bhs'],
    "vāyuvāda": ['mw'],
    "vāyuvāha": ['mw'],
    "vāyuvāhana": ['mw'],
    "vāyuvāhinī": ['mw'],
    "vāyuśānti": ['mw'],
    "vāyuḥ": ['ap90'],
    "vāyuṣa": ['mw'],
    "vāyv": ['mw'],
    "vāyvabhibhūta": ['mw'],
    "vāyvadhika": ['mw'],
    "vāyvagni": ['mw'],
    "vāyvaśva": ['cae', 'mw'],
    "vāyvābādhika": ['bhs'],
    "vāyvādhika": ['bhs'],
    "vāyvāspada": ['mw'],
    "vāyya": ['cae', 'gra', 'mw'],
    "vāyāma": ['cped'],
    "vāñceśvara": ['mw'],
    "vāñch": ['cae', 'ddsa', 'gra', 'mw'],
    "vāñchaka": ['mw'],
    "vāñchana": ['mw'],
    "vāñchanīya": ['mw'],
    "vāñcheśa": ['mw'],
    "vāñcheśvara": ['mw'],
    "vāñcheśvaramāhātmya": ['mw'],
    "vāñchin": ['mw'],
    "vāñchinī": ['mw'],
    "vāñchita": ['cae', 'ddsa', 'mw'],
    "vāñchitavya": ['mw'],
    "vāñchoddhāra": ['mw'],
    "vāñchya": ['mw'],
    "vāñchā": ['cae', 'mw'],
    "vāñchāka": ['mw'],
    "vāñchākalpa": ['mw'],
    "vāñchākalpalatā": ['mw'],
    "vāñchānātha": ['mw'],
    "vāñchānāthīyasūtra": ['mw'],
    "vāś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vāśa": ['cae', 'gra', 'mw'],
    "vāśaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāśana": ['cae', 'mw'],
    "vāśanaṃ": ['ap90'],
    "vāśava": ['mw'],
    "vāśi": ['mw'],
    "vāśin": ['cae', 'ddsa', 'mw'],
    "vāśita": ['cae', 'ddsa', 'mw'],
    "vāśitaṃ": ['ap90'],
    "vāśitā": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāśitāgṛṣṭi": ['mw'],
    "vāśiḥ": ['ap90'],
    "vāśiṣṭha": ['ap90', 'bhs', 'mw'],
    "vāśra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vāśrā": ['mw'],
    "vāśurā": ['ap90', 'mw'],
    "vāśyate": ['bhs'],
    "vāśā": ['mw'],
    "vāśī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vāśīcandanakalpa": ['bhs'],
    "vāśīmat": ['gra', 'mw'],
    "vāḍ": ['ap90', 'mw'],
    "vāḍa": ['bhs'],
    "vāḍaba": ['cae', 'ddsa', 'mw'],
    "vāḍabaharaṇa": ['mw'],
    "vāḍabahāraka": ['mw'],
    "vāḍabahārya": ['mw'],
    "vāḍabakarṣa": ['mw'],
    "vāḍabakarṣīya": ['mw'],
    "vāḍabeya": ['mw'],
    "vāḍabhīkāra": ['mw'],
    "vāḍabhīkārya": ['mw'],
    "vāḍabya": ['mw'],
    "vāḍabāgni": ['cae', 'mw'],
    "vāḍabānala": ['mw'],
    "vāḍabīya": ['ddsa', 'mw'],
    "vāḍaka": ['bhs'],
    "vāḍava": ['cae', 'ddsa', 'mw'],
    "vāḍavaḥ": ['ap90'],
    "vāḍaveyaḥ": ['ap90'],
    "vāḍavyaṃ": ['ap90'],
    "vāḍeyīputra": ['mw'],
    "vāḍha": ['ap90', 'mw'],
    "vāḍhavya": ['bhs'],
    "vāḍita": ['bhs'],
    "vāḍiśika": ['bhs'],
    "vāḍvali": ['mw'],
    "vāḍḍautsa": ['ddsa', 'mw'],
    "vāḥ": ['mw'],
    "vāḥkiṭi": ['mw'],
    "vāḥpuṣpa": ['mw'],
    "vāḥsadana": ['mw'],
    "vāḥstha": ['mw'],
    "vāṃch": ['ap90'],
    "vāṃchanaṃ": ['ap90'],
    "vāṃchin": ['ap90'],
    "vāṃchita": ['ap90'],
    "vāṃchā": ['ap90'],
    "vāṃkaḥ": ['ap90'],
    "vāṃkṣ": ['ap90'],
    "vāṃta": ['ap90'],
    "vāṃti": ['ap90'],
    "vāṃśa": ['ap90', 'mw'],
    "vāṃśabhārika": ['mw'],
    "vāṃśakaṭhinika": ['mw'],
    "vāṃśika": ['mw'],
    "vāṃśikaḥ": ['ap90'],
    "vāṃśī": ['mw'],
    "vāṅ": ['mw'],
    "vāṅga": ['ddsa', 'mw'],
    "vāṅgaka": ['mw'],
    "vāṅgāla": ['mw'],
    "vāṅgālī": ['mw'],
    "vāṅgāri": ['mw'],
    "vāṅka": ['mw'],
    "vāṅkṣ": ['mw'],
    "vāṅmadhu": ['cae', 'ddsa', 'mw'],
    "vāṅmadhura": ['cae', 'mw'],
    "vāṅmanas": ['cae', 'mw'],
    "vāṅmanasa": ['mw'],
    "vāṅmatsara": ['mw'],
    "vāṅmatī": ['mw'],
    "vāṅmaya": ['ap90', 'cae', 'mw'],
    "vāṅmayadevatā": ['mw'],
    "vāṅmayatva": ['mw'],
    "vāṅmayaviveka": ['mw'],
    "vāṅmayādhikṛtatā": ['mw'],
    "vāṅmayī": ['mw'],
    "vāṅmiśraṇa": ['mw'],
    "vāṅmukha": ['mw'],
    "vāṅmādhurya": ['mw'],
    "vāṅmālā": ['mw'],
    "vāṅmātra": ['cae', 'mw'],
    "vāṅmūla": ['mw'],
    "vāṅmūrti": ['mw'],
    "vāṅnidhana": ['mw'],
    "vāṅniścaya": ['mw'],
    "vāṅniṣṭhā": ['mw'],
    "vāṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vāṇaki": ['mw'],
    "vāṇavat": ['mw'],
    "vāṇaśabda": ['cae', 'mw'],
    "vāṇaśāla": ['mw'],
    "vāṇi": ['mw'],
    "vāṇibhūṣaṇa": ['mw'],
    "vāṇija": ['cae', 'cped', 'ddsa', 'mw'],
    "vāṇijaka": ['cped', 'mw'],
    "vāṇijakavidha": ['mw'],
    "vāṇijaḥ": ['ap90'],
    "vāṇijika": ['cae', 'mw'],
    "vāṇijikaḥ": ['ap90'],
    "vāṇijja": ['cped'],
    "vāṇijya": ['cae', 'ddsa', 'mw'],
    "vāṇijyaka": ['mw'],
    "vāṇijyaṃ": ['ap90'],
    "vāṇijyā": ['mw'],
    "vāṇikājya": ['mw'],
    "vāṇin": ['mw'],
    "vāṇinī": ['ap90', 'ddsa', 'mw'],
    "vāṇitaka": ['bhs'],
    "vāṇitā": ['mw'],
    "vāṇiḥ": ['ap90'],
    "vāṇyavida": ['mw'],
    "vāṇyovida": ['mw'],
    "vāṇārasī": ['ddsa', 'mw'],
    "vāṇāravaghoṣa": ['bhs'],
    "vāṇārṇī": ['mw'],
    "vāṇī": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vāṇībhūṣaṇa": ['mw'],
    "vāṇīcī": ['cae', 'ddsa', 'gra', 'mw'],
    "vāṇīkavi": ['mw'],
    "vāṇīkūṭalakṣmīdhara": ['mw'],
    "vāṇīnātha": ['mw'],
    "vāṇīpūrvapakṣa": ['mw'],
    "vāṇīvat": ['mw'],
    "vāṇīvilāsa": ['mw'],
    "vāṇīvāda": ['mw'],
    "vāṣkala": ['ap90', 'mw'],
    "vāṣpa": ['bhs', 'mw'],
    "vāṣpaḥ": ['ap90'],
    "vāṣpāyate": ['bhs'],
    "vāṣṭukā": ['ddsa', 'mw'],
    "vāṭ": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāṭa": ['cae', 'cped', 'ddsa', 'mw'],
    "vāṭadattikā": ['bhs'],
    "vāṭadhāna": ['cae', 'mw'],
    "vāṭaka": ['cae', 'cped', 'mw'],
    "vāṭamūla": ['mw'],
    "vāṭara": ['mw'],
    "vāṭaśṛṅkhalā": ['mw'],
    "vāṭaḥ": ['ap90'],
    "vāṭi": ['mw'],
    "vāṭidīrgha": ['mw'],
    "vāṭikā": ['ap90', 'ddsa', 'mw'],
    "vāṭkāra": ['mw'],
    "vāṭu": ['mw'],
    "vāṭya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vāṭyamaṇḍa": ['mw'],
    "vāṭyapuṣpikā": ['mw'],
    "vāṭyapuṣpī": ['mw'],
    "vāṭyā": ['ap90', 'mw'],
    "vāṭyāla": ['mw'],
    "vāṭyālaka": ['mw'],
    "vāṭyālī": ['mw'],
    "vāṭyāyanī": ['mw'],
    "vāṭāgravedikā": ['bhs'],
    "vāṭākavi": ['mw'],
    "vāṭī": ['ap90', 'mw'],
    "vāṭīdīrgha": ['mw'],
    "vāṭīya": ['mw'],
    "vāṭṭadeva": ['mw'],
    "vāṭṭaka": ['mw'],
    "vī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vībarha": ['mw'],
    "vībh": ['ap90', 'mw'],
    "vībukośa": ['mw'],
    "vīca": ['mw'],
    "vīcayana": ['mw'],
    "vīci": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vīcikṣobha": ['mw'],
    "vīcimālin": ['mw'],
    "vīcitaraṃganyāya": ['mw'],
    "vīciḥ": ['ap90'],
    "vīcī": ['cae'],
    "vīcīkāka": ['mw'],
    "vīdhra": ['ap90', 'cae', 'ddsa', 'mw'],
    "vīdhrabindu": ['mw'],
    "vīdhrasamṛddha": ['mw'],
    "vīdhrya": ['mw'],
    "vīhi": ['cped'],
    "vīhāra": ['mw'],
    "vīhāraḥ": ['ap90'],
    "vīj": ['ap90', 'cae', 'ddsa', 'mw'],
    "vīja": ['ap90', 'mw'],
    "vījaka": ['ap90'],
    "vījala": ['ap90'],
    "vījana": ['cae', 'cped', 'ddsa', 'mw'],
    "vījanaka": ['bhs'],
    "vījanaḥ": ['ap90'],
    "vījanī": ['bhs', 'cped'],
    "vījati": ['cped'],
    "vījayamāna": ['cped'],
    "vījenta": ['cped'],
    "vījesi": ['cped'],
    "vījeti": ['cped'],
    "vījetvā": ['cped'],
    "vīji": ['cped'],
    "vījika": ['ap90'],
    "vījin": ['ap90'],
    "vījita": ['cped', 'mw'],
    "vījiyamāna": ['cped'],
    "vījya": ['ap90', 'mw'],
    "vīka": ['mw'],
    "vīkaḥ": ['ap90'],
    "vīkhā": ['mw'],
    "vīkāśa": ['ap90', 'ddsa', 'mw'],
    "vīkṛḍa": ['mw'],
    "vīkṣ": ['ap90', 'mw'],
    "vīkṣa": ['mw'],
    "vīkṣaṃ": ['ap90'],
    "vīkṣaṇa": ['cae', 'ddsa', 'mw'],
    "vīkṣaṇaṃ": ['ap90'],
    "vīkṣaṇīya": ['mw'],
    "vīkṣita": ['cae', 'mw'],
    "vīkṣitavya": ['cae', 'mw'],
    "vīkṣitaṃ": ['ap90'],
    "vīkṣitṛ": ['cae', 'mw'],
    "vīkṣya": ['ap90', 'mw'],
    "vīkṣā": ['cae', 'mw'],
    "vīkṣāpanna": ['mw'],
    "vīkṣāraṇyamāhātmya": ['mw'],
    "vīlaka": ['mw'],
    "vīl̤ita": ['mw'],
    "vīl̤u": ['cae', 'mw'],
    "vīmati": ['bhs'],
    "vīmaṁsaka": ['cped'],
    "vīmaṁsana": ['cped'],
    "vīmaṁsanta": ['cped'],
    "vīmaṁsati": ['cped'],
    "vīmaṁsi": ['cped'],
    "vīmaṁsita": ['cped'],
    "vīmaṁsiya": ['cped'],
    "vīmaṁsā": ['cped'],
    "vīmaṁsī": ['cped'],
    "vīmārga": ['mw'],
    "vīn": ['mw'],
    "vīndra": ['mw'],
    "vīndvarka": ['mw'],
    "vīnā": ['mw'],
    "vīnāha": ['ddsa', 'mw'],
    "vīnāhaḥ": ['ap90'],
    "vīnāhin": ['mw'],
    "vīpa": ['mw'],
    "vīps": ['mw'],
    "vīpsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "vīpsāvicāra": ['mw'],
    "vīpā": ['ap90'],
    "vīr": ['mw'],
    "vīra": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vīrabali": ['mw'],
    "vīrabhadra": ['mw'],
    "vīrabhadracampū": ['mw'],
    "vīrabhadradeva": ['mw'],
    "vīrabhadradevacampū": ['mw'],
    "vīrabhadrajit": ['mw'],
    "vīrabhadraka": ['mw'],
    "vīrabhadrakālikāvacana": ['mw'],
    "vīrabhadramantra": ['mw'],
    "vīrabhadrastotra": ['mw'],
    "vīrabhadrasutā": ['mw'],
    "vīrabhadratantra": ['mw'],
    "vīrabhadravijaya": ['mw'],
    "vīrabhadravijṛmbhaṇa": ['mw'],
    "vīrabhavat": ['mw'],
    "vīrabhaṭa": ['cae', 'mw'],
    "vīrabhuja": ['mw'],
    "vīrabhukti": ['mw'],
    "vīrabhānu": ['mw'],
    "vīrabhāryā": ['mw'],
    "vīrabhāva": ['mw'],
    "vīrabhūpati": ['mw'],
    "vīrabukka": ['mw'],
    "vīrabāhu": ['bhs', 'cae', 'mw'],
    "vīracakra": ['mw'],
    "vīracakreśvara": ['mw'],
    "vīracakṣuṣmat": ['mw'],
    "vīracarita": ['mw'],
    "vīracaritra": ['mw'],
    "vīracarya": ['mw'],
    "vīracaryā": ['cae', 'mw'],
    "vīracintāmaṇi": ['mw'],
    "vīradatta": ['mw'],
    "vīradattagṛhapatiparipṛcchā": ['bhs', 'mw'],
    "vīradeva": ['cae', 'mw'],
    "vīradeya": ['mw'],
    "vīradhanvan": ['mw'],
    "vīradhara": ['mw'],
    "vīradru": ['mw'],
    "vīradyumna": ['mw'],
    "vīradāman": ['mw'],
    "vīragati": ['mw'],
    "vīraghnī": ['cae', 'mw'],
    "vīragotra": ['mw'],
    "vīragoṣṭhī": ['mw'],
    "vīrahan": ['cae', 'gra', 'mw'],
    "vīraharipralāpa": ['mw'],
    "vīrahatyā": ['cae', 'mw'],
    "vīrahaṇa": ['mw'],
    "vīrahotra": ['mw'],
    "vīrajanana": ['mw'],
    "vīrajayantikā": ['mw'],
    "vīrajita": ['mw'],
    "vīrajāta": ['gra', 'mw'],
    "vīraka": ['cae', 'ddsa', 'gra', 'mw'],
    "vīrakarma": ['gra', 'mw'],
    "vīrakarman": ['mw'],
    "vīrakarā": ['mw'],
    "vīrakaḥ": ['ap90'],
    "vīrakesarin": ['mw'],
    "vīraketu": ['mw'],
    "vīrakeśarin": ['mw'],
    "vīrakraya": ['bhs'],
    "vīrakukṣi": ['gra', 'mw'],
    "vīrakāma": ['mw'],
    "vīrakāṭī": ['mw'],
    "vīrakīṭa": ['mw'],
    "vīrakṣurikā": ['mw'],
    "vīralalita": ['mw'],
    "vīraloka": ['ddsa', 'mw'],
    "vīralīla": ['mw'],
    "vīramaheśvara": ['mw'],
    "vīramaheśvarācārasaṃgraha": ['mw'],
    "vīramaheśvarīya": ['mw'],
    "vīramaheśvarīyatantra": ['mw'],
    "vīramalla": ['mw'],
    "vīramardala": ['mw'],
    "vīramardalaka": ['mw'],
    "vīramardana": ['mw'],
    "vīramardanaka": ['mw'],
    "vīramatsya": ['mw'],
    "vīramatī": ['bhs', 'mw'],
    "vīramaya": ['mw'],
    "vīramaṇī": ['bhs'],
    "vīramitrodaya": ['mw'],
    "vīramiśra": ['mw'],
    "vīrammanya": ['mw'],
    "vīramudrikā": ['mw'],
    "vīramukundadeva": ['mw'],
    "vīramāhendrakāṇḍa": ['mw'],
    "vīramānin": ['cae', 'mw'],
    "vīramārga": ['mw'],
    "vīramātṛ": ['cae', 'mw'],
    "vīramāṇikya": ['mw'],
    "vīramūlya": ['bhs'],
    "vīranagara": ['mw'],
    "vīranandin": ['bhs'],
    "vīranārāyaṇa": ['mw'],
    "vīranārāyaṇacarita": ['mw'],
    "vīranārāyaṇīya": ['mw'],
    "vīranātha": ['mw'],
    "vīraparākrama": ['mw'],
    "vīraparṇa": ['mw'],
    "vīrapastia": ['gra'],
    "vīrapastya": ['gra'],
    "vīrapatnī": ['cae', 'gra', 'mw'],
    "vīrapatnīvrata": ['mw'],
    "vīrapattrī": ['mw'],
    "vīrapaṭṭa": ['mw'],
    "vīrapeśas": ['gra', 'mw'],
    "vīrapoṣa": ['mw'],
    "vīraprabha": ['mw'],
    "vīraprajāvatī": ['mw'],
    "vīraprajāyinī": ['mw'],
    "vīrapramokṣa": ['mw'],
    "vīraprasavinī": ['cae', 'mw'],
    "vīraprasavā": ['mw'],
    "vīraprasū": ['cae', 'mw'],
    "vīrapura": ['cae', 'mw'],
    "vīrapuruṣa": ['mw'],
    "vīrapuruṣaka": ['mw'],
    "vīrapuṣpa": ['mw'],
    "vīrapuṣpī": ['mw'],
    "vīrapāna": ['mw'],
    "vīrapāṇa": ['mw'],
    "vīrapāṇaka": ['mw'],
    "vīrapāṇḍya": ['mw'],
    "vīrarajas": ['mw'],
    "vīrarasa": ['mw'],
    "vīraratha": ['mw'],
    "vīraravivarman": ['mw'],
    "vīrareṇu": ['mw'],
    "vīrarāghava": ['mw'],
    "vīrarāghavastava": ['mw'],
    "vīrarāghavīya": ['mw'],
    "vīrarājavarman": ['mw'],
    "vīrasainya": ['mw'],
    "vīrasamanvita": ['mw'],
    "vīrasarasvatī": ['mw'],
    "vīrasena": ['bhs', 'cae', 'mw'],
    "vīrasenaja": ['mw'],
    "vīrasenaka": ['bhs'],
    "vīrasenasuta": ['mw'],
    "vīrasiṃha": ['mw'],
    "vīrasiṃhadeva": ['mw'],
    "vīrasiṃhamitrodayesaṃskāraprakaraṇa": ['mw'],
    "vīrasiṃhaśivendrapūjākārikā": ['mw'],
    "vīrasiṃhāvaloka": ['mw'],
    "vīrasiṃhāvalokana": ['mw'],
    "vīraskandha": ['mw'],
    "vīrasnākā": ['mw'],
    "vīrasoma": ['mw'],
    "vīrastha": ['mw'],
    "vīrasthāna": ['mw'],
    "vīrasthāyin": ['mw'],
    "vīrasvāmin": ['mw'],
    "vīrasū": ['cae', 'gra', 'mw'],
    "vīrasūtva": ['mw'],
    "vīratama": ['cae', 'mw'],
    "vīratantra": ['mw'],
    "vīratara": ['cae', 'ddsa', 'mw'],
    "vīrataraḥ": ['ap90'],
    "vīrataru": ['mw'],
    "vīratarāsana": ['mw'],
    "vīrataṇḍula": ['mw'],
    "vīratva": ['mw'],
    "vīratā": ['cae', 'mw'],
    "vīratāpinyupaniṣad": ['mw'],
    "vīratṛṇa": ['mw'],
    "vīravah": ['cae', 'gra', 'mw'],
    "vīravakṣaṇa": ['gra', 'mw'],
    "vīravant": ['cae'],
    "vīravara": ['cae', 'mw'],
    "vīravarapratāpa": ['mw'],
    "vīravarman": ['mw'],
    "vīravat": ['ap90', 'ddsa', 'gra', 'mw'],
    "vīravatsā": ['mw'],
    "vīravatī": ['mw'],
    "vīravetasa": ['mw'],
    "vīravid": ['mw'],
    "vīravijaya": ['mw'],
    "vīravikrama": ['mw'],
    "vīravikraya": ['bhs'],
    "vīraviplāvaka": ['mw'],
    "vīraviruda": ['mw'],
    "vīravrata": ['mw'],
    "vīravratacaryā": ['mw'],
    "vīravyūha": ['mw'],
    "vīravāda": ['mw'],
    "vīravāh": ['gra'],
    "vīravākya": ['mw'],
    "vīravākyamaya": ['mw'],
    "vīravāmana": ['mw'],
    "vīravṛkṣa": ['mw'],
    "vīravṛndabhaṭṭa": ['mw'],
    "vīray": ['cae', 'gra'],
    "vīraya": ['ddsa'],
    "vīrayogasaha": ['mw'],
    "vīrayogavaha": ['mw'],
    "vīrayu": ['cae', 'gra', 'mw'],
    "vīrayā": ['cae', 'gra', 'mw'],
    "vīraśaiva": ['mw'],
    "vīraśaivadikṣāvidhāna": ['mw'],
    "vīraśaivaliṅgārcanavidhi": ['mw'],
    "vīraśaivapradīpikā": ['mw'],
    "vīraśaivapurāṇa": ['mw'],
    "vīraśaivasiddhānta": ['mw'],
    "vīraśaivasiddhāntaśikhāmaṇi": ['mw'],
    "vīraśaivatattvavivaraṇa": ['mw'],
    "vīraśaivotkarṣapradīpa": ['mw'],
    "vīraśaivācārapradīpikā": ['mw'],
    "vīraśaivāgama": ['mw'],
    "vīraśaivāmṛtapurāṇa": ['mw'],
    "vīraśaivānandacandrikā": ['mw'],
    "vīraśarman": ['mw'],
    "vīraśaya": ['cae', 'mw'],
    "vīraśayana": ['cae', 'mw'],
    "vīraśayyā": ['mw'],
    "vīraśaṅku": ['mw'],
    "vīraśekhara": ['mw'],
    "vīraśreṣṭha": ['mw'],
    "vīraśrī": ['mw'],
    "vīraśuṣma": ['gra', 'mw'],
    "vīraśāka": ['mw'],
    "vīraśāyin": ['mw'],
    "vīraṃdhara": ['mw'],
    "vīraṃdharaḥ": ['ap90'],
    "vīraṃkarā": ['mw'],
    "vīraṃmanya": ['cae'],
    "vīraṇa": ['cae', 'ddsa', 'mw'],
    "vīraṇaka": ['mw'],
    "vīraṇastamba": ['cae', 'mw'],
    "vīraṇastambaka": ['cae', 'mw'],
    "vīraṇaṃ": ['ap90'],
    "vīraṇin": ['mw'],
    "vīraṇī": ['ap90', 'mw'],
    "vīrendra": ['cae', 'ddsa', 'mw'],
    "vīrendrī": ['mw'],
    "vīreśa": ['mw'],
    "vīreśvara": ['mw'],
    "vīreśvaraliṅga": ['mw'],
    "vīreśvarastotra": ['mw'],
    "vīreśvarasūnu": ['mw'],
    "vīreśvarānanda": ['mw'],
    "vīreṇia": ['gra'],
    "vīreṇya": ['cae', 'gra', 'mw'],
    "vīria": ['gra'],
    "vīrikā": ['mw'],
    "vīrin": ['gra'],
    "vīriyavant": ['bhs'],
    "vīriṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "vīriṇamiśra": ['mw'],
    "vīriṇatūla": ['mw'],
    "vīriṇavat": ['mw'],
    "vīriṇaṃ": ['ap90'],
    "vīriṇī": ['cae', 'mw'],
    "vīrojjha": ['mw'],
    "vīropajīvaka": ['mw'],
    "vīrtsā": ['cae', 'mw'],
    "vīrudh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vīrudha": ['cae', 'mw'],
    "vīrudhi": ['mw'],
    "vīrudhā": ['mw'],
    "vīrya": ['cae', 'ddsa', 'gra', 'mw'],
    "vīryabhadra": ['mw'],
    "vīryacandra": ['mw'],
    "vīryadhara": ['mw'],
    "vīryaga": ['mw'],
    "vīryahāni": ['mw'],
    "vīryahārin": ['mw'],
    "vīryahīna": ['mw'],
    "vīryaja": ['mw'],
    "vīryakara": ['mw'],
    "vīryakāma": ['mw'],
    "vīryakṛt": ['cae', 'mw'],
    "vīryakṛta": ['mw'],
    "vīryamatta": ['mw'],
    "vīryamitra": ['mw'],
    "vīryaparihāṇi": ['mw'],
    "vīryapaṇa": ['mw'],
    "vīryaprapāta": ['mw'],
    "vīryapravāda": ['mw'],
    "vīryapāramitā": ['mw'],
    "vīryasaha": ['mw'],
    "vīryasammita": ['mw'],
    "vīryasampanna": ['mw'],
    "vīryasattvavat": ['mw'],
    "vīryasena": ['mw'],
    "vīryatama": ['mw'],
    "vīryavant": ['bhs', 'cae'],
    "vīryavat": ['ap90', 'mw'],
    "vīryavattama": ['mw'],
    "vīryavattara": ['mw'],
    "vīryavattaratva": ['mw'],
    "vīryavattva": ['mw'],
    "vīryavattā": ['cae', 'mw'],
    "vīryavatī": ['mw'],
    "vīryavibhūti": ['mw'],
    "vīryavirahita": ['mw'],
    "vīryaviśiṣṭa": ['mw'],
    "vīryavāhin": ['mw'],
    "vīryavṛddhikara": ['mw'],
    "vīryaśulka": ['cae', 'mw'],
    "vīryaśālin": ['mw'],
    "vīryaśṛṅga": ['mw'],
    "vīryaṃ": ['ap90'],
    "vīryā": ['bhs', 'mw'],
    "vīryādhāna": ['mw'],
    "vīryānvita": ['mw'],
    "vīryārabdhi": ['bhs'],
    "vīryārambha": ['bhs'],
    "vīryāvadhūta": ['mw'],
    "vīryāvadāna": ['mw'],
    "vīryāvant": ['cae'],
    "vīryāvat": ['mw'],
    "vīrā": ['ap90', 'mw'],
    "vīrācārya": ['mw'],
    "vīrādhvan": ['mw'],
    "vīrāgama": ['mw'],
    "vīrākhya": ['mw'],
    "vīrākṣaramālāviruda": ['mw'],
    "vīrāmla": ['mw'],
    "vīrānanda": ['mw'],
    "vīrāpura": ['mw'],
    "vīrāruka": ['mw'],
    "vīrāsana": ['cae', 'mw'],
    "vīrāya": ['ddsa', 'mw'],
    "vīrāyate": ['ap90'],
    "vīrāśaṃsana": ['ddsa', 'mw'],
    "vīrāṇaka": ['ddsa', 'mw'],
    "vīrāṣṭaka": ['mw'],
    "vīsa": ['mw'],
    "vīsaladeva": ['mw'],
    "vīsarpa": ['mw'],
    "vīsati": ['cped'],
    "vīsatima": ['cped'],
    "vīta": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "vītabhaya": ['cae', 'mw'],
    "vītabhī": ['cae', 'mw'],
    "vītabhīti": ['cae', 'mw'],
    "vītaccika": ['cped'],
    "vītacinta": ['cae', 'ddsa', 'mw'],
    "vītadambha": ['mw'],
    "vītadarpa": ['cae'],
    "vītagedha": ['cped'],
    "vītaghṛṇa": ['mw'],
    "vītaghṛṇatā": ['mw'],
    "vītahavya": ['cae', 'gra', 'mw'],
    "vītahavyopākhyāna": ['mw'],
    "vītahiraṇmaya": ['mw'],
    "vītahiraṇmayatva": ['mw'],
    "vītajanmajarasa": ['mw'],
    "vītaka": ['mw'],
    "vītakalmaṣa": ['mw'],
    "vītakāma": ['mw'],
    "vītamala": ['cped', 'mw'],
    "vītamanyu": ['cae', 'mw'],
    "vītamatsara": ['mw'],
    "vītamoha": ['cped', 'mw'],
    "vītamohopākhyāna": ['mw'],
    "vītana": ['mw'],
    "vītanau": ['ap90'],
    "vītapṛṣṭha": ['gra', 'mw'],
    "vītarāga": ['cae', 'cped', 'mw'],
    "vītarāgabhayakrodha": ['mw'],
    "vītarāgabhūmi": ['bhs', 'mw'],
    "vītarāgastuti": ['mw'],
    "vītaspṛha": ['mw'],
    "vītasūtra": ['mw'],
    "vītatama": ['mw'],
    "vītataṇha": ['cped'],
    "vītatha": ['bhs'],
    "vītatrasareṇu": ['mw'],
    "vītatṛṣṇa": ['mw'],
    "vītavat": ['mw'],
    "vītaviruddhabuddhi": ['mw'],
    "vītaviṣa": ['mw'],
    "vītavrīḍa": ['cae', 'mw'],
    "vītavāra": ['gra', 'mw'],
    "vītaśaṅka": ['mw'],
    "vītaśaṅkam": ['mw'],
    "vītaśoka": ['bhs', 'cae', 'mw'],
    "vītaśokabhaya": ['mw'],
    "vītaśokabhayābādha": ['mw'],
    "vītaśokatā": ['mw'],
    "vītaśokā": ['mw'],
    "vītaṃsa": ['bhs', 'ddsa', 'mw'],
    "vītaṃsaḥ": ['ap90'],
    "vīthi": ['cae', 'cped', 'ddsa', 'mw'],
    "vīthicitta": ['cped'],
    "vīthika": ['cae', 'mw'],
    "vīthikā": ['ap90', 'cae', 'mw'],
    "vīthiḥ": ['ap90'],
    "vīthy": ['mw'],
    "vīthyaṅga": ['mw'],
    "vīthī": ['cae', 'ddsa', 'mw'],
    "vīthīka": ['mw'],
    "vīthīkṛta": ['mw'],
    "vīthīmārga": ['mw'],
    "vīti": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vītigata": ['bhs'],
    "vītiharati": ['cped'],
    "vītiharaṇa": ['cped'],
    "vītihari": ['cped'],
    "vītiharitvā": ['cped'],
    "vītihotra": ['cae', 'ddsa', 'gra', 'mw'],
    "vītihotradayitā": ['mw'],
    "vītihotrapriyā": ['mw'],
    "vītihāra": ['bhs', 'cped'],
    "vītikkama": ['cped'],
    "vītikkamanta": ['cped'],
    "vītikkamati": ['cped'],
    "vītikkami": ['cped'],
    "vītikkamitvā": ['cped'],
    "vītikkanta": ['cped'],
    "vītikrama": ['bhs'],
    "vītikāśeti": ['bhs'],
    "vītiloketi": ['bhs'],
    "vītin": ['mw'],
    "vītinamati": ['bhs'],
    "vītināmesi": ['cped'],
    "vītināmeti": ['cped'],
    "vītināmetvā": ['cped'],
    "vītināmtia": ['cped'],
    "vītipatati": ['bhs', 'cped'],
    "vītirādhas": ['gra', 'mw'],
    "vītisaṃcarati": ['bhs'],
    "vītisaṃkrama": ['bhs'],
    "vītisārayati": ['bhs'],
    "vītivartati": ['bhs'],
    "vītivatta": ['cped'],
    "vītivattesi": ['cped'],
    "vītivatteti": ['cped'],
    "vītivattetvā": ['cped'],
    "vītivattita": ['cped'],
    "vītiḥ": ['ap90'],
    "vītoccayabandha": ['mw'],
    "vītottara": ['mw'],
    "vītottaram": ['ddsa', 'mw'],
    "vītta": ['mw'],
    "vītā": ['mw'],
    "vītārci": ['mw'],
    "vītārcis": ['mw'],
    "vītāśoka": ['mw'],
    "vīvadha": ['cae', 'mw'],
    "vīvadhaḥ": ['ap90'],
    "vīvadhika": ['mw'],
    "vīvadhikaḥ": ['ap90'],
    "vīvadhā": ['mw'],
    "vīvidha": ['mw'],
    "vīvāha": ['ddsa', 'mw'],
    "vīvṛta": ['mw'],
    "vīya": ['gra'],
    "vīyati": ['cped'],
    "vīśa": ['mw'],
    "vīḍ": ['cae', 'ddsa', 'gra', 'mw'],
    "vīḍita": ['mw'],
    "vīḍu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vīḍuaṅga": ['gra'],
    "vīḍudveṣas": ['gra', 'mw'],
    "vīḍuharas": ['gra', 'mw'],
    "vīḍuharṣin": ['gra', 'mw'],
    "vīḍujambha": ['gra', 'mw'],
    "vīḍupatman": ['gra', 'mw'],
    "vīḍupavi": ['gra', 'mw'],
    "vīḍupāṇi": ['gra', 'mw'],
    "vīḍvaṅga": ['cae', 'gra', 'mw'],
    "vīḍvī": ['cae'],
    "vīṃkhā": ['ap90'],
    "vīṅgita": ['mw'],
    "vīṅka": ['mw'],
    "vīṅkh": ['mw'],
    "vīṅkhā": ['mw'],
    "vīṇaka": ['bhs'],
    "vīṇaya": ['ddsa'],
    "vīṇin": ['ap90', 'cae', 'ddsa', 'mw'],
    "vīṇā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "vīṇābhid": ['mw'],
    "vīṇādatta": ['mw'],
    "vīṇādaṇḍa": ['mw'],
    "vīṇādaṇḍaka": ['cped'],
    "vīṇādoṇi": ['cped'],
    "vīṇāgaṇagin": ['mw'],
    "vīṇāgaṇakin": ['mw'],
    "vīṇāgāthin": ['cae', 'mw'],
    "vīṇāhasta": ['mw'],
    "vīṇākarṇa": ['mw'],
    "vīṇāla": ['mw'],
    "vīṇānubandha": ['mw'],
    "vīṇāpaṇavatūṇavat": ['mw'],
    "vīṇāpraseva": ['mw'],
    "vīṇāpāṇi": ['mw'],
    "vīṇārava": ['mw'],
    "vīṇāravaghoṣa": ['bhs'],
    "vīṇāsya": ['mw'],
    "vīṇātantra": ['mw'],
    "vīṇātūṇava": ['mw'],
    "vīṇāvat": ['mw'],
    "vīṇāvatsarāja": ['mw'],
    "vīṇāvaṃśaśalākā": ['mw'],
    "vīṇāvinoda": ['mw'],
    "vīṇāvāda": ['cae', 'mw'],
    "vīṇāvādaka": ['mw'],
    "vīṇāvādana": ['mw'],
    "vīṇāvādya": ['mw'],
    "vīṇāvāyana": ['cped'],
    "vīṇāśilpa": ['mw'],
    "vīṣ": ['mw'],
    "vīṣita": ['mw'],
    "vīṭa": ['mw'],
    "vīṭaka": ['mw'],
    "vīṭamukha": ['mw'],
    "vīṭi": ['mw'],
    "vīṭikā": ['cae', 'mw'],
    "vīṭiḥ": ['ap90'],
    "vīṭā": ['ap90', 'cae', 'ddsa'],
    "vīṭī": ['mw'],
    "vūdagra": ['bhs'],
    "vūpasama": ['cped'],
    "vūpasamana": ['cped'],
    "vūpasamenta": ['cped'],
    "vūpasamesi": ['cped'],
    "vūpasameti": ['cped'],
    "vūpasametvā": ['cped'],
    "vūpasamita": ['cped'],
    "vūpasammati": ['cped'],
    "vūpasanta": ['cped'],
    "vūria": ['gra'],
    "vūrya": ['cae', 'gra', 'mw'],
    "vūrṇa": ['ap90', 'mw'],
    "vūs": ['mw'],
    "vūtthāna": ['cped'],
    "vūvaśarman": ['mw'],
    "vūḷha": ['cped'],
    "vṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛc": ['ap90'],
    "vṛcayā": ['gra', 'mw'],
    "vṛcīvat": ['gra', 'mw'],
    "vṛddha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "vṛddhabalā": ['mw'],
    "vṛddhabaudhāyana": ['mw'],
    "vṛddhabhoja": ['mw'],
    "vṛddhabhāva": ['cae', 'mw'],
    "vṛddhabrahmasaṃhitā": ['mw'],
    "vṛddhabrāhmaṇopaniṣadbhāṣya": ['mw'],
    "vṛddhabāla": ['mw'],
    "vṛddhabālaka": ['mw'],
    "vṛddhabṛhaspati": ['mw'],
    "vṛddhacāṇakya": ['cae', 'mw'],
    "vṛddhadeva": ['bhs'],
    "vṛddhadhūpa": ['mw'],
    "vṛddhadvijarūpin": ['mw'],
    "vṛddhadyumna": ['mw'],
    "vṛddhadāra": ['mw'],
    "vṛddhadāraka": ['mw'],
    "vṛddhadāru": ['mw'],
    "vṛddhagarbhā": ['mw'],
    "vṛddhagarga": ['cae', 'mw'],
    "vṛddhagautama": ['mw'],
    "vṛddhagautamasaṃhitā": ['mw'],
    "vṛddhagaṅgā": ['mw'],
    "vṛddhagaṅgādhara": ['mw'],
    "vṛddhagirimāhātmya": ['mw'],
    "vṛddhagonasa": ['mw'],
    "vṛddhagārga": ['mw'],
    "vṛddhagārgya": ['mw'],
    "vṛddhagārgīya": ['mw'],
    "vṛddhahārīta": ['mw'],
    "vṛddhajātaka": ['mw'],
    "vṛddhaka": ['bhs', 'ddsa', 'mw'],
    "vṛddhakarman": ['mw'],
    "vṛddhakauśika": ['mw'],
    "vṛddhakeśava": ['mw'],
    "vṛddhakola": ['cae', 'mw'],
    "vṛddhakośa": ['mw'],
    "vṛddhakoṭarapuṣpī": ['mw'],
    "vṛddhakrama": ['mw'],
    "vṛddhakumārīvākyavaranyāya": ['mw'],
    "vṛddhakāka": ['mw'],
    "vṛddhakāla": ['mw'],
    "vṛddhakātyāyana": ['mw'],
    "vṛddhakāverī": ['mw'],
    "vṛddhakāverīmāhātmya": ['mw'],
    "vṛddhakāśyapa": ['bhs'],
    "vṛddhakṛcchra": ['mw'],
    "vṛddhakṣatra": ['mw'],
    "vṛddhakṣema": ['mw'],
    "vṛddhakṣetravaralocana": ['mw'],
    "vṛddhamahas": ['cae', 'gra', 'mw'],
    "vṛddhamanu": ['mw'],
    "vṛddhamata": ['mw'],
    "vṛddhanagara": ['mw'],
    "vṛddhanyāsa": ['mw'],
    "vṛddhanābhi": ['mw'],
    "vṛddhaparāśara": ['mw'],
    "vṛddhapradhāna": ['mw'],
    "vṛddhapramātāmaha": ['mw'],
    "vṛddhapramātāmahī": ['mw'],
    "vṛddhaprapitāmaha": ['mw'],
    "vṛddhaprapitāmahī": ['mw'],
    "vṛddhapārāśarya": ['mw'],
    "vṛddhapārāśarīya": ['mw'],
    "vṛddharaṅka": ['cae', 'mw'],
    "vṛddharāja": ['mw'],
    "vṛddhasaṃgha": ['mw'],
    "vṛddhasena": ['gra', 'mw'],
    "vṛddhasenā": ['mw'],
    "vṛddhasevin": ['cae', 'mw'],
    "vṛddhasevitva": ['mw'],
    "vṛddhasevā": ['cae', 'mw'],
    "vṛddhasuśruta": ['mw'],
    "vṛddhasūtraka": ['mw'],
    "vṛddhasṛgāla": ['cae', 'mw'],
    "vṛddhatama": ['mw'],
    "vṛddhataraka": ['bhs'],
    "vṛddhatva": ['mw'],
    "vṛddhatā": ['cae', 'mw'],
    "vṛddhavaiyākaraṇabhūṣaṇa": ['mw'],
    "vṛddhavasiṣṭha": ['mw'],
    "vṛddhavayas": ['cae', 'gra', 'mw'],
    "vṛddhavega": ['mw'],
    "vṛddhavibhītaka": ['mw'],
    "vṛddhaviṣṇu": ['mw'],
    "vṛddhaviṭa": ['cae', 'mw'],
    "vṛddhavādasūri": ['mw'],
    "vṛddhavādin": ['mw'],
    "vṛddhavāgbhaṭa": ['mw'],
    "vṛddhavāhana": ['mw'],
    "vṛddhavāśinī": ['mw'],
    "vṛddhavīvadhā": ['mw'],
    "vṛddhavṛṣṇa": ['mw'],
    "vṛddhavṛṣṇiya": ['mw'],
    "vṛddhayavana": ['mw'],
    "vṛddhayavanajātaka": ['mw'],
    "vṛddhayavaneśvara": ['mw'],
    "vṛddhayogataraṃgiṇī": ['mw'],
    "vṛddhayogaśataka": ['mw'],
    "vṛddhayoṣit": ['cae', 'mw'],
    "vṛddhayuvati": ['mw'],
    "vṛddhayājñavalkya": ['mw'],
    "vṛddhaśabdaratnaśekhara": ['mw'],
    "vṛddhaśarman": ['cae'],
    "vṛddhaśaunakī": ['mw'],
    "vṛddhaśavas": ['cae', 'gra', 'mw'],
    "vṛddhaśaṅkha": ['mw'],
    "vṛddhaśaṅkhasmṛti": ['mw'],
    "vṛddhaśocis": ['gra', 'mw'],
    "vṛddhaśravas": ['gra', 'mw'],
    "vṛddhaśrāvaka": ['bhs', 'mw'],
    "vṛddhaśākalya": ['cae', 'mw'],
    "vṛddhaśātātapa": ['mw'],
    "vṛddhaśātātapasmṛti": ['mw'],
    "vṛddhaśīlin": ['mw'],
    "vṛddhi": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛddhida": ['cae', 'mw'],
    "vṛddhidatta": ['mw'],
    "vṛddhidātrī": ['mw'],
    "vṛddhijīvaka": ['cae', 'mw'],
    "vṛddhijīvana": ['cae', 'mw'],
    "vṛddhijīvikā": ['mw'],
    "vṛddhika": ['bhs'],
    "vṛddhikara": ['cae', 'ddsa', 'mw'],
    "vṛddhimant": ['cae'],
    "vṛddhimat": ['ap90', 'mw'],
    "vṛddhipattra": ['mw'],
    "vṛddhirādaicsūtravicāra": ['mw'],
    "vṛddhiśrāddha": ['cae', 'mw'],
    "vṛddhiśrāddhadīpikā": ['mw'],
    "vṛddhiśrāddhaprayoga": ['mw'],
    "vṛddhiśrāddhavidhi": ['mw'],
    "vṛddhiḥ": ['ap90'],
    "vṛddhokṣa": ['cae', 'ddsa', 'mw'],
    "vṛddhopasevin": ['cae', 'mw'],
    "vṛddhy": ['mw'],
    "vṛddhyupajīvin": ['mw'],
    "vṛddhyājīva": ['mw'],
    "vṛddhyājīvin": ['mw'],
    "vṛddhā": ['ap90', 'mw'],
    "vṛddhācala": ['mw'],
    "vṛddhācalamāhātmya": ['mw'],
    "vṛddhāditya": ['mw'],
    "vṛddhānta": ['bhs', 'mw'],
    "vṛddhānuśāsana": ['ddsa', 'mw'],
    "vṛddhāpacāyitva": ['mw'],
    "vṛddhāraṇya": ['mw'],
    "vṛddhārka": ['mw'],
    "vṛddhāryabhaṭa": ['mw'],
    "vṛddhātreya": ['mw'],
    "vṛddhātri": ['mw'],
    "vṛddhāvasthā": ['mw'],
    "vṛddhāyu": ['cae', 'gra', 'mw'],
    "vṛddhāśrama": ['mw'],
    "vṛddhāṅguli": ['mw'],
    "vṛddhāṅguṣṭha": ['mw'],
    "vṛddhībhū": ['ddsa'],
    "vṛdh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛdha": ['cae', 'ddsa', 'gra'],
    "vṛdhanvat": ['ddsa'],
    "vṛdhas": ['gra'],
    "vṛdhasnu": ['cae', 'gra'],
    "vṛdhasāna": ['cae', 'ddsa'],
    "vṛdhasānaḥ": ['ap90'],
    "vṛdhasānuḥ": ['ap90'],
    "vṛdhe": ['cae', 'ddsa'],
    "vṛdhna": ['mw'],
    "vṛdhra": ['mw'],
    "vṛdhu": ['mw'],
    "vṛdhīka": ['cae', 'gra'],
    "vṛgala": ['mw'],
    "vṛh": ['ap90', 'gra', 'mw'],
    "vṛha": ['mw'],
    "vṛhaspati": ['ap90'],
    "vṛhat": ['ap90', 'mw'],
    "vṛhatikā": ['ap90'],
    "vṛhatphala": ['bhs'],
    "vṛhatī": ['ap90'],
    "vṛj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛjana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛjania": ['gra'],
    "vṛjanya": ['mw'],
    "vṛjanī": ['ddsa', 'gra', 'mw'],
    "vṛji": ['bhs', 'mw'],
    "vṛjigārhapata": ['mw'],
    "vṛjika": ['bhs', 'mw'],
    "vṛjina": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛjinavartani": ['gra', 'mw'],
    "vṛjinavat": ['mw'],
    "vṛjinā": ['mw'],
    "vṛjināy": ['gra'],
    "vṛjināya": ['mw'],
    "vṛjinīvat": ['mw'],
    "vṛjya": ['mw'],
    "vṛk": ['mw'],
    "vṛka": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛkabandhu": ['mw'],
    "vṛkabhaya": ['mw'],
    "vṛkadaṃśa": ['mw'],
    "vṛkadeva": ['mw'],
    "vṛkadevā": ['mw'],
    "vṛkadevī": ['mw'],
    "vṛkadhoraṇa": ['mw'],
    "vṛkadhūmaka": ['mw'],
    "vṛkadhūpa": ['cae', 'mw'],
    "vṛkadhūrta": ['mw'],
    "vṛkadhūrtaka": ['mw'],
    "vṛkadvaras": ['gra', 'mw'],
    "vṛkadīpti": ['mw'],
    "vṛkagarta": ['mw'],
    "vṛkagartīya": ['mw'],
    "vṛkagrāha": ['mw'],
    "vṛkajambha": ['mw'],
    "vṛkakarman": ['mw'],
    "vṛkakhaṇḍa": ['mw'],
    "vṛkala": ['cae', 'mw'],
    "vṛkaloman": ['cae', 'mw'],
    "vṛkalā": ['mw'],
    "vṛkanirvṛti": ['mw'],
    "vṛkaprastha": ['mw'],
    "vṛkaprekṣin": ['mw'],
    "vṛkaratha": ['mw'],
    "vṛkarūpya": ['mw'],
    "vṛkasthala": ['mw'],
    "vṛkasthalī": ['mw'],
    "vṛkatejas": ['mw'],
    "vṛkati": ['cae', 'gra', 'mw'],
    "vṛkatāt": ['gra', 'mw'],
    "vṛkatāti": ['cae', 'mw'],
    "vṛkavañcika": ['mw'],
    "vṛkavālā": ['mw'],
    "vṛkaḥ": ['ap90'],
    "vṛkka": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛkkaḥ": ['ap90'],
    "vṛkkā": ['mw'],
    "vṛkkāvatī": ['mw'],
    "vṛkodara": ['cae', 'ddsa', 'mw'],
    "vṛkodaramaya": ['mw'],
    "vṛkta": ['ap90', 'cae', 'ddsa', 'mw'],
    "vṛktabarhis": ['cae', 'gra', 'mw'],
    "vṛkti": ['gra', 'mw'],
    "vṛkya": ['cae'],
    "vṛkā": ['mw'],
    "vṛkājina": ['mw'],
    "vṛkākṣī": ['mw'],
    "vṛkāmlikā": ['mw'],
    "vṛkāri": ['mw'],
    "vṛkārāti": ['mw'],
    "vṛkāsuravadha": ['mw'],
    "vṛkāsya": ['mw'],
    "vṛkāvalupta": ['mw'],
    "vṛkāya": ['mw'],
    "vṛkāyu": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛkāśva": ['mw'],
    "vṛkāśvaki": ['mw'],
    "vṛkī": ['ddsa', 'gra', 'mw'],
    "vṛkṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛkṇavat": ['mw'],
    "vṛkṣ": ['ap90', 'mw'],
    "vṛkṣa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛkṣabandha": ['mw'],
    "vṛkṣabhakṣā": ['mw'],
    "vṛkṣabhavana": ['mw'],
    "vṛkṣabhedin": ['mw'],
    "vṛkṣabhid": ['mw'],
    "vṛkṣabhūmi": ['mw'],
    "vṛkṣacandra": ['mw'],
    "vṛkṣacara": ['mw'],
    "vṛkṣacchāya": ['mw'],
    "vṛkṣacchāyā": ['cae', 'mw'],
    "vṛkṣacikitsāropaṇādi": ['mw'],
    "vṛkṣacūḍāmaṇika": ['mw'],
    "vṛkṣada": ['mw'],
    "vṛkṣadala": ['mw'],
    "vṛkṣadevatā": ['cae', 'mw'],
    "vṛkṣadhūpa": ['mw'],
    "vṛkṣadhūpaka": ['mw'],
    "vṛkṣadohada": ['mw'],
    "vṛkṣaghaṭa": ['mw'],
    "vṛkṣagulma": ['mw'],
    "vṛkṣagulmāvṛta": ['mw'],
    "vṛkṣagṛha": ['mw'],
    "vṛkṣaja": ['mw'],
    "vṛkṣajātīya": ['mw'],
    "vṛkṣaka": ['cae', 'mw'],
    "vṛkṣakanda": ['mw'],
    "vṛkṣakaḥ": ['ap90'],
    "vṛkṣakeśa": ['gra', 'mw'],
    "vṛkṣakhaṇḍa": ['mw'],
    "vṛkṣakukkuṭa": ['mw'],
    "vṛkṣamarkaṭikā": ['mw'],
    "vṛkṣamaya": ['cae', 'mw'],
    "vṛkṣamārjāra": ['mw'],
    "vṛkṣamūla": ['cae', 'mw'],
    "vṛkṣamūlaniketana": ['mw'],
    "vṛkṣamūlatā": ['mw'],
    "vṛkṣamūlika": ['bhs', 'mw'],
    "vṛkṣamṛdbhū": ['mw'],
    "vṛkṣaniryāsa": ['cae', 'mw'],
    "vṛkṣanivāsa": ['mw'],
    "vṛkṣanāma": ['mw'],
    "vṛkṣanātha": ['mw'],
    "vṛkṣanāthaka": ['mw'],
    "vṛkṣaparṇa": ['mw'],
    "vṛkṣapurī": ['mw'],
    "vṛkṣapāka": ['mw'],
    "vṛkṣapāla": ['mw'],
    "vṛkṣaropaka": ['mw'],
    "vṛkṣaropayitṛ": ['mw'],
    "vṛkṣaropaṇa": ['mw'],
    "vṛkṣaropin": ['mw'],
    "vṛkṣaruhā": ['mw'],
    "vṛkṣarāj": ['mw'],
    "vṛkṣarāja": ['mw'],
    "vṛkṣasarpī": ['mw'],
    "vṛkṣasaṃkaṭa": ['mw'],
    "vṛkṣasecana": ['mw'],
    "vṛkṣasneha": ['mw'],
    "vṛkṣastha": ['mw'],
    "vṛkṣasthita": ['mw'],
    "vṛkṣasthāyin": ['mw'],
    "vṛkṣasāraka": ['mw'],
    "vṛkṣataila": ['mw'],
    "vṛkṣatakṣaka": ['mw'],
    "vṛkṣatala": ['mw'],
    "vṛkṣatraya": ['mw'],
    "vṛkṣatva": ['mw'],
    "vṛkṣaukas": ['cae', 'mw'],
    "vṛkṣavat": ['mw'],
    "vṛkṣavāsyaniketa": ['mw'],
    "vṛkṣavāṭikā": ['cae', 'mw'],
    "vṛkṣavāṭī": ['mw'],
    "vṛkṣayuddha": ['mw'],
    "vṛkṣaśa": ['mw'],
    "vṛkṣaśākhā": ['cae', 'mw'],
    "vṛkṣaśāyikā": ['mw'],
    "vṛkṣaśūnya": ['mw'],
    "vṛkṣaḥ": ['ap90'],
    "vṛkṣaṣaṇḍa": ['mw'],
    "vṛkṣeśaya": ['cae', 'ddsa', 'mw'],
    "vṛkṣodaya": ['mw'],
    "vṛkṣodyāpana": ['mw'],
    "vṛkṣotpala": ['mw'],
    "vṛkṣottha": ['mw'],
    "vṛkṣya": ['cae', 'ddsa', 'mw'],
    "vṛkṣādana": ['cae', 'mw'],
    "vṛkṣādanī": ['mw'],
    "vṛkṣādhirūḍhaka": ['mw'],
    "vṛkṣādhirūḍhi": ['mw'],
    "vṛkṣādinī": ['mw'],
    "vṛkṣādiruhaka": ['mw'],
    "vṛkṣādirūḍha": ['mw'],
    "vṛkṣādirūḍhaka": ['mw'],
    "vṛkṣādividyā": ['mw'],
    "vṛkṣāgra": ['cae', 'mw'],
    "vṛkṣālaya": ['mw'],
    "vṛkṣāmaya": ['mw'],
    "vṛkṣāmla": ['mw'],
    "vṛkṣārhā": ['mw'],
    "vṛkṣārohaṇa": ['cae', 'mw'],
    "vṛkṣāropaka": ['cae', 'mw'],
    "vṛkṣāropaṇa": ['mw'],
    "vṛkṣārūḍha": ['mw'],
    "vṛkṣāvāsa": ['mw'],
    "vṛkṣāyurveda": ['mw'],
    "vṛkṣāśrayin": ['mw'],
    "vṛkṣāṅghri": ['mw'],
    "vṛkṣīya": ['mw'],
    "vṛm, bṛh": ['ddsa'],
    "vṛnda": ['cae', 'ddsa', 'mw'],
    "vṛndagāyaka": ['mw'],
    "vṛndakaṭa": ['bhs'],
    "vṛndamaya": ['mw'],
    "vṛndamādhava": ['mw'],
    "vṛndara": ['mw'],
    "vṛndasaṃhitā": ['mw'],
    "vṛndasindhu": ['mw'],
    "vṛndaśas": ['mw'],
    "vṛndi": ['bhs'],
    "vṛndin": ['cae', 'ddsa', 'mw'],
    "vṛndiṣṭha": ['mw'],
    "vṛndā": ['ddsa', 'mw'],
    "vṛndāra": ['cae', 'ddsa', 'mw'],
    "vṛndāraka": ['cae', 'ddsa', 'mw'],
    "vṛndārakāya": ['mw'],
    "vṛndāraṇya": ['mw'],
    "vṛndāraṇyamāhātmya": ['mw'],
    "vṛndāvana": ['cae', 'ddsa', 'mw'],
    "vṛndāvanacampū": ['mw'],
    "vṛndāvanacandra": ['mw'],
    "vṛndāvanadeva": ['mw'],
    "vṛndāvanadāsa": ['mw'],
    "vṛndāvanakhaṇḍegargasaṃhitā": ['mw'],
    "vṛndāvanakāvya": ['mw'],
    "vṛndāvanakāvyaṭīkā": ['mw'],
    "vṛndāvanalīlāmṛta": ['mw'],
    "vṛndāvanamañjarī": ['mw'],
    "vṛndāvanamāhātmya": ['mw'],
    "vṛndāvananagara": ['mw'],
    "vṛndāvananirṇaya": ['mw'],
    "vṛndāvanapaddhati": ['mw'],
    "vṛndāvanapratiṣṭhā": ['mw'],
    "vṛndāvanarahasya": ['mw'],
    "vṛndāvanavarṇana": ['mw'],
    "vṛndāvanavinoda": ['mw'],
    "vṛndāvanavipina": ['mw'],
    "vṛndāvanayamaka": ['mw'],
    "vṛndāvanaśataka": ['mw'],
    "vṛndāvaneśa": ['mw'],
    "vṛndāvaneśvara": ['mw'],
    "vṛndāvaneśvarī": ['mw'],
    "vṛndāvanākhyāna": ['mw'],
    "vṛndāvanī": ['mw'],
    "vṛndīyas": ['mw'],
    "vṛnta": ['cae', 'ddsa', 'mw'],
    "vṛntaka": ['cae', 'mw'],
    "vṛntaphala": ['mw'],
    "vṛntatumbī": ['mw'],
    "vṛntayamaka": ['mw'],
    "vṛntikā": ['mw'],
    "vṛntitā": ['mw'],
    "vṛntā": ['mw'],
    "vṛntāka": ['mw'],
    "vṛntākavidhi": ['mw'],
    "vṛsaya": ['mw'],
    "vṛsikā": ['bhs'],
    "vṛt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "vṛtakṣaya": ['mw'],
    "vṛtapattrā": ['mw'],
    "vṛtaṃcaya": ['gra', 'mw'],
    "vṛthag": ['ddsa'],
    "vṛthak": ['cae', 'gra', 'mw'],
    "vṛthodaka": ['mw'],
    "vṛthodyama": ['mw'],
    "vṛthokta": ['mw'],
    "vṛthotpanna": ['cae', 'mw'],
    "vṛthā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛthābhoga": ['mw'],
    "vṛthācheda": ['mw'],
    "vṛthācāra": ['mw'],
    "vṛthādāna": ['mw'],
    "vṛthāghāta": ['mw'],
    "vṛthāgni": ['mw'],
    "vṛthājanman": ['mw'],
    "vṛthājāta": ['mw'],
    "vṛthākarman": ['ddsa', 'mw'],
    "vṛthākathā": ['mw'],
    "vṛthākulasamācāra": ['mw'],
    "vṛthākāra": ['mw'],
    "vṛthākṛsarasaṃyāva": ['mw'],
    "vṛthālambha": ['mw'],
    "vṛthāliṅga": ['mw'],
    "vṛthāliṅgin": ['mw'],
    "vṛthāmati": ['mw'],
    "vṛthāmāṃsa": ['mw'],
    "vṛthānna": ['mw'],
    "vṛthāpakva": ['mw'],
    "vṛthāpalita": ['mw'],
    "vṛthāpaśughna": ['mw'],
    "vṛthāprajā": ['mw'],
    "vṛthāpratijña": ['mw'],
    "vṛthārtavā": ['mw'],
    "vṛthāsaṃkarajāta": ['mw'],
    "vṛthāsuta": ['mw'],
    "vṛthātmāyāsa": ['mw'],
    "vṛthātva": ['mw'],
    "vṛthāvrata": ['mw'],
    "vṛthāvāc": ['mw'],
    "vṛthāvādin": ['mw'],
    "vṛthāvṛddha": ['mw'],
    "vṛthāśrama": ['mw'],
    "vṛthāṣah": ['gra', 'mw'],
    "vṛthāṣāh": ['gra'],
    "vṛthāṭyā": ['cae', 'mw'],
    "vṛti": ['cae', 'ddsa', 'mw'],
    "vṛtibhaṅga": ['mw'],
    "vṛtidruma": ['mw'],
    "vṛtidvāra": ['mw'],
    "vṛtimārga": ['mw'],
    "vṛtivallabha": ['mw'],
    "vṛtiḥ": ['ap90'],
    "vṛtiṃkara": ['ap90', 'mw'],
    "vṛtra": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛtrabhojana": ['mw'],
    "vṛtradruh": ['mw'],
    "vṛtradviṣ": ['mw'],
    "vṛtraghnī": ['mw'],
    "vṛtraha": ['cae', 'gra', 'mw'],
    "vṛtrahan": ['cae', 'gra', 'mw'],
    "vṛtrahant": ['cae'],
    "vṛtrahantama": ['mw'],
    "vṛtrahantṛ": ['mw'],
    "vṛtrahatha": ['gra', 'mw'],
    "vṛtrahatya": ['cae', 'gra', 'mw'],
    "vṛtrahatyā": ['mw'],
    "vṛtrahāya": ['mw'],
    "vṛtrakhāda": ['gra', 'mw'],
    "vṛtranāśana": ['mw'],
    "vṛtraputra": ['gra'],
    "vṛtraputrā": ['cae', 'mw'],
    "vṛtraripu": ['cae', 'mw'],
    "vṛtratara": ['cae', 'ddsa', 'mw'],
    "vṛtratur": ['cae', 'gra', 'mw'],
    "vṛtratva": ['mw'],
    "vṛtratūr": ['mw'],
    "vṛtratūria": ['gra'],
    "vṛtratūrya": ['cae', 'gra', 'mw'],
    "vṛtravadha": ['mw'],
    "vṛtravairin": ['cae', 'mw'],
    "vṛtravidviṣ": ['cae', 'mw'],
    "vṛtraśatru": ['mw'],
    "vṛtraśaṅku": ['mw'],
    "vṛtraḥ": ['ap90'],
    "vṛtrāri": ['cae', 'mw'],
    "vṛtta": ['ap90', 'cae', 'ddsa', 'mw'],
    "vṛttabandha": ['mw'],
    "vṛttabandhojjhita": ['mw'],
    "vṛttabhaṅga": ['mw'],
    "vṛttabhūya": ['mw'],
    "vṛttabīja": ['mw'],
    "vṛttabījakā": ['mw'],
    "vṛttabījā": ['mw'],
    "vṛttacandrikā": ['mw'],
    "vṛttacandrodaya": ['mw'],
    "vṛttacaula": ['mw'],
    "vṛttaceṣṭā": ['mw'],
    "vṛttacūḍa": ['mw'],
    "vṛttadarpaṇa": ['mw'],
    "vṛttadyumaṇi": ['mw'],
    "vṛttadīpavyākhyāna": ['mw'],
    "vṛttadīpikā": ['mw'],
    "vṛttagandhi": ['mw'],
    "vṛttagandhin": ['mw'],
    "vṛttagandhitva": ['mw'],
    "vṛttaguṇḍa": ['mw'],
    "vṛttahīna": ['mw'],
    "vṛttajña": ['cae', 'mw'],
    "vṛttaka": ['bhs', 'mw'],
    "vṛttakalpadruma": ['mw'],
    "vṛttakarkaṭī": ['mw'],
    "vṛttakarṣita": ['cae', 'mw'],
    "vṛttakaumudī": ['mw'],
    "vṛttakautuka": ['mw'],
    "vṛttakaṃ": ['ap90'],
    "vṛttakhaṇḍa": ['mw'],
    "vṛttakāya": ['cae', 'ddsa', 'mw'],
    "vṛttalakṣaṇa": ['mw'],
    "vṛttamallikā": ['mw'],
    "vṛttamauktika": ['mw'],
    "vṛttamaṇikośa": ['mw'],
    "vṛttamuktāvalī": ['mw'],
    "vṛttamuktāvalīṭīkā": ['mw'],
    "vṛttamālā": ['mw'],
    "vṛttamāṇikyamālā": ['mw'],
    "vṛttaniṣpāvikā": ['mw'],
    "vṛttapariṇāha": ['mw'],
    "vṛttaparṇī": ['mw'],
    "vṛttapattrā": ['mw'],
    "vṛttaphala": ['mw'],
    "vṛttaphalā": ['mw'],
    "vṛttapradīpa": ['mw'],
    "vṛttapratyabhijña": ['mw'],
    "vṛttapratyaya": ['mw'],
    "vṛttapratyayakaumudī": ['mw'],
    "vṛttapuṣpa": ['mw'],
    "vṛttapīna": ['mw'],
    "vṛttapūraṇa": ['mw'],
    "vṛttaratnākara": ['mw'],
    "vṛttaratnākarapañcikā": ['mw'],
    "vṛttaratnākarasetu": ['mw'],
    "vṛttaratnākaravyākhyā": ['mw'],
    "vṛttaratnākaraṭīkā": ['mw'],
    "vṛttaratnākarādarśa": ['mw'],
    "vṛttaratnāvali": ['mw'],
    "vṛttaratnāvalī": ['mw'],
    "vṛttarāmāyaṇa": ['mw'],
    "vṛttasampanna": ['mw'],
    "vṛttasaṃketa": ['mw'],
    "vṛttasaṃpanna": ['cae'],
    "vṛttastha": ['cae', 'mw'],
    "vṛttasudhodaya": ['mw'],
    "vṛttasvādhyāyavat": ['mw'],
    "vṛttasādin": ['mw'],
    "vṛttasārāvalī": ['mw'],
    "vṛttataraṃgiṇī": ['mw'],
    "vṛttatas": ['mw'],
    "vṛttataṇḍula": ['mw'],
    "vṛttatumbī": ['mw'],
    "vṛttatuṇḍa": ['mw'],
    "vṛttatva": ['mw'],
    "vṛttaujas": ['cae', 'ddsa', 'mw'],
    "vṛttavaktra": ['mw'],
    "vṛttavant": ['cae'],
    "vṛttavat": ['mw'],
    "vṛttavinoda": ['mw'],
    "vṛttavivecana": ['mw'],
    "vṛttavārttika": ['mw'],
    "vṛttayamaka": ['mw'],
    "vṛttayukta": ['mw'],
    "vṛttaśastra": ['mw'],
    "vṛttaśata": ['mw'],
    "vṛttaśataka": ['mw'],
    "vṛttaślāghin": ['mw'],
    "vṛttaśālin": ['cae', 'mw'],
    "vṛttervāru": ['mw'],
    "vṛtti": ['cae', 'ddsa', 'mw'],
    "vṛttibhaṅga": ['mw'],
    "vṛttibhāj": ['mw'],
    "vṛtticakra": ['mw'],
    "vṛtticandrapradīpikānirukti": ['mw'],
    "vṛtticcheda": ['mw'],
    "vṛttida": ['mw'],
    "vṛttidāna": ['mw'],
    "vṛttidātṛ": ['mw'],
    "vṛttidīpikā": ['mw'],
    "vṛttihan": ['mw'],
    "vṛttihantṛ": ['mw'],
    "vṛttihetu": ['mw'],
    "vṛttihrāsa": ['mw'],
    "vṛttika": ['mw'],
    "vṛttikara": ['ddsa', 'mw'],
    "vṛttikarṣita": ['mw'],
    "vṛttikāra": ['mw'],
    "vṛttikṛt": ['mw'],
    "vṛttikṣīṇa": ['mw'],
    "vṛttilābha": ['mw'],
    "vṛttimant": ['cae'],
    "vṛttimat": ['mw'],
    "vṛttimūla": ['mw'],
    "vṛttin": ['cae', 'mw'],
    "vṛttinibandhana": ['mw'],
    "vṛttinirodha": ['mw'],
    "vṛttiprabhākara": ['mw'],
    "vṛttipradīpa": ['mw'],
    "vṛttisaṃgraha": ['mw'],
    "vṛttistha": ['mw'],
    "vṛttitva": ['mw'],
    "vṛttitā": ['mw'],
    "vṛttivaikalya": ['mw'],
    "vṛttivallabha": ['mw'],
    "vṛttivāda": ['mw'],
    "vṛttivārttika": ['mw'],
    "vṛttiḥ": ['ap90'],
    "vṛttoktiratna": ['mw'],
    "vṛttoru": ['mw'],
    "vṛttotsava": ['mw'],
    "vṛtty": ['mw'],
    "vṛttyanuprāsa": ['ddsa', 'mw'],
    "vṛttyarthabodhaka": ['mw'],
    "vṛttyartham": ['cae', 'mw'],
    "vṛttyuparodha": ['mw'],
    "vṛttyupāya": ['mw'],
    "vṛttā": ['mw'],
    "vṛttādhyayana": ['mw'],
    "vṛttādhyayanarddhi": ['mw'],
    "vṛttādhyayanasampatti": ['mw'],
    "vṛttākṣepa": ['mw'],
    "vṛttānta": ['cae', 'ddsa', 'mw'],
    "vṛttāntadarśin": ['mw'],
    "vṛttāntaśas": ['mw'],
    "vṛttāntānveṣaka": ['mw'],
    "vṛttānupūrva": ['mw'],
    "vṛttānusāra": ['mw'],
    "vṛttānusārin": ['mw'],
    "vṛttānusārāt": ['mw'],
    "vṛttānuvartin": ['mw'],
    "vṛttārdha": ['mw'],
    "vṛttāyatabhuja": ['mw'],
    "vṛttāṅgī": ['mw'],
    "vṛtya": ['mw'],
    "vṛtā": ['cae', 'gra'],
    "vṛtārcis": ['mw'],
    "vṛñj": ['mw'],
    "vṛś": ['ap90', 'mw'],
    "vṛśa": ['cae', 'mw'],
    "vṛśaḥ": ['ap90'],
    "vṛścadvana": ['ddsa', 'gra', 'mw'],
    "vṛścana": ['mw'],
    "vṛścika": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛścikacchadā": ['mw'],
    "vṛścikapattrikā": ['mw'],
    "vṛścikapriyā": ['mw'],
    "vṛścikarāśi": ['mw'],
    "vṛścikarṇī": ['mw'],
    "vṛścikaḥ": ['ap90'],
    "vṛścikeśa": ['mw'],
    "vṛścikā": ['mw'],
    "vṛścikālī": ['mw'],
    "vṛścikī": ['mw'],
    "vṛścipattrī": ['mw'],
    "vṛścita": ['mw'],
    "vṛścī": ['bhs'],
    "vṛścīka": ['mw'],
    "vṛścīra": ['mw'],
    "vṛścīva": ['mw'],
    "vṛśā": ['mw'],
    "vṛśī": ['mw'],
    "vṛḍha": ['mw'],
    "vṛṃda": ['ap90'],
    "vṛṃdiṣṭha": ['ap90'],
    "vṛṃdā": ['ap90'],
    "vṛṃdāra": ['ap90'],
    "vṛṃdāraka": ['ap90'],
    "vṛṃdāvana": ['ap90'],
    "vṛṃdīyas": ['ap90'],
    "vṛṃh": ['mw'],
    "vṛṃhayitar": ['bhs'],
    "vṛṃtaṃ": ['ap90'],
    "vṛṃtikā": ['ap90'],
    "vṛṃtākaḥ": ['ap90'],
    "vṛṅga": ['mw'],
    "vṛṇ": ['ap90', 'mw'],
    "vṛṇāna": ['ddsa'],
    "vṛṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛṣa": ['cae', 'ddsa', 'mw'],
    "vṛṣabha": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛṣabhacarita": ['mw'],
    "vṛṣabhadhvaja": ['cae', 'mw'],
    "vṛṣabhadhvajeśvaramāhātmya": ['mw'],
    "vṛṣabhadāna": ['mw'],
    "vṛṣabhagati": ['mw'],
    "vṛṣabhaikasahasrā": ['cae', 'mw'],
    "vṛṣabhaikādaśā": ['cae', 'mw'],
    "vṛṣabhajātaka": ['bhs'],
    "vṛṣabhaketu": ['cae', 'mw'],
    "vṛṣabhalakṣaṇa": ['mw'],
    "vṛṣabhara": ['gra', 'mw'],
    "vṛṣabhaskandha": ['mw'],
    "vṛṣabhasvargavidhāna": ['mw'],
    "vṛṣabhasvāmin": ['mw'],
    "vṛṣabhatva": ['mw'],
    "vṛṣabhatā": ['bhs'],
    "vṛṣabhatīrthamāhātmya": ['mw'],
    "vṛṣabhavīthi": ['mw'],
    "vṛṣabhayāna": ['cae', 'mw'],
    "vṛṣabhaḥ": ['ap90'],
    "vṛṣabhaṣoḍaśa": ['mw'],
    "vṛṣabhaṣoḍaśā": ['cae', 'mw'],
    "vṛṣabhekṣaṇa": ['mw'],
    "vṛṣabhin": ['bhs'],
    "vṛṣabhitā": ['bhs'],
    "vṛṣabhotsarga": ['mw'],
    "vṛṣabhā": ['mw'],
    "vṛṣabhādri": ['mw'],
    "vṛṣabhādrimāhātmya": ['mw'],
    "vṛṣabhākṣa": ['mw'],
    "vṛṣabhākṣī": ['mw'],
    "vṛṣabhānna": ['gra', 'mw'],
    "vṛṣabhānu": ['cae', 'mw'],
    "vṛṣabhānujā": ['cae', 'mw'],
    "vṛṣabhānunandinī": ['mw'],
    "vṛṣabhāsuravidhvaṃsin": ['mw'],
    "vṛṣabhāsā": ['mw'],
    "vṛṣabhāṅka": ['mw'],
    "vṛṣabhī": ['ap90', 'mw'],
    "vṛṣacakra": ['mw'],
    "vṛṣacyuta": ['gra', 'mw'],
    "vṛṣad": ['mw'],
    "vṛṣadant": ['cae'],
    "vṛṣadanta": ['mw'],
    "vṛṣadarbha": ['mw'],
    "vṛṣadat": ['mw'],
    "vṛṣadañji": ['gra', 'mw'],
    "vṛṣadaṃśa": ['cae', 'ddsa', 'mw'],
    "vṛṣadaṃśaka": ['mw'],
    "vṛṣadaṃśakaka": ['mw'],
    "vṛṣadaṃśamukha": ['mw'],
    "vṛṣadeva": ['mw'],
    "vṛṣadevā": ['mw'],
    "vṛṣadgu": ['mw'],
    "vṛṣadhara": ['mw'],
    "vṛṣadhvaja": ['cae', 'mw'],
    "vṛṣadhvajā": ['mw'],
    "vṛṣadhvāṅkṣī": ['mw'],
    "vṛṣadhūta": ['gra', 'mw'],
    "vṛṣadvīpa": ['mw'],
    "vṛṣadāna": ['mw'],
    "vṛṣaga": ['mw'],
    "vṛṣagandhā": ['mw'],
    "vṛṣagaṇa": ['gra', 'mw'],
    "vṛṣagāyatrī": ['mw'],
    "vṛṣajūti": ['gra', 'mw'],
    "vṛṣaka": ['cae', 'mw'],
    "vṛṣakarman": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛṣakarṇikā": ['mw'],
    "vṛṣakarṇī": ['mw'],
    "vṛṣaketana": ['mw'],
    "vṛṣaketu": ['mw'],
    "vṛṣaketuśiṣya": ['mw'],
    "vṛṣakhādi": ['cae', 'gra', 'mw'],
    "vṛṣakratu": ['cae', 'gra', 'mw'],
    "vṛṣakāma": ['mw'],
    "vṛṣakṛta": ['mw'],
    "vṛṣala": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛṣalaka": ['mw'],
    "vṛṣalakaḥ": ['ap90'],
    "vṛṣalakṣaṇā": ['mw'],
    "vṛṣalakṣman": ['ddsa'],
    "vṛṣalapācaka": ['mw'],
    "vṛṣalatva": ['mw'],
    "vṛṣalatā": ['cae', 'mw'],
    "vṛṣalavṛtti": ['cae'],
    "vṛṣalayājaka": ['mw'],
    "vṛṣalaḥ": ['ap90'],
    "vṛṣalocana": ['mw'],
    "vṛṣalātmaja": ['mw'],
    "vṛṣalāñchana": ['mw'],
    "vṛṣalī": ['ap90', 'ddsa', 'mw'],
    "vṛṣalīpati": ['cae', 'mw'],
    "vṛṣalīphenapīta": ['mw'],
    "vṛṣalīputra": ['mw'],
    "vṛṣalīsevana": ['mw'],
    "vṛṣamaṇas": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛṣamaṇyu": ['cae', 'gra', 'mw'],
    "vṛṣan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛṣandhi": ['gra'],
    "vṛṣantama": ['ddsa'],
    "vṛṣanābhi": ['cae', 'gra', 'mw'],
    "vṛṣanādin": ['ddsa', 'mw'],
    "vṛṣanāman": ['gra', 'mw'],
    "vṛṣanāśana": ['mw'],
    "vṛṣaparvan": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛṣaparṇī": ['mw'],
    "vṛṣapati": ['mw'],
    "vṛṣapatnī": ['gra', 'mw'],
    "vṛṣapattrikā": ['mw'],
    "vṛṣaprabharman": ['gra', 'mw'],
    "vṛṣaprayāvan": ['cae', 'gra', 'mw'],
    "vṛṣapsu": ['cae', 'gra', 'mw'],
    "vṛṣapuṣpa": ['mw'],
    "vṛṣapāṇa": ['gra', 'mw'],
    "vṛṣapāṇi": ['cae', 'gra', 'mw'],
    "vṛṣapūtana": ['mw'],
    "vṛṣaratha": ['gra', 'mw'],
    "vṛṣaraśmi": ['gra', 'mw'],
    "vṛṣarāja": ['mw'],
    "vṛṣarājaketana": ['mw'],
    "vṛṣasava": ['gra', 'mw'],
    "vṛṣasena": ['bhs', 'cae', 'mw'],
    "vṛṣaskandha": ['mw'],
    "vṛṣastubh": ['gra', 'mw'],
    "vṛṣasy": ['cae'],
    "vṛṣasya": ['ddsa', 'mw'],
    "vṛṣasyantī": ['mw'],
    "vṛṣasyati": ['ap90'],
    "vṛṣasyaṃtī": ['ap90'],
    "vṛṣasāhvayā": ['mw'],
    "vṛṣasāhvā": ['mw'],
    "vṛṣasānu": ['mw'],
    "vṛṣasṛkkin": ['mw'],
    "vṛṣatva": ['cae', 'gra', 'mw'],
    "vṛṣatvana": ['cae', 'gra', 'mw'],
    "vṛṣatā": ['mw'],
    "vṛṣavat": ['mw'],
    "vṛṣavivāha": ['mw'],
    "vṛṣavrata": ['cae', 'gra', 'mw'],
    "vṛṣavrāta": ['cae', 'gra', 'mw'],
    "vṛṣavāha": ['ddsa', 'mw'],
    "vṛṣavāhana": ['mw'],
    "vṛṣavṛṣa": ['mw'],
    "vṛṣaya": ['mw'],
    "vṛṣayaḥ": ['ap90'],
    "vṛṣayu": ['cae', 'gra', 'mw'],
    "vṛṣaśatru": ['mw'],
    "vṛṣaśipra": ['gra', 'mw'],
    "vṛṣaśuṣma": ['gra', 'mw'],
    "vṛṣaśuṣṇa": ['mw'],
    "vṛṣaśīla": ['mw'],
    "vṛṣaḥ": ['ap90'],
    "vṛṣaṃdhi": ['mw'],
    "vṛṣaṇ": ['mw'],
    "vṛṣaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vṛṣaṇakacchū": ['mw'],
    "vṛṣaṇaśva": ['cae', 'gra', 'mw'],
    "vṛṣaṇaśvaḥ": ['ap90'],
    "vṛṣaṇvant": ['cae'],
    "vṛṣaṇvasu": ['cae', 'gra', 'mw'],
    "vṛṣaṇvat": ['ddsa', 'gra', 'mw'],
    "vṛṣaṇy": ['cae', 'gra'],
    "vṛṣaṣaṇḍa": ['mw'],
    "vṛṣendra": ['mw'],
    "vṛṣikā": ['bhs'],
    "vṛṣiman": ['mw'],
    "vṛṣin": ['ap90', 'mw'],
    "vṛṣodara": ['mw'],
    "vṛṣotsarga": ['ddsa', 'mw'],
    "vṛṣotsargakaumudī": ['mw'],
    "vṛṣotsargapaddhati": ['mw'],
    "vṛṣotsargapariśiṣṭa": ['mw'],
    "vṛṣotsargaprayoga": ['mw'],
    "vṛṣotsargatattva": ['mw'],
    "vṛṣotsargavidhi": ['mw'],
    "vṛṣotsāha": ['mw'],
    "vṛṣya": ['ap90', 'cae', 'ddsa', 'mw'],
    "vṛṣyagandhikā": ['mw'],
    "vṛṣyagandhā": ['mw'],
    "vṛṣyakandā": ['mw'],
    "vṛṣyatā": ['mw'],
    "vṛṣyavallikā": ['mw'],
    "vṛṣyā": ['mw'],
    "vṛṣā": ['mw'],
    "vṛṣādarbha": ['mw'],
    "vṛṣādarbhi": ['mw'],
    "vṛṣādri": ['mw'],
    "vṛṣāgir": ['gra', 'mw'],
    "vṛṣāhāra": ['mw'],
    "vṛṣākapi": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛṣākapiśastra": ['mw'],
    "vṛṣākapiḥ": ['ap90'],
    "vṛṣākapāyī": ['ap90', 'ddsa', 'gra', 'mw'],
    "vṛṣākara": ['mw'],
    "vṛṣākhya": ['mw'],
    "vṛṣākrāntā": ['mw'],
    "vṛṣākṛti": ['mw'],
    "vṛṣākṣa": ['mw'],
    "vṛṣāmitra": ['mw'],
    "vṛṣāmodinī": ['mw'],
    "vṛṣānna": ['cae', 'mw'],
    "vṛṣāntaka": ['mw'],
    "vṛṣārava": ['cae', 'gra', 'mw'],
    "vṛṣāvāha": ['mw'],
    "vṛṣāy": ['cae', 'gra'],
    "vṛṣāya": ['ddsa', 'mw'],
    "vṛṣāyate": ['ap90'],
    "vṛṣāyaṇa": ['mw'],
    "vṛṣāyaṇaḥ": ['ap90'],
    "vṛṣāyudh": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛṣāñcana": ['mw'],
    "vṛṣāśīla": ['mw'],
    "vṛṣāṅka": ['cae', 'ddsa', 'mw'],
    "vṛṣāṅkaja": ['mw'],
    "vṛṣāṇa": ['mw'],
    "vṛṣāṇaka": ['mw'],
    "vṛṣāṇḍa": ['mw'],
    "vṛṣī": ['ap90', 'mw'],
    "vṛṣīya": ['mw'],
    "vṛṣṇa": ['mw'],
    "vṛṣṇi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "vṛṣṇia": ['gra'],
    "vṛṣṇigarbha": ['mw'],
    "vṛṣṇika": ['mw'],
    "vṛṣṇimat": ['mw'],
    "vṛṣṇipura": ['mw'],
    "vṛṣṇipāla": ['cae', 'mw'],
    "vṛṣṇivareṇya": ['mw'],
    "vṛṣṇivṛddha": ['mw'],
    "vṛṣṇiya": ['mw'],
    "vṛṣṇiāvat": ['gra'],
    "vṛṣṇya": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛṣṇyāvant": ['cae'],
    "vṛṣṇyāvat": ['gra', 'mw'],
    "vṛṣṇī": ['mw'],
    "vṛṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "vṛṣṭadharma": ['mw'],
    "vṛṣṭavat": ['mw'],
    "vṛṣṭe": ['mw'],
    "vṛṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "vṛṣṭibhū": ['mw'],
    "vṛṣṭidyo": ['gra', 'mw'],
    "vṛṣṭidyāvan": ['mw'],
    "vṛṣṭighnī": ['mw'],
    "vṛṣṭihavya": ['gra', 'mw'],
    "vṛṣṭijīvana": ['mw'],
    "vṛṣṭikara": ['mw'],
    "vṛṣṭikarendraprakaraṇa": ['mw'],
    "vṛṣṭikāla": ['mw'],
    "vṛṣṭikāma": ['mw'],
    "vṛṣṭikāmanā": ['mw'],
    "vṛṣṭimant": ['cae'],
    "vṛṣṭimat": ['ap90', 'gra', 'mw'],
    "vṛṣṭimaya": ['mw'],
    "vṛṣṭimāruta": ['mw'],
    "vṛṣṭipāta": ['cae', 'ddsa', 'mw'],
    "vṛṣṭisampāta": ['mw'],
    "vṛṣṭisani": ['cae', 'mw'],
    "vṛṣṭisanitva": ['mw'],
    "vṛṣṭisaṃpāta": ['cae'],
    "vṛṣṭita": ['bhs'],
    "vṛṣṭitā": ['mw'],
    "vṛṣṭitādita": ['mw'],
    "vṛṣṭivani": ['cae', 'gra', 'mw'],
    "vṛṣṭivāta": ['mw'],
    "vṛṣṭiḥ": ['ap90'],
    "vṛṣṭyambu": ['mw'],
    "vṛṣṭāyate": ['bhs'],
    "vṝ": ['ap90', 'mw'],
    "ya": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yabh": ['ap90', 'cae', 'ddsa', 'mw'],
    "yabhana": ['mw'],
    "yabhanaṃ": ['ap90'],
    "yabhyā": ['mw'],
    "yac": ['mw'],
    "yacca": ['bhs', 'ddsa'],
    "yaccha": ['ddsa'],
    "yacchaddha": ['cae'],
    "yacchandas": ['ddsa', 'mw'],
    "yacchraddha": ['mw'],
    "yacchīla": ['mw'],
    "yacitaka": ['cped'],
    "yad": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "yada": ['mw'],
    "yadabhāve": ['mw'],
    "yadahar": ['mw'],
    "yadanna": ['ddsa', 'mw'],
    "yadapi": ['bhs'],
    "yadartha": ['cae', 'mw'],
    "yadartham": ['cae', 'mw'],
    "yadarthe": ['cae', 'mw'],
    "yadavadhi": ['mw'],
    "yadavasāna": ['mw'],
    "yadaśana": ['mw'],
    "yadaśanīya": ['mw'],
    "yadbala": ['mw'],
    "yadbhaviṣya": ['cae', 'mw'],
    "yadbhūyaiṣīya": ['bhs'],
    "yadbhūyas": ['mw'],
    "yadbhūyasikīya": ['bhs'],
    "yadbhūyaskālaka": ['bhs'],
    "yadbhūyaskārin": ['mw'],
    "yadbhūyaso": ['bhs'],
    "yadbhūyasā": ['bhs', 'mw'],
    "yadbhūyopita": ['bhs'],
    "yaddevata": ['cae', 'mw'],
    "yaddevatya": ['mw'],
    "yaddhetos": ['cae', 'mw'],
    "yaddvaṃdva": ['mw'],
    "yadgotra": ['cae', 'ddsa', 'mw'],
    "yadi": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yadidam": ['bhs'],
    "yadidaṁ": ['cped'],
    "yadriyañc": ['cae', 'ddsa', 'mw'],
    "yadryañc": ['cae', 'mw'],
    "yadrūpavicāra": ['mw'],
    "yadu": ['cae', 'ddsa', 'gra', 'mw'],
    "yadubharata": ['mw'],
    "yadudhra": ['mw'],
    "yadugirīśāṣṭottaraśata": ['mw'],
    "yadukulodvaha": ['mw'],
    "yadumaṇi": ['mw'],
    "yadunandana": ['mw'],
    "yadunātha": ['mw'],
    "yadupati": ['mw'],
    "yadupuṃgava": ['mw'],
    "yaduta": ['bhs'],
    "yaduvaṃśa": ['mw'],
    "yaduvaṃśakāvya": ['mw'],
    "yaduvīramukhya": ['mw'],
    "yaduśreṣṭha": ['mw'],
    "yaduḥ": ['ap90'],
    "yadvada": ['mw'],
    "yadvan": ['mw'],
    "yadvat": ['cae', 'ddsa', 'mw'],
    "yadvidha": ['cae', 'mw'],
    "yadvidvas": ['mw'],
    "yadvā": ['cae', 'mw'],
    "yadvāhiṣṭhīya": ['mw'],
    "yadvīrya": ['mw'],
    "yadvṛtta": ['cae', 'mw'],
    "yadā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yadānikāmam": ['mw'],
    "yadārṣeya": ['mw'],
    "yadātmaka": ['ddsa', 'mw'],
    "yadāvājadāvarī": ['mw'],
    "yadī": ['cae'],
    "yadīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "yadūdvaha": ['mw'],
    "yadṛccha": ['cae', 'mw'],
    "yadṛcchalābhasaṃtuṣṭa": ['mw'],
    "yadṛcchamātratas": ['mw'],
    "yadṛcchasaṃvāda": ['mw'],
    "yadṛcchatas": ['mw'],
    "yadṛcchayā": ['mw'],
    "yadṛcchaśabda": ['mw'],
    "yadṛcchika": ['mw'],
    "yadṛcchikaḥ": ['ap90'],
    "yadṛcchā": ['ap90', 'ddsa', 'mw'],
    "yadṛcchābhijña": ['mw'],
    "yadṛcchālābha": ['cae'],
    "yadṛcchātas": ['ap90'],
    "yagghe": ['cped'],
    "yah": ['ddsa', 'gra'],
    "yahas": ['mw'],
    "yahaṁ": ['cped'],
    "yahiṁ": ['cped'],
    "yahu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yahva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yahvant": ['cae'],
    "yahvat": ['gra', 'mw'],
    "yahvā": ['mw'],
    "yahvī": ['gra', 'mw'],
    "yahūt": ['ddsa'],
    "yaiṣṭha": ['gra'],
    "yaj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yaja": ['mw'],
    "yajadhyai": ['cae', 'ddsa', 'mw'],
    "yajamāna": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "yajamānabhāga": ['mw'],
    "yajamānabrāhmaṇa": ['mw'],
    "yajamānacamasa": ['mw'],
    "yajamānadevatya": ['mw'],
    "yajamānahautrānukramaṇī": ['mw'],
    "yajamānahavis": ['mw'],
    "yajamānaka": ['mw'],
    "yajamānakaḥ": ['ap90'],
    "yajamānaloka": ['mw'],
    "yajamānamantrānukramaṇī": ['mw'],
    "yajamānaprayoga": ['mw'],
    "yajamānatva": ['mw'],
    "yajamānavaijayantī": ['mw'],
    "yajamānavākya": ['mw'],
    "yajamānaśiṣya": ['cae', 'mw'],
    "yajamānāyatana": ['mw'],
    "yajana": ['cae', 'cped', 'ddsa', 'mw'],
    "yajanaṃ": ['ap90'],
    "yajanta": ['mw'],
    "yajanādhyayana": ['mw'],
    "yajanīya": ['cae', 'mw'],
    "yajapraiṣa": ['mw'],
    "yajas": ['ap90', 'cae', 'gra', 'mw'],
    "yajata": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yajatha": ['ddsa', 'gra', 'mw'],
    "yajathāya": ['cae'],
    "yajati": ['cae', 'cped', 'ddsa', 'mw'],
    "yajatideśa": ['mw'],
    "yajatisthāna": ['mw'],
    "yajatiḥ": ['ap90'],
    "yajatra": ['cae', 'ddsa', 'gra', 'mw'],
    "yajatraḥ": ['ap90'],
    "yajaḥ": ['ap90'],
    "yaji": ['cae', 'cped', 'ddsa', 'mw'],
    "yajimat": ['mw'],
    "yajin": ['ap90', 'cae', 'mw'],
    "yajita": ['cped'],
    "yajitvā": ['cped'],
    "yajiḥ": ['ap90'],
    "yajiṣṇu": ['cae', 'mw'],
    "yajiṣṭha": ['cae', 'gra', 'mw'],
    "yajnāsāh": ['gra'],
    "yaju": ['mw'],
    "yajunā": ['mw'],
    "yajur": ['mw'],
    "yajurbrāhmaṇabhāṣya": ['mw'],
    "yajurgati": ['mw'],
    "yajurmaya": ['ddsa', 'mw'],
    "yajurmañjarī": ['mw'],
    "yajuruttama": ['mw'],
    "yajurvallabhā": ['mw'],
    "yajurveda": ['cae', 'mw'],
    "yajurvedabhāṣya": ['mw'],
    "yajurvedabrāhmaṇa": ['mw'],
    "yajurvedajaṭāvali": ['mw'],
    "yajurvedakriyāsvaralakṣaṇa": ['mw'],
    "yajurvedalakṣaṇa": ['mw'],
    "yajurvedamantrasaṃhitāsukhabodhana": ['mw'],
    "yajurvedamañjarī": ['mw'],
    "yajurvedapada": ['mw'],
    "yajurvedasaṃhitā": ['mw'],
    "yajurvedasaṃhitābrāhmaṇa": ['mw'],
    "yajurvedasaṃhitānukramaṇikā": ['mw'],
    "yajurvedasmārta": ['mw'],
    "yajurvedatrikāṇḍabhāṣya": ['mw'],
    "yajurvedaśrauta": ['mw'],
    "yajurvedaśrāddha": ['mw'],
    "yajurvedaśākhā": ['mw'],
    "yajurvedin": ['mw'],
    "yajurvedivṛṣotsargatattva": ['mw'],
    "yajurvediśrāddhatattva": ['mw'],
    "yajurvedopaniṣad": ['mw'],
    "yajurvedāraṇyaka": ['mw'],
    "yajurvedārṇava": ['mw'],
    "yajurvedāśīrvāda": ['mw'],
    "yajurvedīya": ['mw'],
    "yajurvedīyadakṣiṇadvāra": ['mw'],
    "yajurvid": ['cae', 'mw'],
    "yajurvidhāna": ['mw'],
    "yajurvivāhapaddhati": ['mw'],
    "yajurvāṇīmantra": ['mw'],
    "yajuryukta": ['mw'],
    "yajurāraṇyaka": ['mw'],
    "yajus": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yajussāt": ['mw'],
    "yajuḥ": ['mw'],
    "yajuḥsaṃdhyā": ['mw'],
    "yajuḥsvāmin": ['ddsa', 'mw'],
    "yajuḥśrāddha": ['mw'],
    "yajuḥśākhin": ['mw'],
    "yajuṣ": ['mw'],
    "yajuṣa": ['mw'],
    "yajuṣka": ['mw'],
    "yajuṣkalpa": ['mw'],
    "yajuṣkriyā": ['mw'],
    "yajuṣkāmya": ['mw'],
    "yajuṣkṛta": ['mw'],
    "yajuṣkṛti": ['mw'],
    "yajuṣmant": ['cae'],
    "yajuṣmat": ['ddsa', 'mw'],
    "yajuṣpati": ['mw'],
    "yajuṣpriya": ['mw'],
    "yajuṣpātra": ['mw'],
    "yajuṣya": ['cae', 'mw'],
    "yajuṣṭama": ['mw'],
    "yajuṣṭara": ['mw'],
    "yajuṣṭas": ['cae', 'mw'],
    "yajuṣṭva": ['mw'],
    "yajuṣṭā": ['mw'],
    "yajvan": ['ap90', 'cae', 'gra', 'mw'],
    "yajvin": ['mw'],
    "yajya": ['ap90', 'gra', 'mw'],
    "yajyu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yajña": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "yajñabandhu": ['gra', 'mw'],
    "yajñabhairava": ['mw'],
    "yajñabhoktṛ": ['mw'],
    "yajñabhuj": ['mw'],
    "yajñabhāga": ['cae', 'mw'],
    "yajñabhāgabhuj": ['mw'],
    "yajñabhāgeśvara": ['cae', 'mw'],
    "yajñabhājana": ['mw'],
    "yajñabhāvana": ['mw'],
    "yajñabhāvita": ['mw'],
    "yajñabhāṇḍa": ['mw'],
    "yajñabhūmi": ['cae', 'mw'],
    "yajñabhūṣaṇa": ['mw'],
    "yajñabhṛt": ['cae', 'mw'],
    "yajñabāhu": ['mw'],
    "yajñacchāga": ['cae', 'mw'],
    "yajñadakṣiṇā": ['mw'],
    "yajñadatta": ['bhs', 'cae', 'mw'],
    "yajñadattaka": ['mw'],
    "yajñadattavadha": ['mw'],
    "yajñadattaśarman": ['mw'],
    "yajñadattā": ['mw'],
    "yajñadattīya": ['mw'],
    "yajñadeva": ['mw'],
    "yajñadhara": ['mw'],
    "yajñadhīra": ['cae', 'gra', 'mw'],
    "yajñadravya": ['mw'],
    "yajñadruh": ['mw'],
    "yajñadugdha": ['mw'],
    "yajñadāsī": ['mw'],
    "yajñadīkṣita": ['mw'],
    "yajñadīkṣā": ['cae', 'mw'],
    "yajñadṛś": ['mw'],
    "yajñagamya": ['mw'],
    "yajñaghna": ['mw'],
    "yajñaghoṣa": ['mw'],
    "yajñagiri": ['mw'],
    "yajñaguhya": ['mw'],
    "yajñagāthā": ['mw'],
    "yajñahan": ['cae', 'mw'],
    "yajñahana": ['mw'],
    "yajñahartṛ": ['mw'],
    "yajñahotṛ": ['cae', 'gra', 'mw'],
    "yajñahut": ['cae', 'mw'],
    "yajñahṛdaya": ['mw'],
    "yajñajña": ['mw'],
    "yajñajāgara": ['mw'],
    "yajñaka": ['mw'],
    "yajñakalpa": ['mw'],
    "yajñakarman": ['cae', 'ddsa', 'mw'],
    "yajñakarmārha": ['mw'],
    "yajñaketu": ['gra', 'mw'],
    "yajñakopa": ['mw'],
    "yajñakoṭigupta": ['bhs'],
    "yajñakratu": ['cae', 'mw'],
    "yajñakriyā": ['cae', 'mw'],
    "yajñakuṇapī": ['mw'],
    "yajñakuṇḍa": ['mw'],
    "yajñakuṇḍacakra": ['mw'],
    "yajñakā": ['mw'],
    "yajñakāla": ['mw'],
    "yajñakāma": ['cae', 'gra', 'mw'],
    "yajñakāra": ['mw'],
    "yajñakīlaka": ['mw'],
    "yajñakṛntatra": ['mw'],
    "yajñakṛt": ['cae', 'mw'],
    "yajñalih": ['mw'],
    "yajñaliṅga": ['mw'],
    "yajñalopa": ['mw'],
    "yajñamahotsava": ['mw'],
    "yajñamanas": ['mw'],
    "yajñamanman": ['cae', 'gra', 'mw'],
    "yajñamaya": ['mw'],
    "yajñamañjūṣā": ['mw'],
    "yajñamaṇḍala": ['mw'],
    "yajñameni": ['mw'],
    "yajñamuh": ['mw'],
    "yajñamukha": ['cae', 'mw'],
    "yajñamuṣ": ['cae', 'mw'],
    "yajñamāli": ['mw'],
    "yajñamūrti": ['mw'],
    "yajñanemi": ['mw'],
    "yajñanidhana": ['mw'],
    "yajñaniṣkṛt": ['gra', 'mw'],
    "yajñanārāyaṇa": ['mw'],
    "yajñanī": ['cae', 'gra', 'mw'],
    "yajñapadī": ['mw'],
    "yajñaparibhāṣā": ['mw'],
    "yajñaparibhāṣāsūtra": ['mw'],
    "yajñaparus": ['mw'],
    "yajñapatha": ['mw'],
    "yajñapati": ['cae', 'gra', 'mw'],
    "yajñapatnī": ['mw'],
    "yajñapatnītva": ['mw'],
    "yajñapaśu": ['cae', 'mw'],
    "yajñapaśumīmāṃsā": ['mw'],
    "yajñaphalada": ['mw'],
    "yajñaprayāṇa": ['mw'],
    "yajñapriya": ['cae', 'mw'],
    "yajñaprāpya": ['mw'],
    "yajñaprāyaścittasūtra": ['mw'],
    "yajñaprāyaścittavivaraṇa": ['mw'],
    "yajñaprī": ['cae', 'gra', 'mw'],
    "yajñapuccha": ['mw'],
    "yajñapuraścaraṇa": ['mw'],
    "yajñapuruṣa": ['mw'],
    "yajñapuruṣavājapeyayājikārikā": ['mw'],
    "yajñapuruṣāsammita": ['mw'],
    "yajñapuṃs": ['mw'],
    "yajñapārśva": ['mw'],
    "yajñapātra": ['cae', 'mw'],
    "yajñapātrakārikā": ['mw'],
    "yajñapātralakṣaṇa": ['mw'],
    "yajñapātrīya": ['mw'],
    "yajñarasa": ['mw'],
    "yajñaretas": ['mw'],
    "yajñarta": ['mw'],
    "yajñaruci": ['mw'],
    "yajñarāj": ['mw'],
    "yajñarūpa": ['mw'],
    "yajñarūpadhṛk": ['mw'],
    "yajñasac": ['mw'],
    "yajñasadana": ['cae', 'mw'],
    "yajñasadas": ['cae', 'mw'],
    "yajñasammita": ['mw'],
    "yajñasamṛddhi": ['mw'],
    "yajñasaṃsiddhi": ['mw'],
    "yajñasaṃstara": ['mw'],
    "yajñasaṃsthā": ['cae', 'mw'],
    "yajñasaṃśita": ['mw'],
    "yajñasena": ['cae', 'mw'],
    "yajñasiddhi": ['mw'],
    "yajñasiddhāntasaṃgraha": ['mw'],
    "yajñasiddhāntavigraha": ['mw'],
    "yajñasoma": ['mw'],
    "yajñastha": ['mw'],
    "yajñasthala": ['mw'],
    "yajñasthāna": ['mw'],
    "yajñasthāṇu": ['mw'],
    "yajñasvāmin": ['mw'],
    "yajñasāc": ['gra'],
    "yajñasādh": ['cae', 'gra', 'mw'],
    "yajñasādhana": ['cae', 'gra', 'mw'],
    "yajñasāra": ['mw'],
    "yajñasārathi": ['mw'],
    "yajñasūkara": ['mw'],
    "yajñasūtra": ['cae', 'mw'],
    "yajñasūtravidhāna": ['mw'],
    "yajñatantra": ['mw'],
    "yajñatantrasudhānidhi": ['mw'],
    "yajñatantrasūtra": ['mw'],
    "yajñatanū": ['mw'],
    "yajñatati": ['mw'],
    "yajñatrātṛ": ['mw'],
    "yajñaturaṃga": ['cae', 'mw'],
    "yajñatyāgin": ['mw'],
    "yajñatā": ['mw'],
    "yajñavacas": ['mw'],
    "yajñavaha": ['mw'],
    "yajñavaibhavakhaṇḍa": ['mw'],
    "yajñavalka": ['cae', 'mw'],
    "yajñavallī": ['mw'],
    "yajñavanas": ['cae', 'gra', 'mw'],
    "yajñavant": ['cae'],
    "yajñavardhana": ['cae', 'mw'],
    "yajñavarman": ['mw'],
    "yajñavarāha": ['mw'],
    "yajñavat": ['gra', 'mw'],
    "yajñavedi": ['mw'],
    "yajñavedī": ['mw'],
    "yajñaveśasa": ['mw'],
    "yajñavibhraṃśa": ['mw'],
    "yajñavibhraṣṭa": ['mw'],
    "yajñavibhraṣṭatva": ['mw'],
    "yajñavid": ['cae', 'mw'],
    "yajñavidyā": ['cae', 'mw'],
    "yajñavoḍhave": ['mw'],
    "yajñavrata": ['mw'],
    "yajñavāha": ['cae', 'mw'],
    "yajñavāhana": ['cae', 'mw'],
    "yajñavāhas": ['cae', 'gra', 'mw'],
    "yajñavāhin": ['mw'],
    "yajñavāma": ['mw'],
    "yajñavāstu": ['mw'],
    "yajñavāṭa": ['cae', 'mw'],
    "yajñavīrya": ['mw'],
    "yajñavṛddha": ['cae', 'gra', 'mw'],
    "yajñavṛdh": ['cae', 'mw'],
    "yajñavṛkṣa": ['mw'],
    "yajñayaśasa": ['mw'],
    "yajñayoga": ['mw'],
    "yajñayogya": ['mw'],
    "yajñaśamala": ['mw'],
    "yajñaśaraṇa": ['cae', 'mw'],
    "yajñaśatru": ['mw'],
    "yajñaśeṣa": ['cae', 'mw'],
    "yajñaśiṣṭa": ['cae', 'mw'],
    "yajñaśiṣṭāśana": ['mw'],
    "yajñaśreṣṭha": ['cae', 'mw'],
    "yajñaśreṣṭhā": ['mw'],
    "yajñaśrī": ['cae', 'gra', 'mw'],
    "yajñaśālā": ['cae', 'mw'],
    "yajñaśāstra": ['cae', 'mw'],
    "yajñaśāstravid": ['mw'],
    "yajñaśīla": ['cae', 'mw'],
    "yajñaḥ": ['ap90'],
    "yajñeśa": ['cae', 'ddsa', 'mw'],
    "yajñeśvara": ['cae', 'mw'],
    "yajñeśvarī": ['mw'],
    "yajñeśvarīvidyāmahātmya": ['mw'],
    "yajñeṣu": ['mw'],
    "yajñeṣṭa": ['mw'],
    "yajñika": ['mw'],
    "yajñikaḥ": ['ap90'],
    "yajñin": ['ap90', 'cae', 'mw'],
    "yajñiya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yajñiyadeśa": ['mw'],
    "yajñiyat": ['mw'],
    "yajñiyaśālā": ['mw'],
    "yajñodumbara": ['mw'],
    "yajñopakaraṇa": ['mw'],
    "yajñopavīta": ['cae', 'mw'],
    "yajñopavītadhāraṇamantra": ['mw'],
    "yajñopavītadāna": ['mw'],
    "yajñopavītaka": ['mw'],
    "yajñopavītamantra": ['mw'],
    "yajñopavītanirmāṇapaddhati": ['mw'],
    "yajñopavītanāśaprāyaścittaprayoga": ['mw'],
    "yajñopavītapaddhati": ['mw'],
    "yajñopavītapratiṣṭhā": ['mw'],
    "yajñopavītapratiṣṭhāsañcikā": ['mw'],
    "yajñopavītavat": ['mw'],
    "yajñopavītavidhi": ['mw'],
    "yajñopavītin": ['cae', 'mw'],
    "yajñopeta": ['mw'],
    "yajñopāsaka": ['mw'],
    "yajñotsava": ['ddsa', 'mw'],
    "yajñotsavavat": ['mw'],
    "yajñāgni": ['mw'],
    "yajñāgāra": ['mw'],
    "yajñānta": ['mw'],
    "yajñāntakṛt": ['mw'],
    "yajñānukāśin": ['mw'],
    "yajñāpeta": ['mw'],
    "yajñāraṅgeśapurī": ['mw'],
    "yajñāraṇya": ['mw'],
    "yajñārha": ['mw'],
    "yajñāri": ['mw'],
    "yajñārtham": ['cae'],
    "yajñārādhya": ['mw'],
    "yajñāsah": ['gra', 'mw'],
    "yajñātman": ['mw'],
    "yajñātīta": ['mw'],
    "yajñāvacara": ['mw'],
    "yajñāvakīrṇa": ['mw'],
    "yajñāvasāna": ['mw'],
    "yajñāvayava": ['mw'],
    "yajñāvṛtti": ['mw'],
    "yajñāy": ['gra'],
    "yajñāya": ['mw'],
    "yajñāyajñiya": ['mw'],
    "yajñāyatana": ['cae', 'mw'],
    "yajñāyudha": ['cae', 'mw'],
    "yajñāyudhin": ['mw'],
    "yajñāyus": ['mw'],
    "yajñāśana": ['mw'],
    "yajñāḍhya": ['mw'],
    "yajñāṃśabhuj": ['ddsa', 'mw'],
    "yajñāṅga": ['cae', 'mw'],
    "yajñāṅgā": ['mw'],
    "yajñīya": ['ap90', 'cae', 'mw'],
    "yajā": ['cae', 'ddsa', 'mw'],
    "yajāka": ['ap90', 'mw'],
    "yajīyas": ['gra', 'mw'],
    "yajīyaṃs": ['cae'],
    "yajūdara": ['mw'],
    "yaka": ['cae', 'ddsa', 'gra', 'mw'],
    "yakan": ['ap90', 'cae', 'ddsa', 'mw'],
    "yakana": ['cped'],
    "yakkha": ['cped'],
    "yakkhabhūta": ['cped'],
    "yakkhagaṇa": ['cped'],
    "yakkhagāha": ['cped'],
    "yakkhasamāgama": ['cped'],
    "yakkhatta": ['cped'],
    "yakkhinī": ['cped'],
    "yakkhādhipa": ['cped'],
    "yakkhī": ['cped'],
    "yakāra": ['cae', 'ddsa', 'mw'],
    "yakārādipada": ['mw'],
    "yakṛd": ['mw'],
    "yakṛdarilauha": ['mw'],
    "yakṛddālya": ['mw'],
    "yakṛddālyudara": ['mw'],
    "yakṛdudara": ['mw'],
    "yakṛdvairin": ['mw'],
    "yakṛdvarṇa": ['cae', 'mw'],
    "yakṛdātmikā": ['mw'],
    "yakṛl": ['mw'],
    "yakṛlloma": ['mw'],
    "yakṛlloman": ['mw'],
    "yakṛn": ['mw'],
    "yakṛnmedas": ['mw'],
    "yakṛt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yakṛtkośa": ['mw'],
    "yakṛttas": ['mw'],
    "yakṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yakṣa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "yakṣabali": ['mw'],
    "yakṣabhavana": ['mw'],
    "yakṣabhṛt": ['gra', 'mw'],
    "yakṣadara": ['mw'],
    "yakṣadattā": ['mw'],
    "yakṣadevagṛha": ['mw'],
    "yakṣadhūpa": ['cae', 'mw'],
    "yakṣadigvijaya": ['mw'],
    "yakṣadāsī": ['mw'],
    "yakṣadṛś": ['cae', 'gra', 'mw'],
    "yakṣagraha": ['mw'],
    "yakṣagrahaparipīḍita": ['mw'],
    "yakṣaka": ['mw'],
    "yakṣakardama": ['cae', 'mw'],
    "yakṣakūpa": ['mw'],
    "yakṣalipi": ['bhs'],
    "yakṣamalla": ['mw'],
    "yakṣan": ['mw'],
    "yakṣanāyaka": ['mw'],
    "yakṣapati": ['cae', 'mw'],
    "yakṣapraśna": ['mw'],
    "yakṣapāla": ['mw'],
    "yakṣarasa": ['mw'],
    "yakṣarāj": ['cae', 'mw'],
    "yakṣarāja": ['cae', 'mw'],
    "yakṣarātri": ['mw'],
    "yakṣarāṭpurī": ['mw'],
    "yakṣasena": ['mw'],
    "yakṣasthala": ['mw'],
    "yakṣataru": ['mw'],
    "yakṣatva": ['mw'],
    "yakṣatā": ['mw'],
    "yakṣavarman": ['mw'],
    "yakṣavitta": ['mw'],
    "yakṣaḥ": ['ap90'],
    "yakṣaṇa": ['mw'],
    "yakṣaṇī": ['bhs'],
    "yakṣendra": ['cae', 'ddsa', 'mw'],
    "yakṣeś": ['mw'],
    "yakṣeśa": ['mw'],
    "yakṣeśvara": ['cae', 'mw'],
    "yakṣeśvaramedhīya": ['mw'],
    "yakṣia": ['gra'],
    "yakṣin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yakṣiṇī": ['ap90', 'mw'],
    "yakṣiṇīkavaca": ['mw'],
    "yakṣiṇīmantra": ['mw'],
    "yakṣiṇīpaṭala": ['mw'],
    "yakṣiṇīsādhana": ['mw'],
    "yakṣiṇītantra": ['mw'],
    "yakṣiṇītva": ['mw'],
    "yakṣiṇīvetālasādhana": ['mw'],
    "yakṣma": ['cae', 'ddsa', 'gra', 'mw'],
    "yakṣmaghnī": ['mw'],
    "yakṣmagraha": ['mw'],
    "yakṣmagrasta": ['mw'],
    "yakṣmagṛhīta": ['mw'],
    "yakṣman": ['cae', 'ddsa', 'mw'],
    "yakṣmanāśana": ['mw'],
    "yakṣmaḥ": ['ap90'],
    "yakṣmin": ['ap90', 'cae', 'mw'],
    "yakṣmodhā": ['mw'],
    "yakṣodumbaraka": ['mw'],
    "yakṣu": ['cae', 'gra', 'mw'],
    "yakṣya": ['cae', 'ddsa', 'gra', 'mw'],
    "yakṣyamāṇa": ['ddsa'],
    "yakṣā": ['mw'],
    "yakṣādhipa": ['cae', 'mw'],
    "yakṣādhipati": ['cae', 'mw'],
    "yakṣāmalaka": ['mw'],
    "yakṣāvāsa": ['mw'],
    "yakṣāyatana": ['mw'],
    "yakṣāṅganā": ['mw'],
    "yakṣāṅgī": ['mw'],
    "yakṣī": ['mw'],
    "yakṣītva": ['mw'],
    "yalla": ['mw'],
    "yallabhaṭṭasuta": ['mw'],
    "yallabhaṭṭīya": ['mw'],
    "yallaya": ['mw'],
    "yallayārya": ['mw'],
    "yallāji": ['mw'],
    "yallājīya": ['mw'],
    "yam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yama": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yamabhaginī": ['mw'],
    "yamabhaṭa": ['mw'],
    "yamadagni": ['mw'],
    "yamadaivata": ['mw'],
    "yamadaṃṣṭra": ['mw'],
    "yamadaṃṣṭrā": ['mw'],
    "yamadaṇḍa": ['cae', 'mw'],
    "yamadaṇḍika": ['bhs'],
    "yamadevata": ['mw'],
    "yamadevatya": ['mw'],
    "yamadharmanirbhayastotra": ['mw'],
    "yamadhānī": ['cae', 'mw'],
    "yamadhāra": ['mw'],
    "yamadiś": ['mw'],
    "yamadruma": ['mw'],
    "yamadvitīyā": ['mw'],
    "yamadvitīyāvrata": ['mw'],
    "yamadvīpa": ['mw'],
    "yamadūta": ['cae', 'cped', 'mw'],
    "yamadūtaka": ['mw'],
    "yamadūtikā": ['mw'],
    "yamadūtī": ['bhs', 'mw'],
    "yamaghaṇṭa": ['mw'],
    "yamaghna": ['mw'],
    "yamagāthā": ['cae', 'mw'],
    "yamagītā": ['mw'],
    "yamagṛha": ['mw'],
    "yamahārdikā": ['mw'],
    "yamahāseśvaratīrtha": ['mw'],
    "yamaja": ['cae', 'mw'],
    "yamajihvā": ['mw'],
    "yamajit": ['mw'],
    "yamajāta": ['cae', 'mw'],
    "yamajātaka": ['cae', 'mw'],
    "yamaka": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "yamakabhārata": ['mw'],
    "yamakakāvya": ['mw'],
    "yamakaratnākara": ['mw'],
    "yamakasāla": ['cped'],
    "yamakatva": ['mw'],
    "yamakaśikhāmaṇi": ['mw'],
    "yamakaśāla": ['bhs'],
    "yamakaśālavana": ['mw'],
    "yamaketu": ['mw'],
    "yamakiṃkara": ['cae', 'mw'],
    "yamakoṭi": ['mw'],
    "yamakoṭipattana": ['mw'],
    "yamakoṭipurī": ['mw'],
    "yamakoṭī": ['mw'],
    "yamakālindī": ['mw'],
    "yamakārṇava": ['mw'],
    "yamakāvalī": ['mw'],
    "yamakāṣṭaka": ['mw'],
    "yamakīla": ['mw'],
    "yamakīṭa": ['mw'],
    "yamakṣaya": ['cae', 'mw'],
    "yamala": ['ap90', 'cae', 'ddsa', 'mw'],
    "yamalacchada": ['mw'],
    "yamalajananaśānti": ['mw'],
    "yamalaka": ['bhs', 'mw'],
    "yamalapattraka": ['mw'],
    "yamalasū": ['mw'],
    "yamalaśānti": ['mw'],
    "yamalita": ['bhs'],
    "yamalodbhava": ['mw'],
    "yamaloka": ['cae', 'cped', 'mw'],
    "yamalokika": ['bhs'],
    "yamalā": ['mw'],
    "yamalārjuna": ['mw'],
    "yamalārjunabhañjana": ['mw'],
    "yamalārjunahan": ['mw'],
    "yamalārjunaka": ['mw'],
    "yamalārjunakabhañjana": ['mw'],
    "yamalārjunakahan": ['mw'],
    "yamalī": ['bhs'],
    "yamamandira": ['mw'],
    "yamamathanī": ['bhs'],
    "yamamārga": ['mw'],
    "yamamārgagamana": ['mw'],
    "yamana": ['ap90', 'cae', 'ddsa', 'mw'],
    "yamanagarātithi": ['mw'],
    "yamanakṣatra": ['mw'],
    "yamanetra": ['cae', 'mw'],
    "yamanikā": ['ap90'],
    "yamanvā": ['mw'],
    "yamapada": ['mw'],
    "yamapaṭa": ['ddsa', 'mw'],
    "yamapaṭika": ['mw'],
    "yamaprasthapura": ['mw'],
    "yamapriya": ['mw'],
    "yamapura": ['mw'],
    "yamapurisa": ['cped'],
    "yamapuruṣa": ['cae', 'mw'],
    "yamapurāṇa": ['mw'],
    "yamapālaka": ['mw'],
    "yamapālapuruṣa": ['mw'],
    "yamapāśa": ['mw'],
    "yamaratha": ['mw'],
    "yamarkṣa": ['mw'],
    "yamarāj": ['mw'],
    "yamarāja": ['cped', 'mw'],
    "yamarājan": ['cae', 'gra', 'mw'],
    "yamarājya": ['cae', 'mw'],
    "yamarāṣṭra": ['cae', 'mw'],
    "yamasabha": ['mw'],
    "yamasabhā": ['mw'],
    "yamasabhīya": ['mw'],
    "yamasadana": ['cae', 'mw'],
    "yamasattvavat": ['mw'],
    "yamasaṃhitā": ['mw'],
    "yamasmṛti": ['mw'],
    "yamastoma": ['mw'],
    "yamastotra": ['mw'],
    "yamasvasṛ": ['mw'],
    "yamasādana": ['cae', 'mw'],
    "yamasāna": ['mw'],
    "yamasāt": ['ap90', 'mw'],
    "yamasū": ['cae', 'gra', 'mw'],
    "yamasūkta": ['mw'],
    "yamasūrya": ['mw'],
    "yamatarpaṇa": ['mw'],
    "yamatva": ['mw'],
    "yamatā": ['mw'],
    "yamatīrtha": ['mw'],
    "yamavant": ['cae'],
    "yamavat": ['ap90', 'mw'],
    "yamavatsā": ['mw'],
    "yamaviṣaya": ['cae', 'mw'],
    "yamavrata": ['mw'],
    "yamavāhana": ['mw'],
    "yamayajña": ['mw'],
    "yamayiṣṇu": ['mw'],
    "yamayā": ['mw'],
    "yamayāga": ['mw'],
    "yamayātanā": ['mw'],
    "yamaśikha": ['mw'],
    "yamaśreṣṭha": ['cae', 'mw'],
    "yamaśrāya": ['mw'],
    "yamaśva": ['cae', 'mw'],
    "yamaśānti": ['mw'],
    "yambhaka": ['bhs'],
    "yamerukā": ['mw'],
    "yameśa": ['mw'],
    "yameśvara": ['mw'],
    "yameṣṭa": ['cae', 'mw'],
    "yamia": ['gra'],
    "yamika": ['mw'],
    "yamikā": ['mw'],
    "yamin": ['ap90', 'cae', 'ddsa', 'mw'],
    "yaminī": ['cae', 'mw'],
    "yamita": ['ap90', 'mw'],
    "yamitrī": ['mw'],
    "yamiṣṭha": ['cae', 'gra', 'mw'],
    "yamunda": ['mw'],
    "yamunā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yamunābhid": ['mw'],
    "yamunābhrātṛ": ['mw'],
    "yamunābhāj": ['mw'],
    "yamunācārya": ['mw'],
    "yamunādatta": ['mw'],
    "yamunādvīpa": ['mw'],
    "yamunājanaka": ['mw'],
    "yamunāmāhātmya": ['mw'],
    "yamunāpati": ['mw'],
    "yamunāprabhava": ['mw'],
    "yamunāpūjā": ['mw'],
    "yamunāstotra": ['mw'],
    "yamunātīrtha": ['mw'],
    "yamunātīrthamāhātmya": ['mw'],
    "yamunāvarṇana": ['mw'],
    "yamunāṣṭaka": ['mw'],
    "yamunāṣṭakaṭīkā": ['mw'],
    "yamunāṣṭapadī": ['mw'],
    "yamuṣadeva": ['ddsa', 'mw'],
    "yamya": ['gra', 'mw'],
    "yamyā": ['mw'],
    "yamādarśanatrayodaśī": ['mw'],
    "yamādarśanatrayodaśīvrata": ['mw'],
    "yamāditya": ['mw'],
    "yamālaya": ['mw'],
    "yamānikā": ['mw'],
    "yamānta": ['bhs'],
    "yamāntaka": ['bhs', 'mw'],
    "yamāntikā": ['mw'],
    "yamānucara": ['mw'],
    "yamānuga": ['ddsa', 'mw'],
    "yamānī": ['mw'],
    "yamāri": ['bhs', 'ddsa', 'mw'],
    "yamātirātra": ['mw'],
    "yamāya": ['ddsa', 'mw'],
    "yamāṅgikā": ['mw'],
    "yamī": ['ddsa', 'gra', 'mw'],
    "yan": ['bhs', 'mw'],
    "yanmadhye": ['mw'],
    "yanmaya": ['ddsa', 'mw'],
    "yanmaṃhiṣṭhīya": ['mw'],
    "yanmātra": ['mw'],
    "yanmūla": ['mw'],
    "yanmūrdhan": ['mw'],
    "yannimitta": ['cae', 'mw'],
    "yannimittam": ['mw'],
    "yannāman": ['ddsa', 'mw'],
    "yanta": ['cped'],
    "yantamutta": ['cped'],
    "yantanāḷi": ['cped'],
    "yantave": ['ddsa', 'mw'],
    "yantavya": ['cae', 'mw'],
    "yantayutta": ['cped'],
    "yanti": ['mw'],
    "yantika": ['cped'],
    "yantr": ['mw'],
    "yantra": ['cae', 'ddsa', 'gra', 'mw'],
    "yantracchedya": ['mw'],
    "yantraceṣṭita": ['mw'],
    "yantracintāmaṇi": ['mw'],
    "yantradhārāgṛha": ['cae', 'mw'],
    "yantradhārāgṛhatva": ['mw'],
    "yantradṛḍha": ['cae', 'mw'],
    "yantragaruḍa": ['mw'],
    "yantragola": ['mw'],
    "yantragṛha": ['mw'],
    "yantrahastin": ['mw'],
    "yantrahaṃsa": ['mw'],
    "yantraka": ['ddsa', 'mw'],
    "yantrakalā": ['bhs'],
    "yantrakaraṇḍikā": ['mw'],
    "yantrakarmakṛt": ['mw'],
    "yantrakarman": ['mw'],
    "yantramaya": ['mw'],
    "yantramayūraka": ['mw'],
    "yantramoha": ['mw'],
    "yantramukta": ['mw'],
    "yantramālikāṭīkā": ['mw'],
    "yantramārga": ['mw'],
    "yantramātṛkā": ['mw'],
    "yantramāṣṭa": ['bhs'],
    "yantranāla": ['mw'],
    "yantrapattra": ['mw'],
    "yantrapeṣaṇī": ['mw'],
    "yantraprakāśa": ['mw'],
    "yantrapratiṣṭhā": ['mw'],
    "yantrapravāha": ['mw'],
    "yantraputraka": ['mw'],
    "yantraputrikā": ['mw'],
    "yantrapīḍā": ['mw'],
    "yantrapūjanaprakāra": ['mw'],
    "yantrapūta": ['mw'],
    "yantrarahasya": ['mw'],
    "yantraratnāvalī": ['mw'],
    "yantrarāja": ['mw'],
    "yantrarājaghaṭanā": ['mw'],
    "yantrarājapaddhati": ['mw'],
    "yantrarājaracanā": ['mw'],
    "yantrarājaracanāprakāra": ['mw'],
    "yantrarājavyākhyāna": ['mw'],
    "yantrarājāgama": ['mw'],
    "yantrasadman": ['mw'],
    "yantrasaṃgraha": ['mw'],
    "yantrasāra": ['mw'],
    "yantrasūtra": ['mw'],
    "yantratakṣan": ['ddsa', 'mw'],
    "yantratoraṇa": ['mw'],
    "yantravat": ['ddsa', 'mw'],
    "yantravedhavicāra": ['mw'],
    "yantravidhi": ['mw'],
    "yantravimāna": ['mw'],
    "yantray": ['cae'],
    "yantraya": ['ddsa', 'mw'],
    "yantrayukta": ['mw'],
    "yantraśara": ['mw'],
    "yantraṇa": ['cae', 'ddsa', 'mw'],
    "yantraṇī": ['mw'],
    "yantreṇa": ['mw'],
    "yantrin": ['cae', 'ddsa', 'mw'],
    "yantrita": ['bhs', 'mw'],
    "yantritakatha": ['mw'],
    "yantritasāyaka": ['mw'],
    "yantriṇī": ['mw'],
    "yantroddhāra": ['mw'],
    "yantroddhāravidhi": ['mw'],
    "yantropala": ['ddsa', 'mw'],
    "yantrotkṣiptopala": ['mw'],
    "yantrādhyāyavivṛti": ['mw'],
    "yantrākāra": ['mw'],
    "yantrālaya": ['mw'],
    "yantrāpīḍa": ['mw'],
    "yantrārūḍha": ['cae', 'mw'],
    "yantrāvalī": ['mw'],
    "yantu": ['mw'],
    "yantur": ['gra', 'mw'],
    "yantṛ": ['cae', 'gra', 'mw'],
    "yarhi": ['ap90', 'cae', 'ddsa', 'mw'],
    "yarādevīrahasya": ['mw'],
    "yas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yasadāyaka": ['cped'],
    "yasagga": ['cped'],
    "yasalābha": ['cped'],
    "yasamahatta": ['cped'],
    "yaska": ['ddsa', 'mw'],
    "yasmāt": ['cae', 'ddsa', 'mw'],
    "yaso": ['cped'],
    "yasodhara": ['cped'],
    "yasoladdha": ['cped'],
    "yasta": ['mw'],
    "yasya": ['mw'],
    "yasyatva": ['mw'],
    "yat": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yata": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yatacetas": ['cae', 'mw'],
    "yatacittendriyānala": ['mw'],
    "yatacittātman": ['cae', 'mw'],
    "yatagir": ['mw'],
    "yatakṛt": ['mw'],
    "yatama": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yatamaithuna": ['mw'],
    "yatamanyu": ['mw'],
    "yatamathā": ['cae', 'mw'],
    "yatamānasa": ['mw'],
    "yatana": ['cped', 'mw'],
    "yatanaṃ": ['ap90'],
    "yatanīya": ['cae', 'ddsa', 'mw'],
    "yatara": ['ap90', 'cae', 'gra', 'mw'],
    "yatarathā": ['cae', 'mw'],
    "yataratra": ['mw'],
    "yataraśmi": ['gra', 'mw'],
    "yatas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yatasruc": ['cae', 'ddsa', 'gra', 'mw'],
    "yatati": ['cped'],
    "yatavrata": ['cae', 'mw'],
    "yatavya": ['mw'],
    "yatavāc": ['ddsa', 'mw'],
    "yatavāktva": ['mw'],
    "yataṃkara": ['gra', 'mw'],
    "yatendriya": ['mw'],
    "yatha": ['mw'],
    "yathaikadivasam": ['mw'],
    "yathaitam": ['mw'],
    "yathaladdha": ['cped'],
    "yatharcam": ['ddsa', 'mw'],
    "yathariva": ['bhs', 'cped'],
    "yathartu": ['mw'],
    "yathartuka": ['mw'],
    "yathartupuṣpita": ['mw'],
    "yathar̥ṣi": ['ddsa'],
    "yatharṣi": ['mw'],
    "yatharṣyādhāna": ['mw'],
    "yathaucityam": ['mw'],
    "yathaucityāt": ['mw'],
    "yathaukasam": ['mw'],
    "yathaṛṣi": ['mw'],
    "yatheccha": ['cae', 'mw'],
    "yathecchakam": ['mw'],
    "yatheccham": ['mw'],
    "yathecchayā": ['mw'],
    "yathekṣitam": ['ddsa', 'mw'],
    "yathepsayā": ['cae', 'mw'],
    "yathepsita": ['cae', 'mw'],
    "yathepsitam": ['mw'],
    "yathetam": ['mw'],
    "yatheṣṭa": ['cae', 'ddsa', 'mw'],
    "yatheṣṭacārin": ['mw'],
    "yatheṣṭagati": ['mw'],
    "yatheṣṭam": ['mw'],
    "yatheṣṭasaṃcārin": ['cae', 'mw'],
    "yatheṣṭatas": ['mw'],
    "yatheṣṭatva": ['mw'],
    "yatheṣṭi": ['mw'],
    "yatheṣṭācaraṇa": ['cae'],
    "yatheṣṭācāra": ['mw'],
    "yatheṣṭāsana": ['mw'],
    "yathicchitaṁ": ['cped'],
    "yathocchritam": ['mw'],
    "yathocita": ['cae', 'mw'],
    "yathocitam": ['mw'],
    "yathodaya": ['mw'],
    "yathodayam": ['mw'],
    "yathodbhavam": ['mw'],
    "yathoddeśam": ['mw'],
    "yathoddiṣṭa": ['cae', 'mw'],
    "yathoddiṣṭam": ['mw'],
    "yathodgamana": ['mw'],
    "yathodgata": ['mw'],
    "yathodita": ['cae', 'mw'],
    "yathoditam": ['mw'],
    "yathojjitam": ['mw'],
    "yathokta": ['cae', 'ddsa', 'mw'],
    "yathoktakārin": ['cae'],
    "yathoktam": ['mw'],
    "yathoktavādin": ['mw'],
    "yathoktena": ['mw'],
    "yathopacāram": ['mw'],
    "yathopadeśam": ['mw'],
    "yathopadiṣṭa": ['mw'],
    "yathopadiṣṭam": ['mw'],
    "yathopajoṣam": ['mw'],
    "yathopakam": ['bhs'],
    "yathopakīrṇam": ['mw'],
    "yathopalambham": ['mw'],
    "yathopamuktam": ['mw'],
    "yathopamā": ['mw'],
    "yathopapadam": ['mw'],
    "yathopapanna": ['mw'],
    "yathopapatti": ['cae', 'mw'],
    "yathopapādam": ['mw'],
    "yathopapādin": ['mw'],
    "yathopapātam": ['mw'],
    "yathopasmāram": ['mw'],
    "yathopasthitam": ['mw'],
    "yathopayoga": ['mw'],
    "yathopta": ['cae', 'mw'],
    "yathopādhi": ['mw'],
    "yathotpatti": ['mw'],
    "yathotsāha": ['mw'],
    "yathotsāham": ['cae', 'mw'],
    "yathottara": ['cae', 'mw'],
    "yathottaram": ['mw'],
    "yathoḍham": ['mw'],
    "yathā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yathābalam": ['cae', 'mw'],
    "yathābalaṁ": ['cped'],
    "yathābhaktyā": ['mw'],
    "yathābhakṣitam": ['mw'],
    "yathābhataṁ": ['cped'],
    "yathābhavanam": ['mw'],
    "yathābhihitam": ['mw'],
    "yathābhijñāya": ['mw'],
    "yathābhijñāyam": ['mw'],
    "yathābhikāmam": ['mw'],
    "yathābhilaṣita": ['cae', 'mw'],
    "yathābhilikhita": ['mw'],
    "yathābhimata": ['cae', 'mw'],
    "yathābhimatam": ['mw'],
    "yathābhiniviṣṭa": ['mw'],
    "yathābhipreta": ['cae', 'mw'],
    "yathābhipretam": ['mw'],
    "yathābhirantaṁ": ['cped'],
    "yathābhirucita": ['cae', 'mw'],
    "yathābhirāmam": ['mw'],
    "yathābhirūpam": ['mw'],
    "yathābhivṛṣṭam": ['mw'],
    "yathābhucca": ['cped'],
    "yathābhyarthita": ['cae', 'mw'],
    "yathābhāgam": ['cae', 'mw'],
    "yathābhāgaśas": ['mw'],
    "yathābhājanam": ['mw'],
    "yathābhāva": ['mw'],
    "yathābhīṣṭa": ['cae', 'mw'],
    "yathābhūmi": ['mw'],
    "yathābhūta": ['cped'],
    "yathābhūtadarśin": ['mw'],
    "yathābhūtam": ['mw'],
    "yathābhūtapratijñā": ['mw'],
    "yathābhūtaṁ": ['cped'],
    "yathābhūyas": ['mw'],
    "yathābhūyasovāda": ['mw'],
    "yathābuddhi": ['mw'],
    "yathābālam": ['mw'],
    "yathābījam": ['cae', 'mw'],
    "yathācamasam": ['mw'],
    "yathāchandasam": ['mw'],
    "yathācintita": ['mw'],
    "yathācintitānubhāvin": ['cae', 'mw'],
    "yathāciti": ['mw'],
    "yathācittam": ['cae', 'mw'],
    "yathācoditam": ['mw'],
    "yathācāram": ['mw'],
    "yathācārin": ['mw'],
    "yathādadhibhakṣam": ['mw'],
    "yathādarśana": ['mw'],
    "yathādarśanam": ['mw'],
    "yathādarśitam": ['cae', 'mw'],
    "yathādatta": ['mw'],
    "yathādevatam": ['cae', 'mw'],
    "yathādeśakāladehāvasthānaviśeṣam": ['mw'],
    "yathādeśam": ['cae', 'mw'],
    "yathādhammaṁ": ['cped'],
    "yathādharmam": ['cae', 'mw'],
    "yathādhauta": ['bhs'],
    "yathādhikāra": ['mw'],
    "yathādhikāram": ['mw'],
    "yathādhiṣṇyam": ['mw'],
    "yathādhota": ['cped'],
    "yathādhyāpakam": ['mw'],
    "yathādhyāyam": ['mw'],
    "yathādhīta": ['cae', 'mw'],
    "yathādhītam": ['mw'],
    "yathādik": ['cae', 'mw'],
    "yathādiśam": ['cae', 'mw'],
    "yathādiṣṭa": ['mw'],
    "yathādiṣṭam": ['mw'],
    "yathādoṣam": ['mw'],
    "yathādravya": ['mw'],
    "yathādāyam": ['mw'],
    "yathādīkṣam": ['mw'],
    "yathādṛṣṭam": ['cae', 'mw'],
    "yathādṛṣṭi": ['mw'],
    "yathāgama": ['mw'],
    "yathāgamam": ['mw'],
    "yathāgamanam": ['cae', 'mw'],
    "yathāgata": ['cae', 'mw'],
    "yathāgatam": ['mw'],
    "yathāgatena": ['mw'],
    "yathāgavam": ['mw'],
    "yathāgni": ['mw'],
    "yathāgotrakulakalpam": ['mw'],
    "yathāgrahaṇam": ['mw'],
    "yathāguṇam": ['mw'],
    "yathāgātram": ['mw'],
    "yathāgīta": ['mw'],
    "yathāgṛham": ['mw'],
    "yathāgṛhītam": ['mw'],
    "yathāhāra": ['cae', 'mw'],
    "yathāhṛtam": ['mw'],
    "yathājanapadam": ['mw'],
    "yathājjhāsaya": ['cped'],
    "yathājoṣam": ['mw'],
    "yathājyagāna": ['mw'],
    "yathājyeṣṭham": ['cae', 'mw'],
    "yathājñaka": ['bhs'],
    "yathājñapta": ['mw'],
    "yathājñapti": ['mw'],
    "yathājñeyam": ['mw'],
    "yathājñānam": ['cae', 'mw'],
    "yathājāta": ['mw'],
    "yathājātam": ['mw'],
    "yathājātarūpadhara": ['mw'],
    "yathājāti": ['mw'],
    "yathājātīyaka": ['mw'],
    "yathākalpam": ['mw'],
    "yathākammaṁ": ['cped'],
    "yathākaniṣṭham": ['ddsa', 'mw'],
    "yathākarma": ['cae', 'mw'],
    "yathākarmaguṇam": ['mw'],
    "yathākartavya": ['cae', 'mw'],
    "yathākathaṁ": ['cped'],
    "yathākathita": ['cae', 'mw'],
    "yathākhelam": ['cae', 'mw'],
    "yathākhyam": ['mw'],
    "yathākhyata": ['mw'],
    "yathākhyānam": ['mw'],
    "yathākhātam": ['mw'],
    "yathākkamaṁ": ['cped'],
    "yathākrama": ['mw'],
    "yathākramam": ['cae', 'mw'],
    "yathākrameṇa": ['mw'],
    "yathākratu": ['mw'],
    "yathākriyamāṇa": ['mw'],
    "yathākrośam": ['mw'],
    "yathākuladharmam": ['mw'],
    "yathākulam": ['mw'],
    "yathākāla": ['cped', 'mw'],
    "yathākālam": ['cae', 'mw'],
    "yathākālaprabodhin": ['mw'],
    "yathākālaṁ": ['cped'],
    "yathākāma": ['mw'],
    "yathākāmacāra": ['mw'],
    "yathākāmajyeya": ['mw'],
    "yathākāmakārī": ['cped'],
    "yathākāmam": ['cae', 'gra', 'mw'],
    "yathākāmaprayāpya": ['mw'],
    "yathākāmavadhya": ['mw'],
    "yathākāmavicārin": ['mw'],
    "yathākāmaṁ": ['cped'],
    "yathākāmin": ['mw'],
    "yathākāmitva": ['mw'],
    "yathākāmya": ['mw'],
    "yathākāmārcitārthin": ['mw'],
    "yathākāram": ['mw'],
    "yathākāri": ['bhs'],
    "yathākārin": ['mw'],
    "yathākārya": ['cae', 'mw'],
    "yathākārī": ['cped'],
    "yathākāyam": ['mw'],
    "yathākāṇḍam": ['mw'],
    "yathākḷpti": ['mw'],
    "yathākṛta": ['cae', 'mw'],
    "yathākṛtam": ['gra', 'mw'],
    "yathākṛṣṭam": ['mw'],
    "yathākṣamam": ['mw'],
    "yathākṣaram": ['mw'],
    "yathākṣemeṇa": ['mw'],
    "yathākṣipram": ['mw'],
    "yathālabdha": ['cae', 'mw'],
    "yathālikhitānubhāvin": ['cae', 'mw'],
    "yathāliṅgam": ['mw'],
    "yathālokam": ['cae', 'mw'],
    "yathālābha": ['cae', 'mw'],
    "yathālābham": ['mw'],
    "yathāmanasam": ['mw'],
    "yathāmantravarṇam": ['mw'],
    "yathāmanīṣitam": ['mw'],
    "yathāmati": ['cae', 'mw'],
    "yathāmaṅgalam": ['mw'],
    "yathāmittaṁ": ['cped'],
    "yathāmnātam": ['cae', 'mw'],
    "yathāmnāyam": ['cae', 'mw'],
    "yathāmukham": ['mw'],
    "yathāmukhya": ['cae'],
    "yathāmukhyam": ['mw'],
    "yathāmukhyena": ['mw'],
    "yathāmukhīna": ['mw'],
    "yathāmānam": ['mw'],
    "yathāmātram": ['mw'],
    "yathāmūlya": ['mw'],
    "yathānikāyam": ['mw'],
    "yathānilayam": ['mw'],
    "yathānirdiṣṭa": ['cae', 'mw'],
    "yathāniruptam": ['mw'],
    "yathāniveśam": ['mw'],
    "yathānivāsin": ['mw'],
    "yathāniśāntam": ['mw'],
    "yathāniḥsṛptam": ['mw'],
    "yathāntaram": ['mw'],
    "yathānubhāvaṁ": ['cped'],
    "yathānubhūtam": ['mw'],
    "yathānupūrvam": ['mw'],
    "yathānupūrvya": ['mw'],
    "yathānupūrvyā": ['mw'],
    "yathānurūpam": ['mw'],
    "yathānusiṭṭaṁ": ['cped'],
    "yathānyastam": ['mw'],
    "yathānyupta": ['mw'],
    "yathānyuptam": ['mw'],
    "yathānyāsam": ['mw'],
    "yathānyāyam": ['cae', 'mw'],
    "yathānāma": ['mw'],
    "yathānāradabhāṣita": ['mw'],
    "yathānīkam": ['mw'],
    "yathāpadam": ['mw'],
    "yathāparam": ['mw'],
    "yathāparidhi": ['mw'],
    "yathāparilikhitam": ['mw'],
    "yathāparu": ['mw'],
    "yathāparva": ['mw'],
    "yathāparyukṣitam": ['mw'],
    "yathāparādhadaṇḍa": ['mw'],
    "yathāparādham": ['mw'],
    "yathāparīttam": ['mw'],
    "yathāpasādaṁ": ['cped'],
    "yathāpaurāṇa": ['bhs', 'mw'],
    "yathāpaṇyam": ['cae', 'ddsa', 'mw'],
    "yathāphalam": ['mw'],
    "yathāphāsuka": ['cped'],
    "yathāpi": ['bhs'],
    "yathāprabhāvam": ['mw'],
    "yathāpradeśam": ['cae', 'mw'],
    "yathāpradhānam": ['cae', 'mw'],
    "yathāpradhānatas": ['mw'],
    "yathāpradiṣṭam": ['mw'],
    "yathāpradānam": ['mw'],
    "yathāpraiṣam": ['mw'],
    "yathāprajñam": ['mw'],
    "yathāprakṛti": ['mw'],
    "yathāprapannam": ['mw'],
    "yathāprastaram": ['mw'],
    "yathāprastutam": ['cae', 'mw'],
    "yathāprastāvam": ['mw'],
    "yathāprasṛptam": ['mw'],
    "yathāpratiguṇais": ['mw'],
    "yathāpratiguṇam": ['mw'],
    "yathāpratijñam": ['cae', 'mw'],
    "yathāpratijñābhis": ['mw'],
    "yathāpratirūpam": ['mw'],
    "yathāpratyakṣadarśanam": ['mw'],
    "yathāpratyarham": ['mw'],
    "yathāpraveśam": ['mw'],
    "yathāpravṛtam": ['mw'],
    "yathāprayogam": ['mw'],
    "yathāpraśnam": ['mw'],
    "yathāpreṣitam": ['mw'],
    "yathāprāpta": ['cae', 'mw'],
    "yathāprāptam": ['mw'],
    "yathāprāptasvara": ['mw'],
    "yathāprāpti": ['mw'],
    "yathāprārthitam": ['mw'],
    "yathāprāśu": ['mw'],
    "yathāprāṇam": ['cae', 'mw'],
    "yathāprāṇena": ['cae', 'mw'],
    "yathāprīti": ['mw'],
    "yathāpuram": ['mw'],
    "yathāpuroḍāśam": ['mw'],
    "yathāpuruṣam": ['mw'],
    "yathāpuṃsam": ['mw'],
    "yathāpāṭha": ['mw'],
    "yathāpāṭham": ['mw'],
    "yathāpūrita": ['cped'],
    "yathāpūrva": ['cae', 'mw'],
    "yathāpūrvaka": ['mw'],
    "yathāpūrvakam": ['mw'],
    "yathāpūrvam": ['gra', 'mw'],
    "yathāpūrvatva": ['mw'],
    "yathāpṛṣṭhya": ['mw'],
    "yathārabdha": ['mw'],
    "yathārahaṁ": ['cped'],
    "yathārambham": ['mw'],
    "yathārasam": ['mw'],
    "yathārha": ['cae', 'mw'],
    "yathārhakṛtapūja": ['mw'],
    "yathārham": ['mw'],
    "yathārhatas": ['cae', 'mw'],
    "yathārhavarṇa": ['mw'],
    "yathārhaṇam": ['cae', 'mw'],
    "yathārpita": ['mw'],
    "yathārtha": ['cae', 'ddsa', 'mw'],
    "yathārthabhāṣin": ['mw'],
    "yathārthaka": ['mw'],
    "yathārthakṛtanāman": ['mw'],
    "yathārtham": ['mw'],
    "yathārthamañjarī": ['mw'],
    "yathārthanāmaka": ['cae', 'mw'],
    "yathārthanāmakatva": ['mw'],
    "yathārthanāman": ['cae', 'mw'],
    "yathārthatas": ['mw'],
    "yathārthatattvam": ['mw'],
    "yathārthatā": ['mw'],
    "yathārthavarṇa": ['mw'],
    "yathārthita": ['cae', 'ddsa', 'mw'],
    "yathārthitvam": ['mw'],
    "yathārthākhya": ['mw'],
    "yathārthākṣara": ['mw'],
    "yathārucam": ['mw'],
    "yathāruci": ['mw'],
    "yathāruciṁ": ['cped'],
    "yathārūpa": ['cae', 'mw'],
    "yathārūpam": ['mw'],
    "yathārṣam": ['mw'],
    "yathāsabhakṣam": ['mw'],
    "yathāsaddhaṁ": ['cped'],
    "yathāsaka": ['cped'],
    "yathāsakaṁ": ['cped'],
    "yathāsakhyam": ['mw'],
    "yathāsamarthitam": ['cae', 'mw'],
    "yathāsamayam": ['cae', 'mw'],
    "yathāsambandham": ['mw'],
    "yathāsambhava": ['mw'],
    "yathāsambhavam": ['mw'],
    "yathāsambhavin": ['mw'],
    "yathāsambhāvita": ['mw'],
    "yathāsampad": ['mw'],
    "yathāsampradāyam": ['mw'],
    "yathāsamprakīrṇam": ['mw'],
    "yathāsampratyayam": ['mw'],
    "yathāsamuditam": ['mw'],
    "yathāsamānnātam": ['mw'],
    "yathāsamīhita": ['cae', 'mw'],
    "yathāsamīhitam": ['mw'],
    "yathāsanam": ['mw'],
    "yathāsanna": ['cae'],
    "yathāsannam": ['mw'],
    "yathāsarvam": ['cae', 'mw'],
    "yathāsattiṁ": ['cped'],
    "yathāsatyam": ['mw'],
    "yathāsavam": ['mw'],
    "yathāsavanam": ['mw'],
    "yathāsaṃdhi": ['mw'],
    "yathāsaṃdiṣṭa": ['mw'],
    "yathāsaṃdiṣṭam": ['mw'],
    "yathāsaṃhitam": ['mw'],
    "yathāsaṃkalpam": ['mw'],
    "yathāsaṃkalpita": ['cae', 'mw'],
    "yathāsaṃkhya": ['mw'],
    "yathāsaṃkhyam": ['cae', 'mw'],
    "yathāsaṃkhyena": ['mw'],
    "yathāsaṃpreṣitam": ['mw'],
    "yathāsaṃstarika": ['bhs'],
    "yathāsaṃstham": ['mw'],
    "yathāsaṃvedam": ['mw'],
    "yathāsaṃvādam": ['mw'],
    "yathāsaṃvṛttam": ['cae', 'mw'],
    "yathāsaṅgam": ['cae', 'mw'],
    "yathāsiddha": ['mw'],
    "yathāsmṛti": ['mw'],
    "yathāsmṛtimaya": ['mw'],
    "yathāstam": ['mw'],
    "yathāsthita": ['mw'],
    "yathāsthitam": ['mw'],
    "yathāsthiti": ['mw'],
    "yathāsthāma": ['mw'],
    "yathāsthāna": ['cae', 'mw'],
    "yathāsthānam": ['mw'],
    "yathāsthāne": ['mw'],
    "yathāsthūla": ['mw'],
    "yathāstomam": ['mw'],
    "yathāstotriyam": ['mw'],
    "yathāstri": ['mw'],
    "yathāstut": ['mw'],
    "yathāstutam": ['mw'],
    "yathāsukha": ['mw'],
    "yathāsukham": ['cae', 'mw'],
    "yathāsukhamukha": ['cae', 'mw'],
    "yathāsukhaṁ": ['cped'],
    "yathāsuṣṭhu": ['mw'],
    "yathāsva": ['cae', 'mw'],
    "yathāsvaira": ['mw'],
    "yathāsvam": ['mw'],
    "yathāsvaram": ['mw'],
    "yathāsāma": ['mw'],
    "yathāsāmarthyam": ['mw'],
    "yathāsāram": ['mw'],
    "yathāsūktam": ['mw'],
    "yathāsūkṣma": ['mw'],
    "yathāsūkṣmam": ['mw'],
    "yathāsūtram": ['mw'],
    "yathātatha": ['cped', 'mw'],
    "yathātatham": ['cae', 'mw'],
    "yathātathaṁ": ['cped'],
    "yathātathyam": ['cae', 'mw'],
    "yathātathyena": ['mw'],
    "yathātattva": ['cae', 'ddsa', 'mw'],
    "yathātattvam": ['mw'],
    "yathātmaka": ['mw'],
    "yathātmya": ['bhs'],
    "yathātṛpti": ['mw'],
    "yathāvabhṛtham": ['mw'],
    "yathāvacanakārin": ['mw'],
    "yathāvacanam": ['mw'],
    "yathāvadbhāvikatā": ['bhs'],
    "yathāvadgrahaṇa": ['mw'],
    "yathāvadānam": ['mw'],
    "yathāvakāśam": ['cae', 'ddsa', 'mw'],
    "yathāvaniktam": ['mw'],
    "yathāvarṇam": ['mw'],
    "yathāvarṇavidhānam": ['mw'],
    "yathāvasaram": ['cae', 'mw'],
    "yathāvastham": ['mw'],
    "yathāvasthitārthakathana": ['mw'],
    "yathāvastu": ['cae', 'mw'],
    "yathāvat": ['ap90', 'cae', 'mw'],
    "yathāvato": ['cped'],
    "yathāvattam": ['mw'],
    "yathāvayas": ['cae', 'mw'],
    "yathāvayasam": ['cae', 'mw'],
    "yathāvaśam": ['cae', 'gra', 'mw'],
    "yathāvaṣaṭkāram": ['mw'],
    "yathāvedam": ['mw'],
    "yathāvedi": ['mw'],
    "yathāvedita": ['cae'],
    "yathāvibhava": ['mw'],
    "yathāvibhavam": ['mw'],
    "yathāvibhavamānena": ['mw'],
    "yathāvibhavasambhavāt": ['mw'],
    "yathāvibhavatas": ['mw'],
    "yathāvibhavavistarais": ['mw'],
    "yathāvibhavavistaram": ['mw'],
    "yathāvibhavavistāram": ['mw'],
    "yathāvibhāgam": ['mw'],
    "yathāvidha": ['cae', 'mw'],
    "yathāvidhi": ['cae', 'mw'],
    "yathāvidhiṁ": ['cped'],
    "yathāvidhānam": ['cae', 'mw'],
    "yathāvidhānena": ['cae', 'mw'],
    "yathāvidyam": ['cae', 'mw'],
    "yathāvihita": ['cped'],
    "yathāviniyogam": ['mw'],
    "yathāvittam": ['mw'],
    "yathāvittānusāram": ['mw'],
    "yathāvittānusāreṇa": ['mw'],
    "yathāvitānam": ['mw'],
    "yathāviṣayam": ['cae', 'mw'],
    "yathāvutta": ['cped'],
    "yathāvuttaṁ": ['cped'],
    "yathāvuḍḍhaṁ": ['cped'],
    "yathāvyavahāram": ['mw'],
    "yathāvyavasitam": ['cae', 'mw'],
    "yathāvyutpatti": ['mw'],
    "yathāvyādhi": ['mw'],
    "yathāvāditathākāri": ['bhs'],
    "yathāvāsa": ['mw'],
    "yathāvāsam": ['mw'],
    "yathāvāstu": ['mw'],
    "yathāvīrya": ['cae', 'mw'],
    "yathāvīryam": ['mw'],
    "yathāvṛddha": ['mw'],
    "yathāvṛddham": ['cae', 'mw'],
    "yathāvṛddhi": ['mw'],
    "yathāvṛddhikā": ['bhs'],
    "yathāvṛtta": ['cae', 'mw'],
    "yathāvṛttam": ['mw'],
    "yathāvṛtti": ['mw'],
    "yathāvṛttānta": ['mw'],
    "yathāyajus": ['mw'],
    "yathāyatanam": ['cae', 'mw'],
    "yathāyatanāt": ['mw'],
    "yathāyatham": ['cae', 'ddsa', 'mw'],
    "yathāyogam": ['cae', 'mw'],
    "yathāyogena": ['mw'],
    "yathāyogenam": ['mw'],
    "yathāyogya": ['mw'],
    "yathāyogyam": ['cae', 'mw'],
    "yathāyoni": ['mw'],
    "yathāyukta": ['mw'],
    "yathāyuktam": ['mw'],
    "yathāyukti": ['mw'],
    "yathāyuktitas": ['mw'],
    "yathāyācita": ['mw'],
    "yathāyūpam": ['mw'],
    "yathāyūtham": ['mw'],
    "yathāśakti": ['cae', 'mw'],
    "yathāśaktyā": ['cae', 'mw'],
    "yathāśarīram": ['mw'],
    "yathāśayam": ['mw'],
    "yathāśiṣam": ['mw'],
    "yathāślakṣṇa": ['mw'],
    "yathāśobham": ['mw'],
    "yathāśraddham": ['cae', 'mw'],
    "yathāśramam": ['mw'],
    "yathāśraya": ['mw'],
    "yathāśrayam": ['mw'],
    "yathāśreṣṭham": ['mw'],
    "yathāśruta": ['cae', 'mw'],
    "yathāśrutam": ['mw'],
    "yathāśruti": ['cae', 'mw'],
    "yathāśrāddham": ['mw'],
    "yathāśāstra": ['cae', 'mw'],
    "yathāśāstram": ['mw'],
    "yathāśāstrānusārin": ['mw'],
    "yathāśīlam": ['mw'],
    "yathāṃśam": ['mw'],
    "yathāṃśatas": ['mw'],
    "yathāṅgam": ['cae', 'mw'],
    "yathāṭhita": ['cped'],
    "yati": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yatibhraṣṭa": ['ddsa', 'mw'],
    "yatibhāgavata": ['mw'],
    "yatibhūṣaṇī": ['mw'],
    "yaticāndrāyaṇa": ['cae', 'ddsa', 'mw'],
    "yatidharma": ['mw'],
    "yatidharman": ['mw'],
    "yatidharmaprakāśa": ['mw'],
    "yatidharmasamuccaya": ['mw'],
    "yatidharmasaṃgraha": ['mw'],
    "yatidharmin": ['mw'],
    "yatidhā": ['cae', 'mw'],
    "yatikartavyagaṅgāstuti": ['mw'],
    "yatilagna": ['mw'],
    "yatiliṅgasamarthana": ['mw'],
    "yatimaithuna": ['mw'],
    "yatin": ['ap90', 'cae', 'ddsa', 'mw'],
    "yatinī": ['ap90', 'mw'],
    "yatinṛtya": ['mw'],
    "yatipañcaka": ['mw'],
    "yatiprativandanakhaṇḍana": ['mw'],
    "yatipravaṇakalpa": ['mw'],
    "yatiprayoga": ['mw'],
    "yatipātra": ['cae', 'mw'],
    "yatirekhā": ['mw'],
    "yatirāja": ['mw'],
    "yatirājadaṇḍaka": ['mw'],
    "yatirājasaptati": ['mw'],
    "yatirājavedāntavilāsa": ['mw'],
    "yatirājavijaya": ['mw'],
    "yatirājaviṃśati": ['mw'],
    "yatirājaśatakaṭīkā": ['mw'],
    "yatirājīya": ['mw'],
    "yatisamārādhanavidhi": ['mw'],
    "yatisaṃskāra": ['mw'],
    "yatisaṃskāraprayoga": ['mw'],
    "yatisaṃskāravidhi": ['mw'],
    "yatisaṃskāravidhinirṇaya": ['mw'],
    "yatisvadharmabhikṣāvidhi": ['mw'],
    "yatisāṃtapana": ['mw'],
    "yatita": ['ap90', 'mw'],
    "yatitavya": ['cae', 'ddsa', 'mw'],
    "yatitha": ['cae', 'ddsa', 'mw'],
    "yatitva": ['cae', 'mw'],
    "yatitāla": ['ddsa', 'mw'],
    "yativandananiṣedha": ['mw'],
    "yativandanasamarthana": ['mw'],
    "yativandanaśatadūṣaṇī": ['mw'],
    "yativarya": ['mw'],
    "yativeṣa": ['cae'],
    "yativilāsa": ['mw'],
    "yatiśekhara": ['mw'],
    "yatiḥ": ['ap90'],
    "yatkara": ['mw'],
    "yatkhalu": ['bhs'],
    "yatkiṃcana": ['mw'],
    "yatkiṃcanakāraka": ['mw'],
    "yatkiṃcanakārin": ['mw'],
    "yatkiṃcanakāritā": ['mw'],
    "yatkiṃcanapralāpin": ['mw'],
    "yatkiṃcanavāda": ['mw'],
    "yatkiṃcedam": ['mw'],
    "yatkiṃciccāraka": ['mw'],
    "yatkiṃcid": ['mw'],
    "yatkiṃcidapisaṃkalpa": ['mw'],
    "yatkiṃcidduḥkha": ['mw'],
    "yatkratu": ['mw'],
    "yatkula": ['mw'],
    "yatkāma": ['cae', 'ddsa', 'gra', 'mw'],
    "yatkāmyā": ['cae', 'mw'],
    "yatkāraṇam": ['cae', 'mw'],
    "yatkārin": ['mw'],
    "yatkāryam": ['mw'],
    "yatkṛte": ['cae', 'mw'],
    "yatna": ['cae', 'ddsa', 'mw'],
    "yatnapratipādya": ['mw'],
    "yatnatas": ['mw'],
    "yatnavant": ['cae'],
    "yatnavat": ['ddsa', 'mw'],
    "yatnavattva": ['mw'],
    "yatnaḥ": ['ap90'],
    "yatnākṣepa": ['mw'],
    "yatnāntara": ['mw'],
    "yato": ['cped', 'mw'],
    "yato kutoci": ['cped'],
    "yatoadhikaraṇaṃ": ['bhs'],
    "yatodbhava": ['mw'],
    "yatojā": ['mw'],
    "yatomūla": ['ddsa', 'mw'],
    "yatparākrama": ['mw'],
    "yatprabhāva": ['cae'],
    "yatprathama": ['mw'],
    "yatpṛṣṭha": ['mw'],
    "yatra": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yatrahināma": ['bhs'],
    "yatrakāmam": ['mw'],
    "yatrakāmāvasāya": ['ddsa', 'mw'],
    "yatrakāmāvasāyin": ['mw'],
    "yatrakāmāvasāyitva": ['mw'],
    "yatrakāmāvasāyitā": ['mw'],
    "yatrastha": ['mw'],
    "yatrasāyampratiśraya": ['mw'],
    "yatrasāyaṃgṛha": ['cae', 'mw'],
    "yatrasāyaṅgṛha": ['ddsa'],
    "yatratatraśaya": ['mw'],
    "yatratya": ['ap90', 'cae', 'ddsa', 'mw'],
    "yatrecchaka": ['cae', 'mw'],
    "yatrodbhūta": ['cae', 'mw'],
    "yatrā": ['cae'],
    "yatrākūta": ['mw'],
    "yatrāstamitaśāyin": ['mw'],
    "yatsaṃkhyāka": ['cae', 'mw'],
    "yatsaṅkhyāka": ['ddsa'],
    "yatsena": ['mw'],
    "yatsvabhāva": ['mw'],
    "yatta": ['ap90', 'mw'],
    "yattaka": ['bhs', 'cped'],
    "yattha": ['cped'],
    "yatthatta": ['cped'],
    "yattu": ['bhs'],
    "yatu": ['mw'],
    "yatukā": ['mw'],
    "yatuna": ['gra', 'mw'],
    "yatva": ['mw'],
    "yaty": ['mw'],
    "yatya": ['mw'],
    "yatyantakarmapaddhati": ['mw'],
    "yatyanuṣṭhāna": ['mw'],
    "yatyanuṣṭhānapaddhati": ['mw'],
    "yatyācārasaptarṣipūjā": ['mw'],
    "yatyācārasaṃgrahīyayatisaṃskāraprayoga": ['mw'],
    "yatāhāra": ['mw'],
    "yatākṣāsumanobuddhi": ['mw'],
    "yatātman": ['cae', 'ddsa', 'mw'],
    "yatātmavant": ['cae'],
    "yatīndra": ['mw'],
    "yatīndramatabhāskara": ['mw'],
    "yatīndramatadīpikā": ['mw'],
    "yatīndramatadūṣaṇī": ['mw'],
    "yatīyasa": ['mw'],
    "yatīśa": ['mw'],
    "yatīśvara": ['mw'],
    "yatīśvaraprārthanā": ['mw'],
    "yatīśvarasvāmin": ['mw'],
    "yatūkā": ['mw'],
    "yaudha": ['ap90', 'cae', 'ddsa', 'mw'],
    "yaudheya": ['cae', 'ddsa', 'mw'],
    "yaudheyaka": ['mw'],
    "yaudhika": ['mw'],
    "yaudhiṣṭhira": ['ddsa', 'mw'],
    "yaudhiṣṭhiri": ['mw'],
    "yaudhājaya": ['mw'],
    "yauga": ['mw'],
    "yaugaka": ['mw'],
    "yaugandharāyaṇa": ['ddsa'],
    "yaugapada": ['cae', 'mw'],
    "yaugapadya": ['cae', 'ddsa', 'mw'],
    "yaugapadyaṃ": ['ap90'],
    "yaugapadyena": ['mw'],
    "yaugavaratra": ['mw'],
    "yaugaḥ": ['ap90'],
    "yaugaṃdhara": ['mw'],
    "yaugaṃdhari": ['mw'],
    "yaugaṃdharāyaṇa": ['cae', 'mw'],
    "yaugaṃdharāyaṇīya": ['mw'],
    "yaugika": ['ap90', 'cae', 'ddsa', 'mw'],
    "yaugikarūḍha": ['mw'],
    "yaugikatva": ['mw'],
    "yaujanaśatika": ['mw'],
    "yaujanika": ['mw'],
    "yaukarīya": ['mw'],
    "yauktasruca": ['mw'],
    "yauktika": ['ap90', 'mw'],
    "yauktāśva": ['mw'],
    "yauna": ['ap90', 'cae', 'ddsa', 'mw'],
    "yaunasambandha": ['mw'],
    "yaunika": ['mw'],
    "yaupa": ['ddsa', 'mw'],
    "yaupya": ['mw'],
    "yautaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "yautaki": ['mw'],
    "yautava": ['mw'],
    "yautavaṃ": ['ap90'],
    "yauthika": ['ap90', 'ddsa', 'mw'],
    "yauthya": ['mw'],
    "yautra": ['mw'],
    "yautuka": ['ddsa', 'mw'],
    "yauvana": ['ap90', 'cae', 'ddsa', 'mw'],
    "yauvanabhinnaśaiśava": ['mw'],
    "yauvanadarpa": ['mw'],
    "yauvanadaśā": ['mw'],
    "yauvanaka": ['mw'],
    "yauvanakaṃ": ['ap90'],
    "yauvanakaṇṭaka": ['mw'],
    "yauvanalakṣaṇa": ['mw'],
    "yauvanamattā": ['mw'],
    "yauvanapadavī": ['mw'],
    "yauvanapiḍakā": ['mw'],
    "yauvanaprānta": ['mw'],
    "yauvanastha": ['cae', 'mw'],
    "yauvanasukha": ['cae', 'mw'],
    "yauvanavant": ['cae'],
    "yauvanavat": ['mw'],
    "yauvanaśrī": ['cae', 'mw'],
    "yauvaneśvara": ['ddsa'],
    "yauvanika": ['bhs', 'mw'],
    "yauvanin": ['ddsa', 'mw'],
    "yauvanodbheda": ['mw'],
    "yauvanānta": ['mw'],
    "yauvanārambha": ['cae', 'mw'],
    "yauvanārūḍha": ['mw'],
    "yauvanāvasthā": ['mw'],
    "yauvanāśva": ['mw'],
    "yauvanāśvaka": ['mw'],
    "yauvanāśvaḥ": ['ap90'],
    "yauvanāśvi": ['mw'],
    "yauvanīya": ['cae', 'mw'],
    "yauvarājika": ['mw'],
    "yauvarājya": ['bhs', 'cae', 'ddsa', 'mw'],
    "yauvarājyaṃ": ['ap90'],
    "yauvata": ['mw'],
    "yauvataṃ": ['ap90'],
    "yauvateya": ['mw'],
    "yauvateyaḥ": ['ap90'],
    "yauyudhāni": ['mw'],
    "yauḍ": ['ap90', 'mw'],
    "yauṣiṇya": ['cae', 'mw'],
    "yauṣiṇyaṃ": ['ap90'],
    "yauṣmāka": ['ap90', 'cae', 'ddsa', 'mw'],
    "yauṣmākīna": ['cae', 'mw'],
    "yauṭ": ['ap90', 'mw'],
    "yava": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yavabusa": ['mw'],
    "yavabusaka": ['mw'],
    "yavacaturthī": ['mw'],
    "yavacūrṇa": ['mw'],
    "yavadvīpa": ['mw'],
    "yavagaṇḍa": ['mw'],
    "yavagodhūmaja": ['mw'],
    "yavagodhūmavant": ['cae'],
    "yavagodhūmavat": ['mw'],
    "yavagrīva": ['mw'],
    "yavaja": ['mw'],
    "yavaka": ['mw'],
    "yavakacchaka": ['bhs'],
    "yavakaḥ": ['ap90'],
    "yavakhada": ['mw'],
    "yavakhadika": ['mw'],
    "yavakhala": ['cae', 'mw'],
    "yavakoṭi": ['mw'],
    "yavakoṭī": ['mw'],
    "yavakrin": ['mw'],
    "yavakrī": ['mw'],
    "yavakrīta": ['mw'],
    "yavakya": ['ap90', 'mw'],
    "yavakṣetra": ['cae', 'ddsa', 'mw'],
    "yavakṣoda": ['mw'],
    "yavakṣā": ['mw'],
    "yavakṣāra": ['mw'],
    "yavalaka": ['mw'],
    "yavalāsa": ['mw'],
    "yavamadhya": ['cae', 'mw'],
    "yavamadhyama": ['cae', 'mw'],
    "yavamadhyā": ['mw'],
    "yavamant": ['cae'],
    "yavamardana": ['mw'],
    "yavamat": ['ap90', 'gra', 'mw'],
    "yavamatya": ['mw'],
    "yavamatī": ['mw'],
    "yavamaya": ['cae', 'mw'],
    "yavamaṇi": ['mw'],
    "yavamuṣṭi": ['mw'],
    "yavamātra": ['mw'],
    "yavan": ['cae', 'ddsa', 'mw'],
    "yavana": ['cae', 'ddsa', 'mw'],
    "yavanadeśa": ['mw'],
    "yavanadeśaja": ['mw'],
    "yavanadeśodbhava": ['mw'],
    "yavanadviṣṭa": ['mw'],
    "yavanahorā": ['mw'],
    "yavanajātaka": ['mw'],
    "yavanaka": ['mw'],
    "yavanamatagolādhyāya": ['mw'],
    "yavanamuṇḍa": ['mw'],
    "yavanapriya": ['mw'],
    "yavanapura": ['mw'],
    "yavanasena": ['mw'],
    "yavanasāra": ['mw'],
    "yavanaśāstremalapraśna": ['mw'],
    "yavanaḥ": ['ap90'],
    "yavaneśvara": ['ddsa', 'mw'],
    "yavaneṣṭa": ['mw'],
    "yavaneṣṭā": ['mw'],
    "yavanikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "yavanācārya": ['mw'],
    "yavanāla": ['mw'],
    "yavanālaja": ['mw'],
    "yavanānī": ['ap90', 'bhs', 'ddsa', 'mw'],
    "yavanāri": ['mw'],
    "yavanī": ['mw'],
    "yavanīyaramalaśāstra": ['mw'],
    "yavaphala": ['mw'],
    "yavapiṣṭa": ['cae', 'ddsa', 'mw'],
    "yavapiṣṭaka": ['mw'],
    "yavaprakhyā": ['mw'],
    "yavapraroha": ['mw'],
    "yavapāla": ['mw'],
    "yavasa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yavasaktu": ['mw'],
    "yavasamuṣṭi": ['mw'],
    "yavasaprathama": ['mw'],
    "yavasaṃ": ['ap90'],
    "yavasin": ['gra', 'mw'],
    "yavasodaka": ['mw'],
    "yavasurā": ['mw'],
    "yavasyu": ['mw'],
    "yavasād": ['cae', 'gra', 'mw'],
    "yavasāhva": ['mw'],
    "yavasānnodakendhana": ['mw'],
    "yavasūka": ['cped'],
    "yavatiktā": ['mw'],
    "yavavaktra": ['mw'],
    "yavavelā": ['mw'],
    "yavaya": ['mw'],
    "yavayasa": ['mw'],
    "yavayu": ['cae', 'gra', 'mw'],
    "yavayāvan": ['cae', 'mw'],
    "yavaśasya": ['mw'],
    "yavaśiras": ['mw'],
    "yavaśūka": ['mw'],
    "yavaśūkaja": ['mw'],
    "yavaḥ": ['ap90'],
    "yavia": ['gra'],
    "yavika": ['mw'],
    "yavila": ['mw'],
    "yavin": ['mw'],
    "yaviṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yaviṣṭhavat": ['mw'],
    "yaviṣṭhia": ['gra'],
    "yaviṣṭhya": ['cae', 'gra', 'mw'],
    "yavodara": ['mw'],
    "yavorvarā": ['ddsa', 'mw'],
    "yavottha": ['mw'],
    "yavya": ['ap90', 'cae', 'gra', 'mw'],
    "yavyā": ['cae', 'gra', 'mw'],
    "yavyābhis": ['mw'],
    "yavyāvatī": ['gra', 'mw'],
    "yavācita": ['cae', 'mw'],
    "yavācāma": ['mw'],
    "yavād": ['cae', 'gra', 'mw'],
    "yavāgraja": ['mw'],
    "yavāgrayaṇa": ['mw'],
    "yavāgū": ['ap90', 'cae', 'ddsa', 'mw'],
    "yavāgūcāraka": ['mw'],
    "yavāgūmaya": ['mw'],
    "yavāhva": ['mw'],
    "yavāhāra": ['cae', 'mw'],
    "yavākāra": ['mw'],
    "yavāmlaja": ['mw'],
    "yavāna": ['mw'],
    "yavānikā": ['ap90', 'mw'],
    "yavānna": ['mw'],
    "yavāntara": ['mw'],
    "yavānvita": ['mw'],
    "yavānī": ['mw'],
    "yavāpatya": ['mw'],
    "yavāsa": ['mw'],
    "yavāsaka": ['cae', 'ddsa', 'mw'],
    "yavāsaśarkarā": ['mw'],
    "yavāsaḥ": ['ap90'],
    "yavāsinī": ['ap90', 'mw'],
    "yavāsā": ['mw'],
    "yavāśir": ['cae', 'gra', 'mw'],
    "yavāṅkura": ['mw'],
    "yavāṣa": ['mw'],
    "yavāṣika": ['mw'],
    "yavāṣin": ['mw'],
    "yavīnara": ['mw'],
    "yavīyas": ['ap90', 'gra', 'mw'],
    "yavīyasa": ['mw'],
    "yavīyasī": ['mw'],
    "yavīyaṃs": ['cae'],
    "yavīyudh": ['cae', 'gra', 'mw'],
    "yavīā": ['gra'],
    "yayi": ['cae', 'ddsa', 'gra', 'mw'],
    "yayin": ['ap90', 'gra', 'mw'],
    "yayiḥ": ['ap90'],
    "yayu": ['cae', 'ddsa', 'mw'],
    "yayuḥ": ['ap90'],
    "yayāti": ['cae', 'ddsa', 'gra', 'mw'],
    "yayāticarita": ['mw'],
    "yayātijā": ['mw'],
    "yayātika": ['mw'],
    "yayātipatana": ['mw'],
    "yayātivat": ['mw'],
    "yayātivijaya": ['mw'],
    "yayātiḥ": ['ap90'],
    "yayāvara": ['mw'],
    "yayāvaraḥ": ['ap90'],
    "yayī": ['cae', 'gra', 'mw'],
    "yañja": ['mw'],
    "yañña": ['cped'],
    "yaññasāmī": ['cped'],
    "yaññupanīta": ['cped'],
    "yaññāvāṭa": ['cped'],
    "yaśa": ['bhs', 'mw'],
    "yaśada": ['mw'],
    "yaśadatta": ['bhs'],
    "yaśadaṃ": ['ap90'],
    "yaśaketu": ['bhs'],
    "yaśamatī": ['bhs'],
    "yaśaparvata": ['bhs'],
    "yaśaprāptā": ['bhs'],
    "yaśarāśi": ['bhs'],
    "yaśas": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "yaśasa": ['mw'],
    "yaśasin": ['mw'],
    "yaśaskara": ['cae', 'ddsa', 'mw'],
    "yaśaskarasvāmin": ['mw'],
    "yaśaskāma": ['bhs', 'cae', 'mw'],
    "yaśaskāmya": ['mw'],
    "yaśaskṛt": ['cae', 'mw'],
    "yaśastama": ['mw'],
    "yaśastara": ['mw'],
    "yaśasvant": ['cae'],
    "yaśasvat": ['gra', 'mw'],
    "yaśasvatī": ['mw'],
    "yaśasvin": ['ap90', 'cae', 'mw'],
    "yaśasvinī": ['mw'],
    "yaśasya": ['ap90', 'cae', 'ddsa', 'mw'],
    "yaśasyati": ['ap90'],
    "yaśasyu": ['cae', 'mw'],
    "yaśasyā": ['mw'],
    "yaśavatī": ['bhs'],
    "yaśavrata": ['bhs'],
    "yaśaś": ['mw'],
    "yaśaścandra": ['mw'],
    "yaśaḥ": ['mw'],
    "yaśaḥkarṇa": ['mw'],
    "yaśaḥketu": ['ddsa', 'mw'],
    "yaśaḥkhaṇḍin": ['mw'],
    "yaśaḥkāya": ['mw'],
    "yaśaḥparvataśrīmegha": ['bhs'],
    "yaśaḥpaṭaha": ['mw'],
    "yaśaḥprabha": ['bhs', 'mw'],
    "yaśaḥprabhāsa": ['bhs'],
    "yaśaḥprabhāva": ['mw'],
    "yaśaḥprakhyāpana": ['mw'],
    "yaśaḥpāla": ['mw'],
    "yaśaḥpūrṇa": ['bhs'],
    "yaśaḥśarīra": ['mw'],
    "yaśaḥśeṣa": ['mw'],
    "yaśaḥśeṣībhūta": ['mw'],
    "yaśaḥśuddhodita": ['bhs'],
    "yaśo": ['mw'],
    "yaśobhadra": ['mw'],
    "yaśobhagin": ['cae', 'mw'],
    "yaśobhagya": ['mw'],
    "yaśobhagīna": ['mw'],
    "yaśobhṛt": ['cae', 'mw'],
    "yaśoda": ['bhs', 'mw'],
    "yaśodarpaṇikā": ['mw'],
    "yaśodatta": ['bhs', 'mw'],
    "yaśodeva": ['bhs', 'mw'],
    "yaśodevī": ['mw'],
    "yaśodgata": ['bhs'],
    "yaśodhana": ['cae', 'mw'],
    "yaśodhara": ['mw'],
    "yaśodhareya": ['mw'],
    "yaśodharman": ['mw'],
    "yaśodharā": ['bhs', 'mw'],
    "yaśodhavala": ['mw'],
    "yaśodhā": ['cae', 'mw'],
    "yaśodhāman": ['mw'],
    "yaśodā": ['cae', 'mw'],
    "yaśodāgarbhasambhūtā": ['mw'],
    "yaśodānanda": ['mw'],
    "yaśodānandana": ['mw'],
    "yaśodāsuta": ['mw'],
    "yaśoghna": ['cae', 'ddsa', 'mw'],
    "yaśogopi": ['mw'],
    "yaśohan": ['cae', 'mw'],
    "yaśohara": ['cae', 'mw'],
    "yaśoharajit": ['mw'],
    "yaśohīna": ['mw'],
    "yaśolekhā": ['mw'],
    "yaśomatya": ['mw'],
    "yaśomatī": ['bhs', 'mw'],
    "yaśomaṅgalastotra": ['mw'],
    "yaśomedhāsamanvita": ['mw'],
    "yaśomitra": ['bhs', 'mw'],
    "yaśomādhava": ['mw'],
    "yaśonandi": ['mw'],
    "yaśonidhi": ['mw'],
    "yaśorāja": ['mw'],
    "yaśorāta": ['mw'],
    "yaśorāśi": ['mw'],
    "yaśottara": ['bhs'],
    "yaśovara": ['mw'],
    "yaśovardhana": ['mw'],
    "yaśovarmaka": ['mw'],
    "yaśovarman": ['cae', 'mw'],
    "yaśovartman": ['mw'],
    "yaśovat": ['mw'],
    "yaśovatī": ['bhs', 'mw'],
    "yaśoviśāla": ['mw'],
    "yaśoyuta": ['mw'],
    "yaśāmatī": ['bhs'],
    "yaḥ": ['ap90'],
    "yaṁ": ['cped'],
    "yaṃ": ['bhs'],
    "yaṃca": ['bhs'],
    "yaṃkhalu": ['bhs'],
    "yaṃtr": ['ap90'],
    "yaṃtrakaḥ": ['ap90'],
    "yaṃtraṃ": ['ap90'],
    "yaṃtraṇaṃ": ['ap90'],
    "yaṃtraṇī": ['ap90'],
    "yaṃtrin": ['ap90'],
    "yaṃtrita": ['ap90'],
    "yaṃtṛ": ['ap90'],
    "yaṅ": ['ap90', 'ddsa', 'mw'],
    "yaṅanta": ['mw'],
    "yaṅluganta": ['mw'],
    "yaṅlugantaśiromaṇi": ['mw'],
    "yaṅluk": ['mw'],
    "yaṇ": ['ddsa', 'mw'],
    "yaṇva": ['mw'],
    "yaṇvāpatye": ['mw'],
    "yaṇādeśasūtra": ['mw'],
    "yaṣṭa": ['bhs'],
    "yaṣṭave": ['cae', 'ddsa', 'mw'],
    "yaṣṭavya": ['cae', 'ddsa', 'mw'],
    "yaṣṭi": ['bhs', 'cae', 'ddsa', 'mw'],
    "yaṣṭigraha": ['mw'],
    "yaṣṭigrāham": ['mw'],
    "yaṣṭigrāma": ['mw'],
    "yaṣṭigṛha": ['mw'],
    "yaṣṭika": ['mw'],
    "yaṣṭikaḥ": ['ap90'],
    "yaṣṭikā": ['ap90', 'mw'],
    "yaṣṭilatā": ['mw'],
    "yaṣṭimadhu": ['mw'],
    "yaṣṭimadhuka": ['mw'],
    "yaṣṭimadhukā": ['mw'],
    "yaṣṭimat": ['mw'],
    "yaṣṭimaudgalya": ['mw'],
    "yaṣṭinivāsa": ['mw'],
    "yaṣṭiprāna": ['mw'],
    "yaṣṭiyantra": ['mw'],
    "yaṣṭiḥ": ['ap90'],
    "yaṣṭraska": ['mw'],
    "yaṣṭukāma": ['mw'],
    "yaṣṭy": ['mw'],
    "yaṣṭyutthāna": ['cae', 'mw'],
    "yaṣṭyāghāta": ['mw'],
    "yaṣṭyāhva": ['mw'],
    "yaṣṭyāhvaya": ['mw'],
    "yaṣṭyāhvā": ['mw'],
    "yaṣṭī": ['ap90', 'mw'],
    "yaṣṭīka": ['mw'],
    "yaṣṭīmadhu": ['mw'],
    "yaṣṭīmadhuka": ['mw'],
    "yaṣṭīpuṣpa": ['mw'],
    "yaṣṭīvana": ['bhs'],
    "yaṣṭṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yaṣṭṛtara": ['mw'],
    "yaṣṭṛtva": ['mw'],
    "yaṣṭṛtā": ['mw'],
    "yaṭṭhi": ['cped'],
    "yaṭṭhikoṭi": ['cped'],
    "yaṭṭhimadhukā": ['cped'],
    "yebhuyya": ['cped'],
    "yebhuyyayena": ['cped'],
    "yebhuyyena": ['cped'],
    "yemana": ['mw'],
    "yena": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "yenaiva": ['bhs'],
    "yenakāma": ['bhs'],
    "yenicchakaṃ": ['bhs'],
    "yeva": ['bhs', 'cped'],
    "yevāṣa": ['mw'],
    "yeyajñenetisūkta": ['mw'],
    "yeyajāmaha": ['mw'],
    "yeyāyeya": ['mw'],
    "yeṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yeṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "yeṣṭiha": ['mw'],
    "yittha": ['mw'],
    "yiyakṣa": ['ddsa'],
    "yiyakṣamāṇa": ['mw'],
    "yiyakṣat": ['mw'],
    "yiyakṣu": ['cae', 'mw'],
    "yiyapsu": ['mw'],
    "yiyapsyamānā": ['mw'],
    "yiyaviṣu": ['mw'],
    "yiyaviṣā": ['mw'],
    "yiyāsu": ['cae', 'mw'],
    "yiyāsā": ['cae', 'ddsa', 'mw'],
    "yiṭṭha": ['cped'],
    "yo": ['cped'],
    "yobbana": ['cped'],
    "yobbanamada": ['cped'],
    "yobbañña": ['cped'],
    "yobhūyena": ['bhs'],
    "yoddhavya": ['cae', 'ddsa', 'mw'],
    "yoddhukāma": ['cae', 'mw'],
    "yoddhṛ": ['ap90', 'cae', 'mw'],
    "yodha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yodhadharma": ['cae', 'mw'],
    "yodhahara": ['mw'],
    "yodhaka": ['mw'],
    "yodhamukhya": ['cae', 'ddsa', 'mw'],
    "yodhana": ['bhs', 'cae', 'mw'],
    "yodhanapuratīrtha": ['mw'],
    "yodhanaṃ": ['ap90'],
    "yodhanīpura": ['mw'],
    "yodhanīya": ['cae', 'mw'],
    "yodhasaṃrāva": ['mw'],
    "yodhavīra": ['cae', 'mw'],
    "yodhaḥ": ['ap90'],
    "yodhesi": ['cped'],
    "yodheti": ['cped'],
    "yodhetvā": ['cped'],
    "yodheya": ['mw'],
    "yodhika": ['mw'],
    "yodhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "yodhita": ['cped'],
    "yodhivana": ['mw'],
    "yodhya": ['cae', 'mw'],
    "yodhāgāra": ['mw'],
    "yodhājīva": ['cped'],
    "yodhīyas": ['gra', 'mw'],
    "yodhīyaṃs": ['cae'],
    "yoga": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yogabala": ['mw'],
    "yogabhadrā": ['mw'],
    "yogabhraṣṭa": ['cae', 'mw'],
    "yogabhāraka": ['mw'],
    "yogabhāskara": ['mw'],
    "yogabhāvanā": ['mw'],
    "yogabhāṣya": ['mw'],
    "yogabinduṭippaṇa": ['mw'],
    "yogabīja": ['mw'],
    "yogacakṣus": ['mw'],
    "yogacandraṭīkā": ['mw'],
    "yogacandrikā": ['mw'],
    "yogacandrikāvilāsa": ['mw'],
    "yogacara": ['mw'],
    "yogacaryā": ['mw'],
    "yogacikitsā": ['mw'],
    "yogacintāmaṇi": ['mw'],
    "yogacūrṇa": ['mw'],
    "yogacūḍopaniṣad": ['mw'],
    "yogacūḍāmaṇi": ['mw'],
    "yogacūḍāmaṇyupaniṣad": ['mw'],
    "yogadarpaṇa": ['mw'],
    "yogadaṇḍa": ['mw'],
    "yogadeva": ['mw'],
    "yogadharmin": ['cae', 'mw'],
    "yogadhāraṇā": ['cae', 'mw'],
    "yogadāna": ['mw'],
    "yogadānapratigraha": ['mw'],
    "yogadīpikā": ['mw'],
    "yogadṛṣṭisamuccayavyākhyā": ['mw'],
    "yogagati": ['mw'],
    "yogagrantha": ['mw'],
    "yogagāmin": ['mw'],
    "yogagātiga": ['cped'],
    "yogahṛdaya": ['mw'],
    "yogaiśvarya": ['mw'],
    "yogaja": ['mw'],
    "yogajñāna": ['mw'],
    "yogakakṣā": ['mw'],
    "yogakalpadruma": ['mw'],
    "yogakalpalatā": ['mw'],
    "yogakanyā": ['mw'],
    "yogakara": ['mw'],
    "yogakaraṇḍaka": ['ddsa', 'mw'],
    "yogakaraṇḍikā": ['mw'],
    "yogakkhema": ['cped'],
    "yogakuṇḍalinī": ['mw'],
    "yogakuṇḍalyupaniṣad": ['mw'],
    "yogakṣema": ['bhs', 'cae', 'gra', 'mw'],
    "yogakṣemakara": ['cae', 'mw'],
    "yogakṣemasamarpitṛ": ['mw'],
    "yogakṣemavaha": ['mw'],
    "yogakṣemavat": ['mw'],
    "yogakṣemin": ['bhs'],
    "yogamahiman": ['mw'],
    "yogamaya": ['mw'],
    "yogamayajñāna": ['mw'],
    "yogamañjarī": ['mw'],
    "yogamaṇiprabhā": ['mw'],
    "yogamaṇipradīpikā": ['mw'],
    "yogamuktāvalī": ['mw'],
    "yogamālā": ['mw'],
    "yogamārga": ['mw'],
    "yogamārtaṇḍa": ['mw'],
    "yogamātṛ": ['mw'],
    "yogamāyā": ['cae', 'mw'],
    "yogamūrtidhara": ['mw'],
    "yogananda": ['mw'],
    "yoganidrā": ['cae', 'mw'],
    "yoganidrālu": ['mw'],
    "yoganilaya": ['mw'],
    "yoganyāsa": ['mw'],
    "yoganātha": ['mw'],
    "yoganāvika": ['mw'],
    "yogapada": ['mw'],
    "yogapadaka": ['mw'],
    "yogapaddhati": ['mw'],
    "yogapatha": ['mw'],
    "yogapati": ['mw'],
    "yogapatnī": ['mw'],
    "yogapaṭṭa": ['mw'],
    "yogapaṭṭaka": ['mw'],
    "yogapradīpa": ['mw'],
    "yogapradīpikā": ['mw'],
    "yogaprakāra": ['mw'],
    "yogaprakāśaṭīkā": ['mw'],
    "yogapraveśavidhi": ['mw'],
    "yogaprāpta": ['mw'],
    "yogapādukā": ['mw'],
    "yogapāraṃga": ['mw'],
    "yogapātañjala": ['mw'],
    "yogapīṭha": ['mw'],
    "yogarahasya": ['mw'],
    "yogarasāyana": ['mw'],
    "yogaratha": ['mw'],
    "yogaratna": ['mw'],
    "yogaratnamālā": ['mw'],
    "yogaratnasamuccaya": ['mw'],
    "yogaratnākara": ['mw'],
    "yogaratnāvalī": ['mw'],
    "yogaraṅga": ['mw'],
    "yogarddhirūpavat": ['mw'],
    "yogarocanā": ['cae', 'mw'],
    "yogarāja": ['mw'],
    "yogarājaguggulu": ['mw'],
    "yogarājopaniṣad": ['mw'],
    "yogarūḍha": ['mw'],
    "yogarūḍhatā": ['mw'],
    "yogarūḍhivicāra": ['mw'],
    "yogarūḍhivāda": ['mw'],
    "yogas": ['ap90', 'mw'],
    "yogasamādhi": ['mw'],
    "yogasaṃgraha": ['mw'],
    "yogasaṃsiddhi": ['mw'],
    "yogasevā": ['mw'],
    "yogasiddha": ['mw'],
    "yogasiddhi": ['mw'],
    "yogasiddhimat": ['mw'],
    "yogasiddhiprakriyā": ['mw'],
    "yogasiddhā": ['mw'],
    "yogasiddhāntacandrikā": ['mw'],
    "yogasiddhāntapaddhati": ['mw'],
    "yogastha": ['cae', 'mw'],
    "yogasudhākara": ['mw'],
    "yogasudhānidhi": ['mw'],
    "yogasvarodaya": ['mw'],
    "yogasvāmin": ['mw'],
    "yogasādhana": ['mw'],
    "yogasāgara": ['mw'],
    "yogasāra": ['mw'],
    "yogasārasamuccaya": ['mw'],
    "yogasārasaṃgraha": ['mw'],
    "yogasāratantra": ['mw'],
    "yogasārāvali": ['mw'],
    "yogasārāvalī": ['mw'],
    "yogasūtra": ['mw'],
    "yogasūtrabhāṣya": ['mw'],
    "yogasūtracandrikā": ['mw'],
    "yogasūtragūḍhārthadyotikā": ['mw'],
    "yogasūtravyākhyāna": ['mw'],
    "yogasūtravṛtti": ['mw'],
    "yogasūtrārthacandrikā": ['mw'],
    "yogatalpa": ['mw'],
    "yogatantra": ['mw'],
    "yogataraṃga": ['mw'],
    "yogataraṃgiṇī": ['mw'],
    "yogatas": ['mw'],
    "yogatattva": ['mw'],
    "yogatattvaprakāśa": ['mw'],
    "yogatattvaprakāśaka": ['mw'],
    "yogatattvopaniṣad": ['mw'],
    "yogataḥ": ['ap90'],
    "yogatva": ['mw'],
    "yogatārakā": ['mw'],
    "yogatārā": ['mw'],
    "yogatārāvalī": ['mw'],
    "yogavaha": ['mw'],
    "yogavant": ['cae'],
    "yogavartikā": ['mw'],
    "yogavarṇana": ['mw'],
    "yogavat": ['mw'],
    "yogavibhāga": ['cae', 'mw'],
    "yogavicāra": ['mw'],
    "yogavid": ['cae', 'mw'],
    "yogavidyā": ['mw'],
    "yogavikraya": ['mw'],
    "yogaviveka": ['mw'],
    "yogaviṣaya": ['mw'],
    "yogavācaspatya": ['mw'],
    "yogavāha": ['mw'],
    "yogavāhaka": ['mw'],
    "yogavāhin": ['mw'],
    "yogavāhitva": ['mw'],
    "yogavāhī": ['mw'],
    "yogavārttika": ['mw'],
    "yogavāsiṣṭha": ['mw'],
    "yogavāsiṣṭhasaṃkṣepa": ['mw'],
    "yogavāsiṣṭhasāra": ['mw'],
    "yogavāsiṣṭhasāracandrikā": ['mw'],
    "yogavāsiṣṭhasārasaṃgraha": ['mw'],
    "yogavāsiṣṭhasāravivṛti": ['mw'],
    "yogavāsiṣṭhatātparyaprakāśa": ['mw'],
    "yogavāsiṣṭhaśāstra": ['mw'],
    "yogavāsiṣṭhīya": ['mw'],
    "yogavṛttisaṃgraha": ['mw'],
    "yogayajña": ['cae'],
    "yogayogin": ['mw'],
    "yogayuj": ['mw'],
    "yogayukta": ['cae', 'mw'],
    "yogayukti": ['mw'],
    "yogayutta": ['cped'],
    "yogayājñavalkya": ['mw'],
    "yogayājñavalkyagītā": ['mw'],
    "yogayājñavalkyasmṛti": ['mw'],
    "yogayātrā": ['cae', 'mw'],
    "yogaśabda": ['mw'],
    "yogaśarīrin": ['mw'],
    "yogaśata": ['mw'],
    "yogaśataka": ['mw'],
    "yogaśatakavyākhyāna": ['mw'],
    "yogaśatakākhyāna": ['mw'],
    "yogaśikhopaniṣad": ['mw'],
    "yogaśikhā": ['mw'],
    "yogaśikṣopaniṣad": ['mw'],
    "yogaśikṣā": ['mw'],
    "yogaśāstra": ['cae', 'mw'],
    "yogaśāstrapattra": ['mw'],
    "yogaśāstrasūtrapāṭha": ['mw'],
    "yogaśāyin": ['mw'],
    "yogaḥ": ['ap90'],
    "yogaṃdhara": ['mw'],
    "yogena": ['mw'],
    "yogendra": ['mw'],
    "yogeśa": ['mw'],
    "yogeśvara": ['cae', 'ddsa', 'mw'],
    "yogeśvaramantra": ['mw'],
    "yogeśvarapaddhati": ['mw'],
    "yogeśvaratva": ['mw'],
    "yogeśvaratīrtha": ['mw'],
    "yogeśvarī": ['mw'],
    "yogeśārṇava": ['mw'],
    "yogeśīsahasranāmastotra": ['mw'],
    "yogeṣṭa": ['mw'],
    "yogga": ['cped'],
    "yogi": ['mw'],
    "yogibhaṭṭa": ['mw'],
    "yogidaṇḍa": ['mw'],
    "yogimārga": ['mw'],
    "yogimātṛ": ['mw'],
    "yogin": ['ap90', 'cae', 'ddsa', 'mw'],
    "yoginidrā": ['mw'],
    "yoginy": ['mw'],
    "yoginyaṣṭadaśākrama": ['mw'],
    "yoginyādipūjanavidhi": ['mw'],
    "yoginī": ['mw'],
    "yoginībhairavatantra": ['mw'],
    "yoginīcakrapūjana": ['mw'],
    "yoginīdaśā": ['mw'],
    "yoginīdaśācintāmaṇi": ['mw'],
    "yoginīdaśādhyāya": ['mw'],
    "yoginīdaśājñāna": ['mw'],
    "yoginīdaśākrama": ['mw'],
    "yoginīdaśāprakaraṇa": ['mw'],
    "yoginīdaśāvicāra": ['mw'],
    "yoginīhṛdaya": ['mw'],
    "yoginīhṛdayasetubandha": ['mw'],
    "yoginījñānārṇava": ['mw'],
    "yoginījālaśambara": ['mw'],
    "yoginījātaka": ['mw'],
    "yoginīpura": ['mw'],
    "yoginīstavarāja": ['mw'],
    "yoginīsādhana": ['mw'],
    "yoginītantra": ['mw'],
    "yogipatnī": ['mw'],
    "yogirāj": ['ddsa', 'mw'],
    "yogita": ['ap90', 'mw'],
    "yogitva": ['mw'],
    "yogitā": ['cae', 'ddsa', 'mw'],
    "yogiyājñavalkya": ['mw'],
    "yogiā": ['gra'],
    "yogodvahana": ['bhs', 'mw'],
    "yogopadeśa": ['mw'],
    "yogopaniṣad": ['mw'],
    "yogya": ['ap90', 'cae', 'ddsa', 'mw'],
    "yogyatva": ['mw'],
    "yogyatā": ['ap90', 'cae', 'mw'],
    "yogyatāgrantharahasya": ['mw'],
    "yogyatāpūrvapakṣarahasya": ['mw'],
    "yogyatārahasya": ['mw'],
    "yogyatāvicāra": ['mw'],
    "yogyatāvāda": ['mw'],
    "yogyaviśeṣaguṇavicāra": ['mw'],
    "yogyā": ['gra', 'mw'],
    "yogyānupalabdhirahasya": ['mw'],
    "yogyānupalabdhivāda": ['mw'],
    "yogyāratha": ['mw'],
    "yogā": ['mw'],
    "yogābhyāsakrama": ['mw'],
    "yogābhyāsalakṣaṇa": ['mw'],
    "yogābhyāsaprakaraṇa": ['mw'],
    "yogācāra": ['bhs', 'mw'],
    "yogācārabhūmi": ['bhs'],
    "yogācārabhūmiśāstra": ['mw'],
    "yogācārin": ['bhs'],
    "yogācārya": ['cae', 'mw'],
    "yogādhamanavikrīta": ['mw'],
    "yogādhikāra": ['mw'],
    "yogāgnimaya": ['ddsa', 'mw'],
    "yogākhyāna": ['mw'],
    "yogākṣaranighaṇṭu": ['mw'],
    "yogāmbara": ['mw'],
    "yogāmṛta": ['mw'],
    "yogāmṛtataraṃgiṇī": ['mw'],
    "yogānanda": ['mw'],
    "yogānandaprahasana": ['mw'],
    "yogānta": ['mw'],
    "yogāntikā": ['mw'],
    "yogānugatā": ['bhs', 'mw'],
    "yogānuśāsana": ['mw'],
    "yogānuśāsanasūtra": ['mw'],
    "yogānuśāsanasūtravṛtti": ['mw'],
    "yogāpatti": ['mw'],
    "yogāraṅga": ['mw'],
    "yogārūḍha": ['mw'],
    "yogārṇava": ['mw'],
    "yogāsana": ['mw'],
    "yogāsanalakṣaṇa": ['mw'],
    "yogātman": ['cae', 'mw'],
    "yogāvacara": ['cped'],
    "yogāvali": ['mw'],
    "yogāvalī": ['mw'],
    "yogāvalījātaka": ['mw'],
    "yogāvalītantrekuladīpinī": ['mw'],
    "yogāvāpa": ['mw'],
    "yogāya": ['mw'],
    "yogāyoga": ['cae', 'mw'],
    "yogāñjana": ['mw'],
    "yogāṅga": ['mw'],
    "yogī": ['cped'],
    "yogīndra": ['mw'],
    "yogīya": ['mw'],
    "yogīśa": ['mw'],
    "yogīśvara": ['cae', 'mw'],
    "yogīśvarī": ['mw'],
    "yogīṣṭa": ['mw'],
    "yohibhāṣya": ['mw'],
    "yohiśikṣā": ['mw'],
    "yohula": ['mw'],
    "yojaka": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "yojana": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yojanabhāj": ['mw'],
    "yojanabāhu": ['mw'],
    "yojanagandhā": ['mw'],
    "yojanaka": ['mw'],
    "yojananābha": ['bhs'],
    "yojanaparṇī": ['mw'],
    "yojanasahasradarśin": ['bhs'],
    "yojanavallikā": ['mw'],
    "yojanavallī": ['mw'],
    "yojanaśata": ['mw'],
    "yojanaṃ": ['ap90'],
    "yojanika": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "yojanya": ['mw'],
    "yojanā": ['cped', 'mw'],
    "yojanīya": ['ap90', 'cae', 'mw'],
    "yojayitavya": ['cae', 'ddsa', 'mw'],
    "yojayitṛ": ['ap90', 'mw'],
    "yojenta": ['cped'],
    "yojesi": ['cped'],
    "yojeti": ['cped'],
    "yojetvā": ['cped'],
    "yojita": ['cped', 'mw'],
    "yojitṛ": ['mw'],
    "yojiya": ['cped'],
    "yojya": ['cae', 'mw'],
    "yojāpeti": ['cped'],
    "yok": ['mw'],
    "yoktavya": ['cae', 'ddsa', 'mw'],
    "yoktra": ['cae', 'ddsa', 'gra', 'mw'],
    "yoktraka": ['mw'],
    "yoktrapāśa": ['mw'],
    "yoktraraśmi": ['cae'],
    "yoktraya": ['mw'],
    "yoktraṃ": ['ap90'],
    "yoktṛ": ['ap90', 'cae', 'mw'],
    "yonala": ['mw'],
    "yoni": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yonia": ['gra'],
    "yonibhraṃśa": ['mw'],
    "yonicikitsā": ['mw'],
    "yonidevatā": ['mw'],
    "yonideśa": ['mw'],
    "yonidoṣa": ['mw'],
    "yonidoṣacikitsā": ['mw'],
    "yoniduṣṭā": ['mw'],
    "yonidvāra": ['mw'],
    "yonigrantha": ['mw'],
    "yoniguṇa": ['mw'],
    "yonigāna": ['mw'],
    "yoniha": ['mw'],
    "yonija": ['mw'],
    "yonika": ['mw'],
    "yonikuṇḍa": ['mw'],
    "yoniliṅga": ['mw'],
    "yonimantra": ['mw'],
    "yonimat": ['mw'],
    "yonimudrā": ['mw'],
    "yonimukha": ['mw'],
    "yonimukta": ['mw'],
    "yonin": ['mw'],
    "yoniniraya": ['mw'],
    "yonināsā": ['mw'],
    "yonipoṣaṇa": ['mw'],
    "yonirañjana": ['mw'],
    "yoniroga": ['mw'],
    "yonisambandha": ['mw'],
    "yonisambhava": ['mw'],
    "yonisaṃkaluṣa": ['mw'],
    "yonisaṃkara": ['cae', 'mw'],
    "yonisaṃkaṭa": ['mw'],
    "yonisaṃvaraṇa": ['mw'],
    "yonisaṃvṛti": ['mw'],
    "yoniso": ['cped'],
    "yonisomanasikāra": ['cped'],
    "yonitantra": ['mw'],
    "yonitas": ['mw'],
    "yonitva": ['mw'],
    "yonivyāpad": ['mw'],
    "yoniśas": ['bhs', 'mw'],
    "yoniśāstra": ['mw'],
    "yoniḥ": ['ap90'],
    "yoniṣad": ['mw'],
    "yonya": ['cae', 'gra', 'mw'],
    "yonyajāta": ['mw'],
    "yonyarśas": ['mw'],
    "yonānī": ['bhs'],
    "yonī": ['ap90', 'ddsa', 'mw'],
    "yopana": ['gra', 'mw'],
    "yopanaṃ": ['ap90'],
    "yopayat": ['ddsa'],
    "yos": ['cae', 'ddsa', 'gra', 'mw'],
    "yosa": ['bhs'],
    "yotave": ['mw'],
    "yotimatsaka": ['mw'],
    "yotra": ['cae', 'mw'],
    "yotrapramāda": ['mw'],
    "yotraṃ": ['ap90'],
    "yotta": ['cped'],
    "yotu": ['mw'],
    "yotuḥ": ['ap90'],
    "yotṛ": ['gra'],
    "yoyupana": ['mw'],
    "yoṇikā": ['bhs'],
    "yoṣan": ['cae', 'gra', 'mw'],
    "yoṣaṇā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yoṣid": ['mw'],
    "yoṣidgrāha": ['mw'],
    "yoṣidratna": ['mw'],
    "yoṣijjana": ['ddsa', 'mw'],
    "yoṣinmaya": ['mw'],
    "yoṣit": ['cae', 'ddsa', 'gra', 'mw'],
    "yoṣitkṛta": ['mw'],
    "yoṣitpratiyātanā": ['mw'],
    "yoṣitpriyā": ['mw'],
    "yoṣitsarpā": ['mw'],
    "yoṣitvā": ['mw'],
    "yoṣitā": ['mw'],
    "yoṣā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yoṭaka": ['mw'],
    "yoṭakaḥ": ['ap90'],
    "yu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yuch": ['cae', 'ddsa', 'mw'],
    "yud": ['mw'],
    "yudbhū": ['mw'],
    "yudbhūmi": ['mw'],
    "yuddha": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "yuddhabhū": ['cae', 'mw'],
    "yuddhabhūmi": ['cae', 'cped', 'mw'],
    "yuddhacintāmaṇi": ['mw'],
    "yuddhadharma": ['mw'],
    "yuddhadhvāna": ['mw'],
    "yuddhadyūta": ['mw'],
    "yuddhagāndharva": ['mw'],
    "yuddhajayaprakāśa": ['mw'],
    "yuddhajayopāya": ['mw'],
    "yuddhajayotsava": ['mw'],
    "yuddhajayārṇava": ['mw'],
    "yuddhajit": ['mw'],
    "yuddhaka": ['mw'],
    "yuddhakauśala": ['mw'],
    "yuddhakutūhala": ['mw'],
    "yuddhakāla": ['mw'],
    "yuddhakārin": ['mw'],
    "yuddhakāritva": ['mw'],
    "yuddhakāṇḍa": ['mw'],
    "yuddhakīrti": ['mw'],
    "yuddhakṣmā": ['mw'],
    "yuddhamaya": ['mw'],
    "yuddhamaṇḍala": ['cped'],
    "yuddhamedinī": ['mw'],
    "yuddhamuṣṭi": ['mw'],
    "yuddhamārga": ['mw'],
    "yuddhaparipāṭī": ['mw'],
    "yuddhaparāṅmukha": ['mw'],
    "yuddhapravīṇa": ['mw'],
    "yuddhapurī": ['mw'],
    "yuddhapurīmāhātmya": ['mw'],
    "yuddharatnasvara": ['mw'],
    "yuddharatnāvalī": ['mw'],
    "yuddharaṅga": ['mw'],
    "yuddhasāra": ['mw'],
    "yuddhasūkta": ['mw'],
    "yuddhatantra": ['mw'],
    "yuddhavarṇa": ['mw'],
    "yuddhavastu": ['mw'],
    "yuddhavat": ['mw'],
    "yuddhavidyā": ['mw'],
    "yuddhavinoda": ['mw'],
    "yuddhaviśārada": ['cae', 'mw'],
    "yuddhavyatikrama": ['mw'],
    "yuddhavīra": ['mw'],
    "yuddhayogya": ['mw'],
    "yuddhayogyatā": ['mw'],
    "yuddhayojaka": ['mw'],
    "yuddhaśakti": ['mw'],
    "yuddhaśauṭīratā": ['mw'],
    "yuddhaśālin": ['cae', 'mw'],
    "yuddhodyama": ['mw'],
    "yuddhodyoga": ['mw'],
    "yuddhonmatta": ['mw'],
    "yuddhopakaraṇa": ['mw'],
    "yuddhācārya": ['cae', 'mw'],
    "yuddhādhvan": ['mw'],
    "yuddhāji": ['mw'],
    "yuddhānivartin": ['mw'],
    "yuddhārthin": ['mw'],
    "yuddhāvahārika": ['mw'],
    "yuddhāvasāna": ['mw'],
    "yudh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yudhaye": ['ddsa'],
    "yudhenia": ['gra'],
    "yudhenya": ['gra', 'mw'],
    "yudhi": ['mw'],
    "yudhika": ['mw'],
    "yudhiṃgama": ['mw'],
    "yudhiṣṭhira": ['bhs', 'cae', 'ddsa', 'mw'],
    "yudhiṣṭhiravijaya": ['mw'],
    "yudhiṣṭhiraḥ": ['ap90'],
    "yudhma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yudhvan": ['cae', 'ddsa', 'gra', 'mw'],
    "yudhvin": ['gra'],
    "yudhya": ['gra'],
    "yudhyāmadhi": ['gra', 'mw'],
    "yudhā": ['mw'],
    "yudhāji": ['mw'],
    "yudhājit": ['ap90', 'ddsa', 'mw'],
    "yudhājīva": ['mw'],
    "yudhāmanyu": ['cae', 'mw'],
    "yudhāna": ['mw'],
    "yudhānaḥ": ['ap90'],
    "yudhāsura": ['mw'],
    "yudhāṃśrauṣṭi": ['mw'],
    "yuga": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yugabhaṅga": ['mw'],
    "yugabāhu": ['mw'],
    "yugacarman": ['mw'],
    "yugacchidda": ['cped'],
    "yugacchidra": ['mw'],
    "yugadhur": ['mw'],
    "yugadhāra": ['cae', 'mw'],
    "yugadīrgha": ['mw'],
    "yugaggāha": ['cped'],
    "yugaggāhī": ['cped'],
    "yugakīlaka": ['mw'],
    "yugakṣaya": ['cae', 'ddsa', 'mw'],
    "yugala": ['cae', 'cped', 'ddsa', 'mw'],
    "yugalabhakta": ['mw'],
    "yugalaja": ['mw'],
    "yugalaka": ['cae', 'mw'],
    "yugalakaṃ": ['ap90'],
    "yugalakiśorasahasranāmastotra": ['mw'],
    "yugalakiśorastotra": ['mw'],
    "yugalalaka": ['cped'],
    "yugalasahasranāman": ['mw'],
    "yugalaṃ": ['ap90'],
    "yugalin": ['mw'],
    "yugalākhya": ['mw'],
    "yugalākṣa": ['mw'],
    "yugalāya": ['ddsa', 'mw'],
    "yugalāyita": ['mw'],
    "yugamatta": ['cped'],
    "yugamātra": ['cae', 'mw'],
    "yugamātradarśin": ['mw'],
    "yugamātradṛś": ['mw'],
    "yugamātraprekṣin": ['mw'],
    "yuganaddha": ['cped'],
    "yuganandha": ['cped'],
    "yugandhara": ['cped'],
    "yuganta": ['cped'],
    "yugapa": ['mw'],
    "yugapad": ['ap90', 'cae', 'mw'],
    "yugapadbhāva": ['mw'],
    "yugapatkarman": ['mw'],
    "yugapatkāla": ['mw'],
    "yugapatprāpti": ['mw'],
    "yugapattra": ['mw'],
    "yugapattraka": ['mw'],
    "yugapattrikā": ['mw'],
    "yugapradhāna": ['mw'],
    "yugapradhānapaṭṭāvalīsūtra": ['mw'],
    "yugapradhānasvarūpa": ['mw'],
    "yugapramāṇa": ['mw'],
    "yugapurāṇa": ['mw'],
    "yugapārśvaga": ['mw'],
    "yugapārśvaka": ['mw'],
    "yugasahasrāya": ['mw'],
    "yugasaṃvatsara": ['mw'],
    "yugat": ['mw'],
    "yugavaratra": ['mw'],
    "yugavyāvat": ['mw'],
    "yugavyāyatabāhu": ['ddsa', 'mw'],
    "yugaśamya": ['cae', 'mw'],
    "yugaśaram": ['cae', 'mw'],
    "yugaḍa": ['bhs'],
    "yugaṃ": ['ap90'],
    "yugaṃdhara": ['bhs', 'cae', 'mw'],
    "yugaṃdharaḥ": ['ap90'],
    "yugeśa": ['mw'],
    "yugin": ['mw'],
    "yugma": ['ap90', 'cae', 'ddsa', 'mw'],
    "yugmacārin": ['mw'],
    "yugmadayuja": ['mw'],
    "yugmadharman": ['mw'],
    "yugmaja": ['mw'],
    "yugmajananaśānti": ['mw'],
    "yugmajanman": ['mw'],
    "yugmaka": ['ap90', 'cae', 'mw'],
    "yugmakṛṣṇala": ['mw'],
    "yugmalāṅgalin": ['mw'],
    "yugman": ['cae', 'mw'],
    "yugmant": ['cae'],
    "yugmaparṇa": ['mw'],
    "yugmapattra": ['mw'],
    "yugmapattrikā": ['mw'],
    "yugmaphalottama": ['mw'],
    "yugmaphalā": ['mw'],
    "yugmat": ['mw'],
    "yugmavipulā": ['mw'],
    "yugmaśukra": ['mw'],
    "yugmin": ['mw'],
    "yugmāpatyā": ['mw'],
    "yugorasya": ['ddsa', 'mw'],
    "yugotpāda": ['bhs'],
    "yugvan": ['gra', 'mw'],
    "yugya": ['ap90', 'cae', 'ddsa', 'mw'],
    "yugyastha": ['cae', 'mw'],
    "yugyavāha": ['cae', 'mw'],
    "yugyāśanapraseva": ['mw'],
    "yugādhyakṣa": ['mw'],
    "yugādi": ['cae', 'ddsa', 'mw'],
    "yugādideva": ['mw'],
    "yugādijina": ['mw'],
    "yugādikṛt": ['mw'],
    "yugādipuruṣa": ['mw'],
    "yugādyā": ['mw'],
    "yugādīśa": ['mw'],
    "yugānta": ['cae', 'mw'],
    "yugāntabandhu": ['mw'],
    "yugāntaka": ['mw'],
    "yugāntara": ['cae', 'mw'],
    "yugāntāgni": ['mw'],
    "yugāvadhi": ['mw'],
    "yugāya": ['ddsa', 'mw'],
    "yugāṃśaka": ['mw'],
    "yuj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yuja": ['gra', 'mw'],
    "yuje": ['cae'],
    "yujia": ['gra'],
    "yujjhamāna": ['cped'],
    "yujjhana": ['cped'],
    "yujjhanta": ['cped'],
    "yujjhati": ['cped'],
    "yujjhi": ['cped'],
    "yujjhita": ['cped'],
    "yujjhitukāma": ['cped'],
    "yujjhituṁ": ['cped'],
    "yujjhitvā": ['cped'],
    "yujjhiya": ['cped'],
    "yujya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yujāna": ['ddsa'],
    "yuk": ['mw'],
    "yukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "yuktaaśva": ['gra'],
    "yuktaceṣṭa": ['cae', 'mw'],
    "yuktadaṇḍa": ['mw'],
    "yuktadaṇḍatā": ['mw'],
    "yuktagrāvan": ['cae', 'gra', 'mw'],
    "yuktaka": ['ddsa', 'mw'],
    "yuktakarman": ['mw'],
    "yuktakarmatā": ['mw'],
    "yuktakārin": ['mw'],
    "yuktakṛt": ['mw'],
    "yuktam": ['mw'],
    "yuktamada": ['cae', 'mw'],
    "yuktamanas": ['mw'],
    "yuktamāṃsala": ['mw'],
    "yuktarasā": ['mw'],
    "yuktaratha": ['mw'],
    "yuktarāsnā": ['mw'],
    "yuktarūpa": ['cae', 'mw'],
    "yuktarūpaka": ['cae', 'mw'],
    "yuktarūpam": ['mw'],
    "yuktasena": ['mw'],
    "yuktasenīya": ['mw'],
    "yuktasvapnāvabodha": ['mw'],
    "yuktatama": ['mw'],
    "yuktatara": ['mw'],
    "yuktatva": ['mw'],
    "yuktavat": ['mw'],
    "yuktavādin": ['mw'],
    "yuktayoga": ['mw'],
    "yuktaśītoṣṇa": ['mw'],
    "yukti": ['cae', 'ddsa', 'gra', 'mw'],
    "yuktibhis": ['mw'],
    "yuktibhāṣā": ['mw'],
    "yuktibāhya": ['mw'],
    "yuktidīpikā": ['mw'],
    "yuktijña": ['mw'],
    "yuktikalpataru": ['mw'],
    "yuktikara": ['ddsa', 'mw'],
    "yuktikathana": ['mw'],
    "yuktikṛta": ['mw'],
    "yuktimallikā": ['mw'],
    "yuktimant": ['cae'],
    "yuktimat": ['ap90', 'mw'],
    "yuktimattva": ['mw'],
    "yuktimuktāvalī": ['mw'],
    "yuktimālikā": ['mw'],
    "yuktiprakāśa": ['mw'],
    "yuktiratnamālā": ['mw'],
    "yuktisnehaprapūraṇī": ['mw'],
    "yuktitas": ['mw'],
    "yuktitaḥ": ['ap90'],
    "yuktiyukta": ['mw'],
    "yuktiśāstra": ['mw'],
    "yuktiḥ": ['ap90'],
    "yuktyā": ['mw'],
    "yuktā": ['mw'],
    "yuktāhāravihāra": ['mw'],
    "yuktārohin": ['mw'],
    "yuktārtha": ['cae', 'mw'],
    "yuktātman": ['cae', 'mw'],
    "yuktāyas": ['mw'],
    "yuktāyukta": ['mw'],
    "yuktāśva": ['gra', 'mw'],
    "yunth": ['mw'],
    "yup": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yupita": ['mw'],
    "yut": ['ap90', 'mw'],
    "yuta": ['ap90', 'cae', 'ddsa', 'mw'],
    "yutadveṣas": ['gra', 'mw'],
    "yutaka": ['ap90', 'mw'],
    "yuti": ['cae', 'ddsa', 'mw'],
    "yutiḥ": ['ap90'],
    "yutkāra": ['cae', 'gra', 'mw'],
    "yutta": ['cped'],
    "yuttabhāva": ['cped'],
    "yuttaka": ['cped'],
    "yuttakārī": ['cped'],
    "yutti": ['cped'],
    "yuttito": ['cped'],
    "yuva": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yuvaddevatya": ['mw'],
    "yuvadhita": ['gra', 'mw'],
    "yuvadrik": ['ddsa', 'gra', 'mw'],
    "yuvagaṇḍa": ['mw'],
    "yuvahan": ['mw'],
    "yuvajarat": ['mw'],
    "yuvajāni": ['gra', 'mw'],
    "yuvaka": ['ddsa', 'mw'],
    "yuvakhalati": ['mw'],
    "yuvakhalatī": ['mw'],
    "yuvamārin": ['mw'],
    "yuvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yuvana": ['mw'],
    "yuvant": ['cae'],
    "yuvanyu": ['cae', 'gra', 'mw'],
    "yuvanāśva": ['ddsa', 'mw'],
    "yuvanāśvaja": ['mw'],
    "yuvapalita": ['mw'],
    "yuvapratyaya": ['ddsa', 'mw'],
    "yuvarāja": ['cae', 'mw'],
    "yuvarājadivākara": ['mw'],
    "yuvarājan": ['mw'],
    "yuvarājatva": ['cae', 'mw'],
    "yuvarājya": ['cae', 'mw'],
    "yuvasena": ['mw'],
    "yuvat": ['ddsa', 'gra', 'mw'],
    "yuvati": ['cae', 'ddsa', 'gra', 'mw'],
    "yuvatidā": ['mw'],
    "yuvatijana": ['mw'],
    "yuvatiḥ": ['ap90'],
    "yuvatva": ['mw'],
    "yuvatā": ['ddsa', 'mw'],
    "yuvatī": ['cae', 'cped', 'mw'],
    "yuvatījana": ['mw'],
    "yuvatīsambhogakāra": ['mw'],
    "yuvatīsārtha": ['mw'],
    "yuvatīṣṭā": ['mw'],
    "yuvavalina": ['mw'],
    "yuvayu": ['cae', 'gra', 'mw'],
    "yuvaśa": ['cae', 'ddsa', 'gra', 'mw'],
    "yuvā": ['mw'],
    "yuvādatta": ['gra', 'mw'],
    "yuvāku": ['cae', 'ddsa', 'gra', 'mw'],
    "yuvām": ['ddsa'],
    "yuvāma": ['mw'],
    "yuvānaka": ['ddsa', 'mw'],
    "yuvānīta": ['gra', 'mw'],
    "yuvāvat": ['gra', 'mw'],
    "yuvāyu": ['gra', 'mw'],
    "yuvāyuj": ['gra', 'mw'],
    "yuvībhū": ['ddsa'],
    "yuvībhūta": ['mw'],
    "yuyu": ['mw'],
    "yuyudhan": ['mw'],
    "yuyudhi": ['ddsa', 'gra', 'mw'],
    "yuyudhāna": ['cae', 'ddsa', 'mw'],
    "yuyudhānaḥ": ['ap90'],
    "yuyujānasapti": ['gra', 'mw'],
    "yuyukkhura": ['mw'],
    "yuyutsu": ['ap90', 'cae', 'mw'],
    "yuyutsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "yuyutsārahita": ['mw'],
    "yuyuvi": ['mw'],
    "yuyuḥ": ['ap90'],
    "yuñj": ['cae', 'ddsa'],
    "yuñjaka": ['mw'],
    "yuñjamāna": ['cped'],
    "yuñjana": ['cped'],
    "yuñjanda": ['mw'],
    "yuñjanta": ['cped'],
    "yuñjati": ['cped'],
    "yuñjavat": ['mw'],
    "yuñji": ['cped'],
    "yuñjitabba": ['cped'],
    "yuñjitvā": ['cped'],
    "yuñjāna": ['mw'],
    "yuñjānaka": ['mw'],
    "yuṃjāna": ['ap90'],
    "yuṅg": ['mw'],
    "yuṅga": ['mw'],
    "yuṅgin": ['cae', 'mw'],
    "yuṣma": ['cae', 'ddsa', 'gra', 'mw'],
    "yuṣmad": ['ap90', 'mw'],
    "yuṣmadartham": ['mw'],
    "yuṣmadvidha": ['cae', 'mw'],
    "yuṣmadvācya": ['mw'],
    "yuṣmadāyatta": ['mw'],
    "yuṣmadīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "yuṣmat": ['ddsa', 'mw'],
    "yuṣmattas": ['mw'],
    "yuṣmaya": ['mw'],
    "yuṣmayat": ['gra'],
    "yuṣmeṣita": ['cae', 'ddsa', 'gra', 'mw'],
    "yuṣmota": ['cae', 'gra', 'mw'],
    "yuṣmā": ['mw'],
    "yuṣmādatta": ['cae', 'gra', 'mw'],
    "yuṣmādṛś": ['ap90', 'cae', 'ddsa', 'mw'],
    "yuṣmādṛśa": ['cae', 'mw'],
    "yuṣmāka": ['cae', 'ddsa', 'gra', 'mw'],
    "yuṣmānīta": ['cae', 'ddsa', 'gra', 'mw'],
    "yuṣmāvant": ['cae'],
    "yuṣmāvat": ['gra', 'mw'],
    "yuṣṭagrāma": ['ddsa', 'mw'],
    "yvāgulyā": ['mw'],
    "yvāgulī": ['mw'],
    "yvāgū": ['bhs'],
    "yā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yābha": ['cae', 'mw'],
    "yābhavat": ['mw'],
    "yābhaḥ": ['ap90'],
    "yābhis": ['ddsa', 'mw'],
    "yāc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yācaka": ['cae', 'cped', 'ddsa', 'mw'],
    "yācakavṛtti": ['mw'],
    "yācakaḥ": ['ap90'],
    "yācakī": ['mw'],
    "yācamāna": ['cped'],
    "yācana": ['cae', 'cped', 'mw'],
    "yācanaka": ['bhs', 'cae', 'cped', 'mw'],
    "yācanakaḥ": ['ap90'],
    "yācanatā": ['bhs'],
    "yācanaṃ": ['ap90'],
    "yācanta": ['cped'],
    "yācanā": ['mw'],
    "yācanīya": ['cae', 'mw'],
    "yācati": ['cped'],
    "yācayoga": ['cped'],
    "yācchreṣṭa": ['gra'],
    "yācchreṣṭha": ['mw'],
    "yāci": ['cped', 'mw'],
    "yācikā": ['cped', 'mw'],
    "yācin": ['cae', 'mw'],
    "yācita": ['ap90', 'bhs', 'cped', 'mw'],
    "yācitaka": ['mw'],
    "yācitakaṃ": ['ap90'],
    "yācitavya": ['cae', 'mw'],
    "yācituṁ": ['cped'],
    "yācitvā": ['cped'],
    "yācitṛ": ['ap90', 'cae', 'mw'],
    "yāciṣṇu": ['ap90', 'cae', 'mw'],
    "yāciṣṇutā": ['mw'],
    "yācya": ['cae', 'ddsa', 'mw'],
    "yācyatā": ['mw'],
    "yācyaṃ": ['ap90'],
    "yācñya": ['cae', 'mw'],
    "yācñā": ['ap90', 'cae', 'ddsa', 'mw'],
    "yācñābhaṅga": ['mw'],
    "yācñājīvana": ['mw'],
    "yācñāprāpta": ['mw'],
    "yācñāvacas": ['mw'],
    "yād": ['cae', 'ddsa', 'gra', 'mw'],
    "yāda": ['mw'],
    "yādas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yādaspati": ['mw'],
    "yādava": ['cae', 'ddsa', 'mw'],
    "yādavacampū": ['mw'],
    "yādavagiri": ['mw'],
    "yādavagirimāhātmya": ['mw'],
    "yādavaka": ['mw'],
    "yādavakośa": ['mw'],
    "yādavapaṇḍita": ['mw'],
    "yādavaprakāśa": ['mw'],
    "yādavaprakāśasvāmin": ['mw'],
    "yādavaputra": ['mw'],
    "yādavarāghavapāṇḍavīya": ['mw'],
    "yādavarāghavīya": ['mw'],
    "yādavarāya": ['mw'],
    "yādavavyāsa": ['mw'],
    "yādavaśārdūla": ['cae', 'mw'],
    "yādavaḥ": ['ap90'],
    "yādavendra": ['cae', 'mw'],
    "yādavodaya": ['mw'],
    "yādavābhyudaya": ['mw'],
    "yādavācārya": ['mw'],
    "yādavī": ['mw'],
    "yādavīputra": ['mw'],
    "yādaīśa": ['mw'],
    "yādaḥ": ['mw'],
    "yādaḥpati": ['mw'],
    "yādisa": ['cped'],
    "yādisasaka": ['cped'],
    "yādo": ['mw'],
    "yādonivāsa": ['mw'],
    "yādonātha": ['ddsa', 'mw'],
    "yādrādhia": ['gra'],
    "yādrādhya": ['gra'],
    "yādrādhyam": ['cae', 'ddsa', 'mw'],
    "yādu": ['mw'],
    "yādua": ['gra'],
    "yādura": ['cae', 'ddsa', 'gra', 'mw'],
    "yāduḥ": ['ap90'],
    "yādva": ['cae', 'ddsa', 'gra', 'mw'],
    "yādāyani": ['mw'],
    "yādṛcchika": ['ap90', 'cae', 'ddsa', 'mw'],
    "yādṛg": ['mw'],
    "yādṛgguṇa": ['cae', 'ddsa', 'mw'],
    "yādṛkṣa": ['ap90', 'mw'],
    "yādṛś": ['cae', 'ddsa', 'gra', 'mw'],
    "yādṛśa": ['bhs', 'cae', 'mw'],
    "yādṛśaka": ['bhs'],
    "yāga": ['cae', 'cped', 'ddsa', 'mw'],
    "yāgakarman": ['mw'],
    "yāgakaṇṭaka": ['mw'],
    "yāgakāla": ['mw'],
    "yāgamaya": ['mw'],
    "yāgamaṇḍapa": ['mw'],
    "yāgasampradāna": ['mw'],
    "yāgasaṃtāna": ['mw'],
    "yāgasūtra": ['mw'],
    "yāgaḥ": ['ap90'],
    "yāgu": ['bhs', 'cped'],
    "yāj": ['cae', 'ddsa', 'mw'],
    "yāja": ['cae', 'gra', 'mw'],
    "yājaka": ['cae', 'cped', 'mw'],
    "yājakatva": ['mw'],
    "yājakaḥ": ['ap90'],
    "yājamāna": ['mw'],
    "yājamānaṃ": ['ap90'],
    "yājamānika": ['mw'],
    "yājana": ['cae', 'mw'],
    "yājanapratigraha": ['mw'],
    "yājanaṃ": ['ap90'],
    "yājanīya": ['mw'],
    "yājayitṛ": ['ap90', 'mw'],
    "yājaḥ": ['ap90'],
    "yāji": ['mw'],
    "yājikā": ['mw'],
    "yājin": ['ap90', 'cae', 'mw'],
    "yājiḥ": ['ap90'],
    "yājuka": ['mw'],
    "yājurvaidika": ['mw'],
    "yājurvedika": ['ddsa', 'mw'],
    "yājuṣa": ['ap90', 'ddsa', 'mw'],
    "yājuṣmata": ['mw'],
    "yājuṣmatī": ['mw'],
    "yājvana": ['mw'],
    "yājvanaḥ": ['ap90'],
    "yājya": ['ap90', 'cae', 'ddsa', 'mw'],
    "yājyatva": ['mw'],
    "yājyatā": ['mw'],
    "yājyavat": ['mw'],
    "yājyā": ['mw'],
    "yājyāvat": ['mw'],
    "yājña": ['cae', 'ddsa', 'mw'],
    "yājñadatta": ['mw'],
    "yājñadattaka": ['mw'],
    "yājñadatti": ['mw'],
    "yājñadeva": ['mw'],
    "yājñapata": ['mw'],
    "yājñasena": ['cae', 'mw'],
    "yājñasenī": ['ap90', 'mw'],
    "yājñatura": ['mw'],
    "yājñavalka": ['mw'],
    "yājñavalkya": ['cae', 'mw'],
    "yājñavalkyadharmaśāstra": ['mw'],
    "yājñavalkyagītā": ['mw'],
    "yājñavalkyamahimavarṇana": ['mw'],
    "yājñavalkyasmṛti": ['mw'],
    "yājñavalkyayoga": ['mw'],
    "yājñavalkyaśikṣā": ['mw'],
    "yājñavalkyaḥ": ['ap90'],
    "yājñavalkyaṭīkā": ['mw'],
    "yājñavalkyopaniṣad": ['mw'],
    "yājñavalkīya": ['mw'],
    "yājñavalkīyadharmaśāstranibandha": ['mw'],
    "yājñavalkīyakāṇḍa": ['mw'],
    "yājñika": ['ap90', 'cae', 'ddsa', 'mw'],
    "yājñikadeva": ['mw'],
    "yājñikakitava": ['mw'],
    "yājñikanātha": ['mw'],
    "yājñikapaddhati": ['mw'],
    "yājñikasarvasva": ['mw'],
    "yājñikavallabhā": ['mw'],
    "yājñikya": ['cae', 'mw'],
    "yājñikyaka": ['mw'],
    "yājñikyupaniṣad": ['mw'],
    "yājñikānanta": ['mw'],
    "yājñikāśraya": ['mw'],
    "yājñikāśva": ['mw'],
    "yājñiya": ['ap90', 'cae', 'mw'],
    "yājñāyani": ['mw'],
    "yājñīya": ['mw'],
    "yājñīyamantra": ['mw'],
    "yājñīyamantraṭīkā": ['mw'],
    "yākṛlloma": ['mw'],
    "yākṛtka": ['mw'],
    "yākṣa": ['ddsa', 'mw'],
    "yāma": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yāmabhadra": ['ddsa', 'mw'],
    "yāmaceṭī": ['ddsa', 'mw'],
    "yāmadundubhi": ['mw'],
    "yāmadūta": ['mw'],
    "yāmaghoṣa": ['mw'],
    "yāmagupta": ['bhs'],
    "yāmahū": ['cae', 'gra', 'mw'],
    "yāmahūti": ['cae', 'gra', 'mw'],
    "yāmaka": ['ap90', 'mw'],
    "yāmakakareṇukā": ['ddsa', 'mw'],
    "yāmakakuñjara": ['mw'],
    "yāmakareṇukā": ['ddsa', 'mw'],
    "yāmakinī": ['ddsa', 'mw'],
    "yāmakośa": ['gra', 'mw'],
    "yāmakuñjara": ['mw'],
    "yāmakālika": ['cped'],
    "yāmala": ['mw'],
    "yāmalasāra": ['mw'],
    "yāmalaṃ": ['ap90'],
    "yāmalokika": ['bhs'],
    "yāmalānusāripraśna": ['mw'],
    "yāmalāyana": ['mw'],
    "yāmalāṣṭakatantra": ['mw'],
    "yāmalīya": ['mw'],
    "yāmamātra": ['mw'],
    "yāman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yāmanemi": ['mw'],
    "yāmanādin": ['mw'],
    "yāmanālī": ['mw'],
    "yāmaratha": ['mw'],
    "yāmastamberama": ['mw'],
    "yāmatūrya": ['mw'],
    "yāmavatī": ['ap90', 'mw'],
    "yāmavṛtti": ['mw'],
    "yāmayama": ['mw'],
    "yāmaśruta": ['cae', 'gra', 'mw'],
    "yāmaḥ": ['ap90'],
    "yāmeya": ['mw'],
    "yāmeyaḥ": ['ap90'],
    "yāmi": ['cae', 'ddsa', 'mw'],
    "yāmika": ['bhs', 'cae', 'ddsa', 'mw'],
    "yāmikabhaṭa": ['mw'],
    "yāmikasthita": ['mw'],
    "yāmikatā": ['mw'],
    "yāmikaḥ": ['ap90'],
    "yāmikā": ['ap90', 'bhs', 'mw'],
    "yāmin": ['mw'],
    "yāminaya": ['mw'],
    "yāminayati": ['ap90'],
    "yāminī": ['bhs', 'cae', 'ddsa', 'mw'],
    "yāminīdayita": ['mw'],
    "yāminīnātha": ['mw'],
    "yāminīpati": ['mw'],
    "yāminīpriyatama": ['mw'],
    "yāminīpūrṇatilakā": ['mw'],
    "yāminīramaṇa": ['mw'],
    "yāminīvirahin": ['mw'],
    "yāminīśa": ['mw'],
    "yāmitra": ['mw'],
    "yāmiḥ": ['ap90'],
    "yāmottara": ['mw'],
    "yāmuna": ['ap90', 'ddsa', 'mw'],
    "yāmunastutiṭīkā": ['mw'],
    "yāmundāyani": ['mw'],
    "yāmundāyanika": ['mw'],
    "yāmundāyanīya": ['mw'],
    "yāmuneṣṭaka": ['mw'],
    "yāmuneṣṭakaṃ": ['ap90'],
    "yāmunācārya": ['mw'],
    "yāmunācāryastotra": ['mw'],
    "yāmya": ['ap90', 'cae', 'ddsa', 'mw'],
    "yāmyapāśa": ['mw'],
    "yāmyasattvavat": ['mw'],
    "yāmyatas": ['mw'],
    "yāmyatīrtha": ['mw'],
    "yāmye": ['mw'],
    "yāmyena": ['mw'],
    "yāmyodbhūta": ['mw'],
    "yāmyottara": ['cae', 'mw'],
    "yāmyottaravṛtta": ['mw'],
    "yāmyottarāyata": ['mw'],
    "yāmyā": ['ap90', 'bhs', 'mw'],
    "yāmyāyana": ['mw'],
    "yāmātṛ": ['mw'],
    "yāmātṛka": ['mw'],
    "yāmāvasthita": ['mw'],
    "yāmāyana": ['mw'],
    "yāmī": ['cae', 'mw'],
    "yāmīra": ['mw'],
    "yāmīraḥ": ['ap90'],
    "yāmīrā": ['mw'],
    "yāna": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yānabhaṅga": ['cae', 'mw'],
    "yānabhūmi": ['cped'],
    "yānaga": ['cae', 'mw'],
    "yānagata": ['cped'],
    "yānaka": ['cae', 'cped', 'ddsa', 'mw'],
    "yānakara": ['cae', 'mw'],
    "yānakaṃ": ['ap90'],
    "yānamukha": ['mw'],
    "yānapātra": ['cae', 'mw'],
    "yānapātraka": ['bhs', 'mw'],
    "yānapātrika": ['bhs'],
    "yānapātrikā": ['mw'],
    "yānasvāmin": ['cae', 'mw'],
    "yānavat": ['mw'],
    "yānayāna": ['mw'],
    "yānayātrā": ['bhs', 'mw'],
    "yānaśayyāsanāśana": ['mw'],
    "yānaśālā": ['mw'],
    "yānaṃ": ['ap90'],
    "yānika": ['bhs'],
    "yānin": ['bhs'],
    "yāntaka": ['bhs'],
    "yāntrika": ['mw'],
    "yānāsana": ['cae', 'mw'],
    "yānāstaraṇa": ['cae', 'mw'],
    "yānāti": ['bhs'],
    "yānī": ['cped', 'mw'],
    "yānīkata": ['cped'],
    "yānīkṛ": ['mw'],
    "yānīkṛta": ['bhs'],
    "yānīya": ['bhs'],
    "yāpa": ['mw'],
    "yāpaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "yāpana": ['ap90', 'cae', 'cped', 'mw'],
    "yāpanaka": ['bhs'],
    "yāpananīya": ['cped'],
    "yāpanīya": ['bhs', 'mw'],
    "yāpanīyaka": ['mw'],
    "yāpanīyatara": ['mw'],
    "yāpayati": ['bhs'],
    "yāpayitavya": ['mw'],
    "yāpenta": ['cped'],
    "yāpesi": ['cped'],
    "yāpeti": ['cped'],
    "yāpetvā": ['cped'],
    "yāpita": ['ap90', 'cped', 'mw'],
    "yāptā": ['ap90', 'mw'],
    "yāpya": ['ap90', 'cae', 'mw'],
    "yāpyatva": ['mw'],
    "yāpyayāna": ['mw'],
    "yārkāyaṇa": ['mw'],
    "yās": ['cae', 'mw'],
    "yāsa": ['cae', 'mw'],
    "yāsaka": ['mw'],
    "yāsaśarkarā": ['mw'],
    "yāsaḥ": ['ap90'],
    "yāska": ['cae', 'ddsa', 'mw'],
    "yāskanirukta": ['mw'],
    "yāskaḥ": ['ap90'],
    "yāskāyani": ['mw'],
    "yāskāyanīya": ['mw'],
    "yāskī": ['mw'],
    "yāskīya": ['mw'],
    "yāsā": ['mw'],
    "yāsīṣṭa": ['ddsa'],
    "yāt": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "yāta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "yātaka": ['bhs'],
    "yātalarāya": ['mw'],
    "yātana": ['cae', 'ddsa', 'mw'],
    "yātanaṃ": ['ap90'],
    "yātanā": ['mw'],
    "yātanāgṛha": ['mw'],
    "yātanārthīya": ['cae', 'mw'],
    "yātasruca": ['mw'],
    "yātave": ['cae', 'ddsa'],
    "yātavya": ['cae', 'ddsa', 'mw'],
    "yātavyapakṣa": ['cae'],
    "yātavyatā": ['mw'],
    "yātavyāya": ['mw'],
    "yātayajjana": ['cae', 'ddsa', 'gra', 'mw'],
    "yātayāma": ['cae', 'mw'],
    "yātayāman": ['cae', 'mw'],
    "yātayāmatva": ['mw'],
    "yātaūtīya": ['mw'],
    "yātha": ['gra', 'mw'],
    "yāthā": ['mw'],
    "yāthākathāca": ['mw'],
    "yāthākathācaṃ": ['ap90'],
    "yāthākāmya": ['ddsa', 'mw'],
    "yāthākāmī": ['ap90', 'cae', 'mw'],
    "yāthārthika": ['ap90', 'mw'],
    "yāthārthya": ['ddsa', 'mw'],
    "yāthārthyaṃ": ['ap90'],
    "yāthāsaṃstarika": ['bhs', 'mw'],
    "yāthātathya": ['cae', 'mw'],
    "yāthātathyam": ['mw'],
    "yāthātathyatas": ['mw'],
    "yāthātathyaṃ": ['ap90'],
    "yāthātathyena": ['mw'],
    "yāthātmya": ['ddsa', 'mw'],
    "yāthāva": ['cped'],
    "yāthāvatas": ['bhs'],
    "yāthāvato": ['cped'],
    "yāti": ['cped', 'mw'],
    "yātika": ['mw'],
    "yātmyāma, yātayāman": ['ddsa'],
    "yātnika": ['mw'],
    "yātopayāta": ['mw'],
    "yātopayātika": ['mw'],
    "yātrika": ['ap90', 'cae', 'ddsa', 'mw'],
    "yātrin": ['cae', 'mw'],
    "yātrotsava": ['cae', 'ddsa', 'mw'],
    "yātrā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "yātrāgamana": ['mw'],
    "yātrākara": ['mw'],
    "yātrākaraṇa": ['mw'],
    "yātrākāra": ['mw'],
    "yātrāmahotsava": ['mw'],
    "yātrāmaṅgala": ['mw'],
    "yātrāphala": ['mw'],
    "yātrāprabandha": ['mw'],
    "yātrāprakaraṇa": ['mw'],
    "yātrāprakaraṇaṭīkā": ['mw'],
    "yātrāprasaṅga": ['mw'],
    "yātrārtham": ['mw'],
    "yātrāsaṃdhāna": ['mw'],
    "yātrāśiromaṇi": ['mw'],
    "yātrāśrāddha": ['mw'],
    "yātsatra": ['cae'],
    "yātsattra": ['mw'],
    "yātu": ['cae', 'ddsa', 'gra', 'mw'],
    "yātucātana": ['mw'],
    "yātudhāna": ['cae', 'gra', 'mw'],
    "yātudhānakṣayaṇa": ['mw'],
    "yātudhānapreṣita": ['mw'],
    "yātudhānī": ['gra'],
    "yātughna": ['mw'],
    "yātuhan": ['cae', 'mw'],
    "yātujambhana": ['mw'],
    "yātujū": ['gra', 'mw'],
    "yātumant": ['cae'],
    "yātumat": ['gra', 'mw'],
    "yātumāvant": ['cae'],
    "yātumāvat": ['gra', 'mw'],
    "yātuvid": ['cae', 'mw'],
    "yātuḥ": ['ap90'],
    "yātvā": ['cped'],
    "yātya": ['mw'],
    "yātānanāndṛ": ['mw'],
    "yātānaprastha": ['mw'],
    "yātānaprasthaka": ['mw'],
    "yātānuyāta": ['mw'],
    "yātāyāta": ['ddsa', 'mw'],
    "yātṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yātṛka": ['mw'],
    "yātṛkaḥ": ['ap90'],
    "yāva": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "yāva-kīvaṁ": ['cped'],
    "yāvac": ['mw'],
    "yāvacchakti": ['mw'],
    "yāvacchaktitas": ['ddsa', 'mw'],
    "yāvacchakya": ['mw'],
    "yāvacchakyam": ['mw'],
    "yāvaccharkaram": ['mw'],
    "yāvaccharāva": ['mw'],
    "yāvacchas": ['cae', 'mw'],
    "yāvacchastram": ['mw'],
    "yāvaccheṣam": ['cae', 'mw'],
    "yāvacchlokam": ['mw'],
    "yāvacchreṣṭha": ['cae', 'mw'],
    "yāvad": ['mw'],
    "yāvad eva": ['cped'],
    "yāvadabhīkṣṇam": ['mw'],
    "yāvadadhyayanam": ['cae', 'mw'],
    "yāvadaha": ['cae', 'mw'],
    "yāvadamatram": ['mw'],
    "yāvadantam": ['cae', 'ddsa', 'mw'],
    "yāvadantya": ['mw'],
    "yāvadantāya": ['cae', 'mw'],
    "yāvadartha": ['cae', 'mw'],
    "yāvadartham": ['mw'],
    "yāvadattha": ['cped'],
    "yāvadatthaṁ": ['cped'],
    "yāvadaupamya": ['mw'],
    "yāvadaṅgīna": ['mw'],
    "yāvadbalam": ['cae', 'mw'],
    "yāvadbhāvikatā": ['bhs'],
    "yāvadbhāṣita": ['mw'],
    "yāvaddaśottarapadasaṃdhilipi": ['bhs'],
    "yāvaddehabhāvin": ['mw'],
    "yāvaddevatya": ['mw'],
    "yāvaddeya": ['mw'],
    "yāvaddhavis": ['mw'],
    "yāvaddhā": ['cae', 'mw'],
    "yāvadetto": ['bhs'],
    "yāvadeva": ['bhs'],
    "yāvadgamam": ['ddsa', 'mw'],
    "yāvadgrahaṇam": ['mw'],
    "yāvadgṛhītin": ['mw'],
    "yāvadiccham": ['mw'],
    "yāvadittham": ['mw'],
    "yāvadiṣṭakam": ['mw'],
    "yāvadiṣṭam": ['mw'],
    "yāvadrājyam": ['mw'],
    "yāvadukta": ['cae', 'mw'],
    "yāvaduktam": ['mw'],
    "yāvadupaniṣad": ['mw'],
    "yāvaduttamam": ['mw'],
    "yāvadvacanam": ['mw'],
    "yāvadvedam": ['mw'],
    "yāvadvidha": ['bhs'],
    "yāvadviṃśati": ['mw'],
    "yāvadvyāpti": ['mw'],
    "yāvadvīryavat": ['mw'],
    "yāvadyajus": ['mw'],
    "yāvadābhūtasamplavam": ['mw'],
    "yāvadādiṣṭa": ['mw'],
    "yāvadāhūtasamplavam": ['mw'],
    "yāvadāvāsa": ['mw'],
    "yāvadāyus": ['cae', 'mw'],
    "yāvadāyuḥpramāṇa": ['mw'],
    "yāvadāyuṣam": ['cae', 'mw'],
    "yāvadīpsitam": ['mw'],
    "yāvaj": ['mw'],
    "yāvajjanma": ['ddsa', 'mw'],
    "yāvajjīva": ['mw'],
    "yāvajjīvam": ['cae', 'mw'],
    "yāvajjīvena": ['cae', 'mw'],
    "yāvajjīvika": ['mw'],
    "yāvajjīvikatā": ['mw'],
    "yāvajīva": ['cped'],
    "yāvajīvaṁ": ['cped'],
    "yāvajīvika": ['cped'],
    "yāvaka": ['cae', 'mw'],
    "yāvakakṛcchra": ['mw'],
    "yāvakavratin": ['mw'],
    "yāvakaḥ": ['ap90'],
    "yāvakrītika": ['mw'],
    "yāvakālika": ['cped'],
    "yāvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yāvana": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "yāvanmātra": ['cae', 'ddsa', 'gra', 'mw'],
    "yāvanmātram": ['mw'],
    "yāvant": ['cae'],
    "yāvantaka": ['bhs'],
    "yāvantara": ['bhs'],
    "yāvantikā": ['mw'],
    "yāvanāla": ['mw'],
    "yāvanālanibha": ['mw'],
    "yāvanālaśara": ['mw'],
    "yāvanālaḥ": ['ap90'],
    "yāvanī": ['bhs'],
    "yāvasa": ['mw'],
    "yāvasaḥ": ['ap90'],
    "yāvasika": ['bhs', 'mw'],
    "yāvat": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "yāvataka": ['bhs', 'cped'],
    "yāvatatiyaṁ": ['cped'],
    "yāvati": ['mw'],
    "yāvatihaṁ": ['cped'],
    "yāvatima": ['mw'],
    "yāvatitha": ['cae', 'ddsa', 'mw'],
    "yāvatkapālam": ['mw'],
    "yāvatkartṛ": ['mw'],
    "yāvatkratu": ['mw'],
    "yāvatkālam": ['cae', 'mw'],
    "yāvatkāmam": ['ddsa', 'mw'],
    "yāvatkṛtvas": ['cae', 'mw'],
    "yāvatpramāṇa": ['mw'],
    "yāvatpriya": ['mw'],
    "yāvatsabandhu": ['mw'],
    "yāvatsamasta": ['mw'],
    "yāvatsampātam": ['mw'],
    "yāvatsattvam": ['mw'],
    "yāvatsaṃsāram": ['mw'],
    "yāvatsmṛti": ['mw'],
    "yāvatsvam": ['cae', 'mw'],
    "yāvatsāmidheni": ['mw'],
    "yāvattaka": ['bhs'],
    "yāvattarasam": ['mw'],
    "yāvattmūtam": ['mw'],
    "yāvattāvatkalpana": ['mw'],
    "yāvatā": ['bhs', 'cped', 'mw'],
    "yāvatāvatihaṁ": ['cped'],
    "yāvatāyukaṁ": ['cped'],
    "yāvatṛtīyaka": ['bhs'],
    "yāvayaddveṣas": ['cae', 'ddsa', 'gra', 'mw'],
    "yāvayat": ['mw'],
    "yāvayatsakha": ['gra', 'mw'],
    "yāvayitṛ": ['mw'],
    "yāvaśūka": ['mw'],
    "yāvaśūkaḥ": ['ap90'],
    "yāveya": ['mw'],
    "yāvihotra": ['mw'],
    "yāvya": ['mw'],
    "yāvāsa": ['mw'],
    "yāvī": ['mw'],
    "yāyajūka": ['cae', 'ddsa', 'mw'],
    "yāyajūkaḥ": ['ap90'],
    "yāyaṣṭi": ['mw'],
    "yāyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "yāyāta": ['ddsa', 'mw'],
    "yāyātika": ['mw'],
    "yāyāvara": ['ap90', 'cae', 'ddsa', 'mw'],
    "yāyī": ['cped'],
    "yāśobhadra": ['mw'],
    "yāśodhareya": ['mw'],
    "yāśu": ['cae', 'gra', 'mw'],
    "yāṃtrika": ['ap90'],
    "yāṣṭi": ['mw'],
    "yāṣṭīka": ['ap90', 'ddsa', 'mw'],
    "yū": ['mw'],
    "yūka": ['cae', 'ddsa', 'mw'],
    "yūkadevī": ['mw'],
    "yūkara": ['mw'],
    "yūkaḥ": ['ap90'],
    "yūkila": ['bhs'],
    "yūkā": ['mw'],
    "yūkālikṣa": ['mw'],
    "yūn": ['cae', 'ddsa'],
    "yūna": ['cae', 'ddsa', 'mw'],
    "yūnarvan": ['mw'],
    "yūni": ['mw'],
    "yūpa": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yūpacchedana": ['mw'],
    "yūpadhvaja": ['mw'],
    "yūpadru": ['mw'],
    "yūpadruma": ['mw'],
    "yūpadāru": ['mw'],
    "yūpaikādaśinī": ['mw'],
    "yūpaka": ['mw'],
    "yūpakarṇa": ['mw'],
    "yūpakavat": ['mw'],
    "yūpakaṭaka": ['mw'],
    "yūpaketu": ['mw'],
    "yūpakeśin": ['mw'],
    "yūpalakṣaṇa": ['mw'],
    "yūpalakṣya": ['mw'],
    "yūpamadhya": ['mw'],
    "yūpamūrdha": ['mw'],
    "yūpasaṃskāra": ['mw'],
    "yūpavat": ['mw'],
    "yūpaveṣṭana": ['mw'],
    "yūpavraska": ['gra', 'mw'],
    "yūpavāha": ['gra', 'mw'],
    "yūpavāsas": ['mw'],
    "yūpaśakala": ['mw'],
    "yūpaḥ": ['ap90'],
    "yūpocchraya": ['mw'],
    "yūpolūkhalika": ['mw'],
    "yūpāgra": ['mw'],
    "yūpāhuti": ['cae', 'mw'],
    "yūpākhya": ['mw'],
    "yūpākṣa": ['mw'],
    "yūpāvaṭa": ['mw'],
    "yūpāvaṭya": ['mw'],
    "yūpāṅga": ['mw'],
    "yūpīkṛ": ['ddsa', 'mw'],
    "yūpīya": ['mw'],
    "yūropakhaṇḍa": ['mw'],
    "yūs": ['ddsa', 'mw'],
    "yūsa": ['cped'],
    "yūtha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "yūthabandha": ['mw'],
    "yūthabhraṣṭa": ['mw'],
    "yūthacārin": ['mw'],
    "yūthaga": ['mw'],
    "yūthahata": ['mw'],
    "yūthajeṭṭha": ['cped'],
    "yūthaka": ['mw'],
    "yūthamukhya": ['mw'],
    "yūthanātha": ['cae', 'mw'],
    "yūthapa": ['cae', 'cped', 'mw'],
    "yūthaparibhraṣṭa": ['mw'],
    "yūthapati": ['cae', 'mw'],
    "yūthapatisakāśam": ['mw'],
    "yūthapaśu": ['mw'],
    "yūthapāla": ['cae', 'mw'],
    "yūthara": ['mw'],
    "yūthatvā": ['mw'],
    "yūthavibhraṣṭa": ['mw'],
    "yūthaśas": ['cae', 'mw'],
    "yūthaṃ": ['ap90'],
    "yūthia": ['gra'],
    "yūthikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "yūthya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "yūthyā": ['mw'],
    "yūthāgraṇī": ['mw'],
    "yūthī": ['mw'],
    "yūthīkṛ": ['ddsa', 'mw'],
    "yūti": ['mw'],
    "yūtiḥ": ['ap90'],
    "yūyam": ['ddsa', 'mw'],
    "yūyudhi": ['gra', 'mw'],
    "yūyuvi": ['cae', 'gra', 'mw'],
    "yūṣ": ['ap90', 'mw'],
    "yūṣa": ['cae', 'ddsa', 'mw'],
    "yūṣan": ['cae', 'gra', 'mw'],
    "yūṣaḥ": ['ap90'],
    "ña": ['mw'],
    "ñakāra": ['mw'],
    "ñasi": ['cped'],
    "ñassati": ['cped'],
    "ñata": ['cped'],
    "ñatabba": ['cped'],
    "ñatayya": ['cped'],
    "ñatta": ['cped'],
    "ñattajjhāpanna": ['cped'],
    "ñatti": ['cped'],
    "ñatticatuttha": ['cped'],
    "ñattidutiya": ['cped'],
    "ñattikamma": ['cped'],
    "ñattisampanna": ['cped'],
    "ñattivipanna": ['cped'],
    "ñatuṁ": ['cped'],
    "ñatvā": ['cped'],
    "ñatvāna": ['cped'],
    "ñaṇi(n)": ['cped'],
    "ñeyya": ['cped'],
    "ñāpesi": ['cped'],
    "ñāpetabba": ['cped'],
    "ñātaka": ['cped'],
    "ñāteyya": ['cped'],
    "ñāti": ['cped'],
    "ñātikā": ['cped'],
    "ñātiparivaṭṭa": ['cped'],
    "ñāya": ['cped'],
    "ñāyamāna": ['cped'],
    "ñāyati": ['cped'],
    "ñāṇa": ['cped'],
    "ñāṇabhandu": ['cped'],
    "ñāṇabhūta": ['cped'],
    "ñāṇadassana": ['cped'],
    "ñāṇadassi(n)": ['cped'],
    "ñāṇakaraṇa": ['cped'],
    "ā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āartana": ['gra'],
    "ābaddha": ['ap90', 'cae', 'mw'],
    "ābaddhadṛṣṭi": ['mw'],
    "ābaddhaka": ['bhs'],
    "ābaddhamaṇḍala": ['mw'],
    "ābaddhamāla": ['ddsa', 'mw'],
    "ābaddhaparikara": ['bhs'],
    "ābaddhāñjali": ['mw'],
    "ābadh": ['mw'],
    "ābadhaḥ": ['ap90'],
    "ābalya": ['mw'],
    "ābalyaṃ": ['ap90'],
    "ābandh": ['mw'],
    "ābandha": ['cae', 'ddsa', 'mw'],
    "ābandhana": ['mw'],
    "ābandhura": ['mw'],
    "ābandhya": ['bhs'],
    "ābarha": ['ap90', 'mw'],
    "ābarham": ['mw'],
    "ābarhaṇa": ['mw'],
    "ābarhin": ['ap90', 'mw'],
    "ābarhita": ['ap90', 'mw'],
    "ābayu": ['mw'],
    "ābaṃdh": ['ap90'],
    "ābaṃdhaḥ": ['ap90'],
    "ābda": ['ap90'],
    "ābdam": ['mw'],
    "ābdika": ['ap90', 'cae', 'ddsa', 'mw'],
    "ābha": ['bhs', 'mw'],
    "ābhaga": ['cae', 'gra', 'mw'],
    "ābhagaḥ": ['ap90'],
    "ābhaj": ['mw'],
    "ābhajanīya": ['mw'],
    "ābhakta": ['cae'],
    "ābhakṣaṇa": ['bhs'],
    "ābhara": ['mw'],
    "ābharadvasava": ['mw'],
    "ābharadvasu": ['gra', 'mw'],
    "ābharaṇa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ābharaṇachattranirghoṣa": ['bhs'],
    "ābharaṇapuṣkariṇī": ['bhs'],
    "ābharaṇasthāna": ['cae', 'mw'],
    "ābharaṇaṃ": ['ap90'],
    "ābharita": ['ap90', 'mw'],
    "ābhassara": ['cped'],
    "ābhasvara": ['bhs'],
    "ābhata": ['cped'],
    "ābhayajāta": ['mw'],
    "ābhayajātya": ['mw'],
    "ābhaśiri": ['bhs'],
    "ābhaṅgin": ['ddsa', 'mw'],
    "ābhaṇḍana": ['mw'],
    "ābhaṭa": ['cped'],
    "ābherī": ['ap90', 'mw'],
    "ābheti": ['cped'],
    "ābhicaraṇika": ['ap90', 'mw'],
    "ābhicetasika": ['cped'],
    "ābhicārika": ['mw'],
    "ābhicāruka": ['bhs'],
    "ābhid": ['mw'],
    "ābhidhā": ['ap90', 'mw'],
    "ābhidhānika": ['ap90', 'mw'],
    "ābhidhānīyaka": ['ap90', 'mw'],
    "ābhidhātaka": ['mw'],
    "ābhidosika": ['cped'],
    "ābhidosiya": ['cped'],
    "ābhihārika": ['ap90', 'mw'],
    "ābhijana": ['ap90', 'ddsa', 'mw'],
    "ābhijita": ['ap90', 'mw'],
    "ābhijitya": ['mw'],
    "ābhijñānika": ['mw'],
    "ābhijātya": ['mw'],
    "ābhijātyaṃ": ['ap90'],
    "ābhijātī": ['cae'],
    "ābhikāmika": ['mw'],
    "ābhimanyava": ['mw'],
    "ābhimukhya": ['cae', 'mw'],
    "ābhimukhyakaraṇa": ['mw'],
    "ābhimukhyaṃ": ['ap90'],
    "ābhimānika": ['bhs', 'mw'],
    "ābhindati": ['cped'],
    "ābhiplavika": ['ap90', 'mw'],
    "ābhipratāriṇa": ['mw'],
    "ābhiprāyika": ['bhs', 'mw'],
    "ābhiprāyāś": ['bhs'],
    "ābhirāmika": ['ap90', 'mw'],
    "ābhirūpaka": ['mw'],
    "ābhirūpakaṃ": ['ap90'],
    "ābhirūpya": ['bhs', 'mw'],
    "ābhisallehika": ['cped'],
    "ābhisamācārika": ['cped'],
    "ābhisaṃkṣepika": ['bhs'],
    "ābhisaṃskārika": ['bhs'],
    "ābhiseka": ['cped'],
    "ābhisekika": ['cped'],
    "ābhiyogika": ['mw'],
    "ābhiśasya": ['mw'],
    "ābhiṣecanika": ['ap90', 'cae', 'mw'],
    "ābhiṣeka": ['cae', 'mw'],
    "ābhoga": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ābhogaya": ['ap90', 'cae', 'gra', 'mw'],
    "ābhogaḥ": ['ap90'],
    "ābhogi": ['ddsa', 'gra', 'mw'],
    "ābhogin": ['mw'],
    "ābhogiḥ": ['ap90'],
    "ābhogya": ['ddsa'],
    "ābhojin": ['mw'],
    "ābhra": ['mw'],
    "ābhrika": ['ap90', 'mw'],
    "ābhrya": ['mw'],
    "ābhrāja": ['mw'],
    "ābhu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ābhugna": ['ap90', 'cae', 'ddsa', 'mw'],
    "ābhugnasaktha": ['mw'],
    "ābhuj": ['mw'],
    "ābhujati": ['bhs'],
    "ābhujitvā": ['cped'],
    "ābhuñjitvā": ['cped'],
    "ābhyantara": ['cae', 'ddsa', 'mw'],
    "ābhyantaram": ['mw'],
    "ābhyantaranṛtta": ['mw'],
    "ābhyantaraprayatna": ['mw'],
    "ābhyantarika": ['mw'],
    "ābhyantaroṣṭha": ['bhs'],
    "ābhyavahārika": ['ap90', 'mw'],
    "ābhyavakāśika": ['ap90', 'bhs', 'mw'],
    "ābhyaṃtara": ['ap90'],
    "ābhyudayika": ['ap90', 'ddsa', 'mw'],
    "ābhyādāyikaṃ": ['ap90'],
    "ābhyāgārika": ['mw'],
    "ābhyāsika": ['ap90', 'mw'],
    "ābhyāśika": ['mw'],
    "ābhā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "ābhār": ['ddsa'],
    "ābhās": ['ap90', 'mw'],
    "ābhāsa": ['bhs', 'cae', 'ddsa', 'mw'],
    "ābhāsana": ['mw'],
    "ābhāsanaṃ": ['ap90'],
    "ābhāsatva": ['mw'],
    "ābhāsatā": ['mw'],
    "ābhāsaḥ": ['ap90'],
    "ābhāsin": ['mw'],
    "ābhāsura": ['ap90', 'mw'],
    "ābhāsvara": ['ap90', 'bhs', 'mw'],
    "ābhāsībhavati": ['bhs'],
    "ābhāta": ['cae', 'mw'],
    "ābhāti": ['cped', 'mw'],
    "ābhātiḥ": ['ap90'],
    "ābhāṇaka": ['mw'],
    "ābhāṇakaḥ": ['ap90'],
    "ābhāṣ": ['ap90', 'mw'],
    "ābhāṣa": ['ddsa', 'mw'],
    "ābhāṣati": ['bhs'],
    "ābhāṣaḥ": ['ap90'],
    "ābhāṣaṇa": ['mw'],
    "ābhāṣaṇaṃ": ['ap90'],
    "ābhāṣita": ['mw'],
    "ābhāṣya": ['ap90', 'mw'],
    "ābhīka": ['mw'],
    "ābhīkaṃ": ['ap90'],
    "ābhīkṣṇa": ['mw'],
    "ābhīkṣṇaka": ['bhs'],
    "ābhīkṣṇya": ['cae', 'ddsa', 'mw'],
    "ābhīkṣṇyaṃ": ['ap90'],
    "ābhīla": ['ap90', 'ddsa', 'mw'],
    "ābhīra": ['bhs', 'cae', 'ddsa', 'mw'],
    "ābhīraka": ['mw'],
    "ābhīrapalli": ['mw'],
    "ābhīrapallī": ['mw'],
    "ābhīraḥ": ['ap90'],
    "ābhīrika": ['mw'],
    "ābhīrī": ['mw'],
    "ābhīya": ['ap90'],
    "ābhīśava": ['mw'],
    "ābhīśavottara": ['mw'],
    "ābhīśavādya": ['mw'],
    "ābhīṣaṇa": ['mw'],
    "ābhū": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ābhūka": ['ap90', 'mw'],
    "ābhūmipāla": ['mw'],
    "ābhūta": ['mw'],
    "ābhūtasaṃplavam": ['mw'],
    "ābhūti": ['cae', 'ddsa', 'gra', 'mw'],
    "ābhūtiḥ": ['ap90'],
    "ābhūṣ": ['mw'],
    "ābhūṣeṇya": ['ap90', 'cae', 'gra', 'mw'],
    "ābhṛ": ['ap90', 'mw'],
    "ābhṛta": ['cae', 'mw'],
    "ābhṛtātman": ['mw'],
    "ābila": ['ap90', 'mw'],
    "ābilakanda": ['mw'],
    "ābilam": ['mw'],
    "ābodhanaṃ": ['ap90'],
    "ābrahitavya": ['bhs'],
    "ābrahma": ['mw'],
    "ābrahmasabham": ['ddsa', 'mw'],
    "ābravantī": ['mw'],
    "ābrīḍha": ['bhs'],
    "ābrū": ['mw'],
    "ābudh": ['ap90', 'mw'],
    "ābudhya": ['mw'],
    "ābutta": ['ap90', 'cae', 'ddsa', 'mw'],
    "ābādh": ['ap90', 'mw'],
    "ābādha": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ābādhati": ['cped'],
    "ābādhayati": ['cped'],
    "ābādhaḥ": ['ap90'],
    "ābādheti": ['cped'],
    "ābādhika": ['bhs', 'cped'],
    "ābādhikinī": ['cped'],
    "ābādhita": ['cped'],
    "ābādhā": ['mw'],
    "ābālam": ['ddsa', 'mw'],
    "ābālya": ['ddsa'],
    "ābālyam": ['mw'],
    "ābālyaṃ": ['ap90'],
    "ābūḍha": ['bhs'],
    "ābṛh": ['mw'],
    "ābṛhati": ['bhs'],
    "ābṛḍha": ['bhs', 'mw'],
    "ābṛṃhaṇa": ['bhs'],
    "ābṛṃhita": ['bhs'],
    "āc": ['ddsa', 'mw'],
    "āca": ['ddsa', 'mw'],
    "ācakri": ['gra', 'mw'],
    "ācakṣ": ['ap90', 'mw'],
    "ācakṣas": ['mw'],
    "ācakṣus": ['ap90', 'mw'],
    "ācal": ['mw'],
    "ācam": ['ap90', 'mw'],
    "ācama": ['cped'],
    "ācamakumbhī": ['cped'],
    "ācamana": ['cae', 'cped', 'ddsa', 'mw'],
    "ācamanaka": ['mw'],
    "ācamanakaṃ": ['ap90'],
    "ācamanakumbhī": ['cped'],
    "ācamanapādukā": ['cped'],
    "ācamanasarāvaka": ['cped'],
    "ācamanaṃ": ['ap90'],
    "ācamanī": ['mw'],
    "ācamanīya": ['ap90', 'mw'],
    "ācamanīyaka": ['mw'],
    "ācamati": ['cped'],
    "ācamayati": ['cped'],
    "ācamayitvāna": ['cped'],
    "ācamaḥ": ['ap90'],
    "ācametabba": ['cped'],
    "ācameti": ['cped'],
    "ācamitabba": ['cped'],
    "ācamya": ['mw'],
    "ācandram": ['mw'],
    "ācandratārakam": ['ddsa', 'mw'],
    "ācaparāca": ['mw'],
    "ācar": ['ap90', 'mw'],
    "ācara": ['cped', 'mw'],
    "ācarat": ['cped'],
    "ācarati": ['cped'],
    "ācaraṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "ācaraṇaṃ": ['ap90'],
    "ācaraṇya": ['mw'],
    "ācaraṇyati": ['ap90'],
    "ācaraṇīya": ['ap90', 'mw'],
    "ācarinī": ['cped'],
    "ācarita": ['ap90', 'cae', 'cped', 'mw'],
    "ācaritabba": ['cped'],
    "ācaritatva": ['mw'],
    "ācaritavya": ['cae', 'mw'],
    "ācaritvā": ['cped'],
    "ācariya": ['bhs', 'cped'],
    "ācariyabhariyā": ['cped'],
    "ācariyadhana": ['cped'],
    "ācariyaka": ['cped'],
    "ācariyakula": ['cped'],
    "ācariyamahāyuga": ['cped'],
    "ācariyamatta": ['cped'],
    "ācariyamuṭṭhi": ['cped'],
    "ācariyaparamparā": ['cped'],
    "ācariyapācariya": ['cped'],
    "ācariṁsu": ['cped'],
    "ācarya": ['mw'],
    "ācaturam": ['mw'],
    "ācaturaṃ": ['ap90'],
    "ācaturya": ['mw'],
    "ācaya": ['cped', 'mw'],
    "ācayagāmi": ['cped'],
    "ācayagāmin": ['cped'],
    "ācayaka": ['ap90', 'mw'],
    "ācayaḥ": ['ap90'],
    "ācañcala": ['mw'],
    "ācchad": ['ap90', 'mw'],
    "ācchadvidhāna": ['mw'],
    "ācchanna": ['cae', 'ddsa', 'mw'],
    "āccheda": ['mw'],
    "ācchedana": ['mw'],
    "ācchedanī": ['mw'],
    "ācchedaḥ": ['ap90'],
    "ācchettṛ": ['mw'],
    "ācchid": ['ap90', 'mw'],
    "ācchidya": ['mw'],
    "ācchinna": ['cae', 'mw'],
    "āccho": ['mw'],
    "ācchodana": ['mw'],
    "ācchodanaṃ": ['ap90'],
    "ācchoṭanaṃ": ['ap90'],
    "ācchoṭita": ['mw'],
    "ācchuka": ['mw'],
    "ācchukaḥ": ['ap90'],
    "ācchurita": ['ap90', 'ddsa', 'mw'],
    "ācchuritaka": ['mw'],
    "ācchuritakaṃ": ['ap90'],
    "ācchāda": ['cae', 'ddsa', 'mw'],
    "ācchādaka": ['ap90', 'cae', 'mw'],
    "ācchādakatva": ['mw'],
    "ācchādana": ['cae', 'mw'],
    "ācchādanavastra": ['mw'],
    "ācchādanaṃ": ['ap90'],
    "ācchādayitvā": ['mw'],
    "ācchādaḥ": ['ap90'],
    "ācchādin": ['ap90', 'cae', 'mw'],
    "ācchādita": ['mw'],
    "ācchādya": ['mw'],
    "ācchākaḥ": ['ap90'],
    "ācchṛd": ['mw'],
    "āceraka": ['cped'],
    "āceśvara": ['ddsa', 'mw'],
    "āceṣṭ": ['mw'],
    "āceṣṭita": ['mw'],
    "āchad": ['gra'],
    "āchadvidhāna": ['gra'],
    "āchindana": ['bhs'],
    "āchoḍita": ['bhs'],
    "āchāda": ['bhs'],
    "āchādana": ['bhs'],
    "āchādayati": ['bhs'],
    "āchāya": ['bhs'],
    "āci": ['ap90', 'mw'],
    "ācikhyāsopamā": ['cae', 'mw'],
    "ācikhyāsu": ['ddsa'],
    "ācikhyāsā": ['cae', 'mw'],
    "ācikkha": ['cped'],
    "ācikkhana": ['cped'],
    "ācikkhat": ['cped'],
    "ācikkhati": ['cped'],
    "ācikkhi": ['cped'],
    "ācikkhissāmi": ['cped'],
    "ācikkhissāṁ": ['cped'],
    "ācikkhita": ['cped'],
    "ācikkhitabba": ['cped'],
    "ācikkhituṁ": ['cped'],
    "ācikkhitvā": ['cped'],
    "ācikkhitvāna": ['cped'],
    "ācikkhiyamāna": ['cped'],
    "ācikkhiṁsu": ['cped'],
    "ācikṣati": ['bhs'],
    "ācinati": ['bhs'],
    "ācinā": ['cped'],
    "ācināt": ['cped'],
    "ācināti": ['cped'],
    "ācit": ['gra', 'mw'],
    "ācita": ['ap90', 'cae', 'ddsa', 'mw'],
    "ācitika": ['ap90', 'mw'],
    "ācitra": ['mw'],
    "ācitādi": ['mw'],
    "ācitīna": ['mw'],
    "āciṇṇa": ['cped'],
    "āciṇṇakappa": ['cped'],
    "ācopaca": ['mw'],
    "ācumb": ['mw'],
    "ācya": ['ddsa', 'mw'],
    "ācyu": ['mw'],
    "ācyudanti": ['mw'],
    "ācyudantīya": ['mw'],
    "ācyutadanti": ['mw'],
    "ācyutadantīya": ['mw'],
    "ācyutanti": ['mw'],
    "ācyutantīya": ['mw'],
    "ācyutika": ['mw'],
    "ācyā": ['mw'],
    "ācyādoha": ['mw'],
    "ācāma": ['cae', 'ddsa', 'mw'],
    "ācāmabhakkha": ['cped'],
    "ācāmaka": ['ap90', 'mw'],
    "ācāmanaka": ['mw'],
    "ācāmanakaṃ": ['ap90'],
    "ācāmaḥ": ['ap90'],
    "ācāmeti": ['cped'],
    "ācāmya": ['ap90', 'mw'],
    "ācānta": ['cae', 'mw'],
    "ācānti": ['mw'],
    "ācāntodaka": ['mw'],
    "ācāra": ['cae', 'cped', 'ddsa', 'mw'],
    "ācārabheda": ['mw'],
    "ācārabhraṣṭa": ['mw'],
    "ācāracakrin": ['mw'],
    "ācāracandrikā": ['mw'],
    "ācāradīpa": ['mw'],
    "ācāragocara": ['cped'],
    "ācārahīna": ['cae', 'mw'],
    "ācāramaya": ['mw'],
    "ācāramayūkha": ['mw'],
    "ācāratantra": ['mw'],
    "ācāravant": ['cae'],
    "ācāravarjita": ['mw'],
    "ācāravat": ['ap90', 'mw'],
    "ācāravedī": ['mw'],
    "ācāraviruddha": ['mw'],
    "ācāravyapeta": ['mw'],
    "ācāraḥ": ['ap90'],
    "ācārika": ['ap90', 'mw'],
    "ācārin": ['ap90', 'mw'],
    "ācārollāsa": ['mw'],
    "ācārya": ['cae', 'ddsa', 'mw'],
    "ācāryabhogīna": ['mw'],
    "ācāryadeva": ['mw'],
    "ācāryadeśīya": ['mw'],
    "ācāryajāyā": ['mw'],
    "ācāryaka": ['ap90', 'bhs', 'cae', 'mw'],
    "ācāryakaraṇa": ['mw'],
    "ācāryamiśra": ['mw'],
    "ācāryamuṣṭi": ['bhs', 'mw'],
    "ācāryasava": ['mw'],
    "ācāryatarpaṇa": ['mw'],
    "ācāryatva": ['mw'],
    "ācāryatā": ['ap90', 'mw'],
    "ācāryavacasa": ['mw'],
    "ācāryavat": ['mw'],
    "ācāryaḥ": ['ap90'],
    "ācāryopāsana": ['cae', 'mw'],
    "ācāryā": ['mw'],
    "ācāryānī": ['ap90', 'mw'],
    "ācāryāsandī": ['mw'],
    "ācāryīkṛ": ['mw'],
    "ācārādarśa": ['mw'],
    "ācārārka": ['mw'],
    "ācārāṅga": ['mw'],
    "ācārī": ['ap90', 'mw'],
    "ācāṃta": ['ap90'],
    "ācīrṇa": ['ap90', 'mw'],
    "ācīrṇadaṇḍatā": ['bhs'],
    "ācūṣayati": ['bhs'],
    "ācūṣaṇa": ['mw'],
    "ācūṣaṇaṃ": ['ap90'],
    "ācṛt": ['mw'],
    "āda": ['ap90', 'mw'],
    "ādabh": ['mw'],
    "ādadhīci": ['mw'],
    "ādadi": ['ap90', 'gra', 'mw'],
    "ādagh": ['mw'],
    "ādaghna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ādah": ['mw'],
    "ādahana": ['mw'],
    "ādahanaṃ": ['ap90'],
    "ādai": ['mw'],
    "ādam": ['mw'],
    "ādam, ādam, ādat": ['ddsa'],
    "ādapana": ['bhs'],
    "ādapayati": ['cped'],
    "ādapayi": ['cped'],
    "ādapeti": ['cped'],
    "ādara": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādaravat": ['mw'],
    "ādaraḥ": ['ap90'],
    "ādaraṇa": ['mw'],
    "ādaraṇaṃ": ['ap90'],
    "ādaraṇīya": ['ap90', 'mw'],
    "ādaraṇīyatva": ['mw'],
    "ādardira": ['ap90', 'cae', 'gra', 'mw'],
    "ādarin": ['mw'],
    "ādartavya": ['ddsa', 'mw'],
    "ādarśa": ['cae', 'ddsa', 'mw'],
    "ādarśabimba": ['mw'],
    "ādarśajñāna": ['bhs'],
    "ādarśaka": ['mw'],
    "ādarśakaḥ": ['ap90'],
    "ādarśamaya": ['mw'],
    "ādarśamaṇḍala": ['mw'],
    "ādarśamaṇḍalanirbhāsā": ['bhs'],
    "ādarśamukha": ['bhs'],
    "ādarśana": ['bhs'],
    "ādarśanajñāna": ['bhs'],
    "ādarśanaṃ": ['ap90'],
    "ādarśaḥ": ['ap90'],
    "ādarśita": ['mw'],
    "ādat": ['mw'],
    "ādatta": ['ap90', 'mw'],
    "ādau": ['mw'],
    "ādaśasya": ['mw'],
    "ādaśāham": ['mw'],
    "ādaṃś": ['ap90', 'mw'],
    "ādaṃśa": ['mw'],
    "ādaṃśaḥ": ['ap90'],
    "ādaṣṭa": ['mw'],
    "ādehadāham": ['mw'],
    "ādesanavidhā": ['cped'],
    "ādesanāpāṭihāriya": ['cped'],
    "ādesita": ['cped'],
    "ādeti": ['cped'],
    "ādeva": ['cped', 'gra', 'mw'],
    "ādevaka": ['ap90', 'mw'],
    "ādevana": ['ddsa', 'mw'],
    "ādevanaṃ": ['ap90', 'cae'],
    "ādevanā": ['cped'],
    "ādevitatta": ['cped'],
    "ādeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādeyataratā": ['mw'],
    "ādeyavacana": ['bhs'],
    "ādeyavākya": ['bhs'],
    "ādeyyavācana": ['cped'],
    "ādeyyavākyavacana": ['cped'],
    "ādeśa": ['cae', 'ddsa', 'mw'],
    "ādeśaka": ['mw'],
    "ādeśakārin": ['mw'],
    "ādeśana": ['mw'],
    "ādeśanaṃ": ['ap90'],
    "ādeśanā": ['bhs'],
    "ādeśayati": ['bhs'],
    "ādeśaḥ": ['ap90'],
    "ādeśin": ['ap90', 'cae', 'mw'],
    "ādeśya": ['mw'],
    "ādeṣṭṛ": ['ap90', 'mw'],
    "ādhamana": ['cae', 'ddsa', 'mw'],
    "ādhamanaṃ": ['ap90'],
    "ādhamarṇya": ['cae', 'ddsa', 'mw'],
    "ādhamarṇyaṃ": ['ap90'],
    "ādhara": ['mw'],
    "ādharmika": ['ap90', 'mw'],
    "ādharya": ['mw'],
    "ādharṣa": ['mw'],
    "ādharṣaka": ['bhs'],
    "ādharṣaḥ": ['ap90'],
    "ādharṣaṇa": ['mw'],
    "ādharṣaṇaṃ": ['ap90'],
    "ādharṣita": ['ap90', 'mw'],
    "ādharṣya": ['mw'],
    "ādhava": ['cae', 'gra', 'mw'],
    "ādhavana": ['mw'],
    "ādhavanaṃ": ['ap90'],
    "ādhavanīya": ['cae', 'ddsa', 'mw'],
    "ādhavanīyaḥ": ['ap90'],
    "ādhavaḥ": ['ap90'],
    "ādhenava": ['mw'],
    "ādhenavaṃ": ['ap90'],
    "ādhenta": ['cped'],
    "ādheya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādheyya": ['cped'],
    "ādheyyamukha": ['cped'],
    "ādhi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ādhibandha": ['mw'],
    "ādhibhautika": ['ap90', 'mw'],
    "ādhibhoga": ['mw'],
    "ādhidaivata": ['cae', 'ddsa', 'mw'],
    "ādhidaivika": ['ap90', 'cae', 'mw'],
    "ādhija": ['mw'],
    "ādhijña": ['mw'],
    "ādhikaraṇika": ['bhs', 'cae', 'mw'],
    "ādhikaraṇikaḥ": ['ap90'],
    "ādhikya": ['cae', 'ddsa', 'mw'],
    "ādhikyaṃ": ['ap90'],
    "ādhikāraṇyaṃ": ['ap90'],
    "ādhikārika": ['ap90', 'mw'],
    "ādhimanyu": ['mw'],
    "ādhimlāna": ['mw'],
    "ādhimokṣika": ['bhs'],
    "ādhimānika": ['bhs'],
    "ādhipacca": ['cped'],
    "ādhipateya": ['bhs'],
    "ādhipateyatā": ['bhs'],
    "ādhipateyya": ['cped'],
    "ādhipati": ['cped'],
    "ādhipatya": ['cae', 'gra', 'mw'],
    "ādhipatyaṃ": ['ap90'],
    "ādhirathi": ['cae', 'mw'],
    "ādhirathīya": ['mw'],
    "ādhirājya": ['cae', 'mw'],
    "ādhirājyaṃ": ['ap90'],
    "ādhistena": ['cae', 'mw'],
    "ādhitsu": ['mw'],
    "ādhitvaṃ": ['ap90'],
    "ādhitā": ['mw'],
    "ādhivedanika": ['mw'],
    "ādhivedanikaṃ": ['ap90'],
    "ādhiḥ": ['ap90'],
    "ādhiṣṭhānika": ['bhs'],
    "ādhmā": ['ap90', 'mw'],
    "ādhmāna": ['mw'],
    "ādhmānaṃ": ['ap90'],
    "ādhmānī": ['mw'],
    "ādhmāpana": ['mw'],
    "ādhmāpanaṃ": ['ap90'],
    "ādhmāta": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādhomukhya": ['ddsa', 'mw'],
    "ādhoraṇa": ['ddsa', 'mw'],
    "ādhoraṇaḥ": ['ap90'],
    "ādhra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ādhu": ['ap90', 'mw'],
    "ādhunaya": ['mw'],
    "ādhunika": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādhuta": ['mw'],
    "ādhvanika": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādhvara": ['mw'],
    "ādhvarika": ['ap90', 'mw'],
    "ādhvaryava": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ādhvarāyaṇa": ['mw'],
    "ādhvasta": ['cae', 'mw'],
    "ādhvaṃs": ['mw'],
    "ādhyai": ['ap90', 'mw'],
    "ādhyakṣya": ['mw'],
    "ādhyakṣyaṃ": ['ap90'],
    "ādhyaśvi": ['mw'],
    "ādhyaśvīya": ['mw'],
    "ādhyā": ['ap90', 'mw'],
    "ādhyāna": ['mw'],
    "ādhyānaṃ": ['ap90'],
    "ādhyāpaka": ['mw'],
    "ādhyāpakaḥ": ['ap90'],
    "ādhyāsika": ['ap90', 'mw'],
    "ādhyātmika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ādhyāyika": ['ap90', 'mw'],
    "ādhā": ['ap90', 'mw'],
    "ādhāna": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ādhānagāhin": ['cped'],
    "ādhānakārikā": ['mw'],
    "ādhānapaddhati": ['mw'],
    "ādhānavidhi": ['mw'],
    "ādhānaṃ": ['ap90'],
    "ādhānika": ['mw'],
    "ādhānikaḥ": ['ap90'],
    "ādhāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ādhāracakra": ['mw'],
    "ādhāraka": ['bhs', 'mw'],
    "ādhārakaḥ": ['ap90'],
    "ādhārakārikā": ['mw'],
    "ādhāramudrā": ['bhs'],
    "ādhārarūpā": ['mw'],
    "ādhāratva": ['mw'],
    "ādhāratā": ['mw'],
    "ādhārayati": ['bhs'],
    "ādhāraḥ": ['ap90'],
    "ādhāraṇa": ['mw'],
    "ādhāraṇamudrā": ['bhs'],
    "ādhāraṇatā": ['bhs'],
    "ādhāraṇaṃ": ['ap90'],
    "ādhāraṇī": ['bhs'],
    "ādhārin": ['mw'],
    "ādhārya": ['ap90', 'mw'],
    "ādhārādheyabhāva": ['mw'],
    "ādhārṣṭya": ['mw'],
    "ādhātavya": ['mw'],
    "ādhātuṁ": ['cped'],
    "ādhātṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādhāv": ['mw'],
    "ādhāva": ['mw'],
    "ādhāvana": ['bhs'],
    "ādhāvati": ['cped'],
    "ādhāvaḥ": ['ap90'],
    "ādhāvitvā": ['cped'],
    "ādhāya": ['cped', 'mw'],
    "ādhāyaka": ['ap90', 'ddsa', 'mw'],
    "ādhāyakatva": ['mw'],
    "ādhāyaḥ": ['ap90'],
    "ādhāyin": ['mw'],
    "ādhāyitā": ['mw'],
    "ādhī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ādhīkaraṇa": ['mw'],
    "ādhīkaraṇaṃ": ['ap90'],
    "ādhīkṛ": ['ap90', 'ddsa', 'mw'],
    "ādhīkṛta": ['mw'],
    "ādhīkṛtya": ['mw'],
    "ādhīna": ['mw'],
    "ādhīparṇa": ['mw'],
    "ādhīta": ['ap90', 'cae', 'gra', 'mw'],
    "ādhītayajus": ['mw'],
    "ādhīti": ['cae', 'mw'],
    "ādhū": ['mw'],
    "ādhūmana": ['mw'],
    "ādhūmaya": ['mw'],
    "ādhūmita": ['mw'],
    "ādhūmra": ['mw'],
    "ādhūpana": ['mw'],
    "ādhūpaya": ['mw'],
    "ādhūta": ['cae', 'mw'],
    "ādhūya": ['mw'],
    "ādhṛ": ['ap90', 'mw'],
    "ādhṛta": ['ap90', 'mw'],
    "ādhṛṣ": ['ap90', 'mw'],
    "ādhṛṣe": ['cae'],
    "ādhṛṣīya": ['mw'],
    "ādhṛṣṭa": ['ap90', 'mw'],
    "ādhṛṣṭi": ['mw'],
    "ādhṛṣṭiḥ": ['ap90'],
    "ādi": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ādibala": ['mw'],
    "ādibharataprastāra": ['mw'],
    "ādibhava": ['mw'],
    "ādibhavānī": ['mw'],
    "ādibhūta": ['cae', 'mw'],
    "ādibrahmacariya": ['cped'],
    "ādibrahmacariyaka": ['cped'],
    "ādibrahmacariyaṁ": ['cped'],
    "ādibuddha": ['mw'],
    "ādicca": ['cped'],
    "ādiccabandhu": ['cped'],
    "ādiccapatha": ['cped'],
    "ādidaitya": ['mw'],
    "ādideva": ['cae', 'ddsa', 'mw'],
    "ādidīpa": ['mw'],
    "ādidīpaka": ['mw'],
    "ādigadādhara": ['mw'],
    "ādigdha": ['cae', 'mw'],
    "ādigrantha": ['mw'],
    "ādiguru": ['cae', 'mw'],
    "ādih": ['mw'],
    "ādijina": ['mw'],
    "ādika": ['ap90', 'bhs'],
    "ādikammika": ['cped'],
    "ādikara": ['cped', 'mw'],
    "ādikarman": ['mw'],
    "ādikarmika": ['bhs'],
    "ādikarmin": ['bhs'],
    "ādikartṛ": ['cae', 'mw'],
    "ādikarṇī": ['mw'],
    "ādikatta": ['cped'],
    "ādikattar": ['cped'],
    "ādikavi": ['mw'],
    "ādikena": ['cped'],
    "ādikeśava": ['mw'],
    "ādikeśavāṣṭaka": ['mw'],
    "ādikāla": ['mw'],
    "ādikālīna": ['mw'],
    "ādikāraṇa": ['mw'],
    "ādikāvya": ['mw'],
    "ādikāṇḍa": ['mw'],
    "ādikṛt": ['mw'],
    "ādilupta": ['mw'],
    "ādima": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādimat": ['ap90', 'mw'],
    "ādimattva": ['mw'],
    "ādimatva": ['mw'],
    "ādimūla": ['cae', 'mw'],
    "ādin": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādinava": ['mw'],
    "ādinavadarśa": ['mw'],
    "ādinavaḥ": ['ap90'],
    "ādinna": ['cped'],
    "ādinnadaṇḍa": ['cped'],
    "ādināntam": ['ddsa', 'mw'],
    "ādinātha": ['mw'],
    "ādiparvan": ['mw'],
    "ādiparvata": ['ddsa', 'mw'],
    "ādipitāmaha": ['mw'],
    "ādipluta": ['mw'],
    "ādippati": ['cped'],
    "ādipuruṣa": ['cae', 'mw'],
    "ādipurāṇa": ['mw'],
    "ādipūruṣa": ['cae', 'mw'],
    "ādirasaśloka": ['mw'],
    "ādirāja": ['mw'],
    "ādirūpa": ['mw'],
    "ādisanta": ['cped'],
    "ādisarga": ['mw'],
    "ādisati": ['cped'],
    "ādisitvā": ['cped'],
    "ādisiṃha": ['mw'],
    "ādiso": ['cped'],
    "ādissa": ['cped'],
    "ādisthāyika": ['mw'],
    "ādisvarita": ['mw'],
    "ādisūra": ['mw'],
    "āditas": ['cae', 'mw'],
    "āditaḥ": ['ap90'],
    "āditeya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āditia": ['gra'],
    "ādito": ['cped'],
    "āditsu": ['ap90', 'cae', 'ddsa', 'mw'],
    "āditsā": ['mw'],
    "āditta": ['cped'],
    "āditva": ['mw'],
    "āditya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ādityabandhu": ['mw'],
    "ādityabhaktā": ['mw'],
    "ādityacandra": ['cae'],
    "ādityacandrau": ['mw'],
    "ādityadarśana": ['mw'],
    "ādityadatta": ['bhs'],
    "ādityadeva": ['mw'],
    "ādityadevata": ['mw'],
    "ādityadhāman": ['mw'],
    "ādityadāsa": ['mw'],
    "ādityagarbha": ['bhs', 'mw'],
    "ādityagarbhaprabhamegharāja": ['bhs'],
    "ādityagata": ['cae', 'mw'],
    "ādityagati": ['mw'],
    "ādityagraha": ['mw'],
    "ādityahṛdaya": ['mw'],
    "ādityajyotis": ['mw'],
    "ādityajūta": ['gra', 'mw'],
    "ādityaketu": ['mw'],
    "ādityakeśava": ['mw'],
    "ādityakāntā": ['mw'],
    "ādityakīlaka": ['mw'],
    "ādityaloka": ['mw'],
    "ādityamaṇḍala": ['cae', 'mw'],
    "ādityanāman": ['mw'],
    "ādityaparṇikā": ['mw'],
    "ādityaparṇin": ['mw'],
    "ādityaparṇinī": ['mw'],
    "ādityapattra": ['mw'],
    "ādityaprabha": ['mw'],
    "ādityapurāṇa": ['mw'],
    "ādityapuṣpikā": ['mw'],
    "ādityapāka": ['mw'],
    "ādityapātra": ['mw'],
    "ādityarāma": ['mw'],
    "ādityasaṃbhava": ['bhs'],
    "ādityasaṃkāśa": ['cae'],
    "ādityasaṃvatsara": ['mw'],
    "ādityasena": ['mw'],
    "ādityasthālī": ['mw'],
    "ādityastotra": ['mw'],
    "ādityasvāmin": ['mw'],
    "ādityasūkta": ['mw'],
    "ādityasūnu": ['mw'],
    "ādityateja": ['bhs'],
    "ādityatejas": ['mw'],
    "ādityatva": ['mw'],
    "ādityatīrtha": ['mw'],
    "ādityavallabhā": ['mw'],
    "ādityavani": ['mw'],
    "ādityavarcas": ['cae'],
    "ādityavardhana": ['mw'],
    "ādityavarman": ['mw'],
    "ādityavarṇa": ['cae', 'mw'],
    "ādityavat": ['cae', 'mw'],
    "ādityavidhi": ['mw'],
    "ādityavrata": ['mw'],
    "ādityavratika": ['mw'],
    "ādityavāra": ['mw'],
    "ādityayaśas": ['mw'],
    "ādityaśakti": ['mw'],
    "ādityaśayana": ['mw'],
    "ādityaśayanavrata": ['mw'],
    "ādityā": ['mw'],
    "ādityācārya": ['mw'],
    "ādityānuvartin": ['mw'],
    "āditā": ['ap90', 'mw'],
    "āditāla": ['mw'],
    "ādivaktṛ": ['mw'],
    "ādivarāha": ['mw'],
    "ādivaṃśa": ['cae', 'mw'],
    "ādivipulā": ['mw'],
    "ādivārāha": ['mw'],
    "ādivārāhatīrtha": ['mw'],
    "ādiya": ['cped'],
    "ādiyamukha": ['cped'],
    "ādiyamāna": ['cped'],
    "ādiyanapaccayā": ['cped'],
    "ādiyanta": ['cped'],
    "ādiyapeti": ['cped'],
    "ādiyat": ['cped'],
    "ādiyati": ['bhs', 'cped'],
    "ādiyi": ['cped'],
    "ādiyituṁ": ['cped'],
    "ādiyitvā": ['cped'],
    "ādiyogācārya": ['mw'],
    "ādiyāmala": ['mw'],
    "ādiś": ['ap90', 'cae', 'gra', 'mw'],
    "ādiśakti": ['mw'],
    "ādiśarīra": ['mw'],
    "ādiśati": ['bhs'],
    "ādiśya": ['mw'],
    "ādiśābdika": ['mw'],
    "ādiśūra": ['mw'],
    "ādiṇṇasipātika": ['cped'],
    "ādiṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādiṣṭin": ['ap90', 'cae', 'mw'],
    "ādo": ['mw'],
    "ādrava": ['mw'],
    "ādrisāra": ['ap90', 'mw'],
    "ādru": ['mw'],
    "ādu": ['cped', 'mw'],
    "āduh": ['mw'],
    "ādumā": ['bhs'],
    "āduri": ['ap90', 'gra', 'mw'],
    "ādvādaśa": ['gra'],
    "ādvādaśam": ['ddsa', 'mw'],
    "ādvāram": ['mw'],
    "ādya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādyabīja": ['mw'],
    "ādyagaṅgā": ['mw'],
    "ādyakavi": ['mw'],
    "ādyakālaka": ['mw'],
    "ādyamāṣaka": ['mw'],
    "ādyanta": ['cae', 'ddsa', 'mw'],
    "ādyantavant": ['cae'],
    "ādyantavat": ['mw'],
    "ādyantayamaka": ['mw'],
    "ādyartvij": ['mw'],
    "ādyota": ['mw'],
    "ādyotaḥ": ['ap90'],
    "ādyudātta": ['ddsa', 'mw'],
    "ādyudāttatva": ['mw'],
    "ādyut": ['mw'],
    "ādyā": ['mw'],
    "ādyādi": ['mw'],
    "ādyādya": ['cae', 'ddsa', 'mw'],
    "ādyūna": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādā": ['ap90', 'mw'],
    "ādādika": ['ap90', 'ddsa', 'mw'],
    "ādāhana": ['ddsa'],
    "ādāna": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ādānanitya": ['cae'],
    "ādānasamiti": ['mw'],
    "ādānasatta": ['cped'],
    "ādānavat": ['mw'],
    "ādānaṃ": ['ap90'],
    "ādānī": ['mw'],
    "ādāpana": ['mw'],
    "ādāpanaṃ": ['ap90'],
    "ādāra": ['ddsa', 'gra', 'mw'],
    "ādārabimbī": ['mw'],
    "ādāraḥ": ['ap90'],
    "ādāribimbī": ['mw'],
    "ādārin": ['ap90', 'gra', 'mw'],
    "ādārita": ['bhs'],
    "ādāsa": ['cped'],
    "ādāsaka": ['cped'],
    "ādāta": ['cped'],
    "ādātabba": ['cped'],
    "ādātar": ['cped'],
    "ādātavya": ['mw'],
    "ādātuṁ": ['cped'],
    "ādātṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādāya": ['ap90', 'cae', 'cped', 'mw'],
    "ādāyacara": ['mw'],
    "ādāyagamanīya": ['cped'],
    "ādāyamāna": ['mw'],
    "ādāyaḥ": ['ap90'],
    "ādāye": ['bhs'],
    "ādāyin": ['ap90', 'mw'],
    "ādī": ['mw'],
    "ādīdhi": ['mw'],
    "ādīdi": ['mw'],
    "ādīkaroti": ['bhs'],
    "ādīnava": ['bhs', 'cped', 'mw'],
    "ādīnavadassa": ['cped'],
    "ādīnavadassāvi": ['cped'],
    "ādīnavadassāvin": ['cped'],
    "ādīnavanupassi": ['cped'],
    "ādīnavanupassin": ['cped'],
    "ādīnavaḥ": ['ap90'],
    "ādīp": ['ap90', 'mw'],
    "ādīpaka": ['mw'],
    "ādīpana": ['mw'],
    "ādīpanaṃ": ['ap90'],
    "ādīpita": ['ap90', 'mw'],
    "ādīpta": ['cae', 'mw'],
    "ādīptaka": ['bhs'],
    "ādīptaśiraścailopama": ['bhs'],
    "ādīpya": ['mw'],
    "ādīrgha": ['ddsa', 'mw'],
    "ādīrya": ['mw'],
    "ādīyaka": ['bhs'],
    "ādīyati": ['bhs'],
    "ādīś": ['ddsa'],
    "ādīśe": ['ddsa'],
    "ādīśvara": ['mw'],
    "ādūna": ['mw'],
    "ādṛ": ['ap90', 'mw'],
    "ādṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "ādṛtya": ['mw'],
    "ādṛś": ['ap90', 'mw'],
    "ādṛśyā": ['bhs'],
    "ādṛṣṭi": ['mw'],
    "ādṛṣṭigocaram": ['ddsa', 'mw'],
    "ādṛṣṭiprasaram": ['mw'],
    "ādṛṣṭiḥ": ['ap90'],
    "ādṝ": ['ap90', 'mw'],
    "āga": ['ap90', 'cped', 'mw'],
    "āgacchana": ['cped'],
    "āgacchanta": ['cped'],
    "āgacchati": ['bhs', 'cped'],
    "āgacchi": ['cped'],
    "āgacchissati": ['cped'],
    "āgacchiṁ": ['cped'],
    "āgacchiṁsu": ['cped'],
    "āgacchuṁ": ['cped'],
    "āgadhita": ['cae', 'mw'],
    "āgai": ['ap90', 'mw'],
    "āgalita": ['ap90', 'mw'],
    "āgam": ['ap90', 'mw'],
    "āgama": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "āgamacandrikā": ['mw'],
    "āgamakalpadruma": ['mw'],
    "āgamakaumudī": ['mw'],
    "āgamakṛsara": ['mw'],
    "āgamana": ['bhs', 'cae', 'cped', 'mw'],
    "āgamanadiṭṭhika": ['cped'],
    "āgamanagamanā": ['bhs'],
    "āgamanatas": ['mw'],
    "āgamanaṃ": ['ap90'],
    "āgamanirapekṣa": ['mw'],
    "āgamanīya": ['cped'],
    "āgamaprakāśa": ['mw'],
    "āgamarahasya": ['mw'],
    "āgamasaṃhita": ['mw'],
    "āgamatattvasaṃgraha": ['mw'],
    "āgamavant": ['cae'],
    "āgamavat": ['ap90', 'mw'],
    "āgamavirodha": ['mw'],
    "āgamayamāna": ['cped'],
    "āgamayati": ['bhs', 'cped'],
    "āgamaśaṣkulī": ['mw'],
    "āgamaśruti": ['mw'],
    "āgamaśāstra": ['mw'],
    "āgamaḥ": ['ap90'],
    "āgamaṁ": ['cped'],
    "āgamaṁsu": ['cped'],
    "āgamenta": ['cped'],
    "āgamesi": ['cped'],
    "āgamesuṁ": ['cped'],
    "āgametabba": ['cped'],
    "āgameti": ['cped'],
    "āgametvā": ['cped'],
    "āgamha": ['cped'],
    "āgamhā": ['cped'],
    "āgami": ['cped'],
    "āgamika": ['bhs', 'mw'],
    "āgamin": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "āgamissati": ['cped'],
    "āgamita": ['mw'],
    "āgamitthā": ['cped'],
    "āgamiṁ": ['cped'],
    "āgamiṣṭha": ['ap90', 'gra', 'mw'],
    "āgamma": ['cped'],
    "āgamuṁ": ['cped'],
    "āgamya": ['bhs', 'mw'],
    "āgamā": ['cped'],
    "āgamāpāyin": ['cae', 'mw'],
    "āgamāsi": ['cped'],
    "āgamāsiṁ": ['cped'],
    "āganta": ['cped'],
    "āgantabba": ['cped'],
    "āgantar": ['cped'],
    "āgantavya": ['cae', 'ddsa', 'mw'],
    "āgantos": ['mw'],
    "āgantu": ['cae', 'mw'],
    "āgantuja": ['mw'],
    "āgantuka": ['cae', 'cped', 'mw'],
    "āgantuṁ": ['cped'],
    "āgantvā": ['cped'],
    "āgantṛ": ['cae', 'mw'],
    "āgara": ['mw'],
    "āgarava": ['mw'],
    "āgaraḥ": ['ap90'],
    "āgarbham": ['mw'],
    "āgarbhanirgama": ['cae'],
    "āgarin": ['mw'],
    "āgas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āgaskārin": ['mw'],
    "āgaskṛt": ['mw'],
    "āgaskṛta": ['mw'],
    "āgastya": ['ap90', 'cae', 'ddsa', 'mw'],
    "āgastyāyana": ['ap90'],
    "āgastī": ['ap90', 'mw'],
    "āgastīya": ['ap90', 'mw'],
    "āgasvin": ['mw'],
    "āgata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "āgataka": ['bhs'],
    "āgatakṣobha": ['mw'],
    "āgatamatsya": ['mw'],
    "āgatanandin": ['mw'],
    "āgatanardin": ['mw'],
    "āgataprahārin": ['mw'],
    "āgatarohin": ['mw'],
    "āgatasādhvasa": ['mw'],
    "āgatatva": ['mw'],
    "āgatavañcin": ['mw'],
    "āgatavisa": ['cped'],
    "āgatavismaya": ['mw'],
    "āgatayodhin": ['mw'],
    "āgati": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "āgatigati": ['bhs'],
    "āgatika": ['bhs'],
    "āgatiḥ": ['ap90'],
    "āgatya": ['mw'],
    "āgatāgama": ['cped', 'mw'],
    "āgatāgata": ['cped'],
    "āgatāstha": ['mw'],
    "āgavīna": ['ap90', 'mw'],
    "āgañchi": ['cped'],
    "āgañchiṁ": ['cped'],
    "āgañchiṁsu": ['cped'],
    "āgañchu": ['cped'],
    "āgañchuṁ": ['cped'],
    "āgaṃtavya": ['ap90'],
    "āgaṃtu": ['ap90'],
    "āgaṃtuka": ['ap90'],
    "āgaṇḍa": ['ddsa', 'mw'],
    "āgeya": ['mw'],
    "āghamarṣaṇa": ['mw'],
    "āgharate": ['bhs'],
    "āghargharam": ['cae', 'ddsa', 'mw'],
    "āgharṣa": ['ddsa', 'mw'],
    "āgharṣaḥ": ['ap90'],
    "āgharṣaṇa": ['mw'],
    "āgharṣaṇī": ['mw'],
    "āghatana": ['bhs'],
    "āghaṭana": ['bhs'],
    "āghaṭṭ": ['ap90', 'mw'],
    "āghaṭṭaka": ['ap90', 'mw'],
    "āghaṭṭalikā": ['mw'],
    "āghaṭṭana": ['bhs', 'mw'],
    "āghaṭṭanā": ['ap90', 'ddsa', 'mw'],
    "āghnat": ['mw'],
    "āghnāna": ['mw'],
    "āghnīya": ['mw'],
    "āghoṣa": ['mw'],
    "āghoṣayat": ['mw'],
    "āghoṣaḥ": ['ap90'],
    "āghoṣaṇaṃ": ['ap90'],
    "āghoṣaṇā": ['cae', 'ddsa', 'mw'],
    "āghoṣita": ['mw'],
    "āghoṣiṇī": ['mw'],
    "āghreya": ['mw'],
    "āghrā": ['ap90', 'mw'],
    "āghrāta": ['ap90', 'mw'],
    "āghrāṇa": ['ap90', 'ddsa', 'mw'],
    "āghuṣ": ['ap90', 'mw'],
    "āghāra": ['mw'],
    "āghāraḥ": ['ap90'],
    "āghāraṇa": ['mw'],
    "āghāta": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "āghātakāla": ['mw'],
    "āghātana": ['bhs', 'cped', 'mw'],
    "āghātanaṃ": ['ap90'],
    "āghātapaṭivinaya": ['cped'],
    "āghātasthāna": ['mw'],
    "āghātavatthu": ['cped'],
    "āghātayati": ['bhs'],
    "āghātaḥ": ['ap90'],
    "āghātin": ['bhs'],
    "āghāṭa": ['cae', 'ddsa', 'mw'],
    "āghāṭaḥ": ['ap90'],
    "āghāṭi": ['gra', 'mw'],
    "āghāṭiḥ": ['ap90'],
    "āghūrṇ": ['ap90', 'mw'],
    "āghūrṇa": ['mw'],
    "āghūrṇana": ['mw'],
    "āghūrṇanaṃ": ['ap90'],
    "āghūrṇita": ['mw'],
    "āghṛ": ['ap90', 'mw'],
    "āghṛṇi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āghṛṇīvasu": ['cae', 'gra', 'mw'],
    "āgilāyati": ['bhs', 'cped'],
    "āglā": ['mw'],
    "āglāyati": ['bhs'],
    "āgnendra": ['mw'],
    "āgneya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "āgneyaindra": ['mw'],
    "āgneyaindrā": ['mw'],
    "āgneyapurāṇa": ['mw'],
    "āgneyapāvamānī": ['mw'],
    "āgneyyaindrī": ['mw'],
    "āgneyāstra": ['mw'],
    "āgneyī": ['bhs', 'mw'],
    "āgneṃdra": ['ap90'],
    "āgnidatteya": ['mw'],
    "āgnihotrika": ['mw'],
    "āgnika": ['ap90', 'cae', 'ddsa', 'mw'],
    "āgnimāruta": ['ap90', 'ddsa', 'mw'],
    "āgnipada": ['ap90', 'mw'],
    "āgnipātnīvatī": ['mw'],
    "āgnipāvamānī": ['mw'],
    "āgniveśi": ['gra', 'mw'],
    "āgniveśya": ['mw'],
    "āgniveśyāyana": ['mw'],
    "āgnivāruṇa": ['mw'],
    "āgniśarmi": ['mw'],
    "āgniśarmāyaṇa": ['mw'],
    "āgniśarmīya": ['mw'],
    "āgniṣṭomika": ['ap90', 'mw'],
    "āgniṣṭomya": ['mw'],
    "āgniṣṭomīya": ['mw'],
    "āgnyādheyika": ['mw'],
    "āgnyādhānikī": ['ap90'],
    "āgnāpauṣṇa": ['ap90', 'mw'],
    "āgnāvaiṣṇava": ['ap90', 'ddsa', 'mw'],
    "āgnīdhra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āgnīdhraka": ['mw'],
    "āgnīdhrya": ['ap90', 'mw'],
    "āgnīdhrā": ['mw'],
    "āgnīdhrī": ['mw'],
    "āgnīdhrīya": ['ap90', 'cae', 'mw'],
    "āgnīndra": ['mw'],
    "āgomuc": ['mw'],
    "āgopāla": ['mw'],
    "āgrabhojanika": ['mw'],
    "āgrabhojanikaḥ": ['ap90'],
    "āgrah": ['ap90', 'mw'],
    "āgraha": ['bhs', 'ddsa', 'mw'],
    "āgrahaḥ": ['ap90'],
    "āgraheṇa": ['mw'],
    "āgrahikā": ['ap90'],
    "āgrahārika": ['ap90', 'mw'],
    "āgrahāt": ['mw'],
    "āgrahāyaṇa": ['mw'],
    "āgrahāyaṇaka": ['ap90', 'mw'],
    "āgrahāyaṇam": ['mw'],
    "āgrahāyaṇaḥ": ['ap90'],
    "āgrahāyaṇi": ['mw'],
    "āgrahāyaṇika": ['ap90', 'mw'],
    "āgrahāyaṇī": ['cae', 'ddsa', 'mw'],
    "āgranth": ['mw'],
    "āgrantham": ['mw'],
    "āgranthana": ['mw'],
    "āgras": ['mw'],
    "āgrasta": ['mw'],
    "āgrathana": ['ddsa', 'mw'],
    "āgrathita": ['bhs'],
    "āgrayaṇa": ['cae', 'ddsa', 'mw'],
    "āgrayaṇaka": ['cae', 'mw'],
    "āgrayaṇapātra": ['mw'],
    "āgrayaṇasthālī": ['mw'],
    "āgrayaṇaḥ": ['ap90'],
    "āgrayaṇeṣṭi": ['mw'],
    "āgrayaṇāgra": ['mw'],
    "āgrayaṇī": ['mw'],
    "āgrayaṇīya": ['mw'],
    "āgreya": ['mw'],
    "āgrāyaṇa": ['mw'],
    "āgrīvanīya": ['bhs'],
    "āgu": ['cped'],
    "āgucāri": ['cped'],
    "āgucārin": ['cped'],
    "āguhyakādhipati": ['bhs'],
    "āgur": ['ap90', 'cae', 'ddsa', 'mw'],
    "āgurava": ['ap90', 'ddsa', 'mw'],
    "āguraṇa": ['mw'],
    "āguraṇaṃ": ['ap90'],
    "āguṁ": ['cped'],
    "āguṇṭhita": ['mw'],
    "āgā": ['cped', 'gra', 'mw'],
    "āgādha": ['ap90', 'mw'],
    "āgāmi": ['cped'],
    "āgāmika": ['ap90', 'bhs', 'mw'],
    "āgāmin": ['cae', 'cped', 'ddsa', 'mw'],
    "āgāmuka": ['ap90', 'cae', 'ddsa', 'mw'],
    "āgāna": ['mw'],
    "āgānaṃ": ['ap90'],
    "āgāntu": ['mw'],
    "āgāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "āgāradhūma": ['mw'],
    "āgāradāha": ['mw'],
    "āgāradāhin": ['mw'],
    "āgāragodhikā": ['mw'],
    "āgāraka": ['cped'],
    "āgāraṃ": ['ap90'],
    "āgārika": ['bhs', 'cped', 'mw'],
    "āgātṛ": ['ap90', 'mw'],
    "āgāvīya": ['mw'],
    "āgāḍhatara": ['bhs'],
    "āgāḍhīkaroti": ['bhs'],
    "āgāḷha": ['cped'],
    "āgīgrāma": ['mw'],
    "āgīta": ['mw'],
    "āgū": ['cped'],
    "āgūraṇaṃ": ['ap90'],
    "āgūrta": ['mw'],
    "āgūrtin": ['ap90', 'mw'],
    "āgūrya": ['mw'],
    "āgūrṇa": ['ap90', 'mw'],
    "āgūḥ": ['ap90'],
    "āgūḥkaraṇa": ['mw'],
    "āgṛhīta": ['bhs'],
    "āgṝ": ['mw'],
    "āha": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "āhacca": ['cped'],
    "āhacca tiṭṭhati": ['cped'],
    "āhaccapādaka": ['cped'],
    "āhaka": ['mw'],
    "āhakaḥ": ['ap90'],
    "āhalak": ['mw'],
    "āhalam": ['mw'],
    "āhan": ['ap90', 'mw'],
    "āhanana": ['cae', 'ddsa', 'mw'],
    "āhananaprakāra": ['mw'],
    "āhananaṃ": ['ap90'],
    "āhananya": ['mw'],
    "āhananīya": ['ap90'],
    "āhanas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āhanasya": ['mw'],
    "āhanasyā": ['mw'],
    "āhara": ['ap90', 'ddsa', 'mw'],
    "āharaceṭā": ['mw'],
    "āharahattha": ['cped'],
    "āharakaraṭā": ['mw'],
    "āharanivapā": ['mw'],
    "āharaniṣkirā": ['mw'],
    "āharanta": ['cped'],
    "āharasenā": ['mw'],
    "āharati": ['cped'],
    "āharavanitā": ['mw'],
    "āharavasanā": ['mw'],
    "āharavitanā": ['mw'],
    "āharaṇa": ['ap90', 'bhs', 'cae', 'mw'],
    "āharaṇatā": ['bhs'],
    "āharaṇīkṛ": ['mw'],
    "āharesi": ['cped'],
    "āhareti": ['cped'],
    "āhari": ['cped'],
    "āharima": ['cped'],
    "āharissami": ['cped'],
    "āharissati": ['cped'],
    "āharit": ['cped'],
    "āharita": ['cped'],
    "āharitr": ['cped'],
    "āharituṁ": ['cped'],
    "āharitvā": ['cped'],
    "āhariyati": ['cped'],
    "āhariyitha": ['cped'],
    "āhariyyati": ['cped'],
    "āhariṁsu": ['cped'],
    "āhartṛ": ['ap90', 'cae', 'mw'],
    "āhary": ['mw'],
    "āharāpayati": ['cped'],
    "āharāpeti": ['cped'],
    "āharāpetvā": ['cped'],
    "āhasa": ['ddsa', 'mw'],
    "āhaspatya": ['mw'],
    "āhata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "āhataka": ['bhs', 'cped'],
    "āhatalakṣaṇa": ['mw'],
    "āhatavisargatā": ['mw'],
    "āhati": ['cae', 'ddsa', 'mw'],
    "āhatiḥ": ['ap90'],
    "āhatta": ['cped'],
    "āhattar": ['cped'],
    "āhattuṁ": ['cped'],
    "āhatvā": ['cped'],
    "āhatya": ['mw'],
    "āhatyavacana": ['mw'],
    "āhatyavāda": ['mw'],
    "āhava": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āhavabhūmi": ['mw'],
    "āhavakāmyā": ['mw'],
    "āhavana": ['cae', 'gra', 'mw'],
    "āhavanaṃ": ['ap90'],
    "āhavanīya": ['ap90', 'bhs', 'cae', 'mw'],
    "āhavanīyaka": ['ap90', 'mw'],
    "āhavanīyatas": ['mw'],
    "āhavanīyāgāra": ['cae'],
    "āhavaśobhin": ['mw'],
    "āhavaḥ": ['ap90'],
    "āhañchaṁ": ['cped'],
    "āhañhi": ['cped'],
    "āhañhiṁ": ['cped'],
    "āhaṁsu": ['cped'],
    "āhaṃkārika": ['mw'],
    "āhaṃkārya": ['mw'],
    "āhaṃkāryaṃ": ['ap90'],
    "āhaṭa": ['cped'],
    "āhetuka": ['bhs'],
    "āheya": ['ap90', 'ddsa', 'mw'],
    "āhi": ['ddsa', 'mw'],
    "āhicchattra": ['mw'],
    "āhicchattrika": ['mw'],
    "āhika": ['mw'],
    "āhikaḥ": ['ap90'],
    "āhimata": ['mw'],
    "āhirbudhna": ['ddsa'],
    "āhirbudhnya": ['cae', 'mw'],
    "āhirbundha": ['cae'],
    "āhita": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "āhitaklama": ['mw'],
    "āhitalakṣaṇa": ['mw'],
    "āhitasamitka": ['mw'],
    "āhiti": ['cae', 'mw'],
    "āhitiḥ": ['ap90'],
    "āhituṃḍikaḥ": ['ap90'],
    "āhituṇḍika": ['ddsa', 'mw'],
    "āhitāgni": ['cae', 'mw'],
    "āhitāgnyādi": ['mw'],
    "āhitāṅka": ['mw'],
    "āhiṃs": ['mw'],
    "āhiṃsi": ['mw'],
    "āhiṃsāyana": ['mw'],
    "āhiṃḍ": ['ap90'],
    "āhiṃḍikaḥ": ['ap90'],
    "āhiṇḍ": ['mw'],
    "āhiṇḍaka": ['cae', 'ddsa', 'mw'],
    "āhiṇḍanta": ['cped'],
    "āhiṇḍati": ['bhs', 'cped'],
    "āhiṇḍika": ['cae'],
    "āhiṇḍituṁ": ['cped'],
    "āhlād": ['mw'],
    "āhlāda": ['cae', 'mw'],
    "āhlādadugha": ['mw'],
    "āhlādaka": ['cae', 'mw'],
    "āhlādakara": ['cae', 'mw'],
    "āhlādakārin": ['cae', 'mw'],
    "āhlādalaharī": ['mw'],
    "āhlādana": ['ap90', 'mw'],
    "āhlādanīya": ['mw'],
    "āhlādaḥ": ['ap90'],
    "āhlādin": ['ap90', 'cae', 'mw'],
    "āhlādita": ['mw'],
    "āhna": ['ap90', 'mw'],
    "āhneya": ['mw'],
    "āhnika": ['ap90', 'cae', 'mw'],
    "āhnikacandrikā": ['mw'],
    "āhnikadīpaka": ['mw'],
    "āhnikamañjarī": ['mw'],
    "āhnikapradīpa": ['mw'],
    "āhnikaprayoga": ['mw'],
    "āhnikasāra": ['mw'],
    "āhnikatattva": ['mw'],
    "āhnikācāra": ['mw'],
    "āhnikācāratattva": ['mw'],
    "āho": ['ap90', 'cae', 'ddsa', 'mw'],
    "āhopuruṣikā": ['mw'],
    "āhosvit": ['mw'],
    "āhruta": ['ap90', 'mw'],
    "āhrutabheṣaja": ['mw'],
    "āhrīkya": ['bhs', 'mw'],
    "āhu": ['ap90', 'cped', 'mw'],
    "āhuka": ['mw'],
    "āhukaḥ": ['ap90'],
    "āhukī": ['mw'],
    "āhulya": ['mw'],
    "āhulyaṃ": ['ap90'],
    "āhuna": ['cped'],
    "āhundarika": ['cped'],
    "āhuneyya": ['cped'],
    "āhuneyyaggi": ['cped'],
    "āhuta": ['ap90', 'cae', 'cped', 'mw'],
    "āhuti": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "āhutibhāga": ['mw'],
    "āhutibhāj": ['mw'],
    "āhutikṛta": ['mw'],
    "āhutimaya": ['mw'],
    "āhutiparimāṇa": ['mw'],
    "āhutivat": ['mw'],
    "āhutiḥ": ['ap90'],
    "āhutiṣṭakā": ['mw'],
    "āhutī": ['mw'],
    "āhutībhū": ['mw'],
    "āhutīkṛ": ['cae', 'ddsa', 'mw'],
    "āhutīvṛdh": ['gra', 'mw'],
    "āhutīṣahi": ['mw'],
    "āhutīṣṭakā": ['mw'],
    "āhuva": ['mw'],
    "āhva": ['ap90', 'mw'],
    "āhvara": ['mw'],
    "āhvaraka": ['mw'],
    "āhvarakantha": ['mw'],
    "āhvarakaḥ": ['ap90'],
    "āhvaya": ['bhs', 'cae', 'ddsa', 'mw'],
    "āhvayana": ['ap90', 'cae', 'mw'],
    "āhvayaḥ": ['ap90'],
    "āhvayitavya": ['mw'],
    "āhve": ['ap90', 'mw'],
    "āhvā": ['ddsa', 'mw'],
    "āhvāna": ['cae', 'ddsa', 'mw'],
    "āhvānadarśana": ['mw'],
    "āhvānana": ['bhs', 'mw'],
    "āhvānay": ['cae'],
    "āhvānaya": ['ddsa', 'mw'],
    "āhvānayati": ['ap90'],
    "āhvānaṃ": ['ap90'],
    "āhvāraka": ['mw'],
    "āhvārakaḥ": ['ap90'],
    "āhvātṛ": ['ddsa', 'mw'],
    "āhvāya": ['mw'],
    "āhvāyaka": ['ap90', 'ddsa', 'mw'],
    "āhvāyayitavya": ['ddsa', 'mw'],
    "āhvāyaḥ": ['ap90'],
    "āhvāyikā": ['mw'],
    "āhvṛ": ['ap90', 'mw'],
    "āhvṛti": ['ap90', 'mw'],
    "āhāra": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "āhārabhūmi": ['mw'],
    "āhāradāna": ['cae'],
    "āhāraka": ['ap90', 'bhs', 'mw'],
    "āhāranirgamasthāna": ['mw'],
    "āhāraniḥsaraṇamārga": ['mw'],
    "āhārapāka": ['mw'],
    "āhārasaṃbhava": ['mw'],
    "āhāraviraha": ['ddsa', 'mw'],
    "āhāravṛtti": ['mw'],
    "āhāraya": ['cped', 'ddsa', 'mw'],
    "āhārayamāna": ['cped'],
    "āhārayat": ['cped'],
    "āhārayati": ['cped'],
    "āhārayojana": ['mw'],
    "āhāraśuddhi": ['mw'],
    "āhāraṭṭhika": ['cped'],
    "āhāresiṁ": ['cped'],
    "āhāreti": ['cped'],
    "āhāretvā": ['cped'],
    "āhārika": ['bhs', 'mw'],
    "āhārikaṃ": ['ap90'],
    "āhārin": ['mw'],
    "āhārisaṁ": ['cped'],
    "āhārupaccheda": ['cped'],
    "āhārupahāra": ['cped'],
    "āhārya": ['ap90', 'ddsa', 'mw'],
    "āhāryapādaka": ['bhs'],
    "āhāryaśobhā": ['mw'],
    "āhārārthin": ['cae', 'mw'],
    "āhāsi": ['cped'],
    "āhāva": ['gra', 'mw'],
    "āhāvaḥ": ['ap90'],
    "āhīnta": ['cae', 'mw'],
    "āhīraṇin": ['ap90'],
    "āhū": ['cae', 'gra', 'mw'],
    "āhūria": ['gra'],
    "āhūrya": ['ap90', 'gra', 'mw'],
    "āhūta": ['ap90', 'cae', 'mw'],
    "āhūtaprapalāyin": ['cae', 'ddsa', 'mw'],
    "āhūtavya": ['ddsa', 'mw'],
    "āhūti": ['cae', 'ddsa', 'mw'],
    "āhūtiḥ": ['ap90'],
    "āhūtādhyāyin": ['ddsa', 'mw'],
    "āhūya": ['mw'],
    "āhūḥ": ['ap90'],
    "āhṛ": ['ap90', 'mw'],
    "āhṛta": ['mw'],
    "āhṛtaka": ['bhs'],
    "āhṛtayajñakratu": ['mw'],
    "āhṛti": ['mw'],
    "āhṛtya": ['mw'],
    "āhṛṣ": ['mw'],
    "āhṛṣṭa": ['bhs'],
    "āi": ['mw'],
    "āindh": ['mw'],
    "āinv": ['mw'],
    "āiṣ": ['mw'],
    "āiṣṭi": ['gra'],
    "āj": ['mw'],
    "āja": ['ap90', 'cae', 'ddsa', 'mw'],
    "ājabandhavi": ['mw'],
    "ājadhenavi": ['mw'],
    "ājagamuṁ": ['cped'],
    "ājagara": ['ap90', 'ddsa', 'mw'],
    "ājagava": ['mw'],
    "ājagavaṃ": ['ap90'],
    "ājagāva": ['mw'],
    "ājaka": ['mw'],
    "ājakaroṇa": ['mw'],
    "ājakaṃ": ['ap90'],
    "ājakeśin": ['mw'],
    "ājakrandaka": ['mw'],
    "ājakrandi": ['mw'],
    "ājakāra": ['mw'],
    "ājakāraḥ": ['ap90'],
    "ājamārya": ['mw'],
    "ājamāyava": ['mw'],
    "ājamīl̤ha": ['mw'],
    "ājamīḍha": ['ap90', 'cae', 'gra', 'mw'],
    "ājamīḍhaka": ['mw'],
    "ājamīḍhi": ['mw'],
    "ājan": ['ap90', 'mw'],
    "ājanana": ['mw'],
    "ājananaṃ": ['ap90'],
    "ājananta": ['cped'],
    "ājani": ['mw'],
    "ājaniḥ": ['ap90'],
    "ājanma": ['ap90', 'ddsa', 'mw'],
    "ājanmasurabhipattra": ['mw'],
    "ājanya": ['bhs'],
    "ājap": ['mw'],
    "ājapathika": ['mw'],
    "ājapāda": ['mw'],
    "ājarasa": ['gra'],
    "ājarasam": ['ddsa', 'mw'],
    "ājarasāya": ['mw'],
    "ājarjarita": ['ddsa', 'mw'],
    "ājasrika": ['mw'],
    "ājavana": ['mw'],
    "ājavanaṃ": ['ap90'],
    "ājavasteya": ['mw'],
    "ājavaṃjava": ['bhs'],
    "ājavaṃjavatā": ['bhs'],
    "ājavaṃjavībhāva": ['bhs'],
    "ājavāha": ['mw'],
    "ājavāhaka": ['mw'],
    "ājayana": ['mw'],
    "ājayanaṃ": ['ap90'],
    "ājañña": ['cped'],
    "ājaññaratha": ['cped'],
    "āji": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ājia": ['gra'],
    "ājibhūmi": ['mw'],
    "ājiga": ['mw'],
    "ājigamiṣu": ['mw'],
    "ājighṛkṣu": ['mw'],
    "ājigraha": ['ap90'],
    "ājigīṣu": ['ap90', 'mw'],
    "ājihmita": ['ddsa', 'mw'],
    "ājihīna": ['mw'],
    "ājihīrṣu": ['mw'],
    "ājijityā": ['mw'],
    "ājijñāsenya": ['ap90'],
    "ājijñāsenyā": ['mw'],
    "ājikṛt": ['gra', 'mw'],
    "ājimukha": ['cae', 'mw'],
    "ājinv": ['mw'],
    "ājipati": ['gra', 'mw'],
    "ājireya": ['ap90', 'mw'],
    "ājiri": ['ap90', 'mw'],
    "ājisṛt": ['mw'],
    "ājitur": ['gra', 'mw'],
    "ājiśiras": ['mw'],
    "ājiśobhin": ['mw'],
    "ājiḥ": ['ap90'],
    "ājjava": ['cped'],
    "ājuhvāna": ['cae'],
    "ājur": ['ap90', 'mw'],
    "ājya": ['cae', 'ddsa', 'gra', 'mw'],
    "ājyabhuj": ['mw'],
    "ājyabhāga": ['mw'],
    "ājyadhanvan": ['mw'],
    "ājyadhānī": ['mw'],
    "ājyadoha": ['mw'],
    "ājyagraha": ['mw'],
    "ājyahavis": ['mw'],
    "ājyahoma": ['mw'],
    "ājyalepa": ['mw'],
    "ājyalipta": ['mw'],
    "ājyanta": ['mw'],
    "ājyapa": ['cae', 'mw'],
    "ājyapātra": ['mw'],
    "ājyasthālī": ['mw'],
    "ājyavilāpanī": ['mw'],
    "ājyavāri": ['mw'],
    "ājyaṃ": ['ap90'],
    "ājyādoha": ['mw'],
    "ājyāhuti": ['mw'],
    "ājñaka": ['bhs'],
    "ājñapta": ['mw'],
    "ājñapti": ['cae', 'ddsa', 'mw'],
    "ājñaptiḥ": ['ap90'],
    "ājñendriya": ['bhs'],
    "ājñeya": ['bhs'],
    "ājñā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ājñābhaṅga": ['cae', 'ddsa', 'mw'],
    "ājñābhaṅgakara": ['mw'],
    "ājñābhaṅgakārin": ['cae', 'mw'],
    "ājñācakra": ['mw'],
    "ājñādāna": ['mw'],
    "ājñākara": ['cae', 'mw'],
    "ājñākaratva": ['mw'],
    "ājñākarī": ['mw'],
    "ājñākārin": ['mw'],
    "ājñākṛta": ['bhs'],
    "ājñāna": ['bhs', 'cae', 'mw'],
    "ājñānaṃ": ['ap90'],
    "ājñāpaka": ['ap90', 'mw'],
    "ājñāpana": ['bhs', 'mw'],
    "ājñāpanaṃ": ['ap90'],
    "ājñāparigraha": ['mw'],
    "ājñāpattra": ['mw'],
    "ājñāpita": ['mw'],
    "ājñāpratighāta": ['mw'],
    "ājñāpya": ['ddsa', 'mw'],
    "ājñāpālana": ['mw'],
    "ājñāsampādin": ['mw'],
    "ājñāta": ['mw'],
    "ājñātakauṇḍinya": ['bhs', 'mw'],
    "ājñātar": ['bhs'],
    "ājñātāvin": ['bhs'],
    "ājñātṛ": ['ap90', 'gra', 'mw'],
    "ājñāvaha": ['mw'],
    "ājñāya": ['mw'],
    "ājñāyin": ['ap90', 'mw'],
    "ājā": ['mw'],
    "ājādya": ['mw'],
    "ājāna": ['cae', 'mw'],
    "ājānadeva": ['mw'],
    "ājānaja": ['mw'],
    "ājānamāna": ['cped'],
    "ājānaḥ": ['ap90'],
    "ājāneya": ['ap90', 'ddsa', 'mw'],
    "ājāneyya": ['ap90', 'mw'],
    "ājāni": ['gra', 'mw'],
    "ājānikya": ['mw'],
    "ājānissati": ['cped'],
    "ājānituṁ": ['cped'],
    "ājānitvā": ['cped'],
    "ājāniya": ['bhs'],
    "ājāniḥ": ['ap90'],
    "ājāniṁsu": ['cped'],
    "ājānu": ['ap90', 'mw'],
    "ājānubāhu": ['mw'],
    "ājānulambin": ['ddsa', 'mw'],
    "ājānusama": ['mw'],
    "ājānā": ['mw'],
    "ājānāti": ['cped'],
    "ājānīya": ['cped'],
    "ājānīyajjāyita": ['cped'],
    "ājāta": ['mw'],
    "ājātaśatrava": ['ddsa', 'mw'],
    "ājātaśātrava": ['mw'],
    "ājāti": ['cae', 'ddsa', 'mw'],
    "ājātiḥ": ['ap90'],
    "ājāvaṃjava": ['bhs'],
    "ājāvika": ['mw'],
    "ājāyana": ['mw'],
    "ājāyati": ['cped'],
    "ājīgarta": ['mw'],
    "ājīgarti": ['cae', 'ddsa', 'mw'],
    "ājīkūla": ['mw'],
    "ājīrṇāntam": ['mw'],
    "ājīv": ['ap90', 'mw'],
    "ājīva": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ājīvaka": ['bhs', 'cped', 'mw'],
    "ājīvakaḥ": ['ap90'],
    "ājīvakinī": ['cped'],
    "ājīvam": ['ddsa', 'mw'],
    "ājīvana": ['mw'],
    "ājīvanika": ['mw'],
    "ājīvati": ['cped'],
    "ājīvaḥ": ['ap90'],
    "ājīvika": ['bhs', 'cped', 'mw'],
    "ājīvikabhaya": ['cped'],
    "ājīvikapakata": ['cped'],
    "ājīvikā": ['ap90'],
    "ājīvikābhaya": ['cped'],
    "ājīvikāpakata": ['cped'],
    "ājīvin": ['ap90', 'mw'],
    "ājīvitāntam": ['cae', 'ddsa', 'mw'],
    "ājīvya": ['ap90', 'mw'],
    "ākac": ['mw'],
    "ākal": ['ap90', 'mw'],
    "ākalana": ['bhs', 'ddsa', 'mw'],
    "ākalanaṃ": ['ap90'],
    "ākalita": ['mw'],
    "ākalla": ['mw'],
    "ākalpa": ['bhs', 'cae', 'ddsa', 'mw'],
    "ākalpaka": ['mw'],
    "ākalpakaḥ": ['ap90'],
    "ākalpam": ['cae', 'ddsa', 'mw'],
    "ākalpasthāyin": ['ddsa', 'mw'],
    "ākalpasāra": ['ddsa'],
    "ākalpaḥ": ['ap90'],
    "ākalpāntam": ['cae', 'mw'],
    "ākaluṣa": ['mw'],
    "ākalya": ['ddsa', 'mw'],
    "ākalyaṃ": ['ap90'],
    "ākamp": ['mw'],
    "ākampa": ['ddsa', 'mw'],
    "ākampana": ['mw'],
    "ākampita": ['mw'],
    "ākampra": ['mw'],
    "ākampya": ['bhs'],
    "ākan": ['mw'],
    "ākapila": ['ddsa', 'mw'],
    "ākapiśa": ['mw'],
    "ākappa": ['cped'],
    "ākappasampanna": ['cped'],
    "ākara": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ākaraja": ['mw'],
    "ākaratīrtha": ['mw'],
    "ākaraḥ": ['ap90'],
    "ākarika": ['mw'],
    "ākarikaḥ": ['ap90'],
    "ākarin": ['ap90', 'mw'],
    "ākarṇ": ['ap90'],
    "ākarṇa": ['cae', 'ddsa', 'mw'],
    "ākarṇaka": ['mw'],
    "ākarṇam": ['mw'],
    "ākarṇamukta": ['mw'],
    "ākarṇamūlam": ['mw'],
    "ākarṇana": ['cae', 'mw'],
    "ākarṇanaṃ": ['ap90'],
    "ākarṇay": ['cae'],
    "ākarṇaya": ['ddsa', 'mw'],
    "ākarṇin": ['mw'],
    "ākarṣa": ['cae', 'ddsa', 'mw'],
    "ākarṣaka": ['ap90', 'mw'],
    "ākarṣakrīḍā": ['mw'],
    "ākarṣakārikā": ['mw'],
    "ākarṣaśva": ['mw'],
    "ākarṣaḥ": ['ap90'],
    "ākarṣaṇa": ['ap90', 'cae', 'mw'],
    "ākarṣaṇā": ['bhs'],
    "ākarṣaṇī": ['mw'],
    "ākarṣika": ['ap90', 'mw'],
    "ākarṣikā": ['mw'],
    "ākarṣin": ['ap90', 'mw'],
    "ākarṣita": ['mw'],
    "ākarṣiṇī": ['mw'],
    "ākarṣādi": ['mw'],
    "ākasmika": ['ap90', 'ddsa', 'mw'],
    "ākatthana": ['mw'],
    "ākatthanaṃ": ['ap90'],
    "ākatya": ['mw'],
    "ākatyaṃ": ['ap90'],
    "ākauśala": ['cae', 'ddsa', 'mw'],
    "ākañcuka": ['bhs'],
    "ākaśāpeya": ['mw'],
    "ākaḍḍhana": ['bhs', 'cped'],
    "ākaḍḍhanta": ['cped'],
    "ākaḍḍhati": ['cped'],
    "ākaḍḍhitva": ['cped'],
    "ākaḍḍhiyamāna": ['cped'],
    "ākaṃp": ['ap90'],
    "ākaṃpana": ['ap90'],
    "ākaṃpaḥ": ['ap90'],
    "ākaṃpita": ['ap90'],
    "ākaṅkha": ['cped'],
    "ākaṅkhamāna": ['cped'],
    "ākaṅkhanta": ['cped'],
    "ākaṅkhat": ['cped'],
    "ākaṅkhati": ['cped'],
    "ākaṅkhita": ['cped'],
    "ākaṅkhiya": ['cped'],
    "ākaṅkhiṁ": ['cped'],
    "ākaṇṭha": ['mw'],
    "ākaṇṭham": ['ddsa', 'mw'],
    "ākaṇṭhatṛpta": ['mw'],
    "ākaṣa": ['mw'],
    "ākaṣaka": ['ap90', 'mw'],
    "ākaṣaḥ": ['ap90'],
    "ākaṣika": ['ap90', 'mw'],
    "ākaṭṭati": ['bhs'],
    "āke": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ākekara": ['ap90', 'cae', 'ddsa', 'mw'],
    "ākenipa": ['ap90', 'gra', 'mw'],
    "ākha": ['mw'],
    "ākhana": ['mw'],
    "ākhanika": ['mw'],
    "ākhanikabaka": ['mw'],
    "ākhanikabakaḥ": ['ap90'],
    "ākhanikaḥ": ['ap90'],
    "ākhara": ['gra', 'mw'],
    "ākharaḥ": ['ap90'],
    "ākhareṣṭha": ['mw'],
    "ākhaḥ": ['ap90'],
    "ākhaṃḍalaḥ": ['ap90'],
    "ākhaṇa": ['ap90', 'mw'],
    "ākhaṇḍala": ['cae', 'ddsa', 'gra', 'mw'],
    "ākhaṇḍalacāpa": ['mw'],
    "ākhaṇḍaladhanus": ['mw'],
    "ākhaṇḍalakakubh": ['mw'],
    "ākhaṇḍalasūnu": ['mw'],
    "ākhaṇḍalā": ['mw'],
    "ākhaṇḍalāśā": ['mw'],
    "ākhaṇḍayitṛ": ['mw'],
    "ākhaṇḍi": ['mw'],
    "ākhaṇḍiśālā": ['mw'],
    "ākhedana": ['mw'],
    "ākheṭa": ['cae', 'ddsa', 'mw'],
    "ākheṭabhūmi": ['mw'],
    "ākheṭaka": ['ap90', 'mw'],
    "ākheṭakāṭavī": ['mw'],
    "ākheṭaśīrṣaka": ['mw'],
    "ākheṭaḥ": ['ap90'],
    "ākheṭika": ['ap90', 'mw'],
    "ākhid": ['mw'],
    "ākhida": ['mw'],
    "ākhidat": ['mw'],
    "ākhilya": ['mw'],
    "ākhoṭa": ['mw'],
    "ākhoṭakatīrtha": ['mw'],
    "ākhoṭaśīrṣaka": ['mw'],
    "ākhoṭaḥ": ['ap90'],
    "ākhu": ['cae', 'ddsa', 'gra', 'mw'],
    "ākhubhuj": ['mw'],
    "ākhuga": ['mw'],
    "ākhughāta": ['mw'],
    "ākhuhan": ['mw'],
    "ākhukarīṣa": ['mw'],
    "ākhukarṇaparṇikā": ['mw'],
    "ākhukarṇī": ['mw'],
    "ākhukiri": ['cae', 'mw'],
    "ākhuparṇikā": ['mw'],
    "ākhuparṇī": ['mw'],
    "ākhupāṣāṇa": ['mw'],
    "ākhuratha": ['mw'],
    "ākhuvagrāma": ['mw'],
    "ākhuviṣahā": ['mw'],
    "ākhuviṣāpahā": ['mw'],
    "ākhuyāna": ['mw'],
    "ākhuśruti": ['mw'],
    "ākhuḥ": ['ap90'],
    "ākhyas": ['mw'],
    "ākhyayā": ['mw'],
    "ākhyeya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ākhyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "ākhyāna": ['cae', 'mw'],
    "ākhyānaka": ['cae', 'mw'],
    "ākhyānakaṃ": ['ap90'],
    "ākhyānakī": ['mw'],
    "ākhyānavid": ['cae', 'mw'],
    "ākhyānaya": ['mw'],
    "ākhyānaṃ": ['ap90'],
    "ākhyāpaka": ['mw'],
    "ākhyāpana": ['mw'],
    "ākhyāpita": ['mw'],
    "ākhyāta": ['ap90', 'bhs', 'cae', 'mw'],
    "ākhyātavya": ['mw'],
    "ākhyāti": ['mw'],
    "ākhyātika": ['mw'],
    "ākhyātiḥ": ['ap90'],
    "ākhyātottara": ['mw'],
    "ākhyātukāma": ['cae'],
    "ākhyātṛ": ['ap90', 'cae', 'mw'],
    "ākhyāyaka": ['ap90'],
    "ākhyāyanī": ['mw'],
    "ākhyāyati": ['bhs'],
    "ākhyāyikā": ['ap90', 'cae', 'mw'],
    "ākhyāyin": ['ap90', 'cae', 'mw'],
    "ākhā": ['mw'],
    "ākhād": ['mw'],
    "ākhāna": ['mw'],
    "ākhānaḥ": ['ap90'],
    "ākhātaḥ": ['ap90'],
    "ākhāyita": ['bhs'],
    "ākhāṭīśvaratīrtha": ['mw'],
    "ākhīṇa": ['cped'],
    "ākhīṇavyappatha": ['cped'],
    "ākhūtkara": ['mw'],
    "ākhūttha": ['mw'],
    "ākidanti": ['mw'],
    "ākidantīya": ['mw'],
    "ākiranta": ['cped'],
    "ākirati": ['bhs', 'cped'],
    "ākiritvā": ['cped'],
    "ākiñcanasambhava": ['cped'],
    "ākiñcanya": ['ddsa'],
    "ākiñcañña": ['cped'],
    "ākiñcaññāyatana": ['cped'],
    "ākiṃcanaṃ": ['ap90'],
    "ākiṃcanya": ['bhs', 'cae', 'mw'],
    "ākiṃcanyānantyāyatana": ['bhs'],
    "ākiṃcanyāyatana": ['bhs', 'mw'],
    "ākiṃcanyāyatanopaga": ['bhs'],
    "ākiṃcityāyatana": ['bhs'],
    "ākiṇṇa": ['cped'],
    "ākiṇṇakammanta": ['cped'],
    "ākiṇṇaloma": ['cped'],
    "ākiṇṇaludda": ['cped'],
    "ākiṇṇamanussa": ['cped'],
    "ākiṇṇavihāra": ['cped'],
    "ākleda": ['mw'],
    "ākledaḥ": ['ap90'],
    "āklinna": ['mw'],
    "āklī": ['ap90', 'mw'],
    "ākna": ['mw'],
    "ākokera": ['mw'],
    "ākokeraḥ": ['ap90'],
    "ākopa": ['ddsa', 'mw'],
    "ākopavat": ['mw'],
    "ākoṣṭham": ['mw'],
    "ākoṭana": ['bhs', 'mw'],
    "ākoṭanā": ['mw'],
    "ākoṭayati": ['bhs', 'cped'],
    "ākoṭesi": ['cped'],
    "ākoṭesuṁ": ['cped'],
    "ākoṭetabba": ['cped'],
    "ākoṭeti": ['cped'],
    "ākoṭetvā": ['cped'],
    "ākoṭita": ['cped'],
    "ākoṭitapaccākoṭita": ['cped'],
    "ākoṭāpeti": ['cped'],
    "ākram": ['ap90', 'mw'],
    "ākrama": ['cae', 'ddsa', 'mw'],
    "ākramati": ['bhs'],
    "ākramaḥ": ['ap90'],
    "ākramaṇa": ['cae', 'mw'],
    "ākramaṇatā": ['bhs'],
    "ākramaṇīya": ['mw'],
    "ākramya": ['mw'],
    "ākramyati": ['bhs'],
    "ākrand": ['mw'],
    "ākranda": ['cae', 'ddsa', 'mw'],
    "ākrandana": ['cae', 'mw'],
    "ākrandanīya": ['mw'],
    "ākrandika": ['mw'],
    "ākrandin": ['mw'],
    "ākrandita": ['mw'],
    "ākraya": ['mw'],
    "ākrayaḥ": ['ap90'],
    "ākrayā": ['mw'],
    "ākraṃd": ['ap90'],
    "ākraṃdanaṃ": ['ap90'],
    "ākraṃdaḥ": ['ap90'],
    "ākraṃdika": ['ap90'],
    "ākraṃdin": ['ap90'],
    "ākraṃdita": ['ap90'],
    "ākraṣṭavya": ['mw'],
    "ākrośa": ['cae', 'ddsa', 'mw'],
    "ākrośaka": ['ap90', 'mw'],
    "ākrośana": ['bhs', 'mw'],
    "ākrośayitṛ": ['mw'],
    "ākrośaḥ": ['ap90'],
    "ākrośin": ['mw'],
    "ākroṣṭṛ": ['mw'],
    "ākruś": ['ap90', 'mw'],
    "ākruṣṭa": ['ap90', 'cae', 'mw'],
    "ākrāmakaḥ": ['ap90'],
    "ākrāmayati": ['bhs'],
    "ākrānta": ['cae', 'ddsa', 'mw'],
    "ākrāntamati": ['mw'],
    "ākrāntanāyakā": ['mw'],
    "ākrānti": ['cae', 'ddsa', 'mw'],
    "ākrāntitas": ['mw'],
    "ākrāṃta": ['ap90'],
    "ākrāṃtiḥ": ['ap90'],
    "ākrī": ['ap90', 'mw'],
    "ākrīta": ['mw'],
    "ākrīḍ": ['ap90', 'mw'],
    "ākrīḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ākrīḍabhūmi": ['mw'],
    "ākrīḍagiri": ['mw'],
    "ākrīḍanaṃ": ['ap90'],
    "ākrīḍaparvata": ['mw'],
    "ākrīḍin": ['ap90', 'mw'],
    "ākta": ['mw'],
    "āktakha": ['mw'],
    "āktākṣa": ['mw'],
    "āktākṣya": ['mw'],
    "ākula": ['ap90', 'cae', 'ddsa', 'mw'],
    "ākulakṛt": ['mw'],
    "ākulatva": ['mw'],
    "ākulatā": ['ap90', 'mw'],
    "ākulay": ['cae'],
    "ākulaya": ['ddsa', 'mw'],
    "ākulayati": ['ap90'],
    "ākulendriya": ['mw'],
    "ākuli": ['cae', 'mw'],
    "ākulita": ['ap90', 'mw'],
    "ākulī": ['mw'],
    "ākulībhāva": ['mw'],
    "ākulībhū": ['ap90'],
    "ākulībhūta": ['mw'],
    "ākulīkaraṇa": ['mw'],
    "ākulīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "ākulīkṛta": ['mw'],
    "ākulīyamāna": ['cae'],
    "ākumāra": ['ddsa'],
    "ākumāram": ['mw'],
    "ākurvatī": ['mw'],
    "ākuñc": ['mw'],
    "ākuñcana": ['ddsa', 'mw'],
    "ākuñcita": ['cae', 'mw'],
    "ākuḍmalīkṛta": ['mw'],
    "ākuṃc": ['ap90'],
    "ākuṃcanaṃ": ['ap90'],
    "ākuṇṭhita": ['mw'],
    "ākuṭ": ['mw'],
    "ākuṭila": ['cae', 'ddsa', 'mw'],
    "ākā": ['mw'],
    "ākāla": ['ddsa', 'mw'],
    "ākālam": ['cae', 'mw'],
    "ākālaḥ": ['ap90'],
    "ākāleyaṃ": ['bhs'],
    "ākālika": ['ap90', 'bhs', 'cae', 'mw'],
    "ākālikā": ['mw'],
    "ākālikātīram": ['ddsa', 'mw'],
    "ākālikī": ['mw'],
    "ākāra": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ākāragopana": ['mw'],
    "ākāragupti": ['mw'],
    "ākāragūhana": ['mw'],
    "ākāramat": ['mw'],
    "ākāraparivitarka": ['bhs'],
    "ākārava": ['cped'],
    "ākāravant": ['cae'],
    "ākāravarṇasuślakṣṇa": ['mw'],
    "ākāravat": ['ap90', 'cped', 'ddsa', 'mw'],
    "ākārayati": ['bhs'],
    "ākāraḥ": ['ap90'],
    "ākāraṇa": ['ddsa', 'mw'],
    "ākāraṇaṃ": ['ap90'],
    "ākāraṇā": ['mw'],
    "ākāraṇīya": ['mw'],
    "ākārita": ['ap90', 'cae', 'ddsa', 'mw'],
    "ākārābhinirhāra": ['bhs'],
    "ākārānavakāra": ['bhs'],
    "ākāsa": ['cped'],
    "ākāsagata": ['cped'],
    "ākāsakasiṇa": ['cped'],
    "ākāsaṅgata": ['cped'],
    "ākāsaṭṭha": ['cped'],
    "ākāsānañcāyatana": ['cped'],
    "ākāya": ['mw'],
    "ākāyam": ['mw'],
    "ākāyaḥ": ['ap90'],
    "ākāyia": ['gra'],
    "ākāyya": ['ap90', 'gra', 'mw'],
    "ākāś": ['ap90', 'mw'],
    "ākāśa": ['bhs', 'cae', 'ddsa', 'mw'],
    "ākāśabaddhalakṣa": ['mw'],
    "ākāśabhāṣita": ['mw'],
    "ākāśacakra": ['mw'],
    "ākāśacamasa": ['mw'],
    "ākāśacārin": ['cae', 'mw'],
    "ākāśadeśa": ['mw'],
    "ākāśadhātuvipula": ['bhs'],
    "ākāśadīpa": ['mw'],
    "ākāśaga": ['cae', 'mw'],
    "ākāśagamana": ['mw'],
    "ākāśagarbha": ['bhs', 'mw'],
    "ākāśagarbhi": ['mw'],
    "ākāśagata": ['mw'],
    "ākāśagati": ['mw'],
    "ākāśagaṅgā": ['mw'],
    "ākāśaja": ['mw'],
    "ākāśajananī": ['mw'],
    "ākāśajñānārthapradīpa": ['bhs'],
    "ākāśakakṣā": ['mw'],
    "ākāśamaya": ['mw'],
    "ākāśamaṇi": ['mw'],
    "ākāśamukhin": ['mw'],
    "ākāśamuṣṭihananāya": ['mw'],
    "ākāśamātar": ['bhs'],
    "ākāśamāṃsī": ['mw'],
    "ākāśamūlī": ['mw'],
    "ākāśapatha": ['mw'],
    "ākāśapathika": ['mw'],
    "ākāśaplavā": ['bhs', 'mw'],
    "ākāśapoli": ['mw'],
    "ākāśapradīpa": ['mw'],
    "ākāśapratiṣṭhita": ['bhs', 'mw'],
    "ākāśarakṣin": ['mw'],
    "ākāśarakṣitā": ['bhs'],
    "ākāśasalila": ['mw'],
    "ākāśasaṃcārin": ['cae'],
    "ākāśaspharaṇa": ['bhs'],
    "ākāśasphaṭika": ['mw'],
    "ākāśastha": ['mw'],
    "ākāśavacana": ['mw'],
    "ākāśavallī": ['mw'],
    "ākāśavartman": ['cae', 'mw'],
    "ākāśavat": ['ap90', 'mw'],
    "ākāśavāṇī": ['mw'],
    "ākāśayoginī": ['mw'],
    "ākāśayāna": ['cae', 'mw'],
    "ākāśaśayana": ['cae', 'mw'],
    "ākāśaḥ": ['ap90'],
    "ākāśe": ['mw'],
    "ākāśeśa": ['cae', 'mw'],
    "ākāśodaka": ['mw'],
    "ākāśopanyāsa": ['mw'],
    "ākāśya": ['mw'],
    "ākāśānantya": ['bhs'],
    "ākāśānantyāyatana": ['bhs', 'mw'],
    "ākāśānantyāyatanopaga": ['bhs'],
    "ākāśāsaṅgavimuktinirupalepa": ['bhs'],
    "ākāśāstikāya": ['mw'],
    "ākāśātman": ['mw'],
    "ākāśīya": ['ap90', 'mw'],
    "ākāṃkṣ": ['ap90'],
    "ākāṃkṣa": ['ap90'],
    "ākāṃkṣin": ['ap90'],
    "ākāṃkṣita": ['ap90'],
    "ākāṃkṣya": ['ap90'],
    "ākāṅkṣ": ['mw'],
    "ākāṅkṣa": ['cae', 'mw'],
    "ākāṅkṣati": ['bhs'],
    "ākāṅkṣin": ['mw'],
    "ākāṅkṣitamukha": ['bhs'],
    "ākāṅkṣya": ['mw'],
    "ākāṅkṣā": ['ddsa', 'mw'],
    "ākīm": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ākīrṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ākīrṇatva": ['mw'],
    "ākīrṇatā": ['mw'],
    "ākīrṇavihāra": ['bhs'],
    "ākīrṇavihārin": ['bhs'],
    "ākīrṇe": ['mw'],
    "ākīṭapataṃgapipīlakam": ['mw'],
    "ākū": ['mw'],
    "ākūj": ['mw'],
    "ākūpāra": ['mw'],
    "ākūta": ['cae', 'ddsa', 'mw'],
    "ākūtana": ['bhs'],
    "ākūtaṃ": ['ap90'],
    "ākūti": ['gra', 'mw'],
    "ākūtipra": ['mw'],
    "ākūtiḥ": ['ap90'],
    "ākūvāra": ['mw'],
    "ākūṇita": ['ap90'],
    "ākṛ": ['ap90', 'mw'],
    "ākṛta": ['ap90', 'mw'],
    "ākṛti": ['cae', 'ddsa', 'gra', 'mw'],
    "ākṛticchattrā": ['mw'],
    "ākṛtigaṇa": ['mw'],
    "ākṛtiloṣṭa": ['mw'],
    "ākṛtimat": ['ap90', 'mw'],
    "ākṛtiyoga": ['mw'],
    "ākṛtiḥ": ['ap90'],
    "ākṛtī": ['mw'],
    "ākṛṣ": ['ap90', 'mw'],
    "ākṛṣṭa": ['mw'],
    "ākṛṣṭavat": ['ddsa'],
    "ākṛṣṭi": ['cae', 'ddsa', 'mw'],
    "ākṛṣṭiman": ['mw'],
    "ākṛṣṭimant": ['bhs'],
    "ākṛṣṭimantra": ['mw'],
    "ākṛṣṭiḥ": ['ap90'],
    "ākṛṣṭya": ['mw'],
    "ākṝ": ['ap90', 'mw'],
    "ākṣa": ['mw'],
    "ākṣabhārika": ['mw'],
    "ākṣadyūtika": ['ap90', 'mw'],
    "ākṣaitrajñya": ['mw'],
    "ākṣaitrajñyaṃ": ['ap90'],
    "ākṣakī": ['mw'],
    "ākṣapaṇaṃ": ['ap90'],
    "ākṣapaṭalika": ['mw'],
    "ākṣapāda": ['ap90', 'mw'],
    "ākṣapāṭika": ['mw'],
    "ākṣapāṭikaḥ": ['ap90'],
    "ākṣar": ['ap90', 'mw'],
    "ākṣarasamāmnāyika": ['mw'],
    "ākṣepa": ['cae', 'ddsa', 'mw'],
    "ākṣepaka": ['ap90', 'mw'],
    "ākṣeparūpaka": ['cae', 'mw'],
    "ākṣepasūtra": ['mw'],
    "ākṣepavalana": ['cae', 'mw'],
    "ākṣepaḥ": ['ap90'],
    "ākṣepaṇa": ['cae', 'mw'],
    "ākṣepaṇaṃ": ['ap90'],
    "ākṣepin": ['ap90', 'cae', 'mw'],
    "ākṣepiṇī": ['mw'],
    "ākṣepopamā": ['cae', 'mw'],
    "ākṣeptṛ": ['ddsa', 'mw'],
    "ākṣepya": ['ddsa', 'mw'],
    "ākṣi": ['ap90', 'mw'],
    "ākṣika": ['ap90', 'cae', 'mw'],
    "ākṣikapaṇa": ['mw'],
    "ākṣikī": ['mw'],
    "ākṣip": ['ap90', 'mw'],
    "ākṣipta": ['ap90', 'cae', 'mw'],
    "ākṣiptikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "ākṣit": ['ap90', 'gra', 'mw'],
    "ākṣodana": ['mw'],
    "ākṣodanaṃ": ['ap90'],
    "ākṣoṭa": ['mw'],
    "ākṣoṭaḥ": ['ap90'],
    "ākṣveḍita": ['mw'],
    "ākṣyat": ['ap90', 'mw'],
    "ākṣāra": ['mw'],
    "ākṣāraḥ": ['ap90'],
    "ākṣāraṇaṃ": ['ap90'],
    "ākṣāraṇā": ['mw'],
    "ākṣārita": ['ap90', 'mw'],
    "ākṣārānta": ['mw'],
    "ākṣāṇa": ['ddsa', 'gra', 'mw'],
    "ākṣība": ['mw'],
    "ākṣīla": ['mw'],
    "ākṣīva": ['ap90'],
    "ākṣṇu": ['mw'],
    "āla": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ālabdha": ['ap90', 'bhs', 'mw'],
    "ālabdhiḥ": ['ap90'],
    "ālabh": ['ap90', 'mw'],
    "ālabha": ['mw'],
    "ālabhana": ['cae', 'mw'],
    "ālabhanaṃ": ['ap90'],
    "ālabhya": ['ap90', 'mw'],
    "ālag": ['mw'],
    "ālagarda": ['mw'],
    "ālagardaḥ": ['ap90'],
    "ālagardha": ['mw'],
    "ālaggetvā": ['cped'],
    "ālaggetvāna": ['cped'],
    "ālagna": ['cae', 'mw'],
    "ālaji": ['mw'],
    "ālajāla": ['mw'],
    "ālakamanda": ['cped'],
    "ālakṣ": ['ap90', 'mw'],
    "ālakṣaṇa": ['mw'],
    "ālakṣaṇyaṃ": ['ap90'],
    "ālakṣi": ['ap90', 'mw'],
    "ālakṣita": ['mw'],
    "ālakṣya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ālamarthya": ['mw'],
    "ālamb": ['mw'],
    "ālamba": ['cae', 'ddsa', 'mw'],
    "ālambaka": ['bhs'],
    "ālambam": ['mw'],
    "ālambana": ['bhs', 'cae', 'cped', 'mw'],
    "ālambanabāhā": ['cped'],
    "ālambanaka": ['bhs'],
    "ālambanaparīkṣā": ['mw'],
    "ālambanavat": ['mw'],
    "ālambara": ['cped'],
    "ālambaṇa": ['cped'],
    "ālambha": ['cae', 'ddsa', 'mw'],
    "ālambham": ['mw'],
    "ālambhana": ['cae', 'mw'],
    "ālambhanīya": ['mw'],
    "ālambhin": ['cae', 'mw'],
    "ālambhya": ['mw'],
    "ālambi": ['mw'],
    "ālambin": ['cae', 'mw'],
    "ālambita": ['cae', 'mw'],
    "ālambitvā": ['cped'],
    "ālambu": ['bhs'],
    "ālambuṣa": ['bhs'],
    "ālambya": ['bhs', 'mw'],
    "ālambā": ['mw'],
    "ālambāyana": ['mw'],
    "ālambāyanīputra": ['mw'],
    "ālambāyanīya": ['mw'],
    "ālambīputra": ['mw'],
    "ālap": ['ap90', 'mw'],
    "ālapana": ['cae', 'cped', 'ddsa', 'mw'],
    "ālapanta": ['cped'],
    "ālapati": ['cped'],
    "ālapi": ['cped'],
    "ālapita": ['cae', 'cped', 'mw'],
    "ālapitavya": ['mw'],
    "ālapiṁsu": ['cped'],
    "ālaptaka": ['bhs', 'mw'],
    "ālapya": ['mw'],
    "ālarka": ['ap90', 'ddsa', 'mw'],
    "ālasa": ['ap90', 'mw'],
    "ālasiya": ['cped'],
    "ālassa": ['cped'],
    "ālasya": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "ālasyavat": ['mw'],
    "ālasāyana": ['mw'],
    "ālava": ['mw'],
    "ālavaṇya": ['mw'],
    "ālavaṇyaṃ": ['ap90'],
    "ālavāla": ['cae', 'ddsa', 'mw'],
    "ālavālaṃ": ['ap90'],
    "ālaya": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ālayana": ['bhs'],
    "ālayati": ['cped'],
    "ālayavijñāna": ['bhs'],
    "ālayaḥ": ['ap90'],
    "ālayesi": ['cped'],
    "ālayesin": ['cped'],
    "ālaṃb": ['ap90'],
    "ālaṃba": ['ap90'],
    "ālaṃbanaṃ": ['ap90'],
    "ālaṃbhaḥ": ['ap90'],
    "ālaṃbhin": ['ap90'],
    "ālaṃbin": ['ap90'],
    "ālaṃbita": ['ap90'],
    "ālaṃkārika": ['mw'],
    "ālaṅkārika": ['ddsa'],
    "ālaṣ": ['mw'],
    "ālekhana": ['cae', 'ddsa', 'mw'],
    "ālekhanaṃ": ['ap90'],
    "ālekhani": ['mw'],
    "ālekhanī": ['mw'],
    "ālekhaḥ": ['ap90'],
    "ālekhya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ālekhyadevatā": ['mw'],
    "ālekhyalekhā": ['mw'],
    "ālekhyapuruṣa": ['mw'],
    "ālekhyasamarpita": ['cae', 'mw'],
    "ālekhyaśeṣa": ['mw'],
    "ālepa": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "ālepana": ['mw'],
    "āleśa": ['mw'],
    "ālhāda": ['ddsa'],
    "ālhādin": ['ddsa'],
    "āli": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "ālibaddha": ['cped'],
    "āligavya": ['mw'],
    "āligavyāyanī": ['mw'],
    "āligī": ['mw'],
    "ālih": ['mw'],
    "ālijana": ['mw'],
    "ālikh": ['ap90', 'mw'],
    "ālikhana": ['bhs'],
    "ālikhat": ['mw'],
    "ālikhita": ['cae', 'mw'],
    "ālikhya": ['mw'],
    "ālikrama": ['mw'],
    "ālikāvendā": ['bhs'],
    "ālimpa": ['cped'],
    "ālimpana": ['mw'],
    "ālimpanta": ['cped'],
    "ālimpat": ['cped'],
    "ālimpati": ['cped'],
    "ālimpesuṁ": ['cped'],
    "ālimpetabba": ['cped'],
    "ālimpeti": ['cped'],
    "ālimpetvā": ['cped'],
    "ālimpita": ['cped'],
    "ālimpitabba": ['cped'],
    "ālimpāpeti": ['cped'],
    "ālin": ['ap90', 'mw'],
    "ālinda": ['cped', 'mw'],
    "ālip": ['ap90', 'mw'],
    "ālipa": ['ap90'],
    "ālipta": ['mw'],
    "ālipya": ['mw'],
    "ālitta": ['cped'],
    "āliñjara": ['mw'],
    "āliś": ['mw'],
    "āliṃdaḥ": ['ap90'],
    "āliṃg": ['ap90'],
    "āliṃganaṃ": ['ap90'],
    "āliṃgaḥ": ['ap90'],
    "āliṃgin": ['ap90'],
    "āliṃgita": ['ap90'],
    "āliṃjaraḥ": ['ap90'],
    "āliṃpanaṃ": ['ap90'],
    "āliṅg": ['cae', 'ddsa', 'mw'],
    "āliṅga": ['bhs', 'mw'],
    "āliṅgana": ['cae', 'ddsa', 'mw'],
    "āliṅganā": ['mw'],
    "āliṅgati": ['cped'],
    "āliṅgeti": ['cped'],
    "āliṅgetvā": ['cped'],
    "āliṅgikā": ['bhs'],
    "āliṅgin": ['mw'],
    "āliṅgita": ['mw'],
    "āliṅgitavat": ['mw'],
    "āliṅgitvā": ['cped'],
    "āliṅgya": ['mw'],
    "āliṅgyāyana": ['mw'],
    "āllakeya": ['mw'],
    "ālm, ālī": ['ddsa'],
    "ālm, ālū": ['ddsa'],
    "āloc": ['ap90', 'mw'],
    "ālocaka": ['ap90', 'mw'],
    "ālocana": ['cae', 'ddsa', 'mw'],
    "ālocanaṃ": ['ap90'],
    "ālocanīya": ['cae', 'mw'],
    "ālocita": ['mw'],
    "ālocya": ['cae', 'mw'],
    "ālohavat": ['mw'],
    "ālohita": ['cae', 'ddsa', 'mw'],
    "ālohitīkṛ": ['mw'],
    "ālohāyana": ['mw'],
    "ālok": ['ap90', 'mw'],
    "āloka": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ālokada": ['cped'],
    "ālokagadādharī": ['mw'],
    "ālokaka": ['mw'],
    "ālokakara": ['bhs', 'mw'],
    "ālokakaraṇa": ['cped'],
    "ālokalābha": ['bhs'],
    "ālokamaṇḍalaprabha": ['bhs'],
    "ālokamārga": ['cae', 'mw'],
    "ālokana": ['cae', 'mw'],
    "ālokanīya": ['cae', 'mw'],
    "ālokanīyatā": ['mw'],
    "ālokapatha": ['cae', 'mw'],
    "ālokapharaṇa": ['cped'],
    "ālokasandhi": ['cped'],
    "ālokasaṃdhi": ['bhs'],
    "ālokasthāna": ['cae', 'mw'],
    "ālokasuvegadhvaja": ['bhs', 'mw'],
    "ālokati": ['bhs'],
    "ālokavat": ['mw'],
    "ālokavṛddhi": ['bhs'],
    "ālokaya": ['cped'],
    "ālokayat": ['cped'],
    "ālokayati": ['cped'],
    "ālokaḥ": ['ap90'],
    "āloketabba": ['cped'],
    "āloketi": ['cped'],
    "ālokin": ['ap90', 'cae', 'ddsa', 'mw'],
    "ālokinī": ['bhs'],
    "ālokita": ['ap90', 'cped', 'mw'],
    "ālokitabba": ['cped'],
    "ālokitavilokita": ['bhs'],
    "ālokya": ['mw'],
    "ālola": ['ap90', 'ddsa', 'mw'],
    "ālolikā": ['mw'],
    "ālolita": ['ap90', 'mw'],
    "ālopa": ['bhs', 'cped', 'mw'],
    "ālopaka": ['bhs'],
    "ālopati": ['cped'],
    "āloḍana": ['mw'],
    "āloḍanaṃ": ['ap90'],
    "āloḍita": ['ap90', 'mw'],
    "āloḍya": ['mw'],
    "āloḷayati": ['cped'],
    "āloḷeti": ['cped'],
    "āloḷetvā": ['cped'],
    "āloṣṭī": ['mw'],
    "ālu": ['bhs', 'cae', 'mw'],
    "ālubh": ['mw'],
    "āluka": ['mw'],
    "ālukaḥ": ['ap90'],
    "ālukī": ['mw'],
    "ālula": ['ap90'],
    "ālulita": ['cae', 'mw'],
    "ālumpati": ['cped'],
    "ālup": ['mw'],
    "āluppakārakaṁ": ['cped'],
    "āluñc": ['mw'],
    "āluñcana": ['cae', 'ddsa', 'mw'],
    "āluḍ": ['ap90', 'mw'],
    "āluḥ": ['ap90'],
    "āluṃcanaṃ": ['ap90'],
    "āluṃṭanaṃ": ['ap90'],
    "ālābu": ['mw'],
    "ālābuḥ": ['ap90'],
    "ālābūḥ": ['ap90'],
    "ālākta": ['gra', 'mw'],
    "ālāla": ['mw'],
    "ālālamehin": ['mw'],
    "ālāmbu": ['bhs'],
    "ālāna": ['cae', 'ddsa', 'mw'],
    "ālānastambha": ['cae'],
    "ālānaṃ": ['ap90'],
    "ālānika": ['ap90', 'mw'],
    "ālānita": ['mw'],
    "ālāpa": ['cae', 'ddsa', 'mw'],
    "ālāpaka": ['bhs'],
    "ālāpana": ['ap90', 'bhs', 'mw'],
    "ālāpanīya": ['mw'],
    "ālāpavat": ['mw'],
    "ālāpaḥ": ['ap90'],
    "ālāpikavaṃśa": ['mw'],
    "ālāpin": ['ap90', 'mw'],
    "ālāpinī": ['mw'],
    "ālāpya": ['ap90', 'mw'],
    "ālāpā": ['mw'],
    "ālārika": ['cped'],
    "ālāriya": ['cped'],
    "ālāsya": ['mw'],
    "ālāsyaḥ": ['ap90'],
    "ālāta": ['mw'],
    "ālātaṃ": ['ap90'],
    "ālāvarta": ['mw'],
    "ālāvartaṃ": ['ap90'],
    "ālāṭya": ['mw'],
    "ālī": ['ap90', 'cae', 'mw'],
    "ālīna": ['ap90', 'cae', 'mw'],
    "ālīnaka": ['mw'],
    "ālīḍha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ālīḍhakaṃ": ['ap90'],
    "ālīḍheya": ['mw'],
    "ālū": ['ap90', 'cae', 'mw'],
    "ālūna": ['ap90', 'cae', 'mw'],
    "ām": ['ap90', 'cae', 'ddsa', 'mw'],
    "āma": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "āmabhṛṣṭa": ['mw'],
    "āmadhyāhnam": ['ddsa', 'mw'],
    "āmagandha": ['bhs', 'cped'],
    "āmagandhi": ['mw'],
    "āmagandhika": ['mw'],
    "āmagandhin": ['mw'],
    "āmagarbha": ['mw'],
    "āmagna": ['cae', 'mw'],
    "āmah": ['mw'],
    "āmahīyava": ['mw'],
    "āmahīyā": ['ap90', 'mw'],
    "āmajjam": ['mw'],
    "āmajjanāntam": ['ddsa'],
    "āmajvara": ['ddsa', 'mw'],
    "āmaka": ['ap90', 'mw'],
    "āmakachinna": ['cped'],
    "āmakamatta": ['cped'],
    "āmakumbha": ['mw'],
    "āmalaka": ['cae', 'cped', 'ddsa', 'mw'],
    "āmalakapatta": ['cped'],
    "āmalakaḥ": ['ap90'],
    "āmalakī": ['cped', 'mw'],
    "āmalakīpattra": ['mw'],
    "āmalakīpattraphala": ['mw'],
    "āmalavaṇṭaka": ['cped'],
    "āmalavaṇṭika": ['cped'],
    "āmalavaṭṭika": ['cped'],
    "āmamaya": ['mw'],
    "āmamāṃsa": ['mw'],
    "āmamāṃsāśin": ['mw'],
    "āman": ['mw'],
    "āmana": ['cae', 'mw'],
    "āmanahoma": ['mw'],
    "āmanas": ['cae', 'mw'],
    "āmanasya": ['mw'],
    "āmanasyaṃ": ['ap90'],
    "āmanaṃ": ['ap90'],
    "āmandra": ['cae', 'ddsa', 'mw'],
    "āmantana": ['cped'],
    "āmantayati": ['cped'],
    "āmantayi": ['cped'],
    "āmantaṇa": ['cped'],
    "āmantesi": ['cped'],
    "āmantesuṁ": ['cped'],
    "āmanteti": ['cped'],
    "āmantetvā": ['cped'],
    "āmanth": ['mw'],
    "āmanthya": ['mw'],
    "āmantita": ['cped'],
    "āmantr": ['mw'],
    "āmantrayitavya": ['mw'],
    "āmantrayitṛ": ['mw'],
    "āmantraṇa": ['cae', 'ddsa', 'mw'],
    "āmantraṇaka": ['bhs', 'cae'],
    "āmantraṇika": ['mw'],
    "āmantraṇā": ['mw'],
    "āmantraṇīya": ['mw'],
    "āmantrita": ['cae', 'mw'],
    "āmantrya": ['mw'],
    "āmantāpetvā": ['cped'],
    "āmanyate": ['bhs'],
    "āmapeṣa": ['mw'],
    "āmapācin": ['mw'],
    "āmapāka": ['mw'],
    "āmapātra": ['cae', 'mw'],
    "āmapīnasa": ['mw'],
    "āmarakta": ['mw'],
    "āmarasa": ['mw'],
    "āmaraṇam": ['cae', 'ddsa', 'mw'],
    "āmaraṇānta": ['cae', 'mw'],
    "āmaraṇāntika": ['cae', 'mw'],
    "āmaraṇāṃta": ['ap90'],
    "āmarda": ['cae', 'ddsa', 'mw'],
    "āmardaka": ['mw'],
    "āmardakatīrthanātha": ['mw'],
    "āmardaḥ": ['ap90'],
    "āmardin": ['ap90', 'mw'],
    "āmarākṣasī": ['mw'],
    "āmarītṛ": ['ap90', 'gra', 'mw'],
    "āmarśa": ['cae', 'ddsa', 'mw'],
    "āmarśana": ['mw'],
    "āmarśaḥ": ['ap90'],
    "āmarṣa": ['mw'],
    "āmarṣaḥ": ['ap90'],
    "āmarṣaṇa": ['mw'],
    "āmasabrahmacāri": ['cped'],
    "āmasabrahmacārin": ['cped'],
    "āmasana": ['cped'],
    "āmasati": ['cped'],
    "āmasi": ['cped'],
    "āmasitvā": ['cped'],
    "āmata": ['cped'],
    "āmateya": ['bhs'],
    "āmath": ['mw'],
    "āmatha": ['bhs'],
    "āmathya": ['mw'],
    "āmattikāpaṇa": ['cped'],
    "āmatā": ['ap90', 'mw'],
    "āmavasesa": ['cped'],
    "āmavasesaka": ['cped'],
    "āmavidhi": ['mw'],
    "āmavāta": ['mw'],
    "āmaya": ['cae', 'ddsa', 'gra', 'mw'],
    "āmayaḥ": ['ap90'],
    "āmayitnu": ['gra'],
    "āmayāvin": ['ap90', 'cae', 'mw'],
    "āmayāvitva": ['mw'],
    "āmañju": ['ddsa', 'mw'],
    "āmaśrāddha": ['mw'],
    "āmaśūla": ['mw'],
    "āmaṃdra": ['ap90'],
    "āmaṃju": ['ap90'],
    "āmaṃtr": ['ap90'],
    "āmaṃtrayitṛ": ['ap90'],
    "āmaṃtraḥ": ['ap90'],
    "āmaṃtraṇaṃ": ['ap90'],
    "āmaṃtrita": ['ap90'],
    "āmaṃtrya": ['ap90'],
    "āmaṃḍaḥ": ['ap90'],
    "āmaṇḍa": ['cped', 'mw'],
    "āmaṇḍaka": ['mw'],
    "āmaṇḍalikā": ['cped'],
    "āmaṇḍaliyā": ['cped'],
    "āmaṇḍalīkṛ": ['ddsa'],
    "āmaṭṭha": ['cped'],
    "āmba": ['mw'],
    "āmbarīṣaputraka": ['mw'],
    "āmbaṣṭha": ['mw'],
    "āmbaṣṭhya": ['mw'],
    "āmbaṣṭhyā": ['mw'],
    "āmbhasa": ['ddsa', 'mw'],
    "āmbhasika": ['mw'],
    "āmbhi": ['mw'],
    "āmbhirya": ['bhs'],
    "āmbhṛṇī": ['mw'],
    "āmbikeya": ['mw'],
    "āmbuda": ['mw'],
    "āmbāsanaka": ['bhs'],
    "āmekhalam": ['ddsa', 'mw'],
    "āmenia": ['gra'],
    "āmenya": ['ap90', 'gra', 'mw'],
    "āmeṣṭaka": ['ddsa', 'mw'],
    "āmeṣṭakā": ['cae'],
    "āmi": ['mw'],
    "āmikṣavat": ['mw'],
    "āmikṣya": ['mw'],
    "āmikṣyaṃ": ['ap90'],
    "āmikṣā": ['ap90', 'cae', 'ddsa', 'mw'],
    "āmikṣāpayasya": ['mw'],
    "āmikṣīya": ['mw'],
    "āmila": ['bhs'],
    "āmilāta": ['bhs'],
    "āmis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āmisa": ['cped'],
    "āmisakhāra": ['cped'],
    "āmisakiñcikkha": ['cped'],
    "āmisantara": ['cped'],
    "āmisapaṭisanthāra": ['cped'],
    "āmisasanthāra": ['cped'],
    "āmitauji": ['mw'],
    "āmitra": ['ap90', 'gra', 'mw'],
    "āmitraśocani": ['mw'],
    "āmitri": ['mw'],
    "āmitriḥ": ['ap90'],
    "āmitrāyaṇa": ['mw'],
    "āmitrāyaṇi": ['mw'],
    "āmitrīya": ['mw'],
    "āmiśla": ['cae', 'gra', 'mw'],
    "āmiślatama": ['mw'],
    "āmiśra": ['ap90', 'cae', 'mw'],
    "āmiśratva": ['mw'],
    "āmiśrm, āmiśla": ['ddsa'],
    "āmiśrībhūta": ['mw'],
    "āmiśrībhūtatva": ['mw'],
    "āmiṣ": ['ap90'],
    "āmiṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "āmiṣabhuj": ['mw'],
    "āmiṣadāna": ['mw'],
    "āmiṣapriya": ['mw'],
    "āmiṣatva": ['mw'],
    "āmiṣatā": ['mw'],
    "āmiṣaṃ": ['ap90'],
    "āmiṣāśin": ['mw'],
    "āmiṣī": ['ap90', 'mw'],
    "āmla": ['mw'],
    "āmlavallī": ['mw'],
    "āmlavetasa": ['bhs', 'mw'],
    "āmlaḥ": ['ap90'],
    "āmlikā": ['ap90', 'mw'],
    "āmlocantī": ['mw'],
    "āmlāna": ['cae', 'mw'],
    "āmlāta": ['bhs'],
    "āmlāyati": ['bhs'],
    "āmlīkā": ['ap90', 'mw'],
    "āmnā": ['ap90', 'mw'],
    "āmnāna": ['mw'],
    "āmnānaṃ": ['ap90'],
    "āmnāta": ['ap90', 'mw'],
    "āmnātatva": ['ddsa'],
    "āmnātavya": ['mw'],
    "āmnātin": ['ap90', 'cae', 'ddsa', 'mw'],
    "āmnāya": ['cae', 'ddsa', 'mw'],
    "āmnāyapara": ['cae', 'mw'],
    "āmnāyarahasya": ['mw'],
    "āmnāyasārin": ['mw'],
    "āmnāyavat": ['ap90'],
    "āmnāyayoni": ['mw'],
    "āmnāyaḥ": ['ap90'],
    "āmnāyin": ['mw'],
    "āmo": ['cped'],
    "āmocana": ['ddsa', 'mw'],
    "āmocanaṃ": ['ap90'],
    "āmoda": ['ap90', 'cae', 'ddsa', 'mw'],
    "āmodajananī": ['mw'],
    "āmodamāna": ['cped'],
    "āmodana": ['ap90', 'mw'],
    "āmodanīya": ['bhs'],
    "āmodayati": ['bhs', 'cped'],
    "āmodeti": ['cped'],
    "āmodin": ['ap90', 'cae', 'mw'],
    "āmodita": ['ap90', 'cae', 'mw'],
    "āmohanikā": ['ap90', 'mw'],
    "āmoka": ['mw'],
    "āmokṣaṇa": ['ddsa', 'mw'],
    "āmoṣa": ['ap90', 'mw'],
    "āmoṣin": ['ap90', 'mw'],
    "āmoṭana": ['cae', 'ddsa', 'mw'],
    "āmoṭanaṃ": ['ap90'],
    "āmra": ['cae', 'ddsa', 'mw'],
    "āmragandhaka": ['mw'],
    "āmragandhiharidrā": ['mw'],
    "āmragupta": ['mw'],
    "āmragupti": ['mw'],
    "āmraguptāyani": ['mw'],
    "āmrakavi": ['mw'],
    "āmrakūṭa": ['ddsa', 'mw'],
    "āmramaya": ['mw'],
    "āmraniśā": ['mw'],
    "āmrapañcama": ['mw'],
    "āmrapeśī": ['mw'],
    "āmraphalaprapānaka": ['mw'],
    "āmraprasāda": ['mw'],
    "āmrapāla": ['mw'],
    "āmrapālikā": ['bhs'],
    "āmrapālī": ['bhs', 'mw'],
    "āmrataila": ['mw'],
    "āmratīrtha": ['bhs'],
    "āmratīrthika": ['bhs'],
    "āmravaṇa": ['mw'],
    "āmravāṭa": ['mw'],
    "āmravāṭaka": ['mw'],
    "āmravāṭika": ['mw'],
    "āmraḥ": ['ap90'],
    "āmreḍ": ['ap90', 'mw'],
    "āmreḍa": ['cae', 'ddsa', 'mw'],
    "āmreḍana": ['mw'],
    "āmreḍanaṃ": ['ap90'],
    "āmreḍayati": ['bhs'],
    "āmreḍita": ['ap90', 'cae', 'mw'],
    "āmreḍitayamaka": ['mw'],
    "āmriman": ['ap90', 'mw'],
    "āmrin": ['mw'],
    "āmrya": ['mw'],
    "āmrāsthi": ['mw'],
    "āmrāta": ['mw'],
    "āmrātaka": ['mw'],
    "āmrātakaḥ": ['ap90'],
    "āmrātakeśvara": ['mw'],
    "āmrātakī": ['mw'],
    "āmrātaḥ": ['ap90'],
    "āmrāvarta": ['mw'],
    "āmrāvatī": ['mw'],
    "āmuc": ['ap90', 'mw'],
    "āmukha": ['bhs', 'ddsa', 'mw'],
    "āmukham": ['mw'],
    "āmukhayati": ['bhs'],
    "āmukhaṃ": ['ap90'],
    "āmukhībhavati": ['bhs'],
    "āmukhībhū": ['mw'],
    "āmukhīkaraṇa": ['bhs'],
    "āmukhīkaroti": ['bhs'],
    "āmukhīkṛ": ['mw'],
    "āmukhīpravṛtta": ['bhs'],
    "āmukhīsthita": ['bhs'],
    "āmukta": ['ap90', 'bhs', 'cae', 'mw'],
    "āmuktaka": ['bhs'],
    "āmukti": ['mw'],
    "āmuktikā": ['mw'],
    "āmuktiḥ": ['ap90'],
    "āmuktā": ['mw'],
    "āmukulita": ['ddsa', 'mw'],
    "āmupa": ['mw'],
    "āmur": ['ap90', 'cae', 'gra', 'mw'],
    "āmuri": ['cae', 'gra', 'mw'],
    "āmutrika": ['bhs'],
    "āmuttamaṇikuṇḍala": ['cped'],
    "āmuttamālābharaṇa": ['cped'],
    "āmuṣ": ['mw'],
    "āmuṣmika": ['ap90', 'cae', 'ddsa', 'mw'],
    "āmuṣmikatva": ['mw'],
    "āmuṣyakulikā": ['mw'],
    "āmuṣyaputrikā": ['mw'],
    "āmuṣyāyaṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "āmyakṣ": ['mw'],
    "āmā": ['mw'],
    "āmād": ['cae', 'ddsa', 'gra', 'mw'],
    "āmādya": ['mw'],
    "āmājīrṇa": ['mw'],
    "āmānasya": ['mw'],
    "āmānasyaṃ": ['ap90'],
    "āmānna": ['mw'],
    "āmārjayati": ['bhs'],
    "āmātisāra": ['mw'],
    "āmātisārin": ['mw'],
    "āmātya": ['mw'],
    "āmātyaḥ": ['ap90'],
    "āmāvāsya": ['ap90', 'cae', 'ddsa', 'mw'],
    "āmāvāsyavidha": ['mw'],
    "āmāśaya": ['mw'],
    "āmī": ['mw'],
    "āmīkṣā": ['ap90', 'mw'],
    "āmīl": ['ap90', 'mw'],
    "āmīlana": ['ddsa', 'mw'],
    "āmīlanaṃ": ['ap90'],
    "āmīv": ['mw'],
    "āmīvat": ['ap90'],
    "āmīvatka": ['mw'],
    "āmīvita": ['mw'],
    "āmīvā": ['mw'],
    "āmūla": ['cae', 'ddsa'],
    "āmūlam": ['mw'],
    "āmūrdhāntam": ['ddsa', 'mw'],
    "āmūrtarayasa": ['mw'],
    "āmṛd": ['ap90', 'mw'],
    "āmṛduka": ['bhs'],
    "āmṛj": ['mw'],
    "āmṛjya": ['mw'],
    "āmṛta": ['mw'],
    "āmṛś": ['ap90', 'mw'],
    "āmṛśa": ['bhs'],
    "āmṛṇa": ['ap90', 'gra', 'mw'],
    "āmṛṣ": ['mw'],
    "āmṛṣṭa": ['ap90', 'cae', 'mw'],
    "āna": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ānabhimlāna": ['mw'],
    "ānabhimlāta": ['mw'],
    "ānabhiramya": ['bhs'],
    "ānad": ['mw'],
    "ānaddha": ['ap90', 'cae', 'mw'],
    "ānaddhatva": ['mw'],
    "ānaddhavastitā": ['mw'],
    "ānah": ['ap90', 'mw'],
    "ānaipuṇa": ['mw'],
    "ānaipuṇaṃ": ['ap90'],
    "ānaiśvarya": ['mw'],
    "ānaiśvaryaṃ": ['ap90'],
    "ānaka": ['cae', 'ddsa', 'mw'],
    "ānakadundubhi": ['mw'],
    "ānakasthalaka": ['mw'],
    "ānakasthalī": ['mw'],
    "ānakaḥ": ['ap90'],
    "ānakāyani": ['mw'],
    "ānakṣ": ['mw'],
    "ānala": ['mw'],
    "ānalavi": ['mw'],
    "ānam": ['ap90', 'mw'],
    "ānama": ['mw'],
    "ānamam": ['mw'],
    "ānamana": ['mw'],
    "ānamaḥ": ['ap90'],
    "ānamita": ['mw'],
    "ānamra": ['ap90', 'ddsa', 'mw'],
    "ānamya": ['mw'],
    "ānana": ['cae', 'ddsa', 'mw'],
    "ānanacara": ['cae', 'mw'],
    "ānanaka": ['bhs'],
    "ānanaṃ": ['ap90'],
    "ānand": ['mw'],
    "ānanda": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ānandabhadra": ['bhs'],
    "ānandabhairava": ['mw'],
    "ānandabhairavī": ['mw'],
    "ānandabhuj": ['mw'],
    "ānandabodhendra": ['mw'],
    "ānandabāṣpa": ['mw'],
    "ānandacandra": ['bhs'],
    "ānandacaturdaśīvrata": ['mw'],
    "ānandacaula": ['mw'],
    "ānandacidghana": ['mw'],
    "ānandada": ['mw'],
    "ānandadatta": ['mw'],
    "ānandadeva": ['mw'],
    "ānandadīpikā": ['mw'],
    "ānandaghana": ['mw'],
    "ānandagiri": ['mw'],
    "ānandaja": ['mw'],
    "ānandajala": ['mw'],
    "ānandajanana": ['cped'],
    "ānandajñāna": ['mw'],
    "ānandajñānagiri": ['mw'],
    "ānandajāta": ['cped'],
    "ānandaka": ['mw'],
    "ānandakalikā": ['mw'],
    "ānandakanda": ['mw'],
    "ānandakara": ['mw'],
    "ānandakośa": ['mw'],
    "ānandakānanamāhātmya": ['mw'],
    "ānandakāvya": ['mw'],
    "ānandalahari": ['mw'],
    "ānandalaharī": ['mw'],
    "ānandalaharīstotra": ['mw'],
    "ānandamaya": ['cae', 'mw'],
    "ānandamayakoṣa": ['mw'],
    "ānandamāla": ['bhs'],
    "ānandamālā": ['mw'],
    "ānandana": ['cae', 'mw'],
    "ānandanidhi": ['mw'],
    "ānandanātha": ['mw'],
    "ānandapaṭa": ['mw'],
    "ānandapaṭṭika": ['bhs'],
    "ānandaprabhava": ['mw'],
    "ānandaprabhā": ['mw'],
    "ānandapura": ['mw'],
    "ānandapūrṇa": ['mw'],
    "ānandarāya": ['mw'],
    "ānandarūpa": ['mw'],
    "ānandasambhava": ['mw'],
    "ānandathu": ['mw'],
    "ānandatā": ['mw'],
    "ānandatāṇḍavapura": ['mw'],
    "ānandatīrtha": ['mw'],
    "ānandavallī": ['mw'],
    "ānandavana": ['mw'],
    "ānandavardhana": ['mw'],
    "ānandaveda": ['mw'],
    "ānandavimala": ['mw'],
    "ānandayitavya": ['mw'],
    "ānandayitṛ": ['cae', 'mw'],
    "ānandayoga": ['mw'],
    "ānandeśvaratīrtha": ['mw'],
    "ānandi": ['cped', 'mw'],
    "ānandika": ['bhs'],
    "ānandin": ['cae', 'cped', 'ddsa', 'mw'],
    "ānandita": ['bhs', 'cae', 'mw'],
    "ānandotsava": ['cae', 'mw'],
    "ānandā": ['bhs', 'mw'],
    "ānandācala": ['mw'],
    "ānandāmṛta": ['mw'],
    "ānandāmṛtarūpa": ['mw'],
    "ānandātman": ['mw'],
    "ānandāśrama": ['mw'],
    "ānandāśru": ['ddsa', 'mw'],
    "ānandī": ['bhs', 'mw'],
    "ānantapaṭṭikā": ['bhs'],
    "ānantarika": ['cped'],
    "ānantarikakamma": ['cped'],
    "ānantariya": ['cped'],
    "ānantarya": ['bhs', 'cae', 'ddsa', 'mw'],
    "ānantaryasamādhi": ['bhs', 'mw'],
    "ānantaryatṛtīyā": ['mw'],
    "ānantarīya": ['bhs'],
    "ānantarīyaka": ['bhs'],
    "ānantya": ['cae', 'ddsa', 'mw'],
    "ānanābja": ['mw'],
    "ānanānta": ['mw'],
    "ānapatya": ['mw'],
    "ānapatyaṃ": ['ap90'],
    "ānapāna": ['cped'],
    "ānapānasati": ['cped'],
    "ānapānassati": ['cped'],
    "ānard": ['mw'],
    "ānardam": ['mw'],
    "ānardita": ['cae', 'mw'],
    "ānarta": ['ap90', 'ddsa', 'mw'],
    "ānartaka": ['ap90', 'mw'],
    "ānartana": ['mw'],
    "ānartapura": ['mw'],
    "ānartaḥ": ['ap90'],
    "ānarthakya": ['ddsa', 'mw'],
    "ānarthakyaṃ": ['ap90'],
    "ānartita": ['mw'],
    "ānartīya": ['ap90', 'mw'],
    "ānasa": ['ap90', 'mw'],
    "ānata": ['ap90', 'cae', 'mw'],
    "ānataja": ['mw'],
    "ānataparvan": ['cae', 'ddsa'],
    "ānati": ['cae', 'ddsa', 'mw'],
    "ānatiḥ": ['ap90'],
    "ānatya": ['mw'],
    "ānava": ['ap90', 'cae', 'gra', 'mw'],
    "ānavya": ['mw'],
    "ānaya": ['mw'],
    "ānayana": ['cae', 'ddsa', 'mw'],
    "ānayati": ['cped'],
    "ānayaḥ": ['ap90'],
    "ānayissami": ['cped'],
    "ānayitavya": ['mw'],
    "ānaśa": ['ddsa'],
    "ānaḍuha": ['ap90', 'ddsa', 'mw'],
    "ānaḍuhaka": ['mw'],
    "ānaḍuhya": ['mw'],
    "ānaḍuhyāyana": ['mw'],
    "ānaḍuhyāyani": ['mw'],
    "ānaḥ": ['ap90'],
    "ānaṃd": ['ap90'],
    "ānaṃdaka": ['ap90'],
    "ānaṃdamaya": ['ap90'],
    "ānaṃdana": ['ap90'],
    "ānaṃdathu": ['ap90'],
    "ānaṃdatā": ['ap90'],
    "ānaṃdayitavyaṃ": ['ap90'],
    "ānaṃdayitṛ": ['ap90'],
    "ānaṃdaḥ": ['ap90'],
    "ānaṃdin": ['ap90'],
    "ānaṃdiḥ": ['ap90'],
    "ānaṃtaryaṃ": ['ap90'],
    "ānaṃtyaṃ": ['ap90'],
    "ānaṃśa": ['ddsa'],
    "ānaṇya": ['cped'],
    "ānaṭ": ['ddsa'],
    "ānda": ['mw'],
    "āndhasika": ['mw'],
    "āndhra": ['mw'],
    "āndhrī": ['mw'],
    "āndhya": ['cae', 'ddsa', 'mw'],
    "āndhāsvara": ['mw'],
    "āndhīgava": ['mw'],
    "āndola": ['mw'],
    "āndolaka": ['ddsa', 'mw'],
    "āndolana": ['mw'],
    "āndolaya": ['ddsa', 'mw'],
    "āndolikā": ['ddsa', 'mw'],
    "āndolita": ['mw'],
    "āndīra": ['mw'],
    "āndīḍa": ['mw'],
    "ānejja": ['cped'],
    "ānejjakārana": ['cped'],
    "ānejjapatta": ['cped'],
    "ānejjappatta": ['cped'],
    "ānemimagna": ['mw'],
    "ānesi": ['cped'],
    "ānessami": ['cped'],
    "ānessati": ['cped'],
    "ānesuṁ": ['cped'],
    "ānetavai": ['mw'],
    "ānetavya": ['ap90', 'mw'],
    "āneti": ['cped'],
    "ānetuṁ": ['cped'],
    "ānetvā": ['cped'],
    "ānetṛ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āneya": ['ap90', 'mw'],
    "āneñja": ['bhs', 'cped'],
    "āneñjabhisaṅkhāra": ['cped'],
    "āneñjakāraṇa": ['cped'],
    "āneñjapatta": ['cped'],
    "āneñjappatta": ['cped'],
    "āneñjya": ['bhs'],
    "ānhika": ['ddsa'],
    "āniceya": ['mw'],
    "ānidhana": ['mw'],
    "ānidheya": ['mw'],
    "ānijya": ['bhs'],
    "ānila": ['ap90', 'mw'],
    "ānili": ['mw'],
    "ānilī": ['mw'],
    "ānimitta": ['bhs'],
    "āninetra": ['bhs'],
    "ānirhata": ['ap90', 'mw'],
    "āniruddha": ['mw'],
    "ānisada": ['cped'],
    "ānisaṁsa": ['cped'],
    "āniyyati": ['cped'],
    "āniñja": ['bhs'],
    "āniñjya": ['bhs', 'mw'],
    "āniśam": ['mw'],
    "āniṣada": ['bhs'],
    "ānna": ['ap90', 'mw'],
    "ānobhadrasūkta": ['mw'],
    "ānta": ['bhs', 'mw'],
    "āntam": ['ddsa', 'mw'],
    "āntara": ['cae', 'ddsa', 'mw'],
    "āntaraprapañca": ['mw'],
    "āntaratamya": ['mw'],
    "āntargaṇika": ['mw'],
    "āntargehika": ['mw'],
    "āntarikā": ['bhs'],
    "āntarikṣa": ['cae', 'ddsa', 'mw'],
    "āntarikṣavāsin": ['bhs'],
    "āntarvedika": ['mw'],
    "āntarveśmika": ['mw'],
    "āntarya": ['mw'],
    "āntarābhavika": ['bhs'],
    "āntarāgārika": ['mw'],
    "āntarāla": ['mw'],
    "āntarālika": ['mw'],
    "āntarāyika": ['bhs', 'mw'],
    "āntarīkṣa": ['cae', 'mw'],
    "āntarīpaka": ['mw'],
    "āntaḥpura": ['bhs'],
    "āntaḥpurika": ['mw'],
    "āntikā": ['mw'],
    "āntra": ['cae', 'ddsa', 'gra', 'mw'],
    "āntraguṇa": ['bhs'],
    "āntrapāśa": ['mw'],
    "āntratantī": ['mw'],
    "āntrika": ['mw'],
    "āntrānucārin": ['mw'],
    "āntrīmukha": ['mw'],
    "āntya": ['mw'],
    "āntyāyana": ['mw'],
    "ānu": ['mw'],
    "ānubandhika": ['mw'],
    "ānubhi": ['cped'],
    "ānubhāva": ['bhs', 'cped'],
    "ānucchavika": ['bhs'],
    "ānucāraka": ['mw'],
    "ānudeśika": ['mw'],
    "ānudhārma": ['bhs'],
    "ānudṛṣṭeya": ['mw'],
    "ānudṛṣṭineya": ['mw'],
    "ānugatika": ['ap90', 'mw'],
    "ānugatya": ['mw'],
    "ānugatyaṃ": ['ap90'],
    "ānugaṅgya": ['mw'],
    "ānugrāmika": ['ap90', 'mw'],
    "ānuguṇika": ['mw'],
    "ānuguṇya": ['mw'],
    "ānuguṇyaṃ": ['ap90'],
    "ānugādika": ['mw'],
    "ānuhārati": ['mw'],
    "ānujāvara": ['ap90', 'mw'],
    "ānukalpika": ['ap90', 'mw'],
    "ānukhaḍgya": ['mw'],
    "ānukūlika": ['ap90', 'ddsa', 'mw'],
    "ānukūlya": ['mw'],
    "ānukūlyatas": ['mw'],
    "ānukūlyaṃ": ['ap90'],
    "ānukṛṣṭa": ['mw'],
    "ānulepika": ['ap90'],
    "ānulomika": ['ap90', 'bhs', 'cped', 'mw'],
    "ānulomya": ['ap90', 'cae', 'mw'],
    "ānumata": ['mw'],
    "ānumānika": ['ap90', 'mw'],
    "ānumānikatva": ['mw'],
    "ānumāṣya": ['mw'],
    "ānunāsikya": ['mw'],
    "ānunāsikyaṃ": ['ap90'],
    "ānunāśya": ['mw'],
    "ānupadika": ['ap90', 'mw'],
    "ānupadya": ['mw'],
    "ānupathika": ['bhs'],
    "ānupathya": ['mw'],
    "ānupubba": ['cped'],
    "ānupubbikathā": ['cped'],
    "ānupūrva": ['cae', 'mw'],
    "ānupūrvaṃ": ['ap90'],
    "ānupūrve": ['ap90'],
    "ānupūrvya": ['mw'],
    "ānupūrvā": ['bhs'],
    "ānurakti": ['mw'],
    "ānuraktiḥ": ['ap90'],
    "ānurohati": ['mw'],
    "ānurohiṇa": ['mw'],
    "ānurāhati": ['mw'],
    "ānurūpya": ['mw'],
    "ānusuka": ['mw'],
    "ānusāyya": ['mw'],
    "ānusīrya": ['mw'],
    "ānusītya": ['mw'],
    "ānusūka": ['mw'],
    "ānusūya": ['ap90', 'mw'],
    "ānusṛtineya": ['mw'],
    "ānusṛṣṭineya": ['mw'],
    "ānutilya": ['mw'],
    "ānutrāsi": ['cped'],
    "ānutrāsin": ['cped'],
    "ānuttariya": ['cped'],
    "ānuttarya": ['bhs'],
    "ānuttāsi": ['cped'],
    "ānuttāsin": ['cped'],
    "ānuvaṃśya": ['mw'],
    "ānuveśya": ['cae', 'mw'],
    "ānuveśyaḥ": ['ap90'],
    "ānuvidhitsā": ['ap90', 'mw'],
    "ānuvāsanika": ['mw'],
    "ānuyavya": ['mw'],
    "ānuyājika": ['mw'],
    "ānuyātrika": ['cae', 'mw'],
    "ānuyātrikaḥ": ['ap90'],
    "ānuyūpya": ['mw'],
    "ānuśaṃsa": ['bhs'],
    "ānuśrava": ['mw'],
    "ānuśravika": ['ap90', 'mw'],
    "ānuśrāvika": ['ap90', 'mw'],
    "ānuśāsanika": ['ap90', 'mw'],
    "ānuśāsti": ['bhs'],
    "ānuśātika": ['mw'],
    "ānuśūka": ['ap90', 'mw'],
    "ānuḍuha": ['mw'],
    "ānuṣaj": ['ap90'],
    "ānuṣak": ['ap90', 'cae', 'gra', 'mw'],
    "ānuṣaṃgika": ['ap90'],
    "ānuṣaṅgika": ['cae', 'mw'],
    "ānuṣaṅgikatva": ['mw'],
    "ānuṣaṇḍa": ['mw'],
    "ānuṣūka": ['ap90', 'mw'],
    "ānuṣṭubha": ['ap90', 'gra', 'mw'],
    "ānuṣṭubhauṣṇiha": ['mw'],
    "ānvayika": ['ap90', 'mw'],
    "ānvāhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "ānvīkṣikī": ['ap90', 'cae', 'ddsa', 'mw'],
    "ānvīpika": ['ap90', 'mw'],
    "ānyabhāvya": ['mw'],
    "ānyabhāvyaṃ": ['ap90'],
    "ānyatareya": ['mw'],
    "ānābhi": ['mw'],
    "ānāha": ['bhs', 'mw'],
    "ānāhaḥ": ['ap90'],
    "ānāhika": ['ap90', 'mw'],
    "ānāka": ['ddsa'],
    "ānākarathavartman": ['mw'],
    "ānāmana": ['mw'],
    "ānāmita": ['mw'],
    "ānāmya": ['mw'],
    "ānāpayati": ['cped'],
    "ānāpesi": ['cped'],
    "ānāpeti": ['bhs', 'cped'],
    "ānāpāna": ['bhs'],
    "ānāthya": ['ddsa', 'mw'],
    "ānāthyaṃ": ['ap90'],
    "ānāya": ['cae', 'ddsa', 'mw'],
    "ānāyaḥ": ['ap90'],
    "ānāyin": ['ap90', 'ddsa', 'mw'],
    "ānāyya": ['ap90', 'mw'],
    "ānāyāya": ['ddsa', 'mw'],
    "ānāśa": ['ddsa'],
    "ānī": ['ap90', 'mw'],
    "ānīkavata": ['mw'],
    "ānīla": ['ap90', 'cae', 'ddsa', 'mw'],
    "ānīlaniṣadhāyata": ['mw'],
    "ānīlaniṣadhāyāma": ['mw'],
    "ānīlī": ['mw'],
    "ānīta": ['cped', 'mw'],
    "ānīti": ['cae', 'ddsa', 'mw'],
    "ānītiḥ": ['ap90'],
    "ānīyamāna": ['cped'],
    "ānīyati": ['cped'],
    "ānūka": ['mw'],
    "ānūkam": ['gra', 'mw'],
    "ānūkaṃ": ['ap90'],
    "ānūpa": ['ap90', 'ddsa', 'mw'],
    "ānūpaka": ['ap90', 'mw'],
    "ānūpamāṃsa": ['mw'],
    "ānṛt": ['mw'],
    "ānṛta": ['ap90', 'mw'],
    "ānṛtaka": ['mw'],
    "ānṛtika": ['mw'],
    "ānṛśaṃsa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ānṛśaṃsi": ['mw'],
    "ānṛśaṃsya": ['cae', 'mw'],
    "ānṛśaṃsyatas": ['mw'],
    "ānṛśaṃsīya": ['mw'],
    "ānṛṇya": ['cae', 'ddsa', 'mw'],
    "ānṛṇyaṃ": ['ap90'],
    "āp": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āpa": ['bhs', 'cped', 'mw'],
    "āpabhaṭṭa": ['mw'],
    "āpabhinandi": ['cped'],
    "āpabhinandin": ['cped'],
    "āpad": ['ap90', 'cae', 'ddsa', 'mw'],
    "āpadatthā": ['cped'],
    "āpadatthāya": ['cped'],
    "āpaddharma": ['cae', 'mw'],
    "āpadeva": ['mw'],
    "āpadevī": ['mw'],
    "āpadgata": ['cae', 'mw'],
    "āpadgrasta": ['mw'],
    "āpadika": ['mw'],
    "āpaduddharaṇa": ['mw'],
    "āpadvinīta": ['mw'],
    "āpadyana": ['bhs'],
    "āpadā": ['ap90', 'bhs', 'cped', 'mw'],
    "āpadī": ['cped'],
    "āpagaharaka": ['cped'],
    "āpageya": ['ddsa', 'mw'],
    "āpageyaḥ": ['ap90'],
    "āpagā": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "āpajigucchaka": ['cped'],
    "āpajja": ['cped'],
    "āpajjamāna": ['cped'],
    "āpajjanta": ['cped'],
    "āpajjati": ['cped'],
    "āpajji": ['cped'],
    "āpajjissatha": ['cped'],
    "āpajjita": ['cped'],
    "āpajjitabba": ['cped'],
    "āpajjitar": ['cped'],
    "āpajjitvā": ['cped'],
    "āpajjiṁsu": ['cped'],
    "āpajjura": ['bhs'],
    "āpaka": ['ap90', 'mw'],
    "āpakara": ['ap90', 'mw'],
    "āpakva": ['ap90', 'ddsa', 'mw'],
    "āpala": ['mw'],
    "āpamityaka": ['ap90', 'mw'],
    "āpan": ['mw'],
    "āpana": ['mw'],
    "āpanaṃ": ['ap90'],
    "āpaneya": ['cae', 'mw'],
    "āpanikaḥ": ['ap90'],
    "āpanna": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "āpannajīvika": ['mw'],
    "āpannaka": ['bhs'],
    "āpannasattvā": ['cae', 'mw'],
    "āpannārtipraśamanaphala": ['mw'],
    "āparapakṣīya": ['mw'],
    "āpartuka": ['ap90', 'mw'],
    "āparuṣa": ['mw'],
    "āparvabhāga": ['ddsa'],
    "āparādhayya": ['mw'],
    "āparāhṇika": ['ap90', 'mw'],
    "āparāntika": ['bhs'],
    "āpas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āpaskara": ['bhs'],
    "āpaskāraṃ": ['ap90'],
    "āpastamba": ['cae', 'ddsa', 'mw'],
    "āpastambadharma": ['mw'],
    "āpastambagṛhya": ['mw'],
    "āpastambasūtra": ['mw'],
    "āpastambaśrauta": ['mw'],
    "āpastambha": ['mw'],
    "āpastambhinī": ['mw'],
    "āpastambi": ['mw'],
    "āpastambīya": ['mw'],
    "āpat": ['ap90', 'mw'],
    "āpatana": ['ddsa', 'mw'],
    "āpatanaṃ": ['ap90'],
    "āpatanta": ['mw'],
    "āpathi": ['ap90', 'cae', 'gra', 'mw'],
    "āpathī": ['cae', 'gra', 'mw'],
    "āpati": ['ap90', 'mw'],
    "āpatika": ['ap90', 'mw'],
    "āpatita": ['ap90', 'mw'],
    "āpatkalpa": ['cae', 'ddsa', 'mw'],
    "āpatkāla": ['mw'],
    "āpatkālika": ['mw'],
    "āpatprāpta": ['ddsa'],
    "āpatsahāya": ['mw'],
    "āpatti": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "āpattibahula": ['cped'],
    "āpattigāmi": ['cped'],
    "āpattigāmin": ['cped'],
    "āpattika": ['bhs'],
    "āpattikkhanda": ['cped'],
    "āpattikusalatā": ['cped'],
    "āpattilesa": ['cped'],
    "āpattivuṭṭhāna": ['cped'],
    "āpattiḥ": ['ap90'],
    "āpattos": ['mw'],
    "āpattādhikaraṇa": ['cped'],
    "āpatya": ['ap90', 'ddsa', 'mw'],
    "āpava": ['mw'],
    "āpavargika": ['mw'],
    "āpavargya": ['ap90', 'mw'],
    "āpavaḥ": ['ap90'],
    "āpayitṛ": ['ap90', 'mw'],
    "āpayā": ['ap90', 'gra', 'mw'],
    "āpaś": ['mw'],
    "āpaśyati": ['bhs'],
    "āpaḥ": ['ap90'],
    "āpaṇa": ['cae', 'cped', 'ddsa', 'mw'],
    "āpaṇadevatā": ['mw'],
    "āpaṇavedikā": ['mw'],
    "āpaṇavīthika": ['mw'],
    "āpaṇaḥ": ['ap90'],
    "āpaṇika": ['ap90', 'bhs', 'cped', 'mw'],
    "āpaṇīya": ['mw'],
    "āpaṭ": ['mw'],
    "āpaṭava": ['mw'],
    "āpekṣika": ['ap90', 'mw'],
    "āpekṣikatva": ['mw'],
    "āpeya": ['mw'],
    "āpeyatva": ['mw'],
    "āpeṣam": ['mw'],
    "āphalaka": ['mw'],
    "āphalodayakarman": ['ddsa', 'mw'],
    "āphalya": ['mw'],
    "āphaṇ": ['mw'],
    "āphīna": ['mw'],
    "āphūkaṃ": ['ap90'],
    "āpi": ['cae', 'ddsa', 'gra', 'mw'],
    "āpia": ['gra'],
    "āpibd": ['mw'],
    "āpitva": ['ddsa', 'gra', 'mw'],
    "āpiñjara": ['ddsa', 'mw'],
    "āpiś": ['mw'],
    "āpiśala": ['ap90', 'mw'],
    "āpiśali": ['mw'],
    "āpiśaliḥ": ['ap90'],
    "āpiśarvara": ['mw'],
    "āpiśaṅga": ['ddsa', 'mw'],
    "āpiḥ": ['ap90'],
    "āpiṃjara": ['ap90'],
    "āpiṅga": ['mw'],
    "āpiṅgala": ['mw'],
    "āpiṅgalaka": ['mw'],
    "āpiṅgalākṣa": ['mw'],
    "āpiṣ": ['mw'],
    "āplava": ['cae', 'ddsa', 'mw'],
    "āplavana": ['mw'],
    "āplavavratin": ['mw'],
    "āplavaḥ": ['ap90'],
    "āplu": ['ap90', 'mw'],
    "āpluta": ['ap90', 'cae', 'mw'],
    "āplutavratin": ['mw'],
    "āpluti": ['mw'],
    "āplutya": ['mw'],
    "āplutāṅga": ['mw'],
    "āpluṣṭa": ['cae', 'mw'],
    "āplāva": ['ddsa', 'mw'],
    "āplāvaḥ": ['ap90'],
    "āplāvita": ['mw'],
    "āplāvya": ['mw'],
    "āpnavāna": ['mw'],
    "āpnāna": ['mw'],
    "āpo": ['cped', 'mw'],
    "āpoda": ['mw'],
    "āpodevata": ['mw'],
    "āpodevatya": ['mw'],
    "āpohiṣṭhīya": ['mw'],
    "āpokasiṇa": ['cped'],
    "āpoklima": ['mw'],
    "āpoklimaṃ": ['ap90'],
    "āpomaya": ['ap90', 'cae', 'ddsa', 'mw'],
    "āpomātrā": ['ap90', 'mw'],
    "āpomūrti": ['mw'],
    "āpothya": ['mw'],
    "āpośāna": ['mw'],
    "āpośānaḥ": ['ap90'],
    "āpo’śāna": ['ddsa'],
    "āpra": ['ap90', 'cae', 'gra', 'mw'],
    "āpracch": ['ap90'],
    "āpracchana": ['mw'],
    "āpracchanaṃ": ['ap90'],
    "āpracchanna": ['ap90'],
    "āprach": ['mw'],
    "āpradivam": ['mw'],
    "āpradivaṃ": ['ap90'],
    "āprapadam": ['cae', 'ddsa', 'mw'],
    "āprapadaṃ": ['ap90'],
    "āprapadīna": ['ap90', 'cae', 'mw'],
    "āprapadīnaka": ['mw'],
    "āprath": ['mw'],
    "āpratinivṛt": ['mw'],
    "āpratinivṛttaguṇormicakra": ['mw'],
    "āpratī": ['mw'],
    "āpravartana": ['mw'],
    "āpravaṇa": ['mw'],
    "āprayam": ['mw'],
    "āpraṣṭavya": ['mw'],
    "āpru": ['mw'],
    "āpruṣāya": ['mw'],
    "āprā": ['mw'],
    "āprāsa": ['mw'],
    "āprāvṛṣam": ['mw'],
    "āprāṇya": ['bhs'],
    "āprī": ['ap90', 'cae', 'ddsa', 'mw'],
    "āprīta": ['cae', 'mw'],
    "āprītapaḥ": ['ap90'],
    "āprītapā": ['mw'],
    "āprītimāyava": ['mw'],
    "āprītimāyu": ['mw'],
    "āpsara": ['mw'],
    "āpsarasa": ['mw'],
    "āpsava": ['mw'],
    "āpta": ['ap90', 'cae', 'ddsa', 'mw'],
    "āptabhāva": ['mw'],
    "āptacchandas": ['mw'],
    "āptadakṣiṇa": ['cae', 'mw'],
    "āptagarbhā": ['mw'],
    "āptagarva": ['mw'],
    "āptakriya": ['mw'],
    "āptakāma": ['mw'],
    "āptakārin": ['cae', 'mw'],
    "āptakṛt": ['mw'],
    "āptamanas": ['bhs'],
    "āptastoma": ['mw'],
    "āptavacana": ['mw'],
    "āptavajrasūci": ['mw'],
    "āptavarga": ['cae', 'mw'],
    "āptavibhaktika": ['mw'],
    "āptavya": ['mw'],
    "āptavāc": ['cae', 'mw'],
    "āptavāda": ['mw'],
    "āptavākya": ['mw'],
    "āptaśruti": ['mw'],
    "āpti": ['cae', 'ddsa', 'mw'],
    "āptia": ['gra'],
    "āptiḥ": ['ap90'],
    "āptokti": ['mw'],
    "āptopadeśa": ['mw'],
    "āptoryāma": ['mw'],
    "āptoryāman": ['mw'],
    "āptya": ['cae', 'ddsa', 'gra', 'mw'],
    "āptyaḥ": ['ap90'],
    "āptā": ['mw'],
    "āptādhīna": ['mw'],
    "āptāgama": ['mw'],
    "āpuccha": ['cped'],
    "āpucchat": ['cped'],
    "āpucchati": ['cped'],
    "āpucchi": ['cped'],
    "āpucchita": ['cped'],
    "āpucchitabba": ['cped'],
    "āpucchitvā": ['cped'],
    "āpucchitūna": ['cped'],
    "āpucchiṁsu": ['cped'],
    "āpucchā": ['cped'],
    "āputh": ['mw'],
    "āpvan": ['ap90'],
    "āpvā": ['ap90', 'mw'],
    "āpya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "āpyai": ['ap90', 'mw'],
    "āpyeya": ['mw'],
    "āpyeyatva": ['mw'],
    "āpyāna": ['ap90', 'mw'],
    "āpyānavat": ['mw'],
    "āpyāya": ['ddsa', 'mw'],
    "āpyāyaka": ['bhs'],
    "āpyāyana": ['ap90', 'cae', 'mw'],
    "āpyāyanavat": ['mw'],
    "āpyāyanaśīla": ['mw'],
    "āpyāyanī": ['mw'],
    "āpyāyaḥ": ['ap90'],
    "āpyāyin": ['mw'],
    "āpyāyinī": ['mw'],
    "āpyāyita": ['ap90', 'mw'],
    "āpyāyya": ['mw'],
    "āpā": ['ap90', 'mw'],
    "āpāda": ['mw'],
    "āpādaka": ['cped', 'mw'],
    "āpādana": ['mw'],
    "āpādanaṃ": ['ap90'],
    "āpādatalamastakam": ['mw'],
    "āpādayati": ['cped'],
    "āpādaḥ": ['ap90'],
    "āpādenta": ['cped'],
    "āpādesi": ['cped'],
    "āpādeta": ['cped'],
    "āpādetar": ['cped'],
    "āpādeti": ['cped'],
    "āpādi": ['cped'],
    "āpādin": ['mw'],
    "āpādu": ['cped'],
    "āpāduṁ": ['cped'],
    "āpāka": ['mw'],
    "āpākaḥ": ['ap90'],
    "āpākestha": ['mw'],
    "āpāla": ['mw'],
    "āpāli": ['mw'],
    "āpāliḥ": ['ap90'],
    "āpāna": ['cae', 'ddsa', 'mw'],
    "āpānabhūmi": ['mw'],
    "āpānagoṣṭhī": ['mw'],
    "āpānaka": ['mw'],
    "āpānaśālā": ['mw'],
    "āpānaṃ": ['ap90'],
    "āpāntamanyu": ['gra', 'mw'],
    "āpānīyakaṁsa": ['cped'],
    "āpārṣṇi": ['cae', 'ddsa', 'mw'],
    "āpāta": ['ap90', 'cae', 'ddsa', 'mw'],
    "āpātalikā": ['mw'],
    "āpātamātra": ['mw'],
    "āpātaparipātaṁ": ['cped'],
    "āpātatas": ['mw'],
    "āpātataḥ": ['ap90'],
    "āpātha": ['cped'],
    "āpāthagata": ['cped'],
    "āpāthakanisādi": ['cped'],
    "āpāthakanisādin": ['cped'],
    "āpātika": ['mw'],
    "āpātin": ['ap90', 'ddsa', 'mw'],
    "āpātita": ['mw'],
    "āpātya": ['mw'],
    "āpāya": ['bhs'],
    "āpāyaka": ['bhs'],
    "āpāyika": ['bhs', 'cped'],
    "āpāyin": ['ap90', 'mw'],
    "āpāyita": ['bhs'],
    "āpāṃgyaṃ": ['ap90'],
    "āpāṅgya": ['mw'],
    "āpāṇakoṭikaṁ": ['cped'],
    "āpāṇḍu": ['cae', 'ddsa', 'mw'],
    "āpāṇḍura": ['cae', 'ddsa', 'mw'],
    "āpāṇḍurībhū": ['mw'],
    "āpāṇḍutā": ['mw'],
    "āpāṣṭhi": ['mw'],
    "āpāṭala": ['cae', 'ddsa', 'mw'],
    "āpāṭaliputram": ['mw'],
    "āpī": ['ap90', 'mw'],
    "āpīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "āpīnavat": ['mw'],
    "āpīrā": ['bhs'],
    "āpīta": ['ap90', 'cae', 'ddsa', 'mw'],
    "āpītaya": ['mw'],
    "āpīya": ['mw'],
    "āpīḍ": ['ap90', 'mw'],
    "āpīḍa": ['ap90', 'cae', 'ddsa', 'mw'],
    "āpīḍaka": ['bhs'],
    "āpīḍakajāta": ['mw'],
    "āpīḍana": ['mw'],
    "āpīḍanaṃ": ['ap90'],
    "āpīḍin": ['mw'],
    "āpīḍita": ['ap90', 'mw'],
    "āpū": ['mw'],
    "āpūpika": ['ap90', 'mw'],
    "āpūpya": ['ddsa', 'mw'],
    "āpūpyaḥ": ['ap90'],
    "āpūra": ['ap90', 'ddsa', 'mw'],
    "āpūrati": ['cped'],
    "āpūraṇa": ['ap90', 'cae', 'mw'],
    "āpūrita": ['mw'],
    "āpūrta": ['ddsa', 'mw'],
    "āpūrtiḥ": ['ap90'],
    "āpūrya": ['mw'],
    "āpūryamāṇa": ['ap90', 'mw'],
    "āpūryamāṇapakṣa": ['mw'],
    "āpūrṇa": ['ap90', 'cae', 'ddsa'],
    "āpūrṇamaṇḍala": ['cae'],
    "āpūy": ['mw'],
    "āpūyita": ['mw'],
    "āpūṣa": ['mw'],
    "āpūṣaṃ": ['ap90'],
    "āpṛ": ['mw'],
    "āpṛc": ['ap90', 'gra', 'mw'],
    "āpṛcchaya": ['cae'],
    "āpṛcchya": ['ap90', 'mw'],
    "āpṛcchā": ['ap90', 'mw'],
    "āpṛchia": ['gra'],
    "āpṛchya": ['gra'],
    "āpṛk": ['cae', 'mw'],
    "āpṛta": ['mw'],
    "āpṛṣṭa": ['mw'],
    "āpṛṣṭvā": ['mw'],
    "āpṝ": ['ap90', 'mw'],
    "ār": ['cae', 'ddsa', 'gra', 'mw'],
    "āra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "āraba": ['mw'],
    "ārabbha": ['cped'],
    "ārabbhati": ['cped'],
    "ārabdha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ārabdhavya": ['mw'],
    "ārabdhi": ['cae', 'ddsa', 'mw'],
    "ārabdhiḥ": ['ap90'],
    "ārabh": ['ap90', 'mw'],
    "ārabha": ['cped'],
    "ārabhamāna": ['cped'],
    "ārabhamāṇa": ['mw'],
    "ārabhat": ['cped'],
    "ārabhati": ['cped'],
    "ārabhaṭa": ['mw'],
    "ārabhaṭaḥ": ['ap90'],
    "ārabhaṭī": ['ddsa', 'mw'],
    "ārabhissati": ['cped'],
    "ārabhiyamāna": ['cped'],
    "ārabhiṁsu": ['cped'],
    "ārabhya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ārabhyamāṇa": ['mw'],
    "ārabyayāminī": ['mw'],
    "ārac": ['mw'],
    "āracayya": ['mw'],
    "āracayāracayā": ['cped'],
    "āracita": ['ap90', 'mw'],
    "āraddha": ['cped', 'mw'],
    "āraddhā": ['cped'],
    "āraddhāyani": ['mw'],
    "āradvat": ['mw'],
    "āragvadha": ['mw'],
    "āragvadhaḥ": ['ap90'],
    "āraik": ['ddsa'],
    "ārajayārajayā": ['cped'],
    "āraka": ['cped'],
    "ārakatta": ['cped'],
    "ārakkha": ['cped'],
    "ārakkhasārathi": ['cped'],
    "ārakkhat": ['cped'],
    "ārakkhādhikaraṇaṁ": ['cped'],
    "ārakta": ['cae', 'ddsa', 'mw'],
    "āraktapuṣpī": ['mw'],
    "āraktībhū": ['mw'],
    "ārakāt": ['ap90', 'cae', 'mw'],
    "ārakūṭa": ['mw'],
    "ārakṣ": ['mw'],
    "ārakṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ārakṣaka": ['cae', 'ddsa', 'mw'],
    "ārakṣakaḥ": ['ap90'],
    "ārakṣaṇa": ['cae'],
    "ārakṣaṇatā": ['bhs'],
    "ārakṣika": ['mw'],
    "ārakṣikaḥ": ['ap90'],
    "ārakṣin": ['mw'],
    "ārakṣita": ['mw'],
    "ārakṣitar": ['bhs'],
    "ārakṣya": ['bhs', 'mw'],
    "ārakṣā": ['mw'],
    "āralu": ['mw'],
    "āram": ['ap90', 'mw'],
    "āramati": ['cped'],
    "āramaṇa": ['ddsa', 'mw'],
    "āramaṇaṃ": ['ap90'],
    "ārambaṇa": ['bhs', 'mw'],
    "ārambaṇacchedana": ['mw'],
    "ārambaṇachedana": ['bhs'],
    "ārambaṇaka": ['bhs'],
    "ārambaṇīya": ['bhs'],
    "ārambha": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "ārambhaka": ['mw'],
    "ārambharuci": ['cae', 'mw'],
    "ārambharucitā": ['mw'],
    "ārambhasiddhi": ['mw'],
    "ārambhati": ['cped'],
    "ārambhatā": ['mw'],
    "ārambhayajña": ['mw'],
    "ārambhaṇa": ['cae', 'gra', 'mw'],
    "ārambhaṇavat": ['mw'],
    "ārambhaṇīya": ['mw'],
    "ārambhin": ['ddsa', 'mw'],
    "ārambhita": ['mw'],
    "ārammaṇa": ['cped'],
    "āranāla": ['mw'],
    "āranālaka": ['mw'],
    "āranālaṃ": ['ap90'],
    "ārap": ['mw'],
    "āras": ['mw'],
    "ārasa": ['mw'],
    "ārasita": ['cae', 'mw'],
    "ārasya": ['mw'],
    "ārasyaṃ": ['ap90'],
    "ārata": ['ap90', 'mw'],
    "āratas": ['bhs'],
    "ārathaḥ": ['ap90'],
    "ārati": ['bhs', 'cped', 'mw'],
    "āratiḥ": ['ap90'],
    "ārava": ['ap90', 'cae', 'ddsa', 'mw'],
    "āravaḍiṇḍima": ['ddsa', 'mw'],
    "āravaḥ": ['ap90'],
    "ārañjita": ['cped'],
    "ārañña": ['cped'],
    "āraññaka": ['cped'],
    "āraññakaṅga": ['cped'],
    "āraññika": ['cped'],
    "āraññikaṅga": ['cped'],
    "āraḍava": ['mw'],
    "āraḥ": ['ap90'],
    "āraṃbaṇaṃ": ['ap90'],
    "āraṃbhaka": ['ap90'],
    "āraṃbhaḥ": ['ap90'],
    "āraṃbhaṇaṃ": ['ap90'],
    "āraṃbhin": ['ap90'],
    "āraṅga": ['bhs'],
    "āraṅgara": ['cae', 'gra', 'mw'],
    "āraṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "āraṇaja": ['mw'],
    "āraṇaṃ": ['ap90'],
    "āraṇeya": ['ap90', 'mw'],
    "āraṇeyaparvan": ['mw'],
    "āraṇi": ['mw'],
    "āraṇiḥ": ['ap90'],
    "āraṇya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āraṇyadhuta": ['bhs'],
    "āraṇyagāna": ['mw'],
    "āraṇyaka": ['ap90', 'bhs', 'cae', 'mw'],
    "āraṇyakagāna": ['mw'],
    "āraṇyakakāṇḍa": ['mw'],
    "āraṇyakukkuṭa": ['mw'],
    "āraṇyakāṇḍa": ['mw'],
    "āraṇyamudgā": ['mw'],
    "āraṇyaparvan": ['mw'],
    "āraṇyapaśu": ['cae', 'mw'],
    "āraṇyarāśi": ['mw'],
    "āraṇyopala": ['mw'],
    "āraṭ": ['mw'],
    "āraṭa": ['mw'],
    "āraṭaḥ": ['ap90'],
    "āraṭi": ['cae', 'ddsa', 'mw'],
    "āraṭita": ['mw'],
    "āraṭṭa": ['mw'],
    "āraṭṭaja": ['mw'],
    "āraṭṭaka": ['mw'],
    "āraṭṭaḥ": ['ap90'],
    "ārbhava": ['ap90', 'mw'],
    "ārbudi": ['mw'],
    "ārca": ['ap90', 'mw'],
    "ārcatka": ['gra', 'mw'],
    "ārch": ['mw'],
    "ārcika": ['ap90', 'mw'],
    "ārcābhin": ['mw'],
    "ārcāyana": ['mw'],
    "ārcīka": ['ap90', 'mw'],
    "ārcīkaparvata": ['mw'],
    "ārda": ['mw'],
    "ārddha": ['bhs', 'mw'],
    "ārdh": ['mw'],
    "ārdha": ['ap90', 'mw'],
    "ārdhadhātuka": ['cae', 'ddsa', 'mw'],
    "ārdhadhātukīya": ['mw'],
    "ārdhadrauṇika": ['mw'],
    "ārdhakauḍavika": ['mw'],
    "ārdhakaṃsika": ['mw'],
    "ārdhakrośika": ['mw'],
    "ārdhamāsika": ['mw'],
    "ārdhanārīśvara": ['mw'],
    "ārdhaprasthika": ['mw'],
    "ārdharātrika": ['mw'],
    "ārdhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "ārdhuka": ['ap90', 'mw'],
    "ārdra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ārdrabhāva": ['cae', 'mw'],
    "ārdradānu": ['mw'],
    "ārdrahasta": ['mw'],
    "ārdraidhāgni": ['cae', 'ddsa', 'mw'],
    "ārdraja": ['mw'],
    "ārdraka": ['ap90', 'mw'],
    "ārdrakāṣṭha": ['mw'],
    "ārdramañjarī": ['mw'],
    "ārdramāṣā": ['mw'],
    "ārdramūla": ['mw'],
    "ārdranayana": ['mw'],
    "ārdrapada": ['mw'],
    "ārdrapattraka": ['mw'],
    "ārdrapavi": ['mw'],
    "ārdrapavitra": ['mw'],
    "ārdrapaṭī": ['mw'],
    "ārdrapāda": ['cae'],
    "ārdratva": ['mw'],
    "ārdratā": ['ap90', 'mw'],
    "ārdravallipratirūpa": ['bhs'],
    "ārdravastra": ['cae'],
    "ārdravastratā": ['mw'],
    "ārdravāsas": ['cae', 'mw'],
    "ārdraya": ['mw'],
    "ārdrayati": ['ap90'],
    "ārdraśāka": ['mw'],
    "ārdrya": ['mw'],
    "ārdrā": ['mw'],
    "ārdrālubdhaka": ['mw'],
    "ārdrānulepana": ['mw'],
    "ārdrārdra": ['ddsa'],
    "ārdrīkṛ": ['ddsa', 'mw'],
    "āre": ['ap90', 'cae', 'ddsa', 'mw'],
    "āreagha": ['gra', 'mw'],
    "āreavadya": ['gra', 'mw'],
    "ārecin": ['mw'],
    "ārecita": ['ap90', 'mw'],
    "ārecitabhrū": ['mw'],
    "ārehaṇa": ['mw'],
    "ārehaṇaṃ": ['ap90'],
    "āreka": ['mw'],
    "ārekaḥ": ['ap90'],
    "ārevataḥ": ['ap90'],
    "āreśatru": ['mw'],
    "ārgala": ['mw'],
    "ārgalaḥ": ['ap90'],
    "ārgayana": ['mw'],
    "ārghya": ['ap90', 'mw'],
    "ārghā": ['ap90', 'mw'],
    "ārgvadha": ['ap90', 'mw'],
    "ārgvaidika": ['mw'],
    "ārhantya": ['mw'],
    "ārhata": ['ap90', 'bhs', 'mw'],
    "ārhatyaṃ": ['ap90'],
    "ārhaṃtī": ['ap90'],
    "ārhāyaṇa": ['mw'],
    "āria": ['gra'],
    "āric": ['ap90', 'mw'],
    "ārih": ['mw'],
    "āriph": ['mw'],
    "āripsu": ['ddsa', 'mw'],
    "ārirādhayiṣu": ['ddsa', 'mw'],
    "ārita": ['mw'],
    "āritrika": ['ap90', 'mw'],
    "āritīyate": ['bhs'],
    "āriś": ['mw'],
    "āriṃdamika": ['mw'],
    "āriṣ": ['mw'],
    "ārjanā": ['bhs'],
    "ārjava": ['bhs', 'cae', 'ddsa', 'mw'],
    "ārjavaka": ['mw'],
    "ārjavaṃ": ['ap90'],
    "ārjavin": ['mw'],
    "ārjayati": ['bhs'],
    "ārjika": ['mw'],
    "ārjuna": ['mw'],
    "ārjuneya": ['gra', 'mw'],
    "ārjuni": ['mw'],
    "ārjuniḥ": ['ap90'],
    "ārjunāyana": ['mw'],
    "ārjunāyanaka": ['mw'],
    "ārjīka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ārjīkīya": ['ap90', 'cae', 'gra', 'mw'],
    "ārjīkīyā": ['mw'],
    "ārka": ['mw'],
    "ārkalūṣa": ['mw'],
    "ārkalūṣāyaṇa": ['mw'],
    "ārkalūṣāyaṇi": ['mw'],
    "ārkam": ['mw'],
    "ārki": ['mw'],
    "ārkiḥ": ['ap90'],
    "ārkāyaṇa": ['mw'],
    "ārkāyaṇi": ['mw'],
    "ārkṣa": ['ap90', 'gra', 'mw'],
    "ārkṣavarṣa": ['mw'],
    "ārkṣoda": ['ap90', 'mw'],
    "ārkṣya": ['mw'],
    "ārkṣyat": ['mw'],
    "ārkṣyāyaṇī": ['mw'],
    "ārkṣākāyaṇa": ['mw'],
    "ārocaka": ['bhs', 'mw'],
    "ārocana": ['ap90', 'bhs', 'mw'],
    "ārocayati": ['bhs'],
    "ārocenta": ['cped'],
    "ārocesi": ['cped'],
    "ārocesiṁ": ['cped'],
    "ārocesuṁ": ['cped'],
    "ārocetabba": ['cped'],
    "āroceti": ['cped'],
    "ārocetvā": ['cped'],
    "ārocimha": ['cped'],
    "ārocita": ['cped'],
    "ārocāpesi": ['cped'],
    "ārocāpesum": ['cped'],
    "ārocāpetabba": ['cped'],
    "ārocāpetvā": ['cped'],
    "ārodana": ['bhs', 'cped'],
    "ārodha": ['ddsa', 'mw'],
    "ārodhana": ['gra', 'mw'],
    "ārodhanaṃ": ['ap90'],
    "āroga": ['mw'],
    "ārogiya": ['cped'],
    "ārogya": ['cae', 'cped', 'ddsa', 'mw'],
    "ārogyacintāmaṇi": ['mw'],
    "ārogyamālā": ['mw'],
    "ārogyapañcaka": ['mw'],
    "ārogyapratipadvrata": ['mw'],
    "ārogyatā": ['mw'],
    "ārogyavat": ['mw'],
    "ārogyavrata": ['mw'],
    "ārogyaya": ['mw'],
    "ārogyayati": ['bhs'],
    "ārogyaśālā": ['mw'],
    "ārogyaṃ": ['ap90'],
    "ārogyā": ['mw'],
    "ārogyāmbu": ['mw'],
    "āroha": ['bhs', 'cae', 'ddsa', 'mw'],
    "ārohaka": ['ap90', 'mw'],
    "ārohana": ['cped'],
    "ārohanta": ['cped'],
    "ārohanīya": ['cped'],
    "ārohati": ['cped'],
    "ārohaḥ": ['ap90'],
    "ārohaṇa": ['cae', 'cped', 'mw'],
    "ārohaṇavāha": ['mw'],
    "ārohaṇaṃ": ['ap90'],
    "ārohaṇika": ['ap90', 'mw'],
    "ārohaṇīya": ['cped', 'mw'],
    "ārohin": ['ap90', 'cae', 'mw'],
    "ārohitvā": ['cped'],
    "āroka": ['gra', 'mw'],
    "ārokaḥ": ['ap90'],
    "āropa": ['cae', 'ddsa', 'mw'],
    "āropaka": ['ap90', 'mw'],
    "āropamānaka": ['cped'],
    "āropanā": ['cped'],
    "āropayati": ['bhs', 'cped'],
    "āropaḥ": ['ap90'],
    "āropaṇa": ['cae', 'mw'],
    "āropaṇaṃ": ['ap90'],
    "āropaṇīya": ['cae', 'mw'],
    "āropesuṁ": ['cped'],
    "āropetabba": ['cped'],
    "āropeti": ['cped'],
    "āropetvā": ['cped'],
    "āropita": ['ap90', 'cae', 'cped', 'mw'],
    "āropya": ['cae', 'mw'],
    "āropyamāṇa": ['mw'],
    "āroḍhavya": ['ddsa', 'mw'],
    "āroḍhṛ": ['ddsa', 'mw'],
    "āroṣita": ['cae', 'mw'],
    "ārpayitṛ": ['ap90', 'mw'],
    "ārpita": ['mw'],
    "ārta": ['ap90', 'cae', 'ddsa', 'mw'],
    "ārtabandhu": ['mw'],
    "ārtabhāga": ['mw'],
    "ārtabhāgīputra": ['mw'],
    "ārtagala": ['mw'],
    "ārtagalaḥ": ['ap90'],
    "ārtana": ['gra', 'mw'],
    "ārtanā": ['ap90', 'mw'],
    "ārtanāda": ['mw'],
    "ārtaparṇa": ['mw'],
    "ārtasvara": ['mw'],
    "ārtatara": ['mw'],
    "ārtatā": ['mw'],
    "ārtava": ['ap90', 'cae', 'ddsa', 'mw'],
    "ārtaveyī": ['ap90'],
    "ārtavī": ['mw'],
    "ārtha": ['ap90', 'cae', 'mw'],
    "ārthapatya": ['mw'],
    "ārthapatyaṃ": ['ap90'],
    "ārthatva": ['mw'],
    "ārthika": ['ap90', 'mw'],
    "ārti": ['cae', 'ddsa', 'mw'],
    "ārtihan": ['mw'],
    "ārtihara": ['cae', 'mw'],
    "ārtimat": ['ap90', 'mw'],
    "ārtiḥ": ['ap90'],
    "ārtniḥ": ['ap90'],
    "ārtnī": ['cae', 'ddsa', 'gra', 'mw'],
    "ārtos": ['mw'],
    "ārtuparṇi": ['mw'],
    "ārtveyī": ['mw'],
    "ārtvijya": ['cae', 'ddsa', 'gra', 'mw'],
    "ārtvijyaṃ": ['ap90'],
    "ārtvijīna": ['ap90', 'mw'],
    "ārtvya": ['mw'],
    "ārtyapaharaṇa": ['mw'],
    "ārtāyana": ['mw'],
    "ārtāyani": ['mw'],
    "ārtībhāva": ['bhs'],
    "ārtīyate": ['bhs'],
    "āru": ['ap90', 'mw'],
    "āruc": ['ap90', 'mw'],
    "ārudh": ['ap90', 'mw'],
    "āruh": ['ap90', 'mw'],
    "āruha": ['ap90', 'cped', 'ddsa', 'mw'],
    "āruhana": ['cped'],
    "āruhanta": ['cped'],
    "āruhat": ['cped'],
    "āruhati": ['cped'],
    "āruhi": ['cped'],
    "āruhitvā": ['cped'],
    "āruhya": ['mw'],
    "āruj": ['ap90', 'cae', 'mw'],
    "āruja": ['cae', 'gra', 'mw'],
    "ārujatnu": ['ap90', 'cae', 'gra', 'mw'],
    "āruka": ['cae', 'mw'],
    "ārukaḥ": ['ap90'],
    "ārum, āruja": ['ddsa'],
    "ārupita": ['gra', 'mw'],
    "āruppa": ['cped'],
    "āruppavasī": ['cped'],
    "āruppavasīn": ['cped'],
    "āruppaṭṭhayi": ['cped'],
    "āruppaṭṭhayin": ['cped'],
    "ārurukṣu": ['ap90', 'cae', 'ddsa', 'mw'],
    "āruta": ['bhs', 'mw'],
    "āruyha": ['cped'],
    "āruyhati": ['cped'],
    "āruyhi": ['cped'],
    "āruḥ": ['ap90'],
    "āruḷha": ['cped'],
    "āruṇa": ['cae', 'mw'],
    "āruṇaka": ['mw'],
    "āruṇaketuka": ['mw'],
    "āruṇaparājin": ['mw'],
    "āruṇeya": ['mw'],
    "āruṇeyapada": ['mw'],
    "āruṇi": ['ap90', 'cae', 'mw'],
    "āruṇihotṛ": ['mw'],
    "āruṇin": ['mw'],
    "āruṇm, āruṇi": ['ddsa'],
    "āruṇya": ['mw'],
    "āruṇyaka": ['mw'],
    "āruṇī": ['ap90', 'gra', 'mw'],
    "āruṇīya": ['mw'],
    "āruṇīyopaniṣad": ['mw'],
    "āruṣ": ['mw'],
    "āruṣkara": ['mw'],
    "āruṣkaraṃ": ['ap90'],
    "āruṣī": ['ap90', 'mw'],
    "āruṣīya": ['mw'],
    "ārvāk": ['ap90'],
    "ārya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āryabala": ['mw'],
    "āryabhaṭa": ['cae', 'mw'],
    "āryabhaṭīya": ['mw'],
    "āryabhaṭṭa": ['mw'],
    "āryabhaṭṭaa": ['ap90'],
    "āryabhāva": ['mw'],
    "āryabhṛkuṭī": ['bhs'],
    "āryabrāhmaṇa": ['mw'],
    "āryacetas": ['cae', 'mw'],
    "āryadeva": ['bhs', 'mw'],
    "āryadeśa": ['cae', 'mw'],
    "āryadeśya": ['mw'],
    "āryadhana": ['mw'],
    "āryadharma": ['mw'],
    "āryaduhitṛ": ['mw'],
    "āryagaṇa": ['mw'],
    "āryagṛhya": ['mw'],
    "āryahalam": ['mw'],
    "āryahṛdya": ['mw'],
    "āryajana": ['mw'],
    "āryajuṣṭa": ['cae', 'mw'],
    "āryajāta": ['cae'],
    "āryaka": ['bhs', 'cae', 'mw'],
    "āryakarman": ['cae', 'mw'],
    "āryakaḥ": ['ap90'],
    "āryakulyā": ['mw'],
    "āryakumāra": ['mw'],
    "āryakā": ['ap90', 'bhs'],
    "āryakṛta": ['mw'],
    "āryaliṅgin": ['cae', 'mw'],
    "āryamahāsiṃhaukkāsita": ['bhs'],
    "āryamahāsiṃhavijṛmbhita": ['bhs'],
    "āryamahāsiṃhavilokita": ['bhs'],
    "āryamaṇa": ['mw'],
    "āryamaṇī": ['mw'],
    "āryamiśra": ['cae', 'ddsa', 'mw'],
    "āryamāna": ['bhs'],
    "āryamārga": ['mw'],
    "āryamārgapudgalanāyaka": ['mw'],
    "āryamṇa": ['cae', 'ddsa', 'mw'],
    "āryanivāsa": ['mw'],
    "āryapakṣa": ['bhs'],
    "āryapatha": ['mw'],
    "āryapravṛtta": ['mw'],
    "āryaprāya": ['cae', 'mw'],
    "āryaputra": ['cae', 'mw'],
    "āryapuṅgala": ['bhs'],
    "āryapāla": ['mw'],
    "āryarāja": ['ddsa', 'mw'],
    "āryarūpa": ['cae', 'mw'],
    "āryasamaya": ['mw'],
    "āryasarvāstivāda": ['bhs'],
    "āryasatya": ['bhs', 'mw'],
    "āryasatyakaparivarta": ['bhs'],
    "āryasaṃgha": ['mw'],
    "āryasaṃmatīya": ['bhs'],
    "āryasiddhānta": ['mw'],
    "āryasiṃha": ['mw'],
    "āryasmita": ['bhs'],
    "āryasthavira": ['mw'],
    "āryasthāvira": ['bhs'],
    "āryasthāvirīyanikāya": ['bhs'],
    "āryastrī": ['mw'],
    "āryasuta": ['mw'],
    "āryasvāmin": ['mw'],
    "āryatva": ['mw'],
    "āryatā": ['cae', 'mw'],
    "āryava": ['mw'],
    "āryavajra": ['mw'],
    "āryavarman": ['mw'],
    "āryavatī": ['bhs'],
    "āryavaṃśa": ['bhs'],
    "āryavaṃśaketu": ['bhs'],
    "āryaveśa": ['mw'],
    "āryavidagdhamiśra": ['cae'],
    "āryavrata": ['mw'],
    "āryavāc": ['cae', 'mw'],
    "āryavṛtta": ['cae', 'mw'],
    "āryayuvan": ['mw'],
    "āryaśīla": ['mw'],
    "āryaśūra": ['bhs', 'mw'],
    "āryikā": ['bhs', 'mw'],
    "āryā": ['bhs', 'mw'],
    "āryācaṇḍītīrtha": ['mw'],
    "āryādhiṣṭhita": ['ddsa', 'mw'],
    "āryādhūtā": ['cae'],
    "āryāgama": ['ddsa', 'mw'],
    "āryāgīti": ['cae', 'ddsa', 'mw'],
    "āryākṣa": ['bhs'],
    "āryāpañcāśat": ['mw'],
    "āryārāmāyaṇa": ['mw'],
    "āryāsaptaśatī": ['mw'],
    "āryāsaṅga": ['bhs'],
    "āryātriśatī": ['mw'],
    "āryāvarta": ['cae', 'ddsa', 'mw'],
    "āryāvilāsa": ['mw'],
    "āryāṇaka": ['ddsa', 'mw'],
    "āryāṣṭaśata": ['mw'],
    "āryāṣṭāṅgamārga": ['mw'],
    "ārñj": ['mw'],
    "ārā": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ārācāri": ['cped'],
    "ārācārin": ['cped'],
    "ārādh": ['ap90', 'mw'],
    "ārādha": ['cae', 'ddsa', 'mw'],
    "ārādhaka": ['ap90', 'cped', 'mw'],
    "ārādhana": ['cae', 'cped', 'mw'],
    "ārādhanaprakāra": ['mw'],
    "ārādhanaṃ": ['ap90'],
    "ārādhanā": ['mw'],
    "ārādhanīya": ['ap90', 'cped', 'mw'],
    "ārādhapekha": ['cped'],
    "ārādhaya": ['mw'],
    "ārādhayati": ['cped'],
    "ārādhayitvā": ['cped'],
    "ārādhayitṛ": ['ap90', 'cae', 'mw'],
    "ārādhayiṁsu": ['cped'],
    "ārādhayiṣṇu": ['ap90', 'mw'],
    "ārādhayya": ['mw'],
    "ārādhesi": ['cped'],
    "ārādheti": ['cped'],
    "ārādhetvā": ['cped'],
    "ārādhita": ['mw'],
    "ārādhya": ['cae', 'mw'],
    "ārādhyakarpūra": ['mw'],
    "ārādhyamāna": ['mw'],
    "ārādupakāraka": ['mw'],
    "ārādupakārin": ['mw'],
    "ārāga": ['mw'],
    "ārāgaya": ['mw'],
    "ārāgayati": ['bhs'],
    "ārāgaṇa": ['bhs'],
    "ārāgga": ['cped'],
    "ārāgita": ['mw'],
    "ārāgra": ['mw'],
    "ārāgrā": ['mw'],
    "ārājaka": ['bhs'],
    "ārājñaka": ['mw'],
    "ārājñī": ['mw'],
    "ārāla": ['mw'],
    "ārālika": ['mw'],
    "ārālikaḥ": ['ap90'],
    "ārālita": ['mw'],
    "ārāl̤hi": ['mw'],
    "ārāma": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "ārāmacetiya": ['cped'],
    "ārāmacetya": ['cped'],
    "ārāmanisādi": ['cped'],
    "ārāmanisādin": ['cped'],
    "ārāmaparigraha": ['mw'],
    "ārāmapesaka": ['cped'],
    "ārāmapāla": ['cped'],
    "ārāmaropa": ['cped'],
    "ārāmarāmaṇeyyaka": ['cped'],
    "ārāmatha": ['bhs'],
    "ārāmavatthu": ['cped'],
    "ārāmaśītalā": ['mw'],
    "ārāmika": ['bhs', 'cped', 'mw'],
    "ārāmikaḥ": ['ap90'],
    "ārāmikini": ['cped'],
    "ārāmukha": ['mw'],
    "ārāmādhipati": ['mw'],
    "ārāsa": ['ddsa', 'mw'],
    "ārāt": ['ap90', 'cae', 'ddsa', 'mw'],
    "ārāti": ['bhs', 'ddsa', 'mw'],
    "ārātiḥ": ['ap90'],
    "ārātka": ['mw'],
    "ārātrika": ['mw'],
    "ārātrikaṃ": ['ap90'],
    "ārātrivivāsam": ['mw'],
    "ārāttāt": ['ap90', 'cae', 'mw'],
    "ārātāt": ['gra'],
    "ārātīya": ['ap90', 'mw'],
    "ārāva": ['bhs', 'cae', 'ddsa', 'mw'],
    "ārāvalī": ['mw'],
    "ārāvaḥ": ['ap90'],
    "ārāvin": ['ap90', 'mw'],
    "ārāvita": ['bhs'],
    "ārāḍa": ['bhs', 'mw'],
    "ārāḍaka": ['bhs'],
    "ārāḍhi": ['mw'],
    "ārī": ['mw'],
    "ārśa": ['ap90', 'mw'],
    "ārū": ['ap90', 'mw'],
    "ārūhana": ['cped'],
    "ārūhanta": ['cped'],
    "ārūhati": ['cped'],
    "ārūhitvā": ['cped'],
    "ārūpa": ['bhs'],
    "ārūpayati": ['bhs'],
    "ārūpin": ['bhs'],
    "ārūpya": ['bhs', 'mw'],
    "ārūpyāvacara": ['bhs'],
    "ārūḍha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ārūḍhacīvara": ['bhs'],
    "ārūḍhavat": ['mw'],
    "ārūḍhayati": ['bhs'],
    "ārūḍhi": ['cae', 'mw'],
    "ārūḍhiḥ": ['ap90'],
    "ārūḷha": ['cped'],
    "ārṇava": ['bhs', 'mw'],
    "ārṣa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ārṣabha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ārṣabhi": ['mw'],
    "ārṣabhya": ['mw'],
    "ārṣabhyaḥ": ['ap90'],
    "ārṣabhī": ['mw'],
    "ārṣaṃdhara": ['mw'],
    "ārṣeya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ārṣeyabrāhmaṇa": ['cae', 'mw'],
    "ārṣeyarāmāyaṇa": ['mw'],
    "ārṣeyavat": ['mw'],
    "ārṣikya": ['mw'],
    "ārṣiṇeśva": ['mw'],
    "ārṣoḍhā": ['cae', 'ddsa', 'mw'],
    "ārṣyaśṛṅga": ['mw'],
    "ārṣī": ['mw'],
    "ārṣṭiṣeṇa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ārṭavaka": ['bhs'],
    "ās": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āsa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "āsabha": ['cped'],
    "āsac": ['mw'],
    "āsad": ['ap90', 'mw'],
    "āsada": ['cped', 'mw'],
    "āsadana": ['mw'],
    "āsadanaṃ": ['ap90'],
    "āsade": ['ddsa'],
    "āsado": ['cped'],
    "āsadā": ['cped'],
    "āsaja": ['mw'],
    "āsajja": ['cped'],
    "āsajjana": ['cped'],
    "āsajjanaṁ": ['cped'],
    "āsajya": ['mw'],
    "āsakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "āsaktabhāva": ['mw'],
    "āsaktacetas": ['mw'],
    "āsaktacitta": ['mw'],
    "āsaktamanas": ['mw'],
    "āsakti": ['cae', 'ddsa', 'gra', 'mw'],
    "āsaktiḥ": ['ap90'],
    "āsamañja": ['mw'],
    "āsamudra": ['ddsa'],
    "āsamudrāntam": ['mw'],
    "āsamudācārika": ['bhs'],
    "āsamāpti": ['ddsa', 'mw'],
    "āsan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āsana": ['cae', 'cped', 'ddsa', 'mw'],
    "āsanabandha": ['mw'],
    "āsanaka": ['bhs'],
    "āsanamantra": ['mw'],
    "āsanantarikā": ['cped'],
    "āsanapariyanta": ['cped'],
    "āsanapaṭṭi": ['mw'],
    "āsanastha": ['cae', 'mw'],
    "āsanatā": ['bhs'],
    "āsanavidhi": ['mw'],
    "āsanaṃ": ['ap90'],
    "āsanda": ['mw'],
    "āsandi": ['cped'],
    "āsandika": ['cped'],
    "āsandikā": ['ddsa', 'mw'],
    "āsandipañcama": ['cped'],
    "āsandī": ['mw'],
    "āsandīsad": ['mw'],
    "āsandīvat": ['mw'],
    "āsaniṣu": ['mw'],
    "āsanna": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "āsannacara": ['cae', 'mw'],
    "āsannaka": ['bhs'],
    "āsannakāla": ['mw'],
    "āsannakālika": ['mw'],
    "āsannakṣaya": ['mw'],
    "āsannanivāsin": ['mw'],
    "āsannaprasavā": ['cae', 'mw'],
    "āsannatara": ['mw'],
    "āsannataratā": ['mw'],
    "āsannavartin": ['cae', 'mw'],
    "āsannayodhin": ['mw'],
    "āsanniṣu": ['gra'],
    "āsannībhavati": ['bhs'],
    "āsanodaka": ['cae'],
    "āsanvat": ['ap90', 'mw'],
    "āsanya": ['ap90', 'mw'],
    "āsanā": ['mw'],
    "āsanī": ['mw'],
    "āsanīkṛ": ['ddsa', 'mw'],
    "āsaphakhāna": ['mw'],
    "āsapiṇḍakriyākarma": ['cae', 'ddsa', 'mw'],
    "āsaptama": ['ddsa', 'mw'],
    "āsapuṭa": ['mw'],
    "āsarita": ['bhs'],
    "āsarvā": ['mw'],
    "āsasāna": ['cped'],
    "āsat": ['gra'],
    "āsatta": ['cped'],
    "āsatti": ['cae', 'cped', 'ddsa', 'mw'],
    "āsattiḥ": ['ap90'],
    "āsattvasthāyin": ['bhs'],
    "āsava": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "āsavadru": ['mw'],
    "āsavakaraka": ['cae'],
    "āsavakhīna": ['cped'],
    "āsavakkhaya": ['cped'],
    "āsavaḥ": ['ap90'],
    "āsavaṭṭhaniya": ['cped'],
    "āsavitṛ": ['mw'],
    "āsaya": ['bhs', 'cped'],
    "āsayā": ['cae', 'gra', 'mw'],
    "āsañj": ['mw'],
    "āsañjana": ['cae', 'ddsa', 'mw'],
    "āsañjanavat": ['mw'],
    "āsañjita": ['mw'],
    "āsaḍa": ['mw'],
    "āsaḥ": ['ap90'],
    "āsaṁsa": ['cped'],
    "āsaṁsuka": ['cped'],
    "āsaṃbādha": ['ap90', 'mw'],
    "āsaṃdaḥ": ['ap90'],
    "āsaṃdikā": ['ap90'],
    "āsaṃga": ['ap90'],
    "āsaṃgatya": ['mw'],
    "āsaṃgatyaṃ": ['ap90'],
    "āsaṃgimaḥ": ['ap90'],
    "āsaṃginī": ['ap90'],
    "āsaṃgrah": ['mw'],
    "āsaṃj": ['ap90'],
    "āsaṃjanaṃ": ['ap90'],
    "āsaṃjñika": ['bhs', 'mw'],
    "āsaṃjñita": ['mw'],
    "āsaṃsāra": ['ap90'],
    "āsaṃsāram": ['ddsa', 'mw'],
    "āsaṅga": ['cae', 'ddsa', 'gra', 'mw'],
    "āsaṅgakāṣṭha": ['mw'],
    "āsaṅgam": ['mw'],
    "āsaṅgima": ['mw'],
    "āsaṅgin": ['cae', 'mw'],
    "āsaṅginī": ['mw'],
    "āsaṅkamāna": ['cped'],
    "āsaṅkati": ['cped'],
    "āsaṭa": ['mw'],
    "āsecana": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āsecanaka": ['bhs', 'mw'],
    "āsecanavat": ['mw'],
    "āsecanī": ['mw'],
    "āseddhṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "āsedha": ['cae', 'ddsa', 'mw'],
    "āsedhaka": ['ap90'],
    "āsedhaḥ": ['ap90'],
    "āseka": ['cae', 'ddsa', 'mw'],
    "āsekaḥ": ['ap90'],
    "āsekya": ['mw'],
    "āsekyaḥ": ['ap90'],
    "āsev": ['ap90', 'mw'],
    "āseva": ['cped'],
    "āsevaka": ['bhs'],
    "āsevamāna": ['cped'],
    "āsevana": ['cae', 'ddsa', 'mw'],
    "āsevanta": ['cped'],
    "āsevanā": ['bhs', 'cped'],
    "āsevat": ['cped'],
    "āsevati": ['cped'],
    "āsevin": ['ap90', 'mw'],
    "āsevita": ['ap90', 'cped', 'mw'],
    "āsevitabba": ['cped'],
    "āseviṁ": ['cped'],
    "āsevya": ['mw'],
    "āsevā": ['ap90', 'mw'],
    "āsi": ['cped', 'mw'],
    "āsia": ['gra'],
    "āsibandhika": ['mw'],
    "āsic": ['ap90', 'cae', 'gra', 'mw'],
    "āsiddha": ['cae', 'mw'],
    "āsidh": ['ap90', 'mw'],
    "āsidhāra": ['ddsa', 'mw'],
    "āsidhāraṃ": ['ap90'],
    "āsika": ['mw'],
    "āsikaḥ": ['ap90'],
    "āsikta": ['mw'],
    "āsikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "āsināsi": ['mw'],
    "āsisādayiṣu": ['ddsa', 'mw'],
    "āsita": ['ap90', 'cae', 'ddsa', 'mw'],
    "āsitavya": ['mw'],
    "āsitta": ['cped'],
    "āsittaka": ['cped'],
    "āsittakupadhāna": ['cped'],
    "āsiv": ['mw'],
    "āsivisa": ['cped'],
    "āsiñcati": ['cped'],
    "āsiñci": ['cped'],
    "āsiñcitabba": ['cped'],
    "āsiñcitvā": ['cped'],
    "āsiṁ": ['cped'],
    "āsiṁsa": ['cped'],
    "āsiṁsamāna": ['cped'],
    "āsiṁsat": ['cped'],
    "āsiṁsati": ['cped'],
    "āsiṁsāpeti": ['cped'],
    "āskabh": ['mw'],
    "āskand": ['mw'],
    "āskanda": ['cae', 'ddsa', 'mw'],
    "āskandam": ['mw'],
    "āskandana": ['mw'],
    "āskandin": ['mw'],
    "āskandita": ['mw'],
    "āskanditaka": ['mw'],
    "āskaṃd": ['ap90'],
    "āskaṃdaḥ": ['ap90'],
    "āskaṃdin": ['ap90'],
    "āskaṃditaṃ": ['ap90'],
    "āskra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āsku": ['mw'],
    "āsmāka": ['ap90', 'mw'],
    "āsmākīna": ['bhs', 'mw'],
    "āsneya": ['ap90', 'mw'],
    "āsnāna": ['mw'],
    "āsnānaṃ": ['ap90'],
    "āspada": ['cae', 'ddsa', 'mw'],
    "āspadatva": ['mw'],
    "āspadatā": ['mw'],
    "āspadaṃ": ['ap90'],
    "āspand": ['mw'],
    "āspandana": ['mw'],
    "āspardhin": ['ap90'],
    "āspardhā": ['ap90'],
    "āsparśa": ['bhs'],
    "āsphal": ['ap90', 'mw'],
    "āspharaṇakasamādhi": ['bhs'],
    "āsphota": ['mw'],
    "āsphotaka": ['mw'],
    "āsphotaḥ": ['ap90'],
    "āsphotā": ['mw'],
    "āsphoṭa": ['cae', 'ddsa', 'mw'],
    "āsphoṭaka": ['ap90', 'mw'],
    "āsphoṭana": ['mw'],
    "āsphoṭanaṃ": ['ap90'],
    "āsphoṭanī": ['mw'],
    "āsphoṭaḥ": ['ap90'],
    "āsphujit": ['ap90', 'mw'],
    "āsphul": ['mw'],
    "āsphura": ['mw'],
    "āsphuṭ": ['mw'],
    "āsphuṭa": ['bhs'],
    "āsphāla": ['mw'],
    "āsphālana": ['cae', 'ddsa', 'mw'],
    "āsphālanaṃ": ['ap90'],
    "āsphālaḥ": ['ap90'],
    "āsphālita": ['mw'],
    "āsphānaka": ['bhs', 'mw'],
    "āsphāra": ['bhs', 'mw'],
    "āsphāy": ['mw'],
    "āsphāṭayati": ['bhs'],
    "āspātra": ['cae', 'mw'],
    "āspṛ": ['mw'],
    "āspṛś": ['mw'],
    "āspṛṣṭa": ['mw'],
    "āsra": ['mw'],
    "āsrapa": ['mw'],
    "āsrasta": ['cae', 'mw'],
    "āsrava": ['bhs', 'mw'],
    "āsravaḥ": ['ap90'],
    "āsraṃ": ['ap90'],
    "āsraṃs": ['mw'],
    "āsru": ['mw'],
    "āsrupayas": ['mw'],
    "āsrāva": ['ap90', 'cae', 'ddsa', 'mw'],
    "āsrāvabheṣaja": ['mw'],
    "āsrāvin": ['ap90', 'mw'],
    "āstara": ['cae', 'ddsa', 'mw'],
    "āstaraḥ": ['ap90'],
    "āstaraṇa": ['ap90', 'ddsa', 'mw'],
    "āstaraṇavat": ['mw'],
    "āstaraṇika": ['ap90', 'mw'],
    "āste": ['ddsa'],
    "āsteya": ['mw'],
    "āstheya": ['mw'],
    "āsthita": ['ap90', 'cae', 'ddsa', 'mw'],
    "āsthiti": ['bhs'],
    "āsthitiḥ": ['ap90'],
    "āsthā": ['ap90', 'cae', 'ddsa', 'mw'],
    "āsthāna": ['cae', 'ddsa', 'gra', 'mw'],
    "āsthānagṛha": ['mw'],
    "āsthānamaṇḍapa": ['mw'],
    "āsthānaṃ": ['ap90'],
    "āsthānī": ['ddsa', 'mw'],
    "āsthānīya": ['mw'],
    "āsthāpana": ['mw'],
    "āsthāpanaṃ": ['ap90'],
    "āsthāpita": ['mw'],
    "āsthātṛ": ['ap90', 'cae', 'gra', 'mw'],
    "āsthāya": ['mw'],
    "āsthāyikā": ['ap90', 'mw'],
    "āstika": ['ap90', 'cae', 'ddsa', 'mw'],
    "āstikatā": ['ap90'],
    "āstikya": ['ddsa', 'mw'],
    "āstikārthada": ['mw'],
    "āstopaka": ['bhs'],
    "āstra": ['ap90'],
    "āstrabudhna": ['gra', 'mw'],
    "āstubh": ['mw'],
    "āstāra": ['cae', 'mw'],
    "āstāraka": ['mw'],
    "āstārapaṅkti": ['mw'],
    "āstāraḥ": ['ap90'],
    "āstāva": ['cae', 'mw'],
    "āstāvaḥ": ['ap90'],
    "āstāyana": ['mw'],
    "āstīka": ['ap90', 'cae', 'ddsa', 'mw'],
    "āstīrya": ['mw'],
    "āstīryati": ['bhs'],
    "āstīrṇa": ['cae', 'mw'],
    "āstṛ": ['ap90', 'mw'],
    "āstṛta": ['cae', 'mw'],
    "āsu": ['ap90', 'mw'],
    "āsuka": ['mw'],
    "āsumbhati": ['cped'],
    "āsumbhitvā": ['cped'],
    "āsumbhiṁsu": ['cped'],
    "āsumhati": ['cped'],
    "āsupta": ['bhs'],
    "āsura": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āsuraniścaya": ['cae'],
    "āsurasva": ['cae', 'mw'],
    "āsuri": ['mw'],
    "āsurivāsin": ['mw'],
    "āsuriḥ": ['ap90'],
    "āsurya": ['bhs'],
    "āsurāyaṇa": ['mw'],
    "āsurāyaṇīya": ['mw'],
    "āsurī": ['mw'],
    "āsurīkalpa": ['mw'],
    "āsurīya": ['ap90', 'mw'],
    "āsut": ['mw'],
    "āsuta": ['mw'],
    "āsuti": ['cae', 'gra', 'mw'],
    "āsutimat": ['mw'],
    "āsutiḥ": ['ap90'],
    "āsutīvala": ['mw'],
    "āsutīvalaḥ": ['ap90'],
    "āsuṁ": ['cped'],
    "āsva": ['ddsa'],
    "āsvad": ['ap90', 'mw'],
    "āsvan": ['mw'],
    "āsvanita": ['ap90', 'mw'],
    "āsvapati": ['bhs'],
    "āsvid": ['mw'],
    "āsvāda": ['ap90', 'cae', 'ddsa', 'mw'],
    "āsvādaka": ['ap90', 'mw'],
    "āsvādana": ['mw'],
    "āsvādanaṃ": ['ap90'],
    "āsvādanīya": ['bhs', 'mw'],
    "āsvādavant": ['cae'],
    "āsvādavat": ['mw'],
    "āsvādita": ['mw'],
    "āsvādya": ['ap90', 'cae', 'mw'],
    "āsvādyatoya": ['mw'],
    "āsvānta": ['mw'],
    "āsvāpana": ['bhs', 'mw'],
    "āsya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āsyadaghna": ['mw'],
    "āsyagarta": ['cae', 'mw'],
    "āsyahātya": ['mw'],
    "āsyajāha": ['mw'],
    "āsyaloman": ['mw'],
    "āsyalāṅgala": ['mw'],
    "āsyamaithunika": ['mw'],
    "āsyamodaka": ['mw'],
    "āsyand": ['mw'],
    "āsyandana": ['mw'],
    "āsyapattra": ['mw'],
    "āsyaprayatna": ['mw'],
    "āsyasammita": ['mw'],
    "āsyasravaṇa": ['mw'],
    "āsyavairasya": ['mw'],
    "āsyaṃdanaṃ": ['ap90'],
    "āsyaṃdhaya": ['ap90', 'mw'],
    "āsyopalepa": ['mw'],
    "āsyā": ['ap90', 'cae', 'mw'],
    "āsyāsava": ['mw'],
    "āsyāsukha": ['mw'],
    "āsyūta": ['cae', 'mw'],
    "āsā": ['ap90', 'cped'],
    "āsāda": ['mw'],
    "āsādana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "āsādanapekkha": ['cped'],
    "āsādanaṃ": ['ap90'],
    "āsādanā": ['mw'],
    "āsādayati": ['bhs', 'cped'],
    "āsādayitavya": ['ap90', 'mw'],
    "āsādaḥ": ['ap90'],
    "āsādesi": ['cped'],
    "āsādetabba": ['cped'],
    "āsādeti": ['cped'],
    "āsādhanaṃ": ['ap90'],
    "āsādi": ['cped'],
    "āsādimhase": ['cped'],
    "āsādita": ['ap90', 'mw'],
    "āsādiya": ['cped'],
    "āsādya": ['cae', 'mw'],
    "āsāra": ['cae', 'ddsa', 'mw'],
    "āsāraśarkarā": ['mw'],
    "āsāraḥ": ['ap90'],
    "āsāraṇa": ['mw'],
    "āsāt": ['ddsa', 'mw'],
    "āsāva": ['gra', 'mw'],
    "āsāvacchedika": ['cped'],
    "āsāvaḥ": ['ap90'],
    "āsāvin": ['mw'],
    "āsāvya": ['mw'],
    "āsāyam": ['ddsa', 'mw'],
    "āsāḷhi": ['cped'],
    "āsāṭikā": ['cped'],
    "āsīdati": ['cped'],
    "āsīditvā": ['cped'],
    "āsīmāntam": ['ddsa', 'mw'],
    "āsīna": ['ap90', 'cped', 'ddsa', 'mw'],
    "āsīnapracalāyita": ['mw'],
    "āsītakī": ['bhs', 'mw'],
    "āsītika": ['cped'],
    "āsītikapabba": ['cped'],
    "āsīvaka": ['bhs'],
    "āsīvana": ['mw'],
    "āsīyati": ['bhs'],
    "āsū": ['mw'],
    "āsūtraya": ['mw'],
    "āsūtrita": ['ap90', 'mw'],
    "āsṛ": ['mw'],
    "āsṛj": ['mw'],
    "āsṛkva": ['ddsa'],
    "āsṛṣṭi": ['ddsa', 'mw'],
    "āt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āta": ['ap90', 'mw'],
    "ātaka": ['mw'],
    "ātakṣ": ['mw'],
    "ātakṣati": ['bhs'],
    "ātam": ['mw'],
    "ātamām": ['ap90', 'mw'],
    "ātan": ['ap90', 'mw'],
    "ātanaṃ": ['ap90'],
    "ātani": ['ap90', 'gra', 'mw'],
    "ātap": ['ap90', 'gra', 'mw'],
    "ātapa": ['ap90', 'bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ātapana": ['mw'],
    "ātapanaḥ": ['ap90'],
    "ātapanivāraṇa": ['mw'],
    "ātapas": ['mw'],
    "ātapat": ['mw'],
    "ātapatra": ['cae', 'mw'],
    "ātapatrāyita": ['mw'],
    "ātapavarṣya": ['mw'],
    "ātapavat": ['ap90', 'mw'],
    "ātapavāraṇa": ['cae', 'mw'],
    "ātapaśuṣka": ['mw'],
    "ātapovanam": ['ddsa'],
    "ātappa": ['cped'],
    "ātapta": ['mw'],
    "ātaptakārin": ['bhs'],
    "ātaptarāṣṭra": ['bhs'],
    "ātapya": ['ap90', 'mw'],
    "ātapāpāya": ['mw'],
    "ātapātyaya": ['mw'],
    "ātapāya": ['ddsa', 'mw'],
    "ātapīya": ['ap90', 'mw'],
    "ātara": ['ddsa', 'mw'],
    "ātaraḥ": ['ap90'],
    "ātarda": ['mw'],
    "ātardana": ['mw'],
    "ātardanaṃ": ['ap90'],
    "ātarj": ['mw'],
    "ātarpaṇa": ['mw'],
    "ātarpaṇaṃ": ['ap90'],
    "ātasya": ['bhs'],
    "ātata": ['ap90', 'cae', 'mw'],
    "ātati": ['mw'],
    "ātatāvin": ['ap90', 'cae', 'mw'],
    "ātatāyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "ātatīkaraṇa": ['mw'],
    "ātava": ['mw'],
    "ātavāyana": ['mw'],
    "ātañc": ['mw'],
    "ātañcana": ['cae', 'mw'],
    "ātaśca": ['mw'],
    "ātaṃc": ['ap90'],
    "ātaṃcanaṃ": ['ap90'],
    "ātaṃkaḥ": ['ap90'],
    "ātaṃs": ['mw'],
    "ātaṅka": ['cae', 'ddsa', 'mw'],
    "ātaṅkaphassa": ['cped'],
    "ātaṅkya": ['mw'],
    "āthabbana": ['cped'],
    "āthabbaṇa": ['cped'],
    "ātharvaṇa": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ātharvaṇarahasya": ['mw'],
    "ātharvaṇaśiras": ['mw'],
    "ātharvaṇi": ['mw'],
    "ātharvaṇika": ['mw'],
    "ātharvaṇikaḥ": ['ap90'],
    "ātharvaṇīyarudropaniṣad": ['mw'],
    "ātharvika": ['mw'],
    "āti": ['cae', 'gra', 'mw'],
    "āticchandasa": ['mw'],
    "ātideśika": ['ap90', 'mw'],
    "ātijagata": ['mw'],
    "ātiraikya": ['cae', 'ddsa', 'mw'],
    "ātiraikyaṃ": ['ap90'],
    "ātiraścīna": ['ddsa', 'mw'],
    "ātireka": ['bhs'],
    "ātirekyaṃ": ['ap90'],
    "ātisvāyana": ['mw'],
    "ātisārika": ['mw'],
    "ātitheya": ['ap90', 'cae', 'ddsa', 'mw'],
    "ātitheyya": ['cped'],
    "ātitheyī": ['mw'],
    "ātithigua": ['gra'],
    "ātithigva": ['gra', 'mw'],
    "ātithya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ātithyarūpa": ['mw'],
    "ātithyasatkriyā": ['mw'],
    "ātithyasatkāra": ['mw'],
    "ātithyavat": ['mw'],
    "ātithyeṣṭi": ['mw'],
    "ātithyā": ['mw'],
    "ātitāṃsu": ['ddsa', 'mw'],
    "ātivijñānya": ['mw'],
    "ātivāhika": ['ap90', 'mw'],
    "ātiyāntrika": ['bhs'],
    "ātiśayika": ['ddsa', 'mw'],
    "ātiśayya": ['mw'],
    "ātiśayyaṃ": ['ap90'],
    "ātiśāyanika": ['mw'],
    "ātiśāyika": ['mw'],
    "ātiḥ": ['ap90'],
    "ātiṣṭha": ['mw'],
    "ātiṣṭhadgu": ['mw'],
    "ātiṣṭhaṃ": ['ap90'],
    "ātm, ātī": ['ddsa'],
    "ātma": ['cae', 'ddsa', 'mw'],
    "ātmabandhu": ['mw'],
    "ātmabhava": ['cae', 'mw'],
    "ātmabhavāyana": ['mw'],
    "ātmabhāva": ['bhs', 'cae', 'mw'],
    "ātmabhāvatā": ['bhs'],
    "ātmabhū": ['cae', 'mw'],
    "ātmabhūta": ['cae', 'mw'],
    "ātmabhūya": ['mw'],
    "ātmabodha": ['cae', 'mw'],
    "ātmabuddhi": ['mw'],
    "ātmacaturtha": ['mw'],
    "ātmacchandatīrtha": ['mw'],
    "ātmacchandānucārin": ['cae'],
    "ātmacintā": ['cae', 'mw'],
    "ātmadakṣiṇa": ['mw'],
    "ātmadarśa": ['mw'],
    "ātmadarśana": ['mw'],
    "ātmadevatā": ['mw'],
    "ātmadhāraṇī": ['bhs', 'mw'],
    "ātmadrohin": ['mw'],
    "ātmadā": ['gra', 'mw'],
    "ātmadāna": ['cae', 'mw'],
    "ātmadīya": ['bhs'],
    "ātmadūṣi": ['mw'],
    "ātmagata": ['cae', 'mw'],
    "ātmagatam": ['mw'],
    "ātmagati": ['cae', 'mw'],
    "ātmagatyā": ['mw'],
    "ātmaghoṣa": ['mw'],
    "ātmaghāta": ['mw'],
    "ātmaghātaka": ['mw'],
    "ātmaghātin": ['mw'],
    "ātmagrāha": ['bhs'],
    "ātmagrāhin": ['mw'],
    "ātmagupti": ['mw'],
    "ātmaguptā": ['mw'],
    "ātmaguṇa": ['mw'],
    "ātmahan": ['cae', 'mw'],
    "ātmahanana": ['mw'],
    "ātmahatyā": ['mw'],
    "ātmahita": ['cae', 'mw'],
    "ātmahitāyana": ['mw'],
    "ātmaja": ['cae', 'mw'],
    "ātmajanman": ['mw'],
    "ātmajit": ['mw'],
    "ātmajyotirupaniṣad": ['mw'],
    "ātmajyotis": ['mw'],
    "ātmajña": ['cae', 'mw'],
    "ātmajñāna": ['cae', 'mw'],
    "ātmajñānopaniṣad": ['mw'],
    "ātmajā": ['mw'],
    "ātmaka": ['ap90', 'bhs', 'cae', 'mw'],
    "ātmakarman": ['mw'],
    "ātmakrīḍa": ['mw'],
    "ātmakāma": ['mw'],
    "ātmakāmeya": ['mw'],
    "ātmakāmeyaka": ['mw'],
    "ātmakārya": ['mw'],
    "ātmakīya": ['ap90', 'mw'],
    "ātmakṛta": ['cae', 'mw'],
    "ātmalābha": ['cae', 'mw'],
    "ātmamaya": ['mw'],
    "ātmambhari": ['ddsa', 'mw'],
    "ātmambharitva": ['mw'],
    "ātmamāna": ['mw'],
    "ātmamūlī": ['mw'],
    "ātmamūrti": ['mw'],
    "ātman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ātmana": ['bhs'],
    "ātmane": ['mw'],
    "ātmanebhāṣa": ['mw'],
    "ātmanebhāṣā": ['mw'],
    "ātmanepada": ['cae', 'ddsa', 'mw'],
    "ātmanepadaṃ": ['ap90'],
    "ātmanepadin": ['mw'],
    "ātmanikā": ['ddsa', 'mw'],
    "ātmanindā": ['ddsa', 'mw'],
    "ātmanirāloka": ['mw'],
    "ātmanirūpaṇa": ['mw'],
    "ātmanitya": ['mw'],
    "ātmanivedana": ['mw'],
    "ātmaniṣkrayaṇa": ['mw'],
    "ātmanvant": ['cae'],
    "ātmanvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "ātmanvin": ['cae', 'mw'],
    "ātmanya": ['mw'],
    "ātmanā": ['ap90', 'mw'],
    "ātmanādaśama": ['mw'],
    "ātmanādvitīya": ['mw'],
    "ātmanāpañcama": ['mw'],
    "ātmanāsaptama": ['mw'],
    "ātmanātṛtīya": ['cae', 'ddsa', 'mw'],
    "ātmanīna": ['ap90', 'mw'],
    "ātmanīya": ['bhs', 'mw'],
    "ātmapa": ['mw'],
    "ātmapakṣa": ['ddsa', 'mw'],
    "ātmaparityāga": ['mw'],
    "ātmaparājita": ['mw'],
    "ātmapañcaka": ['mw'],
    "ātmapañcama": ['mw'],
    "ātmaprabha": ['cae', 'mw'],
    "ātmaprabodha": ['mw'],
    "ātmapradāna": ['cae'],
    "ātmaprakāśa": ['mw'],
    "ātmapratikṛti": ['mw'],
    "ātmapravāda": ['mw'],
    "ātmaprayojana": ['mw'],
    "ātmapraśaṃsaka": ['mw'],
    "ātmapraśaṃsin": ['mw'],
    "ātmapraśaṃsā": ['cae', 'mw'],
    "ātmaprīti": ['mw'],
    "ātmapuruṣa": ['bhs'],
    "ātmapāta": ['mw'],
    "ātmapūjā": ['mw'],
    "ātmapūrvāpara": ['bhs'],
    "ātmarakṣaka": ['mw'],
    "ātmarakṣaṇa": ['mw'],
    "ātmarakṣā": ['mw'],
    "ātmarati": ['cae', 'mw'],
    "ātmaruha": ['mw'],
    "ātmasad": ['mw'],
    "ātmasama": ['cae', 'mw'],
    "ātmasamarpaṇa": ['mw'],
    "ātmasambhava": ['mw'],
    "ātmasambhavā": ['mw'],
    "ātmasambhāvanā": ['mw'],
    "ātmasambhāvita": ['mw'],
    "ātmasammita": ['mw'],
    "ātmasani": ['mw'],
    "ātmasantāna": ['ddsa'],
    "ātmasaṃbhava": ['cae'],
    "ātmasaṃbhāvita": ['cae'],
    "ātmasaṃdeha": ['cae', 'mw'],
    "ātmasaṃsiddhi": ['cae'],
    "ātmasaṃstha": ['cae', 'mw'],
    "ātmasaṃtāna": ['mw'],
    "ātmasaṃyama": ['mw'],
    "ātmasaṃyoga": ['mw'],
    "ātmasaṃyukta": ['mw'],
    "ātmasparaṇa": ['mw'],
    "ātmastava": ['cae', 'mw'],
    "ātmastuti": ['mw'],
    "ātmasukha": ['mw'],
    "ātmasācin": ['mw'],
    "ātmasāt": ['ap90', 'mw'],
    "ātmasātkṛ": ['cae'],
    "ātmatantra": ['mw'],
    "ātmatattva": ['mw'],
    "ātmatattvajña": ['mw'],
    "ātmatattvaviveka": ['mw'],
    "ātmatrāṇa": ['mw'],
    "ātmatrāṇaparigraha": ['mw'],
    "ātmatulya": ['cae'],
    "ātmatva": ['mw'],
    "ātmatyāga": ['cae', 'mw'],
    "ātmatyāgin": ['cae', 'mw'],
    "ātmatā": ['ap90', 'cae', 'mw'],
    "ātmatṛpta": ['cae', 'mw'],
    "ātmaupamya": ['cae', 'ddsa', 'mw'],
    "ātmavadha": ['cae', 'mw'],
    "ātmavadhyā": ['mw'],
    "ātmavant": ['cae'],
    "ātmavat": ['ap90', 'cae', 'mw'],
    "ātmavattā": ['ap90', 'cae', 'mw'],
    "ātmavañcaka": ['mw'],
    "ātmavañcanā": ['mw'],
    "ātmavaśa": ['cae', 'mw'],
    "ātmavaśya": ['cae'],
    "ātmavid": ['cae', 'mw'],
    "ātmavidhitsā": ['mw'],
    "ātmavidyā": ['cae', 'mw'],
    "ātmavikraya": ['cae', 'mw'],
    "ātmavinigraha": ['cae'],
    "ātmavittā": ['mw'],
    "ātmavivṛddhi": ['mw'],
    "ātmavīra": ['mw'],
    "ātmavṛddhi": ['mw'],
    "ātmavṛtti": ['mw'],
    "ātmavṛttānta": ['mw'],
    "ātmavṛṣabhitā": ['bhs'],
    "ātmayoga": ['cae', 'mw'],
    "ātmayoni": ['mw'],
    "ātmayājin": ['cae', 'ddsa', 'mw'],
    "ātmaśakti": ['mw'],
    "ātmaśalyā": ['mw'],
    "ātmaśaṃsā": ['ddsa'],
    "ātmaślāgha": ['mw'],
    "ātmaślāghin": ['mw'],
    "ātmaślāghā": ['mw'],
    "ātmaśreyas": ['cae'],
    "ātmaśuddhi": ['mw'],
    "ātmaṃbhari": ['ap90'],
    "ātmecchā": ['ddsa', 'mw'],
    "ātmeya": ['mw'],
    "ātmeśvara": ['mw'],
    "ātmodaya": ['mw'],
    "ātmodbhava": ['mw'],
    "ātmodbhavā": ['mw'],
    "ātmollāsa": ['mw'],
    "ātmopajīvin": ['cae', 'mw'],
    "ātmopama": ['mw'],
    "ātmopaniṣad": ['mw'],
    "ātmopanāyika": ['bhs'],
    "ātmotkarṣa": ['ddsa'],
    "ātmya": ['ap90', 'bhs', 'mw'],
    "ātmābhilāṣa": ['mw'],
    "ātmābhimarśana": ['mw'],
    "ātmābhimānitā": ['mw'],
    "ātmādhika": ['mw'],
    "ātmādhīna": ['mw'],
    "ātmādiṣṭa": ['ddsa', 'mw'],
    "ātmāmiṣa": ['mw'],
    "ātmānanda": ['mw'],
    "ātmānapekṣa": ['cae', 'mw'],
    "ātmāpahāra": ['cae', 'mw'],
    "ātmāpahāraka": ['cae', 'mw'],
    "ātmāpahārin": ['cae', 'mw'],
    "ātmāparādha": ['mw'],
    "ātmārtham": ['cae', 'mw'],
    "ātmārthe": ['cae', 'mw'],
    "ātmārāma": ['mw'],
    "ātmātmīya": ['bhs'],
    "ātmāvāsya": ['mw'],
    "ātmāyāsa": ['mw'],
    "ātmāśin": ['mw'],
    "ātmāśraya": ['mw'],
    "ātmāśrayopaniṣad": ['mw'],
    "ātmībhāva": ['mw'],
    "ātmībhāvaḥ": ['ap90'],
    "ātmīkṛ": ['ap90', 'ddsa', 'mw'],
    "ātmīya": ['bhs', 'cae', 'mw'],
    "ātodin": ['ap90', 'mw'],
    "ātodya": ['ddsa', 'mw'],
    "ātodyaṃ": ['ap90'],
    "ātra": ['mw'],
    "ātreya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ātreyikā": ['ap90', 'mw'],
    "ātreyāyaṇa": ['mw'],
    "ātreyī": ['mw'],
    "ātreyīputra": ['mw'],
    "ātreyīya": ['mw'],
    "ātta": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "āttadaṇḍa": ['cae'],
    "āttadhanvan": ['cae'],
    "āttagandha": ['cae', 'mw'],
    "āttagarva": ['mw'],
    "āttakānti": ['mw'],
    "āttalakṣmi": ['mw'],
    "āttamana": ['bhs'],
    "āttamanas": ['mw'],
    "āttamanaska": ['bhs', 'mw'],
    "āttamīya": ['bhs'],
    "āttanuyogi": ['cped'],
    "āttanuyogin": ['cped'],
    "āttasomapīthīya": ['mw'],
    "āttasva": ['mw'],
    "āttasvatva": ['mw'],
    "āttavacas": ['mw'],
    "āttavibhava": ['mw'],
    "āttavidya": ['mw'],
    "āttañjaha": ['cped'],
    "āttañjahadaṇḍa": ['cped'],
    "āttaśastra": ['cae'],
    "āttha": ['ddsa', 'mw'],
    "āttām": ['mw'],
    "ātu": ['cped', 'mw'],
    "ātuc": ['ap90', 'gra', 'mw'],
    "ātud": ['ap90', 'mw'],
    "ātuj": ['ap90'],
    "ātuje": ['cae', 'mw'],
    "ātuji": ['ap90', 'gra', 'mw'],
    "ātul": ['mw'],
    "ātuma": ['cped'],
    "ātuman": ['cped'],
    "ātunna": ['mw'],
    "ātura": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "āturyaṃ": ['ap90'],
    "āturīyati": ['cped'],
    "ātuḥ": ['ap90'],
    "ātva": ['ddsa'],
    "ātyantika": ['cae', 'ddsa', 'mw'],
    "ātyayika": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ātyaṃtika": ['ap90'],
    "ātyūhaḥ": ['ap90'],
    "ātā": ['cae', 'ddsa', 'gra', 'mw'],
    "ātāla": ['bhs'],
    "ātālī": ['ap90', 'mw'],
    "ātāmra": ['cae', 'ddsa', 'mw'],
    "ātāna": ['bhs', 'mw'],
    "ātānaḥ": ['ap90'],
    "ātāpana": ['bhs'],
    "ātāpanaparitāpanānuyoga": ['cped'],
    "ātāpayati": ['bhs'],
    "ātāpeti": ['cped'],
    "ātāpetvā": ['cped'],
    "ātāpi": ['cped'],
    "ātāpin": ['ap90', 'bhs', 'cped', 'ddsa', 'mw'],
    "ātāpita": ['cped'],
    "ātāpiya": ['cped'],
    "ātāpiḥ": ['ap90'],
    "ātāra": ['mw'],
    "ātārya": ['ap90', 'mw'],
    "ātāyin": ['ap90', 'mw'],
    "ātī": ['cae', 'mw'],
    "ātīkṣṇendriya": ['bhs'],
    "ātīrī": ['bhs'],
    "ātīṣādīya": ['mw'],
    "ātṛd": ['ap90', 'mw'],
    "ātṛdas": ['mw'],
    "ātṛp": ['ap90', 'mw'],
    "ātṛpti": ['mw'],
    "ātṛpya": ['mw'],
    "ātṛpyaḥ": ['ap90'],
    "ātṛṇṇa": ['ap90', 'mw'],
    "ātṝ": ['ap90', 'mw'],
    "āukṣ": ['mw'],
    "āva": ['cae', 'ddsa', 'mw'],
    "āvabhṛtha": ['mw'],
    "āvabhṛtya": ['mw'],
    "āvac": ['mw'],
    "āvad": ['mw'],
    "āvadh": ['mw'],
    "āvadānika": ['mw'],
    "āvah": ['ap90', 'mw'],
    "āvaha": ['ap90', 'cae', 'ddsa', 'mw'],
    "āvahamāna": ['ap90', 'mw'],
    "āvahana": ['cae', 'cped', 'mw'],
    "āvahanaṃ": ['ap90'],
    "āvahati": ['cped'],
    "āvahāpeyyum": ['cped'],
    "āvajjati": ['cped'],
    "āvajjayati": ['cped'],
    "āvajjesi": ['cped'],
    "āvajjeti": ['cped'],
    "āvaka": ['ap90'],
    "āvalg": ['mw'],
    "āvalgin": ['cae', 'mw'],
    "āvalgita": ['ap90', 'cae', 'mw'],
    "āvalguja": ['ap90', 'mw'],
    "āvali": ['cae', 'ddsa', 'mw'],
    "āvalikā": ['mw'],
    "āvalita": ['ap90'],
    "āvaliḥ": ['ap90'],
    "āvalī": ['cae', 'mw'],
    "āvalīkanda": ['mw'],
    "āvamati": ['cped'],
    "āvan": ['mw'],
    "āvanatīya": ['mw'],
    "āvandana": ['mw'],
    "āvaneya": ['mw'],
    "āvaneyaḥ": ['ap90'],
    "āvanta": ['mw'],
    "āvantaka": ['bhs', 'cae', 'mw'],
    "āvantika": ['cae', 'ddsa', 'mw'],
    "āvantikā": ['mw'],
    "āvantya": ['cae', 'ddsa', 'mw'],
    "āvantī": ['mw'],
    "āvap": ['ap90', 'mw'],
    "āvapana": ['cae', 'ddsa', 'mw'],
    "āvapanaṃ": ['ap90'],
    "āvapantaka": ['mw'],
    "āvapanī": ['mw'],
    "āvapaṃtika": ['ap90'],
    "āvar": ['ddsa'],
    "āvaraka": ['ap90', 'ddsa', 'mw'],
    "āvarasamaka": ['ap90', 'mw'],
    "āvarati": ['cped'],
    "āvaraṇa": ['ap90', 'bhs', 'cae', 'cped', 'mw'],
    "āvaraṇaśakti": ['mw'],
    "āvaraṇaṁ karoti": ['cped'],
    "āvaraṇin": ['mw'],
    "āvaraṇīya": ['bhs', 'cped', 'mw'],
    "āvarha": ['mw'],
    "āvarham": ['mw'],
    "āvarhati": ['bhs'],
    "āvarhaṇa": ['bhs'],
    "āvarhin": ['mw'],
    "āvarhita": ['ap90', 'mw'],
    "āvarikā": ['mw'],
    "āvaritṛ": ['ap90'],
    "āvarjaka": ['mw'],
    "āvarjana": ['bhs', 'cae', 'ddsa', 'mw'],
    "āvarjanaṃ": ['ap90'],
    "āvarjanā": ['bhs'],
    "āvarjanīkṛ": ['mw'],
    "āvarjanīkṛtvā": ['bhs'],
    "āvarjayati": ['bhs'],
    "āvarjita": ['cae', 'mw'],
    "āvarjya": ['mw'],
    "āvarta": ['bhs', 'cae', 'ddsa', 'mw'],
    "āvartaka": ['ap90', 'mw'],
    "āvartakī": ['mw'],
    "āvartam": ['mw'],
    "āvartamāna": ['mw'],
    "āvartana": ['ap90', 'bhs', 'cae', 'gra', 'mw'],
    "āvartanamaṇi": ['mw'],
    "āvartanī": ['mw'],
    "āvartanīya": ['mw'],
    "āvartaḥ": ['ap90'],
    "āvarti": ['bhs'],
    "āvartin": ['ap90', 'mw'],
    "āvartinī": ['mw'],
    "āvartita": ['mw'],
    "āvartā": ['mw'],
    "āvarītṛ": ['ap90', 'mw'],
    "āvarīvar": ['ddsa'],
    "āvarṣa": ['mw'],
    "āvas": ['ap90', 'ddsa', 'mw'],
    "āvasa": ['cped'],
    "āvasanta": ['cped'],
    "āvasat": ['cped'],
    "āvasatha": ['cae', 'cped', 'mw'],
    "āvasathacīvara": ['cped'],
    "āvasathagāra": ['cped'],
    "āvasathapiṇḍa": ['cped'],
    "āvasathaḥ": ['ap90'],
    "āvasathika": ['ap90', 'mw'],
    "āvasathya": ['ap90', 'mw'],
    "āvasathyādhāna": ['mw'],
    "āvasathīya": ['mw'],
    "āvasati": ['cae', 'cped', 'ddsa', 'mw'],
    "āvasatiḥ": ['ap90'],
    "āvasika": ['cped'],
    "āvasita": ['ap90', 'cped', 'mw'],
    "āvasiṁ": ['cped'],
    "āvasiṁsu": ['cped'],
    "āvasthika": ['ap90', 'mw'],
    "āvasu": ['gra'],
    "āvasāna": ['ap90', 'mw'],
    "āvasānika": ['bhs', 'mw'],
    "āvasāyin": ['mw'],
    "āvat": ['ap90', 'cae', 'ddsa', 'mw'],
    "āvatsaram": ['mw'],
    "āvatsarāntam": ['ddsa', 'mw'],
    "āvatta": ['cped'],
    "āvattamāna": ['cped'],
    "āvattati": ['cped'],
    "āvatteti": ['cped'],
    "āvattitvā": ['cped'],
    "āvaya": ['cae', 'ddsa', 'mw'],
    "āvayaka": ['mw'],
    "āvayas": ['mw'],
    "āvayaḥ": ['ap90'],
    "āvayāj": ['ap90', 'ddsa', 'gra'],
    "āvayās": ['mw'],
    "āvañc": ['mw'],
    "āvaśyaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "āvaśyakabṛhadvṛtti": ['mw'],
    "āvaśyakatā": ['ap90', 'mw'],
    "āvaśyaṃ": ['ap90'],
    "āvaśīra": ['mw'],
    "āvaḍi": ['bhs'],
    "āvaṃtaḥ": ['ap90'],
    "āvaṃtika": ['ap90'],
    "āvaṃtya": ['ap90'],
    "āvaṭa": ['cped'],
    "āvaṭika": ['mw'],
    "āvaṭya": ['mw'],
    "āvaṭṭa": ['cped'],
    "āvaṭṭaggāha": ['cped'],
    "āvaṭṭagāha": ['cped'],
    "āvaṭṭamāna": ['cped'],
    "āvaṭṭanī": ['cped'],
    "āvaṭṭati": ['cped'],
    "āvaṭṭeti": ['cped'],
    "āvaṭṭitvā": ['cped'],
    "āve": ['mw'],
    "āvedaka": ['ap90', 'ddsa', 'mw'],
    "āvedana": ['cae', 'mw'],
    "āvedanaṃ": ['ap90'],
    "āvedanika": ['bhs'],
    "āvedanīya": ['ap90', 'mw'],
    "āvedha": ['bhs', 'mw'],
    "āvedhya": ['mw'],
    "āvedin": ['ap90', 'mw'],
    "āvedita": ['ap90', 'mw'],
    "āvedya": ['mw'],
    "āvedyamāna": ['mw'],
    "āvega": ['cae', 'ddsa', 'mw'],
    "āvegaḥ": ['ap90'],
    "āvegī": ['mw'],
    "āvelā": ['cped'],
    "āveni": ['cped'],
    "āvenika": ['cped'],
    "āveniya": ['cped'],
    "āvesana": ['cped'],
    "āvesanavitthaka": ['cped'],
    "āvevidāna": ['mw'],
    "āveśa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "āveśaka": ['bhs'],
    "āveśana": ['cae', 'mw'],
    "āveśanaṃ": ['ap90'],
    "āveśaḥ": ['ap90'],
    "āveśika": ['ap90', 'mw'],
    "āveṇi": ['cped'],
    "āveṇibhāva": ['cped'],
    "āveṇika": ['bhs', 'cped', 'mw'],
    "āveṇiya": ['cped'],
    "āveṇiṁ": ['cped'],
    "āveṇīya": ['bhs'],
    "āveṣṭ": ['ap90', 'mw'],
    "āveṣṭa": ['cae', 'ddsa', 'mw'],
    "āveṣṭaka": ['mw'],
    "āveṣṭakaḥ": ['ap90'],
    "āveṣṭana": ['mw'],
    "āveṣṭanaṃ": ['ap90'],
    "āveṣṭita": ['mw'],
    "āveṣṭya": ['mw'],
    "āveṭhita": ['bhs'],
    "āvi": ['cae', 'cped', 'mw'],
    "āvi-akāsi": ['cped'],
    "āvibhā": ['mw'],
    "āvibhāva": ['cped'],
    "āvid": ['ap90', 'cae', 'ddsa', 'mw'],
    "āviddha": ['ap90', 'bhs', 'cae', 'mw'],
    "āviddhaka": ['bhs'],
    "āviddhakarṇa": ['mw'],
    "āviddhakarṇī": ['mw'],
    "āvidha": ['mw'],
    "āvidhaḥ": ['ap90'],
    "āvidhya": ['mw'],
    "āvidvas": ['ap90', 'ddsa', 'mw'],
    "āvidvaṃs": ['cae'],
    "āvidūrya": ['mw'],
    "āvidūryaṃ": ['ap90'],
    "āvigalita": ['bhs'],
    "āvigna": ['ap90', 'cae', 'mw'],
    "āvihan": ['mw'],
    "āvij": ['mw'],
    "āvijjhati": ['cped'],
    "āvijñānya": ['mw'],
    "āvika": ['ap90', 'cae', 'ddsa', 'mw'],
    "āvikaroti": ['cped'],
    "āvikasautrika": ['cae', 'mw'],
    "āvikata": ['cped'],
    "āvikatta": ['cped'],
    "āvikattar": ['cped'],
    "āvikatvā": ['cped'],
    "āvikya": ['mw'],
    "āvikātabba": ['cped'],
    "āvikātum": ['cped'],
    "āvikī": ['mw'],
    "āvikṣita": ['mw'],
    "āvila": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "āvilakanda": ['mw'],
    "āvilay": ['cae'],
    "āvilaya": ['ddsa', 'mw'],
    "āvilayati": ['ap90'],
    "āvilāyati": ['bhs'],
    "āvinna": ['mw'],
    "āvir": ['mw'],
    "āvirbhāva": ['ap90', 'cae', 'ddsa', 'mw'],
    "āvirbhāvaḥ": ['ap90'],
    "āvirbhū": ['ap90', 'mw'],
    "āvirbhūta": ['mw'],
    "āvirbhūti": ['mw'],
    "āvirhita": ['mw'],
    "āvirhotra": ['mw'],
    "āvirmaṇḍala": ['mw'],
    "āvirmukha": ['mw'],
    "āvirmukhī": ['mw'],
    "āvirmūla": ['mw'],
    "āvirṛjīka": ['gra', 'mw'],
    "āvis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āvisati": ['cped'],
    "āvisi": ['cped'],
    "āvistarām": ['ap90', 'mw'],
    "āvitan": ['mw'],
    "āvitta": ['mw'],
    "āviñchana": ['cped'],
    "āviñchi": ['cped'],
    "āviñjana": ['cped'],
    "āviñjanacchidda": ['cped'],
    "āviñjanarajju": ['cped'],
    "āviñjati": ['cped'],
    "āviñji": ['cped'],
    "āviś": ['ap90', 'mw'],
    "āviḥsūrye": ['mw'],
    "āviṁ": ['cped'],
    "āviṣ": ['mw'],
    "āviṣkaraṇa": ['cae', 'ddsa', 'mw'],
    "āviṣkaraṇaṃ": ['ap90'],
    "āviṣkāra": ['mw'],
    "āviṣkṛ": ['ap90', 'mw'],
    "āviṣkṛta": ['mw'],
    "āviṣya": ['ap90'],
    "āviṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "āviṣṭaliṅga": ['mw'],
    "āviṣṭatva": ['mw'],
    "āviṣṭia": ['gra'],
    "āviṣṭita": ['cae', 'gra', 'mw'],
    "āviṣṭya": ['cae', 'gra', 'mw'],
    "āvm, āvī": ['ddsa'],
    "āvodhavai": ['mw'],
    "āvraj": ['mw'],
    "āvrajita": ['mw'],
    "āvraska": ['mw'],
    "āvraskaḥ": ['ap90'],
    "āvraśc": ['ap90', 'mw'],
    "āvraścana": ['cae', 'mw'],
    "āvraścanaṃ": ['ap90'],
    "āvrīḍaka": ['mw'],
    "āvrīḍakaḥ": ['ap90'],
    "āvrīḍha": ['bhs'],
    "āvudha": ['cped'],
    "āvudhalakkhaṇa": ['cped'],
    "āvuka": ['cae', 'mw'],
    "āvukaḥ": ['ap90'],
    "āvunati": ['cped'],
    "āvus": ['bhs'],
    "āvusa": ['bhs'],
    "āvusavāda": ['cped'],
    "āvuso": ['cped'],
    "āvusovāda": ['cped'],
    "āvustaṃ": ['bhs'],
    "āvuta": ['cped'],
    "āvutta": ['mw'],
    "āvuttaḥ": ['ap90'],
    "āvuttha": ['cped'],
    "āvuṇati": ['cped'],
    "āvuṇoti": ['cped'],
    "āvuṇāti": ['cped'],
    "āvuṭa": ['cped'],
    "āvya": ['ap90', 'cae', 'ddsa', 'mw'],
    "āvyadh": ['ap90', 'mw'],
    "āvyakta": ['ddsa', 'mw'],
    "āvyaktika": ['mw'],
    "āvyathā": ['cae', 'ddsa', 'mw'],
    "āvyañj": ['mw'],
    "āvye": ['mw'],
    "āvyuṣam": ['mw'],
    "āvyādha": ['mw'],
    "āvyādhin": ['ap90', 'cae', 'mw'],
    "āvyādhinī": ['mw'],
    "āvyātta": ['mw'],
    "āvyūhati": ['bhs'],
    "āvā": ['mw'],
    "āvādhā": ['mw'],
    "āvāha": ['bhs', 'cae', 'cped', 'mw'],
    "āvāhaka": ['bhs'],
    "āvāhana": ['cped', 'ddsa', 'mw'],
    "āvāhanaṃ": ['ap90'],
    "āvāhanī": ['mw'],
    "āvāhavivāhaka": ['cped'],
    "āvāhaḥ": ['ap90'],
    "āvāhita": ['mw'],
    "āvāhya": ['mw'],
    "āvāla": ['mw'],
    "āvālaṃ": ['ap90'],
    "āvāpa": ['ap90', 'cae', 'ddsa', 'mw'],
    "āvāpaka": ['cae', 'cped', 'mw'],
    "āvāpakaḥ": ['ap90'],
    "āvāpana": ['mw'],
    "āvāpanaṃ": ['ap90'],
    "āvāpika": ['ap90', 'mw'],
    "āvāra": ['bhs', 'cae', 'ddsa', 'mw'],
    "āvāraḥ": ['ap90'],
    "āvāretabba": ['cped'],
    "āvāri": ['mw'],
    "āvāridhi": ['ddsa', 'mw'],
    "āvāriḥ": ['ap90'],
    "āvārya": ['mw'],
    "āvārī": ['bhs'],
    "āvās": ['mw'],
    "āvāsa": ['cae', 'cped', 'ddsa', 'mw'],
    "āvāsakappa": ['cped'],
    "āvāsamacchari": ['cped'],
    "āvāsamaccharin": ['cped'],
    "āvāsamacchariya": ['cped'],
    "āvāsapaligedhi": ['cped'],
    "āvāsapaligedhin": ['cped'],
    "āvāsaparamparā": ['cped'],
    "āvāsaparamparāṁ": ['cped'],
    "āvāsaśuddha": ['bhs'],
    "āvāsaḥ": ['ap90'],
    "āvāsika": ['bhs', 'cped', 'mw'],
    "āvāsin": ['bhs', 'mw'],
    "āvāsya": ['mw'],
    "āvī": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "āvīci": ['bhs'],
    "āvīcika": ['bhs'],
    "āvīj": ['mw'],
    "āvīracūrṇa": ['mw'],
    "āvīracūrṇaḥ": ['ap90'],
    "āvīsūtra": ['mw'],
    "āvīta": ['ap90', 'cae', 'mw'],
    "āvītin": ['ap90', 'cae', 'mw'],
    "āvṛ": ['ap90', 'mw'],
    "āvṛddhabālakam": ['mw'],
    "āvṛdh": ['mw'],
    "āvṛh": ['mw'],
    "āvṛj": ['ap90', 'mw'],
    "āvṛt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āvṛta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "āvṛti": ['bhs', 'mw'],
    "āvṛtiḥ": ['ap90'],
    "āvṛtta": ['ap90', 'cae', 'mw'],
    "āvṛttatva": ['ddsa'],
    "āvṛtti": ['cae', 'ddsa', 'mw'],
    "āvṛttidīpaka": ['mw'],
    "āvṛttiḥ": ['ap90'],
    "āvṛtvat": ['gra', 'mw'],
    "āvṛtya": ['mw'],
    "āvṛtīśayāna": ['mw'],
    "āvṛṃhati": ['bhs'],
    "āvṛṣ": ['mw'],
    "āvṛṣṭi": ['mw'],
    "āvṛṣṭiḥ": ['ap90'],
    "āya": ['bhs', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "āyadarśin": ['cae', 'ddsa', 'mw'],
    "āyadvasu": ['mw'],
    "āyadvāra": ['bhs', 'mw'],
    "āyaj": ['ap90', 'mw'],
    "āyaji": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āyajin": ['cae', 'mw'],
    "āyajiṣṭha": ['ap90', 'gra', 'mw'],
    "āyajyu": ['ap90', 'cae', 'gra', 'mw'],
    "āyajīyas": ['mw'],
    "āyaka": ['mw'],
    "āyakosalla": ['cped'],
    "āyakusala": ['cped'],
    "āyallaka": ['mw'],
    "āyallakaḥ": ['ap90'],
    "āyam": ['ap90', 'mw'],
    "āyamana": ['mw'],
    "āyamanaṃ": ['ap90'],
    "āyamati": ['cped'],
    "āyamukha": ['cped'],
    "āyamya": ['mw'],
    "āyana": ['gra', 'mw'],
    "āyanaṃ": ['ap90'],
    "āyantṛ": ['gra', 'mw'],
    "āyas": ['ap90', 'mw'],
    "āyasa": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "āyasakka": ['cped'],
    "āyasakya": ['cped'],
    "āyasamaya": ['mw'],
    "āyasampanna": ['cped'],
    "āyaskāra": ['mw'],
    "āyaskāraḥ": ['ap90'],
    "āyaskāri": ['mw'],
    "āyasma": ['cped'],
    "āyasmat": ['cped'],
    "āyasta": ['ap90', 'mw'],
    "āyasthāna": ['mw'],
    "āyasī": ['mw'],
    "āyasīya": ['mw'],
    "āyat": ['ap90', 'mw'],
    "āyata": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "āyatabhrūkatā": ['mw'],
    "āyatacaturasra": ['mw'],
    "āyatacchadā": ['mw'],
    "āyatadīrghacaturasra": ['mw'],
    "āyatagga": ['cped'],
    "āyataka": ['cped'],
    "āyatakena": ['cped'],
    "āyatalocana": ['cae'],
    "āyatam": ['mw'],
    "āyatana": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "āyatanaso": ['cped'],
    "āyatanatva": ['mw'],
    "āyatanatvaṃ": ['ap90'],
    "āyatanavat": ['ap90', 'mw'],
    "āyatanaṃ": ['ap90'],
    "āyatanika": ['bhs'],
    "āyatapakṣmala": ['ddsa', 'mw'],
    "āyatapamha": ['cped'],
    "āyatapaṇhi": ['cped'],
    "āyatapaṇhin": ['cped'],
    "āyatapārṣṇitā": ['mw'],
    "āyatapāṇilekhatā": ['mw'],
    "āyatasamalamba": ['mw'],
    "āyatastū": ['mw'],
    "āyatavikrama": ['mw'],
    "āyatayā": ['mw'],
    "āyatekṣaṇa": ['cae', 'ddsa', 'mw'],
    "āyathāpurya": ['mw'],
    "āyathāpūrvya": ['mw'],
    "āyathātathya": ['ddsa', 'mw'],
    "āyathātathyaṃ": ['ap90'],
    "āyati": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "āyatijātijarāmaraṇiya": ['cped'],
    "āyatika": ['cped'],
    "āyatikṣama": ['cae', 'mw'],
    "āyatimat": ['ap90', 'mw'],
    "āyatiḥ": ['ap90'],
    "āyatiṁ": ['cped'],
    "āyatiṃ": ['bhs'],
    "āyatta": ['ap90', 'cae', 'ddsa', 'mw'],
    "āyattamūla": ['mw'],
    "āyattatva": ['mw'],
    "āyattatā": ['mw'],
    "āyatti": ['mw'],
    "āyattiḥ": ['ap90'],
    "āyatā": ['mw'],
    "āyatākṣa": ['cae', 'mw'],
    "āyatāpāṅga": ['mw'],
    "āyatārdha": ['mw'],
    "āyatāyati": ['mw'],
    "āyatī": ['ddsa', 'mw'],
    "āyatīgavam": ['ap90', 'mw'],
    "āyatīsamam": ['mw'],
    "āyava": ['mw'],
    "āyavan": ['mw'],
    "āyavana": ['mw'],
    "āyavanaṃ": ['ap90'],
    "āyavas": ['mw'],
    "āyavasa": ['gra', 'mw'],
    "āyavasaḥ": ['ap90'],
    "āyavyaya": ['cae', 'mw'],
    "āyaḥ": ['ap90'],
    "āyaḥsthūṇa": ['mw'],
    "āyaḥśūlika": ['ap90', 'mw'],
    "āyaṃtṛ": ['ap90'],
    "āye": ['ap90', 'mw'],
    "āyika": ['bhs'],
    "āyin": ['ap90', 'mw'],
    "āyoda": ['cae', 'ddsa', 'mw'],
    "āyodhana": ['cae', 'ddsa', 'mw'],
    "āyodhanaṃ": ['ap90'],
    "āyodhita": ['mw'],
    "āyodhyaka": ['mw'],
    "āyodhyika": ['mw'],
    "āyoga": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "āyogava": ['cae', 'ddsa', 'mw'],
    "āyogavaḥ": ['ap90'],
    "āyogavī": ['mw'],
    "āyogaḥ": ['ap90'],
    "āyojana": ['ddsa', 'mw'],
    "āyojanam": ['mw'],
    "āyojanaṃ": ['ap90'],
    "āyojita": ['mw'],
    "āyu": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "āyuda": ['cped'],
    "āyudh": ['ap90', 'mw'],
    "āyudha": ['cae', 'ddsa', 'gra', 'mw'],
    "āyudhabhṛt": ['cae', 'mw'],
    "āyudhadharmiṇī": ['mw'],
    "āyudhajīvin": ['mw'],
    "āyudhalakkhaṇa": ['cped'],
    "āyudhapiśācikā": ['mw'],
    "āyudhapiśācī": ['mw'],
    "āyudhapāla": ['mw'],
    "āyudhasahāya": ['mw'],
    "āyudhasāhvaya": ['mw'],
    "āyudhaśālā": ['mw'],
    "āyudhaḥ": ['ap90'],
    "āyudhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "āyudhin": ['ap90', 'cae', 'mw'],
    "āyudhiṣṭhira": ['bhs'],
    "āyudhāgāra": ['cae', 'mw'],
    "āyudhāgāranara": ['mw'],
    "āyudhāgārika": ['mw'],
    "āyudhīya": ['cae', 'mw'],
    "āyudhīyaka": ['mw'],
    "āyudāyi": ['cped'],
    "āyudāyin": ['cped'],
    "āyuhati": ['cped'],
    "āyuj": ['ap90', 'mw'],
    "āyukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "āyuktaka": ['mw'],
    "āyuktin": ['mw'],
    "āyuktā": ['mw'],
    "āyukṛt": ['mw'],
    "āyup": ['mw'],
    "āyupatnī": ['mw'],
    "āyur": ['mw'],
    "āyurdad": ['mw'],
    "āyurdadā": ['bhs'],
    "āyurdravya": ['mw'],
    "āyurdā": ['mw'],
    "āyurdāvan": ['mw'],
    "āyurdāya": ['mw'],
    "āyurhṛt": ['mw'],
    "āyurjñāna": ['mw'],
    "āyurmahodadhi": ['mw'],
    "āyurveda": ['cae', 'ddsa', 'mw'],
    "āyurvedadṛś": ['mw'],
    "āyurvedamaya": ['mw'],
    "āyurvedarasāyana": ['mw'],
    "āyurvedasarvasva": ['mw'],
    "āyurvedasaukhya": ['mw'],
    "āyurvedika": ['mw'],
    "āyurvedin": ['mw'],
    "āyuryoga": ['mw'],
    "āyuryudh": ['mw'],
    "āyus": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āyusaṅkhāra": ['cped'],
    "āyussa": ['cped'],
    "āyustejas": ['bhs', 'mw'],
    "āyuta": ['ap90', 'cae', 'ddsa', 'mw'],
    "āyutta": ['cped'],
    "āyuva": ['cped'],
    "āyuvat": ['cped'],
    "āyuḥ": ['mw'],
    "āyuḥpati": ['mw'],
    "āyuḥsaṃskāra": ['bhs'],
    "āyuḥśeṣa": ['cae', 'ddsa', 'mw'],
    "āyuḥśeṣatā": ['mw'],
    "āyuḥṣṭoma": ['mw'],
    "āyuṣ": ['mw'],
    "āyuṣa": ['ddsa', 'mw'],
    "āyuṣak": ['gra', 'mw'],
    "āyuṣaya": ['mw'],
    "āyuṣaṃ": ['ap90'],
    "āyuṣika": ['bhs'],
    "āyuṣka": ['ddsa', 'mw'],
    "āyuṣkara": ['mw'],
    "āyuṣkaḥ": ['ap90'],
    "āyuṣkāma": ['cae', 'mw'],
    "āyuṣkāraṇa": ['mw'],
    "āyuṣkṛt": ['mw'],
    "āyuṣmant": ['cae'],
    "āyuṣmat": ['ap90', 'mw'],
    "āyuṣmatpuruṣaka": ['mw'],
    "āyuṣmaṃ": ['bhs'],
    "āyuṣmaṃvāda": ['bhs'],
    "āyuṣpati": ['mw'],
    "āyuṣprataraṇa": ['mw'],
    "āyuṣpā": ['mw'],
    "āyuṣya": ['ap90', 'cae', 'mw'],
    "āyuṣyagaṇa": ['mw'],
    "āyuṣyahoma": ['mw'],
    "āyuṣyavat": ['mw'],
    "āyuṣṭoma": ['mw'],
    "āyā": ['ap90', 'mw'],
    "āyāc": ['mw'],
    "āyācamāna": ['cped'],
    "āyācana": ['bhs', 'cped', 'mw'],
    "āyācanta": ['cped'],
    "āyācati": ['cped'],
    "āyācita": ['ap90', 'mw'],
    "āyācñā": ['bhs'],
    "āyāga": ['cped', 'ddsa', 'mw'],
    "āyāgabhūta": ['mw'],
    "āyāgaḥ": ['ap90'],
    "āyāma": ['cae', 'cped', 'ddsa', 'mw'],
    "āyāmatas": ['mw'],
    "āyāmato": ['cped'],
    "āyāmavat": ['ap90', 'mw'],
    "āyāmaḥ": ['ap90'],
    "āyāmena": ['cped'],
    "āyāmin": ['ap90', 'ddsa', 'mw'],
    "āyāmita": ['ap90', 'mw'],
    "āyāna": ['cae', 'gra', 'mw'],
    "āyānaṃ": ['ap90'],
    "āyānta": ['cped'],
    "āyāpana": ['mw'],
    "āyāpanaṃ": ['ap90'],
    "āyāpita": ['bhs', 'mw'],
    "āyāsa": ['bhs', 'cae', 'cped', 'ddsa', 'mw'],
    "āyāsada": ['cae'],
    "āyāsadāyin": ['mw'],
    "āyāsaka": ['ap90', 'cae', 'mw'],
    "āyāsakara": ['cae'],
    "āyāsana": ['mw'],
    "āyāsayitṛ": ['cae'],
    "āyāsaḥ": ['ap90'],
    "āyāsin": ['ap90', 'mw'],
    "āyāsita": ['cped', 'mw'],
    "āyāsya": ['mw'],
    "āyāta": ['ap90', 'ddsa', 'mw'],
    "āyāti": ['cae', 'cped', 'ddsa', 'mw'],
    "āyātiḥ": ['ap90'],
    "āyātrika": ['bhs'],
    "āyūha": ['bhs', 'cped'],
    "āyūhati": ['bhs', 'cped'],
    "āñc": ['mw'],
    "āñch": ['cae', 'ddsa', 'mw'],
    "āñchana": ['mw'],
    "āñchita": ['mw'],
    "āñj": ['mw'],
    "āñjalikya": ['mw'],
    "āñjana": ['cae', 'ddsa', 'gra', 'mw'],
    "āñjanagandhi": ['cae', 'gra', 'mw'],
    "āñjanagiri": ['mw'],
    "āñjaneya": ['ddsa', 'mw'],
    "āñjaneyapurāṇa": ['mw'],
    "āñjaneyastava": ['mw'],
    "āñjaneyastotra": ['mw'],
    "āñjanya": ['mw'],
    "āñjanābhyañjana": ['mw'],
    "āñjanābhyañjanā": ['mw'],
    "āñjanābhyañjanīya": ['mw'],
    "āñjanābhyañjanīyā": ['mw'],
    "āñjanī": ['mw'],
    "āñjanīkārī": ['mw'],
    "āñjasa": ['mw'],
    "āñjasya": ['mw'],
    "āñjiga": ['mw'],
    "āñjika": ['mw'],
    "āñjineya": ['mw'],
    "āñjīkūla": ['mw'],
    "āñjīkūlaka": ['mw'],
    "āññassati": ['cped'],
    "āññeyya": ['cped'],
    "āññāsi": ['cped'],
    "āññāta": ['cped'],
    "āññātabba": ['cped'],
    "āññātaññassāmītindriya": ['cped'],
    "āññāti": ['cped'],
    "āññātuṁ": ['cped'],
    "āññāya": ['cped'],
    "āīkṣ": ['mw'],
    "āīr": ['mw'],
    "āīṣ": ['mw'],
    "āś": ['mw'],
    "āśa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "āśad": ['mw'],
    "āśak": ['ap90', 'mw'],
    "āśaka": ['mw'],
    "āśakaṃ": ['ap90'],
    "āśakta": ['ap90', 'mw'],
    "āśakti": ['mw'],
    "āśaktiḥ": ['ap90'],
    "āśalaḥ": ['ap90'],
    "āśana": ['ap90', 'mw'],
    "āśapātrī": ['bhs'],
    "āśara": ['mw'],
    "āśaraḥ": ['ap90'],
    "āśarīka": ['mw'],
    "āśarīram": ['ddsa', 'mw'],
    "āśas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āśasana": ['cae', 'gra', 'mw'],
    "āśasanaṃ": ['ap90'],
    "āśasta": ['mw'],
    "āśauca": ['cae', 'ddsa', 'mw'],
    "āśaucanirṇaya": ['mw'],
    "āśaucaṃ": ['ap90'],
    "āśaucin": ['mw'],
    "āśava": ['mw'],
    "āśavaṃ": ['ap90'],
    "āśaya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "āśayatas": ['mw'],
    "āśayaḥ": ['ap90'],
    "āśayitṛ": ['ap90', 'mw'],
    "āśayāgni": ['mw'],
    "āśayāna": ['mw'],
    "āśayāśa": ['mw'],
    "āśaṃk": ['ap90'],
    "āśaṃkanīya": ['ap90'],
    "āśaṃkin": ['ap90'],
    "āśaṃkita": ['ap90'],
    "āśaṃkā": ['ap90'],
    "āśaṃs": ['ap90', 'mw'],
    "āśaṃsa": ['ddsa', 'mw'],
    "āśaṃsana": ['cae', 'mw'],
    "āśaṃsanaṃ": ['ap90'],
    "āśaṃsin": ['mw'],
    "āśaṃsita": ['ap90', 'mw'],
    "āśaṃsitṛ": ['ap90', 'ddsa', 'mw'],
    "āśaṃsu": ['ap90', 'mw'],
    "āśaṃsā": ['ap90', 'mw'],
    "āśaṅk": ['mw'],
    "āśaṅka": ['mw'],
    "āśaṅkanīya": ['cae', 'ddsa', 'mw'],
    "āśaṅkin": ['cae', 'mw'],
    "āśaṅkita": ['mw'],
    "āśaṅkitavya": ['bhs', 'mw'],
    "āśaṅkya": ['mw'],
    "āśaṅkā": ['cae', 'mw'],
    "āśaṅkānvita": ['mw'],
    "āścarya": ['ap90', 'cae', 'ddsa', 'mw'],
    "āścaryabhūta": ['mw'],
    "āścaryam": ['mw'],
    "āścaryamaya": ['mw'],
    "āścaryamañjarī": ['mw'],
    "āścaryaratnamālā": ['mw'],
    "āścaryarāmāyaṇa": ['mw'],
    "āścaryarūpa": ['mw'],
    "āścaryatva": ['mw'],
    "āścaryatā": ['ap90', 'mw'],
    "āścotana": ['ap90', 'mw'],
    "āścut": ['mw'],
    "āścutita": ['cae', 'mw'],
    "āścyotana": ['mw'],
    "āścyut": ['mw'],
    "āśekuṭin": ['ap90', 'mw'],
    "āśi": ['cae', 'mw'],
    "āśikham": ['mw'],
    "āśikṣā": ['mw'],
    "āśiman": ['ap90', 'mw'],
    "āśin": ['ap90', 'cae', 'ddsa', 'mw'],
    "āśina": ['ap90', 'cae', 'gra', 'mw'],
    "āśir": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āśira": ['ap90', 'mw'],
    "āśiradugha": ['mw'],
    "āśiraḥpadam": ['mw'],
    "āśiraḥpādam": ['ddsa'],
    "āśis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āśita": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āśitaṃbhava": ['ap90', 'mw'],
    "āśitaṃgavīna": ['ap90', 'mw'],
    "āśitiman": ['mw'],
    "āśitṛ": ['ap90', 'mw'],
    "āśivrate": ['bhs'],
    "āśiñj": ['mw'],
    "āśiñjita": ['cae', 'mw'],
    "āśiḥ": ['ap90'],
    "āśiṃjita": ['ap90'],
    "āśiṣṭha": ['cae', 'ddsa', 'mw'],
    "āślath": ['mw'],
    "āśleṣa": ['cae', 'ddsa', 'mw'],
    "āśleṣaḥ": ['ap90'],
    "āśleṣaṇa": ['mw'],
    "āśleṣita": ['mw'],
    "āśleṣā": ['mw'],
    "āśliṣ": ['ap90', 'mw'],
    "āśliṣṭa": ['ap90', 'cae', 'mw'],
    "āśliṣṭasānu": ['ddsa'],
    "āśma": ['ap90', 'mw'],
    "āśmabhāraka": ['mw'],
    "āśmana": ['ap90', 'mw'],
    "āśmaratha": ['mw'],
    "āśmarathya": ['mw'],
    "āśmarika": ['ap90', 'mw'],
    "āśmeya": ['mw'],
    "āśmika": ['ap90', 'mw'],
    "āśmāyana": ['mw'],
    "āśocani": ['mw'],
    "āśokeya": ['ap90', 'mw'],
    "āśokā": ['mw'],
    "āśoṣaṇaṃ": ['ap90'],
    "āśpṛśya": ['mw'],
    "āśraddhya": ['bhs'],
    "āśrama": ['cae', 'ddsa', 'mw'],
    "āśramabhraṣṭa": ['mw'],
    "āśramadharma": ['mw'],
    "āśramaguru": ['mw'],
    "āśramamaṇḍala": ['mw'],
    "āśramapada": ['mw'],
    "āśramaparvan": ['mw'],
    "āśramasad": ['mw'],
    "āśramasthāna": ['mw'],
    "āśramaviḍambaka": ['mw'],
    "āśramavāsika": ['mw'],
    "āśramavāsin": ['cae', 'mw'],
    "āśramaḥ": ['ap90'],
    "āśramika": ['ap90', 'mw'],
    "āśramin": ['cae', 'ddsa', 'mw'],
    "āśramopaniṣad": ['mw'],
    "āśramālaya": ['ddsa', 'mw'],
    "āśrapaṇa": ['mw'],
    "āśrapaṇaṃ": ['ap90'],
    "āśrava": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "āśravasya": ['mw'],
    "āśravaḥ": ['ap90'],
    "āśravaṇa": ['bhs'],
    "āśravaṇam": ['mw'],
    "āśraya": ['bhs', 'cae', 'ddsa', 'mw'],
    "āśrayabhuj": ['mw'],
    "āśrayabhūta": ['cae', 'ddsa', 'mw'],
    "āśrayaka": ['bhs'],
    "āśrayaliṅga": ['mw'],
    "āśrayatas": ['mw'],
    "āśrayatva": ['mw'],
    "āśrayavat": ['mw'],
    "āśrayaḥ": ['ap90'],
    "āśrayaṇa": ['ap90', 'cae', 'mw'],
    "āśrayaṇīya": ['ap90', 'cae', 'mw'],
    "āśrayaṇīyatva": ['mw'],
    "āśrayin": ['ap90', 'cae', 'ddsa', 'mw'],
    "āśrayitavya": ['mw'],
    "āśrayāsiddha": ['mw'],
    "āśrayāśa": ['ddsa', 'mw'],
    "āśraṃ": ['ap90'],
    "āśretṛ": ['mw'],
    "āśreṣa": ['cae', 'mw'],
    "āśreṣā": ['mw'],
    "āśri": ['ap90', 'mw'],
    "āśrita": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "āśritatva": ['mw'],
    "āśritya": ['cae', 'mw'],
    "āśriḥ": ['ap90'],
    "āśru": ['ap90', 'mw'],
    "āśrukarṇa": ['ap90'],
    "āśrut": ['mw'],
    "āśruta": ['ap90', 'cae', 'mw'],
    "āśruti": ['cae', 'mw'],
    "āśrutiḥ": ['ap90'],
    "āśrutkarṇa": ['cae', 'gra', 'mw'],
    "āśrāva": ['mw'],
    "āśrāvayati": ['bhs'],
    "āśrāvaṇa": ['cae', 'mw'],
    "āśrāvaṇaṃ": ['ap90'],
    "āśrāvitapratyāśrāvita": ['mw'],
    "āśrāvya": ['mw'],
    "āśrī": ['mw'],
    "āśu": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "āśuapas": ['gra'],
    "āśuaśva": ['gra'],
    "āśuaśvia": ['gra'],
    "āśubhāvin": ['mw'],
    "āśubodha": ['mw'],
    "āśuc": ['mw'],
    "āśuga": ['cae', 'mw'],
    "āśugamana": ['cae'],
    "āśugandha": ['bhs', 'mw'],
    "āśugatitva": ['mw'],
    "āśugāmin": ['mw'],
    "āśuheman": ['gra', 'mw'],
    "āśuheṣas": ['gra', 'mw'],
    "āśukavi": ['mw'],
    "āśuketu": ['bhs'],
    "āśuklānta": ['cae', 'mw'],
    "āśukopin": ['mw'],
    "āśukriyā": ['mw'],
    "āśukāri": ['bhs'],
    "āśukārin": ['mw'],
    "āśumat": ['cae', 'mw'],
    "āśupattrī": ['mw'],
    "āśupatvan": ['gra', 'mw'],
    "āśuphala": ['mw'],
    "āśuratha": ['mw'],
    "āśurathīya": ['mw'],
    "āśusaṃdheya": ['mw'],
    "āśutoṣa": ['mw'],
    "āśutva": ['mw'],
    "āśutvaṃ": ['ap90'],
    "āśuvikrama": ['mw'],
    "āśuvimardita": ['ddsa'],
    "āśuvrīhi": ['mw'],
    "āśuvṛttitva": ['mw'],
    "āśuyā": ['cae', 'ddsa', 'gra', 'mw'],
    "āśuśravas": ['mw'],
    "āśuśukṣaṇi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āśuśuṣka": ['ddsa'],
    "āśuśuṣkatva": ['mw'],
    "āśuṃga": ['mw'],
    "āśuṣ": ['mw'],
    "āśuṣeṇa": ['mw'],
    "āśuṣāṇa": ['mw'],
    "āśva": ['ap90', 'cae', 'ddsa', 'mw'],
    "āśvabala": ['mw'],
    "āśvabhārika": ['ap90', 'mw'],
    "āśvaghna": ['gra', 'mw'],
    "āśvalakṣaṇika": ['ap90', 'mw'],
    "āśvalāyana": ['ddsa', 'mw'],
    "āśvalāyanabrāhmaṇa": ['mw'],
    "āśvalāyanagṛhyakārikā": ['mw'],
    "āśvalāyanaśākhin": ['mw'],
    "āśvalāyanaśākhā": ['mw'],
    "āśvalāyanaḥ": ['ap90'],
    "āśvamedha": ['gra', 'mw'],
    "āśvamedhika": ['ap90', 'ddsa', 'mw'],
    "āśvamedhikī": ['mw'],
    "āśvapadika": ['mw'],
    "āśvapas": ['gra', 'mw'],
    "āśvapata": ['mw'],
    "āśvapejin": ['mw'],
    "āśvapeyin": ['mw'],
    "āśvapālika": ['mw'],
    "āśvaratha": ['ap90', 'mw'],
    "āśvas": ['ap90', 'mw'],
    "āśvasya": ['mw'],
    "āśvasūkta": ['mw'],
    "āśvasūkti": ['mw'],
    "āśvatara": ['mw'],
    "āśvatarāsvi": ['mw'],
    "āśvattha": ['ap90', 'cae', 'ddsa', 'mw'],
    "āśvatthi": ['mw'],
    "āśvatthika": ['mw'],
    "āśvavāla": ['mw'],
    "āśvavāra": ['mw'],
    "āśvayuj": ['mw'],
    "āśvayuja": ['ap90', 'cae', 'ddsa', 'mw'],
    "āśvayujaka": ['ap90', 'mw'],
    "āśvayujī": ['mw'],
    "āśvayujīkarman": ['mw'],
    "āśvaśva": ['cae', 'gra', 'mw'],
    "āśvaśvya": ['gra', 'mw'],
    "āśveya": ['mw'],
    "āśvika": ['ap90', 'mw'],
    "āśvina": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "āśvinacihnita": ['mw'],
    "āśvinapātra": ['mw'],
    "āśvineya": ['ap90', 'mw'],
    "āśvināgra": ['mw'],
    "āśvinī": ['mw'],
    "āśvāsa": ['bhs', 'cae', 'ddsa', 'mw'],
    "āśvāsahasta": ['bhs'],
    "āśvāsaka": ['ap90', 'bhs', 'mw'],
    "āśvāsana": ['cae', 'mw'],
    "āśvāsanaśīla": ['cae', 'mw'],
    "āśvāsanaśīlatā": ['mw'],
    "āśvāsanaṃ": ['ap90'],
    "āśvāsanī": ['bhs', 'mw'],
    "āśvāsanīya": ['mw'],
    "āśvāsapraśvāsa": ['bhs'],
    "āśvāsaḥ": ['ap90'],
    "āśvāsin": ['ap90', 'cae', 'mw'],
    "āśvāsita": ['mw'],
    "āśvāsya": ['mw'],
    "āśvāyana": ['mw'],
    "āśvīna": ['ap90', 'ddsa', 'mw'],
    "āśvīya": ['mw'],
    "āśvīyaṃ": ['ap90'],
    "āśya": ['mw'],
    "āśyai": ['ap90', 'mw'],
    "āśyāma": ['mw'],
    "āśyāna": ['ap90', 'cae', 'mw'],
    "āśā": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "āśābandha": ['cae', 'mw'],
    "āśābhaṅga": ['mw'],
    "āśācakravāla": ['mw'],
    "āśāditya": ['mw'],
    "āśādāman": ['mw'],
    "āśāgaja": ['mw'],
    "āśāhīna": ['mw'],
    "āśājanana": ['cae'],
    "āśākṛta": ['mw'],
    "āśāmukha": ['cae', 'mw'],
    "āśānvita": ['cae', 'mw'],
    "āśāparā": ['mw'],
    "āśāpati": ['mw'],
    "āśāpiśācikā": ['mw'],
    "āśāpratīkṣā": ['cae'],
    "āśāprāpta": ['mw'],
    "āśāpura": ['mw'],
    "āśāpuraguggulu": ['mw'],
    "āśāpurasambhava": ['mw'],
    "āśāpurā": ['mw'],
    "āśāpāla": ['mw'],
    "āśāpālīya": ['mw'],
    "āśāpāśa": ['cae'],
    "āśāra": ['mw'],
    "āśāraiṣin": ['mw'],
    "āśāraḥ": ['ap90'],
    "āśārikaḥ": ['ap90'],
    "āśās": ['ap90', 'mw'],
    "āśāsana": ['mw'],
    "āśāsanīya": ['mw'],
    "āśāsaṃśita": ['mw'],
    "āśāsti": ['bhs', 'ddsa', 'mw'],
    "āśāsya": ['ap90', 'cae', 'ddsa', 'mw'],
    "āśātantu": ['cae'],
    "āśātanā": ['mw'],
    "āśātikā": ['bhs'],
    "āśāvaha": ['mw'],
    "āśāvant": ['cae'],
    "āśāvarī": ['mw'],
    "āśāvarītarī": ['mw'],
    "āśāvat": ['ap90', 'mw'],
    "āśāvibhinna": ['mw'],
    "āśāvijaya": ['mw'],
    "āśāvāsas": ['cae', 'mw'],
    "āśāśa": ['ddsa', 'mw'],
    "āśāḍha": ['mw'],
    "āśāḍhaḥ": ['ap90'],
    "āśāṭavī": ['bhs'],
    "āśī": ['ap90', 'mw'],
    "āśīna": ['cae', 'mw'],
    "āśīr": ['mw'],
    "āśīrdā": ['gra', 'mw'],
    "āśīrdāyā": ['mw'],
    "āśīrgeya": ['mw'],
    "āśīrgrahaṇa": ['mw'],
    "āśīrmant": ['cae'],
    "āśīrukti": ['mw'],
    "āśīrvacana": ['cae', 'ddsa', 'mw'],
    "āśīrvacanākṣepa": ['mw'],
    "āśīrvant": ['cae'],
    "āśīrvat": ['gra', 'mw'],
    "āśīrviṣa": ['mw'],
    "āśīrvācaka": ['mw'],
    "āśīrvāda": ['mw'],
    "āśīrvādābhidhānavant": ['cae'],
    "āśīrvādābhidhānavat": ['mw'],
    "āśītakī": ['bhs'],
    "āśīviṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "āśīviṣanadī": ['bhs', 'mw'],
    "āśīviṣaparvata": ['mw'],
    "āśīviṣopama": ['cae'],
    "āśīviṣā": ['bhs', 'mw'],
    "āśīyas": ['ddsa', 'mw'],
    "āśīyaṃs": ['cae'],
    "āśīḥkriya": ['ddsa'],
    "āśū": ['ap90'],
    "āśṛta": ['cae', 'mw'],
    "āūrṇu": ['mw'],
    "āḍambara": ['cae', 'ddsa', 'mw'],
    "āḍambaravat": ['mw'],
    "āḍambarin": ['mw'],
    "āḍambarita": ['mw'],
    "āḍambarāghāta": ['mw'],
    "āḍaṃbaraḥ": ['ap90'],
    "āḍaṃbarin": ['ap90'],
    "āḍhaka": ['cae', 'ddsa', 'mw'],
    "āḍhakajambuka": ['mw'],
    "āḍhakaḥ": ['ap90'],
    "āḍhakika": ['ap90', 'mw'],
    "āḍhakī": ['mw'],
    "āḍhakīna": ['mw'],
    "āḍhika": ['mw'],
    "āḍhya": ['ap90', 'cae', 'ddsa', 'mw'],
    "āḍhyacara": ['mw'],
    "āḍhyaka": ['mw'],
    "āḍhyakulīna": ['mw'],
    "āḍhyambhaviṣṇu": ['mw'],
    "āḍhyambhāvuka": ['mw'],
    "āḍhyapadi": ['mw'],
    "āḍhyapūrva": ['mw'],
    "āḍhyaroga": ['mw'],
    "āḍhyarogin": ['mw'],
    "āḍhyatā": ['ap90', 'mw'],
    "āḍhyavāta": ['mw'],
    "āḍhyaṃbhaviṣṇu": ['ap90'],
    "āḍhyaṃkaraṇa": ['ap90', 'mw'],
    "āḍhyāḍu": ['mw'],
    "āḍhā": ['mw'],
    "āḍhārikā": ['mw'],
    "āḍhīlaka": ['mw'],
    "āḍi": ['mw'],
    "āḍibaka": ['mw'],
    "āḍindikā": ['mw'],
    "āḍiḥ": ['ap90'],
    "āḍu": ['mw'],
    "āḍval": ['mw'],
    "āḍvālana": ['mw'],
    "āḍāraka": ['mw'],
    "āḍī": ['mw'],
    "āḍībaka": ['mw'],
    "āḍīvin": ['ddsa', 'mw'],
    "āḍū": ['mw'],
    "āḍūḥ": ['ap90'],
    "āḥ": ['ap90'],
    "āḷahana": ['cped'],
    "āḷakamanda": ['cped'],
    "āḷambara": ['cped'],
    "āḷhaka": ['cped'],
    "āḷhakathālikā": ['cped'],
    "āḷi": ['cped'],
    "āḷinda": ['cped'],
    "āḷāhana": ['cped'],
    "āṃ": ['ap90'],
    "āṃbarīṣaputrakaḥ": ['ap90'],
    "āṃbaṣṭhaḥ": ['ap90'],
    "āṃbhasa": ['ap90'],
    "āṃbhasika": ['ap90'],
    "āṃbikeyaḥ": ['ap90'],
    "āṃcanaṃ": ['ap90'],
    "āṃch": ['ap90'],
    "āṃchanaṃ": ['ap90'],
    "āṃdhasaḥ": ['ap90'],
    "āṃdhasikaḥ": ['ap90'],
    "āṃdhra": ['ap90'],
    "āṃdhyaṃ": ['ap90'],
    "āṃdol": ['ap90'],
    "āṃdolanaṃ": ['ap90'],
    "āṃdolaḥ": ['ap90'],
    "āṃga": ['ap90'],
    "āṃgaka": ['ap90'],
    "āṃgavidya": ['ap90'],
    "āṃgika": ['ap90'],
    "āṃgirasa": ['ap90'],
    "āṃgāraṃ": ['ap90'],
    "āṃgūṣaḥ": ['ap90'],
    "āṃhaspatya": ['mw'],
    "āṃjalikyaṃ": ['ap90'],
    "āṃjana": ['ap90'],
    "āṃjaneyaḥ": ['ap90'],
    "āṃjanikyaṃ": ['ap90'],
    "āṃjanī": ['ap90'],
    "āṃjineyaḥ": ['ap90'],
    "āṃkuśikaḥ": ['ap90'],
    "āṃkṛti": ['mw'],
    "āṃkṣī": ['ap90'],
    "āṃta": ['ap90'],
    "āṃtara": ['ap90'],
    "āṃtaratamyaṃ": ['ap90'],
    "āṃtargaṇika": ['ap90'],
    "āṃtargehika": ['ap90'],
    "āṃtarikṣa": ['ap90'],
    "āṃtarāgārika": ['ap90'],
    "āṃtarāla": ['ap90'],
    "āṃtarīkṣa": ['ap90'],
    "āṃtikā": ['ap90'],
    "āṃtra": ['ap90'],
    "āṃtrika": ['ap90'],
    "āṃtyaḥ": ['ap90'],
    "āṃśa": ['mw'],
    "āṃśya": ['mw'],
    "āṃḍa": ['ap90'],
    "āṃḍī": ['ap90'],
    "āṃḍīka": ['ap90'],
    "āṃḍīra": ['ap90'],
    "āṅ": ['ddsa'],
    "āṅga": ['ddsa', 'mw'],
    "āṅgadī": ['mw'],
    "āṅgaka": ['mw'],
    "āṅgalaukika": ['mw'],
    "āṅgariṣṭha": ['mw'],
    "āṅgavidya": ['mw'],
    "āṅgeya": ['mw'],
    "āṅgeyī": ['mw'],
    "āṅgi": ['mw'],
    "āṅgika": ['mw'],
    "āṅgirasa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "āṅgirasapavitra": ['mw'],
    "āṅgiraseśvaratīrtha": ['mw'],
    "āṅgirasī": ['mw'],
    "āṅgula": ['mw'],
    "āṅgulika": ['mw'],
    "āṅgya": ['mw'],
    "āṅgāra": ['mw'],
    "āṅgārika": ['ddsa', 'mw'],
    "āṅgī": ['mw'],
    "āṅgīrasa": ['mw'],
    "āṅgūṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "āṅgūṣia": ['gra'],
    "āṅgūṣya": ['gra', 'mw'],
    "āṅkuśāyana": ['mw'],
    "āṅkṣī": ['mw'],
    "āṇaka": ['ap90', 'ddsa', 'mw'],
    "āṇapaka": ['bhs'],
    "āṇapeti": ['bhs'],
    "āṇatta": ['bhs', 'cped'],
    "āṇatti": ['bhs', 'cped'],
    "āṇattikā": ['bhs'],
    "āṇava": ['ap90', 'mw'],
    "āṇavīna": ['ap90', 'mw'],
    "āṇi": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "āṇicoḷaka": ['cped'],
    "āṇidvāra": ['cped'],
    "āṇinema": ['bhs'],
    "āṇinetra": ['bhs'],
    "āṇisaṅghāṭa": ['cped'],
    "āṇiḥ": ['ap90'],
    "āṇuka": ['mw'],
    "āṇā": ['bhs', 'cped'],
    "āṇāpaka": ['bhs', 'cped'],
    "āṇāpayati": ['cped'],
    "āṇāpesi": ['cped'],
    "āṇāpesuṁ": ['cped'],
    "āṇāpeti": ['bhs', 'cped'],
    "āṇāpetvā": ['cped'],
    "āṇāpita": ['cped'],
    "āṇī": ['cped'],
    "āṇīpratyāṇīnirhārayoga": ['bhs'],
    "āṇīveya": ['mw'],
    "āṇūka": ['mw'],
    "āṇḍa": ['cae', 'gra', 'mw'],
    "āṇḍaja": ['ddsa', 'mw'],
    "āṇḍakapāla": ['mw'],
    "āṇḍakośa": ['mw'],
    "āṇḍapīta": ['mw'],
    "āṇḍād": ['mw'],
    "āṇḍāyana": ['mw'],
    "āṇḍī": ['mw'],
    "āṇḍīka": ['mw'],
    "āṇḍīvat": ['mw'],
    "āṇḍīvatāyani": ['mw'],
    "āṛ": ['mw'],
    "āṛdh": ['mw'],
    "āṛñj": ['mw'],
    "āṣāḍha": ['bhs', 'cae', 'ddsa', 'mw'],
    "āṣāḍhabhava": ['mw'],
    "āṣāḍhabhūti": ['mw'],
    "āṣāḍhaka": ['mw'],
    "āṣāḍhakaḥ": ['ap90'],
    "āṣāḍhapura": ['mw'],
    "āṣāḍhaḥ": ['ap90'],
    "āṣāḍhi": ['mw'],
    "āṣāḍhikā": ['mw'],
    "āṣāḍhin": ['ap90'],
    "āṣāḍhā": ['mw'],
    "āṣāḍhābhū": ['mw'],
    "āṣāḍhādripura": ['mw'],
    "āṣāḍhī": ['ddsa', 'mw'],
    "āṣāḍhīya": ['ap90', 'mw'],
    "āṣṭaka": ['mw'],
    "āṣṭakīya": ['mw'],
    "āṣṭama": ['mw'],
    "āṣṭamaḥ": ['ap90'],
    "āṣṭamika": ['bhs', 'ddsa', 'mw'],
    "āṣṭhiyana": ['bhs'],
    "āṣṭhā": ['mw'],
    "āṣṭra": ['mw'],
    "āṣṭraṃ": ['ap90'],
    "āṣṭrā": ['mw'],
    "āṣṭrādaṃṣṭra": ['mw'],
    "āṣṭrī": ['ap90', 'cae', 'gra', 'mw'],
    "āṭ": ['mw'],
    "āṭa": ['mw'],
    "āṭaka": ['mw'],
    "āṭakkara": ['bhs'],
    "āṭaruṣa": ['mw'],
    "āṭarūṣa": ['mw'],
    "āṭarūṣaḥ": ['ap90'],
    "āṭavaka": ['bhs'],
    "āṭavika": ['cae', 'ddsa', 'mw'],
    "āṭavikaḥ": ['ap90'],
    "āṭavikā": ['bhs'],
    "āṭavin": ['mw'],
    "āṭavya": ['mw'],
    "āṭavī": ['ap90', 'mw'],
    "āṭhya": ['bhs'],
    "āṭi": ['mw'],
    "āṭika": ['ap90', 'mw'],
    "āṭikī": ['mw'],
    "āṭiḥ": ['ap90'],
    "āṭopa": ['cae', 'ddsa', 'mw'],
    "āṭopaḥ": ['ap90'],
    "āṭānāti": ['bhs'],
    "āṭānāṭika": ['bhs'],
    "āṭīkana": ['mw'],
    "āṭīkanaṃ": ['ap90'],
    "āṭīkara": ['mw'],
    "āṭīkaraḥ": ['ap90'],
    "āṭīlaka": ['mw'],
    "āṭīmeda": ['mw'],
    "āṭīmukha": ['mw'],
    "āṭṇāra": ['mw'],
    "āṭṭasthalīka": ['mw'],
    "ī": ['ap90', 'mw'],
    "īdisa": ['cped'],
    "īdisaka": ['cped'],
    "īdṛgavastha": ['mw'],
    "īdṛktā": ['ap90', 'ddsa', 'mw'],
    "īdṛkṣa": ['ap90', 'cae', 'mw'],
    "īdṛkṣm, īdṛś": ['ddsa'],
    "īdṛś": ['gra', 'mw'],
    "īdṛśa": ['mw'],
    "īdṛśabhūta": ['mw'],
    "īdṛśabhūtatā": ['mw'],
    "īdṛśaka": ['mw'],
    "īdṛśika": ['bhs'],
    "īh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "īha": ['cae', 'mw'],
    "īhatas": ['mw'],
    "īhaḥ": ['ap90'],
    "īhita": ['ap90', 'cae', 'ddsa', 'mw'],
    "īhā": ['ap90', 'cae', 'ddsa', 'mw'],
    "īhālih": ['mw'],
    "īhāmṛga": ['mw'],
    "īhārthin": ['mw'],
    "īhāvanta": ['cae'],
    "īhāvṛka": ['mw'],
    "īj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ījika": ['mw'],
    "ījitum": ['mw'],
    "ījāna": ['ap90', 'ddsa', 'mw'],
    "īkh": ['ap90', 'mw'],
    "īkāra": ['mw'],
    "īkṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "īkṣa": ['cae', 'mw'],
    "īkṣaka": ['cae', 'ddsa', 'mw'],
    "īkṣakaḥ": ['ap90'],
    "īkṣamāṇa": ['mw'],
    "īkṣatiḥ": ['ap90'],
    "īkṣaṇa": ['cae', 'mw'],
    "īkṣaṇapatha": ['cae'],
    "īkṣaṇaṃ": ['ap90'],
    "īkṣaṇika": ['cae', 'mw'],
    "īkṣaṇikaḥ": ['ap90'],
    "īkṣaṇīka": ['cae', 'mw'],
    "īkṣaṇīya": ['mw'],
    "īkṣeṇia": ['gra'],
    "īkṣeṇya": ['ap90', 'cae', 'gra', 'mw'],
    "īkṣikā": ['ap90'],
    "īkṣita": ['ap90', 'cae', 'mw'],
    "īkṣitṛ": ['ap90', 'cae', 'mw'],
    "īkṣyamāṇa": ['mw'],
    "īkṣā": ['ap90', 'mw'],
    "īl": ['mw'],
    "īlay": ['cae'],
    "īlenya": ['ap90'],
    "īli": ['mw'],
    "īlikā": ['mw'],
    "īlina": ['mw'],
    "īlinī": ['mw'],
    "īliḥ": ['ap90'],
    "īlī": ['mw'],
    "īl̤": ['mw'],
    "īl̤enya": ['mw'],
    "īl̤eṇya": ['cae'],
    "īl̤ita": ['mw'],
    "īl̤itṛ": ['cae'],
    "īm": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "īnt": ['mw'],
    "īps": ['cae', 'mw'],
    "īpsa": ['ddsa'],
    "īpsana": ['mw'],
    "īpsita": ['ap90', 'cae', 'mw'],
    "īpsitatama": ['mw'],
    "īpsu": ['ap90', 'cae', 'mw'],
    "īpsuyajña": ['mw'],
    "īpsā": ['ap90', 'cae', 'ddsa', 'mw'],
    "īr": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "īra": ['cae', 'ddsa', 'mw'],
    "īraja": ['mw'],
    "īraputra": ['mw'],
    "īrapāda": ['cae', 'mw'],
    "īrayadhyai": ['mw'],
    "īraṇa": ['ap90', 'cae', 'mw'],
    "īrin": ['ap90', 'mw'],
    "īrita": ['ap90', 'mw'],
    "īritākūta": ['mw'],
    "īriṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "īriṇastha": ['cae'],
    "īrkṣy": ['ap90', 'mw'],
    "īrma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "īrman": ['mw'],
    "īrmā": ['cae', 'ddsa', 'gra', 'mw'],
    "īrmānta": ['gra', 'mw'],
    "īrmāṃta": ['ap90'],
    "īrts": ['mw'],
    "īrtsu": ['mw'],
    "īrtsā": ['mw'],
    "īrvāru": ['mw'],
    "īrvāruḥ": ['ap90'],
    "īrya": ['ap90', 'cae', 'ddsa', 'mw'],
    "īryati": ['bhs'],
    "īryatā": ['mw'],
    "īryā": ['bhs', 'mw'],
    "īryāpatha": ['bhs', 'mw'],
    "īryāvant": ['bhs'],
    "īrāmā": ['mw'],
    "īrṇa": ['mw'],
    "īrṣita": ['mw'],
    "īrṣitavya": ['mw'],
    "īrṣu": ['bhs', 'mw'],
    "īrṣy": ['ap90', 'cae', 'ddsa', 'mw'],
    "īrṣya": ['ap90', 'mw'],
    "īrṣyaka": ['mw'],
    "īrṣyamāṇa": ['mw'],
    "īrṣyin": ['mw'],
    "īrṣyita": ['mw'],
    "īrṣyu": ['cae', 'mw'],
    "īrṣyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "īrṣyābhirati": ['mw'],
    "īrṣyālu": ['ap90', 'cae', 'mw'],
    "īrṣyāluka": ['bhs'],
    "īrṣyārati": ['mw'],
    "īrṣyāvant": ['cae'],
    "īrṣyāvat": ['mw'],
    "īrṣyāvaśa": ['mw'],
    "īrṣyāyate": ['bhs'],
    "īrṣyāṣaṇḍha": ['mw'],
    "īrṣā": ['ap90', 'mw'],
    "īrṣālu": ['mw'],
    "īrṣī": ['bhs'],
    "īsakapoṇa": ['cped'],
    "īsakaṁ": ['cped'],
    "īsarāpha": ['mw'],
    "īsikā": ['cped'],
    "īsā": ['cped'],
    "īsādanta": ['cped'],
    "īsāmukha": ['cped'],
    "īti": ['ap90', 'cae', 'cped', 'ddsa', 'mw'],
    "ītī": ['cped'],
    "īvant": ['cae'],
    "īvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "īya": ['ap90'],
    "īyacakṣas": ['gra', 'mw'],
    "īyakṣamāṇa": ['mw'],
    "īyivas": ['ddsa', 'mw'],
    "īyuṣī": ['ddsa'],
    "īñj": ['mw'],
    "īś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "īśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "īśagocara": ['mw'],
    "īśagītā": ['mw'],
    "īśake": ['mw'],
    "īśana": ['cae', 'mw'],
    "īśanaṃ": ['ap90'],
    "īśasakhi": ['mw'],
    "īśasaras": ['mw'],
    "īśasaṃstha": ['mw'],
    "īśatva": ['mw'],
    "īśaśakti": ['mw'],
    "īśeśvara": ['mw'],
    "īśin": ['ap90', 'cae', 'ddsa', 'mw'],
    "īśinī": ['mw'],
    "īśitavya": ['mw'],
    "īśitavyaṃ": ['ap90'],
    "īśitva": ['mw'],
    "īśitā": ['ap90', 'cae', 'mw'],
    "īśitṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "īśopaniṣad": ['cae', 'mw'],
    "īśvara": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "īśvarabhāva": ['cae', 'mw'],
    "īśvaradatta": ['mw'],
    "īśvaradeva": ['bhs'],
    "īśvaragupta": ['bhs'],
    "īśvaraguṇāparājitadhvaja": ['bhs'],
    "īśvaragītā": ['mw'],
    "īśvarakāraṇika": ['mw'],
    "īśvarakāraṇin": ['mw'],
    "īśvarakārin": ['mw'],
    "īśvarakṛṣṇa": ['mw'],
    "īśvaraniṣedha": ['mw'],
    "īśvaraniṣṭha": ['mw'],
    "īśvaraprasāda": ['mw'],
    "īśvarapratyabhijñāsūtra": ['mw'],
    "īśvarapraṇidhāna": ['cae', 'mw'],
    "īśvarapriya": ['mw'],
    "īśvarapūjaka": ['mw'],
    "īśvarapūjā": ['mw'],
    "īśvarasabha": ['mw'],
    "īśvarasadman": ['mw'],
    "īśvarasena": ['mw'],
    "īśvarasevā": ['mw'],
    "īśvarasūri": ['mw'],
    "īśvaratva": ['mw'],
    "īśvaratā": ['ap90', 'cae', 'mw'],
    "īśvaratīrthācārya": ['mw'],
    "īśvaravarman": ['mw'],
    "īśvaravāda": ['mw'],
    "īśvarā": ['mw'],
    "īśvarādhīna": ['mw'],
    "īśvarādhīnatva": ['mw'],
    "īśvarādhīnatā": ['mw'],
    "īśvarājitagunadhvaja": ['bhs'],
    "īśvarānanda": ['mw'],
    "īśvarīkṛ": ['mw'],
    "īśvarītantra": ['mw'],
    "īśvarīya": ['bhs'],
    "īśā": ['mw'],
    "īśācala": ['mw'],
    "īśādhara": ['bhs', 'mw'],
    "īśādhyāya": ['mw'],
    "īśādhāra": ['bhs'],
    "īśāna": ['ap90', 'cae', 'ddsa', 'mw'],
    "īśānabali": ['mw'],
    "īśānacandra": ['mw'],
    "īśānadevī": ['mw'],
    "īśānadiś": ['mw'],
    "īśānahata": ['mw'],
    "īśānaja": ['mw'],
    "īśānakalpa": ['mw'],
    "īśānakṛt": ['cae', 'gra', 'mw'],
    "īśānya": ['mw'],
    "īśānā": ['mw'],
    "īśānādhipa": ['mw'],
    "īśānādhipā": ['mw'],
    "īśānī": ['mw'],
    "īśāvāsya": ['mw'],
    "īḍ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "īḍana": ['mw'],
    "īḍanaṃ": ['ap90'],
    "īḍenia": ['gra'],
    "īḍenya": ['ap90', 'ddsa', 'gra', 'mw'],
    "īḍeṇya": ['cae'],
    "īḍia": ['gra'],
    "īḍita": ['mw'],
    "īḍitṛ": ['cae', 'mw'],
    "īḍya": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "īḍyamāna": ['mw'],
    "īḍā": ['ap90', 'mw'],
    "īḥ": ['ap90'],
    "īṃkāra": ['mw'],
    "īṃkṛta": ['mw'],
    "īṃt": ['ap90'],
    "īṅkh": ['cae', 'ddsa', 'gra', 'mw'],
    "īṅkhaka": ['bhs'],
    "īṅkhana": ['cae', 'ddsa', 'mw'],
    "īṅkhaya": ['mw'],
    "īṇmat": ['ap90'],
    "īṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "īṣa": ['mw'],
    "īṣacchvāsa": ['mw'],
    "īṣad": ['mw'],
    "īṣadasamāpta": ['mw'],
    "īṣadasamāpti": ['mw'],
    "īṣadbījā": ['mw'],
    "īṣaddarśana": ['mw'],
    "īṣaddhāsa": ['mw'],
    "īṣaddhāsya": ['mw'],
    "īṣadguṇa": ['mw'],
    "īṣadrakta": ['mw'],
    "īṣadupadāna": ['mw'],
    "īṣaduṣṇa": ['mw'],
    "īṣadvivṛta": ['mw'],
    "īṣadvīrya": ['mw'],
    "īṣadāḍhyaṃbhava": ['mw'],
    "īṣadāḍhyaṃkara": ['mw'],
    "īṣadūna": ['mw'],
    "īṣajjala": ['mw'],
    "īṣallabha": ['mw'],
    "īṣan": ['mw'],
    "īṣanmarṣa": ['mw'],
    "īṣanmarṣaṇa": ['mw'],
    "īṣannimaya": ['mw'],
    "īṣannāda": ['mw'],
    "īṣat": ['ap90', 'cae', 'ddsa', 'mw'],
    "īṣatkara": ['cae', 'mw'],
    "īṣatkārya": ['mw'],
    "īṣatpralambha": ['mw'],
    "īṣatpuruṣa": ['mw'],
    "īṣatpāna": ['cae', 'mw'],
    "īṣatpāṇḍu": ['mw'],
    "īṣatsadṛśa": ['mw'],
    "īṣatsaṃjña": ['mw'],
    "īṣatspṛṣṭa": ['mw'],
    "īṣaḥ": ['ap90'],
    "īṣaṇa": ['ap90', 'mw'],
    "īṣaṇin": ['mw'],
    "īṣaṇā": ['mw'],
    "īṣi": ['bhs'],
    "īṣikā": ['ap90', 'mw'],
    "īṣira": ['mw'],
    "īṣiraḥ": ['ap90'],
    "īṣma": ['ap90', 'mw'],
    "īṣva": ['mw'],
    "īṣā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "īṣādanta": ['mw'],
    "īṣādaṇḍa": ['mw'],
    "īṣādhara": ['bhs'],
    "īṣādhāra": ['bhs', 'mw'],
    "īṣāntabandhana": ['mw'],
    "īṣīkā": ['ap90', 'cae', 'mw'],
    "śa": ['mw'],
    "śabala": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śabalacetana": ['mw'],
    "śabalagu": ['mw'],
    "śabalahṛdaya": ['mw'],
    "śabalaka": ['mw'],
    "śabalatva": ['mw'],
    "śabalatā": ['cae', 'mw'],
    "śabalikā": ['mw'],
    "śabaliman": ['mw'],
    "śabalita": ['ddsa', 'mw'],
    "śabalodara": ['mw'],
    "śabalā": ['mw'],
    "śabalākṣa": ['mw'],
    "śabalāśva": ['mw'],
    "śabalī": ['ddsa', 'mw'],
    "śabalīhoma": ['mw'],
    "śabalīkṛta": ['mw'],
    "śabara": ['bhs', 'cae', 'ddsa', 'mw'],
    "śabarabhāṣya": ['mw'],
    "śabarajambu": ['mw'],
    "śabaraka": ['mw'],
    "śabarakanda": ['mw'],
    "śabaralodhra": ['mw'],
    "śabarasiṃha": ['mw'],
    "śabarasvāmin": ['mw'],
    "śabaraḥ": ['ap90'],
    "śabarikā": ['mw'],
    "śabarā": ['mw'],
    "śabarāhāra": ['mw'],
    "śabarāla": ['mw'],
    "śabarālaya": ['mw'],
    "śabarī": ['bhs', 'mw'],
    "śabarībhū": ['mw'],
    "śabd": ['ap90', 'mw'],
    "śabda": ['bhs', 'cae', 'ddsa', 'mw'],
    "śabdabheda": ['mw'],
    "śabdabhedanirdeśa": ['mw'],
    "śabdabhedanirūpaṇa": ['mw'],
    "śabdabhedaprakāśa": ['mw'],
    "śabdabhedin": ['mw'],
    "śabdabhid": ['mw'],
    "śabdabhāj": ['cae', 'mw'],
    "śabdabhūṣaṇa": ['mw'],
    "śabdabhṛt": ['mw'],
    "śabdabodha": ['mw'],
    "śabdabodhaprakriyā": ['mw'],
    "śabdabodhaprakāra": ['mw'],
    "śabdabodhavicāra": ['mw'],
    "śabdabrahmamaya": ['mw'],
    "śabdabrahman": ['cae', 'mw'],
    "śabdabāṇāgravedhin": ['mw'],
    "śabdabṛhatī": ['mw'],
    "śabdacandrikā": ['mw'],
    "śabdacintāmaṇi": ['mw'],
    "śabdacintāmaṇivṛtti": ['mw'],
    "śabdacitra": ['mw'],
    "śabdacora": ['mw'],
    "śabdacyuta": ['mw'],
    "śabdacāli": ['mw'],
    "śabdacālinṛtya": ['mw'],
    "śabdacāturya": ['mw'],
    "śabdadīpikā": ['mw'],
    "śabdaga": ['mw'],
    "śabdagata": ['mw'],
    "śabdagati": ['mw'],
    "śabdaghoṣā": ['mw'],
    "śabdagocara": ['mw'],
    "śabdagraha": ['mw'],
    "śabdagrāma": ['mw'],
    "śabdaguṇa": ['mw'],
    "śabdahīna": ['mw'],
    "śabdaja": ['mw'],
    "śabdaka": ['mw'],
    "śabdakalpa": ['mw'],
    "śabdakalpadru": ['mw'],
    "śabdakalpadruma": ['cae', 'mw'],
    "śabdakalpataru": ['mw'],
    "śabdakarmaka": ['cae', 'ddsa', 'mw'],
    "śabdakarman": ['cae', 'mw'],
    "śabdakaumudī": ['mw'],
    "śabdakaustubha": ['mw'],
    "śabdakaustubhadūṣaṇa": ['mw'],
    "śabdakhaṇḍa": ['mw'],
    "śabdakhaṇḍaprakāśa": ['mw'],
    "śabdakhaṇḍavyākhyā": ['mw'],
    "śabdakośa": ['mw'],
    "śabdakriya": ['mw'],
    "śabdakāra": ['mw'],
    "śabdakārin": ['mw'],
    "śabdalakṣaṇa": ['mw'],
    "śabdalakṣaṇarahasya": ['mw'],
    "śabdaliṅgārthacandrikā": ['mw'],
    "śabdamaya": ['cae', 'mw'],
    "śabdamañjarī": ['mw'],
    "śabdamaṇiparicchedāloka": ['mw'],
    "śabdamaṇivyākhyā": ['mw'],
    "śabdamuktāmahārṇava": ['mw'],
    "śabdamālikā": ['mw'],
    "śabdamālā": ['mw'],
    "śabdamātra": ['mw'],
    "śabdamīmāṃsā": ['mw'],
    "śabdamūla": ['mw'],
    "śabdana": ['ap90', 'mw'],
    "śabdanetṛ": ['mw'],
    "śabdanirūpaṇa": ['mw'],
    "śabdanirṇaya": ['mw'],
    "śabdanityatā": ['mw'],
    "śabdanityatāvicāra": ['mw'],
    "śabdanīya": ['mw'],
    "śabdanṛtya": ['mw'],
    "śabdapadamañjarī": ['mw'],
    "śabdapariccheda": ['mw'],
    "śabdaparicchedarahasya": ['mw'],
    "śabdaparicchedarahasyepūrvavādarahasya": ['mw'],
    "śabdapati": ['cae', 'mw'],
    "śabdaprabheda": ['mw'],
    "śabdaprabhedanāmamālā": ['mw'],
    "śabdaprakāśa": ['mw'],
    "śabdapramāṇa": ['mw'],
    "śabdaprāmāṇyakhaṇḍana": ['mw'],
    "śabdaprāmāṇyavāda": ['mw'],
    "śabdaprāś": ['mw'],
    "śabdapāta": ['mw'],
    "śabdapātam": ['mw'],
    "śabdapātin": ['mw'],
    "śabdapāṭha": ['mw'],
    "śabdarahasya": ['mw'],
    "śabdarahita": ['mw'],
    "śabdaratna": ['mw'],
    "śabdaratnamālā": ['mw'],
    "śabdaratnasamanvaya": ['mw'],
    "śabdaratnākara": ['mw'],
    "śabdaratnāvalī": ['mw'],
    "śabdarāśi": ['mw'],
    "śabdarāśimaheśvara": ['mw'],
    "śabdarūpa": ['ddsa', 'mw'],
    "śabdarūpaprakāśikā": ['mw'],
    "śabdarūpāvali": ['mw'],
    "śabdasadrūpasaṃgraha": ['mw'],
    "śabdasambhava": ['mw'],
    "śabdasaukarya": ['mw'],
    "śabdasauṣṭhava": ['mw'],
    "śabdasaṃcaya": ['mw'],
    "śabdasaṃdarbhasindhu": ['mw'],
    "śabdasaṃgrahanighaṇṭu": ['mw'],
    "śabdasaṃjña": ['mw'],
    "śabdasaṃjñā": ['mw'],
    "śabdasaṃkīrṇanirūpaṇa": ['mw'],
    "śabdasiddhi": ['mw'],
    "śabdasiddhinibandha": ['mw'],
    "śabdasiddhāntamañjarī": ['mw'],
    "śabdasmṛti": ['mw'],
    "śabdasparśarasa": ['mw'],
    "śabdasphoṭa": ['mw'],
    "śabdastomamahānidhi": ['mw'],
    "śabdasvātantryavāda": ['mw'],
    "śabdasādhana": ['mw'],
    "śabdasādhyaprayoga": ['mw'],
    "śabdasāgara": ['mw'],
    "śabdasāha": ['mw'],
    "śabdasāra": ['mw'],
    "śabdasāranighaṇṭu": ['mw'],
    "śabdatanmātra": ['mw'],
    "śabdataraṃga": ['mw'],
    "śabdataraṃgiṇī": ['mw'],
    "śabdatattvaprakāśa": ['mw'],
    "śabdatriveṇikā": ['mw'],
    "śabdatva": ['cae', 'mw'],
    "śabdatvajātipramāṇa": ['mw'],
    "śabdatāṇḍava": ['mw'],
    "śabdavailakṣaṇya": ['mw'],
    "śabdavajrā": ['mw'],
    "śabdavant": ['cae'],
    "śabdavat": ['mw'],
    "śabdavedha": ['bhs', 'cae', 'mw'],
    "śabdavedhin": ['mw'],
    "śabdavedhitva": ['bhs', 'mw'],
    "śabdavedhya": ['mw'],
    "śabdavidhi": ['mw'],
    "śabdavidyopādhyāya": ['mw'],
    "śabdavidyā": ['cae', 'mw'],
    "śabdavidyāśāstra": ['mw'],
    "śabdavirodha": ['mw'],
    "śabdaviśeṣa": ['mw'],
    "śabdaviśeṣaṇa": ['mw'],
    "śabdavyāpāravicāra": ['mw'],
    "śabdavādārtha": ['mw'],
    "śabdavāridhi": ['mw'],
    "śabdavṛtti": ['mw'],
    "śabday": ['cae'],
    "śabdaya": ['ddsa'],
    "śabdayoni": ['mw'],
    "śabdaśabdārthamañjūṣā": ['mw'],
    "śabdaśakti": ['mw'],
    "śabdaśaktiprabodhinī": ['mw'],
    "śabdaśaktiprakāśikā": ['mw'],
    "śabdaśeṣa": ['mw'],
    "śabdaśleṣa": ['mw'],
    "śabdaśobhā": ['mw'],
    "śabdaśuddhi": ['mw'],
    "śabdaśāsana": ['cae', 'mw'],
    "śabdaśāsanavid": ['mw'],
    "śabdaśāstra": ['cae', 'mw'],
    "śabdaḥ": ['ap90'],
    "śabdendriya": ['mw'],
    "śabdenduśekhara": ['mw'],
    "śabdenduśekharadoṣoddhāra": ['mw'],
    "śabdin": ['cae', 'mw'],
    "śabdita": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śabdodadhi": ['mw'],
    "śabdopātta": ['mw'],
    "śabdotpatti": ['mw'],
    "śabdābdhi": ['mw'],
    "śabdābdhitari": ['mw'],
    "śabdābhivaha": ['mw'],
    "śabdādhikāra": ['mw'],
    "śabdādhiṣṭhāna": ['mw'],
    "śabdādhyāhāra": ['mw'],
    "śabdādi": ['mw'],
    "śabdādidharmin": ['mw'],
    "śabdādimat": ['mw'],
    "śabdākara": ['mw'],
    "śabdākhyeya": ['ddsa', 'mw'],
    "śabdākṣara": ['mw'],
    "śabdāla": ['mw'],
    "śabdālaṃkāra": ['mw'],
    "śabdālaṃkāramañjarī": ['mw'],
    "śabdālaṃkāravicāra": ['mw'],
    "śabdāloka": ['mw'],
    "śabdālokarahasya": ['mw'],
    "śabdālokaviveka": ['mw'],
    "śabdālokoddyota": ['mw'],
    "śabdāmbhodhi": ['mw'],
    "śabdānantasāgarasamuccaya": ['mw'],
    "śabdānityatārahasya": ['mw'],
    "śabdāntarapāda": ['mw'],
    "śabdānukaraṇa": ['mw'],
    "śabdānukṛti": ['mw'],
    "śabdānurūpa": ['mw'],
    "śabdānusāra": ['mw'],
    "śabdānusāreṇa": ['mw'],
    "śabdānuviddhasamādhipañcaka": ['mw'],
    "śabdānuśiṣṭi": ['mw'],
    "śabdānuśāsana": ['mw'],
    "śabdānuśāsanadurgapadāvali": ['mw'],
    "śabdānuśāsanasūtrapāṭha": ['mw'],
    "śabdāpay": ['cae'],
    "śabdāpaya": ['ddsa'],
    "śabdāpayati": ['bhs'],
    "śabdāprāmāṇyarahasya": ['mw'],
    "śabdārtha": ['cae', 'mw'],
    "śabdārthacandrikoddhāra": ['mw'],
    "śabdārthacandrikā": ['mw'],
    "śabdārthacintāmaṇi": ['mw'],
    "śabdārthagarbhavat": ['mw'],
    "śabdārthakalpataru": ['mw'],
    "śabdārthamañjarī": ['mw'],
    "śabdārthanirvacana": ['mw'],
    "śabdārthanirvacanakhaṇḍana": ['mw'],
    "śabdārtharahasya": ['mw'],
    "śabdārtharatna": ['mw'],
    "śabdārtharatnākara": ['mw'],
    "śabdārtharatnāvalī": ['mw'],
    "śabdārthasaṃdīpikā": ['mw'],
    "śabdārthasāramañjarī": ['mw'],
    "śabdārthatarkāmṛta": ['mw'],
    "śabdārthārambhaṇa": ['mw'],
    "śabdārṇava": ['ddsa', 'mw'],
    "śabdārṇavacandrikā": ['mw'],
    "śabdārṇavasudhānidhi": ['mw'],
    "śabdārṇavavācaspati": ['mw'],
    "śabdārṇavābhidhāna": ['mw'],
    "śabdātīta": ['mw'],
    "śabdāvali": ['mw'],
    "śabdāvaloka": ['mw'],
    "śabdāy": ['cae'],
    "śabdāya": ['ddsa', 'mw'],
    "śabdāyate": ['ap90'],
    "śabdāḍambara": ['mw'],
    "śabdīsaka": ['bhs'],
    "śabheda": ['mw'],
    "śac": ['ap90', 'gra', 'mw'],
    "śaci": ['mw'],
    "śacikā": ['mw'],
    "śaciḥ": ['ap90'],
    "śaciṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "śacoka": ['mw'],
    "śacī": ['cae', 'ddsa', 'gra', 'mw'],
    "śacībala": ['mw'],
    "śacīnandana": ['mw'],
    "śacīnara": ['mw'],
    "śacīpati": ['cae', 'gra', 'mw'],
    "śacīpuraṃdara": ['mw'],
    "śacīramaṇa": ['mw'],
    "śacītīrtha": ['cae', 'mw'],
    "śacīvant": ['cae'],
    "śacīvasu": ['cae', 'gra', 'mw'],
    "śacīvat": ['gra', 'mw'],
    "śacīśa": ['mw'],
    "śad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śada": ['bhs', 'cae', 'ddsa', 'mw'],
    "śadaka": ['mw'],
    "śadaḥ": ['ap90'],
    "śadri": ['mw'],
    "śadriḥ": ['ap90'],
    "śadru": ['ap90', 'mw'],
    "śadvalā": ['cae', 'mw'],
    "śagma": ['cae', 'ddsa', 'gra', 'mw'],
    "śagman": ['mw'],
    "śagmia": ['gra'],
    "śagmya": ['gra', 'mw'],
    "śahendravarṇanavilāsa": ['mw'],
    "śai": ['mw'],
    "śaiba": ['mw'],
    "śaibala": ['cae', 'mw'],
    "śaibika": ['mw'],
    "śaibya": ['ap90', 'cae', 'ddsa', 'mw'],
    "śaibyā": ['mw'],
    "śaibāla": ['cae'],
    "śaibī": ['mw'],
    "śaighra": ['cae', 'ddsa', 'mw'],
    "śaighrya": ['cae', 'mw'],
    "śaighryaṃ": ['ap90'],
    "śaigrava": ['mw'],
    "śaikayatāyani": ['mw'],
    "śaikha": ['cae', 'ddsa', 'mw'],
    "śaikhareya": ['mw'],
    "śaikharika": ['mw'],
    "śaikharikaḥ": ['ap90'],
    "śaikhaṇḍa": ['mw'],
    "śaikhaṇḍi": ['mw'],
    "śaikhaṇḍina": ['mw'],
    "śaikhina": ['cae', 'ddsa', 'mw'],
    "śaikhya": ['ap90', 'mw'],
    "śaikhāvata": ['mw'],
    "śaikhāvatya": ['mw'],
    "śaikhāyani": ['mw'],
    "śaiki": ['mw'],
    "śaikya": ['ap90', 'cae', 'mw'],
    "śaikyāyasa": ['cae', 'mw'],
    "śaikyāyasamaya": ['cae', 'mw'],
    "śaikṣa": ['bhs', 'cae', 'ddsa', 'mw'],
    "śaikṣaka": ['bhs'],
    "śaikṣaḥ": ['ap90'],
    "śaikṣika": ['mw'],
    "śaikṣikaḥ": ['ap90'],
    "śaikṣita": ['mw'],
    "śaikṣya": ['mw'],
    "śaikṣyaguṇakrama": ['mw'],
    "śaikṣyaṃ": ['ap90'],
    "śaila": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śailabheda": ['mw'],
    "śailabhitti": ['mw'],
    "śailabāhu": ['bhs', 'mw'],
    "śailabīja": ['mw'],
    "śailadhanvan": ['mw'],
    "śailadhara": ['mw'],
    "śailadhātu": ['mw'],
    "śailadhātuja": ['mw'],
    "śailaduhitṛ": ['cae', 'mw'],
    "śailagandha": ['mw'],
    "śailagarbhāhvā": ['mw'],
    "śailaguru": ['cae', 'mw'],
    "śailagāthā": ['bhs', 'mw'],
    "śailaja": ['cae', 'mw'],
    "śailajana": ['mw'],
    "śailajā": ['mw'],
    "śailajāmantrin": ['mw'],
    "śailajātā": ['mw'],
    "śailaka": ['mw'],
    "śailakampin": ['cae', 'mw'],
    "śailakanyā": ['cae', 'mw'],
    "śailakaṃ": ['ap90'],
    "śailakaṭaka": ['mw'],
    "śailakuñja": ['mw'],
    "śailakūṭa": ['cae', 'mw'],
    "śailamallī": ['mw'],
    "śailamaya": ['cae', 'mw'],
    "śailamūla": ['mw'],
    "śailamṛga": ['cae', 'mw'],
    "śailaniryāsa": ['mw'],
    "śailapatha": ['mw'],
    "śailapati": ['mw'],
    "śailapattra": ['mw'],
    "śailaprastha": ['cae', 'mw'],
    "śailapratimā": ['cae', 'mw'],
    "śailapura": ['cae', 'mw'],
    "śailaputrī": ['cae', 'mw'],
    "śailapuṣpa": ['mw'],
    "śailapūrṇārya": ['mw'],
    "śailarandhra": ['mw'],
    "śailarugṇa": ['mw'],
    "śailarāj": ['cae', 'mw'],
    "śailarāja": ['cae', 'mw'],
    "śailarājaduhitṛ": ['mw'],
    "śailarājaketu": ['bhs'],
    "śailarājasutā": ['mw'],
    "śailasambhava": ['mw'],
    "śailasambhūta": ['mw'],
    "śailasarvajña": ['mw'],
    "śailasaṃdhi": ['mw'],
    "śailasetu": ['mw'],
    "śailasutā": ['cae', 'mw'],
    "śailasutācaraṇarāgayoni": ['mw'],
    "śailasutākānta": ['mw'],
    "śailasutāpati": ['mw'],
    "śailasāra": ['cae', 'mw'],
    "śailatanayā": ['cae', 'mw'],
    "śailatanayātāta": ['mw'],
    "śailatas": ['mw'],
    "śailatva": ['mw'],
    "śailatā": ['mw'],
    "śailavalkalā": ['mw'],
    "śailavanopapanna": ['mw'],
    "śailavara": ['mw'],
    "śailavālukā": ['mw'],
    "śailavāsa": ['mw'],
    "śailayatha": ['mw'],
    "śailaśekhara": ['mw'],
    "śailaśibira": ['mw'],
    "śailaśikhara": ['cae', 'mw'],
    "śailaśikharābhyudgatateja": ['bhs'],
    "śailaśikhā": ['mw'],
    "śailaśṛṅga": ['mw'],
    "śailendra": ['cae', 'ddsa', 'mw'],
    "śailendraduhitṛ": ['mw'],
    "śailendrajā": ['mw'],
    "śailendrarāja": ['bhs'],
    "śailendrarājasaṃghaṭṭanaghoṣa": ['bhs'],
    "śailendrastha": ['mw'],
    "śailendrasutā": ['mw'],
    "śailendraśrīgarbharāja": ['bhs'],
    "śaileya": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śaileyagandhi": ['mw'],
    "śaileyaka": ['mw'],
    "śaileyika": ['mw'],
    "śaileyī": ['mw'],
    "śaileśa": ['mw'],
    "śaileśaliṅga": ['mw'],
    "śaileścaya": ['mw'],
    "śaileśyavasthā": ['mw'],
    "śailika": ['mw'],
    "śailikya": ['mw'],
    "śailikyaḥ": ['ap90'],
    "śailina": ['cae', 'mw'],
    "śailini": ['cae', 'mw'],
    "śailodaka": ['bhs'],
    "śailodbhavā": ['mw'],
    "śailodā": ['mw'],
    "śailya": ['ap90', 'mw'],
    "śailā": ['bhs', 'mw'],
    "śailābha": ['mw'],
    "śailāda": ['mw'],
    "śailādhipa": ['mw'],
    "śailādhirāja": ['cae', 'mw'],
    "śailādhirājatanayā": ['mw'],
    "śailādhārā": ['mw'],
    "śailādi": ['mw'],
    "śailādiḥ": ['ap90'],
    "śailāgra": ['cae', 'ddsa', 'mw'],
    "śailāhva": ['mw'],
    "śailāja": ['mw'],
    "śailākhya": ['mw'],
    "śailāla": ['mw'],
    "śailālaya": ['mw'],
    "śailāli": ['cae', 'ddsa', 'mw'],
    "śailālibrāhmana": ['mw'],
    "śailālin": ['ap90', 'mw'],
    "śailāliyuvan": ['mw'],
    "śailāsana": ['mw'],
    "śailāsanodbhava": ['mw'],
    "śailāsā": ['mw'],
    "śailāvatya": ['mw'],
    "śailāṃśa": ['mw'],
    "śailāṃśadeśa": ['mw'],
    "śailāṅga": ['mw'],
    "śailāṅgadeśa": ['mw'],
    "śailāṭa": ['mw'],
    "śailī": ['ap90', 'cae', 'ddsa', 'mw'],
    "śailījñāpaka": ['mw'],
    "śailīka": ['bhs'],
    "śailūta": ['mw'],
    "śailūṣa": ['cae', 'ddsa', 'mw'],
    "śailūṣaka": ['mw'],
    "śailūṣaḥ": ['ap90'],
    "śailūṣi": ['mw'],
    "śailūṣika": ['mw'],
    "śailūṣikaḥ": ['ap90'],
    "śailūṣī": ['mw'],
    "śaimbya": ['mw'],
    "śaineya": ['cae', 'mw'],
    "śaineyaḥ": ['ap90'],
    "śainya": ['mw'],
    "śainyāḥ": ['ap90'],
    "śaipatha": ['mw'],
    "śaiphālika": ['mw'],
    "śairasa": ['mw'],
    "śairasi": ['mw'],
    "śaireyaka": ['mw'],
    "śairika": ['mw'],
    "śairin": ['mw'],
    "śairīyaka": ['mw'],
    "śairīṣa": ['mw'],
    "śairīṣaka": ['bhs', 'mw'],
    "śairīṣi": ['mw'],
    "śairīṣika": ['mw'],
    "śairṣacchedika": ['mw'],
    "śairṣaghātya": ['mw'],
    "śairṣika": ['mw'],
    "śairṣya": ['mw'],
    "śairṣāyaṇa": ['mw'],
    "śaisīka": ['mw'],
    "śaisīta": ['mw'],
    "śaithilika": ['bhs', 'mw'],
    "śaithilya": ['cae', 'ddsa', 'mw'],
    "śaithilyaṃ": ['ap90'],
    "śaitibāheya": ['mw'],
    "śaitikakṣa": ['mw'],
    "śaitoṣma": ['mw'],
    "śaitoṣman": ['mw'],
    "śaitya": ['cae', 'ddsa', 'mw'],
    "śaityamaya": ['mw'],
    "śaityamayatva": ['mw'],
    "śaityaṃ": ['ap90'],
    "śaityāyana": ['mw'],
    "śaiva": ['ap90', 'cae', 'ddsa', 'mw'],
    "śaivabhāṣya": ['mw'],
    "śaivadarśana": ['mw'],
    "śaivadharmamaṇḍana": ['mw'],
    "śaivagava": ['mw'],
    "śaivakalpadruma": ['mw'],
    "śaivala": ['bhs', 'cae', 'ddsa', 'mw'],
    "śaivalavant": ['cae'],
    "śaivalavat": ['mw'],
    "śaivalaḥ": ['ap90'],
    "śaivalin": ['cae', 'ddsa', 'mw'],
    "śaivalinī": ['ap90', 'mw'],
    "śaivalita": ['mw'],
    "śaivalya": ['cae', 'mw'],
    "śaivanagara": ['mw'],
    "śaivanavadaśaprakaraṇa": ['mw'],
    "śaivaparibhāṣā": ['mw'],
    "śaivapañcaka": ['mw'],
    "śaivapura": ['mw'],
    "śaivapurāṇa": ['mw'],
    "śaivapāśupata": ['mw'],
    "śaivapūjāvidhāna": ['mw'],
    "śaivarūpya": ['mw'],
    "śaivasarvasva": ['mw'],
    "śaivasarvasvasāra": ['mw'],
    "śaivasiddhāntadīpikā": ['mw'],
    "śaivasiddhāntasaṃgraha": ['mw'],
    "śaivasiddhāntasāra": ['mw'],
    "śaivasiddhāntasārāvalī": ['mw'],
    "śaivasiddhāntaśekhara": ['mw'],
    "śaivatantra": ['mw'],
    "śaivatattvaprakāśa": ['mw'],
    "śaivatattvāmṛta": ['mw'],
    "śaivatā": ['mw'],
    "śaivatātparyasaṃgraha": ['mw'],
    "śaivavaiṣṇava": ['mw'],
    "śaivavaiṣṇavamatamaṇḍana": ['mw'],
    "śaivavaiṣṇavapratiṣṭhāprayoga": ['mw'],
    "śaivavaiṣṇavavāda": ['mw'],
    "śaivavaiṣṇavavādārtha": ['mw'],
    "śaivavāyavīyapurāṇa": ['mw'],
    "śaivaśāstra": ['mw'],
    "śaivi": ['mw'],
    "śaivya": ['cae', 'mw'],
    "śaivyaḥ": ['ap90'],
    "śaivāgama": ['mw'],
    "śaivāhnika": ['mw'],
    "śaivākavi": ['mw'],
    "śaivāla": ['ap90', 'cae', 'ddsa', 'mw'],
    "śaivālaka": ['mw'],
    "śaivālavajra": ['mw'],
    "śaivālin": ['mw'],
    "śaivālina": ['mw'],
    "śaivālīya": ['mw'],
    "śaivāyana": ['mw'],
    "śaivāṣṭaka": ['mw'],
    "śaivī": ['mw'],
    "śaiyyā": ['bhs'],
    "śaiśava": ['cae', 'ddsa', 'mw'],
    "śaiśavayauvanīya": ['mw'],
    "śaiśavaṃ": ['ap90'],
    "śaiśavya": ['mw'],
    "śaiśika": ['mw'],
    "śaiśira": ['ap90', 'cae', 'ddsa', 'mw'],
    "śaiśiraśākhā": ['mw'],
    "śaiśireya": ['mw'],
    "śaiśiri": ['mw'],
    "śaiśirika": ['mw'],
    "śaiśirāstra": ['mw'],
    "śaiśirāyaṇa": ['mw'],
    "śaiśirīya": ['mw'],
    "śaiśirīyaka": ['mw'],
    "śaiśirīyaśākhā": ['mw'],
    "śaiśnya": ['mw'],
    "śaiśumāra": ['mw'],
    "śaiśunāga": ['mw'],
    "śaiśunāli": ['mw'],
    "śaiśunāri": ['ddsa', 'mw'],
    "śaiśupāla": ['mw'],
    "śaiśupāli": ['mw'],
    "śaiṣa": ['mw'],
    "śaiṣika": ['mw'],
    "śaiṣikī": ['mw'],
    "śaiṣiri": ['mw'],
    "śaiṣya": ['bhs'],
    "śaiṣyopādhyāyikā": ['ap90', 'mw'],
    "śak": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śaka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śakabali": ['mw'],
    "śakabhūpakāla": ['mw'],
    "śakaca": ['ddsa', 'mw'],
    "śakacella": ['mw'],
    "śakadeśa": ['mw'],
    "śakadhūma": ['cae', 'mw'],
    "śakadhūmaja": ['mw'],
    "śakadhūmajā": ['mw'],
    "śakahū": ['mw'],
    "śakaidha": ['cae', 'mw'],
    "śakakartṛ": ['mw'],
    "śakakāla": ['cae', 'mw'],
    "śakakāraka": ['mw'],
    "śakakārakotpatti": ['mw'],
    "śakakṛt": ['mw'],
    "śakala": ['cae', 'ddsa', 'mw'],
    "śakalajyotis": ['mw'],
    "śakalavat": ['mw'],
    "śakalay": ['cae'],
    "śakalaya": ['ddsa', 'mw'],
    "śakalaḥ": ['ap90'],
    "śakalendu": ['mw'],
    "śakalika": ['bhs'],
    "śakalin": ['ap90', 'mw'],
    "śakalita": ['ap90', 'mw'],
    "śakaloṭa": ['mw'],
    "śakalyeṣin": ['mw'],
    "śakalā": ['bhs'],
    "śakalākṛ": ['mw'],
    "śakalāṅguṣṭhaka": ['mw'],
    "śakalī": ['mw'],
    "śakalībhū": ['mw'],
    "śakalībhūta": ['mw'],
    "śakalīkaraṇa": ['mw'],
    "śakalīkṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "śakalīkṛta": ['mw'],
    "śakalīkṛti": ['mw'],
    "śakam": ['mw'],
    "śakamaya": ['cae', 'gra', 'mw'],
    "śakambhara": ['mw'],
    "śakambharā": ['ddsa'],
    "śakan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śakandhu": ['mw'],
    "śakanṛpatisaṃvatsara": ['mw'],
    "śakanṛpāla": ['mw'],
    "śakapiṇḍa": ['cae', 'mw'],
    "śakapuruṣavivaraṇa": ['mw'],
    "śakapūta": ['gra', 'mw'],
    "śakapūṇa": ['mw'],
    "śakara": ['cae', 'mw'],
    "śakasthāna": ['mw'],
    "śakatāsurabhañjana": ['mw'],
    "śakava": ['mw'],
    "śakavarman": ['mw'],
    "śakavarṇa": ['mw'],
    "śakavarṣa": ['mw'],
    "śakavatsara": ['ddsa', 'mw'],
    "śakavṛddhi": ['mw'],
    "śakaśakāya": ['mw'],
    "śakaḥ": ['ap90'],
    "śakaṃbhara": ['cae'],
    "śakaṃdhi": ['mw'],
    "śakaṭa": ['cae', 'ddsa', 'mw'],
    "śakaṭabheda": ['mw'],
    "śakaṭabhid": ['mw'],
    "śakaṭadāsa": ['mw'],
    "śakaṭahan": ['mw'],
    "śakaṭamantra": ['mw'],
    "śakaṭamukha": ['bhs'],
    "śakaṭanīḍa": ['mw'],
    "śakaṭasārtha": ['cae', 'mw'],
    "śakaṭavila": ['mw'],
    "śakaṭavrata": ['mw'],
    "śakaṭavyūha": ['mw'],
    "śakaṭaḥ": ['ap90'],
    "śakaṭi": ['mw'],
    "śakaṭika": ['mw'],
    "śakaṭikā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śakaṭin": ['cae', 'mw'],
    "śakaṭoccāṭana": ['mw'],
    "śakaṭyā": ['mw'],
    "śakaṭāhvā": ['mw'],
    "śakaṭākṣa": ['mw'],
    "śakaṭāla": ['mw'],
    "śakaṭāpaṇa": ['mw'],
    "śakaṭāra": ['ddsa', 'mw'],
    "śakaṭāri": ['mw'],
    "śakaṭāropākhyāna": ['mw'],
    "śakaṭāvila": ['ddsa', 'mw'],
    "śakaṭāya": ['mw'],
    "śakaṭāṅgaja": ['mw'],
    "śakaṭī": ['gra', 'mw'],
    "śakaṭīkarṇa": ['mw'],
    "śakaṭīmukha": ['mw'],
    "śakaṭīyaśabara": ['mw'],
    "śakaṭīśakaṭa": ['mw'],
    "śakendrakāla": ['mw'],
    "śakeṭaka": ['bhs'],
    "śakita": ['mw'],
    "śakkara": ['mw'],
    "śakkaraḥ": ['ap90'],
    "śakkari": ['mw'],
    "śakkarī": ['ap90'],
    "śakkita": ['bhs'],
    "śakkuli": ['mw'],
    "śakla": ['mw'],
    "śaklīkaraṇa": ['mw'],
    "śakman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śakna": ['ap90', 'mw'],
    "śaknu": ['mw'],
    "śaknuvāna": ['mw'],
    "śakra": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śakrabhakṣa": ['cae', 'mw'],
    "śakrabhakṣabhakṣaka": ['mw'],
    "śakrabhakṣamakha": ['mw'],
    "śakrabhakṣamakhotsava": ['mw'],
    "śakrabhavana": ['mw'],
    "śakrabhid": ['mw'],
    "śakrabhuvana": ['mw'],
    "śakrabhānu": ['bhs'],
    "śakrabhūbhavā": ['mw'],
    "śakrabhūruha": ['mw'],
    "śakrabāṇāsana": ['mw'],
    "śakrabīja": ['mw'],
    "śakracāpa": ['mw'],
    "śakracāpasamudbhavā": ['mw'],
    "śakracāpāya": ['mw'],
    "śakradaivata": ['mw'],
    "śakradantin": ['mw'],
    "śakradeva": ['mw'],
    "śakradevatā": ['mw'],
    "śakradhanus": ['mw'],
    "śakradhvaja": ['mw'],
    "śakradhvajataru": ['mw'],
    "śakradhvajotsava": ['mw'],
    "śakradiś": ['cae', 'mw'],
    "śakradruma": ['mw'],
    "śakragopa": ['mw'],
    "śakragopaka": ['mw'],
    "śakraja": ['mw'],
    "śakrajanitrī": ['mw'],
    "śakrajit": ['mw'],
    "śakrajāla": ['mw'],
    "śakrajānu": ['mw'],
    "śakrajāta": ['mw'],
    "śakrakaṣṭhā": ['mw'],
    "śakraketu": ['mw'],
    "śakrakrīḍācala": ['mw'],
    "śakrakumārikā": ['mw'],
    "śakrakumārī": ['mw'],
    "śakrakārmuka": ['mw'],
    "śakraloka": ['cae', 'mw'],
    "śakralokabhāj": ['mw'],
    "śakramātṛ": ['mw'],
    "śakramātṛkā": ['mw'],
    "śakramūrdhan": ['mw'],
    "śakranandana": ['mw'],
    "śakraparyāya": ['mw'],
    "śakraprastha": ['cae', 'mw'],
    "śakrapraśna": ['bhs'],
    "śakrapura": ['mw'],
    "śakrapurī": ['mw'],
    "śakrapuṣpikā": ['mw'],
    "śakrapuṣpī": ['mw'],
    "śakrapāda": ['mw'],
    "śakrapādapa": ['mw'],
    "śakrapāta": ['mw'],
    "śakrarūpa": ['mw'],
    "śakrasadas": ['mw'],
    "śakrastuti": ['mw'],
    "śakrasudhā": ['mw'],
    "śakrasuta": ['mw'],
    "śakrasārathi": ['mw'],
    "śakrasṛṣṭā": ['mw'],
    "śakrataru": ['mw'],
    "śakratejas": ['cae', 'mw'],
    "śakratva": ['mw'],
    "śakravallī": ['mw'],
    "śakravāhana": ['mw'],
    "śakravāpin": ['mw'],
    "śakravṛkṣa": ['mw'],
    "śakrayava": ['mw'],
    "śakrayaśovidhvaṃsana": ['mw'],
    "śakraśarāsana": ['mw'],
    "śakraśarāsanāya": ['mw'],
    "śakraśiras": ['mw'],
    "śakraśākhin": ['mw'],
    "śakraśālā": ['mw'],
    "śakraḥ": ['ap90'],
    "śakreśvaratīrtha": ['mw'],
    "śakri": ['mw'],
    "śakriḥ": ['ap90'],
    "śakrotsava": ['mw'],
    "śakrotthāna": ['mw'],
    "śakrotthānotsava": ['mw'],
    "śakru": ['mw'],
    "śakrābhilagna": ['bhs'],
    "śakrābhilagnaratna": ['mw'],
    "śakrādana": ['mw'],
    "śakrāditya": ['mw'],
    "śakrāgni": ['mw'],
    "śakrāhva": ['mw'],
    "śakrākhya": ['mw'],
    "śakrānalākhya": ['mw'],
    "śakrāri": ['mw'],
    "śakrāsana": ['cae', 'mw'],
    "śakrātmaja": ['mw'],
    "śakrāvarta": ['mw'],
    "śakrāvatāra": ['cae'],
    "śakrāvatāratīrtha": ['mw'],
    "śakrāyudha": ['cae', 'ddsa', 'mw'],
    "śakrāśana": ['cae', 'mw'],
    "śakrāśanakānana": ['mw'],
    "śakrāśanavipina": ['mw'],
    "śakrāśanavāṭikā": ['mw'],
    "śakrāṇī": ['ap90', 'mw'],
    "śakta": ['ap90', 'cae', 'ddsa', 'mw'],
    "śakti": ['cae', 'ddsa', 'gra', 'mw'],
    "śaktibhadra": ['mw'],
    "śaktibhairavatantra": ['mw'],
    "śaktibheda": ['mw'],
    "śaktibhṛt": ['mw'],
    "śaktibodha": ['mw'],
    "śaktidatta": ['mw'],
    "śaktideva": ['mw'],
    "śaktidhara": ['cae', 'mw'],
    "śaktidhvaja": ['mw'],
    "śaktidhṛk": ['mw'],
    "śaktidvayavant": ['cae'],
    "śaktidvayavat": ['mw'],
    "śaktidāsa": ['mw'],
    "śaktigaṇa": ['mw'],
    "śaktigraha": ['mw'],
    "śaktigrāhaka": ['mw'],
    "śaktihara": ['mw'],
    "śaktihasta": ['mw'],
    "śaktihetika": ['mw'],
    "śaktihīna": ['mw'],
    "śaktija": ['mw'],
    "śaktijña": ['cae', 'mw'],
    "śaktijāgara": ['mw'],
    "śaktijāmala": ['mw'],
    "śaktikara": ['cae', 'ddsa', 'mw'],
    "śaktikumāra": ['mw'],
    "śaktikumāraka": ['mw'],
    "śaktikumārī": ['mw'],
    "śaktikuṇṭhana": ['mw'],
    "śaktimant": ['cae'],
    "śaktimat": ['ap90', 'mw'],
    "śaktimattva": ['mw'],
    "śaktimatī": ['mw'],
    "śaktimaya": ['mw'],
    "śaktimokṣa": ['mw'],
    "śaktin": ['mw'],
    "śaktinalipi": ['bhs'],
    "śaktinyāsa": ['mw'],
    "śaktinātha": ['cae', 'mw'],
    "śaktiparṇa": ['mw'],
    "śaktiprakarṣa": ['mw'],
    "śaktiprakāśabodhinī": ['mw'],
    "śaktiputra": ['mw'],
    "śaktipāta": ['mw'],
    "śaktipāṇi": ['mw'],
    "śaktipūjaka": ['mw'],
    "śaktipūjā": ['mw'],
    "śaktipūrva": ['mw'],
    "śaktirakṣita": ['mw'],
    "śaktirakṣitaka": ['mw'],
    "śaktiratnākara": ['mw'],
    "śaktisaṃgamatantra": ['mw'],
    "śaktisaṃgamāmṛta": ['mw'],
    "śaktisena": ['mw'],
    "śaktisiddhānta": ['mw'],
    "śaktisiṃha": ['mw'],
    "śaktistotra": ['mw'],
    "śaktisvāmin": ['mw'],
    "śaktitantra": ['mw'],
    "śaktitas": ['ap90', 'cae', 'mw'],
    "śaktitraya": ['mw'],
    "śaktitva": ['mw'],
    "śaktitā": ['mw'],
    "śaktivaibhavika": ['mw'],
    "śaktivaikalya": ['mw'],
    "śaktivallabha": ['mw'],
    "śaktivanamāhātmya": ['mw'],
    "śaktivara": ['mw'],
    "śaktivega": ['mw'],
    "śaktivicāra": ['mw'],
    "śaktivijayastuti": ['mw'],
    "śaktivijayasvāmistotra": ['mw'],
    "śaktiviṣaya": ['mw'],
    "śaktivāda": ['mw'],
    "śaktivādakalikā": ['mw'],
    "śaktivādarahasya": ['mw'],
    "śaktivādavivaraṇa": ['mw'],
    "śaktivādaṭīkā": ['mw'],
    "śaktivādin": ['mw'],
    "śaktivādārthadīpikā": ['mw'],
    "śaktivīra": ['mw'],
    "śaktiyaśas": ['mw'],
    "śaktiyāmala": ['mw'],
    "śaktiśodhana": ['mw'],
    "śaktiśūla": ['bhs'],
    "śaktiḥ": ['ap90'],
    "śaktiṣṭha": ['mw'],
    "śaktri": ['mw'],
    "śaktrin": ['mw'],
    "śaktu": ['ap90', 'mw'],
    "śaktuka": ['bhs', 'mw'],
    "śakty": ['mw'],
    "śaktyapekṣa": ['mw'],
    "śaktyardha": ['mw'],
    "śaktyavara": ['mw'],
    "śaktīvant": ['cae'],
    "śaktīvat": ['gra', 'mw'],
    "śaktṛ": ['cae'],
    "śakula": ['cae', 'ddsa', 'mw'],
    "śakulagaṇḍa": ['mw'],
    "śakulaḥ": ['ap90'],
    "śakulin": ['mw'],
    "śakulāda": ['mw'],
    "śakulādanī": ['mw'],
    "śakulākṣaka": ['mw'],
    "śakulākṣī": ['mw'],
    "śakulārbhaka": ['mw'],
    "śakulī": ['mw'],
    "śakuna": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śakunadevatā": ['mw'],
    "śakunadvāra": ['mw'],
    "śakunadīpaka": ['mw'],
    "śakunajña": ['cae', 'mw'],
    "śakunajñā": ['mw'],
    "śakunajñāna": ['cae', 'mw'],
    "śakunaka": ['mw'],
    "śakunaparīkṣā": ['mw'],
    "śakunapattra": ['mw'],
    "śakunapradīpa": ['mw'],
    "śakunaratnāvalī": ['mw'],
    "śakunarutajñāna": ['mw'],
    "śakunasāroddhāra": ['mw'],
    "śakunasūkta": ['mw'],
    "śakunavidyā": ['bhs', 'mw'],
    "śakunaśāstra": ['mw'],
    "śakunaḥ": ['ap90'],
    "śakunda": ['mw'],
    "śakuni": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śakunigraha": ['mw'],
    "śakunikā": ['cae', 'mw'],
    "śakunilubdhaka": ['cae'],
    "śakuniprapā": ['mw'],
    "śakunisavana": ['mw'],
    "śakunisāda": ['mw'],
    "śakunividyā": ['bhs'],
    "śakunivāda": ['mw'],
    "śakuniḥ": ['ap90'],
    "śakunopadeśa": ['mw'],
    "śakunta": ['cae', 'ddsa', 'mw'],
    "śakuntaka": ['cae', 'mw'],
    "śakuntalopākhyāna": ['mw'],
    "śakuntalā": ['cae', 'ddsa', 'mw'],
    "śakuntalātmaja": ['mw'],
    "śakunti": ['cae', 'ddsa', 'gra', 'mw'],
    "śakuntikā": ['gra', 'mw'],
    "śakunyupākhyāna": ['mw'],
    "śakunādhiṣṭhātrī": ['mw'],
    "śakunāhṛt": ['mw'],
    "śakunāhṛta": ['mw'],
    "śakunārṇava": ['mw'],
    "śakunāvalī": ['mw'],
    "śakunāśā": ['mw'],
    "śakunī": ['ap90', 'mw'],
    "śakunīśvara": ['mw'],
    "śakura": ['cae', 'ddsa', 'mw'],
    "śakuṃtakaḥ": ['ap90'],
    "śakuṃtalā": ['ap90'],
    "śakuṃtaḥ": ['ap90'],
    "śakuṃtikā": ['ap90'],
    "śakuṃtiḥ": ['ap90'],
    "śakuṭā": ['mw'],
    "śakvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śakvara": ['cae', 'ddsa', 'mw'],
    "śakvaraḥ": ['ap90'],
    "śakvarā": ['mw'],
    "śakvarī": ['ddsa', 'mw'],
    "śakvarīpṛṣṭha": ['mw'],
    "śakvarītva": ['mw'],
    "śakvaḥ": ['ap90'],
    "śakya": ['ap90', 'cae', 'ddsa', 'mw'],
    "śakyapratikāra": ['mw'],
    "śakyarūpa": ['mw'],
    "śakyasāmantatā": ['mw'],
    "śakyatama": ['mw'],
    "śakyatva": ['mw'],
    "śakyatā": ['mw'],
    "śakyatāvacchedaka": ['mw'],
    "śakyaśaṅka": ['mw'],
    "śakyā": ['bhs'],
    "śakā": ['mw'],
    "śakābda": ['mw'],
    "śakādhiparājadhānī": ['mw'],
    "śakāditya": ['mw'],
    "śakāntaka": ['mw'],
    "śakānīlipi": ['bhs'],
    "śakāra": ['cae', 'ddsa', 'mw'],
    "śakārabheda": ['mw'],
    "śakāraḥ": ['ap90'],
    "śakāri": ['mw'],
    "śakārilipi": ['mw'],
    "śakṛd": ['mw'],
    "śakṛdbheda": ['mw'],
    "śakṛddeśa": ['mw'],
    "śakṛddhata": ['mw'],
    "śakṛddvāra": ['mw'],
    "śakṛdgraha": ['mw'],
    "śakṛdrasa": ['mw'],
    "śakṛdrīti": ['mw'],
    "śakṛn": ['mw'],
    "śakṛnmūtra": ['mw'],
    "śakṛt": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śakṛtkari": ['mw'],
    "śakṛtkāra": ['mw'],
    "śakṛtkīṭa": ['mw'],
    "śakṛtpadī": ['mw'],
    "śakṛtpiṇḍa": ['cae', 'mw'],
    "śal": ['ap90', 'cae', 'ddsa', 'mw'],
    "śala": ['cae', 'ddsa', 'mw'],
    "śalabha": ['bhs', 'cae', 'ddsa', 'mw'],
    "śalabhatva": ['mw'],
    "śalabhatā": ['mw'],
    "śalabhaḥ": ['ap90'],
    "śalabhāstra": ['mw'],
    "śalabhāsura": ['mw'],
    "śalabhāya": ['ddsa', 'mw'],
    "śalabhī": ['mw'],
    "śaladā": ['mw'],
    "śalaka": ['mw'],
    "śalakara": ['cae', 'mw'],
    "śalakaḥ": ['ap90'],
    "śalakaṭaṅkata": ['mw'],
    "śalakā": ['mw'],
    "śalala": ['cae', 'ddsa', 'mw'],
    "śalalacañcu": ['mw'],
    "śalalaṃ": ['ap90'],
    "śalalita": ['cae', 'mw'],
    "śalalī": ['mw'],
    "śalalīpiśaṅga": ['mw'],
    "śalaputra": ['mw'],
    "śalati": ['bhs'],
    "śalaḥ": ['ap90'],
    "śalaṃgaḥ": ['ap90'],
    "śalaṅga": ['mw'],
    "śalaṅkaṭa": ['mw'],
    "śalaṅku": ['mw'],
    "śalbh": ['ap90', 'mw'],
    "śaliputra": ['mw'],
    "śalka": ['cae', 'ddsa', 'mw'],
    "śalkala": ['mw'],
    "śalkalin": ['ap90', 'ddsa', 'mw'],
    "śalkamaya": ['mw'],
    "śalkayuta": ['mw'],
    "śalkaṃ": ['ap90'],
    "śalkin": ['mw'],
    "śalkī": ['ddsa'],
    "śall": ['ap90'],
    "śalla": ['mw'],
    "śallaka": ['cae', 'ddsa', 'mw'],
    "śallakaḥ": ['ap90'],
    "śallaki": ['mw'],
    "śallakāṅgaja": ['mw'],
    "śallakī": ['ap90', 'mw'],
    "śallakīdrava": ['mw'],
    "śallakītvac": ['mw'],
    "śallakīya": ['mw'],
    "śallayati": ['bhs'],
    "śallaḥ": ['ap90'],
    "śallikā": ['mw'],
    "śallā": ['mw'],
    "śalmali": ['ddsa', 'gra', 'mw'],
    "śalmaliḥ": ['ap90'],
    "śalmalī": ['mw'],
    "śalpa": ['mw'],
    "śalpadā": ['mw'],
    "śalpaka": ['mw'],
    "śaluna": ['cae', 'mw'],
    "śalva": ['mw'],
    "śalvaḥ": ['ap90'],
    "śalya": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śalyabhūta": ['mw'],
    "śalyadā": ['mw'],
    "śalyahartṛ": ['mw'],
    "śalyahṛt": ['mw'],
    "śalyajñāna": ['mw'],
    "śalyaka": ['cae', 'ddsa', 'mw'],
    "śalyakartana": ['mw'],
    "śalyakarttṛ": ['cae', 'mw'],
    "śalyakartṛ": ['cae', 'mw'],
    "śalyakarṣaṇa": ['mw'],
    "śalyakavat": ['mw'],
    "śalyakaḥ": ['ap90'],
    "śalyakaṇṭha": ['mw'],
    "śalyakriyā": ['mw'],
    "śalyakīrtana": ['mw'],
    "śalyakṛnta": ['cae', 'mw'],
    "śalyaloman": ['mw'],
    "śalyaparvan": ['mw'],
    "śalyaparṇikā": ['mw'],
    "śalyaparṇī": ['mw'],
    "śalyaprota": ['mw'],
    "śalyapīḍita": ['mw'],
    "śalyasraṃsana": ['mw'],
    "śalyatantra": ['mw'],
    "śalyavant": ['cae'],
    "śalyavat": ['mw'],
    "śalyavāraṅga": ['mw'],
    "śalyaya": ['mw'],
    "śalyaśāstra": ['mw'],
    "śalyaṃ": ['ap90'],
    "śalyita": ['ap90'],
    "śalyoddharaṇa": ['mw'],
    "śalyoddhāra": ['mw'],
    "śalyoddhṛti": ['mw'],
    "śalyā": ['mw'],
    "śalyāharaṇavidhi": ['mw'],
    "śalyāhartar": ['bhs'],
    "śalyāpanayanīya": ['mw'],
    "śalyāri": ['mw'],
    "śalyātman": ['mw'],
    "śalyāya": ['mw'],
    "śalābholi": ['mw'],
    "śalābholiḥ": ['ap90'],
    "śalāhaka": ['mw'],
    "śalāka": ['cae', 'ddsa', 'mw'],
    "śalākadhūrta": ['mw'],
    "śalākalā": ['mw'],
    "śalākikā": ['cae', 'mw'],
    "śalākin": ['mw'],
    "śalākā": ['ap90', 'bhs', 'cae', 'mw'],
    "śalākābhrū": ['mw'],
    "śalākāpari": ['mw'],
    "śalākāpuruṣa": ['mw'],
    "śalākāstha": ['mw'],
    "śalākāvat": ['mw'],
    "śalākāvṛtti": ['bhs', 'mw'],
    "śalākāyantra": ['mw'],
    "śalākībhūta": ['bhs'],
    "śalālu": ['mw'],
    "śalāluglapsa": ['mw'],
    "śalālugrapsa": ['mw'],
    "śalāluka": ['mw'],
    "śalāluḥ": ['ap90'],
    "śalāthala": ['mw'],
    "śalātura": ['cae', 'ddsa', 'mw'],
    "śalāvat": ['mw'],
    "śalāṭa": ['mw'],
    "śalāṭaḥ": ['ap90'],
    "śalāṭu": ['ap90', 'cae', 'ddsa', 'mw'],
    "śalī": ['mw'],
    "śam": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śama": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śamagir": ['mw'],
    "śamaka": ['mw'],
    "śamakā": ['mw'],
    "śamakṛt": ['mw'],
    "śamala": ['cae', 'ddsa', 'mw'],
    "śamalagṛhīta": ['mw'],
    "śamalaṃ": ['ap90'],
    "śamana": ['ap90', 'cae', 'ddsa', 'mw'],
    "śamanavidhi": ['mw'],
    "śamanaśvasṛ": ['mw'],
    "śamantakastotra": ['mw'],
    "śamanī": ['ap90', 'mw'],
    "śamanīcameḍhra": ['mw'],
    "śamanīpāra": ['mw'],
    "śamanīya": ['mw'],
    "śamanīṣada": ['mw'],
    "śamapara": ['cae', 'mw'],
    "śamapradhāna": ['cae', 'mw'],
    "śamaprāpta": ['cae', 'mw'],
    "śamara": ['mw'],
    "śamaruci": ['bhs'],
    "śamasaukhya": ['mw'],
    "śamasetupradīpa": ['mw'],
    "śamastha": ['mw'],
    "śamasthalī": ['mw'],
    "śamasudhā": ['mw'],
    "śamasukha": ['mw'],
    "śamasāmantakam": ['bhs'],
    "śamatha": ['bhs', 'cae', 'mw'],
    "śamathaghoṣa": ['bhs'],
    "śamathaketu": ['bhs'],
    "śamathasambhāra": ['mw'],
    "śamathavipaśyanāvihārin": ['mw'],
    "śamathaḥ": ['ap90'],
    "śamavant": ['cae'],
    "śamavat": ['ddsa', 'mw'],
    "śamavihāra": ['mw'],
    "śamavyasanin": ['mw'],
    "śamayitṛ": ['cae', 'mw'],
    "śamayitṛkā": ['mw'],
    "śamaśama": ['cae', 'mw'],
    "śamaḥ": ['ap90'],
    "śamaṭha": ['mw'],
    "śamb": ['mw'],
    "śamba": ['cae', 'ddsa', 'gra', 'mw'],
    "śambala": ['cae', 'ddsa', 'mw'],
    "śambalī": ['mw'],
    "śambara": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śambaracandana": ['mw'],
    "śambaradāraṇa": ['cae', 'ddsa', 'mw'],
    "śambaraghna": ['cae', 'mw'],
    "śambarahan": ['cae', 'mw'],
    "śambarahatya": ['cae', 'gra', 'mw'],
    "śambarakanda": ['mw'],
    "śambararipu": ['mw'],
    "śambarasiddhi": ['cae', 'mw'],
    "śambarasūdana": ['mw'],
    "śambaravṛtrahan": ['cae', 'mw'],
    "śambaraṇa": ['ddsa', 'mw'],
    "śambarāntakara": ['mw'],
    "śambarāri": ['mw'],
    "śambarāsura": ['mw'],
    "śambarāsuravadhopākhyāna": ['mw'],
    "śambarī": ['mw'],
    "śambaṭ": ['mw'],
    "śambaṭī": ['mw'],
    "śambha": ['mw'],
    "śambhala": ['cae', 'ddsa', 'mw'],
    "śambhalagrāma": ['mw'],
    "śambhalagrāmamāhātmya": ['mw'],
    "śambhaleśvaraliṅga": ['mw'],
    "śambhalī": ['mw'],
    "śambhara": ['mw'],
    "śambhava": ['mw'],
    "śambhaviṣṭha": ['gra', 'mw'],
    "śambhu": ['ddsa', 'gra', 'mw'],
    "śambhubhairava": ['mw'],
    "śambhubhaṭṭīya": ['mw'],
    "śambhucandra": ['mw'],
    "śambhudeva": ['mw'],
    "śambhudāsa": ['mw'],
    "śambhugiri": ['mw'],
    "śambhugirimāhātmya": ['mw'],
    "śambhuhorāprakāśa": ['mw'],
    "śambhukāntā": ['mw'],
    "śambhumahādevakṣetramāhātmya": ['mw'],
    "śambhumayobhū": ['mw'],
    "śambhunandana": ['mw'],
    "śambhunityā": ['mw'],
    "śambhunātha": ['mw'],
    "śambhunātharasa": ['mw'],
    "śambhunāthārcana": ['mw'],
    "śambhupriyā": ['mw'],
    "śambhurahasya": ['mw'],
    "śambhurāja": ['mw'],
    "śambhurājacaritra": ['mw'],
    "śambhurāma": ['mw'],
    "śambhutanaya": ['mw'],
    "śambhutattvānusaṃdhāna": ['mw'],
    "śambhuvallabha": ['mw'],
    "śambhuvardhana": ['mw'],
    "śambhuvākyapalāśāṭīkā": ['mw'],
    "śambhuśikṣā": ['mw'],
    "śambhū": ['ddsa', 'gra', 'mw'],
    "śambhūnātha": ['mw'],
    "śambhūrājacaritra": ['mw'],
    "śambhūvartani": ['mw'],
    "śambin": ['cae', 'ddsa', 'mw'],
    "śambu": ['cae', 'ddsa', 'mw'],
    "śambuka": ['mw'],
    "śambukka": ['mw'],
    "śambuvardhana": ['mw'],
    "śambākṛ": ['cae', 'mw'],
    "śambākṛta": ['mw'],
    "śambū": ['mw'],
    "śambūka": ['cae', 'ddsa', 'mw'],
    "śambūkapuṣpī": ['mw'],
    "śambūkāvarta": ['mw'],
    "śambūputra": ['mw'],
    "śamepsu": ['mw'],
    "śami": ['cae', 'ddsa', 'mw'],
    "śamika": ['mw'],
    "śamin": ['ap90', 'cae', 'mw'],
    "śamira": ['mw'],
    "śamiraḥ": ['ap90'],
    "śamiroha": ['mw'],
    "śamita": ['ap90', 'ddsa', 'mw'],
    "śamitaruci": ['mw'],
    "śamitavya": ['mw'],
    "śamitaśatru": ['bhs'],
    "śamitā": ['mw'],
    "śamitāvin": ['bhs'],
    "śamitāyāma": ['mw'],
    "śamitṛ": ['cae', 'gra', 'mw'],
    "śamiā": ['gra'],
    "śamiṣṭha": ['cae', 'mw'],
    "śamiṣṭhala": ['mw'],
    "śammad": ['mw'],
    "śamopanyāsa": ['mw'],
    "śamopya": ['mw'],
    "śampaka": ['mw'],
    "śamphalī": ['mw'],
    "śampā": ['mw'],
    "śampāka": ['mw'],
    "śampāta": ['mw'],
    "śampātala": ['mw'],
    "śampātāla": ['ddsa'],
    "śamva": ['mw'],
    "śamvat": ['mw'],
    "śamya": ['bhs', 'mw'],
    "śamyoṣa": ['mw'],
    "śamyu": ['mw'],
    "śamyā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śamyāgarta": ['mw'],
    "śamyāgrāha": ['mw'],
    "śamyākṣepa": ['mw'],
    "śamyāmātra": ['mw'],
    "śamyānipāta": ['mw'],
    "śamyāparāsa": ['mw'],
    "śamyāparāsin": ['mw'],
    "śamyāparāvyādha": ['mw'],
    "śamyāprāsa": ['bhs', 'cae', 'mw'],
    "śamyāprāsana": ['mw'],
    "śamyāpāta": ['cae', 'mw'],
    "śamyātāla": ['ddsa', 'mw'],
    "śamā": ['mw'],
    "śamāgāsa": ['ddsa', 'mw'],
    "śamāha": ['mw'],
    "śamālā": ['ddsa', 'mw'],
    "śamāntaka": ['mw'],
    "śamānvita": ['mw'],
    "śamātmaka": ['cae', 'mw'],
    "śamāy": ['cae', 'gra'],
    "śamāya": ['ddsa', 'mw'],
    "śamāśraya": ['mw'],
    "śamāṅga": ['ddsa', 'mw'],
    "śamī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śamīdhānya": ['cae', 'mw'],
    "śamīdṛṣada": ['mw'],
    "śamīgarbha": ['cae', 'mw'],
    "śamījāta": ['mw'],
    "śamījāti": ['mw'],
    "śamīka": ['cae', 'mw'],
    "śamīkuṇa": ['mw'],
    "śamīlatā": ['mw'],
    "śamīlūna": ['mw'],
    "śamīmandāramāhātmya": ['mw'],
    "śamīmaya": ['cae', 'mw'],
    "śamīnahuṣī": ['gra'],
    "śamīnivātam": ['mw'],
    "śamīparṇa": ['cae', 'mw'],
    "śamīpattra": ['mw'],
    "śamīpattrī": ['mw'],
    "śamīphalā": ['mw'],
    "śamīprastha": ['mw'],
    "śamīpūjāvidhi": ['mw'],
    "śamīra": ['mw'],
    "śamīraḥ": ['ap90'],
    "śamīsumanas": ['cae'],
    "śamītaru": ['mw'],
    "śamīvat": ['mw'],
    "śamīvṛkṣa": ['mw'],
    "śamīśākhā": ['cae'],
    "śana": ['gra', 'mw'],
    "śanair": ['mw'],
    "śanairbhāva": ['ddsa', 'mw'],
    "śanairdehin": ['mw'],
    "śanairgaṅgam": ['mw'],
    "śanairmeha": ['mw'],
    "śanairmehin": ['mw'],
    "śanais": ['ap90', 'cae', 'ddsa', 'mw'],
    "śanaistarām": ['mw'],
    "śanaiś": ['mw'],
    "śanaiścara": ['cae', 'ddsa', 'mw'],
    "śanaiścarakavaca": ['mw'],
    "śanaiścarapūjā": ['mw'],
    "śanaiścarasaṃvatsara": ['mw'],
    "śanaiścaravidhāna": ['mw'],
    "śanaiścaravrata": ['mw'],
    "śanaiścaravāra": ['mw'],
    "śanaka": ['gra', 'mw'],
    "śanakais": ['ap90', 'cae', 'ddsa', 'mw'],
    "śanakaiścara": ['mw'],
    "śanakāvali": ['mw'],
    "śanakāvalī": ['mw'],
    "śanaparṇī": ['mw'],
    "śani": ['cae', 'ddsa', 'mw'],
    "śanicakra": ['mw'],
    "śanija": ['mw'],
    "śanipradoṣa": ['mw'],
    "śanipradoṣavrata": ['mw'],
    "śaniprasū": ['mw'],
    "śanipratimādana": ['mw'],
    "śanipriya": ['mw'],
    "śanistotra": ['mw'],
    "śanisūkta": ['mw'],
    "śanitrayodaśīvrata": ['mw'],
    "śanivāra": ['mw'],
    "śanivāsara": ['mw'],
    "śaniścara": ['bhs'],
    "śaniśānti": ['mw'],
    "śaniḥ": ['ap90'],
    "śanna": ['ap90', 'cae', 'ddsa', 'mw'],
    "śannamala": ['mw'],
    "śannodevī": ['ddsa'],
    "śanotsāha": ['mw'],
    "śanta": ['mw'],
    "śantama": ['cae', 'ddsa'],
    "śantanu": ['ddsa', 'mw'],
    "śantaśrī": ['bhs'],
    "śanti": ['mw'],
    "śantiva": ['cae', 'ddsa', 'mw'],
    "śantra": ['bhs'],
    "śantu": ['mw'],
    "śantva": ['cae'],
    "śantācī": ['mw'],
    "śantāti": ['cae', 'ddsa'],
    "śanyaṣṭaka": ['mw'],
    "śap": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śapa": ['mw'],
    "śapana": ['cae', 'mw'],
    "śapanatara": ['mw'],
    "śapanaṃ": ['ap90'],
    "śapatha": ['cae', 'ddsa', 'gra', 'mw'],
    "śapathajambhana": ['mw'],
    "śapathakaraṇa": ['mw'],
    "śapathapattra": ['mw'],
    "śapathapūrvakam": ['mw'],
    "śapathayopana": ['mw'],
    "śapathayāvana": ['mw'],
    "śapathaḥ": ['ap90'],
    "śapatheyya": ['mw'],
    "śapathia": ['gra'],
    "śapathottaram": ['mw'],
    "śapathya": ['cae', 'gra', 'mw'],
    "śapathīya": ['mw'],
    "śapaḥ": ['ap90'],
    "śapha": ['cae', 'ddsa', 'gra', 'mw'],
    "śaphacyuta": ['gra', 'mw'],
    "śaphagraha": ['mw'],
    "śaphara": ['cae', 'ddsa', 'mw'],
    "śaphararūpa": ['mw'],
    "śapharaḥ": ['ap90'],
    "śaphari": ['ddsa', 'mw'],
    "śapharuka": ['ddsa', 'mw'],
    "śapharādhipa": ['mw'],
    "śapharī": ['mw'],
    "śapharīya": ['mw'],
    "śaphavant": ['cae'],
    "śaphavat": ['ddsa', 'gra', 'mw'],
    "śaphaśas": ['mw'],
    "śaphaḥ": ['ap90'],
    "śaphoru": ['mw'],
    "śaphākṣa": ['mw'],
    "śaphāruj": ['gra', 'mw'],
    "śapita": ['mw'],
    "śapta": ['ap90', 'cae', 'ddsa', 'mw'],
    "śaptavat": ['mw'],
    "śaptṛ": ['cae', 'mw'],
    "śapva": ['mw'],
    "śapya": ['mw'],
    "śar": ['gra'],
    "śara": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śarabandha": ['cae', 'mw'],
    "śarabarhis": ['cae', 'mw'],
    "śarabha": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śarabhahṛdaya": ['mw'],
    "śarabhakalpatantra": ['mw'],
    "śarabhakavaca": ['mw'],
    "śarabhaketu": ['mw'],
    "śarabhalīla": ['mw'],
    "śarabhalīlākathā": ['mw'],
    "śarabhamantra": ['mw'],
    "śarabhamālāmantra": ['mw'],
    "śarabhapaddhati": ['mw'],
    "śarabhapakṣirājaprakaraṇa": ['mw'],
    "śarabharājavilāsa": ['mw'],
    "śarabhasahasranāman": ['mw'],
    "śarabhastotra": ['mw'],
    "śarabhatā": ['mw'],
    "śarabhavidhāna": ['mw'],
    "śarabhaḥ": ['ap90'],
    "śarabhaṅga": ['bhs', 'cae', 'ddsa', 'mw'],
    "śarabheda": ['ddsa', 'mw'],
    "śarabheśvarakavaca": ['mw'],
    "śarabhoji": ['mw'],
    "śarabhojirājacaritra": ['mw'],
    "śarabhopaniṣad": ['mw'],
    "śarabhā": ['mw'],
    "śarabhānanā": ['ddsa', 'mw'],
    "śarabhārcanacandrikā": ['mw'],
    "śarabhārcanapaddhati": ['mw'],
    "śarabhārcāpārijāta": ['mw'],
    "śarabhāṣṭaka": ['mw'],
    "śarabhū": ['mw'],
    "śarabhṛṣṭi": ['cae', 'mw'],
    "śarac": ['mw'],
    "śaraccandra": ['cae', 'ddsa', 'mw'],
    "śaraccandrikā": ['mw'],
    "śaraccandrāya": ['mw'],
    "śaracchaśadhara": ['mw'],
    "śaracchaśin": ['mw'],
    "śaracchikhin": ['mw'],
    "śaracchrī": ['mw'],
    "śaracchāli": ['mw'],
    "śarad": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śarada": ['mw'],
    "śaradakṣa": ['mw'],
    "śaradambudhara": ['ddsa', 'mw'],
    "śaradanta": ['mw'],
    "śaradaṇḍa": ['cae', 'mw'],
    "śaradaṇḍā": ['mw'],
    "śaraddhimaruci": ['mw'],
    "śaraddhrada": ['mw'],
    "śaradeva": ['mw'],
    "śaradgata": ['mw'],
    "śaradghana": ['ddsa', 'mw'],
    "śaradharā": ['bhs'],
    "śaradhi": ['cae', 'ddsa', 'mw'],
    "śaradhāna": ['mw'],
    "śaradija": ['ap90', 'cae', 'ddsa', 'mw'],
    "śaradudāśaya": ['mw'],
    "śaradurdina": ['mw'],
    "śaradvadhū": ['cae', 'mw'],
    "śaradvant": ['cae'],
    "śaradvarṇana": ['mw'],
    "śaradvasu": ['mw'],
    "śaradvat": ['gra', 'mw'],
    "śaradvihāra": ['mw'],
    "śaradvīpa": ['mw'],
    "śaradyāminī": ['mw'],
    "śaradā": ['ap90', 'ddsa', 'mw'],
    "śaradāgama": ['mw'],
    "śaradānavarātrapūjā": ['mw'],
    "śaradātilaka": ['mw'],
    "śaradṛtuvarṇana": ['mw'],
    "śaraghāta": ['mw'],
    "śaragocara": ['cae', 'mw'],
    "śaragulma": ['cae', 'mw'],
    "śaraiṣīkā": ['mw'],
    "śaraj": ['mw'],
    "śaraja": ['mw'],
    "śarajanman": ['cae', 'ddsa', 'mw'],
    "śarajjyotsnā": ['cae', 'ddsa', 'mw'],
    "śarajāla": ['cae', 'mw'],
    "śarajālaka": ['mw'],
    "śarajālamaya": ['mw'],
    "śaraka": ['mw'],
    "śaraketu": ['ddsa', 'mw'],
    "śarakuṇḍeśaya": ['mw'],
    "śarakāra": ['cae', 'mw'],
    "śarakāṇḍa": ['cae', 'mw'],
    "śarakūpa": ['mw'],
    "śarakṣepa": ['cae', 'mw'],
    "śarakṣepaṇa": ['bhs'],
    "śarala": ['ap90', 'mw'],
    "śaralaka": ['mw'],
    "śaralakaṃ": ['ap90'],
    "śaraloma": ['mw'],
    "śaraloman": ['mw'],
    "śaramalla": ['mw'],
    "śaramarīcimat": ['mw'],
    "śaramaya": ['cae', 'mw'],
    "śaramukha": ['mw'],
    "śaran": ['mw'],
    "śaranikara": ['mw'],
    "śaraniveśa": ['mw'],
    "śaranivāsa": ['mw'],
    "śaranmegha": ['cae', 'ddsa', 'mw'],
    "śaranmeghavat": ['mw'],
    "śaranmukha": ['mw'],
    "śaraparṇikā": ['mw'],
    "śaraparṇī": ['mw'],
    "śarapatha": ['bhs'],
    "śarapattra": ['mw'],
    "śarapañjara": ['cae', 'mw'],
    "śaraphala": ['mw'],
    "śarapravega": ['mw'],
    "śarapuccha": ['mw'],
    "śarapuṅkha": ['mw'],
    "śarapuṅkhā": ['mw'],
    "śarapāta": ['mw'],
    "śarapātasthāna": ['mw'],
    "śaras": ['cae', 'ddsa', 'mw'],
    "śarasambādha": ['mw'],
    "śarasaṃdhāna": ['mw'],
    "śarastamba": ['cae', 'ddsa', 'mw'],
    "śarasāt": ['mw'],
    "śarasātkṛ": ['ddsa'],
    "śarat": ['mw'],
    "śaratalpa": ['cae', 'ddsa', 'mw'],
    "śaratka": ['bhs'],
    "śaratkāla": ['cae', 'ddsa', 'mw'],
    "śaratkālīna": ['mw'],
    "śaratkāmin": ['mw'],
    "śaratkāntimaya": ['mw'],
    "śaratpadma": ['cae', 'mw'],
    "śaratparvan": ['cae', 'mw'],
    "śaratparvaśaśin": ['cae', 'mw'],
    "śaratpayoda": ['mw'],
    "śaratpratīkṣam": ['mw'],
    "śaratprāvṛṣika": ['mw'],
    "śaratpuṣpa": ['mw'],
    "śaratsamaya": ['cae', 'mw'],
    "śaratsasya": ['mw'],
    "śarattriyāmā": ['mw'],
    "śaratva": ['mw'],
    "śaratā": ['mw'],
    "śaraugha": ['cae', 'ddsa', 'mw'],
    "śarava": ['mw'],
    "śaravana": ['mw'],
    "śaravarṣa": ['cae', 'mw'],
    "śaravarṣin": ['cae', 'mw'],
    "śaravat": ['mw'],
    "śaravaṇa": ['cae', 'mw'],
    "śaravaṇabhava": ['mw'],
    "śaravaṇodbhava": ['mw'],
    "śaravaṇālaya": ['mw'],
    "śaravega": ['mw'],
    "śaraviddha": ['mw'],
    "śaraviā": ['gra'],
    "śaravrāta": ['mw'],
    "śaravya": ['cae', 'ddsa', 'mw'],
    "śaravyaka": ['mw'],
    "śaravyatā": ['mw'],
    "śaravyavyadha": ['mw'],
    "śaravyaya": ['ddsa', 'mw'],
    "śaravyaṃ": ['ap90'],
    "śaravyā": ['ddsa', 'gra', 'mw'],
    "śaravyāya": ['ddsa', 'mw'],
    "śaravyīkaraṇa": ['ddsa', 'mw'],
    "śaravāraṇa": ['mw'],
    "śaravāṇi": ['mw'],
    "śaravṛṣṭi": ['mw'],
    "śarayantraka": ['mw'],
    "śarayu": ['mw'],
    "śarayuḥ": ['ap90'],
    "śarayūḥ": ['ap90'],
    "śaraśarāya": ['mw'],
    "śaraśayana": ['cae', 'ddsa', 'mw'],
    "śaraśayyā": ['mw'],
    "śaraśāstra": ['mw'],
    "śaraḍa": ['bhs'],
    "śaraḥ": ['ap90'],
    "śaraṃḍaḥ": ['ap90'],
    "śaraṇa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śaraṇada": ['mw'],
    "śaraṇadeva": ['mw'],
    "śaraṇaiṣin": ['cae', 'mw'],
    "śaraṇaprada": ['mw'],
    "śaraṇaṃ": ['ap90'],
    "śaraṇaṃgata": ['mw'],
    "śaraṇi": ['cae', 'gra', 'mw'],
    "śaraṇya": ['ap90', 'cae', 'ddsa', 'mw'],
    "śaraṇyapuramāhātmya": ['mw'],
    "śaraṇyatā": ['mw'],
    "śaraṇyu": ['mw'],
    "śaraṇyuḥ": ['ap90'],
    "śaraṇyā": ['mw'],
    "śaraṇādhikāramañjarī": ['mw'],
    "śaraṇāgata": ['cae', 'ddsa', 'mw'],
    "śaraṇāgataghātaka": ['mw'],
    "śaraṇāgataghātin": ['mw'],
    "śaraṇāgatahantṛ": ['mw'],
    "śaraṇāgatatā": ['mw'],
    "śaraṇāgati": ['mw'],
    "śaraṇāgatidīpikā": ['mw'],
    "śaraṇāgatigadya": ['mw'],
    "śaraṇāgatitātparyaślokopanyāsa": ['mw'],
    "śaraṇālaya": ['cae', 'mw'],
    "śaraṇāpanna": ['mw'],
    "śaraṇārpaka": ['mw'],
    "śaraṇārtham": ['mw'],
    "śaraṇārthin": ['cae', 'mw'],
    "śaraṇī": ['ap90', 'mw'],
    "śaraṇīkṛ": ['ddsa', 'mw'],
    "śaraṇḍa": ['mw'],
    "śaraṭaḥ": ['ap90'],
    "śarb": ['ap90', 'mw'],
    "śardh": ['cae', 'gra'],
    "śardha": ['cae', 'ddsa', 'gra', 'mw'],
    "śardhamāna": ['mw'],
    "śardhana": ['ddsa', 'mw'],
    "śardhanīti": ['cae', 'gra', 'mw'],
    "śardhas": ['ap90', 'cae', 'gra', 'mw'],
    "śardhat": ['ddsa', 'mw'],
    "śardhavat": ['mw'],
    "śardhaḥ": ['ap90'],
    "śardhaṃjaha": ['ap90', 'mw'],
    "śardhia": ['gra'],
    "śardhin": ['gra', 'mw'],
    "śardhis": ['cae'],
    "śardhya": ['cae', 'gra', 'mw'],
    "śardis": ['mw'],
    "śardūla": ['bhs'],
    "śareja": ['mw'],
    "śarepha": ['mw'],
    "śareṣīkā": ['mw'],
    "śareṣṭa": ['mw'],
    "śari": ['mw'],
    "śariman": ['ap90', 'mw'],
    "śarin": ['cae', 'mw'],
    "śarita": ['bhs'],
    "śarkalā": ['bhs'],
    "śarkara": ['cae', 'ddsa', 'mw'],
    "śarkarajā": ['ap90', 'mw'],
    "śarkaraka": ['mw'],
    "śarkarakarṣin": ['mw'],
    "śarkarakaḥ": ['ap90'],
    "śarkaratva": ['mw'],
    "śarkaravarṣin": ['mw'],
    "śarkarika": ['ap90', 'mw'],
    "śarkarikā": ['mw'],
    "śarkarila": ['mw'],
    "śarkarin": ['mw'],
    "śarkarodaka": ['cae', 'mw'],
    "śarkarā": ['ap90', 'mw'],
    "śarkarācala": ['mw'],
    "śarkarācaladāna": ['mw'],
    "śarkarādhenu": ['mw'],
    "śarkarākarṣin": ['mw'],
    "śarkarākṣa": ['mw'],
    "śarkarāla": ['ddsa', 'mw'],
    "śarkarāmbu": ['cae', 'mw'],
    "śarkarāprabhā": ['mw'],
    "śarkarāpuṣpa": ['mw'],
    "śarkarārbuda": ['mw'],
    "śarkarāsaptamī": ['mw'],
    "śarkarāsava": ['mw'],
    "śarkarāvartā": ['mw'],
    "śarkarāvarṣin": ['mw'],
    "śarkarāvat": ['mw'],
    "śarkarī": ['ap90', 'mw'],
    "śarkarīdhāna": ['mw'],
    "śarkarīkṛta": ['mw'],
    "śarkarīya": ['mw'],
    "śarkoṭa": ['cae', 'mw'],
    "śarku": ['cae', 'mw'],
    "śarkura": ['mw'],
    "śarkāra": ['mw'],
    "śarma": ['mw'],
    "śarmada": ['mw'],
    "śarmadātṛ": ['mw'],
    "śarmaka": ['cae', 'mw'],
    "śarmakāma": ['mw'],
    "śarmakārin": ['cae', 'mw'],
    "śarmakṛt": ['cae', 'mw'],
    "śarmalābha": ['mw'],
    "śarman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śarmaprada": ['mw'],
    "śarmara": ['mw'],
    "śarmaraḥ": ['ap90'],
    "śarmasad": ['gra', 'mw'],
    "śarmavant": ['cae'],
    "śarmavarmagaṇa": ['mw'],
    "śarmavarūtha": ['mw'],
    "śarmavat": ['ddsa', 'mw'],
    "śarmay": ['cae', 'gra'],
    "śarmaya": ['ddsa', 'mw'],
    "śarmaṇya": ['cae', 'mw'],
    "śarmaṇyadeśa": ['mw'],
    "śarmaṇyadeśīya": ['mw'],
    "śarmila": ['bhs'],
    "śarmilā": ['mw'],
    "śarmin": ['cae', 'mw'],
    "śarmiṣṭhā": ['ap90', 'cae', 'ddsa', 'mw'],
    "śarmiṣṭhāvijaya": ['mw'],
    "śarmiṣṭhāyayāti": ['mw'],
    "śarmopaya": ['mw'],
    "śarogṛhīta": ['ddsa', 'mw'],
    "śarottama": ['mw'],
    "śarpaṇā": ['mw'],
    "śarpaṇāvat": ['mw'],
    "śaru": ['cae', 'ddsa', 'gra', 'mw'],
    "śarumant": ['cae'],
    "śarumat": ['gra', 'mw'],
    "śaruḥ": ['ap90'],
    "śarv": ['ap90', 'mw'],
    "śarva": ['cae', 'ddsa', 'mw'],
    "śarvadatta": ['mw'],
    "śarvaka": ['mw'],
    "śarvakośa": ['mw'],
    "śarvalā": ['ap90', 'mw'],
    "śarvaparvata": ['cae', 'mw'],
    "śarvaparvatavāsinī": ['mw'],
    "śarvapatnī": ['cae', 'mw'],
    "śarvara": ['gra', 'mw'],
    "śarvaraḥ": ['ap90'],
    "śarvarin": ['mw'],
    "śarvarī": ['ap90', 'ddsa', 'gra', 'mw'],
    "śarvarīka": ['mw'],
    "śarvarīpati": ['mw'],
    "śarvarīśa": ['mw'],
    "śarvarīśvara": ['mw'],
    "śarvavarman": ['ddsa', 'mw'],
    "śarvaḥ": ['ap90'],
    "śarvaṭa": ['ddsa', 'mw'],
    "śarvikā": ['mw'],
    "śarvilaka": ['ddsa', 'mw'],
    "śarvā": ['mw'],
    "śarvācala": ['cae', 'mw'],
    "śarvākṣa": ['mw'],
    "śarvāvatāramāhātmya": ['mw'],
    "śarvāṇī": ['ap90', 'cae', 'ddsa', 'mw'],
    "śarvāṇīramaṇa": ['mw'],
    "śarya": ['cae', 'ddsa', 'gra', 'mw'],
    "śaryahan": ['cae', 'gra', 'mw'],
    "śaryaḥ": ['ap90'],
    "śaryaṇa": ['cae', 'mw'],
    "śaryaṇā": ['gra'],
    "śaryaṇāvant": ['cae'],
    "śaryaṇāvat": ['ddsa', 'gra', 'mw'],
    "śaryā": ['ap90', 'ddsa', 'gra', 'mw'],
    "śaryāta": ['cae', 'ddsa', 'gra', 'mw'],
    "śaryāti": ['cae', 'ddsa', 'mw'],
    "śaryāṇa": ['mw'],
    "śaryāṇavat": ['mw'],
    "śarābhyāsa": ['mw'],
    "śarādāna": ['mw'],
    "śarāghāta": ['mw'],
    "śarāgni": ['mw'],
    "śarāgniparimāṇa": ['mw'],
    "śarāgrya": ['mw'],
    "śarāhata": ['mw'],
    "śarāka": ['mw'],
    "śarākṣepa": ['mw'],
    "śarāli": ['mw'],
    "śarālikā": ['mw'],
    "śarālī": ['mw'],
    "śarārcis": ['mw'],
    "śarāri": ['cae', 'ddsa', 'mw'],
    "śarāropa": ['mw'],
    "śarāru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śarāryāsya": ['mw'],
    "śarārī": ['cae', 'mw'],
    "śarārīmukhī": ['mw'],
    "śarāsa": ['cae', 'mw'],
    "śarāsana": ['ddsa', 'mw'],
    "śarāsanadhara": ['mw'],
    "śarāsanajyā": ['mw'],
    "śarāsanavid": ['mw'],
    "śarāsanin": ['mw'],
    "śarāsya": ['cae', 'mw'],
    "śarāsāra": ['cae', 'ddsa', 'mw'],
    "śarāti": ['mw'],
    "śarāva": ['cae', 'ddsa', 'mw'],
    "śarāvaka": ['mw'],
    "śarāvakurda": ['mw'],
    "śarāvara": ['cae', 'mw'],
    "śarāvaraṇa": ['mw'],
    "śarāvasampāta": ['mw'],
    "śarāvasaṃpāta": ['cae'],
    "śarāvatī": ['ap90', 'ddsa', 'mw'],
    "śarāvaḥ": ['ap90'],
    "śarāvikā": ['mw'],
    "śarāvin": ['mw'],
    "śarāvāpa": ['cae', 'mw'],
    "śarāya": ['ddsa', 'mw'],
    "śarāyudha": ['mw'],
    "śarāśani": ['ddsa', 'mw'],
    "śarāśari": ['ddsa', 'mw'],
    "śarāśraya": ['mw'],
    "śarāḍi": ['mw'],
    "śarāṅkuśavyākhyā": ['mw'],
    "śarāṭi": ['mw'],
    "śarāṭikā": ['mw'],
    "śarāṭiḥ": ['ap90'],
    "śarī": ['mw'],
    "śarīkṛ": ['mw'],
    "śarīman": ['mw'],
    "śarīra": ['cae', 'ddsa', 'gra', 'mw'],
    "śarīrabaddha": ['mw'],
    "śarīrabandha": ['mw'],
    "śarīrabandhaka": ['mw'],
    "śarīrabandhena": ['mw'],
    "śarīrabheda": ['cae', 'mw'],
    "śarīrabhāj": ['mw'],
    "śarīrabhūta": ['mw'],
    "śarīrabhṛt": ['mw'],
    "śarīracintā": ['mw'],
    "śarīradaṇḍa": ['cae', 'mw'],
    "śarīradeśa": ['cae', 'mw'],
    "śarīradhātu": ['cae', 'mw'],
    "śarīradhṛk": ['cae', 'mw'],
    "śarīragati": ['bhs'],
    "śarīragrahaṇa": ['cae', 'mw'],
    "śarīrahoma": ['mw'],
    "śarīraja": ['cae', 'mw'],
    "śarīrajanman": ['mw'],
    "śarīraka": ['cae', 'ddsa', 'mw'],
    "śarīrakartṛ": ['cae', 'mw'],
    "śarīrakarṣaṇa": ['cae', 'mw'],
    "śarīrakaṃ": ['ap90'],
    "śarīrakṛt": ['cae', 'mw'],
    "śarīralakṣaṇa": ['mw'],
    "śarīramātra": ['mw'],
    "śarīranicaya": ['mw'],
    "śarīranipāta": ['mw'],
    "śarīranyāsa": ['mw'],
    "śarīrapakti": ['mw'],
    "śarīrapatana": ['mw'],
    "śarīraprabhava": ['mw'],
    "śarīrapradhānatayā": ['mw'],
    "śarīrapradhānatā": ['mw'],
    "śarīraprahlādana": ['bhs', 'mw'],
    "śarīrapuruṣa": ['mw'],
    "śarīrapāka": ['mw'],
    "śarīrapāta": ['cae', 'mw'],
    "śarīrapīḍā": ['mw'],
    "śarīrarakṣaka": ['mw'],
    "śarīrarakṣā": ['mw'],
    "śarīraratna": ['cae', 'mw'],
    "śarīrareṣaṇa": ['mw'],
    "śarīrasambandha": ['mw'],
    "śarīrasampatti": ['mw'],
    "śarīrasaṃdhi": ['mw'],
    "śarīrasaṃskāra": ['mw'],
    "śarīrastha": ['cae', 'mw'],
    "śarīrasthiti": ['mw'],
    "śarīrasthāna": ['mw'],
    "śarīrasthānabhāṣya": ['mw'],
    "śarīrasāda": ['cae', 'mw'],
    "śarīratulya": ['mw'],
    "śarīratva": ['mw'],
    "śarīratyāga": ['cae', 'mw'],
    "śarīratā": ['mw'],
    "śarīravaikalya": ['mw'],
    "śarīravant": ['cae'],
    "śarīravat": ['mw'],
    "śarīravattva": ['mw'],
    "śarīravimokṣaṇa": ['mw'],
    "śarīraviniścayādhikāra": ['mw'],
    "śarīravāda": ['mw'],
    "śarīravṛtta": ['mw'],
    "śarīravṛtti": ['cae', 'mw'],
    "śarīrayaṣṭi": ['cae', 'mw'],
    "śarīrayoga": ['mw'],
    "śarīrayogaja": ['cae', 'mw'],
    "śarīrayātrā": ['cae', 'mw'],
    "śarīraśoṣaṇa": ['cae', 'mw'],
    "śarīraśuśrūṣā": ['cae', 'mw'],
    "śarīraṃ": ['ap90'],
    "śarīrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śarīrābhyadhika": ['cae', 'mw'],
    "śarīrākāra": ['cae', 'mw'],
    "śarīrākṛti": ['ddsa', 'mw'],
    "śarīrānta": ['cae', 'mw'],
    "śarīrāntakara": ['cae', 'mw'],
    "śarīrāntara": ['mw'],
    "śarīrāntaracārin": ['mw'],
    "śarīrārdha": ['cae', 'mw'],
    "śarīrāsthi": ['mw'],
    "śarīrātman": ['mw'],
    "śarīrāvaraṇa": ['mw'],
    "śarīrāvayava": ['cae', 'mw'],
    "śarīrībhū": ['ddsa', 'mw'],
    "śarśarīka": ['ap90', 'mw'],
    "śarṇacāpili": ['mw'],
    "śarṣīkā": ['mw'],
    "śas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śasa": ['mw'],
    "śasana": ['cae', 'ddsa', 'gra', 'mw'],
    "śasanaṃ": ['ap90'],
    "śasita": ['mw'],
    "śasitvā": ['mw'],
    "śasitṛ": ['mw'],
    "śaskulī": ['ap90', 'mw'],
    "śasman": ['cae', 'ddsa', 'gra', 'mw'],
    "śaspaḥ": ['ap90'],
    "śasta": ['ap90', 'cae', 'ddsa', 'mw'],
    "śastaka": ['mw'],
    "śastakeśaka": ['mw'],
    "śastatā": ['mw'],
    "śastavya": ['mw'],
    "śasti": ['cae', 'ddsa', 'gra', 'mw'],
    "śastiḥ": ['ap90'],
    "śastokta": ['mw'],
    "śastra": ['cae', 'ddsa', 'mw'],
    "śastrabhaya": ['mw'],
    "śastrabhṛt": ['cae', 'mw'],
    "śastracikitsā": ['mw'],
    "śastracūrṇa": ['mw'],
    "śastradevatā": ['mw'],
    "śastradhara": ['mw'],
    "śastradhāraṇa": ['mw'],
    "śastradhāraṇajīvaka": ['mw'],
    "śastradhārin": ['mw'],
    "śastraghuṣṭakara": ['mw'],
    "śastraghāta": ['mw'],
    "śastragraha": ['mw'],
    "śastragrāhaka": ['mw'],
    "śastragrāhavat": ['mw'],
    "śastragrāhin": ['mw'],
    "śastrahata": ['mw'],
    "śastrahatacaturdaśī": ['mw'],
    "śastrajāla": ['mw'],
    "śastrajīvin": ['mw'],
    "śastraka": ['bhs', 'mw'],
    "śastrakali": ['cae', 'mw'],
    "śastrakarmakṛt": ['mw'],
    "śastrakarman": ['ddsa', 'mw'],
    "śastrakarmavidhi": ['mw'],
    "śastrakaṃ": ['ap90'],
    "śastrakopa": ['mw'],
    "śastrakośa": ['mw'],
    "śastrakośataru": ['mw'],
    "śastrakuśala": ['mw'],
    "śastrakāra": ['mw'],
    "śastrakṣata": ['mw'],
    "śastrakṣāra": ['mw'],
    "śastralakṣaṇa": ['mw'],
    "śastramaya": ['mw'],
    "śastramukha": ['mw'],
    "śastramārja": ['mw'],
    "śastranidhana": ['mw'],
    "śastranipāta": ['mw'],
    "śastranipātana": ['mw'],
    "śastraniryāṇa": ['mw'],
    "śastranitya": ['mw'],
    "śastranyāsa": ['cae', 'mw'],
    "śastrapada": ['mw'],
    "śastrapattra": ['cae'],
    "śastraprahāra": ['cae', 'mw'],
    "śastraprakopa": ['mw'],
    "śastrapāna": ['mw'],
    "śastrapāta": ['cae', 'mw'],
    "śastrapāṇi": ['cae', 'mw'],
    "śastrapāṇin": ['cae'],
    "śastrapūjāvidhi": ['mw'],
    "śastrapūta": ['mw'],
    "śastrasampāta": ['mw'],
    "śastrasamūha": ['mw'],
    "śastrasaṃhati": ['mw'],
    "śastrasaṃpāta": ['cae'],
    "śastratyāga": ['mw'],
    "śastravadha": ['mw'],
    "śastravant": ['cae'],
    "śastravat": ['mw'],
    "śastravidvas": ['mw'],
    "śastravidyā": ['mw'],
    "śastravihita": ['mw'],
    "śastravikrayin": ['cae', 'mw'],
    "śastravraṇamaya": ['mw'],
    "śastravyavahāra": ['mw'],
    "śastravārtta": ['mw'],
    "śastravṛtti": ['cae', 'mw'],
    "śastraśikhin": ['mw'],
    "śastraśikṣā": ['mw'],
    "śastraśāstra": ['mw'],
    "śastraṃ": ['ap90'],
    "śastrikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "śastrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śastrodyama": ['mw'],
    "śastrodyoga": ['mw'],
    "śastropajīvin": ['ddsa', 'mw'],
    "śastropakaraṇa": ['mw'],
    "śastrotthāpana": ['mw'],
    "śastrābhyāsa": ['mw'],
    "śastrādhāraka": ['bhs'],
    "śastrāgnisambhrama": ['mw'],
    "śastrājīva": ['ddsa', 'mw'],
    "śastrākhya": ['mw'],
    "śastrāmayārti": ['mw'],
    "śastrānta": ['mw'],
    "śastrārcis": ['mw'],
    "śastrāstra": ['mw'],
    "śastrāstrabhṛt": ['cae', 'mw'],
    "śastrāstrabhṛttva": ['mw'],
    "śastrātiga": ['mw'],
    "śastrāvapāta": ['mw'],
    "śastrāyasa": ['mw'],
    "śastrāyudha": ['mw'],
    "śastrāśastri": ['mw'],
    "śastrāṅgā": ['mw'],
    "śastrī": ['ap90', 'cae', 'mw'],
    "śastrīśyāma": ['mw'],
    "śastṛ": ['cae', 'gra', 'mw'],
    "śasya": ['ap90', 'cae', 'ddsa', 'mw'],
    "śasyaka": ['mw'],
    "śasyaṃ": ['ap90'],
    "śasā": ['gra', 'mw'],
    "śat": ['cae', 'ddsa', 'gra', 'mw'],
    "śata": ['cae', 'ddsa', 'gra', 'mw'],
    "śataaśva": ['gra'],
    "śatabaddha": ['mw'],
    "śatabala": ['mw'],
    "śatabali": ['cae', 'mw'],
    "śatabalā": ['mw'],
    "śatabalāka": ['mw'],
    "śatabalākṣa": ['mw'],
    "śatabalśa": ['mw'],
    "śatabhaṅgībhū": ['mw'],
    "śatabhiṣa": ['mw'],
    "śatabhiṣaj": ['mw'],
    "śatabhiṣaksena": ['mw'],
    "śatabhiṣā": ['mw'],
    "śatabhuji": ['cae', 'gra', 'mw'],
    "śatabhāga": ['cae', 'mw'],
    "śatabhīru": ['mw'],
    "śatabhṛṣṭi": ['mw'],
    "śatabradhna": ['gra', 'mw'],
    "śatabrāhmaṇaghātaja": ['mw'],
    "śatabuddhi": ['cae', 'mw'],
    "śatabāhu": ['bhs', 'mw'],
    "śatacakra": ['cae', 'gra', 'mw'],
    "śatacandra": ['mw'],
    "śatacandrita": ['mw'],
    "śatacaraṇā": ['mw'],
    "śatacarman": ['cae', 'mw'],
    "śatacaṇḍī": ['mw'],
    "śatacaṇḍīpaddhati": ['mw'],
    "śatacaṇḍīpūjākrama": ['mw'],
    "śatacaṇḍīsahasracaṇḍyādividhāna": ['mw'],
    "śatacaṇḍīsahasracaṇḍīprayoga": ['mw'],
    "śatacaṇḍīsahasracaṇḍīvidhi": ['mw'],
    "śatacaṇḍīvidhi": ['mw'],
    "śatacaṇḍīvidhāna": ['mw'],
    "śatacaṇḍīvidhānapaddhati": ['mw'],
    "śatacchada": ['mw'],
    "śatacchidra": ['mw'],
    "śatada": ['cae', 'mw'],
    "śatadakṣiṇa": ['mw'],
    "śatadala": ['cae', 'mw'],
    "śatadalā": ['mw'],
    "śatadant": ['cae'],
    "śatadantikā": ['mw'],
    "śatadat": ['mw'],
    "śatadaṇḍa": ['cae'],
    "śatadaṇḍārha": ['mw'],
    "śatadhania": ['gra'],
    "śatadhanu": ['bhs', 'mw'],
    "śatadhanus": ['mw'],
    "śatadhanvan": ['mw'],
    "śatadhanya": ['cae', 'gra', 'mw'],
    "śatadhara": ['mw'],
    "śatadharma": ['bhs'],
    "śatadhauta": ['mw'],
    "śatadhenutantra": ['mw'],
    "śatadhā": ['ap90', 'cae', 'mw'],
    "śatadhāman": ['mw'],
    "śatadhāra": ['gra', 'mw'],
    "śatadhāraka": ['mw'],
    "śatadhāravana": ['mw'],
    "śatadhāya": ['mw'],
    "śatadhṛti": ['mw'],
    "śatadru": ['cae', 'mw'],
    "śatadruja": ['mw'],
    "śatadrukā": ['mw'],
    "śatadruti": ['mw'],
    "śatadrū": ['cae', 'mw'],
    "śatadura": ['gra', 'mw'],
    "śatadvasu": ['gra', 'mw'],
    "śatadvaya": ['mw'],
    "śatadvayī": ['mw'],
    "śatadvayīprāyaścitta": ['mw'],
    "śatadvāra": ['cae', 'mw'],
    "śatadyumna": ['cae', 'mw'],
    "śatadā": ['cae', 'gra', 'mw'],
    "śatadāruka": ['mw'],
    "śatadātu": ['cae', 'gra', 'mw'],
    "śatadāvan": ['cae', 'gra', 'mw'],
    "śatadāya": ['cae', 'gra', 'mw'],
    "śatadūṣaṇī": ['mw'],
    "śatadūṣaṇīkhaṇḍana": ['mw'],
    "śatadūṣaṇīvyākhyā": ['mw'],
    "śatadūṣaṇīyamata": ['mw'],
    "śatadūṣiṇī": ['mw'],
    "śataga": ['mw'],
    "śataghaṇṭā": ['cae', 'mw'],
    "śataghni": ['mw'],
    "śataghnin": ['mw'],
    "śataghnu": ['mw'],
    "śataghnī": ['bhs', 'cae', 'mw'],
    "śataghnīpāśaśaktimat": ['mw'],
    "śataghora": ['mw'],
    "śataghāta": ['mw'],
    "śatagiri": ['bhs'],
    "śatagodānapaddhati": ['mw'],
    "śatagranthi": ['mw'],
    "śatagrīva": ['mw'],
    "śatagu": ['cae', 'mw'],
    "śataguptā": ['mw'],
    "śataguṇa": ['cae', 'mw'],
    "śataguṇam": ['mw'],
    "śataguṇita": ['cae', 'mw'],
    "śataguṇācārya": ['mw'],
    "śataguṇādhikam": ['mw'],
    "śataguṇībhāva": ['mw'],
    "śataguṇībhū": ['mw'],
    "śataguṇībhūta": ['mw'],
    "śatagva": ['mw'],
    "śatagvin": ['cae', 'gra', 'mw'],
    "śatahali": ['mw'],
    "śatahan": ['cae', 'mw'],
    "śatahasta": ['mw'],
    "śatahaya": ['mw'],
    "śatahima": ['cae', 'gra', 'mw'],
    "śatahrada": ['cae', 'mw'],
    "śatahradā": ['mw'],
    "śatahrādā": ['mw'],
    "śatahuta": ['mw'],
    "śatahāyana": ['mw'],
    "śataikaśīrṣan": ['mw'],
    "śataikīya": ['ddsa', 'mw'],
    "śatajihva": ['mw'],
    "śatajit": ['cae', 'mw'],
    "śatajyoti": ['mw'],
    "śatajyotis": ['mw'],
    "śatajīvin": ['mw'],
    "śataka": ['ap90', 'cae', 'ddsa', 'mw'],
    "śatakapāleśa": ['mw'],
    "śatakarman": ['mw'],
    "śatakarṇācārya": ['mw'],
    "śatakavyākhyā": ['mw'],
    "śatakaṇṭaka": ['mw'],
    "śatakaṭīkā": ['mw'],
    "śatakesara": ['mw'],
    "śatakhaṇḍa": ['cae', 'mw'],
    "śatakhaṇḍamaya": ['mw'],
    "śatakiraṇa": ['mw'],
    "śatakoṭi": ['cae', 'mw'],
    "śatakoṭikhaṇḍana": ['mw'],
    "śatakoṭimaṇḍana": ['mw'],
    "śatakoṭivyākhyā": ['mw'],
    "śatakratu": ['cae', 'gra', 'mw'],
    "śatakratuprastha": ['mw'],
    "śatakratusmṛti": ['mw'],
    "śatakrī": ['mw'],
    "śatakulīraka": ['mw'],
    "śatakumbha": ['cae', 'mw'],
    "śatakumbhā": ['mw'],
    "śatakunda": ['mw'],
    "śatakunta": ['mw'],
    "śatakusumā": ['mw'],
    "śatakāṇḍa": ['mw'],
    "śatakīrti": ['mw'],
    "śatakṛtvas": ['cae', 'mw'],
    "śatakṛṣṇala": ['mw'],
    "śatalakṣa": ['mw'],
    "śatalocana": ['mw'],
    "śatalumpa": ['mw'],
    "śatalumpaka": ['mw'],
    "śatamakha": ['cae', 'mw'],
    "śatamanyu": ['cae', 'gra', 'mw'],
    "śatamanyucāpa": ['mw'],
    "śatamanyukaṇṭhi": ['mw'],
    "śatamanyukaṇṭhin": ['mw'],
    "śatamaya": ['mw'],
    "śatamayūkha": ['mw'],
    "śatamukha": ['bhs', 'cae', 'mw'],
    "śatamukharāvaṇacaritra": ['mw'],
    "śatamukhī": ['mw'],
    "śatamāna": ['cae', 'mw'],
    "śatamānadakṣiṇa": ['mw'],
    "śatamānadānavidhi": ['mw'],
    "śatamārin": ['mw'],
    "śatamārja": ['mw'],
    "śatamāya": ['mw'],
    "śatamāṇṭi": ['mw'],
    "śatamūla": ['cae', 'mw'],
    "śatamūlikā": ['mw'],
    "śatamūlā": ['mw'],
    "śatamūlī": ['mw'],
    "śatamūrdhan": ['cae', 'mw'],
    "śatamūti": ['cae', 'gra', 'mw'],
    "śatana": ['bhs', 'mw'],
    "śatanetrikā": ['mw'],
    "śatanetrā": ['bhs'],
    "śatanirhrāda": ['mw'],
    "śatanītha": ['cae', 'gra', 'mw'],
    "śatapad": ['cae', 'gra', 'mw'],
    "śatapada": ['mw'],
    "śatapadacakra": ['mw'],
    "śatapadma": ['mw'],
    "śatapadī": ['mw'],
    "śataparivāra": ['mw'],
    "śataparivārā": ['bhs', 'mw'],
    "śataparva": ['mw'],
    "śataparvadhṛk": ['mw'],
    "śataparvaka": ['mw'],
    "śataparvan": ['cae', 'gra', 'mw'],
    "śataparveśa": ['mw'],
    "śataparvikā": ['mw'],
    "śataparvā": ['mw'],
    "śataparṇa": ['mw'],
    "śatapatha": ['cae', 'mw'],
    "śatapathabrāhmaṇa": ['mw'],
    "śatapathaśruti": ['mw'],
    "śatapathika": ['mw'],
    "śatapathīya": ['mw'],
    "śatapati": ['cae', 'mw'],
    "śatapatra": ['gra'],
    "śatapattra": ['cae', 'mw'],
    "śatapattraka": ['mw'],
    "śatapattranivāsa": ['mw'],
    "śatapattrayoni": ['mw'],
    "śatapattrikā": ['mw'],
    "śatapattrā": ['mw'],
    "śatapattrāyatekṣaṇa": ['mw'],
    "śatapattrī": ['mw'],
    "śatapavitra": ['gra', 'mw'],
    "śatapayas": ['mw'],
    "śataphalin": ['mw'],
    "śatapona": ['mw'],
    "śataponaka": ['mw'],
    "śataponakaḥ": ['ap90'],
    "śataponaḥ": ['ap90'],
    "śatapora": ['mw'],
    "śataporaka": ['mw'],
    "śataprabhedana": ['mw'],
    "śataprada": ['mw'],
    "śataprasava": ['mw'],
    "śataprasūnā": ['mw'],
    "śataprasūti": ['mw'],
    "śataprāsa": ['mw'],
    "śataprāyaścittavājapeya": ['mw'],
    "śataputra": ['mw'],
    "śataputratā": ['mw'],
    "śatapuṣkara": ['mw'],
    "śatapuṣpa": ['bhs', 'mw'],
    "śatapuṣpikā": ['mw'],
    "śatapuṣpā": ['bhs', 'mw'],
    "śatapuṭa": ['mw'],
    "śatapād": ['mw'],
    "śatapādaka": ['mw'],
    "śatapādikā": ['bhs', 'mw'],
    "śatapādī": ['mw'],
    "śatapāka": ['mw'],
    "śatapākya": ['mw'],
    "śatapāla": ['mw'],
    "śatapātin": ['mw'],
    "śatarasa": ['bhs'],
    "śataratha": ['mw'],
    "śatarañjinī": ['mw'],
    "śataraśmi": ['bhs'],
    "śatarca": ['mw'],
    "śatarcas": ['gra', 'mw'],
    "śatarcin": ['mw'],
    "śatarudra": ['mw'],
    "śatarudrasaṃhitā": ['mw'],
    "śatarudriya": ['mw'],
    "śatarudriyabhāṣya": ['mw'],
    "śatarudriyahoma": ['mw'],
    "śatarudriyavat": ['mw'],
    "śatarudriyaśivastotra": ['mw'],
    "śatarudrā": ['mw'],
    "śatarudrīya": ['mw'],
    "śatarā": ['gra', 'mw'],
    "śatarātra": ['cae', 'mw'],
    "śatarūpa": ['mw'],
    "śatarūpā": ['mw'],
    "śatasahasra": ['cae', 'mw'],
    "śatasahasradhā": ['cae', 'mw'],
    "śatasahasraka": ['mw'],
    "śatasahasramātar": ['bhs'],
    "śatasahasrapattra": ['bhs', 'mw'],
    "śatasahasrayāna": ['mw'],
    "śatasahasraśas": ['mw'],
    "śatasahasrānta": ['mw'],
    "śatasahasrāṃśu": ['mw'],
    "śatasani": ['cae', 'mw'],
    "śatasaṃdhāna": ['mw'],
    "śatasaṃghaśas": ['mw'],
    "śatasaṃkhya": ['cae', 'mw'],
    "śatasaṃvatsara": ['mw'],
    "śatasaṃvatsarakālasūcikā": ['mw'],
    "śatasaṃvatsaraphala": ['mw'],
    "śataseya": ['cae', 'gra', 'mw'],
    "śatasphya": ['mw'],
    "śataspṛh": ['gra', 'mw'],
    "śatasukha": ['cae', 'mw'],
    "śatasvin": ['cae', 'gra', 'mw'],
    "śatasā": ['cae', 'gra', 'mw'],
    "śatasāhasra": ['cae', 'mw'],
    "śatasāhasraka": ['mw'],
    "śatasāhasrasammita": ['mw'],
    "śatasāhasrasaṃkhya": ['mw'],
    "śatasāhasrika": ['cae', 'mw'],
    "śatasāhasrikāprajñāpāramitā": ['bhs'],
    "śatasū": ['mw'],
    "śatasūtrī": ['mw'],
    "śatatama": ['ap90', 'cae', 'gra', 'mw'],
    "śatatanti": ['mw'],
    "śatatantrī": ['mw'],
    "śatatantrīka": ['mw'],
    "śatatantu": ['mw'],
    "śatatardma": ['mw'],
    "śatatarha": ['mw'],
    "śatatarham": ['mw'],
    "śatatejas": ['mw'],
    "śatatin": ['mw'],
    "śatatraya": ['mw'],
    "śatatrayī": ['mw'],
    "śatatārā": ['mw'],
    "śataudanā": ['cae', 'mw'],
    "śatavadha": ['mw'],
    "śatavaktra": ['mw'],
    "śatavala": ['mw'],
    "śatavaliśa": ['mw'],
    "śatavalśa": ['gra', 'mw'],
    "śatavani": ['mw'],
    "śatavant": ['cae'],
    "śatavapus": ['mw'],
    "śatavargaāgama": ['bhs'],
    "śatavarṣa": ['cae', 'mw'],
    "śatavarṣasahasrin": ['mw'],
    "śatavarṣasāriṇī": ['mw'],
    "śatavarṣin": ['cae', 'mw'],
    "śatavarṣman": ['mw'],
    "śatavat": ['gra', 'mw'],
    "śatavedhin": ['mw'],
    "śatavicakṣaṇa": ['cae', 'gra', 'mw'],
    "śatavitṛṇṇa": ['mw'],
    "śatavraja": ['gra', 'mw'],
    "śatavāhī": ['mw'],
    "śatavāja": ['cae', 'gra', 'mw'],
    "śatavāra": ['mw'],
    "śatavārakam": ['mw'],
    "śatavāram": ['mw'],
    "śatavārṣika": ['mw'],
    "śatavīra": ['mw'],
    "śatavīrya": ['cae', 'mw'],
    "śatavīryā": ['mw'],
    "śatavṛṣabha": ['mw'],
    "śatavṛṣṇya": ['mw'],
    "śatayajvan": ['mw'],
    "śatayajña": ['cae', 'mw'],
    "śatayajñacāpa": ['mw'],
    "śatayajñopalakṣaka": ['mw'],
    "śatayajñopalakṣita": ['mw'],
    "śatayaṣṭika": ['cae', 'mw'],
    "śatayogamañjarī": ['mw'],
    "śatayojana": ['mw'],
    "śatayojanaparvata": ['mw'],
    "śatayoni": ['mw'],
    "śatayājam": ['mw'],
    "śatayāman": ['gra', 'mw'],
    "śatayātu": ['gra', 'mw'],
    "śatayāyin": ['mw'],
    "śatayāyinvat": ['mw'],
    "śatayūpa": ['mw'],
    "śataśakti": ['mw'],
    "śataśala": ['mw'],
    "śataśalya": ['mw'],
    "śataśalāka": ['mw'],
    "śataśalākā": ['mw'],
    "śataśarkara": ['mw'],
    "śataśarkaratā": ['mw'],
    "śataśas": ['ap90', 'cae', 'mw'],
    "śataślokavyavahāraka": ['mw'],
    "śataślokirāmāyaṇa": ['mw'],
    "śataślokī": ['mw'],
    "śataślokīcandrakalā": ['mw'],
    "śataślokīvyākhyā": ['mw'],
    "śataśākha": ['cae', 'mw'],
    "śataśākhatva": ['mw'],
    "śataśārada": ['cae', 'gra', 'mw'],
    "śataśāradāya": ['mw'],
    "śataśāstra": ['mw'],
    "śataśāstravaipulya": ['mw'],
    "śataśīrṣa": ['bhs', 'cae', 'mw'],
    "śataśīrṣan": ['cae', 'mw'],
    "śataśīrṣarudraśamanīya": ['mw'],
    "śataśīrṣā": ['bhs', 'mw'],
    "śataśṛṅga": ['cae', 'mw'],
    "śataśṛṅgamāhātmya": ['mw'],
    "śataṃ": ['ap90'],
    "śataṃhima": ['mw'],
    "śataṃjayā": ['mw'],
    "śatedhma": ['mw'],
    "śatendriya": ['cae', 'ddsa', 'mw'],
    "śatendriyā": ['mw'],
    "śatepañcāśannyāya": ['mw'],
    "śatera": ['mw'],
    "śateraḥ": ['ap90'],
    "śateśa": ['cae', 'mw'],
    "śateṣudhi": ['mw'],
    "śatika": ['ap90', 'cae', 'ddsa', 'mw'],
    "śatikavṛddhi": ['mw'],
    "śatikā": ['mw'],
    "śatima": ['bhs'],
    "śatin": ['ap90', 'cae', 'gra', 'mw'],
    "śatinībhis": ['mw'],
    "śatodara": ['cae', 'mw'],
    "śatodarī": ['mw'],
    "śatodyāma": ['mw'],
    "śatokthya": ['mw'],
    "śatolūkhalamekhalā": ['mw'],
    "śatonmāna": ['mw'],
    "śatopaniṣad": ['mw'],
    "śatoti": ['cae', 'ddsa', 'gra', 'mw'],
    "śatraṃjaya": ['mw'],
    "śatri": ['cae', 'gra', 'mw'],
    "śatru": ['cae', 'ddsa', 'gra', 'mw'],
    "śatrubha": ['mw'],
    "śatrubhaṅga": ['mw'],
    "śatrubhaṭa": ['mw'],
    "śatrubādhaka": ['mw'],
    "śatrubādhana": ['cae', 'mw'],
    "śatrudamana": ['mw'],
    "śatrugha": ['mw'],
    "śatrughna": ['cae', 'ddsa', 'mw'],
    "śatrughnajananī": ['mw'],
    "śatrughnaśarman": ['mw'],
    "śatrughnī": ['mw'],
    "śatrughāta": ['mw'],
    "śatrughātin": ['mw'],
    "śatrugṛha": ['mw'],
    "śatruha": ['cae', 'mw'],
    "śatruhan": ['cae', 'gra', 'mw'],
    "śatruhantṛ": ['mw'],
    "śatruhatyā": ['mw'],
    "śatrujana": ['mw'],
    "śatrujaya": ['mw'],
    "śatrujit": ['cae', 'mw'],
    "śatruka": ['mw'],
    "śatrukarśana": ['mw'],
    "śatrukarṣaṇa": ['mw'],
    "śatrukula": ['mw'],
    "śatruloka": ['mw'],
    "śatrulumpa": ['mw'],
    "śatrulāva": ['mw'],
    "śatrumardana": ['cae', 'mw'],
    "śatrumitropaśānti": ['mw'],
    "śatrunandana": ['cae', 'mw'],
    "śatrunibarhaṇa": ['mw'],
    "śatrunikāya": ['mw'],
    "śatrunilaya": ['mw'],
    "śatrunāśakṛt": ['mw'],
    "śatrunāśana": ['mw'],
    "śatrupakṣa": ['mw'],
    "śatruparājaya": ['mw'],
    "śatrurūpa": ['mw'],
    "śatrusaha": ['mw'],
    "śatrusammukham": ['mw'],
    "śatrusaṃhananakavaca": ['mw'],
    "śatrusevin": ['cae', 'mw'],
    "śatrusāha": ['cae', 'mw'],
    "śatrusāt": ['mw'],
    "śatrutas": ['mw'],
    "śatrutva": ['gra', 'mw'],
    "śatrutā": ['cae', 'mw'],
    "śatrutāpana": ['mw'],
    "śatrutūrya": ['cae', 'gra', 'mw'],
    "śatruvala": ['mw'],
    "śatruvat": ['mw'],
    "śatruvigraha": ['mw'],
    "śatruviloḍana": ['mw'],
    "śatruvināśana": ['mw'],
    "śatruśalyacarita": ['mw'],
    "śatruḥ": ['ap90'],
    "śatruṃdama": ['cae', 'mw'],
    "śatruṃjaya": ['cae', 'mw'],
    "śatruṃjayamāhātmya": ['mw'],
    "śatruṃjayastava": ['mw'],
    "śatruṃjayastotra": ['mw'],
    "śatruṃjayaḥ": ['ap90'],
    "śatruṃjayā": ['mw'],
    "śatruṃsaha": ['mw'],
    "śatruṃtapa": ['ap90', 'cae', 'mw'],
    "śatrūpajāpa": ['mw'],
    "śatrūpajāpadūṣita": ['mw'],
    "śatrūy": ['cae', 'gra'],
    "śatrūya": ['ddsa', 'mw'],
    "śatrūṣah": ['cae', 'gra', 'mw'],
    "śatrūṣāh": ['gra'],
    "śattri": ['mw'],
    "śattriḥ": ['ap90'],
    "śatvarī": ['ap90', 'mw'],
    "śatya": ['cae', 'ddsa', 'mw'],
    "śatā": ['mw'],
    "śatābda": ['cae', 'mw'],
    "śatābja": ['mw'],
    "śatādhika": ['cae', 'mw'],
    "śatādhipati": ['mw'],
    "śatādhyāya": ['mw'],
    "śatāgniṣṭoma": ['mw'],
    "śatāgra": ['mw'],
    "śatāgramahiṣī": ['mw'],
    "śatāhvayā": ['mw'],
    "śatāhvā": ['mw'],
    "śatājit": ['mw'],
    "śatākarā": ['bhs', 'mw'],
    "śatākārā": ['bhs', 'mw'],
    "śatākṣa": ['mw'],
    "śatākṣara": ['bhs', 'mw'],
    "śatākṣī": ['mw'],
    "śatāmagha": ['gra', 'mw'],
    "śatānaka": ['mw'],
    "śatānana": ['mw'],
    "śatānanda": ['mw'],
    "śatānandasaṃhitā": ['mw'],
    "śatānandā": ['mw'],
    "śatānanā": ['mw'],
    "śatānīka": ['cae', 'gra', 'mw'],
    "śatāpadī": ['bhs', 'mw'],
    "śatāparādhaprāyaścitta": ['mw'],
    "śatāparādhastotra": ['mw'],
    "śatāpāṣṭha": ['mw'],
    "śatāra": ['mw'],
    "śatārdha": ['cae', 'mw'],
    "śatārdhasaṃkhya": ['mw'],
    "śatārdhāra": ['mw'],
    "śatārgha": ['cae', 'mw'],
    "śatārha": ['cae', 'mw'],
    "śatāritra": ['gra', 'mw'],
    "śatāruka": ['mw'],
    "śatārus": ['mw'],
    "śatāruṇa": ['mw'],
    "śatāruṣa": ['mw'],
    "śatāruṣī": ['mw'],
    "śatārṇā": ['mw'],
    "śatātirātra": ['mw'],
    "śatātman": ['cae', 'ddsa', 'gra', 'mw'],
    "śatātṛṇṇa": ['mw'],
    "śatātṛṇṇā": ['mw'],
    "śatātṛṣṇā": ['mw'],
    "śatāvadhāna": ['mw'],
    "śatāvara": ['mw'],
    "śatāvarta": ['mw'],
    "śatāvartavana": ['mw'],
    "śatāvartin": ['mw'],
    "śatāvaruṇa": ['mw'],
    "śatāvarī": ['cae', 'mw'],
    "śatāvat": ['gra', 'mw'],
    "śatāvaya": ['gra', 'mw'],
    "śatāyu": ['cae', 'mw'],
    "śatāyudha": ['cae', 'mw'],
    "śatāyudhā": ['bhs', 'mw'],
    "śatāyus": ['cae', 'gra', 'mw'],
    "śatāyutā": ['mw'],
    "śatāśri": ['cae', 'gra', 'mw'],
    "śatāśva": ['cae', 'gra', 'mw'],
    "śatāśvaratha": ['mw'],
    "śatāśvavijaya": ['mw'],
    "śatāṃśa": ['mw'],
    "śatāṃśaka": ['mw'],
    "śatāṅga": ['cae', 'mw'],
    "śatāṅkura": ['mw'],
    "śatāṣṭaka": ['mw'],
    "śatī": ['mw'],
    "śatīkarṇa": ['mw'],
    "śatṛ": ['ap90', 'ddsa', 'mw'],
    "śaubha": ['mw'],
    "śaubhaneya": ['mw'],
    "śaubhaḥ": ['ap90'],
    "śaubhika": ['mw'],
    "śaubhikaḥ": ['ap90'],
    "śaubhreya": ['mw'],
    "śaubhreyī": ['mw'],
    "śaubhrya": ['mw'],
    "śaubhrāyaṇa": ['mw'],
    "śaubhrāyaṇabhakta": ['mw'],
    "śaubhuśubha": ['mw'],
    "śaubhāyana": ['mw'],
    "śaubhāyani": ['mw'],
    "śaubhāyanya": ['mw'],
    "śaubhāñjana": ['mw'],
    "śaubhāṃjanaḥ": ['ap90'],
    "śauca": ['cae', 'ddsa', 'mw'],
    "śaucadratha": ['gra', 'mw'],
    "śaucaka": ['bhs', 'mw'],
    "śaucakalpa": ['cae', 'mw'],
    "śaucakīya": ['mw'],
    "śaucakūpa": ['mw'],
    "śaucapara": ['cae'],
    "śaucaprepsu": ['cae'],
    "śaucasaṃgrahavivṛti": ['mw'],
    "śaucatas": ['mw'],
    "śaucatva": ['mw'],
    "śaucavant": ['cae'],
    "śaucavat": ['mw'],
    "śaucavidhi": ['mw'],
    "śaucaṃ": ['ap90'],
    "śaucepsu": ['mw'],
    "śauceya": ['mw'],
    "śauceyaḥ": ['ap90'],
    "śaucika": ['mw'],
    "śaucikarṇika": ['mw'],
    "śaucikaḥ": ['ap90'],
    "śaucin": ['mw'],
    "śaucivṛkṣi": ['mw'],
    "śaucācamanavidhi": ['mw'],
    "śaucācāra": ['mw'],
    "śaucācārapaddhati": ['mw'],
    "śaucādireya": ['mw'],
    "śauddhodani": ['ddsa', 'mw'],
    "śauddhodaniḥ": ['ap90'],
    "śauddhākṣara": ['mw'],
    "śaudhikā": ['mw'],
    "śaudra": ['ap90', 'cae', 'ddsa', 'mw'],
    "śaudrakāyaṇa": ['mw'],
    "śaudrāyaṇa": ['mw'],
    "śaudrāyaṇabhakta": ['mw'],
    "śauka": ['mw'],
    "śaukara": ['mw'],
    "śaukaṃ": ['ap90'],
    "śaukeya": ['mw'],
    "śauki": ['mw'],
    "śaukla": ['mw'],
    "śauklikeya": ['mw'],
    "śauklikeyaḥ": ['ap90'],
    "śauklya": ['cae', 'ddsa', 'mw'],
    "śauklyaṃ": ['ap90'],
    "śaukra": ['ap90', 'mw'],
    "śaukreya": ['mw'],
    "śaukri": ['mw'],
    "śaukrya": ['mw'],
    "śaukrāyaṇa": ['mw'],
    "śaukta": ['ddsa', 'mw'],
    "śauktaṃ": ['ap90'],
    "śaukteya": ['mw'],
    "śauktika": ['ap90', 'mw'],
    "śauktikeya": ['mw'],
    "śauktikeyaṃ": ['ap90'],
    "śaula": ['cae', 'mw'],
    "śaulba": ['mw'],
    "śaulbika": ['bhs', 'mw'],
    "śaulbikaḥ": ['ap90'],
    "śaulbāyana": ['mw'],
    "śaulika": ['mw'],
    "śaulka": ['mw'],
    "śaulkaśālika": ['mw'],
    "śaulkaḥ": ['ap90'],
    "śaulkika": ['cae', 'ddsa', 'mw'],
    "śaulkikeya": ['mw'],
    "śaulkāyani": ['mw'],
    "śaulpha": ['mw'],
    "śaulvikaḥ": ['ap90'],
    "śaulāyana": ['mw'],
    "śauna": ['cae', 'ddsa', 'mw'],
    "śaunahotra": ['mw'],
    "śaunahotri": ['mw'],
    "śaunaka": ['cae', 'ddsa', 'mw'],
    "śaunakagṛhyapariśiṣṭa": ['mw'],
    "śaunakagṛhyasūtra": ['mw'],
    "śaunakakalpasūtra": ['mw'],
    "śaunakakārikā": ['mw'],
    "śaunakapañcasūtra": ['mw'],
    "śaunakasmṛti": ['mw'],
    "śaunakasūtra": ['mw'],
    "śaunakayajña": ['mw'],
    "śaunakaḥ": ['ap90'],
    "śaunaki": ['mw'],
    "śaunakin": ['mw'],
    "śaunakopaniṣad": ['mw'],
    "śaunakāraṇyaka": ['mw'],
    "śaunakātharvaṇasūtra": ['mw'],
    "śaunakāyana": ['mw'],
    "śaunakī": ['mw'],
    "śaunakīputra": ['mw'],
    "śaunakīya": ['mw'],
    "śaunakīyacaraṇa": ['mw'],
    "śaunakīyacaturādhyāyikā": ['mw'],
    "śaunakīyaprayoga": ['mw'],
    "śaunakīyasvarāṣṭaka": ['mw'],
    "śaunaḥśepa": ['cae', 'ddsa', 'mw'],
    "śaunaḥśepi": ['mw'],
    "śaunaṃ": ['ap90'],
    "śaunika": ['mw'],
    "śaunikaśāstra": ['mw'],
    "śaunikaḥ": ['ap90'],
    "śaunāsīrya": ['mw'],
    "śaunāyana": ['mw'],
    "śaura": ['mw'],
    "śauradevia": ['gra'],
    "śauradevya": ['gra', 'mw'],
    "śaurasena": ['cae', 'ddsa', 'mw'],
    "śaurasenikā": ['mw'],
    "śaurasenya": ['mw'],
    "śaurasenī": ['ap90', 'mw'],
    "śauraṇa": ['mw'],
    "śauri": ['cae', 'ddsa', 'mw'],
    "śauridatta": ['mw'],
    "śaurisūnu": ['mw'],
    "śauriḥ": ['ap90'],
    "śaurpa": ['ap90', 'mw'],
    "śaurpaṇāyya": ['mw'],
    "śaurpika": ['mw'],
    "śaurya": ['cae', 'ddsa', 'mw'],
    "śauryakaraṇa": ['mw'],
    "śauryakarman": ['cae', 'mw'],
    "śauryanagara": ['mw'],
    "śauryarāśi": ['mw'],
    "śauryasāgara": ['mw'],
    "śauryaudaryaśṛṅgāramaya": ['mw'],
    "śauryavant": ['cae'],
    "śauryavardhana": ['mw'],
    "śauryavat": ['mw'],
    "śauryavrata": ['mw'],
    "śauryaṃ": ['ap90'],
    "śauryonmādin": ['mw'],
    "śauryopārjita": ['mw'],
    "śauryādimat": ['mw'],
    "śauva": ['ap90', 'cae', 'ddsa', 'mw'],
    "śauvadaṃṣṭra": ['mw'],
    "śauvahāna": ['mw'],
    "śauvana": ['ap90', 'mw'],
    "śauvaneya": ['mw'],
    "śauvani": ['mw'],
    "śauvastika": ['ap90', 'cae', 'ddsa', 'mw'],
    "śauvastikatva": ['mw'],
    "śauvādaṃṣṭra": ['mw'],
    "śauvāpada": ['ap90', 'mw'],
    "śauvāvatāna": ['mw'],
    "śauvāvatānika": ['mw'],
    "śauvāvidha": ['mw'],
    "śauḍ": ['ap90', 'mw'],
    "śauḍa": ['ddsa', 'mw'],
    "śauṃḍa": ['ap90'],
    "śauṃḍikaḥ": ['ap90'],
    "śauṃḍikeyaḥ": ['ap90'],
    "śauṃḍī": ['ap90'],
    "śauṃḍīra": ['ap90'],
    "śauṅga": ['mw'],
    "śauṅgeya": ['cae', 'ddsa', 'mw'],
    "śauṅgi": ['mw'],
    "śauṅgya": ['mw'],
    "śauṅgāyani": ['mw'],
    "śauṅgīputra": ['mw'],
    "śauṅgīya": ['mw'],
    "śauṇḍa": ['cae', 'ddsa', 'mw'],
    "śauṇḍaka": ['mw'],
    "śauṇḍarya": ['mw'],
    "śauṇḍatā": ['mw'],
    "śauṇḍeya": ['mw'],
    "śauṇḍi": ['mw'],
    "śauṇḍika": ['cae', 'mw'],
    "śauṇḍikeya": ['ddsa', 'mw'],
    "śauṇḍikāgāra": ['cae', 'mw'],
    "śauṇḍikāpaṇa": ['cae'],
    "śauṇḍikī": ['mw'],
    "śauṇḍin": ['mw'],
    "śauṇḍinya": ['bhs'],
    "śauṇḍinī": ['bhs', 'mw'],
    "śauṇḍrin": ['mw'],
    "śauṇḍā": ['mw'],
    "śauṇḍāpeya": ['bhs'],
    "śauṇḍāyana": ['mw'],
    "śauṇḍāyanya": ['mw'],
    "śauṇḍī": ['mw'],
    "śauṇḍīka": ['mw'],
    "śauṇḍīra": ['cae', 'mw'],
    "śauṇḍīratā": ['mw'],
    "śauṇḍīrya": ['ddsa', 'mw'],
    "śauṣira": ['mw'],
    "śauṣkala": ['mw'],
    "śauṣkalaḥ": ['ap90'],
    "śauṣkula": ['mw'],
    "śauṣkāsya": ['mw'],
    "śauṭ": ['ap90', 'mw'],
    "śauṭa": ['mw'],
    "śauṭīra": ['ap90', 'cae', 'ddsa', 'mw'],
    "śauṭīraka": ['bhs'],
    "śauṭīratā": ['mw'],
    "śauṭīrya": ['mw'],
    "śauṭīryaṃ": ['ap90'],
    "śav": ['ap90', 'ddsa', 'mw'],
    "śava": ['bhs', 'cae', 'ddsa', 'mw'],
    "śavabhasman": ['mw'],
    "śavabhūta": ['mw'],
    "śavadahyā": ['cae', 'mw'],
    "śavadhara": ['cae', 'mw'],
    "śavadhāna": ['mw'],
    "śavadāha": ['mw'],
    "śavadāhaka": ['mw'],
    "śavadāhin": ['mw'],
    "śavagandhin": ['mw'],
    "śavakarman": ['cae', 'mw'],
    "śavakāmya": ['mw'],
    "śavakṛt": ['mw'],
    "śavala": ['ap90'],
    "śavalokadhātu": ['mw'],
    "śavalāśva": ['bhs'],
    "śavamandira": ['mw'],
    "śavanabhya": ['mw'],
    "śavapannaga": ['mw'],
    "śavara": ['ap90', 'ddsa', 'mw'],
    "śavaratha": ['mw'],
    "śavaraḥ": ['ap90'],
    "śavarga": ['mw'],
    "śavarta": ['cae'],
    "śavarūpa": ['mw'],
    "śavas": ['cae', 'ddsa', 'gra', 'mw'],
    "śavasin": ['ddsa', 'gra', 'mw'],
    "śavasparśa": ['mw'],
    "śavaspṛś": ['cae', 'mw'],
    "śavasā": ['mw'],
    "śavasādhana": ['mw'],
    "śavasāna": ['cae', 'ddsa', 'gra', 'mw'],
    "śavasānaḥ": ['ap90'],
    "śavasāvant": ['cae'],
    "śavasāvat": ['gra', 'mw'],
    "śavasī": ['cae', 'gra', 'mw'],
    "śavaviṣa": ['mw'],
    "śavavāha": ['cae', 'mw'],
    "śavavāhaka": ['cae', 'mw'],
    "śavayāna": ['mw'],
    "śavaśatamaya": ['mw'],
    "śavaśayana": ['mw'],
    "śavaśibikā": ['mw'],
    "śavaśiras": ['cae', 'mw'],
    "śavaśirodhvaja": ['cae', 'mw'],
    "śavaśīrṣaka": ['mw'],
    "śavaḥ": ['ap90'],
    "śaviṣṭha": ['cae', 'ddsa', 'gra'],
    "śavodvaha": ['cae', 'mw'],
    "śavya": ['cae', 'mw'],
    "śavācchādana": ['mw'],
    "śavāgni": ['cae', 'ddsa', 'mw'],
    "śavānna": ['cae', 'mw'],
    "śavāsthimālika": ['mw'],
    "śavāśa": ['mw'],
    "śavīra": ['cae', 'gra'],
    "śaya": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śayadhyai": ['cae', 'ddsa', 'mw'],
    "śayana": ['cae', 'ddsa', 'mw'],
    "śayanabhūmi": ['mw'],
    "śayanagṛha": ['cae', 'mw'],
    "śayanaikādaśī": ['mw'],
    "śayanapālikā": ['mw'],
    "śayanaracana": ['mw'],
    "śayanasakhī": ['mw'],
    "śayanastha": ['cae', 'mw'],
    "śayanasthāna": ['mw'],
    "śayanatalagata": ['mw'],
    "śayanavidha": ['mw'],
    "śayanavāsas": ['cae', 'mw'],
    "śayanaṃ": ['ap90'],
    "śayantaka": ['bhs'],
    "śayanāgāra": ['mw'],
    "śayanāsana": ['mw'],
    "śayanāsanasevana": ['mw'],
    "śayanāsanavārika": ['mw'],
    "śayanāspada": ['mw'],
    "śayanāvāsa": ['mw'],
    "śayanīkṛ": ['ddsa', 'mw'],
    "śayanīya": ['cae', 'ddsa', 'mw'],
    "śayanīyagṛha": ['cae', 'mw'],
    "śayanīyaka": ['mw'],
    "śayanīyam": ['mw'],
    "śayanīyatala": ['mw'],
    "śayanīyavāsa": ['mw'],
    "śayanīyaṃ": ['ap90'],
    "śayanīyāśrita": ['mw'],
    "śayata": ['mw'],
    "śayatha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śayavatī": ['bhs'],
    "śayaṃḍa": ['ap90'],
    "śayaṇḍa": ['mw'],
    "śayaṇḍabhakta": ['mw'],
    "śayaṇḍaka": ['mw'],
    "śaye": ['ddsa'],
    "śayi": ['bhs'],
    "śayin": ['bhs'],
    "śayita": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śayitaka": ['bhs'],
    "śayitavat": ['mw'],
    "śayitavya": ['cae', 'mw'],
    "śayitṛ": ['mw'],
    "śayu": ['cae', 'ddsa', 'gra', 'mw'],
    "śayuna": ['mw'],
    "śayutrā": ['cae', 'gra', 'mw'],
    "śayuḥ": ['ap90'],
    "śayyambhadra": ['mw'],
    "śayyambhava": ['mw'],
    "śayyotsaṅga": ['mw'],
    "śayyotthāyam": ['mw'],
    "śayyā": ['ap90', 'cae', 'ddsa', 'mw'],
    "śayyācchādana": ['mw'],
    "śayyādhyakṣa": ['mw'],
    "śayyādāna": ['mw'],
    "śayyādānapaddhati": ['mw'],
    "śayyāgata": ['mw'],
    "śayyāgṛha": ['cae', 'mw'],
    "śayyākāla": ['mw'],
    "śayyāmūtra": ['mw'],
    "śayyāntara": ['mw'],
    "śayyāprayoga": ['mw'],
    "śayyāprāntavivartana": ['mw'],
    "śayyāpāla": ['mw'],
    "śayyāpālaka": ['mw'],
    "śayyāpālatva": ['mw'],
    "śayyāsana": ['mw'],
    "śayyāsanabhoga": ['mw'],
    "śayyāsanastha": ['mw'],
    "śayyātara": ['mw'],
    "śayyāveśman": ['mw'],
    "śayyāvāsaveśman": ['mw'],
    "śayā": ['bhs', 'ddsa', 'gra', 'mw'],
    "śayābja": ['ddsa'],
    "śayālu": ['ap90', 'cae', 'ddsa', 'mw'],
    "śayāna": ['ddsa', 'mw'],
    "śayānaka": ['mw'],
    "śayānakaḥ": ['ap90'],
    "śayāṇḍa": ['mw'],
    "śayāṇḍabhakta": ['mw'],
    "śayāṇḍaka": ['mw'],
    "śayīci": ['mw'],
    "śañc": ['mw'],
    "śaś": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śaśa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śaśabhṛdbhṛt": ['mw'],
    "śaśabhṛt": ['cae', 'mw'],
    "śaśabindu": ['cae', 'mw'],
    "śaśadhara": ['cae', 'ddsa', 'mw'],
    "śaśadharamauli": ['mw'],
    "śaśadharamukhī": ['mw'],
    "śaśadharamālā": ['mw'],
    "śaśadharaprabhā": ['mw'],
    "śaśadharman": ['mw'],
    "śaśadharācārya": ['mw'],
    "śaśadharīya": ['mw'],
    "śaśaghna": ['mw'],
    "śaśaghnī": ['mw'],
    "śaśaghātaka": ['mw'],
    "śaśaghātin": ['mw'],
    "śaśahan": ['mw'],
    "śaśaka": ['cae', 'mw'],
    "śaśakarajas": ['bhs'],
    "śaśakarṇa": ['mw'],
    "śaśakaviṣāṇa": ['cae', 'mw'],
    "śaśakaśiśu": ['mw'],
    "śaśakaḥ": ['ap90'],
    "śaśaketu": ['mw'],
    "śaśakādhama": ['mw'],
    "śaśalakṣaṇa": ['cae', 'mw'],
    "śaśalakṣman": ['cae', 'ddsa', 'mw'],
    "śaśalakṣmaṇa": ['mw'],
    "śaśaloman": ['mw'],
    "śaśalupta": ['mw'],
    "śaśalāñchana": ['cae', 'mw'],
    "śaśamuṇḍarasa": ['mw'],
    "śaśamāna": ['cae', 'mw'],
    "śaśamātra": ['mw'],
    "śaśapada": ['mw'],
    "śaśapadaśakti": ['mw'],
    "śaśaplutaka": ['mw'],
    "śaśarajas": ['mw'],
    "śaśasthalī": ['mw'],
    "śaśat": ['mw'],
    "śaśaviṣāṇa": ['cae', 'mw'],
    "śaśaviṣāṇāya": ['mw'],
    "śaśaya": ['cae', 'ddsa', 'gra', 'mw'],
    "śaśayu": ['cae', 'mw'],
    "śaśayāna": ['mw'],
    "śaśaśimbikā": ['mw'],
    "śaśaśṛṅga": ['cae', 'mw'],
    "śaśaḥ": ['ap90'],
    "śaśi": ['mw'],
    "śaśibhās": ['mw'],
    "śaśibhūṣaṇa": ['mw'],
    "śaśibhṛt": ['mw'],
    "śaśibindu": ['mw'],
    "śaśidaiva": ['mw'],
    "śaśideva": ['mw'],
    "śaśidhara": ['mw'],
    "śaśidharamaṅgalamata": ['mw'],
    "śaśidhvaja": ['mw'],
    "śaśidhāman": ['mw'],
    "śaśidivākara": ['mw'],
    "śaśigaccha": ['mw'],
    "śaśigraha": ['mw'],
    "śaśigrahasamāgama": ['mw'],
    "śaśiguhyā": ['mw'],
    "śaśigupta": ['mw'],
    "śaśija": ['mw'],
    "śaśika": ['mw'],
    "śaśikalā": ['cae', 'ddsa', 'mw'],
    "śaśikalābharaṇa": ['mw'],
    "śaśikalāpañcāśikā": ['mw'],
    "śaśikara": ['mw'],
    "śaśiketu": ['bhs', 'mw'],
    "śaśikhaṇḍa": ['mw'],
    "śaśikhaṇḍapada": ['mw'],
    "śaśikhaṇḍaśekhara": ['mw'],
    "śaśikiraṇa": ['mw'],
    "śaśikoṭi": ['mw'],
    "śaśikānta": ['mw'],
    "śaśikāntā": ['mw'],
    "śaśikṣaya": ['mw'],
    "śaśilekhā": ['cae', 'mw'],
    "śaśimat": ['mw'],
    "śaśimauli": ['cae', 'mw'],
    "śaśimaya": ['mw'],
    "śaśimayūkha": ['mw'],
    "śaśimaṇi": ['mw'],
    "śaśimaṇḍala": ['mw'],
    "śaśimaṇḍalābha": ['bhs'],
    "śaśimukha": ['bhs', 'mw'],
    "śaśimukhī": ['cae', 'mw'],
    "śaśin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śaśinī": ['ap90', 'mw'],
    "śaśiprabha": ['cae', 'mw'],
    "śaśiprabhā": ['mw'],
    "śaśipriya": ['mw'],
    "śaśipriyā": ['mw'],
    "śaśiputra": ['ddsa', 'mw'],
    "śaśipāda": ['mw'],
    "śaśiraśmi": ['mw'],
    "śaśirekhā": ['mw'],
    "śaśisaṃnibha": ['cae', 'mw'],
    "śaśisuta": ['mw'],
    "śaśitanaya": ['mw'],
    "śaśitejas": ['bhs', 'mw'],
    "śaśivadanā": ['cae', 'mw'],
    "śaśivaktradevī": ['bhs'],
    "śaśivardhana": ['mw'],
    "śaśivaṃśa": ['mw'],
    "śaśivaṃśaja": ['mw'],
    "śaśivimala": ['bhs', 'mw'],
    "śaśivimalagarbha": ['bhs'],
    "śaśivāsara": ['mw'],
    "śaśivāṭikā": ['mw'],
    "śaśiśekhara": ['cae', 'mw'],
    "śaśiśikhāmaṇi": ['mw'],
    "śaśolūkamukhī": ['mw'],
    "śaśorṇa": ['mw'],
    "śaśva": ['mw'],
    "śaśvacai": ['mw'],
    "śaśvacchānti": ['mw'],
    "śaśvadhā": ['cae', 'ddsa', 'gra', 'mw'],
    "śaśvant": ['cae'],
    "śaśvat": ['ap90', 'ddsa', 'gra', 'mw'],
    "śaśvatkāma": ['mw'],
    "śaśvattama": ['mw'],
    "śaśvattamam": ['mw'],
    "śaśvāya": ['mw'],
    "śaśāda": ['mw'],
    "śaśādana": ['mw'],
    "śaśākṣa": ['mw'],
    "śaśāṅka": ['cae', 'ddsa', 'mw'],
    "śaśāṅkabhās": ['mw'],
    "śaśāṅkabimba": ['mw'],
    "śaśāṅkadhara": ['mw'],
    "śaśāṅkaja": ['mw'],
    "śaśāṅkakiraṇaprakhya": ['mw'],
    "śaśāṅkakula": ['mw'],
    "śaśāṅkakānta": ['mw'],
    "śaśāṅkalekhā": ['cae', 'mw'],
    "śaśāṅkamukuṭa": ['mw'],
    "śaśāṅkamūrti": ['mw'],
    "śaśāṅkapura": ['mw'],
    "śaśāṅkasuta": ['mw'],
    "śaśāṅkatanaya": ['mw'],
    "śaśāṅkavadanā": ['cae', 'mw'],
    "śaśāṅkavatī": ['mw'],
    "śaśāṅkaśatru": ['mw'],
    "śaśāṅkaśekhara": ['mw'],
    "śaśāṅkaśṛṅga": ['mw'],
    "śaśāṅkita": ['ddsa', 'mw'],
    "śaśāṅkopala": ['mw'],
    "śaśāṅkārdha": ['mw'],
    "śaśāṅkārdhamukha": ['mw'],
    "śaśāṅkārdhaśekhara": ['mw'],
    "śaśāṅkāśmajavāsara": ['mw'],
    "śaśāṇḍuli": ['mw'],
    "śaśāṇḍulī": ['mw'],
    "śaśī": ['bhs', 'mw'],
    "śaśībha": ['mw'],
    "śaśībhū": ['mw'],
    "śaśīyas": ['ddsa', 'gra', 'mw'],
    "śaśīyaṃs": ['cae'],
    "śaśīśa": ['ddsa', 'mw'],
    "śaśīśaśiśu": ['mw'],
    "śaśīśaśiśuśī": ['mw'],
    "śaḍha": ['bhs'],
    "śaḍhī": ['mw'],
    "śaḥ": ['ap90'],
    "śaṃ": ['mw'],
    "śaṃb": ['ap90'],
    "śaṃba": ['ap90'],
    "śaṃbalaḥ": ['ap90'],
    "śaṃbalī": ['ap90'],
    "śaṃbara": ['ap90'],
    "śaṃbarī": ['ap90'],
    "śaṃbhalī": ['ap90'],
    "śaṃbhava": ['cae'],
    "śaṃbhaviṣṭha": ['cae'],
    "śaṃbhaḥ": ['ap90'],
    "śaṃbhu": ['ap90', 'cae'],
    "śaṃbhukāntā": ['cae'],
    "śaṃbhū": ['cae'],
    "śaṃbuḥ": ['ap90'],
    "śaṃbūkaḥ": ['ap90'],
    "śaṃc": ['ap90'],
    "śaṃga": ['cae', 'mw'],
    "śaṃgarā": ['mw'],
    "śaṃgavī": ['cae', 'mw'],
    "śaṃgaya": ['cae', 'gra', 'mw'],
    "śaṃgayī": ['gra'],
    "śaṃgerī": ['bhs'],
    "śaṃgu": ['mw'],
    "śaṃk": ['ap90'],
    "śaṃkanīya": ['ap90'],
    "śaṃkara": ['ap90', 'bhs', 'cae', 'mw'],
    "śaṃkarabhaṭṭa": ['mw'],
    "śaṃkarabhaṭṭī": ['mw'],
    "śaṃkarabhaṭṭīya": ['mw'],
    "śaṃkarabhāratītīrtha": ['mw'],
    "śaṃkarabhāṣyanyāyasaṃgraha": ['mw'],
    "śaṃkarabindu": ['mw'],
    "śaṃkaracaritra": ['mw'],
    "śaṃkaracetovilāsa": ['mw'],
    "śaṃkaradatta": ['mw'],
    "śaṃkaradayālu": ['mw'],
    "śaṃkaradeva": ['mw'],
    "śaṃkaradhara": ['mw'],
    "śaṃkaradigvijaya": ['mw'],
    "śaṃkaradigvijayasāra": ['mw'],
    "śaṃkaradigvijayaḍiṇḍima": ['mw'],
    "śaṃkaradāsa": ['mw'],
    "śaṃkaradīkṣita": ['mw'],
    "śaṃkaragaurīśa": ['mw'],
    "śaṃkaragaṇa": ['mw'],
    "śaṃkaragiri": ['mw'],
    "śaṃkaragītā": ['mw'],
    "śaṃkaragṛha": ['cae'],
    "śaṃkarajaya": ['mw'],
    "śaṃkarajit": ['mw'],
    "śaṃkarajī": ['mw'],
    "śaṃkarajīka": ['mw'],
    "śaṃkarakathā": ['mw'],
    "śaṃkarakavaca": ['mw'],
    "śaṃkarakavi": ['mw'],
    "śaṃkarakiṃkara": ['mw'],
    "śaṃkarakiṃkarībhava": ['mw'],
    "śaṃkarakroḍa": ['mw'],
    "śaṃkaralāla": ['mw'],
    "śaṃkaramandārasaurabha": ['mw'],
    "śaṃkaramiśra": ['mw'],
    "śaṃkaranārāyaṇa": ['mw'],
    "śaṃkaranārāyaṇamāhātmya": ['mw'],
    "śaṃkaranārāyaṇāṣṭottaraśata": ['mw'],
    "śaṃkarapati": ['mw'],
    "śaṃkarapattra": ['mw'],
    "śaṃkarapriya": ['mw'],
    "śaṃkarapriyā": ['mw'],
    "śaṃkaraprādurbhāva": ['mw'],
    "śaṃkarapuṣpa": ['mw'],
    "śaṃkarapādabhūṣaṇa": ['mw'],
    "śaṃkararkṣa": ['mw'],
    "śaṃkarasambhava": ['mw'],
    "śaṃkarasaṃhitā": ['mw'],
    "śaṃkarasena": ['mw'],
    "śaṃkarasiddhi": ['mw'],
    "śaṃkarastotra": ['mw'],
    "śaṃkarastuti": ['mw'],
    "śaṃkarasvāmin": ['mw'],
    "śaṃkaratīrtha": ['mw'],
    "śaṃkaravardhana": ['mw'],
    "śaṃkaravarman": ['mw'],
    "śaṃkaravijaya": ['cae', 'mw'],
    "śaṃkaravijayavilāsa": ['mw'],
    "śaṃkaravilāsa": ['mw'],
    "śaṃkaravilāsacampū": ['mw'],
    "śaṃkaraśikṣā": ['mw'],
    "śaṃkaraśukla": ['mw'],
    "śaṃkaraśukra": ['mw'],
    "śaṃkaraśvaśura": ['mw'],
    "śaṃkarā": ['mw'],
    "śaṃkarābharaṇa": ['mw'],
    "śaṃkarābhyudaya": ['mw'],
    "śaṃkarācārya": ['cae', 'mw'],
    "śaṃkarācāryacarita": ['mw'],
    "śaṃkarācāryavijayaḍiṇḍima": ['mw'],
    "śaṃkarācāryotpatti": ['mw'],
    "śaṃkarācāryāvatārakathā": ['mw'],
    "śaṃkarākhya": ['mw'],
    "śaṃkarālaya": ['cae', 'mw'],
    "śaṃkarānanda": ['mw'],
    "śaṃkarānandanātha": ['mw'],
    "śaṃkarānandatīrtha": ['mw'],
    "śaṃkarāvāsa": ['mw'],
    "śaṃkarāṣṭaka": ['mw'],
    "śaṃkarī": ['mw'],
    "śaṃkarīgīta": ['mw'],
    "śaṃkarīgīti": ['mw'],
    "śaṃkarīya": ['mw'],
    "śaṃkavyaṃ": ['ap90'],
    "śaṃkaḥ": ['ap90'],
    "śaṃkhakaḥ": ['ap90'],
    "śaṃkhanakaḥ": ['ap90'],
    "śaṃkhanakhaḥ": ['ap90'],
    "śaṃkhaḥ": ['ap90'],
    "śaṃkhin": ['ap90'],
    "śaṃkhinī": ['ap90'],
    "śaṃkin": ['ap90'],
    "śaṃkita": ['ap90'],
    "śaṃkuciḥ": ['ap90'],
    "śaṃkulā": ['ap90'],
    "śaṃkura": ['ap90'],
    "śaṃkuḥ": ['ap90'],
    "śaṃkā": ['ap90'],
    "śaṃkāra": ['bhs'],
    "śaṃkṛt": ['cae', 'mw'],
    "śaṃnodevī": ['mw'],
    "śaṃnodevīya": ['mw'],
    "śaṃpā": ['ap90'],
    "śaṃs": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śaṃsa": ['cae', 'ddsa', 'gra', 'mw'],
    "śaṃsana": ['cae', 'mw'],
    "śaṃsanaṃ": ['ap90'],
    "śaṃsanīya": ['cae', 'mw'],
    "śaṃsatha": ['cae', 'ddsa', 'mw'],
    "śaṃsaḥ": ['ap90'],
    "śaṃsin": ['ap90', 'cae', 'gra', 'mw'],
    "śaṃsita": ['ap90', 'cae', 'mw'],
    "śaṃsitṛ": ['cae', 'mw'],
    "śaṃsivas": ['mw'],
    "śaṃstavya": ['cae', 'mw'],
    "śaṃstha": ['mw'],
    "śaṃsthā": ['mw'],
    "śaṃstṛ": ['ap90', 'cae', 'mw'],
    "śaṃsya": ['cae', 'mw'],
    "śaṃsā": ['ap90', 'mw'],
    "śaṃtama": ['gra', 'mw'],
    "śaṃtanu": ['cae', 'gra', 'mw'],
    "śaṃtanutanūja": ['mw'],
    "śaṃtanutva": ['mw'],
    "śaṃtanuḥ": ['ap90'],
    "śaṃtva": ['mw'],
    "śaṃtāti": ['gra', 'mw'],
    "śaṃtātīya": ['mw'],
    "śaṃva": ['ap90', 'mw'],
    "śaṃvada": ['mw'],
    "śaṃvant": ['cae'],
    "śaṃvara": ['bhs'],
    "śaṃvat": ['mw'],
    "śaṃvaḥ": ['ap90'],
    "śaṃya": ['mw'],
    "śaṃyorvāka": ['mw'],
    "śaṃyos": ['cae', 'gra', 'mw'],
    "śaṃyu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śaṃyudhāyas": ['mw'],
    "śaṃyuvāka": ['ddsa', 'mw'],
    "śaṃyvanta": ['mw'],
    "śaṃśamam": ['mw'],
    "śaṃḍ": ['ap90'],
    "śaṃḍaḥ": ['ap90'],
    "śaṃḍhaḥ": ['ap90'],
    "śaṃṭhaḥ": ['ap90'],
    "śaṅgaya": ['ddsa'],
    "śaṅk": ['cae', 'ddsa', 'gra', 'mw'],
    "śaṅka": ['mw'],
    "śaṅkalā": ['bhs'],
    "śaṅkana": ['mw'],
    "śaṅkanīya": ['cae', 'ddsa', 'mw'],
    "śaṅkara": ['ddsa', 'mw'],
    "śaṅkatvanirukti": ['mw'],
    "śaṅkavya": ['ddsa', 'mw'],
    "śaṅkha": ['bhs', 'cae', 'ddsa', 'mw'],
    "śaṅkhabhasman": ['mw'],
    "śaṅkhabhinna": ['mw'],
    "śaṅkhabhṛt": ['cae', 'mw'],
    "śaṅkhacakra": ['mw'],
    "śaṅkhacakradhāraṇavāda": ['mw'],
    "śaṅkhacakragadādhara": ['mw'],
    "śaṅkhacakrapāṇi": ['cae', 'mw'],
    "śaṅkhacakravidhi": ['mw'],
    "śaṅkhacakravivaraṇa": ['mw'],
    "śaṅkhacarcī": ['mw'],
    "śaṅkhacarī": ['mw'],
    "śaṅkhacilla": ['mw'],
    "śaṅkhacūrṇa": ['mw'],
    "śaṅkhacūḍa": ['mw'],
    "śaṅkhacūḍeśvaratīrtha": ['mw'],
    "śaṅkhadatta": ['ddsa', 'mw'],
    "śaṅkhadhara": ['mw'],
    "śaṅkhadharā": ['mw'],
    "śaṅkhadhavalā": ['mw'],
    "śaṅkhadhma": ['cae', 'mw'],
    "śaṅkhadhmā": ['mw'],
    "śaṅkhadhvani": ['cae', 'mw'],
    "śaṅkhadhāmaka": ['bhs'],
    "śaṅkhadrāva": ['mw'],
    "śaṅkhadrāvaka": ['mw'],
    "śaṅkhadrāvin": ['mw'],
    "śaṅkhadvīpa": ['mw'],
    "śaṅkhadāraka": ['mw'],
    "śaṅkhahrada": ['mw'],
    "śaṅkhaja": ['mw'],
    "śaṅkhajātī": ['mw'],
    "śaṅkhaka": ['mw'],
    "śaṅkhakarṇa": ['mw'],
    "śaṅkhakumbhaśravas": ['mw'],
    "śaṅkhakusuma": ['mw'],
    "śaṅkhakuñjara": ['bhs'],
    "śaṅkhakāra": ['mw'],
    "śaṅkhakāraka": ['mw'],
    "śaṅkhakūṭa": ['mw'],
    "śaṅkhakṣīra": ['mw'],
    "śaṅkhalakṣaṇa": ['mw'],
    "śaṅkhalikhita": ['mw'],
    "śaṅkhalikhitapriya": ['mw'],
    "śaṅkhalikhitasmṛti": ['mw'],
    "śaṅkhalikā": ['mw'],
    "śaṅkhamauktika": ['mw'],
    "śaṅkhamedhī": ['bhs'],
    "śaṅkhamekhala": ['cae', 'mw'],
    "śaṅkhamitra": ['mw'],
    "śaṅkhamudrā": ['mw'],
    "śaṅkhamukha": ['mw'],
    "śaṅkhamuktā": ['mw'],
    "śaṅkhamālinī": ['mw'],
    "śaṅkhamūla": ['mw'],
    "śaṅkhanaka": ['mw'],
    "śaṅkhanakha": ['mw'],
    "śaṅkhanābha": ['bhs', 'mw'],
    "śaṅkhanābhi": ['mw'],
    "śaṅkhanābhī": ['bhs', 'mw'],
    "śaṅkhanāmnī": ['mw'],
    "śaṅkhanārī": ['mw'],
    "śaṅkhanūpuriṇī": ['mw'],
    "śaṅkhapad": ['mw'],
    "śaṅkhapada": ['mw'],
    "śaṅkhapiṇḍa": ['mw'],
    "śaṅkhapoṭalin": ['mw'],
    "śaṅkhaprastha": ['mw'],
    "śaṅkhapravara": ['mw'],
    "śaṅkhapraṇāda": ['mw'],
    "śaṅkhapura": ['mw'],
    "śaṅkhapuṣpikā": ['cae', 'mw'],
    "śaṅkhapuṣpī": ['cae', 'mw'],
    "śaṅkhapuṣpīśṛta": ['mw'],
    "śaṅkhapā": ['mw'],
    "śaṅkhapāda": ['mw'],
    "śaṅkhapāla": ['mw'],
    "śaṅkhapātra": ['mw'],
    "śaṅkhapāṇi": ['mw'],
    "śaṅkharoman": ['mw'],
    "śaṅkharāj": ['mw'],
    "śaṅkharāja": ['mw'],
    "śaṅkharāvita": ['mw'],
    "śaṅkhasmṛti": ['mw'],
    "śaṅkhasnāna": ['mw'],
    "śaṅkhasvana": ['mw'],
    "śaṅkhasvara": ['mw'],
    "śaṅkhasvarasamācāra": ['bhs'],
    "śaṅkhatīrtha": ['mw'],
    "śaṅkhavalaya": ['mw'],
    "śaṅkhavalayakāra": ['bhs'],
    "śaṅkhavat": ['mw'],
    "śaṅkhavaṭīrasa": ['mw'],
    "śaṅkhaviṣa": ['mw'],
    "śaṅkhayūthikā": ['mw'],
    "śaṅkhaśilā": ['bhs', 'mw'],
    "śaṅkhaśiras": ['mw'],
    "śaṅkhaśrīdhara": ['mw'],
    "śaṅkhaśuktikā": ['mw'],
    "śaṅkhaśīrṣa": ['mw'],
    "śaṅkhaṇa": ['ddsa', 'mw'],
    "śaṅkhika": ['bhs', 'mw'],
    "śaṅkhikā": ['mw'],
    "śaṅkhila": ['bhs'],
    "śaṅkhin": ['cae', 'ddsa', 'mw'],
    "śaṅkhinī": ['bhs', 'mw'],
    "śaṅkhinīphala": ['mw'],
    "śaṅkhinīvāsa": ['mw'],
    "śaṅkhiṇī": ['mw'],
    "śaṅkhodaka": ['mw'],
    "śaṅkhoddhāra": ['mw'],
    "śaṅkhoddhāramāhātmya": ['mw'],
    "śaṅkhā": ['mw'],
    "śaṅkhāhata": ['mw'],
    "śaṅkhāhvā": ['mw'],
    "śaṅkhākhya": ['mw'],
    "śaṅkhālu": ['mw'],
    "śaṅkhāluka": ['mw'],
    "śaṅkhāntara": ['cae', 'mw'],
    "śaṅkhāntaradyotin": ['mw'],
    "śaṅkhāsura": ['mw'],
    "śaṅkhāvarta": ['mw'],
    "śaṅkhāvatī": ['mw'],
    "śaṅkila": ['mw'],
    "śaṅkin": ['cae', 'mw'],
    "śaṅkita": ['mw'],
    "śaṅkitadṛṣṭi": ['mw'],
    "śaṅkitamanas": ['mw'],
    "śaṅkitavarṇaka": ['mw'],
    "śaṅkitavya": ['cae', 'ddsa', 'mw'],
    "śaṅkoca": ['mw'],
    "śaṅkoci": ['mw'],
    "śaṅku": ['cae', 'ddsa', 'gra', 'mw'],
    "śaṅkucchāyā": ['mw'],
    "śaṅkuci": ['mw'],
    "śaṅkudhāna": ['mw'],
    "śaṅkujīvā": ['mw'],
    "śaṅkuka": ['mw'],
    "śaṅkukarṇa": ['cae', 'mw'],
    "śaṅkukarṇamukha": ['mw'],
    "śaṅkukarṇeśvara": ['mw'],
    "śaṅkukarṇin": ['mw'],
    "śaṅkulya": ['bhs'],
    "śaṅkulā": ['mw'],
    "śaṅkulākhaṇḍa": ['mw'],
    "śaṅkumat": ['mw'],
    "śaṅkumatī": ['mw'],
    "śaṅkumukha": ['cae', 'mw'],
    "śaṅkumūlī": ['mw'],
    "śaṅkupatha": ['mw'],
    "śaṅkuphalikā": ['mw'],
    "śaṅkuphalā": ['mw'],
    "śaṅkuphaṇin": ['mw'],
    "śaṅkupuccha": ['mw'],
    "śaṅkura": ['mw'],
    "śaṅkutala": ['mw'],
    "śaṅkutaru": ['mw'],
    "śaṅkuvicāra": ['mw'],
    "śaṅkuvṛkṣa": ['mw'],
    "śaṅkuśiras": ['mw'],
    "śaṅkuśravaṇa": ['mw'],
    "śaṅkuṣṭha": ['mw'],
    "śaṅkya": ['cae', 'ddsa', 'mw'],
    "śaṅkā": ['cae', 'ddsa', 'mw'],
    "śaṅkābhiyoga": ['cae', 'mw'],
    "śaṅkāhīna": ['mw'],
    "śaṅkākula": ['mw'],
    "śaṅkāmaya": ['mw'],
    "śaṅkānvita": ['mw'],
    "śaṅkāspada": ['mw'],
    "śaṅkāspṛṣṭa": ['mw'],
    "śaṅkātaṅkita": ['mw'],
    "śaṅkāviṣā": ['bhs'],
    "śaṅkāśaṅku": ['mw'],
    "śaṅkāśīla": ['mw'],
    "śaṇ": ['ap90', 'mw'],
    "śaṇa": ['cae', 'ddsa', 'mw'],
    "śaṇacūrṇa": ['mw'],
    "śaṇagaura": ['mw'],
    "śaṇaghaṇṭikā": ['mw'],
    "śaṇaka": ['mw'],
    "śaṇakabābhrava": ['mw'],
    "śaṇakulāya": ['mw'],
    "śaṇamaya": ['cae', 'mw'],
    "śaṇanā": ['bhs'],
    "śaṇaparṇī": ['mw'],
    "śaṇapaṭṭa": ['mw'],
    "śaṇaphalā": ['mw'],
    "śaṇapuṣpikā": ['mw'],
    "śaṇapuṣpī": ['mw'],
    "śaṇarajju": ['cae', 'mw'],
    "śaṇasūtra": ['cae', 'mw'],
    "śaṇasūtramaya": ['cae', 'mw'],
    "śaṇatantu": ['mw'],
    "śaṇatāntava": ['cae', 'mw'],
    "śaṇatūla": ['mw'],
    "śaṇavalka": ['mw'],
    "śaṇaśakala": ['mw'],
    "śaṇaśulba": ['cae', 'mw'],
    "śaṇaśāka": ['mw'],
    "śaṇaśāṭi": ['bhs'],
    "śaṇaṃ": ['ap90'],
    "śaṇikā": ['mw'],
    "śaṇālu": ['mw'],
    "śaṇāluka": ['mw'],
    "śaṇīra": ['mw'],
    "śaṇīraṃ": ['ap90'],
    "śaṇḍ": ['mw'],
    "śaṇḍa": ['cae', 'ddsa', 'mw'],
    "śaṇḍha": ['mw'],
    "śaṇḍika": ['gra', 'mw'],
    "śaṇḍikā": ['mw'],
    "śaṇḍila": ['cae', 'ddsa', 'mw'],
    "śaṇḍilī": ['mw'],
    "śaṇḍāmarka": ['cae', 'mw'],
    "śaṇṭha": ['mw'],
    "śaṣ": ['ap90', 'mw'],
    "śaṣkaṇḍī": ['mw'],
    "śaṣkula": ['mw'],
    "śaṣkuli": ['cae', 'ddsa', 'mw'],
    "śaṣkulikā": ['mw'],
    "śaṣkulī": ['ap90', 'cae', 'mw'],
    "śaṣpa": ['cae', 'ddsa', 'mw'],
    "śaṣpabhojana": ['mw'],
    "śaṣpabhuj": ['mw'],
    "śaṣpabṛsī": ['mw'],
    "śaṣpatulya": ['mw'],
    "śaṣpavat": ['mw'],
    "śaṣpaḥ": ['ap90'],
    "śaṣpiñjara": ['mw'],
    "śaṣpya": ['cae'],
    "śaṣpāda": ['mw'],
    "śaṣpīkṛ": ['ddsa'],
    "śaṭ": ['ap90', 'mw'],
    "śaṭa": ['ap90', 'bhs', 'mw'],
    "śaṭaḥ": ['bhs'],
    "śaṭh": ['ap90', 'mw'],
    "śaṭha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śaṭhabuddhi": ['cae', 'mw'],
    "śaṭhabuddhitā": ['mw'],
    "śaṭhadhī": ['cae', 'mw'],
    "śaṭhaka": ['bhs'],
    "śaṭhakopa": ['mw'],
    "śaṭhakopasahasranāman": ['mw'],
    "śaṭhakopaviṣaya": ['mw'],
    "śaṭhamati": ['cae', 'mw'],
    "śaṭhatva": ['mw'],
    "śaṭhatā": ['mw'],
    "śaṭhatācaraṇa": ['mw'],
    "śaṭhavairivaibhavadīpikā": ['mw'],
    "śaṭhavairivaibhavaprabhākara": ['mw'],
    "śaṭhodarka": ['mw'],
    "śaṭhāmbā": ['mw'],
    "śaṭhāri": ['mw'],
    "śaṭhārivyutpattidīpikā": ['mw'],
    "śaṭhī": ['mw'],
    "śaṭi": ['mw'],
    "śaṭiḥ": ['ap90'],
    "śaṭā": ['ap90', 'mw'],
    "śaṭṭaka": ['mw'],
    "śaṭṭakaṃ": ['ap90'],
    "ścam": ['ddsa', 'gra', 'mw'],
    "ścand": ['cae', 'ddsa', 'gra', 'mw'],
    "ścandra": ['cae', 'ddsa', 'gra', 'mw'],
    "ścar": ['ddsa', 'mw'],
    "ścota": ['mw'],
    "ścotana": ['mw'],
    "ścotanmayūkha": ['mw'],
    "ścoti": ['mw'],
    "ścut": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ścutita": ['mw'],
    "ścyota": ['bhs'],
    "ścyotaḥ": ['ap90'],
    "ścyut": ['ap90', 'mw'],
    "śe": ['ddsa'],
    "śekhara": ['cae', 'ddsa', 'mw'],
    "śekharajyotis": ['mw'],
    "śekharaka": ['mw'],
    "śekharatā": ['mw'],
    "śekharavyākhyā": ['mw'],
    "śekharaya": ['ddsa', 'mw'],
    "śekharaḥ": ['ap90'],
    "śekharita": ['ap90', 'mw'],
    "śekharāpīḍayojana": ['mw'],
    "śekharāya": ['mw'],
    "śekharī": ['mw'],
    "śekharībhāva": ['mw'],
    "śekharībhū": ['mw'],
    "śekharīkṛ": ['ddsa', 'mw'],
    "śekhayati": ['bhs'],
    "śeku": ['mw'],
    "śekuṣṭha": ['mw'],
    "śel": ['ap90', 'mw'],
    "śela": ['bhs'],
    "śelaga": ['mw'],
    "śelu": ['cae', 'ddsa', 'mw'],
    "śelālaka": ['bhs'],
    "śelāya": ['mw'],
    "śemuṣī": ['ap90', 'cae', 'ddsa', 'mw'],
    "śemuṣīmuṣ": ['mw'],
    "śepa": ['cae', 'ddsa', 'gra', 'mw'],
    "śepaharṣaṇa": ['mw'],
    "śepas": ['cae', 'mw'],
    "śepaḥ": ['ap90'],
    "śepha": ['cae', 'ddsa', 'mw'],
    "śephas": ['cae', 'mw'],
    "śephaḥstambha": ['mw'],
    "śephāli": ['mw'],
    "śephālikā": ['cae', 'ddsa', 'mw'],
    "śephāliḥ": ['ap90'],
    "śephālī": ['cae', 'mw'],
    "śepya": ['mw'],
    "śepyā": ['mw'],
    "śepyāvat": ['mw'],
    "śepāla": ['mw'],
    "śepāna": ['mw'],
    "śerabha": ['mw'],
    "śerabhaka": ['mw'],
    "śetya": ['mw'],
    "śev": ['mw'],
    "śeva": ['cae', 'ddsa', 'gra', 'mw'],
    "śevadhi": ['cae', 'ddsa', 'gra', 'mw'],
    "śevadhipā": ['gra', 'mw'],
    "śevala": ['cae', 'ddsa', 'mw'],
    "śevaladatta": ['mw'],
    "śevalaṃ": ['ap90'],
    "śevalendradatta": ['mw'],
    "śevalika": ['mw'],
    "śevalila": ['mw'],
    "śevalinī": ['ap90', 'mw'],
    "śevaliya": ['mw'],
    "śevaraka": ['ddsa', 'mw'],
    "śevas": ['mw'],
    "śevaḥ": ['ap90'],
    "śevia": ['gra'],
    "śevya": ['cae', 'gra', 'mw'],
    "śevā": ['mw'],
    "śevāla": ['ap90', 'mw'],
    "śevālaghoṣa": ['mw'],
    "śevālaghoṣī": ['mw'],
    "śevālī": ['mw'],
    "śevāra": ['cae', 'ddsa', 'gra', 'mw'],
    "śevṛdha": ['cae', 'ddsa', 'gra', 'mw'],
    "śevṛdhaka": ['cae'],
    "śeya": ['mw'],
    "śeyia": ['gra'],
    "śeyya": ['mw'],
    "śeyyā": ['bhs'],
    "śeśvīyamāna": ['mw'],
    "śeśyita": ['mw'],
    "śeḍa": ['ddsa', 'mw'],
    "śeḍḍa": ['mw'],
    "śeṇavī": ['mw'],
    "śeṇā": ['mw'],
    "śeṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "śeṣabhojana": ['mw'],
    "śeṣabhojin": ['cae', 'mw'],
    "śeṣabhuj": ['cae', 'mw'],
    "śeṣabhāga": ['mw'],
    "śeṣabhāva": ['mw'],
    "śeṣabhūta": ['cae', 'mw'],
    "śeṣabhūṣaṇa": ['mw'],
    "śeṣacakrapāṇi": ['mw'],
    "śeṣacintāmaṇi": ['mw'],
    "śeṣadeva": ['mw'],
    "śeṣadharma": ['mw'],
    "śeṣagovinda": ['mw'],
    "śeṣahomaprayoga": ['mw'],
    "śeṣajāti": ['mw'],
    "śeṣaka": ['mw'],
    "śeṣakamalākara": ['mw'],
    "śeṣakaraṇa": ['ddsa', 'mw'],
    "śeṣakriyā": ['mw'],
    "śeṣakāla": ['mw'],
    "śeṣakārita": ['mw'],
    "śeṣakṛṣṇa": ['mw'],
    "śeṣanāga": ['mw'],
    "śeṣanārāyaṇa": ['mw'],
    "śeṣapati": ['bhs', 'mw'],
    "śeṣarakṣaṇa": ['mw'],
    "śeṣaratnākara": ['mw'],
    "śeṣarāmacandra": ['mw'],
    "śeṣarātri": ['mw'],
    "śeṣarūpin": ['mw'],
    "śeṣas": ['cae', 'ddsa', 'gra', 'mw'],
    "śeṣasamuccayaṭīkā": ['mw'],
    "śeṣasaṃgrahanāmamālā": ['mw'],
    "śeṣasaṃgrahasāroddhāra": ['mw'],
    "śeṣasaṃhitā": ['mw'],
    "śeṣatas": ['cae', 'mw'],
    "śeṣatva": ['cae', 'mw'],
    "śeṣatvavicāra": ['mw'],
    "śeṣatā": ['cae', 'mw'],
    "śeṣavant": ['cae'],
    "śeṣavat": ['mw'],
    "śeṣavistārapāṇḍu": ['mw'],
    "śeṣavākyārthacandrikā": ['mw'],
    "śeṣaśarīra": ['mw'],
    "śeṣaśeṣibhāva": ['mw'],
    "śeṣaśeṣin": ['mw'],
    "śeṣaśeṣitva": ['mw'],
    "śeṣaśārṅgadhara": ['mw'],
    "śeṣaṇa": ['mw'],
    "śeṣin": ['cae', 'mw'],
    "śeṣita": ['bhs'],
    "śeṣya": ['cae', 'ddsa', 'mw'],
    "śeṣā": ['ddsa', 'mw'],
    "śeṣādhikārīya": ['mw'],
    "śeṣādri": ['mw'],
    "śeṣāhi": ['mw'],
    "śeṣānanda": ['mw'],
    "śeṣānanta": ['mw'],
    "śeṣānna": ['mw'],
    "śeṣāryā": ['mw'],
    "śeṣāryāvyākhyāna": ['mw'],
    "śeṣāvacayana": ['mw'],
    "śeṣāvasthā": ['mw'],
    "śeṣāṅkagaṇanā": ['mw'],
    "śeṣī": ['mw'],
    "śeṣībhū": ['cae', 'ddsa', 'mw'],
    "śi": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śibhra": ['cae', 'mw'],
    "śibi": ['cae', 'ddsa', 'mw'],
    "śibicarita": ['mw'],
    "śibicaritra": ['mw'],
    "śibighoṣā": ['bhs'],
    "śibika": ['cae', 'mw'],
    "śibikā": ['ap90', 'ddsa', 'mw'],
    "śibikādāna": ['mw'],
    "śibikādānavidhi": ['mw'],
    "śibikāla": ['mw'],
    "śibinta": ['mw'],
    "śibira": ['cae', 'ddsa', 'mw'],
    "śibiragiri": ['mw'],
    "śibirathaḥ": ['ap90'],
    "śibiraṃ": ['ap90'],
    "śibiḥ": ['ap90'],
    "śibīratha": ['mw'],
    "śic": ['ap90', 'cae', 'mw'],
    "śigru": ['cae', 'ddsa', 'gra', 'mw'],
    "śigrubīja": ['mw'],
    "śigruja": ['mw'],
    "śigruka": ['cae', 'mw'],
    "śigrumūla": ['mw'],
    "śigruḥ": ['ap90'],
    "śihla": ['mw'],
    "śihlaḥ": ['ap90'],
    "śihlaṇa": ['mw'],
    "śikam": ['mw'],
    "śikha": ['cae', 'mw'],
    "śikhaka": ['mw'],
    "śikhala": ['bhs'],
    "śikhaladatta": ['bhs'],
    "śikhalohita": ['mw'],
    "śikhalābha": ['bhs'],
    "śikhara": ['cae', 'ddsa', 'mw'],
    "śikharadatī": ['mw'],
    "śikharadaśanā": ['mw'],
    "śikharadhara": ['bhs'],
    "śikharanicaya": ['mw'],
    "śikharasena": ['mw'],
    "śikharasvāminī": ['mw'],
    "śikharavāsinī": ['mw'],
    "śikharaḥ": ['ap90'],
    "śikhareśaliṅga": ['mw'],
    "śikhari": ['mw'],
    "śikharin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śikharipattrin": ['mw'],
    "śikharipat‍trin": ['ddsa'],
    "śikharisama": ['mw'],
    "śikhariṇī": ['ap90', 'mw'],
    "śikharā": ['mw'],
    "śikharābha": ['bhs'],
    "śikharādri": ['mw'],
    "śikharī": ['mw'],
    "śikharīndra": ['mw'],
    "śikhaṃḍakaḥ": ['ap90'],
    "śikhaṃḍaḥ": ['ap90'],
    "śikhaṃḍikaḥ": ['ap90'],
    "śikhaṃḍikā": ['ap90'],
    "śikhaṃḍin": ['ap90'],
    "śikhaṃḍinī": ['ap90'],
    "śikhaṇḍa": ['cae', 'ddsa', 'mw'],
    "śikhaṇḍaka": ['cae', 'mw'],
    "śikhaṇḍi": ['mw'],
    "śikhaṇḍika": ['mw'],
    "śikhaṇḍiketu": ['mw'],
    "śikhaṇḍikā": ['mw'],
    "śikhaṇḍimant": ['cae'],
    "śikhaṇḍimat": ['ddsa', 'mw'],
    "śikhaṇḍin": ['bhs', 'cae', 'ddsa', 'mw'],
    "śikhaṇḍinī": ['mw'],
    "śikhaṇḍita": ['mw'],
    "śikhaṇḍāstha": ['mw'],
    "śikhaṇḍī": ['mw'],
    "śikhaṇḍīvedāntasāra": ['mw'],
    "śikhi": ['mw'],
    "śikhibhū": ['mw'],
    "śikhidhvaja": ['mw'],
    "śikhidhvajatīrtha": ['mw'],
    "śikhidiś": ['mw'],
    "śikhidyut": ['mw'],
    "śikhigrīva": ['mw'],
    "śikhikaṇa": ['mw'],
    "śikhikaṇṭha": ['mw'],
    "śikhimaṇḍala": ['mw'],
    "śikhimodā": ['mw'],
    "śikhimūla": ['mw'],
    "śikhin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śikhina": ['mw'],
    "śikhinī": ['mw'],
    "śikhipiccha": ['mw'],
    "śikhipriya": ['mw'],
    "śikhipuccha": ['mw'],
    "śikhitama": ['mw'],
    "śikhitā": ['ddsa', 'mw'],
    "śikhitīrtha": ['mw'],
    "śikhivardhaka": ['mw'],
    "śikhivrata": ['mw'],
    "śikhivāhana": ['mw'],
    "śikhivāsas": ['mw'],
    "śikhiyūpa": ['mw'],
    "śikhiśekhara": ['mw'],
    "śikhiśikhā": ['mw'],
    "śikhiśṛṅga": ['mw'],
    "śikhopaniṣad": ['mw'],
    "śikhā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śikhābandha": ['bhs', 'mw'],
    "śikhābandhana": ['mw'],
    "śikhābharaṇa": ['cae', 'mw'],
    "śikhācala": ['mw'],
    "śikhādhara": ['mw'],
    "śikhādharaja": ['mw'],
    "śikhādhāra": ['mw'],
    "śikhādāman": ['cae', 'mw'],
    "śikhāgradanta": ['mw'],
    "śikhāgradat": ['mw'],
    "śikhājaṭa": ['cae', 'mw'],
    "śikhākanda": ['mw'],
    "śikhālambin": ['cae', 'mw'],
    "śikhāluḥ": ['ap90'],
    "śikhāmaṇi": ['cae', 'mw'],
    "śikhāmuṇḍa": ['mw'],
    "śikhāmārjita": ['mw'],
    "śikhāmūla": ['mw'],
    "śikhāpati": ['mw'],
    "śikhāpitta": ['mw'],
    "śikhāpāśa": ['mw'],
    "śikhāsūtra": ['mw'],
    "śikhātaru": ['mw'],
    "śikhāvala": ['cae', 'mw'],
    "śikhāvant": ['cae'],
    "śikhāvara": ['mw'],
    "śikhāvarta": ['mw'],
    "śikhāvat": ['ap90', 'mw'],
    "śikhāvatī": ['mw'],
    "śikhāvṛddhi": ['mw'],
    "śikhāvṛkṣa": ['mw'],
    "śikhāṇḍaka": ['mw'],
    "śikhī": ['bhs', 'mw'],
    "śikhīndra": ['mw'],
    "śikku": ['ap90', 'mw'],
    "śikman": ['mw'],
    "śiktha": ['mw'],
    "śikthaṃ": ['ap90'],
    "śikva": ['cae', 'mw'],
    "śikvan": ['cae', 'ddsa', 'gra', 'mw'],
    "śikvas": ['cae', 'gra', 'mw'],
    "śikya": ['cae', 'ddsa', 'mw'],
    "śikyaka": ['mw'],
    "śikyakavastra": ['mw'],
    "śikyakā": ['bhs'],
    "śikyapāśa": ['mw'],
    "śikyavat": ['mw'],
    "śikyaṃ": ['ap90'],
    "śikyita": ['ap90', 'mw'],
    "śikyoduta": ['mw'],
    "śikyādhāra": ['mw'],
    "śikyākṛta": ['mw'],
    "śikṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śikṣa": ['bhs', 'mw'],
    "śikṣaka": ['cae', 'ddsa', 'mw'],
    "śikṣakaḥ": ['ap90'],
    "śikṣamāṇaḥ": ['ap90'],
    "śikṣayitṛ": ['mw'],
    "śikṣaṇa": ['cae', 'mw'],
    "śikṣaṇaṃ": ['ap90'],
    "śikṣaṇā": ['bhs'],
    "śikṣaṇīya": ['cae', 'mw'],
    "śikṣeṇya": ['cae', 'ddsa', 'mw'],
    "śikṣin": ['mw'],
    "śikṣita": ['ap90', 'cae', 'ddsa', 'mw'],
    "śikṣitaka": ['bhs'],
    "śikṣitavya": ['mw'],
    "śikṣitukāma": ['cae', 'mw'],
    "śikṣitā": ['mw'],
    "śikṣitākṣara": ['mw'],
    "śikṣitāyudha": ['mw'],
    "śikṣu": ['cae', 'ddsa', 'gra', 'mw'],
    "śikṣuka": ['mw'],
    "śikṣya": ['mw'],
    "śikṣā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śikṣābodha": ['mw'],
    "śikṣācāra": ['mw'],
    "śikṣādattaka": ['bhs'],
    "śikṣādaśaka": ['mw'],
    "śikṣādaṇḍa": ['mw'],
    "śikṣāguru": ['mw'],
    "śikṣākara": ['mw'],
    "śikṣākaragupta": ['mw'],
    "śikṣākāra": ['mw'],
    "śikṣākṣara": ['mw'],
    "śikṣānara": ['cae', 'gra', 'mw'],
    "śikṣānīti": ['mw'],
    "śikṣāpada": ['bhs', 'mw'],
    "śikṣāpadaprajñapti": ['mw'],
    "śikṣāpattra": ['mw'],
    "śikṣāpattrī": ['mw'],
    "śikṣāpayati": ['bhs'],
    "śikṣāpañcaka": ['mw'],
    "śikṣāprakāśa": ['mw'],
    "śikṣārasa": ['mw'],
    "śikṣāsamuccaya": ['bhs', 'mw'],
    "śikṣāsaṃvara": ['mw'],
    "śikṣāsvara": ['mw'],
    "śikṣāsūtra": ['mw'],
    "śikṣāvallī": ['mw'],
    "śikṣāvant": ['cae'],
    "śikṣāvat": ['mw'],
    "śikṣāvidhi": ['mw'],
    "śikṣāśakti": ['mw'],
    "śikṣāṇa": ['mw'],
    "śil": ['ap90', 'mw'],
    "śila": ['cae', 'ddsa', 'mw'],
    "śilagarbhaja": ['mw'],
    "śilaja": ['mw'],
    "śilajā": ['mw'],
    "śilaka": ['mw'],
    "śilamba": ['mw'],
    "śilamānakhāna": ['mw'],
    "śilaprastha": ['mw'],
    "śilarati": ['mw'],
    "śilaukas": ['mw'],
    "śilavaha": ['mw'],
    "śilavāhā": ['mw'],
    "śilavṛtti": ['cae', 'mw'],
    "śilaḥ": ['ap90'],
    "śilaṃdhara": ['mw'],
    "śilaṃdhari": ['mw'],
    "śileya": ['ap90', 'mw'],
    "śilgu": ['mw'],
    "śilhaṇa": ['mw'],
    "śili": ['mw'],
    "śilika": ['mw'],
    "śilikākoṣṭha": ['ddsa', 'mw'],
    "śilin": ['cae', 'mw'],
    "śilina": ['mw'],
    "śilinda": ['mw'],
    "śiliḥ": ['ap90'],
    "śiliṃdaḥ": ['ap90'],
    "śiliṣṭa": ['bhs'],
    "śiloccaya": ['cae', 'ddsa', 'mw'],
    "śilodbhava": ['mw'],
    "śilodbheda": ['mw'],
    "śiloraska": ['mw'],
    "śilottha": ['mw'],
    "śiloñcha": ['cae', 'ddsa', 'mw'],
    "śiloñchana": ['mw'],
    "śiloñchavṛtti": ['cae', 'mw'],
    "śiloñchin": ['cae', 'mw'],
    "śilpa": ['cae', 'ddsa', 'gra', 'mw'],
    "śilpageha": ['mw'],
    "śilpagṛha": ['mw'],
    "śilpajīvikā": ['mw'],
    "śilpajīvin": ['mw'],
    "śilpajīvinī": ['mw'],
    "śilpaka": ['mw'],
    "śilpakalādīpikā": ['mw'],
    "śilpakara": ['mw'],
    "śilpakarman": ['mw'],
    "śilpakarī": ['mw'],
    "śilpakaṃ": ['ap90'],
    "śilpakāra": ['mw'],
    "śilpakāraka": ['mw'],
    "śilpakārikā": ['cae', 'mw'],
    "śilpakārin": ['mw'],
    "śilpakāriṇī": ['mw'],
    "śilpakārī": ['cae', 'ddsa', 'mw'],
    "śilpalekha": ['mw'],
    "śilpaprajāpati": ['mw'],
    "śilpasarvasvasaṃgraha": ['mw'],
    "śilpasthāna": ['mw'],
    "śilpatva": ['mw'],
    "śilpavant": ['bhs', 'cae'],
    "śilpavat": ['mw'],
    "śilpavidhānadṛṣṭa": ['mw'],
    "śilpavidyā": ['mw'],
    "śilpavṛtti": ['mw'],
    "śilpaśāla": ['mw'],
    "śilpaśālā": ['mw'],
    "śilpaśāstra": ['mw'],
    "śilpaṃ": ['ap90'],
    "śilpi": ['mw'],
    "śilpidārikā": ['cae'],
    "śilpijana": ['mw'],
    "śilpika": ['ap90', 'bhs', 'mw'],
    "śilpikarman": ['mw'],
    "śilpikā": ['mw'],
    "śilpin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śilpinī": ['mw'],
    "śilpisāra": ['mw'],
    "śilpiśāla": ['mw'],
    "śilpiśālā": ['mw'],
    "śilpiśāstra": ['mw'],
    "śilpopajīvin": ['cae', 'ddsa', 'mw'],
    "śilpā": ['mw'],
    "śilpābhijña": ['bhs'],
    "śilpājīva": ['mw'],
    "śilpālaya": ['mw'],
    "śilpārthasāra": ['mw'],
    "śilpāyatana": ['bhs'],
    "śilpī": ['mw'],
    "śilukṣa": ['bhs'],
    "śilā": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śilābandha": ['mw'],
    "śilābhava": ['mw'],
    "śilābheda": ['mw'],
    "śilābhid": ['mw'],
    "śilābhāva": ['mw'],
    "śilācakra": ['mw'],
    "śilācaya": ['cae', 'mw'],
    "śilāda": ['mw'],
    "śilādadru": ['mw'],
    "śilādhara": ['mw'],
    "śilādhātu": ['mw'],
    "śilāditya": ['mw'],
    "śilādāna": ['mw'],
    "śilāghana": ['mw'],
    "śilāgṛha": ['cae', 'mw'],
    "śilāhva": ['mw'],
    "śilāhvaya": ['mw'],
    "śilāhya": ['mw'],
    "śilāhārin": ['ddsa', 'mw'],
    "śilāja": ['mw'],
    "śilājatu": ['mw'],
    "śilājatukalpa": ['mw'],
    "śilājit": ['mw'],
    "śilākarṇī": ['mw'],
    "śilākusuma": ['mw'],
    "śilākuṭṭa": ['bhs', 'mw'],
    "śilākuṭṭaka": ['mw'],
    "śilākā": ['bhs'],
    "śilākṣara": ['ddsa', 'mw'],
    "śilālin": ['mw'],
    "śilāmala": ['mw'],
    "śilāmaya": ['cae', 'mw'],
    "śilāmāhātmya": ['mw'],
    "śilāndhas": ['mw'],
    "śilānicaya": ['mw'],
    "śilāniryāsa": ['mw'],
    "śilānta": ['mw'],
    "śilānyāsapaddhati": ['mw'],
    "śilānīḍa": ['mw'],
    "śilāpaṭṭa": ['cae', 'mw'],
    "śilāpaṭṭaka": ['cae', 'mw'],
    "śilāpeṣa": ['mw'],
    "śilāphalaka": ['mw'],
    "śilāprasūna": ['mw'],
    "śilāpratikṛti": ['mw'],
    "śilāprāsāda": ['mw'],
    "śilāpura": ['bhs'],
    "śilāputra": ['bhs', 'mw'],
    "śilāputraka": ['mw'],
    "śilāpuṣpa": ['mw'],
    "śilārambhā": ['mw'],
    "śilārasa": ['mw'],
    "śilāsana": ['mw'],
    "śilāstambha": ['cae', 'mw'],
    "śilāsthāpanapaddhati": ['mw'],
    "śilāsveda": ['mw'],
    "śilāsāra": ['mw'],
    "śilātala": ['cae', 'mw'],
    "śilātmaja": ['mw'],
    "śilātmikā": ['mw'],
    "śilātva": ['mw'],
    "śilātvac": ['mw'],
    "śilāvaha": ['mw'],
    "śilāvahā": ['mw'],
    "śilāvalkala": ['mw'],
    "śilāvalkā": ['mw'],
    "śilāvarṣin": ['cae', 'mw'],
    "śilāveśman": ['cae', 'mw'],
    "śilāvitāna": ['mw'],
    "śilāvyādhi": ['mw'],
    "śilāvṛṣṭi": ['mw'],
    "śilāyūpa": ['mw'],
    "śilāñjanī": ['mw'],
    "śilāśastra": ['mw'],
    "śilāśita": ['mw'],
    "śilāṭaka": ['mw'],
    "śilī": ['ap90', 'mw'],
    "śilībhū": ['cae', 'mw'],
    "śilībhūta": ['ddsa', 'mw'],
    "śilīmukha": ['cae', 'ddsa', 'mw'],
    "śilīndhra": ['ddsa', 'mw'],
    "śilīndhraka": ['mw'],
    "śilīndhrī": ['mw'],
    "śilīpada": ['cae', 'mw'],
    "śilīpṛṣṭha": ['mw'],
    "śilīṃdhra": ['cae'],
    "śilīṃdhraka": ['ap90'],
    "śilīṃdhraḥ": ['ap90'],
    "śilīṃdhrī": ['ap90'],
    "śilūṣa": ['mw'],
    "śim": ['cae', 'ddsa', 'mw'],
    "śim, śiṣ": ['ddsa'],
    "śima": ['cae', 'mw'],
    "śimba": ['cae', 'ddsa', 'mw'],
    "śimbala": ['gra', 'mw'],
    "śimbi": ['cae', 'ddsa', 'mw'],
    "śimbijā": ['mw'],
    "śimbika": ['mw'],
    "śimbikā": ['mw'],
    "śimbiparṇikā": ['mw'],
    "śimbiparṇī": ['mw'],
    "śimbā": ['mw'],
    "śimbāta": ['gra', 'mw'],
    "śimbī": ['mw'],
    "śimbīdhānya": ['mw'],
    "śimbīphala": ['mw'],
    "śimi": ['mw'],
    "śimidvat": ['mw'],
    "śimidā": ['gra', 'mw'],
    "śimijāvarī": ['mw'],
    "śimikā": ['ddsa', 'mw'],
    "śimiśimāya": ['mw'],
    "śimiṣīpada": ['mw'],
    "śimo": ['ddsa'],
    "śimrīḍī": ['mw'],
    "śimyu": ['cae', 'ddsa', 'gra', 'mw'],
    "śimī": ['cae', 'gra', 'mw'],
    "śimīvant": ['cae'],
    "śimīvat": ['gra', 'mw'],
    "śimṛḍī": ['mw'],
    "śina": ['mw'],
    "śineyu": ['mw'],
    "śini": ['cae', 'ddsa', 'mw'],
    "śinibāhu": ['mw'],
    "śinipravīra": ['mw'],
    "śinivāsa": ['mw'],
    "śinivāsudeva": ['mw'],
    "śiniḥ": ['ap90'],
    "śinīka": ['mw'],
    "śinīpati": ['mw'],
    "śinīvālī": ['mw'],
    "śinīvāsa": ['mw'],
    "śipada": ['gra', 'mw'],
    "śipavitnuka": ['mw'],
    "śipaviṣṭa": ['mw'],
    "śipha": ['mw'],
    "śiphaḥ": ['ap90'],
    "śiphā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śiphādhara": ['mw'],
    "śiphāka": ['mw'],
    "śiphākanda": ['mw'],
    "śiphākaḥ": ['ap90'],
    "śiphāruha": ['mw'],
    "śipi": ['cae', 'ddsa', 'mw'],
    "śipita": ['cae', 'ddsa', 'mw'],
    "śipiviṣṭa": ['cae', 'ddsa', 'gra', 'mw'],
    "śipiviṣṭaka": ['mw'],
    "śipiviṣṭavat": ['mw'],
    "śipiviṣṭavatī": ['mw'],
    "śipiḥ": ['ap90'],
    "śipra": ['mw'],
    "śipraka": ['mw'],
    "śipravant": ['cae'],
    "śipravat": ['ddsa', 'gra', 'mw'],
    "śipraḥ": ['ap90'],
    "śiprin": ['cae', 'ddsa', 'gra', 'mw'],
    "śipriṇīvant": ['cae'],
    "śipriṇīvat": ['ddsa', 'gra', 'mw'],
    "śiprā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śipāṭaka": ['mw'],
    "śir": ['cae', 'ddsa', 'gra', 'mw'],
    "śira": ['ddsa', 'mw'],
    "śiraja": ['mw'],
    "śiramakuṭa": ['bhs'],
    "śiras": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śirasa": ['mw'],
    "śirasi": ['mw'],
    "śirasija": ['cae', 'ddsa', 'mw'],
    "śirasijapāśa": ['mw'],
    "śirasijaḥ": ['ap90'],
    "śirasiruh": ['mw'],
    "śirasiruha": ['mw'],
    "śirasisic": ['mw'],
    "śirasita": ['mw'],
    "śirasitāḥ": ['bhs'],
    "śiraska": ['cae', 'ddsa', 'mw'],
    "śiraskatva": ['mw'],
    "śiraskaṃ": ['ap90'],
    "śiraskā": ['ap90', 'mw'],
    "śirasnāta": ['mw'],
    "śiraspada": ['mw'],
    "śirasstha": ['mw'],
    "śirastas": ['ap90', 'cae', 'mw'],
    "śirastra": ['cae', 'mw'],
    "śirastrāṇa": ['cae', 'mw'],
    "śirastāpin": ['mw'],
    "śirasya": ['ap90', 'mw'],
    "śirasāhvaya": ['bhs'],
    "śiraupaniṣad": ['mw'],
    "śiraś": ['mw'],
    "śiraścheda": ['cae', 'mw'],
    "śiraśchedana": ['mw'],
    "śiraḥ": ['mw'],
    "śiraḥkampa": ['cae', 'mw'],
    "śiraḥkampin": ['mw'],
    "śiraḥkapāla": ['cae', 'ddsa', 'mw'],
    "śiraḥkapālin": ['mw'],
    "śiraḥkarṇa": ['cae', 'mw'],
    "śiraḥkriyā": ['mw'],
    "śiraḥkṛntana": ['mw'],
    "śiraḥpaṭṭa": ['cae', 'mw'],
    "śiraḥphala": ['mw'],
    "śiraḥpiṇḍa": ['mw'],
    "śiraḥpradāna": ['mw'],
    "śiraḥpraṇāma": ['mw'],
    "śiraḥprāvaraṇa": ['mw'],
    "śiraḥpāka": ['mw'],
    "śiraḥpīḍā": ['mw'],
    "śiraḥpīṭha": ['mw'],
    "śiraḥsnāna": ['mw'],
    "śiraḥsnānīya": ['mw'],
    "śiraḥsnāta": ['cae', 'mw'],
    "śiraḥsraj": ['mw'],
    "śiraḥstha": ['ddsa', 'mw'],
    "śiraḥsthita": ['mw'],
    "śiraḥsthāna": ['mw'],
    "śiraḥśeṣa": ['cae', 'mw'],
    "śiraḥśila": ['mw'],
    "śiraḥśreṇi": ['mw'],
    "śiraḥśrit": ['mw'],
    "śiraḥśāṭaka": ['mw'],
    "śiraḥśūla": ['cae', 'mw'],
    "śiraṃ": ['ap90'],
    "śiri": ['bhs', 'mw'],
    "śiribhadra": ['bhs'],
    "śirijātaka": ['bhs'],
    "śirikā": ['bhs'],
    "śirimbiṭha": ['ddsa', 'gra', 'mw'],
    "śiriprabha": ['bhs'],
    "śiriśirā": ['mw'],
    "śiriśirāya": ['mw'],
    "śiriḥ": ['ap90'],
    "śiriṇā": ['ddsa', 'gra', 'mw'],
    "śiro": ['mw'],
    "śirobhava": ['mw'],
    "śirobhitāpa": ['cae', 'mw'],
    "śirobhāga": ['cae', 'mw'],
    "śirobhūṣaṇa": ['cae', 'mw'],
    "śirobhūṣaṇāya": ['mw'],
    "śirobīja": ['mw'],
    "śirodhara": ['cae', 'mw'],
    "śirodharaṇīya": ['cae', 'mw'],
    "śirodharā": ['mw'],
    "śirodhi": ['mw'],
    "śirodhra": ['mw'],
    "śirodhāman": ['mw'],
    "śirodhārya": ['cae', 'mw'],
    "śirodhūnana": ['cae', 'mw'],
    "śiroduḥkha": ['cae', 'mw'],
    "śirodāman": ['cae', 'mw'],
    "śirogada": ['mw'],
    "śirogata": ['mw'],
    "śirogaurava": ['mw'],
    "śirogeha": ['mw'],
    "śiroghāta": ['cae', 'mw'],
    "śirograha": ['mw'],
    "śirogrīva": ['cae', 'ddsa', 'mw'],
    "śirogṛha": ['mw'],
    "śirohārin": ['mw'],
    "śirohṛtkamala": ['cae', 'mw'],
    "śiroja": ['cae', 'mw'],
    "śirojvara": ['mw'],
    "śirojānu": ['mw'],
    "śiromarman": ['mw'],
    "śiromauli": ['mw'],
    "śiromaṇi": ['cae', 'mw'],
    "śiromaṇibhaṭṭa": ['mw'],
    "śiromaṇibhaṭṭācārya": ['mw'],
    "śiromaṇikhaṇḍana": ['mw'],
    "śiromaṇimathurānāthīya": ['mw'],
    "śiromaṇinyāyānusārivivṛti": ['mw'],
    "śiromaṇitā": ['mw'],
    "śiromaṇivyākhyā": ['mw'],
    "śiromukha": ['cae', 'mw'],
    "śiromālin": ['mw'],
    "śiromātrāvaśeṣa": ['mw'],
    "śironati": ['mw'],
    "śironyāsa": ['mw'],
    "śiropasthāyin": ['mw'],
    "śiropti": ['mw'],
    "śirorakṣin": ['mw'],
    "śiroratna": ['cae', 'mw'],
    "śiroroga": ['mw'],
    "śirorogaghnayajñopavītadāna": ['mw'],
    "śirorti": ['mw'],
    "śiroruh": ['mw'],
    "śiroruha": ['cae', 'mw'],
    "śiroruhā": ['mw'],
    "śiroruj": ['cae', 'mw'],
    "śirorujā": ['cae', 'mw'],
    "śirosthi": ['mw'],
    "śirovallī": ['mw'],
    "śirovartin": ['mw'],
    "śirovasti": ['mw'],
    "śirovedanā": ['cae', 'mw'],
    "śiroveṣṭa": ['mw'],
    "śiroveṣṭana": ['bhs', 'mw'],
    "śirovirecana": ['mw'],
    "śirovireka": ['mw'],
    "śirovrata": ['mw'],
    "śirovāhya": ['mw'],
    "śirovṛtta": ['mw'],
    "śirovṛttaphala": ['mw'],
    "śiruha": ['cae'],
    "śirā": ['ap90', 'mw'],
    "śirāla": ['ap90'],
    "śirījalarāja": ['bhs'],
    "śirīmatī": ['bhs'],
    "śirīṣa": ['cae', 'ddsa', 'mw'],
    "śirīṣabīja": ['mw'],
    "śirīṣaka": ['mw'],
    "śirīṣakusuma": ['mw'],
    "śirīṣapattrikā": ['mw'],
    "śirīṣapattrā": ['mw'],
    "śirīṣaphala": ['mw'],
    "śirīṣavana": ['mw'],
    "śirīṣavaṇa": ['mw'],
    "śirīṣaḥ": ['ap90'],
    "śirīṣika": ['mw'],
    "śirīṣikā": ['mw'],
    "śirīṣin": ['mw'],
    "śirīṣiṇī": ['mw'],
    "śis": ['gra'],
    "śista": ['bhs'],
    "śit": ['ddsa', 'mw'],
    "śita": ['ap90', 'cae', 'ddsa', 'mw'],
    "śitadhāra": ['cae'],
    "śitadru": ['mw'],
    "śitadruḥ": ['ap90'],
    "śithila": ['ap90', 'cae', 'ddsa', 'mw'],
    "śithilabala": ['mw'],
    "śithilakuṇḍala": ['bhs'],
    "śithilam": ['mw'],
    "śithilambhāva": ['mw'],
    "śithilaprayatna": ['mw'],
    "śithilapīḍita": ['mw'],
    "śithilapīḍitatā": ['mw'],
    "śithilasamādhi": ['cae', 'ddsa', 'mw'],
    "śithilatva": ['mw'],
    "śithilatā": ['cae', 'mw'],
    "śithilavasu": ['mw'],
    "śithilay": ['cae'],
    "śithilaya": ['ddsa', 'mw'],
    "śithilayati": ['ap90'],
    "śithilaśakti": ['mw'],
    "śithilita": ['ap90', 'mw'],
    "śithilitajya": ['mw'],
    "śithilitamṛṇāla": ['mw'],
    "śithilāya": ['ddsa', 'mw'],
    "śithilāyate": ['ap90'],
    "śithilī": ['mw'],
    "śithilībhū": ['mw'],
    "śithilībhūta": ['mw'],
    "śithilīkaraṇa": ['mw'],
    "śithilīkṛ": ['cae', 'ddsa', 'mw'],
    "śithilīkṛta": ['mw'],
    "śithilīśānti": ['mw'],
    "śithira": ['cae', 'ddsa', 'gra', 'mw'],
    "śiti": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śitibhasad": ['mw'],
    "śitibhru": ['cae', 'mw'],
    "śitibāhu": ['cae', 'mw'],
    "śiticandana": ['mw'],
    "śiticchada": ['mw'],
    "śiticāra": ['mw'],
    "śitikakud": ['mw'],
    "śitikakuda": ['mw'],
    "śitikakṣa": ['cae', 'mw'],
    "śitikakṣin": ['mw'],
    "śitikaṇṭha": ['cae', 'mw'],
    "śitikaṇṭhaka": ['cae', 'mw'],
    "śitikaṇṭharāmāyaṇa": ['mw'],
    "śitikaṇṭhastotra": ['mw'],
    "śitikaṇṭhīya": ['mw'],
    "śitikaṇṭhīyaṭippaṇī": ['mw'],
    "śitikeśa": ['mw'],
    "śitikumbha": ['mw'],
    "śitilalāṭa": ['mw'],
    "śitimāṃsa": ['cae', 'mw'],
    "śitinas": ['mw'],
    "śitipad": ['cae', 'gra', 'mw'],
    "śitipakṣa": ['cae', 'mw'],
    "śitiprabha": ['mw'],
    "śitipād": ['cae'],
    "śitipāda": ['cae', 'mw'],
    "śitipṛṣṭha": ['cae', 'gra', 'mw'],
    "śitirandhra": ['mw'],
    "śitiratna": ['cae', 'mw'],
    "śitisāraka": ['mw'],
    "śitivara": ['mw'],
    "śitivāla": ['cae', 'mw'],
    "śitivāra": ['cae', 'mw'],
    "śitivāsas": ['cae', 'mw'],
    "śitiṅga": ['cae', 'mw'],
    "śitodara": ['cae'],
    "śitpuṭa": ['mw'],
    "śity": ['mw'],
    "śityaṃsa": ['cae', 'mw'],
    "śityoṣṭha": ['cae', 'mw'],
    "śitābhra": ['mw'],
    "śitāman": ['cae', 'mw'],
    "śitāmatas": ['mw'],
    "śitāvara": ['mw'],
    "śitīcūḍa": ['bhs'],
    "śitīkṛ": ['ddsa'],
    "śitīkṣu": ['mw'],
    "śitīman": ['mw'],
    "śitīmat": ['mw'],
    "śiva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śivabhadra": ['bhs', 'mw'],
    "śivabhadrakāvya": ['mw'],
    "śivabhakta": ['cae', 'mw'],
    "śivabhaktamāhātmya": ['mw'],
    "śivabhakti": ['cae', 'mw'],
    "śivabhaktimuktābharaṇa": ['mw'],
    "śivabhaktimāhātmya": ['mw'],
    "śivabhaktisudhodaya": ['mw'],
    "śivabhaktisudhānidhi": ['mw'],
    "śivabhaktisudhārṇava": ['mw'],
    "śivabhaktivilāsa": ['mw'],
    "śivabhaktānanda": ['mw'],
    "śivabhaktānandakārikā": ['mw'],
    "śivabhaṭṭa": ['mw'],
    "śivabhujaṃga": ['mw'],
    "śivabhujaṃgastotra": ['mw'],
    "śivabhujaṃgāṣṭaka": ['mw'],
    "śivabhāgavata": ['mw'],
    "śivabhārata": ['mw'],
    "śivabhāratī": ['mw'],
    "śivabhāskara": ['mw'],
    "śivabhūti": ['cae', 'mw'],
    "śivabhūtika": ['mw'],
    "śivabīja": ['mw'],
    "śivacakra": ['mw'],
    "śivacampū": ['mw'],
    "śivacandra": ['mw'],
    "śivacaritra": ['mw'],
    "śivacaturdaśī": ['mw'],
    "śivacaturdaśīvrata": ['mw'],
    "śivacatuḥślokīvyākhyā": ['mw'],
    "śivacitta": ['mw'],
    "śivadaiva": ['mw'],
    "śivadatta": ['cae', 'mw'],
    "śivadattamāla": ['bhs'],
    "śivadattapura": ['mw'],
    "śivadayālu": ['mw'],
    "śivadayāsahasra": ['mw'],
    "śivadaśaka": ['mw'],
    "śivadaṇḍaka": ['mw'],
    "śivadeva": ['mw'],
    "śivadhanurveda": ['mw'],
    "śivadharma": ['mw'],
    "śivadharmopapurāṇa": ['mw'],
    "śivadharmottara": ['mw'],
    "śivadhyānapaddhati": ['mw'],
    "śivadhāra": ['mw'],
    "śivadhāriṇī": ['mw'],
    "śivadhātu": ['mw'],
    "śivadiś": ['cae', 'mw'],
    "śivadruma": ['mw'],
    "śivadviṣṭā": ['mw'],
    "śivadyumaṇidīpikā": ['mw'],
    "śivadāru": ['mw'],
    "śivadāsa": ['cae', 'mw'],
    "śivadāsadeva": ['mw'],
    "śivadāsasena": ['mw'],
    "śivadāyin": ['mw'],
    "śivadīkṣā": ['mw'],
    "śivadīkṣāṭīkā": ['mw'],
    "śivadīna": ['mw'],
    "śivadīnadāsa": ['mw'],
    "śivadūtikā": ['mw'],
    "śivadūtī": ['mw'],
    "śivadūtītantra": ['mw'],
    "śivadṛṣṭi": ['mw'],
    "śivagati": ['mw'],
    "śivagayā": ['mw'],
    "śivagaṅgā": ['mw'],
    "śivagaṅgāmāhātmya": ['mw'],
    "śivagaṅgātīrtha": ['mw'],
    "śivagaṇa": ['mw'],
    "śivagaṇapura": ['mw'],
    "śivagharmaja": ['mw'],
    "śivaghoṣā": ['bhs'],
    "śivaguptadeva": ['mw'],
    "śivaguru": ['mw'],
    "śivagāyatrī": ['mw'],
    "śivagītā": ['mw'],
    "śivagītābhāṣya": ['mw'],
    "śivagītādīpikā": ['mw'],
    "śivagītātātparyabodhinī": ['mw'],
    "śivagītāvyākhyā": ['mw'],
    "śivajyotirvid": ['mw'],
    "śivajña": ['mw'],
    "śivajñā": ['mw'],
    "śivajñāna": ['mw'],
    "śivajñānabodha": ['mw'],
    "śivajñānabodhasūtra": ['mw'],
    "śivajñānatārāvalī": ['mw'],
    "śivajñānavidyā": ['mw'],
    "śivajñāneśvara": ['mw'],
    "śivajī": ['mw'],
    "śivaka": ['mw'],
    "śivakara": ['mw'],
    "śivakarṇāmṛta": ['mw'],
    "śivakarṇī": ['mw'],
    "śivakavaca": ['mw'],
    "śivakaḥ": ['ap90'],
    "śivakaṇṭhamalikā": ['mw'],
    "śivakesara": ['mw'],
    "śivakeśādipādāntavarṇanastotra": ['mw'],
    "śivakhaṇḍa": ['mw'],
    "śivakiṃkara": ['mw'],
    "śivakopamuni": ['mw'],
    "śivakośa": ['mw'],
    "śivakusumāñjali": ['mw'],
    "śivakuṇḍa": ['mw'],
    "śivakāmadughā": ['mw'],
    "śivakāntā": ['mw'],
    "śivakāntī": ['mw'],
    "śivakāriṇī": ['mw'],
    "śivakāñcī": ['mw'],
    "śivakāñcīmāhātmya": ['mw'],
    "śivakīrtana": ['mw'],
    "śivakṛṣṇa": ['mw'],
    "śivakṣetra": ['cae', 'ddsa', 'mw'],
    "śivalaharī": ['mw'],
    "śivaliṅga": ['cae', 'mw'],
    "śivaliṅgadānavidhi": ['mw'],
    "śivaliṅgalakṣaṇa": ['mw'],
    "śivaliṅgaparīkṣā": ['mw'],
    "śivaliṅgapratiṣṭhākrama": ['mw'],
    "śivaliṅgapratiṣṭhāprayoga": ['mw'],
    "śivaliṅgapratiṣṭhāvidhi": ['mw'],
    "śivaliṅgasūryodaya": ['mw'],
    "śivaliṅgin": ['mw'],
    "śivaliṅgānandajñānodaya": ['mw'],
    "śivaloka": ['cae', 'mw'],
    "śivalāla": ['mw'],
    "śivalīlāmṛta": ['mw'],
    "śivalīlārṇava": ['mw'],
    "śivam": ['mw'],
    "śivamahiman": ['mw'],
    "śivamahimaprakhyāpana": ['mw'],
    "śivamahimavyākhyā": ['mw'],
    "śivamahimnaḥstava": ['mw'],
    "śivamahimnaḥstotra": ['mw'],
    "śivamallaka": ['mw'],
    "śivamallikā": ['mw'],
    "śivamallī": ['mw'],
    "śivamantra": ['bhs', 'mw'],
    "śivamantravidhi": ['mw'],
    "śivamauli": ['mw'],
    "śivamaya": ['cae', 'mw'],
    "śivamaṅgalāṣṭaka": ['mw'],
    "śivamāhātmya": ['mw'],
    "śivamāhātmyakhaṇḍa": ['mw'],
    "śivamāhātmyamuktāvalī": ['mw'],
    "śivamālā": ['mw'],
    "śivamānasapūjā": ['mw'],
    "śivamānasikasnāna": ['mw'],
    "śivamārga": ['cae', 'mw'],
    "śivamātra": ['bhs', 'mw'],
    "śivanakṣatramālikā": ['mw'],
    "śivanakṣatrapuruṣavrata": ['mw'],
    "śivanirmālyabhakṣaṇa": ['mw'],
    "śivanirvāṇastotra": ['mw'],
    "śivanābhi": ['mw'],
    "śivanāmāvalī": ['mw'],
    "śivanāmāṣṭottaraśata": ['mw'],
    "śivanārāyaṇa": ['mw'],
    "śivanārāyaṇadāsa": ['mw'],
    "śivanārāyaṇaghoṣa": ['mw'],
    "śivanārāyaṇānandatīrtha": ['mw'],
    "śivanātha": ['mw'],
    "śivapada": ['mw'],
    "śivapaddhati": ['mw'],
    "śivapara": ['mw'],
    "śivapathikā": ['bhs'],
    "śivapathī": ['bhs'],
    "śivapattra": ['mw'],
    "śivapattramuhūrtaprakaraṇa": ['mw'],
    "śivapavitraka": ['mw'],
    "śivapañcamukhadhyāna": ['mw'],
    "śivapañcaratna": ['mw'],
    "śivapañcavadanastotra": ['mw'],
    "śivapañcākṣarastotra": ['mw'],
    "śivapañcākṣarī": ['mw'],
    "śivapañcākṣarīmuktāvalī": ['mw'],
    "śivapañcākṣarīmāhātmya": ['mw'],
    "śivapañcākṣarīnakṣatramālikā": ['mw'],
    "śivapañcāśikā": ['mw'],
    "śivapañcāṅga": ['mw'],
    "śivaphalābhiṣeka": ['mw'],
    "śivaprakāsakasiṃha": ['mw'],
    "śivaprakāśadeva": ['mw'],
    "śivaprasāda": ['mw'],
    "śivaprasādasundarastava": ['mw'],
    "śivaprasādavikṛti": ['mw'],
    "śivapratiṣṭhā": ['mw'],
    "śivapratiṣṭhāpaddhati": ['mw'],
    "śivapraṇāmaśikṣāstuti": ['mw'],
    "śivapriya": ['mw'],
    "śivapriyā": ['cae', 'mw'],
    "śivaprādurbhāva": ['mw'],
    "śivaprārthanāstotra": ['mw'],
    "śivapur": ['mw'],
    "śivapura": ['bhs', 'cae', 'mw'],
    "śivapurāṇa": ['cae', 'mw'],
    "śivapurāṇatāmasatvakhaṇḍana": ['mw'],
    "śivapurī": ['mw'],
    "śivaputra": ['mw'],
    "śivapuṣpaka": ['mw'],
    "śivapādādikeśāntavarṇanastotra": ['mw'],
    "śivapāramparyapratipādikaśrutismṛtyudāharaṇa": ['mw'],
    "śivapārvatīsaṃvāda": ['mw'],
    "śivapūjana": ['mw'],
    "śivapūjā": ['mw'],
    "śivapūjāmahiman": ['mw'],
    "śivapūjāpaddhati": ['mw'],
    "śivapūjāprakāśa": ['mw'],
    "śivapūjāsaṃgraha": ['mw'],
    "śivapūjāvidhi": ['mw'],
    "śivapūjāvidhāna": ['mw'],
    "śivarahasya": ['mw'],
    "śivarasa": ['mw'],
    "śivaratha": ['mw'],
    "śivaratnamālā": ['mw'],
    "śivaratnāvalī": ['mw'],
    "śivaratnāvalīvyākhyā": ['mw'],
    "śivarāghavasaṃvāda": ['mw'],
    "śivarāgra": ['bhs'],
    "śivarāja": ['mw'],
    "śivarājabhaṭṭa": ['mw'],
    "śivarājacaritra": ['mw'],
    "śivarājadhānī": ['mw'],
    "śivarāma": ['mw'],
    "śivarāmagira": ['mw'],
    "śivarāmagītā": ['mw'],
    "śivarāmastotra": ['mw'],
    "śivarāmatīrtha": ['mw'],
    "śivarāmendra": ['mw'],
    "śivarāmānandatīrtha": ['mw'],
    "śivarātri": ['mw'],
    "śivarātrikalpa": ['mw'],
    "śivarātrikathā": ['mw'],
    "śivarātrimāhātmya": ['mw'],
    "śivarātrinirṇaya": ['mw'],
    "śivarātripūjā": ['mw'],
    "śivarātrivrata": ['mw'],
    "śivarātrivratakalpa": ['mw'],
    "śivarātrivratakathā": ['mw'],
    "śivarātrivratodyāpana": ['mw'],
    "śivarātryargha": ['mw'],
    "śivarūpa": ['mw'],
    "śivarūpin": ['cae'],
    "śivarūpya": ['mw'],
    "śivasahasranāman": ['mw'],
    "śivasahasranāmāvali": ['mw'],
    "śivasahāya": ['mw'],
    "śivasamarasa": ['mw'],
    "śivasamarasatā": ['mw'],
    "śivasamudra": ['mw'],
    "śivasarvasva": ['mw'],
    "śivasaṃhitā": ['mw'],
    "śivasaṃkalpa": ['cae', 'mw'],
    "śivasiddhānta": ['mw'],
    "śivasiddhāntaśāstra": ['mw'],
    "śivasiṃha": ['mw'],
    "śivaskanda": ['mw'],
    "śivaskandha": ['mw'],
    "śivastavarāja": ['mw'],
    "śivasthalamahimavarṇana": ['mw'],
    "śivastotra": ['mw'],
    "śivastuti": ['mw'],
    "śivasundarī": ['cae', 'mw'],
    "śivasva": ['mw'],
    "śivasvarūpamantra": ['mw'],
    "śivasvarūpapūjā": ['mw'],
    "śivasvarūpapūjāvidhi": ['mw'],
    "śivasvāmin": ['mw'],
    "śivasvāti": ['mw'],
    "śivasāsasana": ['mw'],
    "śivasāyujya": ['mw'],
    "śivasūkta": ['mw'],
    "śivasūnu": ['mw'],
    "śivasūtra": ['cae', 'mw'],
    "śivasūtrajālagrantha": ['mw'],
    "śivasūtravimarśinī": ['mw'],
    "śivasūtravivṛti": ['mw'],
    "śivatama": ['mw'],
    "śivatantra": ['mw'],
    "śivatara": ['mw'],
    "śivatattva": ['mw'],
    "śivatattvabodha": ['mw'],
    "śivatattvaprakāśikā": ['mw'],
    "śivatattvarahasya": ['mw'],
    "śivatattvaratnakalikā": ['mw'],
    "śivatattvaratnākara": ['mw'],
    "śivatattvasudhānidhi": ['mw'],
    "śivatattvaviveka": ['mw'],
    "śivatattvavivekakhaṇḍana": ['mw'],
    "śivatattvopaniṣad": ['mw'],
    "śivatattvārṇava": ['mw'],
    "śivatattvāvabodha": ['mw'],
    "śivatva": ['mw'],
    "śivatā": ['mw'],
    "śivatāla": ['mw'],
    "śivatāti": ['cae', 'ddsa', 'mw'],
    "śivatāṇḍava": ['mw'],
    "śivatāṇḍavastotra": ['mw'],
    "śivatīrtha": ['mw'],
    "śivavallabha": ['mw'],
    "śivavallabhā": ['mw'],
    "śivavallikā": ['mw'],
    "śivavallī": ['mw'],
    "śivavarmakathana": ['mw'],
    "śivavarman": ['mw'],
    "śivavilāsacampū": ['mw'],
    "śivavipra": ['mw'],
    "śivavivāhaprayoga": ['mw'],
    "śivaviṣṇustotra": ['mw'],
    "śivavratakalpa": ['mw'],
    "śivavratin": ['mw'],
    "śivavāhana": ['mw'],
    "śivavīja": ['mw'],
    "śivavīrya": ['mw'],
    "śivayajvan": ['mw'],
    "śivayoga": ['mw'],
    "śivayogibhikṣu": ['mw'],
    "śivayogin": ['mw'],
    "śivayogīndra": ['mw'],
    "śivayoṣit": ['cae', 'mw'],
    "śivaśabdakhaṇḍa": ['mw'],
    "śivaśakti": ['mw'],
    "śivaśaktimaya": ['mw'],
    "śivaśaktipūjanavidhi": ['mw'],
    "śivaśaktisiddhi": ['mw'],
    "śivaśarman": ['cae', 'mw'],
    "śivaśataka": ['mw'],
    "śivaśatanāmastotra": ['mw'],
    "śivaśaṃkara": ['mw'],
    "śivaśaṃkaragītā": ['mw'],
    "śivaśekhara": ['mw'],
    "śivaśikhariṇīstuti": ['mw'],
    "śivaśrī": ['mw'],
    "śivaśāstra": ['mw'],
    "śivaṃkara": ['mw'],
    "śivaṣaḍakṣarastotra": ['mw'],
    "śivendra": ['mw'],
    "śivetara": ['cae', 'mw'],
    "śiveṣṭa": ['mw'],
    "śiveṣṭā": ['mw'],
    "śivi": ['bhs', 'cae', 'mw'],
    "śivika": ['cae'],
    "śivikadvāra": ['bhs'],
    "śivikā": ['ap90'],
    "śivipiṣṭa": ['mw'],
    "śivira": ['cae', 'mw'],
    "śivirathaḥ": ['ap90'],
    "śiviraṃ": ['ap90'],
    "śiviḥ": ['ap90'],
    "śivodbheda": ['mw'],
    "śivopaniṣad": ['mw'],
    "śivopapurāṇa": ['mw'],
    "śivotkarṣa": ['mw'],
    "śivotkarṣamañjarī": ['mw'],
    "śivotkarṣaprakāśa": ['mw'],
    "śivā": ['ap90', 'ddsa', 'mw'],
    "śivābali": ['mw'],
    "śivābhimarśana": ['cae', 'gra', 'mw'],
    "śivācalamāhātmya": ['mw'],
    "śivācārasaṃgraha": ['mw'],
    "śivādeśaka": ['cae', 'mw'],
    "śivādhikyaśikhāmaṇi": ['mw'],
    "śivāditya": ['mw'],
    "śivādityamaṇidīpikā": ['mw'],
    "śivādityamaṇidīpikākhaṇḍana": ['mw'],
    "śivādityaprakāśikā": ['mw'],
    "śivādvaita": ['mw'],
    "śivādvaitanirṇaya": ['mw'],
    "śivādvaitaprakāśikā": ['mw'],
    "śivādvaitasiddhāntaprakāśikā": ['mw'],
    "śivādyaṣṭottaraśatanāman": ['mw'],
    "śivāgama": ['mw'],
    "śivāhlāda": ['mw'],
    "śivāhvā": ['mw'],
    "śivākhya": ['mw'],
    "śivāku": ['mw'],
    "śivākāra": ['ddsa'],
    "śivākṣa": ['mw'],
    "śivālakasūtra": ['bhs'],
    "śivālaya": ['cae', 'mw'],
    "śivālayapratiṣṭhā": ['mw'],
    "śivālikhita": ['mw'],
    "śivālikhitaparibhāṣā": ['mw'],
    "śivālu": ['mw'],
    "śivāluḥ": ['ap90'],
    "śivāmbudhi": ['mw'],
    "śivāmbātriśatī": ['mw'],
    "śivānanda": ['mw'],
    "śivānandalaharī": ['mw'],
    "śivānandanātha": ['mw'],
    "śivānandasena": ['mw'],
    "śivānubhavasūtra": ['mw'],
    "śivānī": ['ap90', 'mw'],
    "śivāpara": ['mw'],
    "śivāparādhakṣamāpaṇastotra": ['mw'],
    "śivāphalā": ['mw'],
    "śivāpriyā": ['mw'],
    "śivāpāmārjanamālāmantrastotra": ['mw'],
    "śivāpīḍa": ['mw'],
    "śivārcana": ['mw'],
    "śivārcanacandrikā": ['mw'],
    "śivārcanakrama": ['mw'],
    "śivārcanamahodadhi": ['mw'],
    "śivārcanapaddhati": ['mw'],
    "śivārcanaratna": ['mw'],
    "śivāri": ['mw'],
    "śivārka": ['mw'],
    "śivārkacandrikā": ['mw'],
    "śivārkamaṇidīpikā": ['mw'],
    "śivārkodaya": ['mw'],
    "śivārti": ['mw'],
    "śivārtiprakāra": ['mw'],
    "śivārudra": ['mw'],
    "śivāruta": ['mw'],
    "śivārya": ['mw'],
    "śivārādhanadīpikā": ['mw'],
    "śivārāti": ['mw'],
    "śivāsmṛti": ['mw'],
    "śivāstotra": ['mw'],
    "śivāstuti": ['mw'],
    "śivātharvaśīrṣopaniṣad": ['mw'],
    "śivātmaka": ['mw'],
    "śivāvidyā": ['bhs', 'mw'],
    "śivāyatana": ['cae', 'mw'],
    "śivāṇḍakalpa": ['mw'],
    "śivāṣṭaka": ['mw'],
    "śivāṣṭamūrtitattvaprakāśa": ['mw'],
    "śivāṣṭapadī": ['mw'],
    "śivāṣṭottarabhāṣya": ['mw'],
    "śivāṣṭottaraśatanāman": ['mw'],
    "śivāṭikā": ['mw'],
    "śivāṭī": ['mw'],
    "śivīratha": ['mw'],
    "śivīya": ['mw'],
    "śiñj": ['cae', 'ddsa', 'gra', 'mw'],
    "śiñjad": ['mw'],
    "śiñjadvalayasubhaga": ['mw'],
    "śiñjadṣaḍaṅghri": ['mw'],
    "śiñjat": ['mw'],
    "śiñjañjikā": ['mw'],
    "śiñjin": ['mw'],
    "śiñjinī": ['cae', 'mw'],
    "śiñjita": ['cae', 'mw'],
    "śiñjā": ['cae', 'ddsa', 'mw'],
    "śiñjālatā": ['mw'],
    "śiñjāna": ['mw'],
    "śiñjānabhramara": ['mw'],
    "śiñjāra": ['cae', 'gra', 'mw'],
    "śiñjāśvattha": ['mw'],
    "śiśan": ['cae', 'mw'],
    "śiśapā": ['mw'],
    "śiśava": ['bhs', 'mw'],
    "śiśaya": ['cae', 'ddsa', 'gra', 'mw'],
    "śiśayiṣu": ['cae', 'ddsa', 'mw'],
    "śiśayiṣā": ['mw'],
    "śiśira": ['ap90', 'cae', 'ddsa', 'mw'],
    "śiśiradīdhiti": ['cae', 'mw'],
    "śiśiragabhasti": ['mw'],
    "śiśiraghna": ['mw'],
    "śiśiragu": ['mw'],
    "śiśirakara": ['cae', 'mw'],
    "śiśirakiraṇa": ['cae', 'mw'],
    "śiśirakiraṇavāsara": ['mw'],
    "śiśirakāla": ['mw'],
    "śiśiramathita": ['mw'],
    "śiśiramayūkha": ['cae', 'mw'],
    "śiśiramāsa": ['mw'],
    "śiśirartu": ['cae', 'mw'],
    "śiśirartuvarṇana": ['mw'],
    "śiśirasamaya": ['cae', 'mw'],
    "śiśiratara": ['mw'],
    "śiśiratā": ['mw'],
    "śiśiray": ['cae'],
    "śiśiraya": ['ddsa', 'mw'],
    "śiśiraśrī": ['mw'],
    "śiśirita": ['mw'],
    "śiśiropacāra": ['ddsa', 'mw'],
    "śiśiroṣṇavarṣā": ['mw'],
    "śiśirā": ['mw'],
    "śiśirākṣa": ['mw'],
    "śiśirāpagama": ['mw'],
    "śiśirātyaya": ['cae', 'mw'],
    "śiśirāya": ['ddsa', 'mw'],
    "śiśirāyaṇa": ['mw'],
    "śiśirāṃśu": ['cae', 'ddsa', 'mw'],
    "śiśirāṃśutva": ['mw'],
    "śiśirī": ['mw'],
    "śiśirībhū": ['mw'],
    "śiśirīkṛ": ['cae', 'ddsa', 'mw'],
    "śiśivadāna": ['ap90'],
    "śiślikṣu": ['mw'],
    "śiśna": ['cae', 'ddsa', 'gra', 'mw'],
    "śiśnacchedana": ['mw'],
    "śiśnadeva": ['cae', 'gra', 'mw'],
    "śiśnapraṇejinī": ['mw'],
    "śiśnatha": ['cae', 'ddsa', 'gra', 'mw'],
    "śiśnaṃ": ['ap90'],
    "śiśnodara": ['mw'],
    "śiśnodarambhara": ['mw'],
    "śiśnodaraparāyaṇa": ['mw'],
    "śiśnodaratṛp": ['mw'],
    "śiśodara": ['mw'],
    "śiśoka": ['mw'],
    "śiśrivas": ['mw'],
    "śiśu": ['cae', 'ddsa', 'gra', 'mw'],
    "śiśubhāva": ['cae', 'mw'],
    "śiśubhūpati": ['mw'],
    "śiśubodha": ['mw'],
    "śiśubodhinī": ['mw'],
    "śiśucāndrāyaṇa": ['cae', 'mw'],
    "śiśudeśya": ['mw'],
    "śiśugandhā": ['mw'],
    "śiśuhariṇadṛś": ['mw'],
    "śiśuhatyā": ['mw'],
    "śiśuhitaiṣiṇī": ['mw'],
    "śiśujana": ['cae', 'mw'],
    "śiśuka": ['cae', 'ddsa', 'mw'],
    "śiśukaḥ": ['ap90'],
    "śiśukranda": ['mw'],
    "śiśukrandana": ['mw'],
    "śiśukrandīya": ['mw'],
    "śiśukrīḍā": ['mw'],
    "śiśukāla": ['cae', 'mw'],
    "śiśukṛcchra": ['cae', 'mw'],
    "śiśukṛcchrātikṛcchra": ['mw'],
    "śiśulaḥ": ['ap90'],
    "śiśumant": ['cae'],
    "śiśumat": ['gra', 'mw'],
    "śiśumāra": ['cae', 'mw'],
    "śiśumāragiri": ['bhs'],
    "śiśumāramukhī": ['mw'],
    "śiśumārarṣi": ['mw'],
    "śiśumāravasā": ['mw'],
    "śiśumāraśiras": ['mw'],
    "śiśumārākṛti": ['mw'],
    "śiśumārī": ['mw'],
    "śiśunandi": ['mw'],
    "śiśunāga": ['cae', 'mw'],
    "śiśunāka": ['mw'],
    "śiśunāman": ['mw'],
    "śiśuprabhodhālaṃkāra": ['mw'],
    "śiśupramāṇa": ['mw'],
    "śiśupriya": ['mw'],
    "śiśupāla": ['cae', 'mw'],
    "śiśupālahan": ['mw'],
    "śiśupālaka": ['mw'],
    "śiśupālakathā": ['mw'],
    "śiśupālaniṣūdana": ['mw'],
    "śiśupālavadha": ['cae', 'mw'],
    "śiśupālavadhaparvan": ['mw'],
    "śiśupālaśiraśchettṛ": ['mw'],
    "śiśurakṣāratna": ['mw'],
    "śiśuroman": ['mw'],
    "śiśusaukhya": ['mw'],
    "śiśutva": ['mw'],
    "śiśutā": ['cae', 'mw'],
    "śiśuvarjitā": ['mw'],
    "śiśuvāhaka": ['mw'],
    "śiśuvāhyaka": ['mw'],
    "śiśuḥ": ['ap90'],
    "śiśvan": ['mw'],
    "śiśvi": ['ddsa', 'gra', 'mw'],
    "śiśvidāna": ['mw'],
    "śiśūla": ['cae', 'ddsa', 'gra', 'mw'],
    "śiḥ": ['ap90'],
    "śiṃbaḥ": ['ap90'],
    "śiṃbikā": ['ap90'],
    "śiṃbī": ['ap90'],
    "śiṃgh": ['ap90'],
    "śiṃghita": ['ap90'],
    "śiṃghāṇakaḥ": ['ap90'],
    "śiṃghāṇaḥ": ['ap90'],
    "śiṃh": ['mw'],
    "śiṃhāṇa": ['mw'],
    "śiṃhāṇaka": ['mw'],
    "śiṃj": ['ap90'],
    "śiṃjaḥ": ['ap90'],
    "śiṃjaṃjikā": ['ap90'],
    "śiṃjinī": ['ap90'],
    "śiṃjita": ['ap90'],
    "śiṃjā": ['ap90'],
    "śiṃkh": ['ap90'],
    "śiṃśa": ['cae', 'mw'],
    "śiṃśapa": ['cae'],
    "śiṃśapā": ['ap90', 'ddsa', 'gra', 'mw'],
    "śiṃśapāsthala": ['mw'],
    "śiṃśapāyana": ['mw'],
    "śiṃśipā": ['mw'],
    "śiṃśumāra": ['cae', 'ddsa', 'gra', 'mw'],
    "śiṃśumārastava": ['mw'],
    "śiṃśumāraśānti": ['mw'],
    "śiṅga": ['mw'],
    "śiṅgabhaṭṭa": ['mw'],
    "śiṅgabhaṭṭīya": ['mw'],
    "śiṅgabhūpāla": ['mw'],
    "śiṅgabhūpālīya": ['mw'],
    "śiṅgadharaṇīsena": ['mw'],
    "śiṅgadharaṇīśa": ['mw'],
    "śiṅgarāja": ['mw'],
    "śiṅgaya": ['mw'],
    "śiṅgh": ['ddsa', 'mw'],
    "śiṅghaṇa": ['mw'],
    "śiṅghaṇadeva": ['mw'],
    "śiṅghinī": ['mw'],
    "śiṅghita": ['mw'],
    "śiṅghāṇa": ['mw'],
    "śiṅghāṇaka": ['mw'],
    "śiṅghāṇikā": ['mw'],
    "śiṅghāṇin": ['mw'],
    "śiṅgi": ['mw'],
    "śiṅgin": ['mw'],
    "śiṅgī": ['mw'],
    "śiṅkh": ['mw'],
    "śiṅkhapa": ['mw'],
    "śiṇḍākī": ['mw'],
    "śiṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śiṣita": ['bhs'],
    "śiṣya": ['cae', 'ddsa', 'mw'],
    "śiṣyadhīvṛddhidamahātantra": ['mw'],
    "śiṣyahitaiṣiṇī": ['mw'],
    "śiṣyahitā": ['mw'],
    "śiṣyahitānyāsa": ['mw'],
    "śiṣyaka": ['cae', 'mw'],
    "śiṣyaparamparā": ['mw'],
    "śiṣyapradeya": ['mw'],
    "śiṣyapraśnopaniṣad": ['mw'],
    "śiṣyaputra": ['mw'],
    "śiṣyarūpin": ['cae', 'mw'],
    "śiṣyasakha": ['mw'],
    "śiṣyate": ['bhs'],
    "śiṣyatva": ['mw'],
    "śiṣyatā": ['mw'],
    "śiṣyayati": ['bhs'],
    "śiṣyaśikṣāvāda": ['mw'],
    "śiṣyaśiṣṭi": ['mw'],
    "śiṣyaḥ": ['ap90'],
    "śiṣyaṇa": ['bhs'],
    "śiṣyopaniṣad": ['mw'],
    "śiṣyā": ['bhs'],
    "śiṣyāpayati": ['bhs'],
    "śiṣyāya": ['ddsa', 'mw'],
    "śiṣyīkṛ": ['ddsa', 'mw'],
    "śiṣṭa": ['ap90', 'cae', 'ddsa', 'mw'],
    "śiṣṭabhakṣa": ['cae', 'mw'],
    "śiṣṭacāra": ['mw'],
    "śiṣṭagītā": ['mw'],
    "śiṣṭaprayoga": ['cae', 'mw'],
    "śiṣṭasabhā": ['cae', 'mw'],
    "śiṣṭasammata": ['mw'],
    "śiṣṭasmṛti": ['mw'],
    "śiṣṭatva": ['mw'],
    "śiṣṭatā": ['ddsa', 'mw'],
    "śiṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "śiṣṭiḥ": ['ap90'],
    "śiṣṭācāra": ['cae', 'mw'],
    "śiṣṭācāraviruddha": ['mw'],
    "śiṣṭācārāviruddha": ['mw'],
    "śiṣṭācīrṇa": ['mw'],
    "śiṣṭādhyāya": ['mw'],
    "śiṣṭādiṣṭa": ['cae', 'mw'],
    "śiṣṭāgama": ['cae', 'mw'],
    "śiṣṭākaraṇa": ['mw'],
    "śiṣṭāntaka": ['mw'],
    "śiṣṭārtham": ['mw'],
    "śiṣṭāśana": ['mw'],
    "śiṣṭāśin": ['mw'],
    "śiṣṭāṇuśiṣṭa": ['mw'],
    "śiṭ": ['ap90', 'mw'],
    "śiṭā": ['bhs', 'mw'],
    "ślaiṣmika": ['ddsa', 'mw'],
    "ślakha": ['mw'],
    "ślakṣṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ślakṣṇaka": ['ap90', 'mw'],
    "ślakṣṇam": ['mw'],
    "ślakṣṇana": ['mw'],
    "ślakṣṇapattraka": ['mw'],
    "ślakṣṇapiṣṭa": ['mw'],
    "ślakṣṇarūpasamanvita": ['mw'],
    "ślakṣṇatara": ['mw'],
    "ślakṣṇatvac": ['mw'],
    "ślakṣṇatā": ['mw'],
    "ślakṣṇatīkṣṇāgra": ['mw'],
    "ślakṣṇavāc": ['mw'],
    "ślakṣṇavādin": ['mw'],
    "ślakṣṇaya": ['mw'],
    "ślakṣṇaśilā": ['mw'],
    "ślakṣṇita": ['bhs'],
    "ślakṣṇā": ['bhs', 'mw'],
    "ślakṣṇī": ['mw'],
    "ślakṣṇīkaraṇa": ['mw'],
    "ślakṣṇīkṛ": ['mw'],
    "ślanavāsa": ['mw'],
    "ślath": ['ap90', 'cae', 'ddsa', 'mw'],
    "ślatha": ['ap90', 'cae', 'ddsa', 'mw'],
    "ślathabandhana": ['mw'],
    "ślathalambin": ['mw'],
    "ślathasaṃdhi": ['cae', 'mw'],
    "ślathasaṃdhitā": ['mw'],
    "ślathatva": ['mw'],
    "ślathaśila": ['cae', 'mw'],
    "ślathodyama": ['ddsa', 'mw'],
    "ślathādara": ['mw'],
    "ślathāy": ['cae'],
    "ślathāya": ['mw'],
    "ślathāṅga": ['cae', 'mw'],
    "ślathāṅgatā": ['mw'],
    "ślathīkṛ": ['ddsa', 'mw'],
    "ślavana": ['mw'],
    "ślaṃg": ['ap90'],
    "ślaṃk": ['ap90'],
    "ślaṅg": ['mw'],
    "ślaṅk": ['mw'],
    "śleṣa": ['cae', 'ddsa', 'mw'],
    "śleṣabhittika": ['mw'],
    "śleṣacampūrāmāyaṇa": ['mw'],
    "śleṣacūḍāmaṇi": ['mw'],
    "śleṣaka": ['mw'],
    "śleṣakavi": ['mw'],
    "śleṣamaya": ['mw'],
    "śleṣaḥ": ['ap90'],
    "śleṣaṇa": ['mw'],
    "śleṣaṇīya": ['mw'],
    "śleṣin": ['mw'],
    "śleṣita": ['mw'],
    "śleṣma": ['mw'],
    "śleṣmabhava": ['mw'],
    "śleṣmabhū": ['mw'],
    "śleṣmadhātu": ['mw'],
    "śleṣmaduṣṭa": ['mw'],
    "śleṣmaghana": ['mw'],
    "śleṣmaghna": ['mw'],
    "śleṣmaghnā": ['mw'],
    "śleṣmaghnī": ['mw'],
    "śleṣmagulma": ['mw'],
    "śleṣmaha": ['mw'],
    "śleṣmahara": ['mw'],
    "śleṣmaja": ['mw'],
    "śleṣmajvara": ['mw'],
    "śleṣmajvaranidāna": ['mw'],
    "śleṣmaka": ['mw'],
    "śleṣmakaḥ": ['ap90'],
    "śleṣmakaṭāhaka": ['mw'],
    "śleṣmakṛta": ['mw'],
    "śleṣmakṣaya": ['mw'],
    "śleṣmala": ['ap90', 'mw'],
    "śleṣman": ['ap90', 'cae', 'ddsa', 'mw'],
    "śleṣmapitta": ['mw'],
    "śleṣmapittajvara": ['mw'],
    "śleṣmapurīṣa": ['mw'],
    "śleṣmasaṃghātaja": ['mw'],
    "śleṣmatyāga": ['mw'],
    "śleṣmaujas": ['mw'],
    "śleṣmavat": ['mw'],
    "śleṣmavidagdha": ['mw'],
    "śleṣmavināśakṛt": ['mw'],
    "śleṣmavṛddhi": ['mw'],
    "śleṣmaśopha": ['mw'],
    "śleṣmaṇa": ['ap90', 'cae', 'mw'],
    "śleṣmaṇā": ['mw'],
    "śleṣmika": ['ap90', 'bhs'],
    "śleṣmin": ['mw'],
    "śleṣmopanāha": ['mw'],
    "śleṣmāgāra": ['mw'],
    "śleṣmāntaka": ['mw'],
    "śleṣmāpihitalocana": ['mw'],
    "śleṣmāsrāva": ['mw'],
    "śleṣmāta": ['mw'],
    "śleṣmātaka": ['cae', 'ddsa', 'mw'],
    "śleṣmātakamaya": ['mw'],
    "śleṣmātakaphala": ['mw'],
    "śleṣmātakatvac": ['mw'],
    "śleṣmātakavana": ['mw'],
    "śleṣmātaḥ": ['ap90'],
    "śleṣmātisāra": ['mw'],
    "śleṣmātura": ['mw'],
    "śleṣmāśmarī": ['mw'],
    "śleṣmāśru": ['mw'],
    "śleṣokti": ['mw'],
    "śleṣopamā": ['cae', 'mw'],
    "śleṣā": ['mw'],
    "śleṣārtha": ['mw'],
    "śleṣārthapadasaṃgraha": ['mw'],
    "śli": ['mw'],
    "śliku": ['mw'],
    "ślikuḥ": ['ap90'],
    "ślikyuḥ": ['ap90'],
    "śliṣ": ['ap90', 'cae', 'ddsa', 'mw'],
    "śliṣā": ['ap90', 'mw'],
    "śliṣṭa": ['ap90', 'cae', 'mw'],
    "śliṣṭaparamparitarūpaka": ['ddsa', 'mw'],
    "śliṣṭarūpaka": ['cae', 'mw'],
    "śliṣṭavartman": ['mw'],
    "śliṣṭi": ['mw'],
    "śliṣṭiḥ": ['ap90'],
    "śliṣṭokti": ['mw'],
    "śliṣṭākṣepa": ['mw'],
    "śliṣṭārthadīpaka": ['mw'],
    "ślok": ['ap90', 'mw'],
    "śloka": ['cae', 'ddsa', 'gra', 'mw'],
    "ślokabaddha": ['cae', 'mw'],
    "ślokabhū": ['mw'],
    "ślokacaraṇa": ['mw'],
    "ślokadvaya": ['mw'],
    "ślokadvayavyākhyā": ['mw'],
    "ślokadīpikā": ['mw'],
    "ślokagautama": ['mw'],
    "ślokakālanirṇaya": ['mw'],
    "ślokakāra": ['mw'],
    "ślokakṛt": ['mw'],
    "ślokamātra": ['mw'],
    "ślokapañcakavivaraṇa": ['mw'],
    "ślokasaṃgraha": ['mw'],
    "ślokasthāna": ['mw'],
    "ślokatarpaṇa": ['mw'],
    "ślokatraya": ['mw'],
    "ślokatva": ['mw'],
    "ślokavārttika": ['mw'],
    "ślokaya": ['ddsa', 'mw'],
    "ślokayantra": ['gra', 'mw'],
    "ślokayati": ['ap90'],
    "ślokaḥ": ['ap90'],
    "ślokin": ['cae', 'gra', 'mw'],
    "ślokya": ['cae', 'mw'],
    "ślokābhinayana": ['mw'],
    "ślokārdha": ['mw'],
    "ślokāvali": ['mw'],
    "śloṇ": ['ap90', 'mw'],
    "śloṇa": ['cae', 'ddsa', 'mw'],
    "śloṇaḥ": ['ap90'],
    "śloṇya": ['mw'],
    "ślu": ['ddsa', 'mw'],
    "śluvat": ['mw'],
    "ślāgh": ['ap90', 'cae', 'ddsa', 'mw'],
    "ślāghana": ['cae', 'ddsa', 'mw'],
    "ślāghanaṃ": ['ap90'],
    "ślāghanīya": ['cae', 'mw'],
    "ślāghanīyatara": ['mw'],
    "ślāghanīyatā": ['mw'],
    "ślāghate": ['bhs'],
    "ślāghin": ['cae', 'mw'],
    "ślāghita": ['ap90', 'mw'],
    "ślāghiṣṭha": ['mw'],
    "ślāghya": ['ap90', 'cae', 'mw'],
    "ślāghyam": ['mw'],
    "ślāghyapada": ['cae'],
    "ślāghyatama": ['mw'],
    "ślāghyatara": ['mw'],
    "ślāghyatā": ['mw'],
    "ślāghyayauvanā": ['cae', 'mw'],
    "ślāghyānvaya": ['cae', 'mw'],
    "ślāghā": ['ap90', 'cae', 'mw'],
    "ślāghāvaha": ['mw'],
    "ślākh": ['ap90', 'mw'],
    "ślākṣṇabhārika": ['mw'],
    "ślākṣṇika": ['mw'],
    "ślīla": ['ap90', 'ddsa', 'mw'],
    "ślīpada": ['cae', 'ddsa', 'mw'],
    "ślīpadaprabhava": ['mw'],
    "ślīpadaṃ": ['ap90'],
    "ślīpadin": ['ap90', 'ddsa', 'mw'],
    "ślīpadāpaha": ['mw'],
    "ślīpāda": ['bhs'],
    "śman": ['ap90', 'mw'],
    "śmasi": ['gra', 'mw'],
    "śmaśa": ['mw'],
    "śmaśayana": ['mw'],
    "śmaśru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śmaśrudhara": ['cae', 'mw'],
    "śmaśrudhārin": ['cae', 'mw'],
    "śmaśrujāta": ['mw'],
    "śmaśrukara": ['cae', 'mw'],
    "śmaśrukarman": ['cae', 'mw'],
    "śmaśrula": ['ap90', 'cae', 'ddsa', 'mw'],
    "śmaśrumukhī": ['mw'],
    "śmaśrupravṛddhi": ['mw'],
    "śmaśruvant": ['cae'],
    "śmaśruvardhaka": ['cae', 'mw'],
    "śmaśruvat": ['mw'],
    "śmaśruyajñopavītin": ['mw'],
    "śmaśruśekhara": ['mw'],
    "śmaśruṇa": ['cae', 'mw'],
    "śmaśrūya": ['ddsa', 'mw'],
    "śmaśā": ['cae', 'ddsa', 'gra', 'mw'],
    "śmaśāna": ['cae', 'ddsa', 'gra', 'mw'],
    "śmaśānabhairavī": ['mw'],
    "śmaśānabhāj": ['mw'],
    "śmaśānacit": ['mw'],
    "śmaśānagocara": ['cae', 'mw'],
    "śmaśānakaraṇa": ['mw'],
    "śmaśānakālikā": ['mw'],
    "śmaśānakālī": ['mw'],
    "śmaśānakālīkavaca": ['mw'],
    "śmaśānakālīmantra": ['mw'],
    "śmaśānaloṣṭa": ['mw'],
    "śmaśānanilaya": ['cae', 'mw'],
    "śmaśānanivāsin": ['mw'],
    "śmaśānapati": ['mw'],
    "śmaśānapāla": ['cae', 'mw'],
    "śmaśānasumanas": ['cae', 'mw'],
    "śmaśānasādhana": ['mw'],
    "śmaśānavairāgya": ['mw'],
    "śmaśānavartin": ['mw'],
    "śmaśānavetāla": ['mw'],
    "śmaśānaveśman": ['mw'],
    "śmaśānavāsin": ['cae', 'mw'],
    "śmaśānavāsinī": ['mw'],
    "śmaśānavāṭa": ['cae', 'mw'],
    "śmaśānavīthī": ['cae', 'mw'],
    "śmaśānaśūla": ['mw'],
    "śmaśānaṃ": ['ap90'],
    "śmaśānika": ['bhs', 'mw'],
    "śmaśānādhivyatikrama": ['mw'],
    "śmaśānāgni": ['mw'],
    "śmaśānālaya": ['mw'],
    "śmaśānālayavāsin": ['mw'],
    "śmaśānālayavāsinī": ['mw'],
    "śmaśāru": ['gra', 'mw'],
    "śme": ['mw'],
    "śmetra": ['mw'],
    "śmlpa, śalpaka": ['ddsa'],
    "śmāśānika": ['bhs', 'mw'],
    "śmīl": ['ap90', 'mw'],
    "śmīla": ['mw'],
    "śmīlanaṃ": ['ap90'],
    "śmīlita": ['mw'],
    "śmīlitaṃ": ['ap90'],
    "śnam": ['ap90', 'mw'],
    "śnaptra": ['cae', 'mw'],
    "śnath": ['cae', 'ddsa', 'gra', 'mw'],
    "śnathana": ['cae', 'gra', 'mw'],
    "śnathita": ['mw'],
    "śnathitṛ": ['cae', 'gra', 'mw'],
    "śnauṣṭa": ['mw'],
    "śnauṣṭīgava": ['mw'],
    "śnu": ['ap90', 'mw'],
    "śnuṣṭi": ['cae', 'mw'],
    "śnyaptra": ['mw'],
    "śnā": ['ap90', 'mw'],
    "śnābhāśnauṣṭīya": ['mw'],
    "śo": ['ap90', 'mw'],
    "śobha": ['bhs', 'cae', 'ddsa', 'mw'],
    "śobhajāta": ['mw'],
    "śobhaka": ['cae', 'mw'],
    "śobhakṛt": ['mw'],
    "śobhana": ['ap90', 'cae', 'gra', 'mw'],
    "śobhanaka": ['bhs', 'mw'],
    "śobhanakaḥ": ['ap90'],
    "śobhanasāgara": ['bhs'],
    "śobhanavatī": ['mw'],
    "śobhanavyūha": ['mw'],
    "śobhanavāha": ['mw'],
    "śobhanika": ['mw'],
    "śobhanā": ['bhs', 'mw'],
    "śobhanācarita": ['mw'],
    "śobhanīya": ['cae', 'mw'],
    "śobhase": ['cae', 'mw'],
    "śobhate": ['bhs'],
    "śobhatha": ['cae', 'mw'],
    "śobhayitṛ": ['mw'],
    "śobhika": ['bhs'],
    "śobhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śobhita": ['ap90', 'bhs', 'cae', 'mw'],
    "śobhiṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "śobhuśubha": ['mw'],
    "śobhā": ['ap90', 'ddsa', 'mw'],
    "śobhāka": ['mw'],
    "śobhākara": ['mw'],
    "śobhākarabhaṭṭa": ['mw'],
    "śobhākaramitra": ['mw'],
    "śobhāmaya": ['mw'],
    "śobhāsiṃha": ['mw'],
    "śobhāvatī": ['bhs', 'mw'],
    "śobhāya": ['mw'],
    "śobhāñjana": ['mw'],
    "śobhāñjanaka": ['mw'],
    "śoca": ['mw'],
    "śocaka": ['ap90'],
    "śocana": ['mw'],
    "śocanaṃ": ['ap90'],
    "śocanīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "śocanīyatā": ['mw'],
    "śocayantī": ['mw'],
    "śocayat": ['mw'],
    "śocayitṛ": ['mw'],
    "śoci": ['cae', 'gra', 'mw'],
    "śocis": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śocita": ['bhs'],
    "śocitavya": ['cae', 'mw'],
    "śocitavye": ['mw'],
    "śociṣ": ['mw'],
    "śociṣkeśa": ['cae', 'ddsa', 'gra', 'mw'],
    "śociṣmant": ['cae'],
    "śociṣmat": ['gra', 'mw'],
    "śociṣṭha": ['cae', 'ddsa', 'gra', 'mw'],
    "śocya": ['ap90', 'cae', 'ddsa', 'mw'],
    "śocyaka": ['mw'],
    "śocyatā": ['mw'],
    "śoddhavya": ['mw'],
    "śodha": ['mw'],
    "śodhaka": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śodhana": ['ap90', 'cae', 'mw'],
    "śodhanaka": ['cae', 'mw'],
    "śodhanakaḥ": ['ap90'],
    "śodhanī": ['ap90', 'mw'],
    "śodhanībīja": ['mw'],
    "śodhanīya": ['cae', 'mw'],
    "śodhapattra": ['mw'],
    "śodhayati": ['bhs'],
    "śodhayitavya": ['mw'],
    "śodhayitṛ": ['mw'],
    "śodhaḥ": ['ap90'],
    "śodhikā": ['mw'],
    "śodhin": ['cae', 'mw'],
    "śodhita": ['ap90', 'mw'],
    "śodhya": ['ap90', 'cae', 'mw'],
    "śoka": ['cae', 'ddsa', 'gra', 'mw'],
    "śokabhaṅga": ['mw'],
    "śokabhāra": ['mw'],
    "śokacarcā": ['mw'],
    "śokacchid": ['mw'],
    "śokaduḥkhasamanvita": ['mw'],
    "śokahārī": ['mw'],
    "śokaikamaya": ['mw'],
    "śokaja": ['cae', 'mw'],
    "śokakara": ['mw'],
    "śokakarṣita": ['mw'],
    "śokalālasa": ['mw'],
    "śokamaya": ['cae', 'mw'],
    "śokamūrchita": ['mw'],
    "śokanihata": ['mw'],
    "śokanāśa": ['mw'],
    "śokanāśana": ['mw'],
    "śokaparipluta": ['mw'],
    "śokaparāyaṇa": ['cae', 'mw'],
    "śokapaṅka": ['mw'],
    "śokapātrātman": ['cae', 'mw'],
    "śokarugṇa": ['mw'],
    "śokas": ['cae', 'gra'],
    "śokasaṃtapta": ['mw'],
    "śokasaṃtaptamānasa": ['mw'],
    "śokasaṃvignamānasa": ['mw'],
    "śokasthāna": ['mw'],
    "śokasāgara": ['mw'],
    "śokatara": ['cae', 'mw'],
    "śokavant": ['cae'],
    "śokavartavya": ['cae', 'mw'],
    "śokavat": ['mw'],
    "śokavihvala": ['mw'],
    "śokavikala": ['mw'],
    "śokavināśana": ['cae', 'mw'],
    "śokavināśin": ['mw'],
    "śokavivardhana": ['mw'],
    "śokaḥ": ['ap90'],
    "śokin": ['ap90'],
    "śokodbhava": ['mw'],
    "śokonmathitacittātman": ['mw'],
    "śokopahata": ['mw'],
    "śokotpādana": ['mw'],
    "śokābhibhūta": ['mw'],
    "śokāgni": ['mw'],
    "śokāgnisaṃtapta": ['mw'],
    "śokāgāra": ['bhs', 'mw'],
    "śokākula": ['mw'],
    "śokānala": ['mw'],
    "śokāntara": ['cae', 'mw'],
    "śokānuśoka": ['mw'],
    "śokānvita": ['mw'],
    "śokāpaha": ['mw'],
    "śokāpahartṛ": ['mw'],
    "śokāpanoda": ['mw'],
    "śokāpanuda": ['mw'],
    "śokāri": ['mw'],
    "śokārta": ['cae', 'mw'],
    "śokārti": ['cae', 'mw'],
    "śokārātibhayatrāṇa": ['mw'],
    "śokātiga": ['cae', 'mw'],
    "śokātisāra": ['mw'],
    "śokātura": ['cae'],
    "śokāveśa": ['cae', 'mw'],
    "śokāviṣṭa": ['mw'],
    "śokī": ['mw'],
    "śollaka": ['bhs'],
    "śolī": ['mw'],
    "śom": ['mw'],
    "śonita": ['mw'],
    "śonāya": ['mw'],
    "śopha": ['cae', 'ddsa', 'mw'],
    "śophaghnī": ['mw'],
    "śophahārin": ['mw'],
    "śophahṛt": ['mw'],
    "śophanāśana": ['mw'],
    "śophanāśanī": ['mw'],
    "śophaḥ": ['ap90'],
    "śophin": ['mw'],
    "śophita": ['mw'],
    "śophāri": ['mw'],
    "śos": ['mw'],
    "śotha": ['cae', 'ddsa', 'mw'],
    "śothaghnī": ['mw'],
    "śothahṛt": ['mw'],
    "śothajihma": ['mw'],
    "śothajit": ['mw'],
    "śothaka": ['mw'],
    "śothakṛt": ['mw'],
    "śotharoga": ['mw'],
    "śothaśatra": ['mw'],
    "śothaḥ": ['ap90'],
    "śothāri": ['mw'],
    "śośoṃsāvas": ['mw'],
    "śośubhyamāna": ['mw'],
    "śośucat": ['mw'],
    "śośucyamāna": ['mw'],
    "śośucāna": ['mw'],
    "śoḍha": ['ddsa', 'mw'],
    "śoṃs": ['mw'],
    "śoṃsāmas": ['mw'],
    "śoṃsāva": ['mw'],
    "śoṃsāvas": ['mw'],
    "śoṇ": ['ap90', 'ddsa', 'mw'],
    "śoṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śoṇabhadra": ['mw'],
    "śoṇahaya": ['cae', 'mw'],
    "śoṇajhiṇṭikā": ['mw'],
    "śoṇajhiṇṭī": ['mw'],
    "śoṇaka": ['mw'],
    "śoṇakarṇa": ['cae', 'mw'],
    "śoṇamaṇī": ['mw'],
    "śoṇanada": ['mw'],
    "śoṇapadma": ['mw'],
    "śoṇapadmaka": ['mw'],
    "śoṇapattra": ['mw'],
    "śoṇaprastha": ['mw'],
    "śoṇapura": ['mw'],
    "śoṇapuṣpaka": ['mw'],
    "śoṇapuṣpī": ['mw'],
    "śoṇaratna": ['mw'],
    "śoṇasambhava": ['mw'],
    "śoṇasaṃgama": ['mw'],
    "śoṇatā": ['cae', 'mw'],
    "śoṇavajra": ['mw'],
    "śoṇaśāli": ['mw'],
    "śoṇiman": ['ap90', 'cae', 'ddsa', 'mw'],
    "śoṇita": ['ap90', 'cae', 'ddsa', 'mw'],
    "śoṇitabinduvarṣin": ['mw'],
    "śoṇitacandana": ['mw'],
    "śoṇitamehin": ['mw'],
    "śoṇitamāṃsasāra": ['mw'],
    "śoṇitapa": ['mw'],
    "śoṇitapitta": ['mw'],
    "śoṇitapittavat": ['mw'],
    "śoṇitapriyā": ['mw'],
    "śoṇitapura": ['mw'],
    "śoṇitapāraṇā": ['mw'],
    "śoṇitasnāta": ['mw'],
    "śoṇitasāhvaya": ['mw'],
    "śoṇitatva": ['mw'],
    "śoṇitaugha": ['mw'],
    "śoṇitavarṇana": ['mw'],
    "śoṇitavarṇanīya": ['mw'],
    "śoṇitavarṣin": ['mw'],
    "śoṇitaśarkarā": ['mw'],
    "śoṇitin": ['mw'],
    "śoṇitoda": ['mw'],
    "śoṇitokṣita": ['mw'],
    "śoṇitopala": ['mw'],
    "śoṇitotpala": ['mw'],
    "śoṇitotpādaka": ['cae', 'mw'],
    "śoṇitābhiṣyanda": ['mw'],
    "śoṇitādigdha": ['mw'],
    "śoṇitāhvaya": ['mw'],
    "śoṇitākhya": ['mw'],
    "śoṇitākṣa": ['mw'],
    "śoṇitāmaya": ['mw'],
    "śoṇitārbuda": ['mw'],
    "śoṇitārśas": ['mw'],
    "śoṇitārśin": ['mw'],
    "śoṇitāśin": ['mw'],
    "śoṇopala": ['mw'],
    "śoṇottara": ['bhs'],
    "śoṇottarā": ['ddsa', 'mw'],
    "śoṇā": ['mw'],
    "śoṇādhara": ['cae', 'mw'],
    "śoṇāka": ['mw'],
    "śoṇāmbu": ['mw'],
    "śoṇāprastha": ['mw'],
    "śoṇāya": ['mw'],
    "śoṇāyita": ['mw'],
    "śoṇāśman": ['mw'],
    "śoṇāśva": ['cae', 'mw'],
    "śoṇī": ['mw'],
    "śoṇīkṛ": ['ddsa', 'mw'],
    "śoṇīpuramāhātmya": ['mw'],
    "śoṇīta": ['bhs'],
    "śoṇḍa": ['mw'],
    "śoṇḍī": ['mw'],
    "śoṣa": ['cae', 'ddsa', 'mw'],
    "śoṣaka": ['mw'],
    "śoṣasambhava": ['mw'],
    "śoṣayitavya": ['mw'],
    "śoṣayitṛ": ['mw'],
    "śoṣaḥ": ['ap90'],
    "śoṣaṇa": ['ap90', 'cae', 'mw'],
    "śoṣaṇīya": ['mw'],
    "śoṣin": ['ap90', 'cae', 'mw'],
    "śoṣita": ['ap90', 'mw'],
    "śoṣitasaras": ['mw'],
    "śoṣiṇī": ['mw'],
    "śoṣu": ['mw'],
    "śoṣya": ['mw'],
    "śoṣyantī": ['mw'],
    "śoṣāpahā": ['mw'],
    "śoṭha": ['ap90', 'mw'],
    "śoṭīrya": ['mw'],
    "śoṭīryaṃ": ['ap90'],
    "śrad": ['cae', 'mw'],
    "śraddadha": ['bhs'],
    "śraddadhāna": ['mw'],
    "śraddadhānatā": ['cae', 'ddsa', 'mw'],
    "śraddadhānavant": ['cae'],
    "śraddadhānavat": ['mw'],
    "śraddahanā": ['bhs'],
    "śraddha": ['ap90', 'bhs', 'mw'],
    "śraddhayat": ['mw'],
    "śraddhayate": ['bhs'],
    "śraddhayita": ['mw'],
    "śraddhayā": ['mw'],
    "śraddhendriya": ['mw'],
    "śraddheya": ['cae', 'ddsa', 'mw'],
    "śraddheyatva": ['mw'],
    "śraddheyatā": ['mw'],
    "śraddhin": ['cae', 'ddsa', 'mw'],
    "śraddhita": ['mw'],
    "śraddhiva": ['cae', 'gra', 'mw'],
    "śraddhā": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śraddhābalādhāna": ['bhs', 'mw'],
    "śraddhādeva": ['cae', 'mw'],
    "śraddhādeya": ['bhs', 'mw'],
    "śraddhājāḍya": ['mw'],
    "śraddhākṛta": ['mw'],
    "śraddhālu": ['ap90', 'cae', 'ddsa', 'mw'],
    "śraddhāmanas": ['cae', 'gra', 'mw'],
    "śraddhāmanasyā": ['cae', 'gra', 'mw'],
    "śraddhāmaya": ['cae', 'ddsa', 'mw'],
    "śraddhāna": ['cae'],
    "śraddhānusārin": ['mw'],
    "śraddhānvita": ['mw'],
    "śraddhāpana": ['mw'],
    "śraddhāprakaraṇa": ['mw'],
    "śraddhārahita": ['mw'],
    "śraddhāsamanvita": ['mw'],
    "śraddhātavya": ['ddsa', 'mw'],
    "śraddhātṛ": ['mw'],
    "śraddhāvant": ['cae'],
    "śraddhāvat": ['mw'],
    "śraddhāvatī": ['mw'],
    "śraddhāvimukta": ['mw'],
    "śraddhāvirahita": ['mw'],
    "śraddhāvitta": ['mw'],
    "śraddhāyukta": ['mw'],
    "śraddāna": ['mw'],
    "śrai": ['ap90', 'mw'],
    "śraiṇya": ['bhs', 'mw'],
    "śraiṣṭhya": ['cae', 'ddsa', 'mw'],
    "śraiṣṭhyatama": ['mw'],
    "śraiṣṭhyaṃ": ['ap90'],
    "śram": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śram, śrad": ['ddsa'],
    "śrama": ['cae', 'ddsa', 'gra', 'mw'],
    "śramacchid": ['cae', 'mw'],
    "śramaghna": ['cae', 'mw'],
    "śramaghnī": ['mw'],
    "śramajala": ['cae', 'mw'],
    "śramakara": ['cae', 'mw'],
    "śramakarśita": ['mw'],
    "śramakarṣita": ['mw'],
    "śramakhinna": ['mw'],
    "śramaklānta": ['mw'],
    "śramamohita": ['mw'],
    "śramanud": ['cae', 'ddsa', 'mw'],
    "śramapīḍita": ['mw'],
    "śramasaṃtāpakarṣita": ['mw'],
    "śramasiddha": ['mw'],
    "śramasthāna": ['mw'],
    "śramasādhya": ['mw'],
    "śramavat": ['mw'],
    "śramavinayana": ['mw'],
    "śramavinoda": ['mw'],
    "śramavāri": ['cae', 'mw'],
    "śramavāribindu": ['mw'],
    "śramavārileśa": ['mw'],
    "śramayu": ['cae', 'gra', 'mw'],
    "śramaśīkara": ['mw'],
    "śramaḥ": ['ap90'],
    "śramaṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śramaṇadatta": ['mw'],
    "śramaṇaka": ['bhs', 'cae', 'mw'],
    "śramaṇamaṇḍala": ['bhs'],
    "śramaṇavarṇapratirūpaka": ['bhs'],
    "śramaṇaśākyaputrīya": ['mw'],
    "śramaṇoddeśa": ['bhs', 'mw'],
    "śramaṇoddeśaka": ['bhs'],
    "śramaṇā": ['mw'],
    "śramaṇācārya": ['mw'],
    "śramaṇāy": ['cae'],
    "śramaṇāya": ['ddsa', 'mw'],
    "śramaṇāyate": ['ap90'],
    "śrambh": ['cae', 'ddsa', 'gra', 'mw'],
    "śramin": ['ap90', 'mw'],
    "śramādhāyin": ['mw'],
    "śramāmbu": ['cae', 'mw'],
    "śramāpanayana": ['mw'],
    "śramārta": ['cae', 'mw'],
    "śramāyukta": ['mw'],
    "śranth": ['mw'],
    "śrantha": ['mw'],
    "śranthana": ['mw'],
    "śranthita": ['mw'],
    "śrapa": ['mw'],
    "śrapay": ['cae'],
    "śrapaya": ['ddsa'],
    "śrapayitavya": ['mw'],
    "śrapayitṛ": ['cae', 'mw'],
    "śrapaṇa": ['cae', 'ddsa', 'mw'],
    "śrapaṇaṃ": ['ap90'],
    "śrapaṇī": ['mw'],
    "śrapaṇīya": ['mw'],
    "śrapita": ['ap90', 'mw'],
    "śrapitā": ['mw'],
    "śrapāyya": ['mw'],
    "śrat": ['ap90', 'mw'],
    "śrath": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śratha": ['mw'],
    "śrathana": ['mw'],
    "śrathanaṃ": ['ap90'],
    "śrathary": ['cae', 'gra'],
    "śratharya": ['mw'],
    "śrathāy": ['cae', 'gra'],
    "śrathāya": ['ddsa', 'mw'],
    "śratkṛ": ['mw'],
    "śraumata": ['mw'],
    "śraumatya": ['mw'],
    "śrauta": ['ap90', 'cae', 'ddsa', 'mw'],
    "śrautacandrikā": ['mw'],
    "śrautagrantha": ['mw'],
    "śrautahoma": ['mw'],
    "śrautakakṣa": ['mw'],
    "śrautakarman": ['mw'],
    "śrautakarmapadārthasaṃgraha": ['mw'],
    "śrautakarmaprāyaścitta": ['mw'],
    "śrautakarmaṇyāśvalāyanopayogiprāyaścitta": ['mw'],
    "śrautamārga": ['mw'],
    "śrautamīmāṃsā": ['mw'],
    "śrautanṛsiṃhakārikā": ['mw'],
    "śrautapaddhati": ['mw'],
    "śrautapadārthanirvacana": ['mw'],
    "śrautaparibhāṣāsaṃgrahavṛtti": ['mw'],
    "śrautaprakriyā": ['mw'],
    "śrautapravāsavidhi": ['mw'],
    "śrautaprayoga": ['mw'],
    "śrautaprayogasāman": ['mw'],
    "śrautapraśna": ['mw'],
    "śrautapraśnottaravyavasthā": ['mw'],
    "śrautaprāyaścitta": ['mw'],
    "śrautaprāyaścittacandrikā": ['mw'],
    "śrautaprāyaścittaprayoga": ['mw'],
    "śrautarṣa": ['mw'],
    "śrautasarvasva": ['mw'],
    "śrautasiddhānta": ['mw'],
    "śrautasmārtadharma": ['mw'],
    "śrautasmārtakarmapaddhati": ['mw'],
    "śrautasmārtakriyā": ['mw'],
    "śrautasmārtavidhi": ['mw'],
    "śrautasūtra": ['cae', 'mw'],
    "śrautasūtravidhi": ['mw'],
    "śrautasūtravyākhyā": ['mw'],
    "śrautavyākhyāna": ['mw'],
    "śrautavājapeya": ['mw'],
    "śrautayajñadarśapaurṇamāsikaprayoga": ['mw'],
    "śrautaśrava": ['mw'],
    "śrautaṛṣi": ['mw'],
    "śrauti": ['mw'],
    "śrautollāsa": ['mw'],
    "śrautra": ['cae', 'ddsa', 'mw'],
    "śrautraṃ": ['ap90'],
    "śrautriyaka": ['mw'],
    "śrautādhāna": ['mw'],
    "śrautādhānapaddhati": ['mw'],
    "śrautāhnika": ['mw'],
    "śrautāntyeṣṭi": ['mw'],
    "śrautānukramaṇikā": ['mw'],
    "śrautāṇḍabilā": ['mw'],
    "śrautīya": ['mw'],
    "śrauṣaṭ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śrauṣṭa": ['mw'],
    "śrauṣṭi": ['cae', 'gra', 'mw'],
    "śrauṣṭīgava": ['mw'],
    "śrauṣṭīya": ['mw'],
    "śrava": ['cae', 'ddsa', 'mw'],
    "śravaeṣa": ['cae', 'gra'],
    "śravas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śravasia": ['gra'],
    "śravaskāma": ['gra', 'mw'],
    "śravasy": ['cae', 'gra'],
    "śravasya": ['cae', 'ddsa', 'gra', 'mw'],
    "śravasyati": ['ap90'],
    "śravasyaṃ": ['ap90'],
    "śravasyu": ['cae', 'gra', 'mw'],
    "śravasyā": ['gra', 'mw'],
    "śravaḥ": ['ap90'],
    "śravaṇa": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śravaṇabhūṣaṇa": ['mw'],
    "śravaṇabhṛta": ['mw'],
    "śravaṇadatta": ['mw'],
    "śravaṇadvādaśī": ['mw'],
    "śravaṇadvādaśīvrata": ['mw'],
    "śravaṇadvādaśīvratakathā": ['mw'],
    "śravaṇagocara": ['cae', 'mw'],
    "śravaṇagocaratā": ['mw'],
    "śravaṇahārin": ['cae', 'mw'],
    "śravaṇaka": ['mw'],
    "śravaṇakātaratā": ['cae', 'ddsa', 'mw'],
    "śravaṇamaya": ['mw'],
    "śravaṇamāhātmya": ['mw'],
    "śravaṇamūla": ['cae', 'mw'],
    "śravaṇaparuṣa": ['cae', 'mw'],
    "śravaṇapatha": ['cae', 'mw'],
    "śravaṇapathagata": ['mw'],
    "śravaṇapathaparyantagamana": ['mw'],
    "śravaṇapathātithi": ['mw'],
    "śravaṇaprāghuṇika": ['mw'],
    "śravaṇaprāghuṇikīkṛta": ['mw'],
    "śravaṇapuṭaka": ['mw'],
    "śravaṇapāli": ['mw'],
    "śravaṇapāśa": ['mw'],
    "śravaṇapūraka": ['mw'],
    "śravaṇaruj": ['mw'],
    "śravaṇas": ['mw'],
    "śravaṇasubhaga": ['cae', 'mw'],
    "śravaṇasukha": ['cae', 'mw'],
    "śravaṇasya": ['mw'],
    "śravaṇavidhi": ['mw'],
    "śravaṇavidhivicāra": ['mw'],
    "śravaṇavidāraṇa": ['mw'],
    "śravaṇaviṣaya": ['cae', 'mw'],
    "śravaṇaviṣayaprāpin": ['mw'],
    "śravaṇavyādhi": ['mw'],
    "śravaṇaśīrṣikā": ['mw'],
    "śravaṇaḥ": ['ap90'],
    "śravaṇendriya": ['mw'],
    "śravaṇikāvrata": ['mw'],
    "śravaṇodara": ['ddsa', 'mw'],
    "śravaṇodyāpana": ['mw'],
    "śravaṇotpala": ['mw'],
    "śravaṇā": ['mw'],
    "śravaṇādhikārin": ['mw'],
    "śravaṇāhvayā": ['mw'],
    "śravaṇākarman": ['mw'],
    "śravaṇāmukha": ['bhs'],
    "śravaṇānanda": ['mw'],
    "śravaṇānandinī": ['mw'],
    "śravaṇāpakṣa": ['mw'],
    "śravaṇāvabhāsa": ['mw'],
    "śravaṇī": ['mw'],
    "śravaṇīya": ['cae', 'ddsa', 'mw'],
    "śravaṇīyapāra": ['mw'],
    "śraviṣṭha": ['mw'],
    "śraviṣṭhaka": ['mw'],
    "śraviṣṭhā": ['ap90', 'cae', 'ddsa', 'mw'],
    "śraviṣṭhābhū": ['mw'],
    "śraviṣṭhāja": ['mw'],
    "śraviṣṭhāramaṇa": ['mw'],
    "śraviṣṭhīya": ['mw'],
    "śravo": ['mw'],
    "śravojit": ['gra', 'mw'],
    "śravya": ['cae', 'ddsa', 'mw'],
    "śravyatva": ['mw'],
    "śravāpya": ['mw'],
    "śravāpyaḥ": ['ap90'],
    "śravāyia": ['gra'],
    "śravāyya": ['cae', 'ddsa', 'gra', 'mw'],
    "śraya": ['mw'],
    "śrayaḥ": ['ap90'],
    "śrayaṇa": ['cae', 'ddsa', 'mw'],
    "śrayaṇīya": ['mw'],
    "śrayin": ['mw'],
    "śrayitavya": ['mw'],
    "śrayiṣṭha": ['gra'],
    "śrayiṣṭhavarcas": ['gra'],
    "śrayiṣṭhaśocis": ['gra'],
    "śraṃbh": ['ap90', 'cae'],
    "śraṃg": ['ap90'],
    "śraṃk": ['ap90'],
    "śraṃs": ['mw'],
    "śraṃth": ['ap90'],
    "śraṃthanaṃ": ['ap90'],
    "śraṃthaḥ": ['ap90'],
    "śraṃthita": ['ap90'],
    "śraṃś": ['mw'],
    "śraṅg": ['mw'],
    "śraṅk": ['mw'],
    "śraṇ": ['ap90', 'cae', 'mw'],
    "śraṇa": ['ddsa'],
    "średhī": ['mw'],
    "średhīphala": ['mw'],
    "średhīvyavahāra": ['mw'],
    "śrek": ['mw'],
    "śreman": ['cae', 'ddsa', 'mw'],
    "śretṛ": ['mw'],
    "śreyaka": ['bhs'],
    "śreyas": ['ap90', 'ddsa', 'gra', 'mw'],
    "śreyasa": ['ddsa', 'mw'],
    "śreyasitarā": ['mw'],
    "śreyaskara": ['cae', 'ddsa', 'mw'],
    "śreyaskarabhāṣya": ['mw'],
    "śreyaskaratara": ['mw'],
    "śreyaskāma": ['cae', 'mw'],
    "śreyaskāmatā": ['mw'],
    "śreyaskṛt": ['mw'],
    "śreyastara": ['mw'],
    "śreyastva": ['cae', 'mw'],
    "śreyasī": ['ap90', 'bhs', 'mw'],
    "śreyasītarā": ['mw'],
    "śreyatara": ['bhs'],
    "śreyaḥ": ['mw'],
    "śreyaḥketa": ['mw'],
    "śreyaḥpariśrāma": ['mw'],
    "śreyaṃs": ['cae'],
    "śreyo": ['mw'],
    "śreyobhikāṅkṣin": ['mw'],
    "śreyomaya": ['cae', 'mw'],
    "śreyorthin": ['cae', 'mw'],
    "śreyo’bhikāṅkṣin": ['ddsa'],
    "śreyāṃsa": ['mw'],
    "śreḍhī": ['ap90', 'mw'],
    "śreḍī": ['mw'],
    "śreṇi": ['cae', 'ddsa', 'gra', 'mw'],
    "śreṇibaddha": ['mw'],
    "śreṇidat": ['gra', 'mw'],
    "śreṇika": ['bhs', 'mw'],
    "śreṇikapurāṇa": ['mw'],
    "śreṇikā": ['ap90', 'mw'],
    "śreṇikṛta": ['mw'],
    "śreṇimant": ['cae'],
    "śreṇimat": ['mw'],
    "śreṇisthāna": ['mw'],
    "śreṇiya": ['bhs'],
    "śreṇiśas": ['cae', 'gra', 'mw'],
    "śreṇiḥ": ['ap90'],
    "śreṇya": ['bhs', 'mw'],
    "śreṇī": ['ap90', 'cae', 'ddsa', 'mw'],
    "śreṇībandha": ['cae', 'mw'],
    "śreṇībhū": ['ap90'],
    "śreṇībhūta": ['mw'],
    "śreṇīdharma": ['cae', 'mw'],
    "śreṇīkṛta": ['mw'],
    "śreṣman": ['mw'],
    "śreṣṭha": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śreṣṭhabhāj": ['mw'],
    "śreṣṭhaka": ['bhs', 'mw'],
    "śreṣṭhakāṣṭha": ['mw'],
    "śreṣṭhamati": ['bhs'],
    "śreṣṭhapāla": ['mw'],
    "śreṣṭhasena": ['mw'],
    "śreṣṭhasthā": ['mw'],
    "śreṣṭhasāman": ['mw'],
    "śreṣṭhatama": ['cae', 'mw'],
    "śreṣṭhatamā": ['mw'],
    "śreṣṭhatara": ['cae', 'mw'],
    "śreṣṭhatas": ['mw'],
    "śreṣṭhatva": ['mw'],
    "śreṣṭhatā": ['cae', 'mw'],
    "śreṣṭhavarcas": ['cae', 'gra', 'mw'],
    "śreṣṭhavāc": ['mw'],
    "śreṣṭhayajña": ['mw'],
    "śreṣṭhayāna": ['mw'],
    "śreṣṭhaśocis": ['gra', 'mw'],
    "śreṣṭhaśāka": ['mw'],
    "śreṣṭhika": ['bhs', 'mw'],
    "śreṣṭhin": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śreṣṭhā": ['mw'],
    "śreṣṭhāmla": ['mw'],
    "śreṣṭhānvaya": ['cae', 'mw'],
    "śreṣṭhāśrama": ['mw'],
    "śreṭī": ['mw'],
    "śri": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śrimanya": ['mw'],
    "śrit": ['cae', 'ddsa', 'mw'],
    "śrita": ['ap90', 'cae', 'ddsa', 'mw'],
    "śritakṣama": ['mw'],
    "śritasattva": ['mw'],
    "śritavat": ['mw'],
    "śriti": ['cae', 'mw'],
    "śritiḥ": ['ap90'],
    "śritī": ['gra', 'mw'],
    "śriv": ['mw'],
    "śriyadhyai": ['mw'],
    "śriyammanya": ['mw'],
    "śriyaputra": ['mw'],
    "śriyase": ['cae', 'mw'],
    "śriyaṃmanya": ['ap90'],
    "śriyā": ['bhs', 'cae', 'ddsa', 'mw'],
    "śriyāditya": ['mw'],
    "śriyāmatī": ['bhs'],
    "śriyānakula": ['mw'],
    "śriyāpatiḥ": ['ap90'],
    "śriyāvāsa": ['cae', 'mw'],
    "śriyāvāsin": ['cae', 'mw'],
    "śriṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śromata": ['ddsa', 'gra', 'mw'],
    "śrota": ['bhs', 'mw'],
    "śrotas": ['ap90', 'mw'],
    "śrotavya": ['cae', 'ddsa', 'mw'],
    "śrotaāpatti": ['bhs'],
    "śrotra": ['cae', 'ddsa', 'gra', 'mw'],
    "śrotrabhid": ['mw'],
    "śrotrabhṛt": ['mw'],
    "śrotracit": ['mw'],
    "śrotradā": ['mw'],
    "śrotrahārin": ['mw'],
    "śrotrahīna": ['cae', 'mw'],
    "śrotrajña": ['mw'],
    "śrotrajñatā": ['mw'],
    "śrotrakāntā": ['mw'],
    "śrotramaya": ['cae', 'mw'],
    "śrotramārga": ['cae', 'mw'],
    "śrotramūla": ['cae', 'mw'],
    "śrotranetramaya": ['mw'],
    "śrotrapadavī": ['cae', 'mw'],
    "śrotrapadānuga": ['mw'],
    "śrotraparamparā": ['mw'],
    "śrotraparaṃparā": ['cae'],
    "śrotrapati": ['mw'],
    "śrotrapeya": ['cae', 'mw'],
    "śrotrapuṭa": ['mw'],
    "śrotrapā": ['mw'],
    "śrotrapāli": ['cae', 'mw'],
    "śrotraramya": ['mw'],
    "śrotrasaṃvāda": ['cae', 'mw'],
    "śrotrasparśin": ['mw'],
    "śrotrasukha": ['mw'],
    "śrotrasvin": ['mw'],
    "śrotratas": ['cae', 'mw'],
    "śrotratā": ['mw'],
    "śrotravant": ['cae'],
    "śrotravartman": ['mw'],
    "śrotravat": ['mw'],
    "śrotravādin": ['mw'],
    "śrotraśuktipuṭa": ['mw'],
    "śrotraṃ": ['ap90'],
    "śrotrendriya": ['mw'],
    "śrotriya": ['ap90', 'cae', 'ddsa', 'mw'],
    "śrotriyasva": ['cae', 'mw'],
    "śrotriyasātkṛ": ['mw'],
    "śrotriyatva": ['mw'],
    "śrotriyatā": ['mw'],
    "śrotrābhirāma": ['mw'],
    "śrotrādi": ['mw'],
    "śrotrānukūla": ['mw'],
    "śrotrāpeta": ['cae', 'mw'],
    "śrotrāśayasukha": ['mw'],
    "śrotu": ['gra', 'mw'],
    "śroturāti": ['gra', 'mw'],
    "śrotā": ['bhs'],
    "śrotāpatti": ['bhs'],
    "śrotṛ": ['ap90', 'cae', 'ddsa', 'mw'],
    "śroṇ": ['ap90', 'mw'],
    "śroṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śroṇakoṭi": ['bhs'],
    "śroṇakoṭikarṇa": ['mw'],
    "śroṇakoṭiviṃśa": ['mw'],
    "śroṇakoṭīkarṇa": ['bhs'],
    "śroṇi": ['cae', 'ddsa', 'gra', 'mw'],
    "śroṇibhaṇḍikā": ['bhs'],
    "śroṇibimba": ['mw'],
    "śroṇideśa": ['mw'],
    "śroṇikapāla": ['mw'],
    "śroṇikaṭāha": ['bhs'],
    "śroṇikā": ['mw'],
    "śroṇimat": ['mw'],
    "śroṇiphala": ['mw'],
    "śroṇiphalaka": ['mw'],
    "śroṇipratodin": ['mw'],
    "śroṇisūtra": ['mw'],
    "śroṇitas": ['mw'],
    "śroṇitaṭa": ['mw'],
    "śroṇivarjam": ['mw'],
    "śroṇivedha": ['mw'],
    "śroṇivimba": ['mw'],
    "śroṇiyugma": ['mw'],
    "śroṇiḥ": ['ap90'],
    "śroṇya": ['mw'],
    "śroṇā": ['ap90', 'mw'],
    "śroṇāparānta": ['bhs', 'mw'],
    "śroṇāparāntaka": ['bhs', 'mw'],
    "śroṇī": ['cae', 'ddsa', 'mw'],
    "śroṇībhāra": ['mw'],
    "śroṇīkā": ['mw'],
    "śroṇīphala": ['mw'],
    "śroṇīsūtra": ['mw'],
    "śroṣamāṇa": ['cae', 'mw'],
    "śroṣyam": ['bhs'],
    "śru": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śruc": ['mw'],
    "śrudhya": ['mw'],
    "śrudhīy": ['gra'],
    "śrudhīya": ['mw'],
    "śrudhīyat": ['mw'],
    "śrughnikā": ['mw'],
    "śrughnā": ['bhs'],
    "śrumat": ['mw'],
    "śrut": ['cae', 'ddsa', 'mw'],
    "śruta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śrutabandhu": ['mw'],
    "śrutabhāvaprakāśikā": ['mw'],
    "śrutabhṛt": ['mw'],
    "śrutabodha": ['cae', 'mw'],
    "śrutadeva": ['mw'],
    "śrutadevā": ['mw'],
    "śrutadevī": ['mw'],
    "śrutadhara": ['cae', 'mw'],
    "śrutadharman": ['mw'],
    "śrutadhi": ['mw'],
    "śrutadhvaja": ['mw'],
    "śrutadhāraṇa": ['mw'],
    "śrutadīpa": ['mw'],
    "śrutagraha": ['mw'],
    "śrutakakṣa": ['gra', 'mw'],
    "śrutakarman": ['cae', 'mw'],
    "śrutakevalin": ['mw'],
    "śrutakāma": ['cae', 'mw'],
    "śrutakīrti": ['cae', 'mw'],
    "śrutamahat": ['mw'],
    "śrutamaya": ['mw'],
    "śrutamātra": ['mw'],
    "śrutanigadin": ['mw'],
    "śrutanigaditva": ['mw'],
    "śrutaniṣkraya": ['mw'],
    "śrutapradīpa": ['mw'],
    "śrutapradīpikā": ['mw'],
    "śrutaprakāśa": ['mw'],
    "śrutaprakāśikā": ['mw'],
    "śrutaprakāśikācāryakṛtarahasyatraya": ['mw'],
    "śrutaprakāśikākhaṇḍana": ['mw'],
    "śrutaprakāśikāsaṃgraha": ['mw'],
    "śrutaprakāśikātātparyadīpikā": ['mw'],
    "śrutapāla": ['mw'],
    "śrutapāradṛśvan": ['mw'],
    "śrutapāraga": ['mw'],
    "śrutapūrva": ['cae', 'mw'],
    "śrutar": ['mw'],
    "śrutaratha": ['gra', 'mw'],
    "śrutarvan": ['gra', 'mw'],
    "śrutarya": ['gra', 'mw'],
    "śrutarṣi": ['gra', 'mw'],
    "śrutasad": ['mw'],
    "śrutasena": ['cae', 'mw'],
    "śrutasenā": ['mw'],
    "śrutasoma": ['mw'],
    "śrutasomā": ['mw'],
    "śrutatas": ['cae', 'mw'],
    "śrutatva": ['mw'],
    "śrutavadana": ['mw'],
    "śrutavant": ['cae'],
    "śrutavardhana": ['mw'],
    "śrutavarman": ['mw'],
    "śrutavat": ['ap90', 'mw'],
    "śrutavid": ['gra', 'mw'],
    "śrutavindā": ['mw'],
    "śrutavismṛta": ['mw'],
    "śrutaviṃśatikoṭi": ['mw'],
    "śrutavṛddha": ['mw'],
    "śrutavṛtta": ['cae', 'mw'],
    "śrutavṛttopapanna": ['cae', 'mw'],
    "śrutavṛttāḍhya": ['cae', 'mw'],
    "śrutayukta": ['mw'],
    "śrutaśabdārthasamuccaya": ['mw'],
    "śrutaśarman": ['mw'],
    "śrutaśravas": ['cae', 'mw'],
    "śrutaśravonuja": ['mw'],
    "śrutaśroṇī": ['mw'],
    "śrutaśruvas": ['mw'],
    "śrutaśrī": ['mw'],
    "śrutaśālin": ['mw'],
    "śrutaśīla": ['cae', 'mw'],
    "śrutaśīlasampanna": ['mw'],
    "śrutaśīlasaṃpanna": ['cae'],
    "śrutaśīlavat": ['mw'],
    "śrutaśīlopasampanna": ['mw'],
    "śrutaṃdhara": ['mw'],
    "śrutaṃjaya": ['mw'],
    "śrutaṛṣi": ['gra', 'mw'],
    "śruti": ['cae', 'ddsa', 'gra', 'mw'],
    "śrutia": ['gra'],
    "śrutibhāskara": ['mw'],
    "śruticandrikā": ['mw'],
    "śruticikitsā": ['mw'],
    "śruticodana": ['mw'],
    "śrutidhara": ['mw'],
    "śrutiduṣṭa": ['mw'],
    "śrutidvaidha": ['cae', 'ddsa', 'mw'],
    "śrutidūṣaka": ['mw'],
    "śrutigocara": ['cae', 'mw'],
    "śrutigītā": ['mw'],
    "śrutihārin": ['mw'],
    "śrutijātiviśārada": ['mw'],
    "śrutijīvikā": ['mw'],
    "śrutikalpadruma": ['mw'],
    "śrutikalpalatā": ['mw'],
    "śrutikathita": ['mw'],
    "śrutikaṇṭha": ['mw'],
    "śrutikaṭa": ['mw'],
    "śrutikaṭu": ['cae', 'mw'],
    "śrutikīrti": ['mw'],
    "śrutilakṣaṇaprāyaścitta": ['mw'],
    "śrutimahant": ['cae'],
    "śrutimahat": ['mw'],
    "śrutimant": ['cae'],
    "śrutimat": ['mw'],
    "śrutimattva": ['mw'],
    "śrutimatānumāna": ['mw'],
    "śrutimaya": ['mw'],
    "śrutimayūra": ['mw'],
    "śrutimaṇḍala": ['mw'],
    "śrutimitaprakāśikā": ['mw'],
    "śrutimukha": ['mw'],
    "śrutimukharamukha": ['mw'],
    "śrutimuktāphala": ['mw'],
    "śrutimārga": ['cae', 'mw'],
    "śrutimīmāṃsā": ['mw'],
    "śrutimūla": ['mw'],
    "śrutimūlaka": ['mw'],
    "śrutimṛgya": ['mw'],
    "śrutin": ['mw'],
    "śrutinidarśana": ['mw'],
    "śrutinigadin": ['mw'],
    "śrutipatha": ['cae', 'mw'],
    "śrutipathagata": ['mw'],
    "śrutipathamadhura": ['mw'],
    "śrutipathaprāpta": ['mw'],
    "śrutipathāyāta": ['mw'],
    "śrutiprakāśikā": ['mw'],
    "śrutiprapādikā": ['mw'],
    "śrutiprasādana": ['mw'],
    "śrutiprāmāṇyatas": ['mw'],
    "śrutipurāṇasaṃgraha": ['mw'],
    "śrutipāda": ['mw'],
    "śrutirañjanī": ['mw'],
    "śrutirañjinī": ['mw'],
    "śrutisaṃgraha": ['mw'],
    "śrutisaṃkṣiptavarṇana": ['mw'],
    "śrutismṛti": ['mw'],
    "śrutismṛtivihita": ['mw'],
    "śrutismṛtiviruddha": ['mw'],
    "śrutismṛtyudita": ['mw'],
    "śrutismṛtyāditātparya": ['mw'],
    "śrutisphoṭā": ['mw'],
    "śrutistuti": ['mw'],
    "śrutisukha": ['mw'],
    "śrutisukhada": ['mw'],
    "śrutisukhāvaha": ['mw'],
    "śrutisāgara": ['mw'],
    "śrutisāra": ['mw'],
    "śrutisārapañcaratna": ['mw'],
    "śrutisārasamuccaya": ['mw'],
    "śrutisārasamuddharaṇaprakaraṇa": ['mw'],
    "śrutisūktimālā": ['mw'],
    "śrutisūtratātparyāmṛta": ['mw'],
    "śrutitas": ['cae', 'mw'],
    "śrutitatpara": ['mw'],
    "śrutitattvanirṇaya": ['mw'],
    "śrutitā": ['mw'],
    "śrutitātparyanirṇaya": ['mw'],
    "śrutivacana": ['mw'],
    "śrutivarjita": ['mw'],
    "śrutivedha": ['mw'],
    "śrutivikrāyaka": ['mw'],
    "śrutivipratipanna": ['mw'],
    "śrutivivara": ['mw'],
    "śrutiviṣaya": ['mw'],
    "śrutiviṣayaguṇa": ['mw'],
    "śrutivāksārasaṃgraha": ['mw'],
    "śrutiśiras": ['cae', 'mw'],
    "śrutiśīla": ['mw'],
    "śrutiśīlavant": ['cae'],
    "śrutiśīlavat": ['mw'],
    "śrutiḥ": ['ap90'],
    "śrutkarṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "śrutodgrahaṇa": ['bhs'],
    "śruty": ['mw'],
    "śrutya": ['cae', 'ddsa', 'gra', 'mw'],
    "śrutyantasuradruma": ['mw'],
    "śrutyanuprāsa": ['ddsa', 'mw'],
    "śrutyartharatnamālā": ['mw'],
    "śrutyarthābhāva": ['mw'],
    "śrutyudita": ['mw'],
    "śrutyukta": ['cae', 'mw'],
    "śrutyānarthakya": ['mw'],
    "śrutā": ['ddsa', 'mw'],
    "śrutādhyayanasampanna": ['mw'],
    "śrutādhāra": ['bhs'],
    "śrutādāna": ['mw'],
    "śrutāmagha": ['cae', 'gra', 'mw'],
    "śrutānta": ['mw'],
    "śrutānvita": ['mw'],
    "śrutānīka": ['mw'],
    "śrutārtha": ['mw'],
    "śrutārthā": ['mw'],
    "śrutāvatī": ['mw'],
    "śrutāvin": ['bhs'],
    "śrutāyu": ['cae', 'mw'],
    "śrutāyudha": ['mw'],
    "śrutāyus": ['cae', 'mw'],
    "śrutāñjanaṭīkā": ['mw'],
    "śrutī": ['ap90'],
    "śrutīka": ['mw'],
    "śruva": ['mw'],
    "śruvaḥ": ['ap90'],
    "śruvā": ['ap90'],
    "śruṇa": ['mw'],
    "śruṇana": ['bhs'],
    "śruṇoti": ['bhs'],
    "śruṣ": ['cae', 'ddsa', 'gra', 'mw'],
    "śruṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "śruṣṭigu": ['gra', 'mw'],
    "śruṣṭimant": ['cae'],
    "śruṣṭimat": ['gra', 'mw'],
    "śruṣṭiḥ": ['ap90'],
    "śruṣṭī": ['mw'],
    "śruṣṭīvan": ['cae', 'ddsa', 'gra', 'mw'],
    "śrvas": ['ddsa'],
    "śry": ['mw'],
    "śryāhva": ['mw'],
    "śrā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śrāddha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śrāddhabhojana": ['cae', 'mw'],
    "śrāddhabhuj": ['cae', 'mw'],
    "śrāddhabhāskaraprayogapaddhati": ['mw'],
    "śrāddhabrāhmaṇa": ['mw'],
    "śrāddhacandrikā": ['mw'],
    "śrāddhacintāmaṇi": ['mw'],
    "śrāddhada": ['mw'],
    "śrāddhadarpaṇa": ['mw'],
    "śrāddhadeva": ['cae', 'mw'],
    "śrāddhadevatva": ['mw'],
    "śrāddhadevatā": ['mw'],
    "śrāddhadevatānirṇaya": ['mw'],
    "śrāddhadina": ['cae', 'mw'],
    "śrāddhadvāsaptatikalā": ['mw'],
    "śrāddhadīdhiti": ['mw'],
    "śrāddhadīpa": ['mw'],
    "śrāddhadīpakalikā": ['mw'],
    "śrāddhadīpikā": ['mw'],
    "śrāddhagaṇapati": ['mw'],
    "śrāddhaguṇasaṃgraha": ['mw'],
    "śrāddhahemādri": ['mw'],
    "śrāddhakalpa": ['mw'],
    "śrāddhakalpabhāṣyagobhilīya": ['mw'],
    "śrāddhakalpadruma": ['mw'],
    "śrāddhakalpadīpa": ['mw'],
    "śrāddhakalpalatā": ['mw'],
    "śrāddhakalpasūtra": ['mw'],
    "śrāddhakalā": ['mw'],
    "śrāddhakara": ['mw'],
    "śrāddhakarman": ['cae', 'mw'],
    "śrāddhakarmavidhi": ['mw'],
    "śrāddhakartṛ": ['mw'],
    "śrāddhakaumudī": ['mw'],
    "śrāddhakriyā": ['mw'],
    "śrāddhakāla": ['cae', 'mw'],
    "śrāddhakārikā": ['mw'],
    "śrāddhakāryanirṇayasaṃkṣepa": ['mw'],
    "śrāddhakāśikā": ['mw'],
    "śrāddhakāṇḍa": ['mw'],
    "śrāddhakāṇḍasaṃgraha": ['mw'],
    "śrāddhakṛt": ['mw'],
    "śrāddhamayūkha": ['mw'],
    "śrāddhamañjarī": ['mw'],
    "śrāddhamitra": ['cae', 'mw'],
    "śrāddhamīmāṃsā": ['mw'],
    "śrāddhanavakaṇḍikāsūtra": ['mw'],
    "śrāddhanirūpaṇa": ['mw'],
    "śrāddhanirṇaya": ['mw'],
    "śrāddhapaddhati": ['mw'],
    "śrāddhapallava": ['mw'],
    "śrāddhapaṅkti": ['mw'],
    "śrāddhaprabhā": ['mw'],
    "śrāddhapradīpa": ['mw'],
    "śrāddhaprakāśa": ['mw'],
    "śrāddhaprakīrṇakārikā": ['mw'],
    "śrāddhaprayoga": ['mw'],
    "śrāddhaprayogacintāmaṇi": ['mw'],
    "śrāddhaprayogapaddhati": ['mw'],
    "śrāddhapraśaṃsā": ['mw'],
    "śrāddhapārijāta": ['mw'],
    "śrāddharahasya": ['mw'],
    "śrāddharatna": ['mw'],
    "śrāddhasamuccaya": ['mw'],
    "śrāddhasaukhya": ['mw'],
    "śrāddhasaṃgraha": ['mw'],
    "śrāddhasaṃkalpa": ['mw'],
    "śrāddhasaṃkalpavidhi": ['mw'],
    "śrāddhastabaka": ['mw'],
    "śrāddhasāgara": ['mw'],
    "śrāddhasāra": ['mw'],
    "śrāddhasūtaka": ['mw'],
    "śrāddhasūtakabhojana": ['mw'],
    "śrāddhasūtra": ['mw'],
    "śrāddhatattva": ['mw'],
    "śrāddhatattvaṭīkā": ['mw'],
    "śrāddhatilaka": ['mw'],
    "śrāddhatva": ['mw'],
    "śrāddhavacanasaṃgraha": ['mw'],
    "śrāddhavamanaprāyaścitta": ['mw'],
    "śrāddhavarṇana": ['mw'],
    "śrāddhavasiṣṭha": ['mw'],
    "śrāddhavidhi": ['mw'],
    "śrāddhaviveka": ['mw'],
    "śrāddhavivekasaṃgraha": ['mw'],
    "śrāddhavyavasthāsaṃkṣepa": ['mw'],
    "śrāddhavāsara": ['mw'],
    "śrāddhavṛttiprakaraṇa": ['mw'],
    "śrāddhaśiṣṭa": ['mw'],
    "śrāddhaśāka": ['mw'],
    "śrāddhendu": ['mw'],
    "śrāddheya": ['mw'],
    "śrāddhika": ['ap90', 'cae', 'ddsa', 'mw'],
    "śrāddhin": ['cae', 'mw'],
    "śrāddhopayogin": ['mw'],
    "śrāddhopayogivacana": ['mw'],
    "śrāddhābhimarśana": ['mw'],
    "śrāddhādarśa": ['mw'],
    "śrāddhādhikāra": ['mw'],
    "śrāddhādhikārinirṇaya": ['mw'],
    "śrāddhādividhi": ['mw'],
    "śrāddhāha": ['cae', 'mw'],
    "śrāddhāhnika": ['cae', 'mw'],
    "śrāddhānukramaṇikā": ['mw'],
    "śrāddhāparārka": ['mw'],
    "śrāddhāśaucīyadarpaṇa": ['mw'],
    "śrāddhīya": ['ap90', 'mw'],
    "śrām": ['mw'],
    "śrāma": ['mw'],
    "śrāmaḥ": ['ap90'],
    "śrāmaṇa": ['bhs', 'mw'],
    "śrāmaṇaka": ['bhs', 'ddsa', 'mw'],
    "śrāmaṇera": ['bhs', 'mw'],
    "śrāmaṇeraka": ['bhs', 'mw'],
    "śrāmaṇya": ['bhs', 'mw'],
    "śrāmaṇyaka": ['bhs'],
    "śrāmaṇyaphalasūtra": ['bhs'],
    "śrāmaṇī": ['mw'],
    "śrānta": ['cae', 'ddsa', 'mw'],
    "śrāntacitta": ['mw'],
    "śrāntahṛdaya": ['mw'],
    "śrāntaklānta": ['mw'],
    "śrāntamanas": ['mw'],
    "śrāntasad": ['mw'],
    "śrāntasaṃvāhana": ['mw'],
    "śrānti": ['cae', 'ddsa'],
    "śrāntāgata": ['mw'],
    "śrāpaya": ['ddsa', 'mw'],
    "śrāpin": ['cae', 'ddsa', 'mw'],
    "śrāta": ['cae', 'mw'],
    "śrāva": ['cae', 'mw'],
    "śrāvaka": ['bhs', 'cae', 'ddsa', 'mw'],
    "śrāvakabhūmi": ['bhs'],
    "śrāvakabodhi": ['bhs'],
    "śrāvakakṛtya": ['mw'],
    "śrāvakatva": ['mw'],
    "śrāvakavinaya": ['bhs'],
    "śrāvakavrata": ['mw'],
    "śrāvakayāna": ['bhs', 'mw'],
    "śrāvakaḥ": ['ap90'],
    "śrāvakānuṣṭhānavidhi": ['mw'],
    "śrāvakārādhana": ['mw'],
    "śrāvakīya": ['bhs'],
    "śrāvantī": ['mw'],
    "śrāvasta": ['cae', 'ddsa', 'mw'],
    "śrāvastaka": ['mw'],
    "śrāvasteya": ['bhs', 'mw'],
    "śrāvasteyaka": ['bhs'],
    "śrāvastiḥ": ['ap90'],
    "śrāvastī": ['ap90', 'mw'],
    "śrāvastīyaka": ['bhs'],
    "śrāvayat": ['mw'],
    "śrāvayatpati": ['cae', 'gra', 'mw'],
    "śrāvayatsakhi": ['cae', 'gra', 'mw'],
    "śrāvayitavya": ['cae', 'ddsa', 'mw'],
    "śrāvaḥ": ['ap90'],
    "śrāvaṇa": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śrāvaṇadvādaśī": ['mw'],
    "śrāvaṇadvādaśīmāhātmya": ['mw'],
    "śrāvaṇadvādaśīpāraṇavidhi": ['mw'],
    "śrāvaṇadvādaśīvrata": ['mw'],
    "śrāvaṇadvādaśīvratakalpa": ['mw'],
    "śrāvaṇahomamantra": ['mw'],
    "śrāvaṇakarman": ['mw'],
    "śrāvaṇakarmasarpabaliprayoga": ['mw'],
    "śrāvaṇamāhātmya": ['mw'],
    "śrāvaṇaniṣedhavacana": ['mw'],
    "śrāvaṇatva": ['ddsa', 'mw'],
    "śrāvaṇavidhi": ['mw'],
    "śrāvaṇaśanivāravrata": ['mw'],
    "śrāvaṇaśukla": ['mw'],
    "śrāvaṇaśuklacaturthī": ['mw'],
    "śrāvaṇaśuklatṛtīyā": ['mw'],
    "śrāvaṇika": ['ap90', 'mw'],
    "śrāvaṇikā": ['mw'],
    "śrāvaṇikāvrata": ['mw'],
    "śrāvaṇotsargakarman": ['mw'],
    "śrāvaṇya": ['bhs'],
    "śrāvaṇāmukha": ['bhs'],
    "śrāvaṇī": ['ap90', 'mw'],
    "śrāvaṇīkarman": ['mw'],
    "śrāvaṇīkarmavidhi": ['mw'],
    "śrāvaṇīpaddhati": ['mw'],
    "śrāvaṇīprayoga": ['mw'],
    "śrāvaṇīya": ['cae', 'mw'],
    "śrāvaṣṭhīya": ['mw'],
    "śrāvikā": ['bhs', 'mw'],
    "śrāvikātva": ['mw'],
    "śrāvin": ['cae', 'mw'],
    "śrāvita": ['ap90', 'mw'],
    "śrāvitaka": ['bhs'],
    "śrāvitṛ": ['cae', 'mw'],
    "śrāviṣṭha": ['mw'],
    "śrāviṣṭhāyana": ['mw'],
    "śrāviṣṭhīya": ['mw'],
    "śrāvya": ['ap90', 'cae', 'ddsa', 'mw'],
    "śrāya": ['cae', 'ddsa', 'gra', 'mw'],
    "śrāyantīya": ['mw'],
    "śrāyasa": ['mw'],
    "śrāyat": ['mw'],
    "śrāyaḥ": ['ap90'],
    "śrāṃta": ['ap90'],
    "śrāṃtiḥ": ['ap90'],
    "śrāṇa": ['ap90', 'mw'],
    "śrāṇā": ['ap90', 'mw'],
    "śrī": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śrībabba": ['mw'],
    "śrībaka": ['mw'],
    "śrībala": ['bhs'],
    "śrībali": ['mw'],
    "śrībappa": ['mw'],
    "śrībappapādīyavihāra": ['mw'],
    "śrībera": ['mw'],
    "śrībhadra": ['bhs', 'mw'],
    "śrībhadrā": ['bhs', 'mw'],
    "śrībhakṣa": ['cae', 'mw'],
    "śrībhartṛ": ['cae', 'mw'],
    "śrībhaḍa": ['mw'],
    "śrībhaṭṭa": ['mw'],
    "śrībhrātṛ": ['mw'],
    "śrībhuja": ['mw'],
    "śrībhāgavata": ['mw'],
    "śrībhānu": ['mw'],
    "śrībhāṣya": ['mw'],
    "śrībhāṣyadīpa": ['mw'],
    "śrībhāṣyasaṃgraha": ['mw'],
    "śrībhāṣyavṛtti": ['mw'],
    "śrībhāṣyavṛttyupanyāsa": ['mw'],
    "śrībhāṣyodāhṛtopaniṣadvākyavivaraṇa": ['mw'],
    "śrībhāṣyāndhraṭīkā": ['mw'],
    "śrībāpa": ['mw'],
    "śrīcakra": ['mw'],
    "śrīcakranyāsakavaca": ['mw'],
    "śrīcakrapattra": ['mw'],
    "śrīcakrapūjāvidhi": ['mw'],
    "śrīcandana": ['mw'],
    "śrīcandra": ['mw'],
    "śrīcaṅkuṇavihāra": ['mw'],
    "śrīcaṇḍa": ['mw'],
    "śrīcintāmaṇidatta": ['bhs'],
    "śrīcūrṇaparipālana": ['mw'],
    "śrīda": ['cae', 'mw'],
    "śrīdarpaṇa": ['mw'],
    "śrīdarśana": ['cae', 'mw'],
    "śrīdatta": ['cae', 'mw'],
    "śrīdayita": ['mw'],
    "śrīdaśākṣara": ['mw'],
    "śrīdeva": ['mw'],
    "śrīdevā": ['mw'],
    "śrīdhana": ['mw'],
    "śrīdhanvipurīmāhātmya": ['mw'],
    "śrīdhara": ['bhs', 'cae', 'mw'],
    "śrīdharadāsa": ['mw'],
    "śrīdharamālava": ['mw'],
    "śrīdharanandin": ['mw'],
    "śrīdharapaddhati": ['mw'],
    "śrīdharapati": ['mw'],
    "śrīdharasena": ['mw'],
    "śrīdharasvāmin": ['mw'],
    "śrīdharendra": ['mw'],
    "śrīdharolanagara": ['mw'],
    "śrīdharānanda": ['mw'],
    "śrīdharīpañcadaśī": ['mw'],
    "śrīdharīya": ['mw'],
    "śrīdharīyasaṃhitā": ['mw'],
    "śrīdharīyavyākhyā": ['mw'],
    "śrīdhra": ['mw'],
    "śrīdhāman": ['mw'],
    "śrīdruma": ['mw'],
    "śrīdurgāyantra": ['mw'],
    "śrīdā": ['mw'],
    "śrīdākṣinagara": ['mw'],
    "śrīdāmacarita": ['mw'],
    "śrīdāman": ['mw'],
    "śrīdāmanandadātrī": ['mw'],
    "śrīdāmeśvaravallabhā": ['mw'],
    "śrīgadita": ['mw'],
    "śrīgarbha": ['bhs', 'mw'],
    "śrīgarbhakūṭavinarditarāja": ['bhs'],
    "śrīgarbhaprabhāsa": ['bhs'],
    "śrīgarbharatna": ['mw'],
    "śrīgarbhavatī": ['bhs'],
    "śrīgarbhā": ['mw'],
    "śrīgaṇeśa": ['mw'],
    "śrīgaṇeśā": ['mw'],
    "śrīghana": ['mw'],
    "śrīgiri": ['cae', 'mw'],
    "śrīgoṣṭhīmāhātmya": ['mw'],
    "śrīgraha": ['mw'],
    "śrīgrāma": ['mw'],
    "śrīgrāmara": ['mw'],
    "śrīgunna": ['mw'],
    "śrīgupta": ['mw'],
    "śrīgurusahasranāmastotra": ['mw'],
    "śrīguṇalekhā": ['mw'],
    "śrīguṇaratnakośa": ['mw'],
    "śrīguṇasahasranāman": ['mw'],
    "śrīhara": ['mw'],
    "śrīhari": ['mw'],
    "śrīharihara": ['bhs'],
    "śrīharistotra": ['mw'],
    "śrīharṣa": ['ap90', 'cae', 'mw'],
    "śrīharṣadeva": ['cae'],
    "śrīhastinī": ['mw'],
    "śrīhaṭṭa": ['mw'],
    "śrīja": ['mw'],
    "śrījagadrāma": ['mw'],
    "śrījyotirīśvara": ['mw'],
    "śrīka": ['cae', 'ddsa', 'mw'],
    "śrīkajāka": ['mw'],
    "śrīkallaṭa": ['mw'],
    "śrīkandā": ['mw'],
    "śrīkara": ['cae', 'mw'],
    "śrīkaraṇa": ['cae', 'mw'],
    "śrīkaraṇādhyakṣa": ['mw'],
    "śrīkaraṇādi": ['mw'],
    "śrīkarṇa": ['mw'],
    "śrīkarṇadeva": ['mw'],
    "śrīkarṇīyaka": ['mw'],
    "śrīkavaca": ['mw'],
    "śrīkayyasvāmin": ['mw'],
    "śrīkaṇṭha": ['bhs', 'cae', 'mw'],
    "śrīkaṇṭhabhāṣya": ['mw'],
    "śrīkaṇṭhacarita": ['mw'],
    "śrīkaṇṭhadatta": ['mw'],
    "śrīkaṇṭhadeva": ['mw'],
    "śrīkaṇṭhadeśa": ['mw'],
    "śrīkaṇṭhakaṇṭha": ['mw'],
    "śrīkaṇṭhakaṇṭhataṭinī": ['mw'],
    "śrīkaṇṭhakaṇṭhīya": ['mw'],
    "śrīkaṇṭhamiśra": ['mw'],
    "śrīkaṇṭhamāhātmya": ['mw'],
    "śrīkaṇṭhanilaya": ['mw'],
    "śrīkaṇṭhanāthīya": ['mw'],
    "śrīkaṇṭhapadalāñchana": ['mw'],
    "śrīkaṇṭhasakha": ['mw'],
    "śrīkaṇṭhastava": ['mw'],
    "śrīkaṇṭhatriśatī": ['mw'],
    "śrīkaṇṭhatā": ['mw'],
    "śrīkaṇṭhatīrtha": ['mw'],
    "śrīkaṇṭhaviṣaya": ['mw'],
    "śrīkaṇṭhaśambhu": ['mw'],
    "śrīkaṇṭhaśarman": ['mw'],
    "śrīkaṇṭhaśiva": ['mw'],
    "śrīkaṇṭhikā": ['mw'],
    "śrīkaṇṭhīya": ['mw'],
    "śrīkaṇṭhīyasaṃhitā": ['mw'],
    "śrīkeśava": ['mw'],
    "śrīkeśavācārya": ['mw'],
    "śrīkhaṇḍa": ['cae', 'mw'],
    "śrīkhaṇḍacarcā": ['cae', 'mw'],
    "śrīkhaṇḍadruma": ['mw'],
    "śrīkhaṇḍadāsa": ['cae', 'mw'],
    "śrīkhaṇḍakhaṇḍa": ['mw'],
    "śrīkhaṇḍapṛthvīdhara": ['mw'],
    "śrīkhaṇḍatamālapattra": ['mw'],
    "śrīkhaṇḍavilepana": ['mw'],
    "śrīkhaṇḍaśaila": ['mw'],
    "śrīkhaṇḍaśītala": ['mw'],
    "śrīkhaṇḍārdravilepana": ['mw'],
    "śrīkhaṇḍāṅgarāga": ['mw'],
    "śrīkhaṇḍī": ['mw'],
    "śrīkhaṇḍīvedāntasāra": ['mw'],
    "śrīkośahṛdaya": ['mw'],
    "śrīkrama": ['mw'],
    "śrīkramacandrikā": ['mw'],
    "śrīkramasaṃhitā": ['mw'],
    "śrīkramatantra": ['mw'],
    "śrīkriyārūpiṇī": ['mw'],
    "śrīkula": ['mw'],
    "śrīkuñja": ['mw'],
    "śrīkuṇḍa": ['mw'],
    "śrīkāma": ['cae', 'mw'],
    "śrīkāmā": ['mw'],
    "śrīkānta": ['mw'],
    "śrīkāntākathā": ['mw'],
    "śrīkāra": ['bhs', 'mw'],
    "śrīkārin": ['mw'],
    "śrīkārī": ['mw'],
    "śrīkīrti": ['mw'],
    "śrīkūrmamāhātmya": ['mw'],
    "śrīkūṭa": ['bhs'],
    "śrīkṛcchra": ['cae', 'mw'],
    "śrīkṛṣṇa": ['mw'],
    "śrīkṛṣṇanyāyavāgīśabhaṭṭācārya": ['mw'],
    "śrīkṛṣṇarāya": ['mw'],
    "śrīkṛṣṇasarasvatī": ['mw'],
    "śrīkṛṣṇasarojabhramarī": ['mw'],
    "śrīkṛṣṇatarkālaṃkārabhaṭṭācārya": ['mw'],
    "śrīkṛṣṇatīrtha": ['mw'],
    "śrīkṛṣṇavidyāvāgīśa": ['mw'],
    "śrīkṛṣṇavipra": ['mw'],
    "śrīkṛṣṇālaṃkāra": ['mw'],
    "śrīkṣatra": ['mw'],
    "śrīkṣetra": ['mw'],
    "śrīla": ['ap90', 'ddsa', 'mw'],
    "śrīlahanumat": ['mw'],
    "śrīlakṣman": ['mw'],
    "śrīlakṣmaṇa": ['mw'],
    "śrīlatā": ['mw'],
    "śrīlaśrīvopadeva": ['mw'],
    "śrīlekhā": ['mw'],
    "śrīlābha": ['mw'],
    "śrīmacchataśalākin": ['mw'],
    "śrīmada": ['mw'],
    "śrīmaddattopaniṣad": ['mw'],
    "śrīmahiman": ['mw'],
    "śrīmahimnaḥstava": ['mw'],
    "śrīmahādevī": ['mw'],
    "śrīmakuṭa": ['mw'],
    "śrīmallakarṇi": ['mw'],
    "śrīmalā": ['mw'],
    "śrīmalāpahā": ['mw'],
    "śrīmanas": ['cae', 'mw'],
    "śrīmanmanya": ['mw'],
    "śrīmannṛpurī": ['mw'],
    "śrīmant": ['bhs', 'cae'],
    "śrīmanta": ['bhs', 'mw'],
    "śrīmastaka": ['mw'],
    "śrīmat": ['ap90', 'mw'],
    "śrīmati": ['bhs', 'mw'],
    "śrīmatkumbha": ['mw'],
    "śrīmatottara": ['mw'],
    "śrīmattama": ['mw'],
    "śrīmattā": ['cae', 'mw'],
    "śrīmatī": ['bhs', 'mw'],
    "śrīmaya": ['cae', 'mw'],
    "śrīmañju": ['mw'],
    "śrīmaṅgala": ['mw'],
    "śrīmaṇas": ['mw'],
    "śrīmaṇḍapa": ['mw'],
    "śrīmitra": ['mw'],
    "śrīmudrā": ['mw'],
    "śrīmukha": ['mw'],
    "śrīmukhī": ['mw'],
    "śrīmukhīsahasranāman": ['mw'],
    "śrīmuṣ": ['mw'],
    "śrīmuṣṇamāhātmya": ['mw'],
    "śrīmuṣṭimāhātmya": ['mw'],
    "śrīmāla": ['mw'],
    "śrīmālakhaṇḍa": ['mw'],
    "śrīmālamāhātmya": ['mw'],
    "śrīmālapurāṇa": ['mw'],
    "śrīmālinīvijayottara": ['mw'],
    "śrīmālā": ['bhs'],
    "śrīmālādevīsiṃhanādasūtra": ['mw'],
    "śrīmālāsiṃhanādasūtra": ['bhs'],
    "śrīmūrti": ['mw'],
    "śrīnagara": ['cae', 'mw'],
    "śrīnandana": ['mw'],
    "śrīnandīya": ['mw'],
    "śrīnarendraprabhā": ['mw'],
    "śrīnarendreśvara": ['mw'],
    "śrīnidhi": ['cae', 'mw'],
    "śrīniketa": ['mw'],
    "śrīniketana": ['mw'],
    "śrīnitambā": ['mw'],
    "śrīnivāsa": ['cae', 'mw'],
    "śrīnivāsabrahmatantraparakālasvāmyaṣṭottaraśata": ['mw'],
    "śrīnivāsacampū": ['mw'],
    "śrīnivāsadāsa": ['mw'],
    "śrīnivāsadīkṣitīya": ['mw'],
    "śrīnivāsadīpikā": ['mw'],
    "śrīnivāsakavacāntastotra": ['mw'],
    "śrīnivāsamāhātmya": ['mw'],
    "śrīnivāsarāghava": ['mw'],
    "śrīnivāsatīrtha": ['mw'],
    "śrīnivāsatīrthīya": ['mw'],
    "śrīnivāsaśiṣya": ['mw'],
    "śrīnivāsā": ['mw'],
    "śrīnivāsīya": ['mw'],
    "śrīnāradapurāṇa": ['mw'],
    "śrīnātha": ['cae', 'mw'],
    "śrīnīlakaṇṭha": ['mw'],
    "śrīpaddhati": ['mw'],
    "śrīpaddhatipradīpa": ['mw'],
    "śrīpadma": ['cae', 'mw'],
    "śrīpadī": ['mw'],
    "śrīparvata": ['cae', 'mw'],
    "śrīparāpūjana": ['mw'],
    "śrīparṇa": ['cae', 'mw'],
    "śrīparṇi": ['mw'],
    "śrīparṇikā": ['mw'],
    "śrīparṇī": ['mw'],
    "śrīpatha": ['mw'],
    "śrīpati": ['cae', 'mw'],
    "śrīpatibhāṣya": ['mw'],
    "śrīpatidatta": ['mw'],
    "śrīpatigovinda": ['mw'],
    "śrīpatigrantha": ['mw'],
    "śrīpatipaddhati": ['mw'],
    "śrīpatisaṃhitā": ['mw'],
    "śrīpativyavahāranirṇaya": ['mw'],
    "śrīpativyavahārasamuccaya": ['mw'],
    "śrīpatiśiṣya": ['mw'],
    "śrīpattana": ['mw'],
    "śrīpatīya": ['mw'],
    "śrīpañcamī": ['mw'],
    "śrīpañcamīvrata": ['mw'],
    "śrīphala": ['cae', 'mw'],
    "śrīphalakṛcchra": ['cae', 'mw'],
    "śrīphalavardhinī": ['mw'],
    "śrīphalikā": ['mw'],
    "śrīphalā": ['mw'],
    "śrīphalī": ['mw'],
    "śrīpiṣṭa": ['mw'],
    "śrīprabhā": ['bhs'],
    "śrīprabhāsamati": ['bhs'],
    "śrīprabhāva": ['mw'],
    "śrīprada": ['mw'],
    "śrīprasūna": ['mw'],
    "śrīpraśna": ['mw'],
    "śrīpriya": ['mw'],
    "śrīpura": ['mw'],
    "śrīpuruṣottamatattva": ['mw'],
    "śrīputra": ['mw'],
    "śrīpuṣpa": ['mw'],
    "śrīpuṭa": ['mw'],
    "śrīpuṭoṣṭha": ['mw'],
    "śrīpā": ['mw'],
    "śrīpāda": ['mw'],
    "śrīpāla": ['mw'],
    "śrīpālacarita": ['mw'],
    "śrīpālita": ['mw'],
    "śrīpāñcarātra": ['mw'],
    "śrīpāñcarātrārādhana": ['mw'],
    "śrīpūjāmahāpaddhati": ['mw'],
    "śrīra": ['gra', 'mw'],
    "śrīrasa": ['mw'],
    "śrīratnagiri": ['mw'],
    "śrīratnākara": ['mw'],
    "śrīraṅga": ['mw'],
    "śrīraṅgadeva": ['mw'],
    "śrīraṅgadevadevālayapradakṣiṇa": ['mw'],
    "śrīraṅgagadya": ['mw'],
    "śrīraṅgagurustotra": ['mw'],
    "śrīraṅgamāhātmya": ['mw'],
    "śrīraṅganātha": ['mw'],
    "śrīraṅganāthakṣamāṣoḍaśī": ['mw'],
    "śrīraṅganāthamaṅgalāśāsana": ['mw'],
    "śrīraṅganāthaprapatti": ['mw'],
    "śrīraṅganāthastotra": ['mw'],
    "śrīraṅganāthasuprabhāta": ['mw'],
    "śrīraṅganāthārādhanakrama": ['mw'],
    "śrīraṅganāthāṣṭottaraśata": ['mw'],
    "śrīraṅganāyakī": ['mw'],
    "śrīraṅganāyakīstotra": ['mw'],
    "śrīraṅganāyakīstuti": ['mw'],
    "śrīraṅgapattana": ['mw'],
    "śrīraṅgarājacatuṣṭaya": ['mw'],
    "śrīraṅgarājastava": ['mw'],
    "śrīraṅgarājastotra": ['mw'],
    "śrīraṅgasaptaprākārapradakṣiṇavidhi": ['mw'],
    "śrīraṅgavimānastotra": ['mw'],
    "śrīraṅgeśa": ['mw'],
    "śrīraṅgeśvarī": ['mw'],
    "śrīrudrahṛdayopaniṣad": ['mw'],
    "śrīrādhāvallabha": ['mw'],
    "śrīrāga": ['mw'],
    "śrīrāghavīya": ['mw'],
    "śrīrājacūḍāmaṇidīkṣita": ['mw'],
    "śrīrāma": ['mw'],
    "śrīrāmakalpadruma": ['mw'],
    "śrīrāmamaṅgala": ['mw'],
    "śrīrāmanavamī": ['mw'],
    "śrīrāmanavamīnirṇaya": ['mw'],
    "śrīrāmapaddhati": ['mw'],
    "śrīrāmarakṣā": ['mw'],
    "śrīrāmastuti": ['mw'],
    "śrīrāmodanta": ['mw'],
    "śrīrāṣṭramitrāyuṣkāma": ['mw'],
    "śrīrūpā": ['mw'],
    "śrīsahasra": ['mw'],
    "śrīsahodara": ['mw'],
    "śrīsambhūtā": ['mw'],
    "śrīsamudra": ['bhs'],
    "śrīsarasvatī": ['mw'],
    "śrīsaṃbhava": ['bhs'],
    "śrīsaṃgrāma": ['mw'],
    "śrīsaṃhitā": ['mw'],
    "śrīsaṃjña": ['cae', 'mw'],
    "śrīsaṃsthā": ['mw'],
    "śrīsena": ['mw'],
    "śrīsiddhi": ['mw'],
    "śrīsmaraṇadarpaṇa": ['mw'],
    "śrīsraja": ['mw'],
    "śrīstava": ['mw'],
    "śrīsthala": ['mw'],
    "śrīsthalamāhātmya": ['mw'],
    "śrīsthalaprakāśa": ['mw'],
    "śrīstuti": ['mw'],
    "śrīsukha": ['mw'],
    "śrīsumeru": ['bhs'],
    "śrīsvarūpa": ['mw'],
    "śrīsvarūpiṇī": ['mw'],
    "śrīsvāmin": ['mw'],
    "śrīsūkta": ['mw'],
    "śrīsūktanyāsa": ['mw'],
    "śrīsūktavidhi": ['mw'],
    "śrīsūktavidhāna": ['mw'],
    "śrīta": ['mw'],
    "śrītala": ['mw'],
    "śrītattvabodhinī": ['mw'],
    "śrītattvanidhi": ['mw'],
    "śrītejas": ['bhs', 'mw'],
    "śrītrikaṭukavihāra": ['mw'],
    "śrītāla": ['mw'],
    "śrītāḍa": ['mw'],
    "śrītīrtha": ['mw'],
    "śrīv": ['mw'],
    "śrīvabhāsa": ['mw'],
    "śrīvacanabhūṣaṇamīmāṃsā": ['mw'],
    "śrīvada": ['mw'],
    "śrīvaha": ['cae', 'mw'],
    "śrīvaidyanāthamāhātmya": ['mw'],
    "śrīvaiṣṇava": ['mw'],
    "śrīvaiṣṇavācārasaṃgraha": ['mw'],
    "śrīvallabha": ['mw'],
    "śrīvallī": ['mw'],
    "śrīvara": ['mw'],
    "śrīvarabodhibhagavat": ['mw'],
    "śrīvardhana": ['bhs', 'mw'],
    "śrīvarāha": ['mw'],
    "śrīvasukra": ['mw'],
    "śrīvat": ['mw'],
    "śrīvatsa": ['cae', 'mw'],
    "śrīvatsabhṛt": ['mw'],
    "śrīvatsadhārin": ['mw'],
    "śrīvatsakin": ['mw'],
    "śrīvatsalakṣman": ['mw'],
    "śrīvatsalāñchana": ['mw'],
    "śrīvatsamuktikanandyāvartalakṣitapāṇipādatalatā": ['mw'],
    "śrīvatsapiṇyāka": ['mw'],
    "śrīvatsāṅka": ['mw'],
    "śrīveṣṭa": ['bhs', 'cae', 'mw'],
    "śrīveṣṭaka": ['mw'],
    "śrīvidyottaratāpinī": ['mw'],
    "śrīvidyā": ['mw'],
    "śrīvidyāpaddhati": ['mw'],
    "śrīvidyāpūjāpaddhati": ['mw'],
    "śrīvidyārcanacandrikā": ['mw'],
    "śrīvidyārcanapaddhati": ['mw'],
    "śrīvidyātriśatī": ['mw'],
    "śrīvidyāviṣaya": ['mw'],
    "śrīviśāla": ['mw'],
    "śrīviṣṇupadī": ['mw'],
    "śrīvāraka": ['mw'],
    "śrīvāsa": ['cae', 'mw'],
    "śrīvāsaka": ['mw'],
    "śrīvāsas": ['mw'],
    "śrīvāñcheśvaramāhātmya": ['mw'],
    "śrīvāṭī": ['mw'],
    "śrīvṛddhi": ['mw'],
    "śrīvṛkṣa": ['cae', 'mw'],
    "śrīvṛkṣaka": ['mw'],
    "śrīvṛkṣakanavamīvrata": ['mw'],
    "śrīvṛkṣakin": ['mw'],
    "śrīya": ['mw'],
    "śrīyadhyai": ['mw'],
    "śrīyaśas": ['mw'],
    "śrīyaśasa": ['cae', 'mw'],
    "śrīyaśaskāma": ['mw'],
    "śrīyukta": ['mw'],
    "śrīyuta": ['mw'],
    "śrīyāka": ['mw'],
    "śrīyāmala": ['mw'],
    "śrīāhnika": ['mw'],
    "śrīśa": ['cae', 'mw'],
    "śrīśaila": ['cae', 'mw'],
    "śrīśailakhaṇḍa": ['mw'],
    "śrīśailamāhātmya": ['mw'],
    "śrīśailatātācārya": ['mw'],
    "śrīśailopākhyāna": ['mw'],
    "śrīśalmalībhāṇḍatīrtha": ['mw'],
    "śrīśataka": ['mw'],
    "śrīślokapaddhati": ['mw'],
    "śrīśuka": ['mw'],
    "śrīśukatīrtha": ['mw'],
    "śrīśvara": ['mw'],
    "śrīśyāmalāmbāstotra": ['mw'],
    "śrīśā": ['mw'],
    "śrīśāna": ['bhs'],
    "śrīśānta": ['mw'],
    "śrīḍhakka": ['mw'],
    "śrīṇā": ['mw'],
    "śrīṣavāyaṇa": ['mw'],
    "śrīṣeṇa": ['mw'],
    "śrīṣeṇā": ['mw'],
    "śrū": ['mw'],
    "śrūyamāṇa": ['mw'],
    "śrūyamāṇatva": ['cae', 'ddsa', 'mw'],
    "śrūṇute": ['bhs'],
    "śrūṣā": ['mw'],
    "śu": ['bhs', 'mw'],
    "śubh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śubha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śubhabhrū": ['mw'],
    "śubhabhāvanā": ['mw'],
    "śubhacandra": ['mw'],
    "śubhada": ['mw'],
    "śubhadanta": ['mw'],
    "śubhadantī": ['mw'],
    "śubhadarśa": ['mw'],
    "śubhadarśana": ['cae', 'mw'],
    "śubhadatta": ['bhs', 'cae', 'mw'],
    "śubhadhara": ['mw'],
    "śubhadhāraṇa": ['mw'],
    "śubhadina": ['cae', 'mw'],
    "śubhadārumaya": ['mw'],
    "śubhadāyin": ['mw'],
    "śubhadṛḍhavrata": ['mw'],
    "śubhadṛṣṭi": ['mw'],
    "śubhaga": ['mw'],
    "śubhagandhaka": ['mw'],
    "śubhagarbha": ['bhs', 'mw'],
    "śubhagraha": ['mw'],
    "śubhagrahodaya": ['mw'],
    "śubhagā": ['mw'],
    "śubhagābhīrī": ['mw'],
    "śubhaikadṛś": ['mw'],
    "śubhajālihasta": ['mw'],
    "śubhajāni": ['mw'],
    "śubhaka": ['mw'],
    "śubhakara": ['cae', 'ddsa', 'mw'],
    "śubhakarman": ['mw'],
    "śubhakarmanirṇaya": ['mw'],
    "śubhakarī": ['mw'],
    "śubhakatha": ['mw'],
    "śubhakāma": ['mw'],
    "śubhakāmyā": ['mw'],
    "śubhakūṭa": ['mw'],
    "śubhakṛt": ['mw'],
    "śubhakṛtsna": ['bhs', 'mw'],
    "śubhakṣaṇa": ['mw'],
    "śubhalagna": ['cae', 'mw'],
    "śubhalakṣaṇa": ['cae', 'ddsa', 'mw'],
    "śubhalocana": ['mw'],
    "śubhamaya": ['cae', 'mw'],
    "śubhamaṅgala": ['cae', 'mw'],
    "śubhamekhalā": ['bhs'],
    "śubhamitra": ['mw'],
    "śubhamālā": ['bhs', 'mw'],
    "śubhanaya": ['mw'],
    "śubhanāmā": ['mw'],
    "śubhanātha": ['bhs'],
    "śubhapattrikā": ['mw'],
    "śubhaphala": ['mw'],
    "śubhaphalakṛt": ['mw'],
    "śubhaprabha": ['bhs'],
    "śubhaprada": ['mw'],
    "śubhapratibhāsa": ['bhs'],
    "śubhapuṣpitaśuddhi": ['bhs', 'mw'],
    "śubhapāraṃgama": ['bhs'],
    "śubharatna": ['bhs'],
    "śubhasamanvita": ['cae', 'mw'],
    "śubhasaptamīvrata": ['mw'],
    "śubhasaṃyuta": ['mw'],
    "śubhaspati": ['cae', 'ddsa', 'mw'],
    "śubhasthalī": ['mw'],
    "śubhasu": ['bhs'],
    "śubhasāra": ['mw'],
    "śubhasūcanī": ['mw'],
    "śubhatara": ['mw'],
    "śubhatāti": ['mw'],
    "śubhatātikṛt": ['mw'],
    "śubhavaktrā": ['mw'],
    "śubhavarṇanīya": ['bhs'],
    "śubhavastu": ['mw'],
    "śubhaveṇutriveṇumat": ['mw'],
    "śubhavimalagarbha": ['bhs', 'mw'],
    "śubhavrata": ['cae', 'mw'],
    "śubhavyūha": ['bhs', 'mw'],
    "śubhavārttā": ['mw'],
    "śubhavāsana": ['mw'],
    "śubhavāsara": ['mw'],
    "śubhay": ['cae'],
    "śubhaya": ['ddsa'],
    "śubhayoga": ['mw'],
    "śubhaśakuna": ['mw'],
    "śubhaśaṃsin": ['cae', 'mw'],
    "śubhaśīla": ['mw'],
    "śubhaśīlagaṇi": ['mw'],
    "śubhaṃ": ['mw'],
    "śubhaṃbhāvuka": ['ap90', 'mw'],
    "śubhaṃcarā": ['mw'],
    "śubhaṃkara": ['ap90', 'bhs', 'cae', 'mw'],
    "śubhaṃkarī": ['mw'],
    "śubhaṃyikā": ['mw'],
    "śubhaṃyu": ['ap90', 'cae', 'gra', 'mw'],
    "śubhaṃyā": ['cae', 'ddsa', 'gra', 'mw'],
    "śubhaṃyāvan": ['cae', 'gra', 'mw'],
    "śubhe": ['cae'],
    "śubhekṣaṇa": ['mw'],
    "śubhesthitā": ['bhs'],
    "śubhetara": ['cae', 'ddsa', 'mw'],
    "śubhikā": ['mw'],
    "śubhita": ['mw'],
    "śubhodarka": ['cae', 'ddsa', 'mw'],
    "śubhodarkatā": ['mw'],
    "śubhodaya": ['mw'],
    "śubhorṇabhrū": ['mw'],
    "śubhra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śubhrabhānu": ['mw'],
    "śubhradant": ['cae'],
    "śubhradanta": ['mw'],
    "śubhradantī": ['mw'],
    "śubhradat": ['mw'],
    "śubhrakhādi": ['cae', 'gra', 'mw'],
    "śubhrakṛt": ['mw'],
    "śubhramatī": ['mw'],
    "śubhraraśmi": ['mw'],
    "śubhratva": ['mw'],
    "śubhratā": ['cae', 'mw'],
    "śubhravatī": ['mw'],
    "śubhrayāma": ['cae', 'gra', 'mw'],
    "śubhrayāvan": ['cae', 'gra', 'mw'],
    "śubhraśastama": ['cae', 'gra', 'mw'],
    "śubhri": ['cae', 'gra', 'mw'],
    "śubhrikā": ['mw'],
    "śubhriḥ": ['ap90'],
    "śubhrā": ['ap90', 'mw'],
    "śubhrālu": ['mw'],
    "śubhrāvant": ['cae'],
    "śubhrāvat": ['gra', 'mw'],
    "śubhrāṃśu": ['mw'],
    "śubhrībhū": ['ddsa', 'mw'],
    "śubhvan": ['cae', 'gra', 'mw'],
    "śubhā": ['ap90', 'bhs', 'mw'],
    "śubhācāra": ['cae', 'ddsa', 'mw'],
    "śubhācārā": ['mw'],
    "śubhāgama": ['mw'],
    "śubhākaragupta": ['mw'],
    "śubhākṣa": ['mw'],
    "śubhāna": ['mw'],
    "śubhānana": ['mw'],
    "śubhānandā": ['mw'],
    "śubhānvita": ['mw'],
    "śubhāpāṅgā": ['mw'],
    "śubhārcita": ['mw'],
    "śubhārthin": ['cae', 'mw'],
    "śubhāsana": ['mw'],
    "śubhātmaka": ['cae', 'mw'],
    "śubhāvaha": ['cae', 'mw'],
    "śubhāy": ['cae', 'gra'],
    "śubhāya": ['mw'],
    "śubhāñjana": ['mw'],
    "śubhāśaya": ['mw'],
    "śubhāśis": ['cae', 'mw'],
    "śubhāśubha": ['cae', 'mw'],
    "śubhāśubhalakṣaṇa": ['mw'],
    "śubhāśubhaphala": ['mw'],
    "śubhāśubhaprakaraṇaṭīkā": ['mw'],
    "śubhāśubhayoga": ['mw'],
    "śubhāśīrvacana": ['cae', 'mw'],
    "śubhāśīrvāda": ['mw'],
    "śubhāṅga": ['bhs', 'cae', 'mw'],
    "śubhāṅgada": ['mw'],
    "śubhāṅgin": ['mw'],
    "śubhāṅgī": ['mw'],
    "śubhāṅka": ['mw'],
    "śubhāṣṭakaṭīkā": ['mw'],
    "śubhīkṛ": ['mw'],
    "śuc": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śuca": ['cae', 'gra', 'mw'],
    "śucadhyai": ['mw'],
    "śucadratha": ['ddsa', 'gra', 'mw'],
    "śucanti": ['gra', 'mw'],
    "śucay": ['cae'],
    "śucaya": ['ddsa'],
    "śucayat": ['mw'],
    "śuci": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śucibandhu": ['gra', 'mw'],
    "śucibhrāja": ['gra'],
    "śucibhrājas": ['cae', 'mw'],
    "śucibāhya": ['mw'],
    "śucicarita": ['cae', 'mw'],
    "śucidant": ['cae'],
    "śucidat": ['gra', 'mw'],
    "śucidratha": ['mw'],
    "śucidrava": ['mw'],
    "śucidravya": ['mw'],
    "śucidruma": ['mw'],
    "śucigātra": ['bhs'],
    "śucigātratā": ['mw'],
    "śucijanman": ['cae', 'gra', 'mw'],
    "śucijihva": ['gra', 'mw'],
    "śucika": ['bhs'],
    "śucikarṇa": ['mw'],
    "śucikarṇika": ['mw'],
    "śucikranda": ['gra', 'mw'],
    "śucikā": ['mw'],
    "śucikāma": ['ddsa', 'mw'],
    "śucimallikā": ['mw'],
    "śucimaṇi": ['mw'],
    "śucimukhī": ['mw'],
    "śucimānasa": ['mw'],
    "śucin": ['mw'],
    "śucinetraratisambhava": ['mw'],
    "śucinetraratisaṃbhava": ['bhs'],
    "śucināsatā": ['mw'],
    "śucipadī": ['mw'],
    "śucipati": ['mw'],
    "śucipeśas": ['gra', 'mw'],
    "śucipraroja": ['bhs'],
    "śucipratīka": ['cae', 'gra', 'mw'],
    "śucipraṇī": ['mw'],
    "śucipā": ['cae', 'gra', 'mw'],
    "śuciratha": ['mw'],
    "śucirocis": ['mw'],
    "śucis": ['ap90'],
    "śucisamudācāratā": ['mw'],
    "śucisamācāra": ['mw'],
    "śucisaṃkṣaya": ['mw'],
    "śucismita": ['cae', 'mw'],
    "śucita": ['mw'],
    "śucitva": ['mw'],
    "śucitā": ['cae', 'mw'],
    "śucivana": ['mw'],
    "śucivarcas": ['mw'],
    "śucivarcāya": ['mw'],
    "śucivarṇa": ['cae', 'gra', 'mw'],
    "śucivrata": ['cae', 'gra', 'mw'],
    "śucivāc": ['mw'],
    "śucivāhya": ['mw'],
    "śucivāsas": ['mw'],
    "śucivṛkṣa": ['mw'],
    "śuciśravas": ['mw'],
    "śuciṣad": ['cae', 'gra', 'mw'],
    "śuciṣah": ['mw'],
    "śuciṣmant": ['cae'],
    "śuciṣmat": ['ap90', 'gra', 'mw'],
    "śuciṣmatī": ['mw'],
    "śucy": ['ap90', 'mw'],
    "śucyadakṣa": ['mw'],
    "śucyakṣa": ['cae', 'mw'],
    "śucyupacāra": ['ddsa', 'mw'],
    "śucyācāra": ['mw'],
    "śucā": ['mw'],
    "śucī": ['ddsa', 'mw'],
    "śucībhū": ['mw'],
    "śucīkṛ": ['cae', 'ddsa', 'mw'],
    "śucīvatī": ['mw'],
    "śucīya": ['mw'],
    "śucīyati": ['ap90'],
    "śuddha": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śuddhabadha": ['mw'],
    "śuddhabaṭuka": ['mw'],
    "śuddhabhairava": ['mw'],
    "śuddhabhikṣu": ['mw'],
    "śuddhabhāva": ['cae', 'mw'],
    "śuddhabodha": ['mw'],
    "śuddhabuddha": ['mw'],
    "śuddhabuddhi": ['cae', 'mw'],
    "śuddhacaitanya": ['cae', 'mw'],
    "śuddhadant": ['cae'],
    "śuddhadanta": ['bhs', 'cae', 'mw'],
    "śuddhadat": ['mw'],
    "śuddhadhī": ['cae', 'mw'],
    "śuddhagaṇapati": ['mw'],
    "śuddhahasta": ['cae', 'mw'],
    "śuddhahṛdaya": ['cae', 'mw'],
    "śuddhajaḍa": ['mw'],
    "śuddhajaṅgha": ['mw'],
    "śuddhaka": ['bhs'],
    "śuddhakarman": ['cae', 'mw'],
    "śuddhakarṇa": ['mw'],
    "śuddhakoṭi": ['mw'],
    "śuddhakāṃsyamaya": ['mw'],
    "śuddhakīrti": ['mw'],
    "śuddhamadhyamārgī": ['mw'],
    "śuddhamati": ['cae', 'mw'],
    "śuddhamiśratva": ['mw'],
    "śuddhamukha": ['mw'],
    "śuddhamāṃsa": ['mw'],
    "śuddhanaṭṭā": ['mw'],
    "śuddhaneri": ['mw'],
    "śuddhapakṣa": ['cae', 'mw'],
    "śuddhapaṭa": ['mw'],
    "śuddhapratibhāsa": ['bhs', 'mw'],
    "śuddhapurī": ['mw'],
    "śuddhapurīmāhātmya": ['mw'],
    "śuddhapāda": ['mw'],
    "śuddhapārṣṇi": ['mw'],
    "śuddharaśmiprabha": ['bhs', 'mw'],
    "śuddharūpin": ['mw'],
    "śuddhasattva": ['bhs', 'cae', 'mw'],
    "śuddhasaukhya": ['mw'],
    "śuddhasaṃgama": ['mw'],
    "śuddhasnāna": ['mw'],
    "śuddhasvabhāva": ['cae', 'mw'],
    "śuddhasādhyavasānā": ['mw'],
    "śuddhasāra": ['bhs', 'mw'],
    "śuddhasāropalakṣaṇā": ['mw'],
    "śuddhasāropā": ['mw'],
    "śuddhasūḍanṛtya": ['mw'],
    "śuddhatattvadāsavijñapti": ['mw'],
    "śuddhatva": ['mw'],
    "śuddhatā": ['cae', 'mw'],
    "śuddhatākośa": ['mw'],
    "śuddhaujas": ['mw'],
    "śuddhavadha": ['cae'],
    "śuddhavallikā": ['mw'],
    "śuddhavant": ['cae'],
    "śuddhavarṇa": ['mw'],
    "śuddhavat": ['mw'],
    "śuddhavatī": ['mw'],
    "śuddhavaṃśa": ['bhs'],
    "śuddhavaṃśya": ['cae', 'mw'],
    "śuddhaveṣa": ['cae', 'mw'],
    "śuddhavirāj": ['mw'],
    "śuddhavirāḍṛṣabha": ['mw'],
    "śuddhaviṣkambhaka": ['mw'],
    "śuddhavāla": ['cae', 'mw'],
    "śuddhavāsas": ['mw'],
    "śuddhaśukra": ['mw'],
    "śuddhaśīla": ['cae', 'mw'],
    "śuddhaṣaḍjā": ['mw'],
    "śuddhi": ['cae', 'ddsa', 'mw'],
    "śuddhibhūmi": ['mw'],
    "śuddhibhṛt": ['mw'],
    "śuddhicandrikā": ['mw'],
    "śuddhicintāmaṇi": ['mw'],
    "śuddhidarpaṇa": ['mw'],
    "śuddhidīpa": ['mw'],
    "śuddhidīpikā": ['mw'],
    "śuddhikara": ['mw'],
    "śuddhikaumudī": ['mw'],
    "śuddhikṛt": ['mw'],
    "śuddhilocana": ['mw'],
    "śuddhimakaranda": ['mw'],
    "śuddhimant": ['cae'],
    "śuddhimat": ['ddsa', 'mw'],
    "śuddhimayūkha": ['mw'],
    "śuddhinirūpaṇa": ['mw'],
    "śuddhinirṇaya": ['mw'],
    "śuddhipanthaka": ['bhs'],
    "śuddhipattra": ['mw'],
    "śuddhipañjī": ['mw'],
    "śuddhiprabhā": ['mw'],
    "śuddhipradīpa": ['mw'],
    "śuddhiprakāśa": ['mw'],
    "śuddhiratna": ['mw'],
    "śuddhiratnākara": ['mw'],
    "śuddhiratnāṅkura": ['mw'],
    "śuddhisetu": ['mw'],
    "śuddhismṛti": ['mw'],
    "śuddhisāra": ['mw'],
    "śuddhitama": ['cae', 'mw'],
    "śuddhitattva": ['mw'],
    "śuddhitattvakārikā": ['mw'],
    "śuddhitattvārṇava": ['mw'],
    "śuddhiviveka": ['mw'],
    "śuddhivivekoddyota": ['mw'],
    "śuddhivyavasthāsaṃkṣepa": ['mw'],
    "śuddhiśrāddha": ['mw'],
    "śuddhiḥ": ['ap90'],
    "śuddhoda": ['mw'],
    "śuddhodana": ['bhs', 'cae', 'ddsa', 'mw'],
    "śuddhodanasuta": ['mw'],
    "śuddhodani": ['mw'],
    "śuddhyadhyāśayabhūmi": ['bhs'],
    "śuddhā": ['bhs', 'mw'],
    "śuddhābha": ['bhs', 'cae', 'mw'],
    "śuddhābhijanakarman": ['mw'],
    "śuddhādhivāsa": ['bhs', 'mw'],
    "śuddhādhyāśayabhūmi": ['bhs'],
    "śuddhādvaitamārtaṇḍa": ['mw'],
    "śuddhākhyasahasrasaṃhitā": ['mw'],
    "śuddhākṣa": ['mw'],
    "śuddhānanda": ['mw'],
    "śuddhānta": ['cae', 'mw'],
    "śuddhāntacara": ['cae', 'mw'],
    "śuddhāntacārin": ['cae', 'mw'],
    "śuddhāntakāntā": ['mw'],
    "śuddhāntapālaka": ['mw'],
    "śuddhāntarakṣaka": ['mw'],
    "śuddhāntarakṣī": ['mw'],
    "śuddhāntarayuj": ['mw'],
    "śuddhāntavṛddha": ['mw'],
    "śuddhāntayuj": ['mw'],
    "śuddhāntaḥpura": ['mw'],
    "śuddhāntika": ['bhs'],
    "śuddhāntā": ['mw'],
    "śuddhānumāna": ['mw'],
    "śuddhāpahnuti": ['mw'],
    "śuddhāraṃ": ['bhs'],
    "śuddhātman": ['cae', 'ddsa', 'mw'],
    "śuddhāvarta": ['mw'],
    "śuddhāvāsa": ['bhs', 'mw'],
    "śuddhāvāsadeva": ['mw'],
    "śuddhāvāsadevaputra": ['mw'],
    "śuddhāvāsakāyika": ['bhs', 'mw'],
    "śuddhāyū": ['mw'],
    "śuddhāśaya": ['cae', 'mw'],
    "śuddhāśubodha": ['mw'],
    "śuddhāśuddhīya": ['mw'],
    "śudh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śudi": ['ddsa', 'mw'],
    "śuj": ['cae', 'gra', 'mw'],
    "śuk": ['ap90', 'mw'],
    "śuka": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śukababhru": ['cae', 'mw'],
    "śukabarha": ['mw'],
    "śukabṛhatkathā": ['mw'],
    "śukacchada": ['ddsa', 'mw'],
    "śukadeva": ['cae', 'mw'],
    "śukadevacaritra": ['mw'],
    "śukadruma": ['mw'],
    "śukahari": ['cae', 'mw'],
    "śukaharita": ['cae', 'mw'],
    "śukajihvā": ['mw'],
    "śukajātaka": ['mw'],
    "śukakarṇī": ['mw'],
    "śukakūṭa": ['mw'],
    "śukalāṅgala": ['mw'],
    "śukam": ['mw'],
    "śukamahimnaḥstava": ['mw'],
    "śukamukha": ['bhs'],
    "śukanalikānyāya": ['mw'],
    "śukanalikānyāyena": ['mw'],
    "śukanasā": ['mw'],
    "śukanaśā": ['mw'],
    "śukanāmā": ['mw'],
    "śukanāsa": ['mw'],
    "śukanāsikā": ['mw'],
    "śukanāsā": ['mw'],
    "śukanāśa": ['mw'],
    "śukanāśana": ['mw'],
    "śukanāśā": ['mw'],
    "śukapakṣīya": ['mw'],
    "śukapakṣīyavyākhyā": ['mw'],
    "śukaphala": ['mw'],
    "śukapitāmaha": ['mw'],
    "śukapiṇḍi": ['mw'],
    "śukapotra": ['mw'],
    "śukapraśnasaṃhitā": ['mw'],
    "śukapriya": ['mw'],
    "śukapriyā": ['mw'],
    "śukapuccha": ['mw'],
    "śukapucchaka": ['mw'],
    "śukapuṣpa": ['mw'],
    "śukarahasya": ['mw'],
    "śukarahasyopaniṣad": ['mw'],
    "śukarūpa": ['cae', 'mw'],
    "śukasaptati": ['cae', 'mw'],
    "śukasaṃdeśa": ['mw'],
    "śukasaṃdeśavyākhyā": ['mw'],
    "śukasaṃhitā": ['mw'],
    "śukasaṃvāda": ['mw'],
    "śukasārikāpralāpana": ['mw'],
    "śukasūktisudhākara": ['mw'],
    "śukasūtra": ['mw'],
    "śukataru": ['mw'],
    "śukatuṇḍa": ['mw'],
    "śukatuṇḍaka": ['mw'],
    "śukatva": ['mw'],
    "śukatā": ['mw'],
    "śukatātparyaratnāvali": ['mw'],
    "śukavallabha": ['mw'],
    "śukavat": ['mw'],
    "śukavāc": ['mw'],
    "śukavāha": ['mw'],
    "śukayogin": ['mw'],
    "śukaśimbi": ['mw'],
    "śukaśimbā": ['mw'],
    "śukaśārika": ['mw'],
    "śukaḥ": ['ap90'],
    "śukeśvaratīrtha": ['mw'],
    "śukeṣṭa": ['mw'],
    "śukla": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śuklabala": ['mw'],
    "śuklabhāga": ['mw'],
    "śuklabhāsvara": ['mw'],
    "śuklabhūdeva": ['mw'],
    "śuklabuddhikara": ['mw'],
    "śuklabīja": ['mw'],
    "śukladant": ['cae'],
    "śukladat": ['mw'],
    "śukladaśabhāṣya": ['mw'],
    "śukladaśana": ['mw'],
    "śukladaṃṣṭratā": ['mw'],
    "śukladeha": ['mw'],
    "śukladharma": ['mw'],
    "śukladhvajapatākin": ['mw'],
    "śukladhyāna": ['mw'],
    "śukladhānya": ['mw'],
    "śukladhātu": ['mw'],
    "śukladruma": ['mw'],
    "śukladugdha": ['mw'],
    "śuklaharita": ['mw'],
    "śuklajanārdana": ['mw'],
    "śuklaka": ['ap90', 'bhs', 'mw'],
    "śuklakanda": ['mw'],
    "śuklakandā": ['mw'],
    "śuklakarman": ['mw'],
    "śuklakarṇa": ['mw'],
    "śuklakaṇṭhaka": ['mw'],
    "śuklakeśa": ['cae', 'mw'],
    "śuklakuṣṭha": ['mw'],
    "śuklakṛṣṇa": ['cae', 'mw'],
    "śuklakṣetra": ['mw'],
    "śuklakṣīra": ['mw'],
    "śuklala": ['ap90', 'mw'],
    "śuklalā": ['mw'],
    "śuklamathurānātha": ['mw'],
    "śuklamaṇḍala": ['mw'],
    "śuklameha": ['mw'],
    "śuklamehin": ['mw'],
    "śuklamālyānulepana": ['mw'],
    "śuklapakṣa": ['bhs', 'cae', 'mw'],
    "śuklapakṣīya": ['mw'],
    "śuklapuṣpa": ['mw'],
    "śuklapuṣpā": ['mw'],
    "śuklapuṣpī": ['mw'],
    "śuklapākṣika": ['bhs'],
    "śuklapṛṣṭhaka": ['mw'],
    "śuklarohita": ['mw'],
    "śuklarūpa": ['cae', 'mw'],
    "śuklasūtra": ['mw'],
    "śuklatva": ['mw'],
    "śuklatā": ['mw'],
    "śuklatīrtha": ['mw'],
    "śuklatīrthamāhātmya": ['mw'],
    "śuklavacā": ['mw'],
    "śuklavarga": ['mw'],
    "śuklavastra": ['cae', 'mw'],
    "śuklavat": ['mw'],
    "śuklavatsā": ['cae', 'mw'],
    "śuklavidarśanā": ['mw'],
    "śuklavidarśanābhūmi": ['bhs'],
    "śuklaviśrāma": ['mw'],
    "śuklavāsas": ['cae', 'mw'],
    "śuklavāyasa": ['mw'],
    "śuklavṛtta": ['cae', 'mw'],
    "śuklavṛtti": ['mw'],
    "śuklayajurvedādhyetṛpraśaṃsā": ['mw'],
    "śuklayajñopavītavat": ['mw'],
    "śuklaśāla": ['mw'],
    "śukletara": ['mw'],
    "śukleśvara": ['mw'],
    "śukleśvaranātha": ['mw'],
    "śukliman": ['ap90', 'cae', 'ddsa', 'mw'],
    "śuklodana": ['bhs', 'mw'],
    "śuklopala": ['mw'],
    "śuklopalā": ['mw'],
    "śuklā": ['ap90', 'bhs', 'mw'],
    "śuklābhijātīya": ['mw'],
    "śuklācāra": ['cae', 'mw'],
    "śuklādiśrāvaṇakṛṣṇasaptamī": ['mw'],
    "śuklādiśrāvaṇakṛṣṇāṣṭamī": ['mw'],
    "śuklāguru": ['ddsa', 'mw'],
    "śuklāmbara": ['cae', 'mw'],
    "śuklāmbaradhara": ['mw'],
    "śuklāmla": ['mw'],
    "śuklāpara": ['mw'],
    "śuklāpāṅga": ['cae', 'mw'],
    "śuklārka": ['mw'],
    "śuklārman": ['mw'],
    "śuklāyana": ['mw'],
    "śuklāṅga": ['mw'],
    "śuklāṅgī": ['mw'],
    "śuklāṣṭamī": ['mw'],
    "śuklī": ['mw'],
    "śuklībhū": ['mw'],
    "śuklīkaraṇa": ['mw'],
    "śuklīkṛ": ['cae', 'ddsa', 'mw'],
    "śuklīkṛta": ['mw'],
    "śukodara": ['mw'],
    "śukoktijāla": ['mw'],
    "śukorvaśīsaṃvāda": ['mw'],
    "śukotpatti": ['mw'],
    "śukra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śukrabhuj": ['mw'],
    "śukrabhū": ['mw'],
    "śukracāra": ['mw'],
    "śukradanta": ['mw'],
    "śukradina": ['mw'],
    "śukradoṣa": ['mw'],
    "śukradugha": ['gra', 'mw'],
    "śukragṛha": ['mw'],
    "śukraharaṇa": ['mw'],
    "śukraja": ['cae', 'mw'],
    "śukrajyotis": ['cae', 'mw'],
    "śukrakara": ['mw'],
    "śukrakṛcchra": ['mw'],
    "śukrala": ['ap90', 'mw'],
    "śukralā": ['mw'],
    "śukrameha": ['mw'],
    "śukramehin": ['mw'],
    "śukramūtrala": ['mw'],
    "śukranālikodāharaṇa": ['mw'],
    "śukranāḍi": ['mw'],
    "śukranīti": ['mw'],
    "śukrapa": ['cae', 'mw'],
    "śukrapiś": ['gra', 'mw'],
    "śukrapātra": ['mw'],
    "śukrapāṇi": ['mw'],
    "śukrapūjā": ['mw'],
    "śukrapūtapā": ['cae', 'gra', 'mw'],
    "śukrapṛṣṭha": ['mw'],
    "śukrarūpa": ['mw'],
    "śukrarṣabha": ['mw'],
    "śukrasadman": ['gra', 'mw'],
    "śukrastoma": ['mw'],
    "śukrasuta": ['mw'],
    "śukrasāra": ['mw'],
    "śukrasāratā": ['mw'],
    "śukrasūkta": ['mw'],
    "śukrasṛṣṭā": ['mw'],
    "śukratīrtha": ['mw'],
    "śukravaha": ['mw'],
    "śukravant": ['cae'],
    "śukravarcas": ['gra', 'mw'],
    "śukravardhinī": ['mw'],
    "śukravarṇa": ['cae', 'gra', 'mw'],
    "śukravat": ['mw'],
    "śukravisarga": ['bhs'],
    "śukravisṛṣṭi": ['mw'],
    "śukravāra": ['mw'],
    "śukravāsara": ['mw'],
    "śukravāsas": ['cae', 'gra', 'mw'],
    "śukrayajus": ['mw'],
    "śukraśiṣya": ['mw'],
    "śukraśoca": ['mw'],
    "śukraśoci": ['mw'],
    "śukraśocis": ['gra', 'mw'],
    "śukraśānti": ['mw'],
    "śukreśvara": ['mw'],
    "śukreśvarastuti": ['mw'],
    "śukriman": ['mw'],
    "śukriya": ['cae', 'ddsa', 'mw'],
    "śukrodana": ['bhs'],
    "śukrottara": ['mw'],
    "śukrā": ['bhs'],
    "śukrācārya": ['mw'],
    "śukrāmanthinau": ['ddsa', 'mw'],
    "śukrāṅga": ['mw'],
    "śukrībhū": ['mw'],
    "śukta": ['ap90', 'cae', 'ddsa', 'mw'],
    "śuktaka": ['cae', 'mw'],
    "śuktakaṃ": ['ap90'],
    "śuktapāka": ['mw'],
    "śuktasvara": ['mw'],
    "śuktatiktakaṣāyaka": ['mw'],
    "śukti": ['cae', 'ddsa', 'mw'],
    "śuktibīja": ['mw'],
    "śuktija": ['cae', 'mw'],
    "śuktika": ['mw'],
    "śuktikarṇa": ['mw'],
    "śuktikhalati": ['mw'],
    "śuktikā": ['ap90', 'cae', 'mw'],
    "śuktimat": ['ap90', 'mw'],
    "śuktimatī": ['mw'],
    "śuktimaṇi": ['mw'],
    "śuktiparṇa": ['mw'],
    "śuktipaṭṭa": ['mw'],
    "śuktipeśī": ['mw'],
    "śuktipuṭa": ['mw'],
    "śuktisparśa": ['mw'],
    "śuktisāhvayā": ['mw'],
    "śuktivadhū": ['mw'],
    "śuktiḥ": ['ap90'],
    "śukty": ['mw'],
    "śuktyudbhava": ['mw'],
    "śuktā": ['mw'],
    "śukvan": ['gra', 'mw'],
    "śukādana": ['mw'],
    "śukākhyā": ['mw'],
    "śukānana": ['mw'],
    "śukānanā": ['mw'],
    "śukānuśāsana": ['mw'],
    "śukāyana": ['mw'],
    "śukāṣṭaka": ['mw'],
    "śukāṣṭakavyākhyā": ['mw'],
    "śukī": ['ddsa', 'mw'],
    "śukībhū": ['ddsa', 'mw'],
    "śukṣi": ['mw'],
    "śukṣiḥ": ['ap90'],
    "śulb": ['mw'],
    "śulba": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śulbabhāṣya": ['mw'],
    "śulbadīpikā": ['mw'],
    "śulbaja": ['mw'],
    "śulbakalpa": ['mw'],
    "śulbakārikā": ['mw'],
    "śulbamīmāṃsā": ['mw'],
    "śulbapariśiṣṭa": ['mw'],
    "śulbarahasyaprakāśa": ['mw'],
    "śulbasūtra": ['mw'],
    "śulbasūtrabhāṣyavārttikavyākhyā": ['mw'],
    "śulbavārttika": ['mw'],
    "śulbavṛttivivaraṇa": ['mw'],
    "śulbaṃ": ['ap90'],
    "śulbika": ['mw'],
    "śulbopadhāna": ['mw'],
    "śulbāgninidhiṭīkā": ['mw'],
    "śulbāri": ['mw'],
    "śulk": ['ap90', 'mw'],
    "śulka": ['cae', 'ddsa', 'gra', 'mw'],
    "śulkada": ['cae', 'mw'],
    "śulkagrāhaka": ['mw'],
    "śulkagrāhin": ['mw'],
    "śulkahāni": ['mw'],
    "śulkakhaṇḍana": ['mw'],
    "śulkamoṣaṇa": ['mw'],
    "śulkasaṃjña": ['mw'],
    "śulkasthāna": ['mw'],
    "śulkatva": ['mw'],
    "śulkayati": ['bhs'],
    "śulkaśālika": ['bhs'],
    "śulkaśālā": ['bhs', 'mw'],
    "śulkaḥ": ['ap90'],
    "śulkikā": ['mw'],
    "śulkopajīvin": ['mw'],
    "śulkābhidhāna": ['mw'],
    "śulkādhyakṣa": ['mw'],
    "śulkāvāpta": ['mw'],
    "śulla": ['mw'],
    "śullaṃ": ['ap90'],
    "śuluka": ['bhs'],
    "śulv": ['ap90', 'mw'],
    "śulva": ['mw'],
    "śulvaṃ": ['ap90'],
    "śumba": ['mw'],
    "śumbala": ['cae', 'mw'],
    "śumbh": ['cae', 'ddsa', 'gra', 'mw'],
    "śumbha": ['cae', 'ddsa', 'mw'],
    "śumbhadeśa": ['mw'],
    "śumbhaghātinī": ['mw'],
    "śumbhahananī": ['mw'],
    "śumbhaka": ['bhs'],
    "śumbhamardinī": ['mw'],
    "śumbhamathanī": ['mw'],
    "śumbhamāna": ['ddsa', 'mw'],
    "śumbhana": ['cae', 'mw'],
    "śumbhaniśumbha": ['cae', 'mw'],
    "śumbhapura": ['mw'],
    "śumbhapurī": ['mw'],
    "śumbhavadha": ['mw'],
    "śumbhita": ['mw'],
    "śumbhāna": ['mw'],
    "śumbhū": ['mw'],
    "śun": ['ap90', 'mw'],
    "śuna": ['cae', 'ddsa', 'gra', 'mw'],
    "śunahotra": ['gra', 'mw'],
    "śunaka": ['cae', 'ddsa', 'mw'],
    "śunakacillī": ['mw'],
    "śunakakañcuka": ['mw'],
    "śunakaputra": ['mw'],
    "śunakasadṛśa": ['cae'],
    "śunakasuta": ['mw'],
    "śunakaḥ": ['ap90'],
    "śunakha": ['bhs'],
    "śunakī": ['mw'],
    "śunam": ['mw'],
    "śunapṛṣṭha": ['ddsa', 'gra', 'mw'],
    "śunas": ['mw'],
    "śunaskarṇa": ['mw'],
    "śunavant": ['cae'],
    "śunavat": ['mw'],
    "śunaśśepa": ['gra'],
    "śunaḥ": ['mw'],
    "śunaḥpuccha": ['cae', 'ddsa', 'mw'],
    "śunaḥpucchasmṛti": ['mw'],
    "śunaḥsakha": ['mw'],
    "śunaḥśepa": ['cae', 'ddsa', 'mw'],
    "śunaḥśepaḥ": ['ap90'],
    "śunaḥśepha": ['cae', 'mw'],
    "śunaḥśephaḥ": ['ap90'],
    "śunaṃhavīyā": ['ddsa'],
    "śunaṃhuvīyā": ['mw'],
    "śunaṃkuri": ['mw'],
    "śunaṅkuri": ['ddsa'],
    "śundh": ['cae', 'ddsa', 'gra', 'mw'],
    "śundhana": ['cae', 'mw'],
    "śundhyu": ['cae', 'ddsa', 'gra', 'mw'],
    "śundhyū": ['cae', 'mw'],
    "śundhāvat": ['mw'],
    "śuneṣita": ['gra', 'mw'],
    "śuni": ['mw'],
    "śuniḥ": ['ap90'],
    "śuniṃdhama": ['mw'],
    "śuniṃdhaya": ['mw'],
    "śuno": ['mw'],
    "śunolāṅgūla": ['cae', 'ddsa', 'mw'],
    "śunya": ['ap90', 'mw'],
    "śunā": ['mw'],
    "śunāsīra": ['cae', 'gra', 'mw'],
    "śunāsīraśarāsana": ['mw'],
    "śunāsīraḥ": ['ap90'],
    "śunāsīrin": ['mw'],
    "śunāsīrya": ['mw'],
    "śunāsīrīya": ['mw'],
    "śunāvant": ['cae'],
    "śunāvat": ['mw'],
    "śunāśīra": ['ddsa'],
    "śunāśīraḥ": ['ap90'],
    "śunī": ['ap90', 'cae', 'ddsa', 'mw'],
    "śunīra": ['mw'],
    "śunīraḥ": ['ap90'],
    "śup": ['ap90', 'mw'],
    "śuphāliha": ['mw'],
    "śupti": ['cae', 'ddsa', 'gra', 'mw'],
    "śur": ['ap90'],
    "śura": ['mw'],
    "śurudh": ['cae', 'ddsa', 'gra', 'mw'],
    "śuti": ['mw'],
    "śutudriḥ": ['ap90'],
    "śutudrī": ['cae', 'ddsa', 'gra', 'mw'],
    "śuve": ['bhs'],
    "śuvedāni": ['bhs'],
    "śuvetanāni": ['bhs'],
    "śuvetanāya": ['bhs'],
    "śuścu": ['bhs'],
    "śuśruvas": ['mw'],
    "śuśrū": ['ap90', 'cae', 'mw'],
    "śuśrūyati": ['bhs'],
    "śuśrūṣaka": ['ap90', 'cae', 'ddsa', 'mw'],
    "śuśrūṣaṇa": ['cae', 'mw'],
    "śuśrūṣaṇaṃ": ['ap90'],
    "śuśrūṣaṇā": ['bhs'],
    "śuśrūṣeṇya": ['cae', 'mw'],
    "śuśrūṣin": ['cae', 'mw'],
    "śuśrūṣita": ['cae'],
    "śuśrūṣitavya": ['mw'],
    "śuśrūṣitṛ": ['mw'],
    "śuśrūṣu": ['ap90', 'cae', 'mw'],
    "śuśrūṣya": ['cae', 'mw'],
    "śuśrūṣā": ['ap90', 'cae', 'mw'],
    "śuśrūṣāpara": ['mw'],
    "śuśucāna": ['mw'],
    "śuśukvana": ['cae', 'ddsa', 'gra', 'mw'],
    "śuśukvani": ['cae', 'gra', 'mw'],
    "śuśukvas": ['mw'],
    "śuśukā": ['bhs'],
    "śuśukṣaṇi": ['mw'],
    "śuśulūka": ['cae', 'gra', 'mw'],
    "śuśulūkayātu": ['ddsa', 'gra', 'mw'],
    "śuśulūkā": ['mw'],
    "śuśumāra": ['bhs'],
    "śuśumāragiri": ['bhs', 'mw'],
    "śuśumāragirīya": ['bhs', 'mw'],
    "śuśumāragirīyaka": ['mw'],
    "śuśuvas": ['ddsa'],
    "śuṃbh": ['ap90'],
    "śuṃbhaḥ": ['ap90'],
    "śuṃdh": ['ap90'],
    "śuṃdhyuḥ": ['ap90'],
    "śuṃgaḥ": ['ap90'],
    "śuṃgin": ['ap90'],
    "śuṃgā": ['ap90'],
    "śuṃśumāra": ['mw'],
    "śuṃśumāraḥ": ['ap90'],
    "śuṃḍ": ['ap90'],
    "śuṃḍakaḥ": ['ap90'],
    "śuṃḍaḥ": ['ap90'],
    "śuṃḍikā": ['ap90'],
    "śuṃḍin": ['ap90'],
    "śuṃḍā": ['ap90'],
    "śuṃḍālaḥ": ['ap90'],
    "śuṃḍāraḥ": ['ap90'],
    "śuṃṭh": ['ap90'],
    "śuṃṭhiḥ": ['ap90'],
    "śuṅga": ['cae', 'ddsa', 'mw'],
    "śuṅgarājan": ['mw'],
    "śuṅgin": ['mw'],
    "śuṅgā": ['mw'],
    "śuṅgākarman": ['mw'],
    "śuṅgī": ['mw'],
    "śuṅgībhūta": ['bhs'],
    "śuṇḍ": ['mw'],
    "śuṇḍa": ['mw'],
    "śuṇḍaka": ['mw'],
    "śuṇḍaroha": ['mw'],
    "śuṇḍhi": ['mw'],
    "śuṇḍika": ['bhs', 'cae', 'mw'],
    "śuṇḍikā": ['mw'],
    "śuṇḍimūṣikā": ['mw'],
    "śuṇḍin": ['cae', 'ddsa', 'mw'],
    "śuṇḍā": ['cae', 'ddsa', 'mw'],
    "śuṇḍādaṇḍa": ['mw'],
    "śuṇḍāla": ['mw'],
    "śuṇḍāpeya": ['bhs'],
    "śuṇḍāpāna": ['mw'],
    "śuṇḍāra": ['cae', 'ddsa', 'mw'],
    "śuṇḍārocanikā": ['mw'],
    "śuṇḍārocanī": ['mw'],
    "śuṇḍī": ['mw'],
    "śuṇḍīrocanikā": ['mw'],
    "śuṇḍīrocanī": ['mw'],
    "śuṇṭa": ['mw'],
    "śuṇṭh": ['mw'],
    "śuṇṭha": ['cae', 'mw'],
    "śuṇṭhi": ['cae', 'mw'],
    "śuṇṭhika": ['bhs'],
    "śuṇṭhya": ['mw'],
    "śuṇṭhācārya": ['mw'],
    "śuṇṭhādhī": ['mw'],
    "śuṇṭhākarṇa": ['cae', 'mw'],
    "śuṇṭhī": ['cae', 'ddsa', 'mw'],
    "śuṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śuṣa": ['mw'],
    "śuṣaḥ": ['ap90'],
    "śuṣi": ['mw'],
    "śuṣikā": ['mw'],
    "śuṣila": ['mw'],
    "śuṣilaḥ": ['ap90'],
    "śuṣira": ['ap90', 'mw'],
    "śuṣirā": ['ap90'],
    "śuṣiḥ": ['ap90'],
    "śuṣka": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śuṣkabhṛṅgāra": ['cae', 'mw'],
    "śuṣkabhṛṅgārīya": ['mw'],
    "śuṣkacarcana": ['mw'],
    "śuṣkadṛti": ['cae', 'mw'],
    "śuṣkagomaya": ['mw'],
    "śuṣkagāna": ['mw'],
    "śuṣkajñānanirādara": ['mw'],
    "śuṣkaka": ['mw'],
    "śuṣkakalaha": ['mw'],
    "śuṣkakaṇṭha": ['mw'],
    "śuṣkakāsa": ['mw'],
    "śuṣkakāṣṭha": ['cae', 'mw'],
    "śuṣkakṣetra": ['mw'],
    "śuṣkala": ['mw'],
    "śuṣkalaḥ": ['ap90'],
    "śuṣkaletra": ['ddsa', 'mw'],
    "śuṣkamatsya": ['mw'],
    "śuṣkamukha": ['cae', 'mw'],
    "śuṣkamāṃsa": ['mw'],
    "śuṣkanitambhasthalī": ['mw'],
    "śuṣkaparṇa": ['mw'],
    "śuṣkaparṇavat": ['mw'],
    "śuṣkapattra": ['mw'],
    "śuṣkapeṣam": ['mw'],
    "śuṣkaphala": ['mw'],
    "śuṣkapāka": ['mw'],
    "śuṣkarevatī": ['mw'],
    "śuṣkarudita": ['mw'],
    "śuṣkasambhava": ['mw'],
    "śuṣkasrota": ['mw'],
    "śuṣkasrotas": ['mw'],
    "śuṣkatarka": ['mw'],
    "śuṣkati": ['bhs'],
    "śuṣkatoya": ['cae', 'mw'],
    "śuṣkatva": ['mw'],
    "śuṣkatā": ['cae', 'mw'],
    "śuṣkavaira": ['cae', 'mw'],
    "śuṣkavairin": ['mw'],
    "śuṣkavant": ['cae'],
    "śuṣkavartikā": ['bhs'],
    "śuṣkavat": ['ddsa', 'mw'],
    "śuṣkavigraha": ['mw'],
    "śuṣkavirohaṇa": ['mw'],
    "śuṣkavraṇa": ['mw'],
    "śuṣkavādavivāda": ['mw'],
    "śuṣkavṛkṣa": ['mw'],
    "śuṣkaṭavarman": ['mw'],
    "śuṣkāgra": ['cae', 'mw'],
    "śuṣkākṣipāka": ['mw'],
    "śuṣkānna": ['cae', 'mw'],
    "śuṣkāpa": ['cae', 'mw'],
    "śuṣkārdra": ['cae', 'mw'],
    "śuṣkārśas": ['mw'],
    "śuṣkāsthi": ['mw'],
    "śuṣkāsya": ['cae', 'mw'],
    "śuṣkāṅga": ['mw'],
    "śuṣkāṅgī": ['mw'],
    "śuṣma": ['cae', 'ddsa', 'gra', 'mw'],
    "śuṣmada": ['cae', 'mw'],
    "śuṣman": ['ap90', 'cae', 'ddsa', 'mw'],
    "śuṣmavant": ['cae'],
    "śuṣmavat": ['mw'],
    "śuṣmaya": ['cae', 'mw'],
    "śuṣmaḥ": ['ap90'],
    "śuṣmi": ['mw'],
    "śuṣmin": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śuṣmintama": ['mw'],
    "śuṣmiṇa": ['ddsa', 'mw'],
    "śuṣmāyaṇa": ['mw'],
    "śuṣṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "śuṣṇahatya": ['cae', 'gra', 'mw'],
    "śuṣṇaḥ": ['ap90'],
    "śuṭh": ['ap90', 'mw'],
    "śuṭīra": ['mw'],
    "śuṭīratva": ['mw'],
    "śuṭīratā": ['mw'],
    "śuṭīraḥ": ['ap90'],
    "śuṭīrya": ['mw'],
    "śuṭīryaṃ": ['ap90'],
    "śva": ['mw'],
    "śvabhakṣa": ['cae', 'mw'],
    "śvabhakṣya": ['cae', 'mw'],
    "śvabhojana": ['mw'],
    "śvabhojin": ['mw'],
    "śvabhr": ['ap90', 'mw'],
    "śvabhra": ['cae', 'ddsa', 'gra', 'mw'],
    "śvabhramukha": ['mw'],
    "śvabhrapada": ['bhs'],
    "śvabhrapati": ['mw'],
    "śvabhratiryañc": ['mw'],
    "śvabhravat": ['mw'],
    "śvabhravatī": ['mw'],
    "śvabhraṃ": ['ap90'],
    "śvabhrita": ['mw'],
    "śvabhrīy": ['cae'],
    "śvabhrīya": ['ddsa', 'mw'],
    "śvabhīru": ['mw'],
    "śvabāla": ['mw'],
    "śvac": ['ap90', 'gra', 'mw'],
    "śvacakra": ['mw'],
    "śvacaryā": ['mw'],
    "śvacaṇḍāla": ['mw'],
    "śvacillī": ['mw'],
    "śvadayita": ['mw'],
    "śvadaṃṣṭraka": ['mw'],
    "śvadaṃṣṭrin": ['mw'],
    "śvadaṃṣṭrā": ['mw'],
    "śvadhiti": ['mw'],
    "śvadhūrta": ['mw'],
    "śvadṛti": ['cae', 'ddsa', 'mw'],
    "śvagardabha": ['cae', 'mw'],
    "śvagardabhapati": ['mw'],
    "śvagaṇa": ['mw'],
    "śvagaṇika": ['mw'],
    "śvagaṇin": ['mw'],
    "śvaghnin": ['cae', 'ddsa', 'gra', 'mw'],
    "śvaghnī": ['mw'],
    "śvagraha": ['mw'],
    "śvagrahagṛhīta": ['mw'],
    "śvagrahaprāyaścitta": ['mw'],
    "śvahan": ['mw'],
    "śvahata": ['cae', 'mw'],
    "śvahāna": ['mw'],
    "śvaikna": ['cae', 'mw'],
    "śvaita": ['mw'],
    "śvaitacchattrika": ['mw'],
    "śvaitarī": ['cae', 'ddsa', 'gra', 'mw'],
    "śvaitavaidārava": ['mw'],
    "śvaiti": ['mw'],
    "śvaitra": ['mw'],
    "śvaitraṃ": ['ap90'],
    "śvaitreya": ['gra', 'mw'],
    "śvaitrya": ['cae', 'ddsa', 'mw'],
    "śvaitya": ['cae', 'ddsa', 'mw'],
    "śvaityaṃ": ['ap90'],
    "śvaitāṃśava": ['ddsa', 'mw'],
    "śvaj": ['ap90', 'mw'],
    "śvajāghanī": ['cae', 'mw'],
    "śvajīvana": ['mw'],
    "śvajīvikā": ['mw'],
    "śvajīvin": ['mw'],
    "śvaka": ['mw'],
    "śvakarṇa": ['mw'],
    "śvakaṇṭaka": ['mw'],
    "śvakharoṣṭra": ['mw'],
    "śvakiṣkin": ['mw'],
    "śvakrīḍin": ['cae', 'ddsa', 'mw'],
    "śval": ['ap90', 'mw'],
    "śvalehya": ['mw'],
    "śvalih": ['mw'],
    "śvalk": ['ap90', 'mw'],
    "śvall": ['ap90', 'mw'],
    "śvalominī": ['mw'],
    "śvamukha": ['mw'],
    "śvamāṃsa": ['cae', 'ddsa', 'mw'],
    "śvan": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śvanakula": ['mw'],
    "śvanara": ['mw'],
    "śvanin": ['cae', 'mw'],
    "śvaniśa": ['mw'],
    "śvanvatī": ['mw'],
    "śvanī": ['cae', 'mw'],
    "śvapa": ['mw'],
    "śvapac": ['ddsa', 'mw'],
    "śvapaca": ['cae', 'mw'],
    "śvapacatva": ['mw'],
    "śvapacatā": ['mw'],
    "śvapacī": ['mw'],
    "śvapad": ['mw'],
    "śvapada": ['cae', 'mw'],
    "śvapaka": ['mw'],
    "śvapati": ['cae', 'mw'],
    "śvaphala": ['mw'],
    "śvaphalka": ['mw'],
    "śvapoṣaka": ['mw'],
    "śvapuccha": ['cae', 'mw'],
    "śvapāda": ['mw'],
    "śvapāka": ['cae', 'mw'],
    "śvapākī": ['mw'],
    "śvapāmana": ['mw'],
    "śvart": ['mw'],
    "śvarūpadhārin": ['mw'],
    "śvas": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śvasana": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śvasanamanoga": ['mw'],
    "śvasanarandhra": ['mw'],
    "śvasanasamīraṇa": ['mw'],
    "śvasanavat": ['mw'],
    "śvasanaḥ": ['ap90'],
    "śvasaneśvara": ['mw'],
    "śvasanormi": ['mw'],
    "śvasanotsuka": ['mw'],
    "śvasanāśana": ['mw'],
    "śvasatha": ['cae', 'ddsa', 'gra', 'mw'],
    "śvasaya": ['mw'],
    "śvasita": ['ap90', 'cae', 'ddsa', 'mw'],
    "śvaspṛṣṭa": ['mw'],
    "śvastana": ['ap90', 'cae', 'ddsa', 'mw'],
    "śvastanavat": ['mw'],
    "śvastanika": ['mw'],
    "śvastanī": ['mw'],
    "śvastya": ['mw'],
    "śvasuna": ['mw'],
    "śvasuta": ['mw'],
    "śvasā": ['bhs'],
    "śvasāna": ['mw'],
    "śvasīvas": ['gra'],
    "śvasīvat": ['mw'],
    "śvasṛgāla": ['mw'],
    "śvavant": ['cae'],
    "śvavarta": ['cae', 'mw'],
    "śvavat": ['ddsa', 'mw'],
    "śvaviṣṭhā": ['cae', 'mw'],
    "śvavyāghra": ['mw'],
    "śvavāla": ['cae', 'mw'],
    "śvavṛtti": ['cae', 'mw'],
    "śvavṛttin": ['cae', 'mw'],
    "śvaya": ['mw'],
    "śvayana": ['mw'],
    "śvayas": ['mw'],
    "śvayatha": ['cae', 'mw'],
    "śvayathu": ['cae', 'ddsa', 'mw'],
    "śvayathucikitsā": ['mw'],
    "śvayathukara": ['mw'],
    "śvayathumat": ['mw'],
    "śvayathuḥ": ['ap90'],
    "śvayaḥ": ['ap90'],
    "śvayātu": ['cae', 'gra', 'mw'],
    "śvayīci": ['mw'],
    "śvayīcī": ['ap90'],
    "śvayūtha": ['mw'],
    "śvayūthya": ['mw'],
    "śvañc": ['cae', 'ddsa', 'gra', 'mw'],
    "śvañj": ['mw'],
    "śvaśrū": ['cae', 'ddsa', 'gra', 'mw'],
    "śvaśrūsnuṣā": ['cae', 'mw'],
    "śvaśrūsnuṣādhanasaṃvāda": ['mw'],
    "śvaśrūśvaśura": ['mw'],
    "śvaśrūḥ": ['ap90'],
    "śvaśura": ['cae', 'ddsa', 'gra', 'mw'],
    "śvaśuraka": ['mw'],
    "śvaśurakaḥ": ['ap90'],
    "śvaśuraḥ": ['ap90'],
    "śvaśurya": ['cae', 'ddsa', 'mw'],
    "śvaśuryaḥ": ['ap90'],
    "śvaśurī": ['mw'],
    "śvaśurīya": ['mw'],
    "śvaśīrṣa": ['mw'],
    "śvaḥ": ['mw'],
    "śvaḥkraya": ['mw'],
    "śvaḥkāla": ['cae', 'mw'],
    "śvaḥkāle": ['mw'],
    "śvaḥprabhṛti": ['mw'],
    "śvaḥstotriya": ['mw'],
    "śvaḥsutyā": ['cae', 'ddsa', 'mw'],
    "śvaḥśreyasa": ['mw'],
    "śvaḥśva": ['cae', 'mw'],
    "śvaṃk": ['ap90'],
    "śvaṃṭh": ['ap90'],
    "śvaṅg": ['mw'],
    "śvaṅk": ['mw'],
    "śvaṇṭh": ['mw'],
    "śvaṭh": ['ap90', 'mw'],
    "śvaṭha": ['mw'],
    "śvelu": ['bhs'],
    "śvelā": ['bhs'],
    "śveta": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śvetabalā": ['mw'],
    "śvetabarbara": ['mw'],
    "śvetabhadra": ['bhs', 'mw'],
    "śvetabhasman": ['mw'],
    "śvetabhaṇḍā": ['mw'],
    "śvetabhikṣu": ['mw'],
    "śvetabhiṇḍā": ['mw'],
    "śvetabhujaṃga": ['mw'],
    "śvetabhānu": ['cae', 'mw'],
    "śvetabindukā": ['mw'],
    "śvetabuhnā": ['mw'],
    "śvetabṛhatī": ['mw'],
    "śvetacampaka": ['mw'],
    "śvetacandana": ['mw'],
    "śvetacaraṇa": ['mw'],
    "śvetacchada": ['mw'],
    "śvetacchattra": ['cae', 'mw'],
    "śvetacchattrin": ['mw'],
    "śvetacchattrāya": ['mw'],
    "śvetacillikā": ['mw'],
    "śvetacillī": ['mw'],
    "śvetacintāmaṇi": ['mw'],
    "śvetadhāman": ['mw'],
    "śvetadhātu": ['mw'],
    "śvetadruma": ['mw'],
    "śvetadvipa": ['mw'],
    "śvetadvīpa": ['cae', 'mw'],
    "śvetadvīpāya": ['mw'],
    "śvetadyuti": ['mw'],
    "śvetadūrvā": ['mw'],
    "śvetagaja": ['mw'],
    "śvetagarut": ['mw'],
    "śvetagaruta": ['mw'],
    "śvetagaṅgā": ['mw'],
    "śvetaghaṇṭā": ['mw'],
    "śvetaghaṇṭī": ['mw'],
    "śvetaghoṣā": ['mw'],
    "śvetagiri": ['mw'],
    "śvetagirimāhātmya": ['mw'],
    "śvetagodhūma": ['mw'],
    "śvetagokarṇī": ['mw'],
    "śvetaguñjā": ['mw'],
    "śvetaguṇavat": ['mw'],
    "śvetahanu": ['mw'],
    "śvetahastin": ['mw'],
    "śvetahaya": ['mw'],
    "śvetahūṇa": ['mw'],
    "śvetairaṇḍa": ['mw'],
    "śvetajala": ['mw'],
    "śvetajīraka": ['mw'],
    "śvetaka": ['bhs', 'mw'],
    "śvetakalpa": ['mw'],
    "śvetakamala": ['mw'],
    "śvetakanda": ['mw'],
    "śvetakandā": ['mw'],
    "śvetakapota": ['mw'],
    "śvetakarṇa": ['mw'],
    "śvetakaḥ": ['ap90'],
    "śvetakaṇṭakārī": ['mw'],
    "śvetakaṇṭhin": ['mw'],
    "śvetaketu": ['bhs', 'cae', 'mw'],
    "śvetakeśa": ['mw'],
    "śvetakhadira": ['mw'],
    "śvetaki": ['mw'],
    "śvetakiṇihī": ['mw'],
    "śvetakola": ['mw'],
    "śvetakolaka": ['mw'],
    "śvetakukṣi": ['mw'],
    "śvetakuñjara": ['mw'],
    "śvetakuśa": ['mw'],
    "śvetakuṣṭha": ['mw'],
    "śvetakuṣṭhatva": ['mw'],
    "śvetakāka": ['cae', 'mw'],
    "śvetakākīya": ['ddsa', 'mw'],
    "śvetakāmbojī": ['mw'],
    "śvetakāpotī": ['mw'],
    "śvetakāṇḍā": ['mw'],
    "śvetakṛṣṇā": ['mw'],
    "śvetakṣāra": ['mw'],
    "śvetalodhra": ['mw'],
    "śvetalohita": ['mw'],
    "śvetamadhya": ['mw'],
    "śvetamahoṭikā": ['mw'],
    "śvetamandāra": ['mw'],
    "śvetamandāraka": ['mw'],
    "śvetamarica": ['mw'],
    "śvetamayūkha": ['mw'],
    "śvetamaṇḍala": ['mw'],
    "śvetameha": ['mw'],
    "śvetamoda": ['mw'],
    "śvetamādhava": ['mw'],
    "śvetamādhavatīrtha": ['mw'],
    "śvetamāla": ['mw'],
    "śvetamāṇḍavya": ['mw'],
    "śvetamūla": ['mw'],
    "śvetamūlā": ['mw'],
    "śvetamūtra": ['mw'],
    "śvetamūtratā": ['mw'],
    "śvetamṛd": ['mw'],
    "śvetanyaṅga": ['mw'],
    "śvetanā": ['cae', 'ddsa', 'gra', 'mw'],
    "śvetanāman": ['mw'],
    "śvetanīla": ['mw'],
    "śvetapadma": ['mw'],
    "śvetapakṣa": ['cae', 'ddsa', 'mw'],
    "śvetaparvata": ['mw'],
    "śvetaparṇa": ['mw'],
    "śvetaparṇā": ['mw'],
    "śvetaparṇāsa": ['mw'],
    "śvetapattra": ['mw'],
    "śvetapattraratha": ['mw'],
    "śvetapattrā": ['mw'],
    "śvetapaṭa": ['bhs', 'mw'],
    "śvetaphalā": ['mw'],
    "śvetapiṅga": ['mw'],
    "śvetapiṅgala": ['mw'],
    "śvetapiṅgalaka": ['mw'],
    "śvetapiṇḍītaka": ['mw'],
    "śvetaprasūnaka": ['mw'],
    "śvetapunarnavā": ['mw'],
    "śvetapuṅkhā": ['mw'],
    "śvetapuṣpa": ['cae', 'mw'],
    "śvetapuṣpaka": ['mw'],
    "śvetapuṣpikā": ['mw'],
    "śvetapuṣpā": ['mw'],
    "śvetapuṣpī": ['mw'],
    "śvetapāda": ['mw'],
    "śvetapākī": ['mw'],
    "śvetapāṭalā": ['mw'],
    "śvetapītala": ['mw'],
    "śvetarakta": ['mw'],
    "śvetarasa": ['mw'],
    "śvetaratha": ['mw'],
    "śvetarañjana": ['mw'],
    "śvetaraśmi": ['mw'],
    "śvetarocis": ['mw'],
    "śvetarohita": ['mw'],
    "śvetaroman": ['mw'],
    "śvetaromāṅka": ['mw'],
    "śvetarājī": ['mw'],
    "śvetarāsnā": ['mw'],
    "śvetarāvaka": ['mw'],
    "śvetarūpya": ['mw'],
    "śvetasarpa": ['mw'],
    "śvetasarṣapa": ['mw'],
    "śvetasiddha": ['mw'],
    "śvetasiṃhī": ['mw'],
    "śvetaspandā": ['mw'],
    "śvetasurasā": ['mw'],
    "śvetasāra": ['mw'],
    "śvetatantrī": ['mw'],
    "śvetatapas": ['mw'],
    "śvetatara": ['mw'],
    "śvetataṇḍula": ['mw'],
    "śvetatā": ['mw'],
    "śvetauhī": ['ap90', 'mw'],
    "śvetavacā": ['mw'],
    "śvetavah": ['mw'],
    "śvetavaktra": ['mw'],
    "śvetavalkala": ['mw'],
    "śvetavalākā": ['bhs'],
    "śvetavarṇa": ['mw'],
    "śvetavarṇā": ['bhs', 'mw'],
    "śvetavastrin": ['mw'],
    "śvetavatsā": ['cae', 'mw'],
    "śvetavrata": ['mw'],
    "śvetavāh": ['mw'],
    "śvetavāha": ['cae', 'mw'],
    "śvetavāhana": ['cae', 'mw'],
    "śvetavāhin": ['mw'],
    "śvetavāhī": ['mw'],
    "śvetavājin": ['mw'],
    "śvetavārija": ['mw'],
    "śvetavārttākī": ['mw'],
    "śvetavārāha": ['mw'],
    "śvetavārāhakalpa": ['mw'],
    "śvetavārāhatīrtha": ['mw'],
    "śvetavāsas": ['mw'],
    "śvetavṛkṣa": ['mw'],
    "śvetaya": ['mw'],
    "śvetayat": ['mw'],
    "śvetayāvan": ['gra'],
    "śvetayāvarī": ['mw'],
    "śvetaśaila": ['mw'],
    "śvetaśailamaya": ['mw'],
    "śvetaśarapuṅkhā": ['mw'],
    "śvetaśigru": ['mw'],
    "śvetaśikha": ['mw'],
    "śvetaśimbikā": ['mw'],
    "śvetaśiṃśapā": ['mw'],
    "śvetaśuṅga": ['mw'],
    "śvetaśyāma": ['mw'],
    "śvetaśāla": ['mw'],
    "śvetaśīrṣa": ['mw'],
    "śvetaśūraṇa": ['mw'],
    "śvetaśṛṅga": ['mw'],
    "śvetaṭaṅkaka": ['mw'],
    "śvetaṭaṅkaṇa": ['mw'],
    "śvetekṣu": ['mw'],
    "śvetia": ['gra'],
    "śvetika": ['ddsa', 'mw'],
    "śvetikā": ['bhs'],
    "śvetiman": ['cae', 'mw'],
    "śvetita": ['mw'],
    "śvetodara": ['mw'],
    "śvetopakāśa": ['mw'],
    "śvetotpala": ['mw'],
    "śvetra": ['mw'],
    "śvetraṃ": ['ap90'],
    "śveturāṣṭra": ['bhs'],
    "śvetya": ['cae', 'ddsa', 'gra', 'mw'],
    "śvetyā": ['mw'],
    "śvetā": ['ap90', 'ddsa', 'mw'],
    "śvetādri": ['mw'],
    "śvetādrivāsāṣṭaka": ['mw'],
    "śvetāhvā": ['mw'],
    "śvetākṣa": ['mw'],
    "śvetāmbara": ['cae', 'mw'],
    "śvetāmbaracandra": ['mw'],
    "śvetāmlī": ['mw'],
    "śvetānukāśa": ['mw'],
    "śvetānulepana": ['mw'],
    "śvetānūkāśa": ['mw'],
    "śvetāparājitakalpa": ['mw'],
    "śvetāraṇya": ['mw'],
    "śvetāraṇyamāhātmya": ['mw'],
    "śvetārcis": ['cae', 'ddsa', 'mw'],
    "śvetārdhavaktra": ['mw'],
    "śvetārka": ['mw'],
    "śvetārkakalpa": ['mw'],
    "śvetāsthi": ['bhs', 'mw'],
    "śvetāsya": ['mw'],
    "śvetātapatra": ['mw'],
    "śvetātapatrāya": ['mw'],
    "śvetātreya": ['mw'],
    "śvetātrivṛt": ['mw'],
    "śvetāvara": ['mw'],
    "śvetāy": ['cae'],
    "śvetāya": ['ddsa', 'mw'],
    "śvetāyin": ['mw'],
    "śvetāñjana": ['mw'],
    "śvetāśva": ['cae', 'mw'],
    "śvetāśvadānavidhi": ['mw'],
    "śvetāśvatara": ['cae', 'mw'],
    "śvetāśvataraśākhin": ['mw'],
    "śvetāśvataraśākhā": ['mw'],
    "śvetāśvataropaniṣad": ['cae', 'mw'],
    "śvetāśvataropaniṣaddīpikā": ['mw'],
    "śvetāśvataropaniṣatprakāśikā": ['mw'],
    "śvetāśvā": ['mw'],
    "śvetāṃśu": ['cae', 'ddsa', 'mw'],
    "śvetāṃśuka": ['mw'],
    "śvetāṇḍa": ['mw'],
    "śvetī": ['mw'],
    "śvi": ['ap90', 'ddsa', 'mw'],
    "śvikna": ['cae', 'mw'],
    "śvind": ['ddsa', 'mw'],
    "śvit": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śvita": ['ap90', 'mw'],
    "śviti": ['mw'],
    "śvitiḥ": ['ap90'],
    "śvitna": ['cae', 'gra', 'mw'],
    "śvitnia": ['gra'],
    "śvitnya": ['cae', 'gra', 'mw'],
    "śvitra": ['cae', 'ddsa', 'gra', 'mw'],
    "śvitraghnī": ['mw'],
    "śvitrahara": ['mw'],
    "śvitraṃ": ['ap90'],
    "śvitria": ['gra'],
    "śvitrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śvitropakāśa": ['mw'],
    "śvitrya": ['gra', 'mw'],
    "śvitrā": ['mw'],
    "śvitya": ['ap90', 'mw'],
    "śvityac": ['gra'],
    "śvityañc": ['cae', 'mw'],
    "śvityañca": ['ddsa'],
    "śvitāna": ['ap90', 'mw'],
    "śvitīci": ['cae', 'gra', 'mw'],
    "śviṃd": ['ap90'],
    "śvm, śvi": ['ddsa'],
    "śvo": ['mw'],
    "śvobhāva": ['cae', 'ddsa', 'mw'],
    "śvobhāvin": ['cae', 'mw'],
    "śvobhūta": ['cae', 'mw'],
    "śvobhūti": ['mw'],
    "śvomaraṇa": ['mw'],
    "śvovasyasa": ['cae', 'mw'],
    "śvovasīya": ['cae', 'mw'],
    "śvovasīyas": ['mw'],
    "śvovasīyasa": ['cae', 'mw'],
    "śvovijayin": ['cae', 'mw'],
    "śvā": ['cae', 'gra', 'mw'],
    "śvābhastra": ['mw'],
    "śvābhastri": ['mw'],
    "śvāda": ['mw'],
    "śvādanta": ['mw'],
    "śvādaṃtaḥ": ['ap90'],
    "śvādaṃṣṭra": ['mw'],
    "śvādaṃṣṭṛ": ['mw'],
    "śvāgaṇika": ['mw'],
    "śvāgaṇikaḥ": ['ap90'],
    "śvāghnikaḥ": ['ap90'],
    "śvāgra": ['cae', 'ddsa', 'mw'],
    "śvāhi": ['mw'],
    "śvājani": ['mw'],
    "śvājina": ['cae', 'mw'],
    "śvākarṇa": ['mw'],
    "śvākarṇaḥ": ['ap90'],
    "śvākunda": ['mw'],
    "śvāna": ['cae', 'ddsa', 'mw'],
    "śvānacillikā": ['mw'],
    "śvānala": ['mw'],
    "śvānanidrā": ['mw'],
    "śvānavaikharī": ['mw'],
    "śvānaḥ": ['ap90'],
    "śvānocchiṣṭa": ['mw'],
    "śvānta": ['cae', 'ddsa', 'gra', 'mw'],
    "śvānī": ['mw'],
    "śvāpad": ['cae', 'mw'],
    "śvāpada": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śvāpadarājan": ['mw'],
    "śvāpadasevita": ['mw'],
    "śvāpadācarita": ['mw'],
    "śvāpadānusaraṇa": ['mw'],
    "śvāphalka": ['mw'],
    "śvāphalkacaitraka": ['mw'],
    "śvāphalki": ['mw'],
    "śvāpuccha": ['mw'],
    "śvāpucchaḥ": ['ap90'],
    "śvāpākaka": ['mw'],
    "śvāsa": ['bhs', 'cae', 'ddsa', 'mw'],
    "śvāsadhāraṇa": ['mw'],
    "śvāsaheti": ['mw'],
    "śvāsahikkin": ['mw'],
    "śvāsahikkā": ['mw'],
    "śvāsakarmaprakāśa": ['mw'],
    "śvāsakuṭhāra": ['mw'],
    "śvāsakāsa": ['mw'],
    "śvāsakāsin": ['mw'],
    "śvāsapraśvāsadhāraṇa": ['mw'],
    "śvāsarodha": ['mw'],
    "śvāsatā": ['mw'],
    "śvāsaviṣa": ['bhs'],
    "śvāsaśeṣa": ['mw'],
    "śvāsaḥ": ['ap90'],
    "śvāsika": ['mw'],
    "śvāsin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śvāsita": ['mw'],
    "śvāsocchvāsa": ['mw'],
    "śvāsopavāsaka": ['bhs'],
    "śvāsā": ['mw'],
    "śvāsākula": ['mw'],
    "śvāsānila": ['mw'],
    "śvāsāri": ['mw'],
    "śvātr": ['mw'],
    "śvātra": ['cae', 'ddsa', 'gra', 'mw'],
    "śvātrabhāj": ['gra', 'mw'],
    "śvātram": ['mw'],
    "śvātria": ['gra'],
    "śvātrya": ['cae', 'gra', 'mw'],
    "śvāvarāha": ['mw'],
    "śvāvarāhikā": ['mw'],
    "śvāvic": ['mw'],
    "śvāvicchalalita": ['mw'],
    "śvāviccharaṇa": ['mw'],
    "śvāvid": ['mw'],
    "śvāvidgarta": ['mw'],
    "śvāvidgartīya": ['mw'],
    "śvāvidh": ['ap90', 'cae', 'ddsa', 'mw'],
    "śvāvidha": ['mw'],
    "śvāvidroman": ['mw'],
    "śvāvil": ['mw'],
    "śvāvilloman": ['mw'],
    "śvāvillomāpaha": ['mw'],
    "śvāvillomāpanayana": ['mw'],
    "śvāyūthika": ['mw'],
    "śvāśura": ['cae', 'ddsa', 'mw'],
    "śvāśuri": ['mw'],
    "śvāśurya": ['ddsa', 'mw'],
    "śvāśva": ['mw'],
    "śyai": ['ap90', 'mw'],
    "śyaina": ['mw'],
    "śyainampāta": ['mw'],
    "śyainaṃpātā": ['ap90'],
    "śyaineya": ['ddsa', 'mw'],
    "śyainika": ['mw'],
    "śyaita": ['ddsa', 'mw'],
    "śyan": ['mw'],
    "śyena": ['cae', 'ddsa', 'gra', 'mw'],
    "śyenabhṛta": ['cae', 'mw'],
    "śyenabṛhat": ['mw'],
    "śyenacit": ['mw'],
    "śyenacita": ['mw'],
    "śyenacitra": ['mw'],
    "śyenaghaṇṭā": ['mw'],
    "śyenagāmin": ['mw'],
    "śyenahṛta": ['cae', 'mw'],
    "śyenajidākhyāna": ['mw'],
    "śyenajit": ['mw'],
    "śyenajīvin": ['cae', 'mw'],
    "śyenajūta": ['cae', 'gra', 'mw'],
    "śyenakapotīya": ['mw'],
    "śyenakaraṇa": ['mw'],
    "śyenapattra": ['cae', 'mw'],
    "śyenapattvan": ['cae'],
    "śyenapatvan": ['gra', 'mw'],
    "śyenapāta": ['mw'],
    "śyenavṛṣaka": ['mw'],
    "śyenayāga": ['mw'],
    "śyenaḥ": ['ap90'],
    "śyenikā": ['mw'],
    "śyenopadeśa": ['mw'],
    "śyenā": ['mw'],
    "śyenābhṛta": ['cae', 'gra', 'mw'],
    "śyenāhṛta": ['mw'],
    "śyenākhya": ['mw'],
    "śyenāvapātam": ['mw'],
    "śyenāśvaśyaina": ['mw'],
    "śyenāśvaśyena": ['mw'],
    "śyenī": ['cae', 'ddsa', 'mw'],
    "śyeta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śyetakolaka": ['mw'],
    "śyetākṣa": ['cae', 'mw'],
    "śyetīkṛ": ['mw'],
    "śyonāka": ['mw'],
    "śyoṇāka": ['mw'],
    "śyoṇākaḥ": ['ap90'],
    "śyā": ['cae', 'ddsa', 'gra'],
    "śyāla": ['cae', 'ddsa', 'mw'],
    "śyālakaḥ": ['ap90'],
    "śyālakī": ['ap90'],
    "śyālaḥ": ['ap90'],
    "śyāma": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śyāmabhaṭṭa": ['mw'],
    "śyāmabhās": ['mw'],
    "śyāmacaṭaka": ['mw'],
    "śyāmadeva": ['mw'],
    "śyāmadāsa": ['mw'],
    "śyāmagranthi": ['mw'],
    "śyāmajayanta": ['mw'],
    "śyāmajit": ['mw'],
    "śyāmajātaka": ['bhs'],
    "śyāmaka": ['cae', 'mw'],
    "śyāmakandā": ['mw'],
    "śyāmakarṇa": ['mw'],
    "śyāmakaḥ": ['ap90'],
    "śyāmakaṅgu": ['mw'],
    "śyāmakaṇṭha": ['mw'],
    "śyāmakāṇḍā": ['mw'],
    "śyāmala": ['ap90', 'cae', 'ddsa', 'mw'],
    "śyāmalacūḍā": ['mw'],
    "śyāmaladevī": ['mw'],
    "śyāmalaka": ['cae', 'mw'],
    "śyāmalakacūḍā": ['mw'],
    "śyāmalatva": ['mw'],
    "śyāmalatā": ['ddsa', 'mw'],
    "śyāmalekṣu": ['mw'],
    "śyāmalikā": ['ap90', 'mw'],
    "śyāmaliman": ['ap90', 'cae', 'mw'],
    "śyāmalita": ['cae', 'ddsa', 'mw'],
    "śyāmalā": ['mw'],
    "śyāmalādaṇḍaka": ['mw'],
    "śyāmalāgītā": ['mw'],
    "śyāmalāmantrasādhana": ['mw'],
    "śyāmalāmbāstotra": ['mw'],
    "śyāmalānavaratna": ['mw'],
    "śyāmalārahasya": ['mw'],
    "śyāmalāsahasranāman": ['mw'],
    "śyāmalāṅgī": ['mw'],
    "śyāmalāṣṭaka": ['mw'],
    "śyāmalī": ['mw'],
    "śyāmalīkṛ": ['cae', 'mw'],
    "śyāmamukha": ['cae', 'mw'],
    "śyāmapattra": ['mw'],
    "śyāmaphena": ['mw'],
    "śyāmaphenatā": ['mw'],
    "śyāmaruci": ['mw'],
    "śyāmasujayanta": ['mw'],
    "śyāmasundara": ['mw'],
    "śyāmasāhśaṃkara": ['mw'],
    "śyāmasāra": ['mw'],
    "śyāmatva": ['mw'],
    "śyāmatā": ['cae', 'mw'],
    "śyāmavallī": ['mw'],
    "śyāmavarṇa": ['cae', 'ddsa', 'mw'],
    "śyāmavarṇatva": ['mw'],
    "śyāmavrata": ['mw'],
    "śyāmaśabala": ['cae', 'mw'],
    "śyāmaśavala": ['bhs'],
    "śyāmaśiṃśapā": ['mw'],
    "śyāmekṣu": ['mw'],
    "śyāmeya": ['mw'],
    "śyāmikā": ['ap90', 'bhs', 'ddsa', 'mw'],
    "śyāmita": ['ap90', 'cae', 'ddsa', 'mw'],
    "śyāmā": ['ap90', 'bhs', 'ddsa', 'mw'],
    "śyāmācara": ['mw'],
    "śyāmācāratantra": ['mw'],
    "śyāmācārya": ['mw'],
    "śyāmādevī": ['bhs', 'mw'],
    "śyāmādīpadāna": ['mw'],
    "śyāmāka": ['bhs', 'cae', 'ddsa', 'mw'],
    "śyāmākajātaka": ['bhs'],
    "śyāmākalpalatikā": ['mw'],
    "śyāmākalpalatā": ['mw'],
    "śyāmākamuṣṭimpaca": ['mw'],
    "śyāmākataṇḍula": ['mw'],
    "śyāmākaudana": ['mw'],
    "śyāmākavaca": ['mw'],
    "śyāmākaḥ": ['ap90'],
    "śyāmākeṣṭi": ['mw'],
    "śyāmākāgrayaṇa": ['mw'],
    "śyāmākāgrayaṇeṣṭi": ['mw'],
    "śyāmālatā": ['mw'],
    "śyāmāmantra": ['mw'],
    "śyāmāmlī": ['mw'],
    "śyāmāmānasārcana": ['mw'],
    "śyāmānityapūjāpaddhati": ['mw'],
    "śyāmāpaddhati": ['mw'],
    "śyāmāpradīpa": ['mw'],
    "śyāmāprakaraṇa": ['mw'],
    "śyāmāprayogavidhi": ['mw'],
    "śyāmāpūjā": ['mw'],
    "śyāmāpūjāpaddhati": ['mw'],
    "śyāmārahasya": ['mw'],
    "śyāmāratna": ['mw'],
    "śyāmārcanacandrikā": ['mw'],
    "śyāmāruta": ['mw'],
    "śyāmāruṇa": ['mw'],
    "śyāmārya": ['mw'],
    "śyāmāsahasranāman": ['mw'],
    "śyāmāsaparyākrama": ['mw'],
    "śyāmāsaparyāvidhi": ['mw'],
    "śyāmāstotra": ['mw'],
    "śyāmātāpanyupaniṣad": ['mw'],
    "śyāmāvadāta": ['cae', 'mw'],
    "śyāmāvartā": ['bhs'],
    "śyāmāvatī": ['bhs', 'mw'],
    "śyāmāy": ['cae'],
    "śyāmāya": ['ddsa', 'mw'],
    "śyāmāyana": ['mw'],
    "śyāmāyani": ['mw'],
    "śyāmāyanin": ['mw'],
    "śyāmāyanīya": ['mw'],
    "śyāmāyate": ['ap90'],
    "śyāmāṅga": ['mw'],
    "śyāmāṅgī": ['mw'],
    "śyāmī": ['mw'],
    "śyāmībhū": ['mw'],
    "śyāmīkṛ": ['cae', 'ddsa', 'mw'],
    "śyāna": ['ap90', 'cae', 'mw'],
    "śyānapulina": ['mw'],
    "śyāparṇa": ['cae', 'ddsa', 'mw'],
    "śyāparṇeya": ['mw'],
    "śyāparṇīya": ['mw'],
    "śyāpīya": ['mw'],
    "śyāva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śyāvaaśva": ['gra'],
    "śyāvaaśvastuta": ['gra'],
    "śyāvada": ['mw'],
    "śyāvadant": ['cae', 'ddsa'],
    "śyāvadanta": ['cae', 'mw'],
    "śyāvadantaka": ['cae', 'mw'],
    "śyāvadantatā": ['mw'],
    "śyāvadat": ['mw'],
    "śyāvaka": ['gra', 'mw'],
    "śyāvala": ['mw'],
    "śyāvali": ['mw'],
    "śyāvanāya": ['mw'],
    "śyāvanāyya": ['mw'],
    "śyāvanāyīya": ['mw'],
    "śyāvaputra": ['mw'],
    "śyāvaputrya": ['mw'],
    "śyāvaratha": ['mw'],
    "śyāvarathya": ['mw'],
    "śyāvataila": ['mw'],
    "śyāvatā": ['mw'],
    "śyāvavartman": ['mw'],
    "śyāvaya": ['mw'],
    "śyāviā": ['gra'],
    "śyāvyā": ['cae', 'gra', 'mw'],
    "śyāvākṣa": ['cae', 'mw'],
    "śyāvāsya": ['mw'],
    "śyāvāsyatā": ['mw'],
    "śyāvāśva": ['cae', 'ddsa', 'gra', 'mw'],
    "śyāvāśvastuta": ['gra', 'mw'],
    "śyāvāśvi": ['mw'],
    "śyāvī": ['gra', 'mw'],
    "śā": ['cae', 'ddsa', 'gra'],
    "śāba": ['cae', 'mw'],
    "śābalya": ['cae', 'ddsa', 'mw'],
    "śābalyā": ['mw'],
    "śābalīya": ['mw'],
    "śābara": ['ap90', 'cae', 'mw'],
    "śābarabhedākhya": ['mw'],
    "śābarabhāṣya": ['mw'],
    "śābaracintāmaṇi": ['mw'],
    "śābarajambuka": ['mw'],
    "śābaraka": ['mw'],
    "śābarakaustubha": ['mw'],
    "śābaramahātantra": ['mw'],
    "śābaratantra": ['mw'],
    "śābaratantrasarvasva": ['mw'],
    "śābari": ['mw'],
    "śābarikā": ['cae', 'ddsa', 'mw'],
    "śābaropaniṣad": ['mw'],
    "śābarotsava": ['mw'],
    "śābarāyaṇa": ['mw'],
    "śābarī": ['mw'],
    "śābasta": ['mw'],
    "śābasti": ['mw'],
    "śābastī": ['mw'],
    "śābda": ['ap90', 'cae', 'ddsa', 'mw'],
    "śābdabodha": ['mw'],
    "śābdabodhataraṃgiṇī": ['mw'],
    "śābdaprakriyā": ['mw'],
    "śābdatva": ['mw'],
    "śābdavyañjanā": ['mw'],
    "śābdika": ['ap90', 'cae', 'mw'],
    "śābdikacintāmaṇi": ['mw'],
    "śābdikanarasiṃha": ['mw'],
    "śābdikarakṣā": ['mw'],
    "śābdikavidvatkavipramodaka": ['mw'],
    "śābdikābharaṇa": ['mw'],
    "śābdī": ['mw'],
    "śābrarī": ['ddsa'],
    "śābulyā": ['mw'],
    "śābīya": ['mw'],
    "śāci": ['ap90', 'cae', 'mw'],
    "śācigu": ['cae', 'gra', 'mw'],
    "śācipūjana": ['gra', 'mw'],
    "śāda": ['cae', 'ddsa', 'gra', 'mw'],
    "śādaharita": ['mw'],
    "śādana": ['cae'],
    "śādaḥ": ['ap90'],
    "śādvala": ['ap90', 'cae', 'ddsa', 'mw'],
    "śādvalasthalī": ['mw'],
    "śādvalavant": ['cae'],
    "śādvalavat": ['mw'],
    "śādvalin": ['cae', 'mw'],
    "śādvalita": ['mw'],
    "śādvalā": ['bhs'],
    "śādvalābha": ['mw'],
    "śādā": ['mw'],
    "śāha": ['ddsa', 'mw'],
    "śāhajī": ['mw'],
    "śāheva": ['mw'],
    "śāheśa": ['mw'],
    "śāhi": ['mw'],
    "śāhimakaranda": ['mw'],
    "śāhnāma": ['mw'],
    "śāhājyāhām": ['mw'],
    "śāka": ['cae', 'ddsa', 'gra', 'mw'],
    "śākabhakṣa": ['ddsa', 'mw'],
    "śākabhakṣatā": ['mw'],
    "śākabhava": ['mw'],
    "śākabilva": ['mw'],
    "śākabilvaka": ['mw'],
    "śākabāleya": ['mw'],
    "śākacukrikā": ['mw'],
    "śākadvīpa": ['mw'],
    "śākadvīpīya": ['mw'],
    "śākadāsa": ['mw'],
    "śākadīkṣā": ['mw'],
    "śākahāra": ['mw'],
    "śākajagdha": ['mw'],
    "śākajambu": ['mw'],
    "śākajambuka": ['mw'],
    "śākajañjabha": ['mw'],
    "śākakalambaka": ['mw'],
    "śākakāla": ['cae', 'mw'],
    "śākala": ['ap90', 'cae', 'ddsa', 'mw'],
    "śākalahoma": ['cae', 'mw'],
    "śākalahomīya": ['mw'],
    "śākalaka": ['mw'],
    "śākalaprātiśākhya": ['mw'],
    "śākalasaṃhitā": ['mw'],
    "śākalasmṛti": ['mw'],
    "śākalaśākhā": ['mw'],
    "śākali": ['mw'],
    "śākalika": ['ap90', 'mw'],
    "śākalin": ['mw'],
    "śākalya": ['cae', 'ddsa', 'mw'],
    "śākalyacarita": ['mw'],
    "śākalyamata": ['mw'],
    "śākalyapalya": ['mw'],
    "śākalyapitṛ": ['mw'],
    "śākalyasaṃhitā": ['mw'],
    "śākalyasaṃhitāpariśiṣṭa": ['mw'],
    "śākalyaḥ": ['ap90'],
    "śākalyāyanī": ['mw'],
    "śākambharī": ['mw'],
    "śākambharīya": ['mw'],
    "śākamṛṣa": ['mw'],
    "śākandhavya": ['mw'],
    "śākanighaṇṭu": ['mw'],
    "śākapattra": ['mw'],
    "śākapaṇa": ['mw'],
    "śākapiṇḍī": ['mw'],
    "śākapota": ['mw'],
    "śākaprabandha": ['bhs'],
    "śākaprati": ['mw'],
    "śākapārthiva": ['mw'],
    "śākapārthiva*": ['ddsa'],
    "śākapātra": ['mw'],
    "śākapūṇi": ['cae', 'ddsa', 'mw'],
    "śākapūṇiḥ": ['ap90'],
    "śākaracita": ['mw'],
    "śākarasa": ['mw'],
    "śākarasīkṛ": ['mw'],
    "śākarāj": ['mw'],
    "śākarāja": ['mw'],
    "śākarī": ['ap90', 'mw'],
    "śākataru": ['mw'],
    "śākavarṇa": ['mw'],
    "śākavindaka": ['mw'],
    "śākaviḍambaka": ['mw'],
    "śākavrata": ['mw'],
    "śākavāṭa": ['cae', 'ddsa', 'mw'],
    "śākavāṭaka": ['mw'],
    "śākavāṭikā": ['mw'],
    "śākavīra": ['mw'],
    "śākavṛkṣa": ['mw'],
    "śākavṛṣa": ['mw'],
    "śākayogya": ['mw'],
    "śākaśreṣṭha": ['mw'],
    "śākaśreṣṭhā": ['mw'],
    "śākaśākaṭa": ['mw'],
    "śākaśākina": ['mw'],
    "śākaḥ": ['ap90'],
    "śākaṃbharī": ['ap90'],
    "śākaṃdheya": ['mw'],
    "śākaṭa": ['ap90', 'mw'],
    "śākaṭapotikā": ['mw'],
    "śākaṭika": ['ap90', 'ddsa', 'mw'],
    "śākaṭākhya": ['mw'],
    "śākaṭāyana": ['cae', 'ddsa', 'mw'],
    "śākaṭāyanasmṛti": ['mw'],
    "śākaṭāyanavyākaraṇa": ['mw'],
    "śākaṭāyanaḥ": ['ap90'],
    "śākaṭāyani": ['mw'],
    "śākaṭāyanopaniṣadbhāṣya": ['mw'],
    "śākaṭīkarṇa": ['mw'],
    "śākaṭīna": ['mw'],
    "śākaṭīnaḥ": ['ap90'],
    "śākekṣu": ['mw'],
    "śākendra": ['mw'],
    "śākeya": ['mw'],
    "śākh": ['ap90', 'mw'],
    "śākha": ['ddsa', 'mw'],
    "śākhaḥ": ['ap90'],
    "śākhi": ['mw'],
    "śākhila": ['mw'],
    "śākhin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śākhoṭa": ['ddsa', 'mw'],
    "śākhoṭaka": ['mw'],
    "śākhoṭaḥ": ['ap90'],
    "śākhya": ['mw'],
    "śākhā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śākhābheda": ['cae', 'mw'],
    "śākhābhṛt": ['mw'],
    "śākhābāhu": ['cae', 'mw'],
    "śākhācandranyāya": ['mw'],
    "śākhācaṅkramaṇa": ['mw'],
    "śākhāda": ['mw'],
    "śākhādaṇḍa": ['mw'],
    "śākhādhyetṛ": ['mw'],
    "śākhākaṇṭa": ['mw'],
    "śākhāla": ['mw'],
    "śākhālaḥ": ['ap90'],
    "śākhāmaya": ['cae', 'mw'],
    "śākhāmlā": ['mw'],
    "śākhāmṛga": ['cae', 'mw'],
    "śākhāmṛgagaṇāyuta": ['mw'],
    "śākhāmṛgatva": ['mw'],
    "śākhāmṛgānīkapati": ['mw'],
    "śākhānagara": ['mw'],
    "śākhānagaraka": ['mw'],
    "śākhāntaga": ['cae', 'mw'],
    "śākhāntara": ['mw'],
    "śākhāntarīya": ['mw'],
    "śākhāntarīyakarman": ['mw'],
    "śākhāntika": ['bhs'],
    "śākhāpavitra": ['mw'],
    "śākhāpaśu": ['mw'],
    "śākhāpitta": ['mw'],
    "śākhāprakṛti": ['mw'],
    "śākhāpura": ['mw'],
    "śākhāpurī": ['mw'],
    "śākhāpuṣpapalāśavat": ['mw'],
    "śākhārathyā": ['mw'],
    "śākhāraṇḍa": ['mw'],
    "śākhāsamāna": ['mw'],
    "śākhāskandha": ['mw'],
    "śākhāstha": ['mw'],
    "śākhāsthi": ['mw'],
    "śākhāvilīna": ['mw'],
    "śākhāvāta": ['mw'],
    "śākhāśiphā": ['mw'],
    "śākhāśraya": ['mw'],
    "śākhāṅga": ['cae', 'ddsa', 'mw'],
    "śākhīya": ['cae', 'mw'],
    "śākin": ['cae', 'ddsa', 'gra', 'mw'],
    "śākina": ['cae', 'gra', 'mw'],
    "śākinaṃ": ['ap90'],
    "śākinikā": ['mw'],
    "śākinī": ['ap90', 'ddsa', 'mw'],
    "śākiya": ['bhs'],
    "śākiyānī": ['bhs'],
    "śākkara": ['mw'],
    "śākkaraḥ": ['ap90'],
    "śākkī": ['mw'],
    "śākman": ['cae', 'ddsa', 'gra', 'mw'],
    "śākola": ['mw'],
    "śākoṭa": ['mw'],
    "śākoṭaka": ['mw'],
    "śākra": ['cae', 'ddsa', 'mw'],
    "śākrī": ['ap90', 'mw'],
    "śākrīya": ['mw'],
    "śākrīyadiś": ['mw'],
    "śākta": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śāktabhāṣya": ['mw'],
    "śāktakrama": ['mw'],
    "śāktamataratnasūtradīpikā": ['mw'],
    "śāktasarvasva": ['mw'],
    "śāktatantra": ['mw'],
    "śākteya": ['mw'],
    "śākteyaḥ": ['ap90'],
    "śāktika": ['mw'],
    "śāktikaḥ": ['ap90'],
    "śāktra": ['mw'],
    "śāktreya": ['mw'],
    "śāktya": ['ddsa', 'mw'],
    "śāktyasāman": ['mw'],
    "śāktyāyana": ['mw'],
    "śāktābhiṣeka": ['mw'],
    "śāktāgama": ['mw'],
    "śāktānandataraṃgiṇī": ['mw'],
    "śāktīka": ['cae', 'ddsa', 'mw'],
    "śāktīkaḥ": ['ap90'],
    "śākulika": ['mw'],
    "śākulikaḥ": ['ap90'],
    "śākulādika": ['mw'],
    "śākuna": ['ap90', 'cae', 'ddsa', 'mw'],
    "śākunasāroddhāra": ['mw'],
    "śākunasūkta": ['mw'],
    "śākunavicāra": ['mw'],
    "śākunaśāstrasāra": ['mw'],
    "śākuneya": ['ddsa', 'mw'],
    "śākuneyaḥ": ['ap90'],
    "śākuni": ['cae', 'mw'],
    "śākunika": ['cae', 'mw'],
    "śākunikalubdhaka": ['cae'],
    "śākunikapraśna": ['mw'],
    "śākunikaḥ": ['ap90'],
    "śākunikāyinī": ['bhs', 'mw'],
    "śākunimitra": ['mw'],
    "śākunin": ['mw'],
    "śākuntaki": ['mw'],
    "śākuntakīya": ['mw'],
    "śākuntala": ['cae', 'ddsa', 'mw'],
    "śākuntaleya": ['mw'],
    "śākuntalopākhyāna": ['mw'],
    "śākunteya": ['mw'],
    "śākuntika": ['mw'],
    "śākuṃtalaḥ": ['ap90'],
    "śākuṇa": ['ap90'],
    "śākvara": ['cae', 'ddsa', 'mw'],
    "śākvaragarbha": ['mw'],
    "śākvarapathyā": ['mw'],
    "śākvarapṛṣṭha": ['mw'],
    "śākvaravarṇa": ['mw'],
    "śākvaraḥ": ['ap90'],
    "śākvarya": ['mw'],
    "śākya": ['cae', 'ddsa', 'mw'],
    "śākyabhikṣu": ['cae', 'mw'],
    "śākyabhikṣuka": ['mw'],
    "śākyabhikṣukī": ['mw'],
    "śākyabodhisattva": ['mw'],
    "śākyabuddha": ['mw'],
    "śākyabuddhi": ['bhs', 'mw'],
    "śākyaketu": ['mw'],
    "śākyakīrti": ['mw'],
    "śākyamahābala": ['mw'],
    "śākyamati": ['mw'],
    "śākyamitra": ['bhs', 'mw'],
    "śākyamuni": ['bhs', 'cae', 'mw'],
    "śākyaprabha": ['mw'],
    "śākyaputrīya": ['bhs', 'mw'],
    "śākyapuṃgava": ['mw'],
    "śākyapāla": ['mw'],
    "śākyarakṣita": ['mw'],
    "śākyasiṃha": ['bhs', 'mw'],
    "śākyasūtra": ['bhs'],
    "śākyavardha": ['bhs', 'mw'],
    "śākyavaṃśa": ['mw'],
    "śākyavaṃśāvatīrṇa": ['mw'],
    "śākyayanī": ['bhs'],
    "śākyaśramaṇa": ['cae', 'mw'],
    "śākyaśramaṇaka": ['mw'],
    "śākyaśravaṇa": ['mw'],
    "śākyaśrī": ['mw'],
    "śākyaśāsana": ['mw'],
    "śākyaḥ": ['ap90'],
    "śākyāyanikā": ['bhs'],
    "śākyāyanī": ['bhs'],
    "śākyāyanīya": ['mw'],
    "śākā": ['mw'],
    "śākāda": ['mw'],
    "śākāhāra": ['mw'],
    "śākākhya": ['mw'],
    "śākālābu": ['mw'],
    "śākāmla": ['mw'],
    "śākāmlabhedaka": ['mw'],
    "śākāmlabhedana": ['mw'],
    "śākārikā": ['mw'],
    "śākārī": ['ap90', 'ddsa', 'mw'],
    "śākāsana": ['mw'],
    "śākāyana": ['mw'],
    "śākāyanin": ['mw'],
    "śākāyanya": ['mw'],
    "śākāśana": ['ddsa', 'mw'],
    "śākāṅga": ['mw'],
    "śākāṣṭakā": ['mw'],
    "śākāṣṭamī": ['mw'],
    "śākī": ['bhs', 'mw'],
    "śākīya": ['mw'],
    "śākṛtka": ['mw'],
    "śāl": ['ap90', 'ddsa', 'mw'],
    "śāla": ['bhs', 'cae', 'ddsa', 'mw'],
    "śālabha": ['cae', 'ddsa', 'mw'],
    "śālabhañjikā": ['cae', 'mw'],
    "śālabhañjikāprakhya": ['mw'],
    "śālabhañjikāya": ['mw'],
    "śālabhañjī": ['cae', 'mw'],
    "śālagrāma": ['cae', 'mw'],
    "śālagrāmadānakalpa": ['mw'],
    "śālagrāmagiri": ['mw'],
    "śālagrāmakalpa": ['mw'],
    "śālagrāmakṣetra": ['mw'],
    "śālagrāmalakṣaṇa": ['mw'],
    "śālagrāmamāhātmya": ['mw'],
    "śālagrāmanirṇaya": ['mw'],
    "śālagrāmaparīkṣā": ['mw'],
    "śālagrāmastotra": ['mw'],
    "śālagrāmatīrtha": ['mw'],
    "śālagrāmaśilā": ['mw'],
    "śālagrāmī": ['mw'],
    "śālagupta": ['mw'],
    "śālaguptāyani": ['mw'],
    "śālaja": ['mw'],
    "śālaka": ['mw'],
    "śālakaṭaṅkaṭa": ['ddsa', 'mw'],
    "śālakaṭaṅkaṭī": ['mw'],
    "śālam": ['mw'],
    "śālamarkaṭaka": ['mw'],
    "śālamaya": ['mw'],
    "śālana": ['mw'],
    "śālaniryāsa": ['mw'],
    "śālaparṇikā": ['mw'],
    "śālaparṇī": ['mw'],
    "śālapattrā": ['mw'],
    "śālapota": ['cae', 'mw'],
    "śālaprāṃśu": ['mw'],
    "śālapuṣpa": ['mw'],
    "śālapuṣpabhañjikā": ['mw'],
    "śālapuṣpamaya": ['mw'],
    "śālapuṣpanibha": ['mw'],
    "śālarasa": ['mw'],
    "śālarāja": ['bhs'],
    "śālarājendra": ['bhs'],
    "śālasaṃkāśa": ['mw'],
    "śālaskandha": ['mw'],
    "śālastambha": ['mw'],
    "śālasucitra": ['bhs'],
    "śālasāra": ['mw'],
    "śālava": ['mw'],
    "śālavadana": ['mw'],
    "śālavalaya": ['ddsa', 'mw'],
    "śālavana": ['mw'],
    "śālavaḥ": ['ap90'],
    "śālavaṃśanṛpamuktāvalī": ['mw'],
    "śālaveṣṭa": ['mw'],
    "śālavāha": ['mw'],
    "śālavāhana": ['mw'],
    "śālavāṇaka": ['mw'],
    "śālaśṛṅga": ['mw'],
    "śālaḥ": ['ap90'],
    "śālaṅka": ['mw'],
    "śālaṅkaṭaṅkaṭa": ['mw'],
    "śālaṅki": ['mw'],
    "śālaṅkāyana": ['cae', 'mw'],
    "śālaṅkāyanabāṣkala": ['mw'],
    "śālaṅkāyanagotra": ['mw'],
    "śālaṅkāyanajā": ['mw'],
    "śālaṅkāyanasauśrava": ['mw'],
    "śālaṅkāyani": ['mw'],
    "śālaṅkāyanin": ['mw'],
    "śālaṅkāyanīputra": ['mw'],
    "śālaṅkṛtya": ['mw'],
    "śālendrarāja": ['bhs', 'mw'],
    "śālendraskandha": ['bhs'],
    "śāleya": ['cae', 'ddsa', 'mw'],
    "śāleyaṃ": ['ap90'],
    "śāli": ['cae', 'ddsa', 'mw'],
    "śālibhadra": ['mw'],
    "śālibhadracaritra": ['mw'],
    "śālibhavana": ['cae', 'ddsa', 'mw'],
    "śālibhañjikāya": ['mw'],
    "śālibhū": ['mw'],
    "śālicūrṇa": ['cae', 'mw'],
    "śāligopa": ['cae'],
    "śāligopī": ['mw'],
    "śāligotra": ['mw'],
    "śālihotra": ['cae', 'mw'],
    "śālihotrajña": ['mw'],
    "śālihotrasāra": ['mw'],
    "śālihotrin": ['mw'],
    "śālihotronnaya": ['mw'],
    "śālihotrāyaṇa": ['mw'],
    "śālihotrīya": ['mw'],
    "śālijaudana": ['mw'],
    "śālijāla": ['mw'],
    "śālika": ['mw'],
    "śālikanātha": ['mw'],
    "śālikaḥ": ['ap90'],
    "śālikaṇa": ['cae', 'mw'],
    "śālikedāra": ['cae', 'mw'],
    "śālikā": ['mw'],
    "śālikūṭa": ['mw'],
    "śālikṣetra": ['mw'],
    "śālimañjari": ['mw'],
    "śālin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śālinātha": ['mw'],
    "śālinī": ['ap90', 'mw'],
    "śāliparṇī": ['mw'],
    "śālipiṇḍa": ['mw'],
    "śālipiṣṭa": ['mw'],
    "śāliputra": ['bhs'],
    "śālisaṃrakṣikā": ['mw'],
    "śālistambaka": ['bhs'],
    "śālistambasūtra": ['bhs'],
    "śālistambhaka": ['mw'],
    "śālisūrya": ['mw'],
    "śālita": ['mw'],
    "śālitva": ['mw'],
    "śālitā": ['ddsa', 'mw'],
    "śālivah": ['mw'],
    "śālivāha": ['mw'],
    "śālivāhana": ['cae', 'mw'],
    "śālivāhanacaritra": ['mw'],
    "śālivāhanasaptatī": ['mw'],
    "śālivāhanaśataka": ['mw'],
    "śāliñca": ['mw'],
    "śāliśiras": ['mw'],
    "śāliśūka": ['mw'],
    "śāliḥ": ['ap90'],
    "śālmala": ['ddsa', 'mw'],
    "śālmalaḥ": ['ap90'],
    "śālmali": ['cae', 'ddsa', 'mw'],
    "śālmalidvīpa": ['mw'],
    "śālmalika": ['mw'],
    "śālmalikaṃ": ['ap90'],
    "śālmalin": ['ap90', 'mw'],
    "śālmalinī": ['ap90', 'mw'],
    "śālmalipattraka": ['mw'],
    "śālmalistha": ['mw'],
    "śālmaliḥ": ['ap90'],
    "śālmalyā": ['mw'],
    "śālmalī": ['ap90', 'mw'],
    "śālmalīkanda": ['mw'],
    "śālmalīphala": ['mw'],
    "śālmalīphalaka": ['cae', 'mw'],
    "śālmalīvana": ['bhs'],
    "śālmalīveṣṭa": ['mw'],
    "śālmalīveṣṭaka": ['mw'],
    "śālottarīya": ['mw'],
    "śālottarīyaḥ": ['ap90'],
    "śālu": ['cae', 'mw'],
    "śāluka": ['bhs', 'mw'],
    "śālukaṃ": ['ap90'],
    "śāluraḥ": ['ap90'],
    "śāluveśakavaca": ['mw'],
    "śāluḍa": ['cae', 'mw'],
    "śāluḥ": ['ap90'],
    "śālva": ['cae', 'ddsa', 'mw'],
    "śālvaka": ['mw'],
    "śālvakinī": ['mw'],
    "śālvakī": ['mw'],
    "śālvanagara": ['mw'],
    "śālvapati": ['mw'],
    "śālvarāja": ['mw'],
    "śālvarājan": ['mw'],
    "śālvaseni": ['mw'],
    "śālvaḥ": ['ap90'],
    "śālvaṇa": ['mw'],
    "śālveya": ['mw'],
    "śālveyaka": ['mw'],
    "śālvika": ['mw'],
    "śālvā": ['mw'],
    "śālvāgiri": ['mw'],
    "śālvāri": ['mw'],
    "śālvāyana": ['mw'],
    "śāly": ['mw'],
    "śālyanna": ['cae', 'ddsa', 'mw'],
    "śālyapati": ['mw'],
    "śālyodana": ['cae', 'mw'],
    "śālyūḍha": ['mw'],
    "śālā": ['ap90', 'cae', 'ddsa', 'mw'],
    "śālādvār": ['mw'],
    "śālādvāra": ['mw'],
    "śālādvārya": ['mw'],
    "śālāgni": ['cae', 'mw'],
    "śālājira": ['mw'],
    "śālāka": ['cae', 'mw'],
    "śālākarkaṭaka": ['mw'],
    "śālākarman": ['mw'],
    "śālākarmapaddhati": ['mw'],
    "śālākaḥ": ['ap90'],
    "śālākeya": ['mw'],
    "śālākin": ['ap90', 'mw'],
    "śālākya": ['mw'],
    "śālākyaśāstra": ['mw'],
    "śālākyaṃ": ['ap90'],
    "śālākābhreya": ['mw'],
    "śālākṣa": ['mw'],
    "śālāluka": ['mw'],
    "śālāmarkaṭaka": ['mw'],
    "śālāmukha": ['mw'],
    "śālāmukhīya": ['cae', 'mw'],
    "śālāmṛga": ['mw'],
    "śālānī": ['mw'],
    "śālāpati": ['cae', 'mw'],
    "śālāra": ['mw'],
    "śālāraṃ": ['ap90'],
    "śālāsad": ['ddsa', 'mw'],
    "śālāstambha": ['cae', 'mw'],
    "śālāstha": ['mw'],
    "śālāsthali": ['mw'],
    "śālāsthalyā": ['mw'],
    "śālāthala": ['mw'],
    "śālāthaleya": ['mw'],
    "śālāturīya": ['cae', 'ddsa', 'mw'],
    "śālāturīyaḥ": ['ap90'],
    "śālātva": ['mw'],
    "śālāvat": ['mw'],
    "śālāvata": ['mw'],
    "śālāvatya": ['mw'],
    "śālāvatī": ['mw'],
    "śālāvaṃśa": ['cae', 'mw'],
    "śālāvṛka": ['cae', 'mw'],
    "śālāñci": ['mw'],
    "śālāñji": ['mw'],
    "śālāśarkaṭaka": ['mw'],
    "śālāśraya": ['cae', 'mw'],
    "śālāśrayatva": ['mw'],
    "śālāṅkī": ['mw'],
    "śālī": ['mw'],
    "śālībhartṛ": ['mw'],
    "śālīhotramuni": ['mw'],
    "śālīki": ['mw'],
    "śālīkṣumat": ['mw'],
    "śālīna": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śālīnam": ['mw'],
    "śālīnatva": ['cae', 'mw'],
    "śālīnatvavarjita": ['mw'],
    "śālīnatā": ['ap90', 'cae', 'mw'],
    "śālīnaśīla": ['mw'],
    "śālīnaśīlatva": ['mw'],
    "śālīnya": ['mw'],
    "śālīnā": ['mw'],
    "śālīnī": ['mw'],
    "śālīnīkaraṇa": ['mw'],
    "śālīnīkṛ": ['mw'],
    "śālīya": ['mw'],
    "śālūka": ['cae', 'ddsa', 'mw'],
    "śālūkaṃ": ['ap90'],
    "śālūkeya": ['mw'],
    "śālūkikā": ['mw'],
    "śālūkikīya": ['mw'],
    "śālūkinī": ['mw'],
    "śālūra": ['cae', 'ddsa', 'mw'],
    "śālūraka": ['mw'],
    "śālūraḥ": ['ap90'],
    "śālūḍha": ['mw'],
    "śāma": ['bhs', 'mw'],
    "śāmadatta": ['mw'],
    "śāmalabhaṭṭa": ['mw'],
    "śāmaladāsa": ['mw'],
    "śāmam": ['mw'],
    "śāman": ['ap90', 'mw'],
    "śāmana": ['ddsa', 'mw'],
    "śāmanaḥ": ['ap90'],
    "śāmanī": ['mw'],
    "śāmba": ['mw'],
    "śāmbali": ['bhs'],
    "śāmbalāmbāvarmaratna": ['mw'],
    "śāmbara": ['cae', 'ddsa', 'gra', 'mw'],
    "śāmbaraśilpa": ['mw'],
    "śāmbarika": ['cae', 'mw'],
    "śāmbarī": ['mw'],
    "śāmbava": ['mw'],
    "śāmbavika": ['mw'],
    "śāmbavya": ['mw'],
    "śāmbavānandakalpa": ['mw'],
    "śāmbhara": ['mw'],
    "śāmbharanagara": ['mw'],
    "śāmbharāyiṇī": ['mw'],
    "śāmbharāyiṇīvrata": ['mw'],
    "śāmbhava": ['ddsa', 'mw'],
    "śāmbhavadeva": ['mw'],
    "śāmbhavadīpikā": ['mw'],
    "śāmbhavya": ['mw'],
    "śāmbhavāha": ['mw'],
    "śāmbhavī": ['mw'],
    "śāmbhavītantra": ['mw'],
    "śāmbhavīya": ['mw'],
    "śāmbu": ['mw'],
    "śāmbuka": ['mw'],
    "śāmbuvi": ['mw'],
    "śāmbūka": ['mw'],
    "śāmeya": ['mw'],
    "śāmika": ['mw'],
    "śāmilī": ['ap90'],
    "śāmitra": ['cae', 'ddsa', 'mw'],
    "śāmitrakarman": ['cae', 'mw'],
    "śāmitraṃ": ['ap90'],
    "śāmmada": ['mw'],
    "śāmulia": ['gra'],
    "śāmulya": ['cae', 'ddsa', 'gra', 'mw'],
    "śāmupāla": ['mw'],
    "śāmya": ['cae', 'ddsa', 'mw'],
    "śāmyaka": ['bhs'],
    "śāmyaprāśa": ['bhs', 'mw'],
    "śāmyatā": ['mw'],
    "śāmyavākā": ['mw'],
    "śāmyāka": ['mw'],
    "śāmā": ['mw'],
    "śāmāka": ['mw'],
    "śāmāyana": ['mw'],
    "śāmāyanīya": ['mw'],
    "śāmīla": ['cae', 'ddsa', 'mw'],
    "śāmīlaṃ": ['ap90'],
    "śāmīlī": ['ap90', 'mw'],
    "śāmīnaṃ": ['ap90'],
    "śāmīvata": ['mw'],
    "śāmīvatya": ['mw'],
    "śāmīvatī": ['mw'],
    "śāmūla": ['cae', 'ddsa', 'mw'],
    "śān": ['ap90', 'mw'],
    "śāna": ['mw'],
    "śānac": ['ap90', 'ddsa', 'mw'],
    "śānaiścara": ['ap90', 'ddsa', 'mw'],
    "śānakavāsin": ['bhs'],
    "śānapāda": ['mw'],
    "śānaḥ": ['ap90'],
    "śāni": ['mw'],
    "śānila": ['mw'],
    "śānita": ['mw'],
    "śāniścara": ['bhs'],
    "śānta": ['bhs', 'cae', 'ddsa', 'mw'],
    "śāntabhaya": ['mw'],
    "śāntacetas": ['mw'],
    "śāntadevatya": ['mw'],
    "śāntadhvaja": ['bhs'],
    "śāntaga": ['bhs'],
    "śāntaghoravimūḍhatva": ['mw'],
    "śāntaguṇa": ['mw'],
    "śāntahaya": ['mw'],
    "śāntahṛdaya": ['mw'],
    "śāntajvara": ['mw'],
    "śāntaka": ['mw'],
    "śāntakarṇa": ['mw'],
    "śāntakrodha": ['mw'],
    "śāntalābha": ['mw'],
    "śāntamala": ['mw'],
    "śāntamanas": ['cae', 'mw'],
    "śāntamati": ['bhs', 'mw'],
    "śāntamoha": ['mw'],
    "śāntamukha": ['bhs'],
    "śāntanava": ['ddsa'],
    "śāntanirghoṣa": ['bhs'],
    "śāntanirghoṣahāramati": ['bhs'],
    "śāntanu": ['ddsa'],
    "śāntaprabharāja": ['bhs'],
    "śāntapradīpameghaśirirāja": ['bhs'],
    "śāntapura": ['mw'],
    "śāntapurī": ['mw'],
    "śāntara": ['bhs'],
    "śāntaraja": ['bhs'],
    "śāntarajas": ['cae', 'mw'],
    "śāntarakṣita": ['bhs'],
    "śāntarasa": ['mw'],
    "śāntarasanāṭaka": ['mw'],
    "śāntarava": ['mw'],
    "śāntaraya": ['mw'],
    "śāntaraśmi": ['bhs', 'mw'],
    "śāntareṇu": ['bhs'],
    "śāntarutasāgaravatī": ['bhs'],
    "śāntarūpa": ['cae', 'ddsa', 'mw'],
    "śāntasena": ['mw'],
    "śāntasumati": ['mw'],
    "śāntasūri": ['mw'],
    "śāntatoya": ['mw'],
    "śāntatva": ['mw'],
    "śāntatā": ['cae', 'mw'],
    "śāntavivāda": ['mw'],
    "śāntavīradeśikendra": ['mw'],
    "śāntay": ['cae'],
    "śāntaya": ['ddsa', 'mw'],
    "śāntayoni": ['mw'],
    "śāntaśrī": ['bhs', 'mw'],
    "śāntendrarāja": ['bhs'],
    "śānti": ['cae', 'ddsa', 'mw'],
    "śāntibhājana": ['cae', 'mw'],
    "śāntibhāṣya": ['mw'],
    "śānticandrikā": ['mw'],
    "śānticaritra": ['mw'],
    "śānticaritranāṭaka": ['mw'],
    "śānticintāmaṇi": ['mw'],
    "śāntida": ['cae', 'mw'],
    "śāntideva": ['mw'],
    "śāntidhvaja": ['bhs'],
    "śāntidīpikā": ['mw'],
    "śāntigaṇapati": ['mw'],
    "śāntigrantha": ['mw'],
    "śāntigupta": ['mw'],
    "śāntiguru": ['mw'],
    "śāntigṛha": ['mw'],
    "śāntigṛhaka": ['mw'],
    "śāntihoma": ['cae', 'mw'],
    "śāntihomamantra": ['mw'],
    "śāntijala": ['mw'],
    "śāntika": ['cae', 'ddsa', 'mw'],
    "śāntikakarman": ['mw'],
    "śāntikalpa": ['mw'],
    "śāntikalpadīpikā": ['mw'],
    "śāntikalpalatā": ['mw'],
    "śāntikalpapradīpa": ['mw'],
    "śāntikalyāṇī": ['mw'],
    "śāntikamalākara": ['mw'],
    "śāntikara": ['mw'],
    "śāntikaraṇa": ['mw'],
    "śāntikarman": ['cae', 'mw'],
    "śāntikartṛ": ['mw'],
    "śāntikhaṇḍa": ['mw'],
    "śāntikādhyāya": ['mw'],
    "śāntikāma": ['mw'],
    "śāntikārin": ['mw'],
    "śāntikṛt": ['mw'],
    "śāntimantra": ['mw'],
    "śāntimat": ['mw'],
    "śāntimatī": ['bhs'],
    "śāntimayūkha": ['mw'],
    "śāntinirṇaya": ['mw'],
    "śāntinātha": ['mw'],
    "śāntināthacaritra": ['mw'],
    "śāntināthapurāṇa": ['mw'],
    "śāntipaddhati": ['mw'],
    "śāntiparvan": ['mw'],
    "śāntipaṭala": ['mw'],
    "śāntiprabha": ['bhs', 'mw'],
    "śāntiprabhagambhīrakūṭa": ['bhs'],
    "śāntiprakaraṇa": ['mw'],
    "śāntiprakāra": ['mw'],
    "śāntiprakāśa": ['mw'],
    "śāntiprayoga": ['mw'],
    "śāntipura": ['mw'],
    "śāntipurāṇa": ['mw'],
    "śāntipustaka": ['mw'],
    "śāntipārijāta": ['mw'],
    "śāntipātra": ['cae', 'mw'],
    "śāntipāṭha": ['mw'],
    "śāntirakṣita": ['mw'],
    "śāntiratna": ['mw'],
    "śāntiratnākara": ['mw'],
    "śāntirāja": ['bhs'],
    "śāntisadman": ['mw'],
    "śāntisalila": ['cae', 'mw'],
    "śāntisarvasva": ['mw'],
    "śāntisoma": ['mw'],
    "śāntistava": ['mw'],
    "śāntisāra": ['mw'],
    "śāntisārabhāṣya": ['mw'],
    "śāntisūkta": ['mw'],
    "śāntisūri": ['mw'],
    "śāntitattvāmṛta": ['mw'],
    "śāntivaravarman": ['mw'],
    "śāntivarman": ['mw'],
    "śāntividhi": ['mw'],
    "śāntividhāna": ['mw'],
    "śāntivilāsa": ['mw'],
    "śāntiviveka": ['mw'],
    "śāntivrata": ['mw'],
    "śāntivā": ['mw'],
    "śāntivācana": ['mw'],
    "śāntivāda": ['mw'],
    "śāntivāhana": ['mw'],
    "śāntiyukta": ['mw'],
    "śāntiśarman": ['mw'],
    "śāntiśataka": ['mw'],
    "śāntiśatakasaṃgraha": ['mw'],
    "śāntiśīla": ['mw'],
    "śāntiṣeṇa": ['mw'],
    "śāntodara": ['mw'],
    "śāntodaratva": ['mw'],
    "śāntv": ['mw'],
    "śāntvati": ['mw'],
    "śāntvay": ['cae'],
    "śāntvā": ['mw'],
    "śānty": ['mw'],
    "śāntyagniparīkṣādigrantha": ['mw'],
    "śāntyuda": ['mw'],
    "śāntyudaka": ['cae', 'mw'],
    "śāntyudakaprayoga": ['mw'],
    "śāntyudakumbha": ['mw'],
    "śāntyuddyota": ['mw'],
    "śāntyākara": ['mw'],
    "śāntyākaragupta": ['mw'],
    "śāntā": ['ddsa', 'mw'],
    "śāntābha": ['bhs'],
    "śāntāntakara": ['mw'],
    "śāntārcis": ['mw'],
    "śāntātman": ['cae', 'mw'],
    "śānī": ['mw'],
    "śānīya": ['mw'],
    "śāpa": ['cae', 'ddsa', 'gra', 'mw'],
    "śāpabhāj": ['mw'],
    "śāpagrasta": ['mw'],
    "śāpaja": ['mw'],
    "śāpamokṣa": ['cae', 'mw'],
    "śāpamukta": ['mw'],
    "śāpamukti": ['mw'],
    "śāpanāśana": ['mw'],
    "śāpaparikṣata": ['mw'],
    "śāpaprada": ['mw'],
    "śāpapradāna": ['cae', 'mw'],
    "śāpasamāyukta": ['mw'],
    "śāpatā": ['ddsa', 'mw'],
    "śāpavimocana": ['mw'],
    "śāpayantrita": ['mw'],
    "śāpaḥ": ['ap90'],
    "śāpaṭhika": ['mw'],
    "śāpaṭhikaḥ": ['ap90'],
    "śāpaṭika": ['mw'],
    "śāpeya": ['mw'],
    "śāpeyin": ['mw'],
    "śāpeṭa": ['ddsa', 'mw'],
    "śāpharika": ['mw'],
    "śāpharikaḥ": ['ap90'],
    "śāpheya": ['mw'],
    "śāphākṣi": ['mw'],
    "śāpita": ['ap90', 'mw'],
    "śāpodaka": ['cae', 'ddsa', 'mw'],
    "śāpoddhāra": ['mw'],
    "śāpotsarga": ['mw'],
    "śāpāmbu": ['cae', 'mw'],
    "śāpānta": ['mw'],
    "śāpāstra": ['mw'],
    "śāpāvasāna": ['mw'],
    "śāpāyana": ['mw'],
    "śāpīya": ['mw'],
    "śār": ['ap90', 'mw'],
    "śāra": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śārada": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śāradabhūruh": ['mw'],
    "śāradaka": ['bhs', 'mw'],
    "śāradatilaka": ['mw'],
    "śāradaśarvarī": ['mw'],
    "śāradaṇḍāyani": ['mw'],
    "śāradaṇḍāyanī": ['mw'],
    "śāradaṇḍāyinī": ['mw'],
    "śāradika": ['mw'],
    "śāradikaḥ": ['ap90'],
    "śāradikā": ['mw'],
    "śāradin": ['mw'],
    "śāradollāsa": ['mw'],
    "śāradvata": ['bhs', 'cae', 'ddsa', 'mw'],
    "śāradvatāyana": ['mw'],
    "śāradvatī": ['mw'],
    "śāradvatīputra": ['bhs', 'mw'],
    "śāradvatīsuta": ['mw'],
    "śāradya": ['bhs', 'cae', 'mw'],
    "śāradā": ['mw'],
    "śāradādevīmāhātmyapaṭala": ['mw'],
    "śāradādikalpa": ['mw'],
    "śāradākalpa": ['mw'],
    "śāradākalpalatā": ['mw'],
    "śāradākramadīpikā": ['mw'],
    "śāradākāra": ['mw'],
    "śāradāmbā": ['mw'],
    "śāradāmāhātmya": ['mw'],
    "śāradānanda": ['mw'],
    "śāradānandana": ['mw'],
    "śāradāpurāṇa": ['mw'],
    "śāradāpūjā": ['mw'],
    "śāradāsahasranāman": ['mw'],
    "śāradāstava": ['mw'],
    "śāradāstotra": ['mw'],
    "śāradātanaya": ['mw'],
    "śāradātilaka": ['mw'],
    "śāradātilakatantra": ['mw'],
    "śāradī": ['mw'],
    "śāradīna": ['cae', 'mw'],
    "śāradīya": ['ap90', 'cae', 'mw'],
    "śāradīyamahāpūjā": ['mw'],
    "śāradīyākhyanāmamālā": ['mw'],
    "śāralomyā": ['mw'],
    "śāralomī": ['mw'],
    "śārambara": ['ddsa'],
    "śārapada": ['mw'],
    "śārasamātulya": ['bhs'],
    "śāratalpika": ['mw'],
    "śāratka": ['mw'],
    "śāratva": ['mw'],
    "śāratā": ['mw'],
    "śāraṃgaḥ": ['ap90'],
    "śāraṃgī": ['ap90'],
    "śāraṅga": ['cae', 'mw'],
    "śāraṅgī": ['ddsa'],
    "śāraṇa": ['ddsa'],
    "śāraṇika": ['mw'],
    "śārdūla": ['bhs', 'cae', 'ddsa', 'mw'],
    "śārdūlacarman": ['cae', 'mw'],
    "śārdūlajyeṣṭha": ['mw'],
    "śārdūlakarṇa": ['bhs', 'mw'],
    "śārdūlakarṇāvadāna": ['bhs'],
    "śārdūlalalita": ['mw'],
    "śārdūlaloman": ['cae', 'mw'],
    "śārdūlamṛgasevita": ['mw'],
    "śārdūlasamavikrama": ['mw'],
    "śārdūlavarman": ['mw'],
    "śārdūlavikrīḍita": ['cae', 'mw'],
    "śārdūlavāhana": ['mw'],
    "śārdūlaśataka": ['mw'],
    "śārdūlaḥ": ['ap90'],
    "śārdūlī": ['mw'],
    "śārga": ['cae', 'mw'],
    "śārgāla": ['mw'],
    "śāri": ['cae', 'ddsa', 'mw'],
    "śārijā": ['mw'],
    "śārika": ['cae', 'mw'],
    "śārikukṣa": ['mw'],
    "śārikā": ['ap90', 'bhs', 'ddsa', 'mw'],
    "śārikākavaca": ['mw'],
    "śārikākūṭa": ['mw'],
    "śārikānātha": ['mw'],
    "śārikāpīṭha": ['mw'],
    "śārikāstotra": ['mw'],
    "śāripaṭṭa": ['mw'],
    "śāriphala": ['mw'],
    "śāriphalaka": ['mw'],
    "śāriprastara": ['mw'],
    "śāriputra": ['bhs', 'ddsa', 'mw'],
    "śārisuta": ['bhs', 'mw'],
    "śārita": ['ddsa', 'mw'],
    "śārivā": ['mw'],
    "śāriśākā": ['mw'],
    "śāriśṛṅkhalā": ['mw'],
    "śāriḥ": ['ap90'],
    "śārka": ['mw'],
    "śārkaka": ['mw'],
    "śārkakaḥ": ['ap90'],
    "śārkara": ['ap90', 'ddsa', 'mw'],
    "śārkaraka": ['ap90', 'mw'],
    "śārkarika": ['mw'],
    "śārkarin": ['mw'],
    "śārkarākṣa": ['mw'],
    "śārkarākṣasa": ['mw'],
    "śārkarākṣi": ['mw'],
    "śārkarākṣya": ['mw'],
    "śārkarākṣyāyaṇī": ['mw'],
    "śārkarīdhāna": ['mw'],
    "śārkarīya": ['mw'],
    "śārkaḥ": ['ap90'],
    "śārkoṭa": ['mw'],
    "śārmaṇa": ['mw'],
    "śārmaṇya": ['ddsa', 'mw'],
    "śārmaṇyadeśa": ['mw'],
    "śāru": ['mw'],
    "śāruka": ['ap90', 'mw'],
    "śārva": ['cae', 'ddsa', 'mw'],
    "śārvara": ['ap90', 'cae', 'ddsa'],
    "śārvarika": ['cae', 'mw'],
    "śārvarin": ['mw'],
    "śārvarī": ['mw'],
    "śārvavarmika": ['mw'],
    "śāryāta": ['cae', 'ddsa', 'gra', 'mw'],
    "śāryātaka": ['mw'],
    "śārāva": ['mw'],
    "śārī": ['ap90', 'bhs', 'gra', 'mw'],
    "śārīra": ['ap90', 'cae', 'ddsa', 'mw'],
    "śārīrabrāhmaṇa": ['mw'],
    "śārīraka": ['ap90', 'cae', 'ddsa', 'mw'],
    "śārīrakabhāṣya": ['mw'],
    "śārīrakabhāṣyanyāyavārttika": ['mw'],
    "śārīrakabhāṣyavibhāga": ['mw'],
    "śārīrakabhāṣyavyākhyā": ['mw'],
    "śārīrakabhāṣyavārttika": ['mw'],
    "śārīrakabhāṣyaṭīkā": ['mw'],
    "śārīrakamīmāṃsā": ['cae', 'mw'],
    "śārīrakamīmāṃsābhāṣya": ['mw'],
    "śārīrakamīmāṃsānyāyasaṃgraha": ['mw'],
    "śārīrakamīmāṃsāvyākhyā": ['mw'],
    "śārīrakanyāya": ['mw'],
    "śārīrakanyāyamaṇimālā": ['mw'],
    "śārīrakanyāyanirṇaya": ['mw'],
    "śārīrakanyāyarakṣāmaṇi": ['mw'],
    "śārīrakanyāyasaṃgraha": ['mw'],
    "śārīrakapradīpikā": ['mw'],
    "śārīrakasambandhoktisaṃkṣepa": ['mw'],
    "śārīrakasaṃgraha": ['mw'],
    "śārīrakasaṃkṣepa": ['mw'],
    "śārīrakasūtra": ['mw'],
    "śārīrakasūtrasārārthacandrikā": ['mw'],
    "śārīrakaśāstradarpaṇa": ['mw'],
    "śārīrakaṭīkā": ['mw'],
    "śārīrakopaniṣad": ['mw'],
    "śārīrakīya": ['ap90', 'mw'],
    "śārīralakṣaṇa": ['mw'],
    "śārīrasthāna": ['mw'],
    "śārīravaidya": ['mw'],
    "śārīravidyā": ['mw'],
    "śārīravraṇa": ['mw'],
    "śārīrika": ['ap90', 'mw'],
    "śārīropaniṣad": ['mw'],
    "śārīṭaka": ['ddsa', 'mw'],
    "śārṃga": ['ap90'],
    "śārṃgin": ['ap90'],
    "śārṅga": ['cae', 'ddsa', 'mw'],
    "śārṅgabhṛt": ['cae', 'mw'],
    "śārṅgadatta": ['mw'],
    "śārṅgadeva": ['mw'],
    "śārṅgadhanurdhara": ['cae', 'mw'],
    "śārṅgadhanus": ['mw'],
    "śārṅgadhanvan": ['cae', 'mw'],
    "śārṅgadhanvin": ['cae', 'mw'],
    "śārṅgadhara": ['cae', 'mw'],
    "śārṅgadharapaddhati": ['mw'],
    "śārṅgadharapāṇi": ['cae'],
    "śārṅgadharasaṃhitā": ['mw'],
    "śārṅgadharavrajyā": ['mw'],
    "śārṅgadharīya": ['mw'],
    "śārṅgajagdha": ['mw'],
    "śārṅgaka": ['cae', 'mw'],
    "śārṅgapakṣin": ['mw'],
    "śārṅgapāṇi": ['mw'],
    "śārṅgapāṇistotra": ['mw'],
    "śārṅgarava": ['cae', 'mw'],
    "śārṅgaravī": ['mw'],
    "śārṅgavata": ['mw'],
    "śārṅgaṣṭā": ['mw'],
    "śārṅgeṣṭā": ['mw'],
    "śārṅgi": ['mw'],
    "śārṅgideva": ['mw'],
    "śārṅgika": ['mw'],
    "śārṅgikā": ['mw'],
    "śārṅgin": ['cae', 'ddsa', 'mw'],
    "śārṅgoṣṭhā": ['mw'],
    "śārṅgāyudha": ['mw'],
    "śārṅgī": ['ddsa', 'mw'],
    "śārṅkhalatodi": ['mw'],
    "śās": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śāsa": ['cae', 'ddsa', 'gra', 'mw'],
    "śāsahasta": ['cae', 'mw'],
    "śāsaka": ['cae', 'ddsa', 'mw'],
    "śāsakaḥ": ['ap90'],
    "śāsana": ['cae', 'ddsa', 'gra', 'mw'],
    "śāsanadevatā": ['mw'],
    "śāsanadevī": ['mw'],
    "śāsanadhara": ['cae', 'mw'],
    "śāsanadūṣaka": ['mw'],
    "śāsanahara": ['mw'],
    "śāsanahāraka": ['cae', 'mw'],
    "śāsanahārin": ['cae', 'mw'],
    "śāsanalaṅghana": ['mw'],
    "śāsanaparāṅmukha": ['mw'],
    "śāsanapattra": ['mw'],
    "śāsanavartin": ['mw'],
    "śāsanavāhaka": ['cae', 'mw'],
    "śāsanaśilā": ['mw'],
    "śāsanaṃ": ['ap90'],
    "śāsaniya": ['bhs'],
    "śāsanāda": ['bhs'],
    "śāsanātivṛtti": ['mw'],
    "śāsanī": ['gra', 'mw'],
    "śāsanīya": ['ap90', 'cae', 'ddsa', 'mw'],
    "śāsaḥ": ['ap90'],
    "śāsin": ['cae', 'mw'],
    "śāsita": ['ap90', 'mw'],
    "śāsitavya": ['cae', 'mw'],
    "śāsitṛ": ['ap90', 'cae', 'mw'],
    "śāstar": ['bhs'],
    "śāsti": ['cae', 'mw'],
    "śāstiḥ": ['ap90'],
    "śāstra": ['cae', 'ddsa', 'gra', 'mw'],
    "śāstrabuddhi": ['cae', 'mw'],
    "śāstracakṣus": ['mw'],
    "śāstracaura": ['mw'],
    "śāstracintaka": ['cae', 'mw'],
    "śāstracāraṇa": ['mw'],
    "śāstradarpaṇa": ['mw'],
    "śāstradarśana": ['mw'],
    "śāstradarśanāt": ['mw'],
    "śāstradarśin": ['mw'],
    "śāstradasyu": ['mw'],
    "śāstradīpa": ['mw'],
    "śāstradīpikā": ['mw'],
    "śāstradīpārthasāra": ['mw'],
    "śāstradṛṣṭa": ['cae', 'mw'],
    "śāstradṛṣṭi": ['mw'],
    "śāstragañja": ['mw'],
    "śāstragaṇḍa": ['mw'],
    "śāstrajaladhiratna": ['mw'],
    "śāstrajña": ['cae', 'mw'],
    "śāstrajñatva": ['mw'],
    "śāstrajñatā": ['mw'],
    "śāstrajñāna": ['mw'],
    "śāstrakovida": ['mw'],
    "śāstrakroḍa": ['mw'],
    "śāstrakāra": ['cae', 'mw'],
    "śāstrakṛt": ['cae', 'mw'],
    "śāstraloka": ['mw'],
    "śāstramati": ['cae', 'mw'],
    "śāstramālā": ['mw'],
    "śāstramālāvṛtti": ['mw'],
    "śāstranetra": ['mw'],
    "śāstranindā": ['mw'],
    "śāstraprabhā": ['mw'],
    "śāstraprakāśa": ['mw'],
    "śāstraprakāśikā": ['mw'],
    "śāstraprasaṅga": ['mw'],
    "śāstrapraveśa": ['mw'],
    "śāstrapāṇin": ['mw'],
    "śāstrapūjanaprakaraṇa": ['mw'],
    "śāstrasaṃgraha": ['mw'],
    "śāstrasiddha": ['mw'],
    "śāstrasiddhāntaleśasaṃgraha": ['mw'],
    "śāstrasiddhāntaleśasaṃgrahasāra": ['mw'],
    "śāstrasāra": ['mw'],
    "śāstrasāroddhāra": ['mw'],
    "śāstrasārāvali": ['mw'],
    "śāstratas": ['cae', 'mw'],
    "śāstratattva": ['mw'],
    "śāstratattvajña": ['mw'],
    "śāstratva": ['mw'],
    "śāstraugha": ['mw'],
    "śāstravaktṛ": ['mw'],
    "śāstravarjita": ['mw'],
    "śāstravat": ['mw'],
    "śāstravid": ['cae', 'mw'],
    "śāstravidhi": ['mw'],
    "śāstravidhāna": ['mw'],
    "śāstravidhānokta": ['mw'],
    "śāstravimukha": ['mw'],
    "śāstravipratiṣedha": ['mw'],
    "śāstravipratiṣiddha": ['mw'],
    "śāstravirodha": ['mw'],
    "śāstraviruddha": ['mw'],
    "śāstraviśārada": ['bhs'],
    "śāstravyutpatti": ['mw'],
    "śāstravyākhyā": ['mw'],
    "śāstravāda": ['cae', 'mw'],
    "śāstravādin": ['cae', 'mw'],
    "śāstrayoni": ['mw'],
    "śāstrayonitva": ['mw'],
    "śāstraśilpin": ['mw'],
    "śāstraṃ": ['ap90'],
    "śāstraṭīkā": ['mw'],
    "śāstrika": ['mw'],
    "śāstrin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śāstrita": ['mw'],
    "śāstritārtha": ['mw'],
    "śāstrokta": ['mw'],
    "śāstropadeśakrama": ['mw'],
    "śāstrābhijña": ['mw'],
    "śāstrācaraṇa": ['mw'],
    "śāstrādhyāpaka": ['mw'],
    "śāstrānanuṣṭhāna": ['mw'],
    "śāstrānusāra": ['mw'],
    "śāstrānuṣṭhita": ['mw'],
    "śāstrānuṣṭhāna": ['mw'],
    "śāstrānvita": ['mw'],
    "śāstrārambhasamarthana": ['mw'],
    "śāstrārambhavādārtha": ['mw'],
    "śāstrārtha": ['mw'],
    "śāstrātikrama": ['mw'],
    "śāstrāvarta": ['bhs'],
    "śāstrāvartalipi": ['mw'],
    "śāstrīya": ['ap90', 'cae', 'mw'],
    "śāstrīyatva": ['mw'],
    "śāstāravādin": ['bhs'],
    "śāstṛ": ['ap90', 'cae', 'mw'],
    "śāstṛka": ['mw'],
    "śāstṛtva": ['mw'],
    "śāsus": ['cae', 'gra', 'mw'],
    "śāsya": ['ap90', 'cae', 'ddsa', 'mw'],
    "śāsā": ['gra'],
    "śāta": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "śātabhiṣa": ['mw'],
    "śātabhiṣaja": ['mw'],
    "śātabhīru": ['mw'],
    "śātabhīruḥ": ['ap90'],
    "śātadvāreya": ['mw'],
    "śātahrada": ['cae', 'ddsa', 'mw'],
    "śātaka": ['mw'],
    "śātakarṇi": ['mw'],
    "śātakarṇin": ['mw'],
    "śātakaumbha": ['cae', 'ddsa', 'mw'],
    "śātakaumbhamaya": ['mw'],
    "śātakauṃbhaṃ": ['ap90'],
    "śātakratava": ['ddsa', 'mw'],
    "śātakumbha": ['cae', 'ddsa', 'mw'],
    "śātakumbhadrava": ['mw'],
    "śātakumbhamaya": ['cae', 'mw'],
    "śātakuṃbhaṃ": ['ap90'],
    "śātaleya": ['mw'],
    "śātalā": ['mw'],
    "śātamanyava": ['ddsa', 'mw'],
    "śātamāna": ['ap90', 'mw'],
    "śātana": ['cae', 'ddsa', 'mw'],
    "śātanaṃ": ['ap90'],
    "śātapanta": ['mw'],
    "śātaparṇeya": ['mw'],
    "śātapata": ['mw'],
    "śātapatha": ['ddsa', 'mw'],
    "śātapathika": ['mw'],
    "śātapatrakaḥ": ['ap90'],
    "śātapattra": ['mw'],
    "śātapattraka": ['mw'],
    "śātapattrakī": ['mw'],
    "śātaputraka": ['mw'],
    "śātarātrika": ['mw'],
    "śātavaneya": ['gra', 'mw'],
    "śātavat": ['gra'],
    "śātavāhana": ['mw'],
    "śātaśikha": ['mw'],
    "śātaśūrpa": ['mw'],
    "śātaśṛṅgin": ['mw'],
    "śātin": ['cae', 'ddsa', 'mw'],
    "śātita": ['mw'],
    "śātodara": ['cae', 'ddsa', 'mw'],
    "śātodaratva": ['mw'],
    "śātra": ['mw'],
    "śātrava": ['ap90', 'cae', 'ddsa', 'mw'],
    "śātraveṅgita": ['mw'],
    "śātravīya": ['ap90', 'mw'],
    "śātruṃtapi": ['mw'],
    "śātruṃtapīya": ['mw'],
    "śātvala": ['mw'],
    "śātāgiri": ['bhs'],
    "śātāhara": ['mw'],
    "śātāhareya": ['mw'],
    "śātātapa": ['ddsa', 'mw'],
    "śātātapasmṛti": ['mw'],
    "śātātapīya": ['mw'],
    "śāva": ['ap90', 'cae', 'ddsa', 'mw'],
    "śāvaka": ['cae', 'mw'],
    "śāvakaḥ": ['ap90'],
    "śāvara": ['ap90', 'mw'],
    "śāvasta": ['mw'],
    "śāvasāyana": ['mw'],
    "śāvatva": ['mw'],
    "śāvirī": ['mw'],
    "śāvāśauca": ['cae', 'mw'],
    "śāya": ['cae', 'mw'],
    "śāyaka": ['cae', 'mw'],
    "śāyakaḥ": ['ap90'],
    "śāyana": ['mw'],
    "śāyasthi": ['mw'],
    "śāyayitavya": ['ddsa', 'mw'],
    "śāyaḥ": ['ap90'],
    "śāyaṇḍāyana": ['mw'],
    "śāyaṇḍāyanabhakta": ['mw'],
    "śāyikā": ['ap90', 'mw'],
    "śāyin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śāyita": ['bhs'],
    "śāyitā": ['ddsa', 'mw'],
    "śāyyika": ['mw'],
    "śāyāpitaka": ['bhs'],
    "śāśa": ['cae', 'ddsa', 'mw'],
    "śāśabindu": ['mw'],
    "śāśadāna": ['mw'],
    "śāśaka": ['cae', 'mw'],
    "śāśakarṇi": ['mw'],
    "śāśika": ['mw'],
    "śāśvata": ['ap90', 'cae', 'ddsa', 'mw'],
    "śāśvatadṛṣṭi": ['bhs'],
    "śāśvatadṛṣṭika": ['bhs'],
    "śāśvatamandira": ['mw'],
    "śāśvatatva": ['cae', 'mw'],
    "śāśvatavajra": ['bhs'],
    "śāśvatavādin": ['bhs'],
    "śāśvatendra": ['mw'],
    "śāśvatika": ['ap90', 'bhs', 'mw'],
    "śāśvatikatā": ['mw'],
    "śāśvatoccheda": ['bhs'],
    "śāśvatānanda": ['mw'],
    "śāśvatī": ['ap90', 'mw'],
    "śāśādanaka": ['mw'],
    "śāḍ": ['mw'],
    "śāḍava": ['mw'],
    "śāḍbala": ['mw'],
    "śāḍvala": ['mw'],
    "śāṃbarī": ['ap90'],
    "śāṃbavikaḥ": ['ap90'],
    "śāṃbaḥ": ['ap90'],
    "śāṃbhava": ['ap90', 'cae'],
    "śāṃbhavī": ['ap90'],
    "śāṃbukaḥ": ['ap90'],
    "śāṃbūkaḥ": ['ap90'],
    "śāṃkara": ['cae', 'mw'],
    "śāṃkarabrāhmaṇa": ['mw'],
    "śāṃkaraḥ": ['ap90'],
    "śāṃkari": ['mw'],
    "śāṃkariḥ": ['ap90'],
    "śāṃkarī": ['mw'],
    "śāṃkarīkroḍa": ['mw'],
    "śāṃkarīratnamālā": ['mw'],
    "śāṃkarīya": ['mw'],
    "śāṃkhaṃ": ['ap90'],
    "śāṃkhikaḥ": ['ap90'],
    "śāṃta": ['ap90'],
    "śāṃtanava": ['cae', 'mw'],
    "śāṃtanavaḥ": ['ap90'],
    "śāṃtanavaṣaṭsūtra": ['mw'],
    "śāṃtanavācārya": ['mw'],
    "śāṃtanavī": ['mw'],
    "śāṃtanu": ['cae', 'mw'],
    "śāṃtanunandana": ['mw'],
    "śāṃtanutva": ['mw'],
    "śāṃtanūja": ['mw'],
    "śāṃtika": ['ap90'],
    "śāṃtiḥ": ['ap90'],
    "śāṃtv": ['ap90'],
    "śāṃtā": ['ap90'],
    "śāṃvatya": ['ddsa', 'mw'],
    "śāṃśapa": ['ddsa', 'mw'],
    "śāṃśapaka": ['mw'],
    "śāṃśapāsthala": ['mw'],
    "śāṃśapāyana": ['mw'],
    "śāṃśapāyanaka": ['mw'],
    "śāṃśapāyani": ['mw'],
    "śāṃḍilyaḥ": ['ap90'],
    "śāṅguṣṭhā": ['mw'],
    "śāṅkara": ['ddsa'],
    "śāṅkavya": ['mw'],
    "śāṅkavyāyanī": ['mw'],
    "śāṅkha": ['mw'],
    "śāṅkhalikhita": ['ddsa', 'mw'],
    "śāṅkhamitra": ['mw'],
    "śāṅkhamitri": ['mw'],
    "śāṅkhika": ['cae', 'ddsa', 'mw'],
    "śāṅkhina": ['mw'],
    "śāṅkhya": ['cae', 'mw'],
    "śāṅkhāyana": ['cae', 'ddsa', 'mw'],
    "śāṅkhāyanabrāhmaṇa": ['mw'],
    "śāṅkhāyanacaraṇa": ['mw'],
    "śāṅkhāyanagṛhyasūtra": ['mw'],
    "śāṅkhāyanaśrautasūtra": ['mw'],
    "śāṅkhāyanin": ['mw'],
    "śāṅkhāyanya": ['mw'],
    "śāṅkhāyanāhnika": ['mw'],
    "śāṅkhāyanāraṇyaka": ['mw'],
    "śāṅkhāyanāraṇyakopaniṣad": ['mw'],
    "śāṅkucī": ['mw'],
    "śāṅkuka": ['ddsa', 'mw'],
    "śāṅkupathika": ['mw'],
    "śāṅkura": ['mw'],
    "śāṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "śāṇaka": ['bhs', 'mw'],
    "śāṇakavāsa": ['mw'],
    "śāṇakavāsin": ['bhs'],
    "śāṇapramaṇa": ['mw'],
    "śāṇapāda": ['mw'],
    "śāṇavatya": ['mw'],
    "śāṇavāsa": ['mw'],
    "śāṇavāsika": ['mw'],
    "śāṇi": ['mw'],
    "śāṇika": ['mw'],
    "śāṇita": ['ap90', 'mw'],
    "śāṇiḥ": ['ap90'],
    "śāṇopala": ['cae', 'mw'],
    "śāṇya": ['mw'],
    "śāṇājīva": ['mw'],
    "śāṇāśmagharṣaṇa": ['mw'],
    "śāṇāśmaka": ['ddsa', 'mw'],
    "śāṇāśman": ['mw'],
    "śāṇī": ['ap90', 'mw'],
    "śāṇīra": ['mw'],
    "śāṇīraṃ": ['ap90'],
    "śāṇḍa": ['cae', 'gra', 'mw'],
    "śāṇḍadūrvā": ['mw'],
    "śāṇḍika": ['mw'],
    "śāṇḍikera": ['mw'],
    "śāṇḍikya": ['mw'],
    "śāṇḍila": ['cae', 'ddsa', 'mw'],
    "śāṇḍileya": ['mw'],
    "śāṇḍilya": ['cae', 'ddsa', 'mw'],
    "śāṇḍilyagotra": ['mw'],
    "śāṇḍilyagṛhya": ['mw'],
    "śāṇḍilyalakṣmaṇa": ['mw'],
    "śāṇḍilyaputra": ['mw'],
    "śāṇḍilyasmṛti": ['mw'],
    "śāṇḍilyasūtra": ['mw'],
    "śāṇḍilyasūtrabhāṣya": ['mw'],
    "śāṇḍilyasūtrapravacana": ['mw'],
    "śāṇḍilyasūtravyākhyā": ['mw'],
    "śāṇḍilyasūtrībhāṣya": ['mw'],
    "śāṇḍilyasūtrīya": ['mw'],
    "śāṇḍilyavidyā": ['mw'],
    "śāṇḍilyopaniṣad": ['mw'],
    "śāṇḍilyāyana": ['mw'],
    "śāṇḍilyāyanaka": ['mw'],
    "śāṇḍilī": ['mw'],
    "śāṇḍilīmātṛ": ['mw'],
    "śāṇḍilīputra": ['mw'],
    "śāṇḍākī": ['mw'],
    "śāṣasāna": ['mw'],
    "śāṣkula": ['ap90', 'mw'],
    "śāṣkulika": ['mw'],
    "śāṣkulikaṃ": ['ap90'],
    "śāṣpaka": ['mw'],
    "śāṣpeya": ['mw'],
    "śāṣpeyin": ['mw'],
    "śāṭa": ['cae', 'ddsa', 'mw'],
    "śāṭaka": ['mw'],
    "śāṭakaḥ": ['ap90'],
    "śāṭayati": ['bhs'],
    "śāṭaḥ": ['ap90'],
    "śāṭha": ['mw'],
    "śāṭhara": ['mw'],
    "śāṭhin": ['mw'],
    "śāṭhiya": ['bhs'],
    "śāṭhya": ['cae', 'ddsa', 'mw'],
    "śāṭhyavat": ['mw'],
    "śāṭhyaṃ": ['ap90'],
    "śāṭhyāyanīya": ['mw'],
    "śāṭhā": ['bhs'],
    "śāṭhāyana": ['mw'],
    "śāṭhāyanya": ['mw'],
    "śāṭi": ['bhs', 'mw'],
    "śāṭikā": ['bhs', 'mw'],
    "śāṭya": ['mw'],
    "śāṭyāyana": ['cae', 'ddsa', 'mw'],
    "śāṭyāyanabrāhmaṇa": ['mw'],
    "śāṭyāyanagotra": ['mw'],
    "śāṭyāyanahoma": ['mw'],
    "śāṭyāyanaka": ['mw'],
    "śāṭyāyanasmṛti": ['mw'],
    "śāṭyāyanaṃ": ['ap90'],
    "śāṭyāyani": ['mw'],
    "śāṭyāyanin": ['mw'],
    "śāṭyāyanyupaniṣad": ['mw'],
    "śāṭyāyanī": ['mw'],
    "śāṭyāyanīyopaniṣad": ['mw'],
    "śāṭī": ['mw'],
    "śāṭīpaṭīra": ['mw'],
    "śāṭīpaṭṭika": ['mw'],
    "śāṭīpicchaka": ['mw'],
    "śāṭīpracchada": ['mw'],
    "śāṭīya": ['mw'],
    "śī": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śībh": ['ap90', 'mw'],
    "śībha": ['gra'],
    "śībham": ['cae', 'ddsa', 'mw'],
    "śībhara": ['cae', 'mw'],
    "śībhya": ['cae', 'mw'],
    "śībhyaḥ": ['ap90'],
    "śīdhu": ['ap90', 'ddsa', 'mw'],
    "śīghra": ['ap90', 'cae', 'ddsa', 'mw'],
    "śīghrabodha": ['mw'],
    "śīghrabodhabhūṣaṇa": ['mw'],
    "śīghrabodhinī": ['mw'],
    "śīghrabuddha": ['mw'],
    "śīghrabuddhi": ['mw'],
    "śīghrabāhukāyana": ['mw'],
    "śīghracetana": ['mw'],
    "śīghracāra": ['cae', 'mw'],
    "śīghraga": ['cae', 'mw'],
    "śīghragamana": ['mw'],
    "śīghragantṛ": ['mw'],
    "śīghragati": ['mw'],
    "śīghragatva": ['mw'],
    "śīghragaṅga": ['mw'],
    "śīghragāmin": ['cae', 'mw'],
    "śīghrajanman": ['mw'],
    "śīghrajava": ['mw'],
    "śīghrakarman": ['mw'],
    "śīghrakendra": ['mw'],
    "śīghrakopin": ['mw'],
    "śīghrakārin": ['cae', 'mw'],
    "śīghrakāritva": ['mw'],
    "śīghrakṛt": ['cae', 'mw'],
    "śīghrakṛtya": ['cae', 'mw'],
    "śīghralaṅghana": ['mw'],
    "śīghram": ['mw'],
    "śīghraparidhi": ['mw'],
    "śīghraparākrama": ['mw'],
    "śīghraphala": ['mw'],
    "śīghrapuṣpa": ['mw'],
    "śīghrapātin": ['cae', 'mw'],
    "śīghrapāyin": ['cae', 'mw'],
    "śīghrapāṇi": ['cae', 'mw'],
    "śīghrasaṃcārin": ['mw'],
    "śīghrasrotas": ['mw'],
    "śīghratara": ['mw'],
    "śīghrataragati": ['mw'],
    "śīghrataram": ['mw'],
    "śīghratva": ['mw'],
    "śīghratā": ['cae', 'mw'],
    "śīghravaha": ['mw'],
    "śīghravedhin": ['mw'],
    "śīghravega": ['cae', 'mw'],
    "śīghravikrama": ['mw'],
    "śīghravāhin": ['cae', 'mw'],
    "śīghrayāna": ['cae', 'mw'],
    "śīghrayāyin": ['mw'],
    "śīghreṇa": ['mw'],
    "śīghrin": ['ap90', 'ddsa', 'mw'],
    "śīghriya": ['ap90', 'mw'],
    "śīghrocca": ['mw'],
    "śīghrya": ['cae', 'mw'],
    "śīghryaṃ": ['ap90'],
    "śīghrā": ['mw'],
    "śīghrāstra": ['mw'],
    "śīghrāstratva": ['mw'],
    "śīghrāya": ['mw'],
    "śīghrāyate": ['ap90'],
    "śīghrīya": ['ap90', 'mw'],
    "śīhara": ['mw'],
    "śīk": ['ap90', 'cae', 'ddsa', 'mw'],
    "śīkara": ['cae', 'ddsa', 'mw'],
    "śīkarakaṇa": ['mw'],
    "śīkaraugha": ['mw'],
    "śīkaravarṣin": ['mw'],
    "śīkaraḥ": ['ap90'],
    "śīkarin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śīkarāmbhas": ['mw'],
    "śīkarāmbu": ['mw'],
    "śīkarārdra": ['mw'],
    "śīkayata": ['mw'],
    "śīkita": ['mw'],
    "śīkāya": ['mw'],
    "śīkṣopaniṣad": ['mw'],
    "śīkṣā": ['mw'],
    "śīkṣādhyāyopaniṣad": ['mw'],
    "śīl": ['ap90', 'mw'],
    "śīla": ['cae', 'ddsa', 'mw'],
    "śīlabhadra": ['bhs', 'mw'],
    "śīlabhaṅga": ['cae', 'mw'],
    "śīlabhaṭṭārikā": ['mw'],
    "śīlabhraṃśa": ['mw'],
    "śīlabhāj": ['mw'],
    "śīladhara": ['mw'],
    "śīladhārin": ['mw'],
    "śīlagupta": ['mw'],
    "śīlahara": ['mw'],
    "śīlajña": ['mw'],
    "śīlajñānanidhi": ['mw'],
    "śīlaka": ['mw'],
    "śīlakhaṇḍana": ['mw'],
    "śīlakīrti": ['mw'],
    "śīlamaya": ['mw'],
    "śīlana": ['cae', 'ddsa', 'mw'],
    "śīlanaṃ": ['ap90'],
    "śīlanidhi": ['mw'],
    "śīlapālita": ['mw'],
    "śīlapāramitā": ['ddsa', 'mw'],
    "śīlasampanna": ['mw'],
    "śīlasamādāna": ['mw'],
    "śīlasaṃgha": ['mw'],
    "śīlatas": ['cae', 'mw'],
    "śīlataṭa": ['mw'],
    "śīlatulya": ['mw'],
    "śīlatva": ['mw'],
    "śīlatyāga": ['cae', 'mw'],
    "śīlatā": ['mw'],
    "śīlavalka": ['bhs'],
    "śīlavant": ['cae'],
    "śīlavarjita": ['mw'],
    "śīlavat": ['mw'],
    "śīlavatī": ['mw'],
    "śīlavañcanā": ['ddsa', 'mw'],
    "śīlavela": ['cae', 'mw'],
    "śīlavighnakṛt": ['mw'],
    "śīlavilaya": ['mw'],
    "śīlavilāsa": ['mw'],
    "śīlaviplava": ['mw'],
    "śīlaviśuddhanetra": ['bhs', 'mw'],
    "śīlavrata": ['bhs', 'mw'],
    "śīlavṛddha": ['mw'],
    "śīlavṛtta": ['cae', 'mw'],
    "śīlavṛttadhara": ['mw'],
    "śīlavṛttavid": ['mw'],
    "śīlavṛtti": ['mw'],
    "śīlay": ['cae'],
    "śīlaya": ['ddsa', 'mw'],
    "śīlaśālin": ['mw'],
    "śīlaḥ": ['ap90'],
    "śīlendrabodhi": ['mw'],
    "śīlika": ['mw'],
    "śīlin": ['cae', 'ddsa', 'mw'],
    "śīlita": ['ap90', 'cae', 'mw'],
    "śīlopadeśamālā": ['mw'],
    "śīlopasampanna": ['mw'],
    "śīloṣṇā": ['mw'],
    "śīlā": ['mw'],
    "śīlāditya": ['cae', 'mw'],
    "śīlākhya": ['bhs'],
    "śīlāravaṃśa": ['mw'],
    "śīlāḍhya": ['mw'],
    "śīlāṅga": ['mw'],
    "śīlāṅka": ['ddsa', 'mw'],
    "śīma": ['mw'],
    "śīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "śīpalya": ['mw'],
    "śīphara": ['cae', 'ddsa', 'mw'],
    "śīphālikā": ['mw'],
    "śīpudru": ['mw'],
    "śīpāla": ['cae', 'ddsa', 'gra', 'mw'],
    "śīpālila": ['mw'],
    "śīpālā": ['mw'],
    "śīra": ['cae', 'ddsa', 'gra', 'mw'],
    "śīraśocis": ['cae', 'gra', 'mw'],
    "śīraḥ": ['ap90'],
    "śīri": ['cae', 'mw'],
    "śīrin": ['mw'],
    "śīrta": ['ddsa', 'mw'],
    "śīrti": ['cae', 'mw'],
    "śīrvi": ['ap90', 'mw'],
    "śīrya": ['cae', 'mw'],
    "śīrī": ['cae', 'mw'],
    "śīrṇa": ['ap90', 'cae', 'ddsa', 'mw'],
    "śīrṇadanta": ['mw'],
    "śīrṇaka": ['mw'],
    "śīrṇamālā": ['mw'],
    "śīrṇamūla": ['mw'],
    "śīrṇanālā": ['mw'],
    "śīrṇaparṇa": ['mw'],
    "śīrṇaparṇaphala": ['mw'],
    "śīrṇaparṇāśin": ['mw'],
    "śīrṇaparṇī": ['mw'],
    "śīrṇapattra": ['mw'],
    "śīrṇapuṣpa": ['mw'],
    "śīrṇapuṣpikā": ['mw'],
    "śīrṇapāda": ['mw'],
    "śīrṇatva": ['mw'],
    "śīrṇatā": ['mw'],
    "śīrṇavṛnta": ['mw'],
    "śīrṇaśīrṣan": ['mw'],
    "śīrṇi": ['cae', 'mw'],
    "śīrṇāṃhri": ['mw'],
    "śīrṇāṅghri": ['mw'],
    "śīrṇīkṛ": ['ddsa', 'mw'],
    "śīrṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "śīrṣabandhanā": ['mw'],
    "śīrṣabhidya": ['cae', 'mw'],
    "śīrṣabhāra": ['mw'],
    "śīrṣabhārika": ['mw'],
    "śīrṣaccheda": ['cae', 'mw'],
    "śīrṣacchedana": ['mw'],
    "śīrṣacchedika": ['mw'],
    "śīrṣacchedya": ['cae', 'mw'],
    "śīrṣacchida": ['mw'],
    "śīrṣacchinna": ['cae', 'mw'],
    "śīrṣaghātin": ['mw'],
    "śīrṣahārya": ['cae', 'mw'],
    "śīrṣaka": ['bhs', 'cae', 'mw'],
    "śīrṣakapāla": ['cae', 'mw'],
    "śīrṣakastha": ['mw'],
    "śīrṣakaḥ": ['ap90'],
    "śīrṣakaṭāhaka": ['bhs'],
    "śīrṣakti": ['cae', 'mw'],
    "śīrṣaktimat": ['mw'],
    "śīrṣamāya": ['mw'],
    "śīrṣan": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śīrṣaparṇī": ['mw'],
    "śīrṣapaṭṭaka": ['cae', 'ddsa', 'mw'],
    "śīrṣarakṣa": ['mw'],
    "śīrṣarakṣaṇa": ['mw'],
    "śīrṣarogin": ['mw'],
    "śīrṣas": ['bhs'],
    "śīrṣatas": ['cae', 'ddsa', 'mw'],
    "śīrṣatrāṇa": ['cae', 'mw'],
    "śīrṣavana": ['bhs', 'mw'],
    "śīrṣavartana": ['mw'],
    "śīrṣavedanā": ['cae', 'mw'],
    "śīrṣavirecana": ['mw'],
    "śīrṣavyathā": ['mw'],
    "śīrṣaya": ['mw'],
    "śīrṣaśoka": ['cae', 'mw'],
    "śīrṣaṃ": ['ap90'],
    "śīrṣaṇ": ['mw'],
    "śīrṣaṇvant": ['cae'],
    "śīrṣaṇvat": ['mw'],
    "śīrṣaṇya": ['cae', 'ddsa', 'gra', 'mw'],
    "śīrṣaṇyaḥ": ['ap90'],
    "śīrṣaṇī": ['cae', 'mw'],
    "śīrṣe": ['mw'],
    "śīrṣebhāra": ['mw'],
    "śīrṣebhārika": ['mw'],
    "śīrṣika": ['mw'],
    "śīrṣin": ['mw'],
    "śīrṣodaya": ['mw'],
    "śīrṣā": ['mw'],
    "śīrṣāhārya": ['mw'],
    "śīrṣāmaya": ['cae', 'mw'],
    "śīrṣānta": ['mw'],
    "śīrṣāvaśeṣīkṛta": ['mw'],
    "śīt": ['ap90', 'ddsa', 'mw'],
    "śīta": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śītabalā": ['mw'],
    "śītabhañjirasa": ['mw'],
    "śītabhojin": ['mw'],
    "śītabhāna": ['cae'],
    "śītabhānavīya": ['mw'],
    "śītabhānu": ['mw'],
    "śītabhīru": ['mw'],
    "śītabhīruka": ['mw'],
    "śītabhīta": ['mw'],
    "śītabudhna": ['mw'],
    "śītacampaka": ['mw'],
    "śītadyuti": ['cae', 'mw'],
    "śītadīdhiti": ['cae', 'mw'],
    "śītadūrvā": ['mw'],
    "śītagandha": ['mw'],
    "śītagandhā": ['mw'],
    "śītagu": ['cae', 'mw'],
    "śītagutanaya": ['mw'],
    "śītagātra": ['mw'],
    "śītahara": ['mw'],
    "śītahrada": ['cae', 'mw'],
    "śītajvara": ['mw'],
    "śītaka": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śītakara": ['cae', 'ddsa', 'mw'],
    "śītakiraṇa": ['cae', 'mw'],
    "śītakriyā": ['cae', 'mw'],
    "śītakumbha": ['mw'],
    "śītakumbhī": ['mw'],
    "śītakāla": ['mw'],
    "śītakālīna": ['mw'],
    "śītakṛcchra": ['cae', 'mw'],
    "śītakṛcchraka": ['mw'],
    "śītakṣāra": ['mw'],
    "śītala": ['ap90', 'cae', 'ddsa', 'mw'],
    "śītalacchada": ['mw'],
    "śītaladīkṣita": ['mw'],
    "śītalajala": ['mw'],
    "śītalaka": ['bhs', 'mw'],
    "śītalakaṃ": ['ap90'],
    "śītalapattrikā": ['mw'],
    "śītalaprada": ['mw'],
    "śītalaprasāda": ['mw'],
    "śītalasaptamī": ['mw'],
    "śītalasparśa": ['cae', 'ddsa', 'mw'],
    "śītalasvāmin": ['mw'],
    "śītalatara": ['mw'],
    "śītalatva": ['mw'],
    "śītalatā": ['cae', 'mw'],
    "śītalavāta": ['mw'],
    "śītalavātaka": ['mw'],
    "śītalay": ['cae'],
    "śītalaya": ['ddsa', 'mw'],
    "śītalā": ['ap90', 'mw'],
    "śītalāgaurīpūjāvidhi": ['mw'],
    "śītalāprakaraṇa": ['mw'],
    "śītalāpūjā": ['mw'],
    "śītalāsaptamī": ['mw'],
    "śītalāstotra": ['mw'],
    "śītalāvrata": ['mw'],
    "śītalāy": ['cae'],
    "śītalāya": ['mw'],
    "śītalāṣṭaka": ['mw'],
    "śītalī": ['ap90', 'mw'],
    "śītalībhū": ['mw'],
    "śītalījaṭā": ['mw'],
    "śītalīkṛ": ['cae', 'ddsa', 'mw'],
    "śītamarīci": ['cae', 'mw'],
    "śītamaya": ['cae', 'mw'],
    "śītamayūkha": ['cae', 'mw'],
    "śītamayūkhamālin": ['mw'],
    "śītamañjarī": ['mw'],
    "śītameha": ['mw'],
    "śītamehin": ['mw'],
    "śītamūlaka": ['mw'],
    "śītapallava": ['mw'],
    "śītapallavā": ['mw'],
    "śītaparṇi": ['mw'],
    "śītaparṇī": ['mw'],
    "śītapaṅka": ['mw'],
    "śītaphala": ['mw'],
    "śītaphalā": ['mw'],
    "śītapitta": ['mw'],
    "śītaprabha": ['bhs', 'mw'],
    "śītaprada": ['mw'],
    "śītapriya": ['mw'],
    "śītapuṣpa": ['mw'],
    "śītapuṣpaka": ['mw'],
    "śītapuṣpā": ['mw'],
    "śītapākinī": ['mw'],
    "śītapākya": ['mw'],
    "śītapākī": ['mw'],
    "śītapāṇi": ['cae', 'mw'],
    "śītapūtanā": ['cae', 'mw'],
    "śītara": ['bhs'],
    "śītaramya": ['mw'],
    "śītarasa": ['mw'],
    "śītarasika": ['mw'],
    "śītaraśmi": ['cae', 'mw'],
    "śītaraśmija": ['mw'],
    "śītaraśmitva": ['mw'],
    "śītarocis": ['cae', 'mw'],
    "śītaruc": ['cae', 'mw'],
    "śītaruci": ['cae', 'mw'],
    "śītarūra": ['cae', 'mw'],
    "śītasaha": ['mw'],
    "śītasahā": ['mw'],
    "śītasaṃsparśa": ['cae', 'mw'],
    "śītasparśa": ['ddsa', 'mw'],
    "śītatva": ['mw'],
    "śītatā": ['cae', 'mw'],
    "śītavaha": ['cae', 'mw'],
    "śītavalka": ['mw'],
    "śītavana": ['bhs', 'mw'],
    "śītavatī": ['bhs', 'mw'],
    "śītavātoṣṇavetālī": ['mw'],
    "śītavīrya": ['mw'],
    "śītavīryaka": ['mw'],
    "śītay": ['cae'],
    "śītaya": ['mw'],
    "śītaśiva": ['mw'],
    "śītaśivā": ['mw'],
    "śītaśūka": ['mw'],
    "śītetara": ['ddsa', 'mw'],
    "śītetararaśmi": ['mw'],
    "śītetarācis": ['mw'],
    "śīteṣu": ['cae', 'mw'],
    "śīti": ['bhs'],
    "śītibhāva": ['bhs'],
    "śītikā": ['mw'],
    "śītikāvant": ['cae'],
    "śītikāvat": ['ddsa', 'gra', 'mw'],
    "śītiman": ['mw'],
    "śītkāra": ['cae', 'ddsa', 'mw'],
    "śītkārin": ['mw'],
    "śītkṛ": ['cae', 'mw'],
    "śītkṛta": ['cae', 'mw'],
    "śītkṛti": ['mw'],
    "śītkṛtin": ['mw'],
    "śītoda": ['mw'],
    "śītodaka": ['bhs', 'mw'],
    "śītodā": ['ddsa', 'mw'],
    "śītopacāra": ['mw'],
    "śītottama": ['mw'],
    "śītoṣma": ['mw'],
    "śītoṣman": ['mw'],
    "śītoṣṇa": ['cae', 'mw'],
    "śītoṣṇakiraṇa": ['cae', 'mw'],
    "śītoṣṇā": ['mw'],
    "śītya": ['ap90', 'mw'],
    "śītā": ['ap90', 'bhs', 'mw'],
    "śītābalā": ['mw'],
    "śītāda": ['mw'],
    "śītādhivāsa": ['cae', 'mw'],
    "śītādri": ['cae', 'mw'],
    "śītākula": ['mw'],
    "śītālu": ['ap90', 'cae', 'ddsa', 'mw'],
    "śītānta": ['mw'],
    "śītārirasa": ['mw'],
    "śītārta": ['cae', 'mw'],
    "śītāru": ['mw'],
    "śītātapatra": ['mw'],
    "śītāśman": ['mw'],
    "śītāṃśu": ['cae', 'ddsa', 'mw'],
    "śītāṃśubhāj": ['mw'],
    "śītāṃśumat": ['mw'],
    "śītāṃśutaila": ['mw'],
    "śītāṃśutva": ['mw'],
    "śītāṃśutā": ['mw'],
    "śītāṅga": ['mw'],
    "śītāṅgī": ['mw'],
    "śītī": ['mw'],
    "śītībhavati": ['bhs'],
    "śītībhāva": ['bhs', 'mw'],
    "śītībhū": ['mw'],
    "śītībhūta": ['bhs', 'mw'],
    "śītīkaraṇa": ['mw'],
    "śītīkṛ": ['mw'],
    "śītīmbhāva": ['mw'],
    "śīvala": ['mw'],
    "śīvan": ['ap90', 'cae', 'ddsa', 'mw'],
    "śīvarī": ['mw'],
    "śīvālī": ['bhs'],
    "śīṣṭa": ['gra', 'mw'],
    "śū": ['cae', 'ddsa', 'gra', 'mw'],
    "śūci": ['mw'],
    "śūdra": ['cae', 'ddsa', 'gra', 'mw'],
    "śūdrabhikṣita": ['mw'],
    "śūdrabhojin": ['mw'],
    "śūdrabhūyiṣṭha": ['mw'],
    "śūdradharma": ['mw'],
    "śūdradharmabodhinī": ['mw'],
    "śūdradharmatattva": ['mw'],
    "śūdragamana": ['cae', 'mw'],
    "śūdraghna": ['cae', 'mw'],
    "śūdrahan": ['cae', 'mw'],
    "śūdrahatyā": ['cae', 'mw'],
    "śūdrajana": ['cae', 'mw'],
    "śūdrajanman": ['cae', 'mw'],
    "śūdrajapavidhāna": ['mw'],
    "śūdraka": ['cae', 'mw'],
    "śūdrakakathā": ['mw'],
    "śūdrakalpa": ['mw'],
    "śūdrakamalākara": ['mw'],
    "śūdrakanyā": ['mw'],
    "śūdrakaḥ": ['ap90'],
    "śūdrakuladīpikā": ['mw'],
    "śūdrakṛta": ['cae', 'mw'],
    "śūdrakṛtya": ['mw'],
    "śūdrakṛtyavicāratattva": ['mw'],
    "śūdrakṛtyavicāraṇa": ['mw'],
    "śūdrakṛtyavicāraṇatattva": ['mw'],
    "śūdrapaddhati": ['mw'],
    "śūdrapañcasaṃskāravidhi": ['mw'],
    "śūdrapreṣya": ['mw'],
    "śūdrapriya": ['mw'],
    "śūdrarājya": ['cae', 'mw'],
    "śūdrasaṃskāra": ['mw'],
    "śūdrasaṃsparśa": ['mw'],
    "śūdrasevana": ['cae', 'mw'],
    "śūdrasmṛti": ['mw'],
    "śūdratva": ['mw'],
    "śūdratā": ['cae', 'mw'],
    "śūdravarga": ['mw'],
    "śūdravarjam": ['mw'],
    "śūdraviveka": ['mw'],
    "śūdravṛtti": ['cae', 'mw'],
    "śūdrayoni": ['cae', 'mw'],
    "śūdrayonija": ['mw'],
    "śūdrayājaka": ['cae', 'mw'],
    "śūdrayājakaprāyaścitta": ['mw'],
    "śūdraśiṣya": ['cae'],
    "śūdraśāsana": ['mw'],
    "śūdraḥ": ['ap90'],
    "śūdrika": ['mw'],
    "śūdrocchiṣṭa": ['cae', 'mw'],
    "śūdrodaka": ['mw'],
    "śūdrodakapānaprāyaścitta": ['mw'],
    "śūdroddyota": ['mw'],
    "śūdrotpatti": ['mw'],
    "śūdrā": ['ap90', 'ddsa', 'mw'],
    "śūdrābhārya": ['mw'],
    "śūdrācāra": ['mw'],
    "śūdrācāracintāmaṇi": ['mw'],
    "śūdrācārasaṃgraha": ['mw'],
    "śūdrācāraśiromaṇi": ['mw'],
    "śūdrāhnika": ['mw'],
    "śūdrāhnikācāratattva": ['mw'],
    "śūdrānna": ['cae', 'mw'],
    "śūdrāpariṇayana": ['mw'],
    "śūdrāputra": ['mw'],
    "śūdrārthayājaka": ['mw'],
    "śūdrārtā": ['mw'],
    "śūdrārya": ['mw'],
    "śūdrāsuta": ['mw'],
    "śūdrāvedana": ['mw'],
    "śūdrāvedin": ['cae', 'mw'],
    "śūdrāśauca": ['mw'],
    "śūdrāṇī": ['ap90', 'mw'],
    "śūdrī": ['ddsa', 'mw'],
    "śūdrībhū": ['cae', 'mw'],
    "śūghana": ['cae', 'gra', 'mw'],
    "śūka": ['bhs', 'cae', 'ddsa', 'mw'],
    "śūkadhānya": ['mw'],
    "śūkadoṣa": ['mw'],
    "śūkaka": ['mw'],
    "śūkakaḥ": ['ap90'],
    "śūkakīṭa": ['mw'],
    "śūkakīṭaka": ['mw'],
    "śūkala": ['mw'],
    "śūkalaḥ": ['ap90'],
    "śūkapattra": ['mw'],
    "śūkapiṇḍi": ['mw'],
    "śūkapiṇḍī": ['mw'],
    "śūkara": ['cae', 'ddsa', 'mw'],
    "śūkaraḥ": ['ap90'],
    "śūkaroga": ['mw'],
    "śūkataru": ['mw'],
    "śūkatṛṇa": ['mw'],
    "śūkavat": ['ap90', 'mw'],
    "śūkavatī": ['mw'],
    "śūkavṛnta": ['mw'],
    "śūkaśimbi": ['mw'],
    "śūkaśimbikā": ['mw'],
    "śūkaśimbā": ['mw'],
    "śūkaśimbī": ['mw'],
    "śūkaḥ": ['ap90'],
    "śūkin": ['mw'],
    "śūkula": ['mw'],
    "śūkā": ['mw'],
    "śūkāmaya": ['mw'],
    "śūkāpuṭṭa": ['mw'],
    "śūkāpūṭṭa": ['mw'],
    "śūkāra": ['cae', 'ddsa', 'mw'],
    "śūkāḍhya": ['mw'],
    "śūkṛta": ['cae', 'gra', 'mw'],
    "śūkṣma": ['mw'],
    "śūl": ['ap90', 'ddsa', 'mw'],
    "śūla": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "śūlabheda": ['mw'],
    "śūlabhṛt": ['cae', 'mw'],
    "śūladhanvan": ['mw'],
    "śūladhara": ['mw'],
    "śūladharā": ['cae', 'mw'],
    "śūladhārin": ['cae', 'mw'],
    "śūladhāriṇī": ['mw'],
    "śūladhṛk": ['cae', 'mw'],
    "śūladoṣaharī": ['mw'],
    "śūladviṣ": ['mw'],
    "śūlagava": ['ddsa', 'mw'],
    "śūlagavaprayoga": ['mw'],
    "śūlaghna": ['mw'],
    "śūlaghnī": ['mw'],
    "śūlaghātana": ['mw'],
    "śūlagraha": ['mw'],
    "śūlagranthi": ['mw'],
    "śūlagrāhin": ['mw'],
    "śūlahantrī": ['mw'],
    "śūlahasta": ['cae', 'mw'],
    "śūlahṛt": ['mw'],
    "śūlaka": ['mw'],
    "śūlakaḥ": ['ap90'],
    "śūlakāra": ['mw'],
    "śūlamudgarahasta": ['mw'],
    "śūlanāśaka": ['mw'],
    "śūlanāśana": ['mw'],
    "śūlanāśinī": ['mw'],
    "śūlapadī": ['mw'],
    "śūlaparṇī": ['mw'],
    "śūlapattrī": ['mw'],
    "śūlaprota": ['mw'],
    "śūlapāla": ['mw'],
    "śūlapāṇi": ['cae', 'mw'],
    "śūlapāṇin": ['mw'],
    "śūlastha": ['mw'],
    "śūlavara": ['mw'],
    "śūlavat": ['mw'],
    "śūlavata": ['mw'],
    "śūlavedanā": ['mw'],
    "śūlayoga": ['mw'],
    "śūlaśatru": ['mw'],
    "śūlaḥ": ['ap90'],
    "śūleśvarī": ['mw'],
    "śūleśvarītīrtha": ['mw'],
    "śūli": ['mw'],
    "śūlika": ['ap90', 'mw'],
    "śūlikā": ['mw'],
    "śūlin": ['ap90', 'cae', 'ddsa', 'mw'],
    "śūlina": ['mw'],
    "śūlinaḥ": ['ap90'],
    "śūlinī": ['mw'],
    "śūlinīdurgādigbandhana": ['mw'],
    "śūlinīkalpa": ['mw'],
    "śūlinīkavaca": ['mw'],
    "śūlinīmantrakalpa": ['mw'],
    "śūlinīvidhāna": ['mw'],
    "śūlodyatakara": ['mw'],
    "śūlotkhā": ['mw'],
    "śūlotthā": ['mw'],
    "śūlvāṇa": ['mw'],
    "śūlya": ['ap90', 'cae', 'mw'],
    "śūlyamāṃsa": ['cae', 'mw'],
    "śūlyamāṃsabhūyiṣṭha": ['cae'],
    "śūlyapāka": ['mw'],
    "śūlā": ['ap90', 'mw'],
    "śūlādhiropita": ['mw'],
    "śūlāgra": ['cae', 'ddsa', 'mw'],
    "śūlākṛ": ['cae', 'ddsa', 'mw'],
    "śūlākṛta": ['mw'],
    "śūlākṛtaṃ": ['ap90'],
    "śūlāpāla": ['mw'],
    "śūlāri": ['mw'],
    "śūlāropaṇa": ['mw'],
    "śūlāvataṃsita": ['mw'],
    "śūlāṅka": ['mw'],
    "śūlī": ['mw'],
    "śūlīka": ['mw'],
    "śūna": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śūnagātra": ['mw'],
    "śūnatva": ['mw'],
    "śūnavat": ['mw'],
    "śūnya": ['ap90', 'cae', 'ddsa', 'mw'],
    "śūnyabandhu": ['mw'],
    "śūnyabhāva": ['mw'],
    "śūnyabindu": ['mw'],
    "śūnyacitta": ['cae', 'ddsa', 'mw'],
    "śūnyageha": ['cae', 'mw'],
    "śūnyahara": ['mw'],
    "śūnyahasta": ['mw'],
    "śūnyahṛdaya": ['cae', 'mw'],
    "śūnyahṛdayatva": ['mw'],
    "śūnyaiṣa": ['mw'],
    "śūnyaka": ['bhs', 'mw'],
    "śūnyakalpa": ['bhs'],
    "śūnyakarṇa": ['mw'],
    "śūnyamadhya": ['mw'],
    "śūnyamanas": ['cae', 'mw'],
    "śūnyamūla": ['mw'],
    "śūnyapadavī": ['mw'],
    "śūnyapakṣa": ['mw'],
    "śūnyapāla": ['cae', 'mw'],
    "śūnyasthāna": ['mw'],
    "śūnyatva": ['mw'],
    "śūnyatā": ['bhs', 'cae', 'mw'],
    "śūnyatāsamāpti": ['mw'],
    "śūnyavat": ['mw'],
    "śūnyavyāpāra": ['mw'],
    "śūnyavāda": ['mw'],
    "śūnyavādin": ['mw'],
    "śūnyaśarīra": ['mw'],
    "śūnyaśarīratā": ['mw'],
    "śūnyaśālā": ['mw'],
    "śūnyaśūnya": ['mw'],
    "śūnyā": ['ap90', 'mw'],
    "śūnyāgāra": ['bhs'],
    "śūnyāgārakṛtālaya": ['mw'],
    "śūnyākṛti": ['mw'],
    "śūnyālaya": ['mw'],
    "śūnyāśaya": ['mw'],
    "śūnyāśūnya": ['mw'],
    "śūnyī": ['mw'],
    "śūnyībhū": ['mw'],
    "śūnyīkṛ": ['cae', 'ddsa', 'mw'],
    "śūnā": ['ap90', 'cae', 'ddsa', 'mw'],
    "śūnākṣa": ['mw'],
    "śūnāṇḍameḍhratā": ['mw'],
    "śūpakāra": ['mw'],
    "śūr": ['ap90', 'ddsa', 'gra', 'mw'],
    "śūra": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "śūrabala": ['bhs', 'mw'],
    "śūrabhogeśvara": ['mw'],
    "śūrabhū": ['mw'],
    "śūrabhūmi": ['mw'],
    "śūradanta": ['mw'],
    "śūradatta": ['bhs'],
    "śūradeva": ['cae', 'mw'],
    "śūradhvaja": ['bhs'],
    "śūragrāma": ['gra', 'mw'],
    "śūraja": ['mw'],
    "śūraka": ['mw'],
    "śūrakīṭa": ['mw'],
    "śūrakūṭa": ['bhs'],
    "śūramaṭha": ['mw'],
    "śūrammanya": ['mw'],
    "śūramāna": ['mw'],
    "śūramānin": ['cae', 'mw'],
    "śūramūrdhamaya": ['mw'],
    "śūrapatnī": ['cae', 'gra', 'mw'],
    "śūrapura": ['cae', 'mw'],
    "śūraputrā": ['cae', 'mw'],
    "śūrasena": ['cae', 'mw'],
    "śūrasenā": ['mw'],
    "śūrasenī": ['mw'],
    "śūrasiṃha": ['mw'],
    "śūrasāti": ['cae', 'gra', 'mw'],
    "śūratama": ['mw'],
    "śūratara": ['mw'],
    "śūrataraka": ['bhs'],
    "śūratva": ['mw'],
    "śūratā": ['cae', 'ddsa', 'mw'],
    "śūravarman": ['cae', 'mw'],
    "śūravidya": ['mw'],
    "śūravākya": ['mw'],
    "śūravīra": ['cae', 'mw'],
    "śūraśloka": ['mw'],
    "śūraṃgama": ['bhs', 'mw'],
    "śūraṃgamasamādhinirdeśa": ['bhs', 'mw'],
    "śūraṃmanya": ['ap90'],
    "śūraṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "śūraṇaḥ": ['ap90'],
    "śūraṇodbhuja": ['mw'],
    "śūreśvara": ['ddsa', 'mw'],
    "śūrma": ['mw'],
    "śūrmaḥ": ['ap90'],
    "śūrmi": ['mw'],
    "śūrp": ['ap90', 'mw'],
    "śūrpa": ['cae', 'ddsa', 'mw'],
    "śūrpagrāha": ['mw'],
    "śūrpagrāmaka": ['bhs'],
    "śūrpaka": ['mw'],
    "śūrpakarṇa": ['mw'],
    "śūrpakarṇapuṭa": ['mw'],
    "śūrpakhārī": ['mw'],
    "śūrpakāri": ['mw'],
    "śūrpakārāti": ['mw'],
    "śūrpanakhā": ['mw'],
    "śūrpanakhī": ['mw'],
    "śūrpaniṣpāva": ['mw'],
    "śūrpaparṇī": ['mw'],
    "śūrpapuṭa": ['mw'],
    "śūrpaviṇā": ['mw'],
    "śūrpavāta": ['mw'],
    "śūrpaśruti": ['mw'],
    "śūrpaḥ": ['ap90'],
    "śūrpaṇakhā": ['cae', 'mw'],
    "śūrpaṇāya": ['mw'],
    "śūrpaṇāyīya": ['mw'],
    "śūrpādri": ['mw'],
    "śūrpākāra": ['mw'],
    "śūrpāraka": ['cae', 'mw'],
    "śūrpī": ['ap90', 'mw'],
    "śūrta": ['ddsa', 'mw'],
    "śūryakarṇa": ['mw'],
    "śūrācārya": ['mw'],
    "śūrāditya": ['mw'],
    "śūrīkṛ": ['ddsa', 'mw'],
    "śūrṇa": ['mw'],
    "śūtha": ['mw'],
    "śūtiparṇa": ['mw'],
    "śūtiḥ": ['ap90'],
    "śūtkāra": ['ddsa', 'mw'],
    "śūśujāna": ['mw'],
    "śūśuvas": ['mw'],
    "śūṣ": ['ap90', 'mw'],
    "śūṣa": ['cae', 'ddsa', 'gra', 'mw'],
    "śūṣan": ['gra'],
    "śūṣaṇi": ['mw'],
    "śūṣia": ['gra'],
    "śūṣya": ['cae', 'gra', 'mw'],
    "śṛ": ['cae', 'ddsa'],
    "śṛddha": ['ap90', 'mw'],
    "śṛdh": ['ap90', 'ddsa', 'mw'],
    "śṛdhu": ['mw'],
    "śṛdhuḥ": ['ap90'],
    "śṛdhyā": ['cae', 'ddsa', 'gra', 'mw'],
    "śṛdhū": ['mw'],
    "śṛgāla": ['cae', 'ddsa', 'mw'],
    "śṛgālaḥ": ['ap90'],
    "śṛgālikā": ['ap90'],
    "śṛgāra": ['bhs'],
    "śṛkālaḥ": ['ap90'],
    "śṛta": ['ap90', 'cae', 'ddsa', 'mw'],
    "śṛtakāma": ['cae', 'mw'],
    "śṛtam": ['mw'],
    "śṛtapā": ['cae', 'gra', 'mw'],
    "śṛtapāka": ['gra', 'mw'],
    "śṛtatva": ['mw'],
    "śṛtaśīta": ['mw'],
    "śṛtaṃ": ['mw'],
    "śṛtaṃkartṛ": ['mw'],
    "śṛtaṃkāra": ['mw'],
    "śṛtaṃkṛta": ['mw'],
    "śṛtaṃkṛtya": ['mw'],
    "śṛtoṣṇa": ['mw'],
    "śṛtātaṅkya": ['mw'],
    "śṛtāvadāna": ['mw'],
    "śṛṃgakaḥ": ['ap90'],
    "śṛṃgavat": ['ap90'],
    "śṛṃgaṃ": ['ap90'],
    "śṛṃgikaṃ": ['ap90'],
    "śṛṃgin": ['ap90'],
    "śṛṃgiḥ": ['ap90'],
    "śṛṃgiṇaḥ": ['ap90'],
    "śṛṃgiṇī": ['ap90'],
    "śṛṃgārakaḥ": ['ap90'],
    "śṛṃgāraḥ": ['ap90'],
    "śṛṃgārin": ['ap90'],
    "śṛṃgārita": ['ap90'],
    "śṛṃgāṭakaḥ": ['ap90'],
    "śṛṃgāṭaḥ": ['ap90'],
    "śṛṃgī": ['ap90'],
    "śṛṃkhalakaḥ": ['ap90'],
    "śṛṃkhalaḥ": ['ap90'],
    "śṛṃkhalita": ['ap90'],
    "śṛṅga": ['cae', 'ddsa', 'gra', 'mw'],
    "śṛṅgabhuja": ['mw'],
    "śṛṅgadhara": ['mw'],
    "śṛṅgagiri": ['cae', 'mw'],
    "śṛṅgagrāhikā": ['mw'],
    "śṛṅgaja": ['mw'],
    "śṛṅgajāha": ['mw'],
    "śṛṅgaka": ['cae', 'mw'],
    "śṛṅgakanda": ['mw'],
    "śṛṅgakośa": ['mw'],
    "śṛṅgakūṭa": ['mw'],
    "śṛṅgalā": ['mw'],
    "śṛṅgamaya": ['mw'],
    "śṛṅgamohin": ['mw'],
    "śṛṅgamūla": ['mw'],
    "śṛṅgaprahārin": ['mw'],
    "śṛṅgapriya": ['mw'],
    "śṛṅgapura": ['cae', 'mw'],
    "śṛṅgaroha": ['mw'],
    "śṛṅgaruha": ['mw'],
    "śṛṅgasukha": ['mw'],
    "śṛṅgavant": ['cae'],
    "śṛṅgavarjita": ['mw'],
    "śṛṅgavat": ['mw'],
    "śṛṅgavera": ['cae', 'mw'],
    "śṛṅgaveracūrṇa": ['mw'],
    "śṛṅgaverakalka": ['mw'],
    "śṛṅgaveramāhātmya": ['mw'],
    "śṛṅgaverapura": ['mw'],
    "śṛṅgaverābhamūlaka": ['mw'],
    "śṛṅgavādya": ['mw'],
    "śṛṅgavādyapriya": ['mw'],
    "śṛṅgavṛṣ": ['cae', 'gra', 'mw'],
    "śṛṅgaśata": ['mw'],
    "śṛṅgeri": ['mw'],
    "śṛṅgerimaṭhā": ['mw'],
    "śṛṅgeripura": ['cae', 'ddsa', 'mw'],
    "śṛṅgerī": ['mw'],
    "śṛṅgeśvara": ['mw'],
    "śṛṅghāṇikā": ['cae', 'mw'],
    "śṛṅgi": ['mw'],
    "śṛṅgika": ['mw'],
    "śṛṅgikā": ['mw'],
    "śṛṅgin": ['cae', 'ddsa', 'gra', 'mw'],
    "śṛṅgiputra": ['mw'],
    "śṛṅgivara": ['mw'],
    "śṛṅgiṇa": ['mw'],
    "śṛṅgiṇī": ['mw'],
    "śṛṅgocchrāya": ['mw'],
    "śṛṅgonnamana": ['mw'],
    "śṛṅgonnati": ['mw'],
    "śṛṅgonnatyadhikāra": ['mw'],
    "śṛṅgotpādana": ['ddsa', 'mw'],
    "śṛṅgotpādinī": ['mw'],
    "śṛṅgoṣṇīṣa": ['mw'],
    "śṛṅgya": ['mw'],
    "śṛṅgābhihita": ['mw'],
    "śṛṅgāgrapraharaṇābhimukha": ['mw'],
    "śṛṅgāntara": ['cae', 'ddsa', 'mw'],
    "śṛṅgāra": ['cae', 'ddsa', 'mw'],
    "śṛṅgārabhedapradīpa": ['mw'],
    "śṛṅgārabhāṣita": ['mw'],
    "śṛṅgārabhūṣaṇa": ['mw'],
    "śṛṅgāracandrodaya": ['mw'],
    "śṛṅgāraceṣṭita": ['mw'],
    "śṛṅgāraceṣṭā": ['mw'],
    "śṛṅgāradhārin": ['mw'],
    "śṛṅgāradīpaka": ['mw'],
    "śṛṅgāradīpikā": ['mw'],
    "śṛṅgāragarva": ['mw'],
    "śṛṅgāragupta": ['mw'],
    "śṛṅgārahāra": ['mw'],
    "śṛṅgāraikarasa": ['mw'],
    "śṛṅgārajanman": ['mw'],
    "śṛṅgārajīvana": ['mw'],
    "śṛṅgāraka": ['mw'],
    "śṛṅgārakalikā": ['mw'],
    "śṛṅgārakaustubha": ['mw'],
    "śṛṅgārakośa": ['mw'],
    "śṛṅgāralaharī": ['mw'],
    "śṛṅgāralajjā": ['mw'],
    "śṛṅgāralatā": ['mw'],
    "śṛṅgāramañjarī": ['mw'],
    "śṛṅgāramaṇḍapa": ['mw'],
    "śṛṅgārapaddhati": ['mw'],
    "śṛṅgārapadya": ['mw'],
    "śṛṅgārapiṇḍaka": ['mw'],
    "śṛṅgāraprabandhadīpikā": ['mw'],
    "śṛṅgāraprakāśa": ['mw'],
    "śṛṅgārapāvana": ['mw'],
    "śṛṅgārarasa": ['mw'],
    "śṛṅgārarasamaṇḍana": ['mw'],
    "śṛṅgārarasavilāsa": ['mw'],
    "śṛṅgārarasodaya": ['mw'],
    "śṛṅgārarasāṣṭaka": ['mw'],
    "śṛṅgārarājīvana": ['mw'],
    "śṛṅgārasahāya": ['mw'],
    "śṛṅgārasaptaśatī": ['mw'],
    "śṛṅgārasarasī": ['mw'],
    "śṛṅgārasarvasva": ['mw'],
    "śṛṅgārasiṃha": ['mw'],
    "śṛṅgārastabaka": ['mw'],
    "śṛṅgārasudhākara": ['mw'],
    "śṛṅgārasundarī": ['mw'],
    "śṛṅgārasāra": ['mw'],
    "śṛṅgārataraṃgiṇī": ['mw'],
    "śṛṅgārataṭinī": ['mw'],
    "śṛṅgāratilaka": ['cae', 'mw'],
    "śṛṅgāratā": ['mw'],
    "śṛṅgāravairāgyataraṃgiṇī": ['mw'],
    "śṛṅgāravant": ['cae'],
    "śṛṅgāravat": ['mw'],
    "śṛṅgāravatī": ['mw'],
    "śṛṅgāraveṣa": ['mw'],
    "śṛṅgāraveṣābharaṇa": ['mw'],
    "śṛṅgāravidhi": ['mw'],
    "śṛṅgāravāpikā": ['mw'],
    "śṛṅgārayoni": ['mw'],
    "śṛṅgāraśata": ['mw'],
    "śṛṅgāraśataka": ['mw'],
    "śṛṅgāraśekhara": ['mw'],
    "śṛṅgāraśūra": ['mw'],
    "śṛṅgāraṇa": ['mw'],
    "śṛṅgārikā": ['mw'],
    "śṛṅgārin": ['cae', 'mw'],
    "śṛṅgārita": ['cae', 'ddsa', 'mw'],
    "śṛṅgāriṇī": ['mw'],
    "śṛṅgārā": ['mw'],
    "śṛṅgārābhra": ['mw'],
    "śṛṅgārādirasa": ['mw'],
    "śṛṅgārāmṛtalaharī": ['mw'],
    "śṛṅgārīy": ['cae'],
    "śṛṅgārīya": ['ddsa', 'mw'],
    "śṛṅgāy": ['cae'],
    "śṛṅgāya": ['mw'],
    "śṛṅgāṭa": ['cae', 'ddsa', 'mw'],
    "śṛṅgāṭaka": ['cae', 'mw'],
    "śṛṅgī": ['mw'],
    "śṛṅgīkanaka": ['mw'],
    "śṛṅgīviṣa": ['mw'],
    "śṛṅgīśvaratīrtha": ['mw'],
    "śṛṅkhala": ['cae', 'ddsa', 'mw'],
    "śṛṅkhalabaddha": ['mw'],
    "śṛṅkhalaka": ['mw'],
    "śṛṅkhalatodin": ['mw'],
    "śṛṅkhalatva": ['mw'],
    "śṛṅkhalatā": ['mw'],
    "śṛṅkhalay": ['cae'],
    "śṛṅkhalaya": ['ddsa', 'mw'],
    "śṛṅkhalika": ['bhs'],
    "śṛṅkhalita": ['mw'],
    "śṛṅkhalā": ['mw'],
    "śṛṅkhalābandha": ['mw'],
    "śṛṅkhalābandhana": ['mw'],
    "śṛṅkhalādāman": ['cae', 'ddsa', 'mw'],
    "śṛṅkhalākalāpa": ['cae', 'mw'],
    "śṛṅkhalāpāśa": ['mw'],
    "śṛṅkhalī": ['mw'],
    "śṛṅkhāṇikā": ['cae', 'mw'],
    "śṛṇiḥ": ['ap90'],
    "śṝ": ['ap90', 'mw'],
    "ś‍cyut": ['ddsa'],
    "ū": ['cae', 'ddsa', 'mw'],
    "ūbadhya": ['mw'],
    "ūbadhyagoha": ['mw'],
    "ūbhāva": ['mw'],
    "ūcus": ['ddsa'],
    "ūdaka": ['mw'],
    "ūdala": ['mw'],
    "ūdaleśvara": ['mw'],
    "ūddhata": ['bhs'],
    "ūdhan": ['cae', 'ddsa', 'gra'],
    "ūdhanya": ['mw'],
    "ūdhanyaṃ": ['ap90'],
    "ūdhar": ['cae', 'ddsa', 'gra'],
    "ūdhas": ['ap90', 'cae', 'gra', 'mw'],
    "ūdhasvatī": ['mw'],
    "ūdhasya": ['cae', 'mw'],
    "ūh": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ūha": ['ap90', 'cae', 'ddsa', 'mw'],
    "ūhacca": ['cped'],
    "ūhacchalā": ['mw'],
    "ūhadati": ['cped'],
    "ūhagāna": ['mw'],
    "ūhagīti": ['mw'],
    "ūhana": ['cae', 'mw'],
    "ūhanati": ['bhs', 'cped'],
    "ūhanaṃ": ['ap90'],
    "ūhanī": ['ap90', 'mw'],
    "ūhanīya": ['cae', 'mw'],
    "ūhasati": ['bhs', 'cped'],
    "ūhasita": ['bhs'],
    "ūhasiyaṁāna": ['cped'],
    "ūhata": ['bhs', 'cped'],
    "ūhate": ['bhs'],
    "ūhavant": ['cae'],
    "ūhavat": ['ddsa', 'mw'],
    "ūhaññati": ['cped'],
    "ūhaññi": ['cped'],
    "ūhin": ['ap90'],
    "ūhinī": ['mw'],
    "ūhita": ['mw'],
    "ūhitavya": ['mw'],
    "ūhivas": ['mw'],
    "ūhya": ['ap90', 'cae', 'mw'],
    "ūhyacchalā": ['mw'],
    "ūhyagāna": ['mw'],
    "ūhā": ['ap90', 'mw'],
    "ūjñā": ['bhs'],
    "ūkha": ['mw'],
    "ūkhara": ['mw'],
    "ūkāra": ['cae', 'ddsa', 'mw'],
    "ūlupin": ['ap90', 'mw'],
    "ūlī": ['cae', 'mw'],
    "ūlībhakṣam": ['mw'],
    "ūlībheda": ['mw'],
    "ūlīviveka": ['mw'],
    "ūlūka": ['ap90', 'mw'],
    "ūm": ['ap90', 'mw'],
    "ūma": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ūmi": ['cped'],
    "ūmighāta": ['cped'],
    "ūmijāta": ['cped'],
    "ūmī": ['cped'],
    "ūm̐": ['ddsa'],
    "ūna": ['ap90', 'cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ūnadasavassa": ['cped'],
    "ūnadvivārṣika": ['cae', 'mw'],
    "ūnaka": ['ap90', 'cped', 'mw'],
    "ūnakadvatikkhatuṁ": ['cped'],
    "ūnakadvitikkhatuṁ": ['cped'],
    "ūnakatikkhatuṁ": ['cped'],
    "ūnakoṭiliṅga": ['mw'],
    "ūnamāna": ['bhs'],
    "ūnarātra": ['mw'],
    "ūnarātri": ['mw'],
    "ūnatva": ['mw'],
    "ūnatā": ['mw'],
    "ūnavarṇatā": ['mw'],
    "ūnavāda": ['bhs', 'mw'],
    "ūnay": ['cae', 'gra'],
    "ūnaya": ['mw'],
    "ūnayati": ['ap90'],
    "ūnaṣoḍaśavarṣa": ['mw'],
    "ūnendupūrṇimā": ['mw'],
    "ūnita": ['ap90', 'mw'],
    "ūnodara": ['cped'],
    "ūnudara": ['cped'],
    "ūnākṣara": ['mw'],
    "ūnātirikta": ['mw'],
    "ūnībhū": ['mw'],
    "ūnīkṛ": ['mw'],
    "ūnūdara": ['cped'],
    "ūpā": ['mw'],
    "ūpāsvara": ['mw'],
    "ūrantarikā": ['cped'],
    "ūrarī": ['ap90', 'mw'],
    "ūravya": ['mw'],
    "ūravyaḥ": ['ap90'],
    "ūraṭṭhika": ['cped'],
    "ūrd": ['ap90', 'mw'],
    "ūrda": ['mw'],
    "ūrdara": ['cae', 'gra', 'mw'],
    "ūrdaraṃ": ['ap90'],
    "ūrdha": ['bhs', 'mw'],
    "ūrdhva": ['ap90', 'bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ūrdhvabarhis": ['mw'],
    "ūrdhvabhaktika": ['mw'],
    "ūrdhvabharam": ['mw'],
    "ūrdhvabhāga": ['cae', 'mw'],
    "ūrdhvabhāgahara": ['mw'],
    "ūrdhvabhāgika": ['mw'],
    "ūrdhvabhāgīya": ['bhs'],
    "ūrdhvabhāj": ['mw'],
    "ūrdhvabhās": ['gra', 'mw'],
    "ūrdhvabhāsin": ['mw'],
    "ūrdhvabhūmi": ['mw'],
    "ūrdhvabudhna": ['mw'],
    "ūrdhvabāhu": ['cae', 'mw'],
    "ūrdhvabṛhatī": ['cae', 'mw'],
    "ūrdhvacaraṇa": ['mw'],
    "ūrdhvacit": ['mw'],
    "ūrdhvacūḍa": ['cae', 'mw'],
    "ūrdhvadaṃṣṭrakeśa": ['mw'],
    "ūrdhvadeha": ['cae', 'mw'],
    "ūrdhvadeva": ['mw'],
    "ūrdhvadiś": ['mw'],
    "ūrdhvadvāra": ['mw'],
    "ūrdhvadṛś": ['cae', 'mw'],
    "ūrdhvadṛṣṭi": ['cae', 'mw'],
    "ūrdhvaga": ['bhs', 'cae', 'mw'],
    "ūrdhvagamana": ['cae', 'mw'],
    "ūrdhvagamanavant": ['cae'],
    "ūrdhvagamanavat": ['mw'],
    "ūrdhvagapura": ['mw'],
    "ūrdhvagati": ['cae', 'mw'],
    "ūrdhvagrāvan": ['gra', 'mw'],
    "ūrdhvaguda": ['mw'],
    "ūrdhvagāmin": ['cae', 'mw'],
    "ūrdhvagātman": ['mw'],
    "ūrdhvaja": ['mw'],
    "ūrdhvajatru": ['mw'],
    "ūrdhvajaṭā": ['bhs'],
    "ūrdhvajhampa": ['mw'],
    "ūrdhvajvalana": ['mw'],
    "ūrdhvajyotis": ['mw'],
    "ūrdhvajña": ['mw'],
    "ūrdhvajñu": ['cae', 'mw'],
    "ūrdhvajānu": ['cae', 'mw'],
    "ūrdhvajānuka": ['mw'],
    "ūrdhvaka": ['cae', 'mw'],
    "ūrdhvakaca": ['mw'],
    "ūrdhvakam": ['mw'],
    "ūrdhvakapāla": ['mw'],
    "ūrdhvakara": ['cae', 'ddsa', 'mw'],
    "ūrdhvakarman": ['mw'],
    "ūrdhvakarṇa": ['cae', 'mw'],
    "ūrdhvakaḥ": ['ap90'],
    "ūrdhvakaṇṭha": ['mw'],
    "ūrdhvakaṇṭhaka": ['mw'],
    "ūrdhvakaṇṭhakā": ['mw'],
    "ūrdhvakaṇṭhā": ['mw'],
    "ūrdhvaketu": ['mw'],
    "ūrdhvakeśa": ['mw'],
    "ūrdhvakeśī": ['mw'],
    "ūrdhvakriyā": ['mw'],
    "ūrdhvakāya": ['mw'],
    "ūrdhvakṛta": ['mw'],
    "ūrdhvakṛśana": ['gra', 'mw'],
    "ūrdhvaliṅga": ['mw'],
    "ūrdhvaliṅgin": ['mw'],
    "ūrdhvaloka": ['cae', 'mw'],
    "ūrdhvalokanā": ['bhs'],
    "ūrdhvam": ['mw'],
    "ūrdhvamanthin": ['mw'],
    "ūrdhvamauhūrtika": ['mw'],
    "ūrdhvamaṇḍalin": ['mw'],
    "ūrdhvamuhūrta": ['mw'],
    "ūrdhvamukha": ['cae', 'mw'],
    "ūrdhvamuṇḍa": ['cae', 'mw'],
    "ūrdhvamāna": ['mw'],
    "ūrdhvamāruta": ['mw'],
    "ūrdhvamāyu": ['mw'],
    "ūrdhvamūla": ['cae', 'mw'],
    "ūrdhvanabhas": ['cae', 'mw'],
    "ūrdhvanayana": ['mw'],
    "ūrdhvanāla": ['mw'],
    "ūrdhvanāpita": ['mw'],
    "ūrdhvapatha": ['cae', 'mw'],
    "ūrdhvapavitra": ['mw'],
    "ūrdhvapramāṇa": ['mw'],
    "ūrdhvapravarṣin": ['mw'],
    "ūrdhvapuṇḍra": ['cae', 'mw'],
    "ūrdhvapuṇḍraka": ['cae', 'mw'],
    "ūrdhvapāda": ['cae', 'mw'],
    "ūrdhvapātana": ['mw'],
    "ūrdhvapātanayantra": ['mw'],
    "ūrdhvapātra": ['cae', 'mw'],
    "ūrdhvapāṭha": ['mw'],
    "ūrdhvapūram": ['mw'],
    "ūrdhvapṛśni": ['mw'],
    "ūrdhvaraktin": ['mw'],
    "ūrdhvarekhā": ['mw'],
    "ūrdhvareta": ['cae', 'mw'],
    "ūrdhvaretas": ['cae', 'mw'],
    "ūrdhvaretastīrtha": ['mw'],
    "ūrdhvaretatīrtha": ['mw'],
    "ūrdhvaroman": ['mw'],
    "ūrdhvarāji": ['cae', 'mw'],
    "ūrdhvasad": ['mw'],
    "ūrdhvasadman": ['mw'],
    "ūrdhvasadmana": ['mw'],
    "ūrdhvasasya": ['mw'],
    "ūrdhvasaṃdhi": ['bhs'],
    "ūrdhvasaṃhanana": ['mw'],
    "ūrdhvasrota": ['bhs'],
    "ūrdhvasrotas": ['mw'],
    "ūrdhvastana": ['mw'],
    "ūrdhvasthiti": ['mw'],
    "ūrdhvastoma": ['mw'],
    "ūrdhvasvapna": ['mw'],
    "ūrdhvasāna": ['cae', 'gra', 'mw'],
    "ūrdhvasānu": ['cae', 'gra', 'mw'],
    "ūrdhvasūcikā": ['mw'],
    "ūrdhvataraṇa": ['mw'],
    "ūrdhvatas": ['cae', 'mw'],
    "ūrdhvathā": ['cae', 'gra', 'mw'],
    "ūrdhvatilaka": ['mw'],
    "ūrdhvatilakin": ['mw'],
    "ūrdhvatva": ['mw'],
    "ūrdhvatā": ['mw'],
    "ūrdhvatāla": ['mw'],
    "ūrdhvavaktra": ['mw'],
    "ūrdhvavartman": ['mw'],
    "ūrdhvavayas": ['mw'],
    "ūrdhvaveṇīdhara": ['mw'],
    "ūrdhvaveṇīdharā": ['mw'],
    "ūrdhvavirecana": ['bhs'],
    "ūrdhvavāc": ['mw'],
    "ūrdhvavāla": ['mw'],
    "ūrdhvavāsin": ['mw'],
    "ūrdhvavāsya": ['mw'],
    "ūrdhvavāta": ['mw'],
    "ūrdhvavṛta": ['cae', 'mw'],
    "ūrdhvaśocis": ['gra', 'mw'],
    "ūrdhvaśodhana": ['mw'],
    "ūrdhvaśoṣam": ['mw'],
    "ūrdhvaśuṣī": ['mw'],
    "ūrdhvaśvāsa": ['mw'],
    "ūrdhvaśāyin": ['mw'],
    "ūrdhvaṃdama": ['mw'],
    "ūrdhvaṃjānu": ['mw'],
    "ūrdhveha": ['mw'],
    "ūrdhveḍa": ['mw'],
    "ūrdhvocchvāsin": ['mw'],
    "ūrdhvā": ['mw'],
    "ūrdhvāgra": ['bhs', 'mw'],
    "ūrdhvāgraromatā": ['mw'],
    "ūrdhvāmnāya": ['mw'],
    "ūrdhvāroha": ['mw'],
    "ūrdhvāsita": ['mw'],
    "ūrdhvāvarta": ['mw'],
    "ūrdhvāya": ['mw'],
    "ūrdhvāyana": ['mw'],
    "ūrdhvāśin": ['mw'],
    "ūrdhvāṅga": ['mw'],
    "ūrdhvāṅguli": ['cae', 'ddsa', 'mw'],
    "ūrdhvīkṛ": ['mw'],
    "ūrikṛ": ['mw'],
    "ūrj": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ūrja": ['cae', 'ddsa', 'gra', 'mw'],
    "ūrjaad": ['gra'],
    "ūrjamedha": ['mw'],
    "ūrjas": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ūrjasani": ['gra', 'mw'],
    "ūrjaskara": ['mw'],
    "ūrjaspati": ['mw'],
    "ūrjastambha": ['mw'],
    "ūrjasvala": ['ap90', 'cae', 'mw'],
    "ūrjasvant": ['cae'],
    "ūrjasvat": ['ap90', 'gra', 'mw'],
    "ūrjasvatī": ['mw'],
    "ūrjasvin": ['ap90', 'cae', 'mw'],
    "ūrjasvinī": ['mw'],
    "ūrjavaha": ['mw'],
    "ūrjavia": ['gra'],
    "ūrjavya": ['ap90', 'gra', 'mw'],
    "ūrjavāha": ['mw'],
    "ūrjay": ['cae', 'gra'],
    "ūrjaya": ['ddsa'],
    "ūrjayantatīrtha": ['mw'],
    "ūrjayat": ['mw'],
    "ūrjayati": ['ap90'],
    "ūrjayoni": ['mw'],
    "ūrjaḥ": ['ap90'],
    "ūrji": ['gra'],
    "ūrjin": ['ap90', 'cae', 'mw'],
    "ūrjita": ['ap90', 'cae', 'mw'],
    "ūrjitacitta": ['mw'],
    "ūrjitam": ['mw'],
    "ūrjitāśraya": ['mw'],
    "ūrjā": ['mw'],
    "ūrjād": ['gra', 'mw'],
    "ūrjāhuti": ['gra', 'mw'],
    "ūrjānī": ['gra', 'mw'],
    "ūrjāvant": ['cae'],
    "ūrjāvat": ['mw'],
    "ūrmi": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ūrmikā": ['ap90', 'cae', 'ddsa', 'mw'],
    "ūrmilā": ['ap90', 'cae', 'mw'],
    "ūrmimant": ['cae'],
    "ūrmimat": ['ap90', 'mw'],
    "ūrmimattā": ['mw'],
    "ūrmimālin": ['mw'],
    "ūrmimālā": ['cae', 'mw'],
    "ūrmin": ['ap90', 'cae', 'gra', 'mw'],
    "ūrmiā": ['gra'],
    "ūrmiḥ": ['ap90'],
    "ūrmiṣaṭkātiga": ['mw'],
    "ūrmya": ['ap90', 'cae', 'mw'],
    "ūrmyā": ['gra', 'mw'],
    "ūru": ['cae', 'cped', 'ddsa', 'gra', 'mw'],
    "ūrubali": ['cped'],
    "ūrubalin": ['cped'],
    "ūrubhaṅga": ['mw'],
    "ūrubhinna": ['mw'],
    "ūrubhitti": ['mw'],
    "ūrucchinna": ['mw'],
    "ūrudaghna": ['mw'],
    "ūrudvayasa": ['mw'],
    "ūruglāni": ['mw'],
    "ūrugraha": ['mw'],
    "ūrugrahin": ['mw'],
    "ūrugrāha": ['mw'],
    "ūruja": ['mw'],
    "ūrujanman": ['cae', 'mw'],
    "ūrukkhambha": ['cped'],
    "ūrumātra": ['mw'],
    "ūrumūla": ['mw'],
    "ūruntarikā": ['cped'],
    "ūruparvan": ['mw'],
    "ūruphalaka": ['mw'],
    "ūrurī": ['ap90', 'mw'],
    "ūrusaṃbhava": ['cae'],
    "ūruskambha": ['cae', 'mw'],
    "ūruskambhagṛhīta": ['mw'],
    "ūrustambha": ['cae', 'mw'],
    "ūrustambhā": ['mw'],
    "ūrusāda": ['mw'],
    "ūrutthambha": ['cped'],
    "ūruḥ": ['ap90'],
    "ūruṇikā": ['bhs'],
    "ūruṣkambha": ['mw'],
    "ūruṭṭhika": ['cped'],
    "ūrv": ['mw'],
    "ūrva": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ūrvarā": ['ap90', 'mw'],
    "ūrvastha": ['cae', 'mw'],
    "ūrvasthamātra": ['mw'],
    "ūrvaśī": ['mw'],
    "ūrvaṅga": ['mw'],
    "ūrvaṣṭhīva": ['mw'],
    "ūrvaṣṭīva": ['cae'],
    "ūrvya": ['ap90', 'mw'],
    "ūrvyaṃgaṃ": ['ap90'],
    "ūrvī": ['mw'],
    "ūryādi": ['mw'],
    "ūrī": ['ap90', 'mw'],
    "ūrūdbhava": ['cae', 'ddsa', 'mw'],
    "ūrūpapīḍam": ['mw'],
    "ūrṇa": ['cae', 'ddsa', 'gra', 'mw'],
    "ūrṇamrada": ['cae'],
    "ūrṇamradas": ['cae', 'gra', 'mw'],
    "ūrṇanābha": ['cae', 'mw'],
    "ūrṇanābhi": ['cae', 'mw'],
    "ūrṇanābhī": ['mw'],
    "ūrṇapaṭa": ['mw'],
    "ūrṇapāśa": ['bhs'],
    "ūrṇatejas": ['bhs'],
    "ūrṇavābhi": ['cae', 'gra', 'mw'],
    "ūrṇavāhi": ['mw'],
    "ūrṇaśiriprabhāsamati": ['bhs'],
    "ūrṇaṃ": ['ap90'],
    "ūrṇodara": ['mw'],
    "ūrṇu": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ūrṇuta": ['mw'],
    "ūrṇā": ['ap90', 'bhs', 'ddsa', 'gra', 'mw'],
    "ūrṇākośa": ['bhs'],
    "ūrṇālaṃkṛtamukhatā": ['mw'],
    "ūrṇāmaya": ['cae', 'mw'],
    "ūrṇāmradas": ['cae', 'mw'],
    "ūrṇāmṛdu": ['cae', 'mw'],
    "ūrṇāpiṇḍa": ['mw'],
    "ūrṇāstukā": ['mw'],
    "ūrṇāsūtra": ['mw'],
    "ūrṇāvala": ['mw'],
    "ūrṇāvant": ['cae'],
    "ūrṇāvat": ['gra', 'mw'],
    "ūrṇāvatī": ['mw'],
    "ūrṇāvāhi": ['mw'],
    "ūrṇāyu": ['ap90', 'cae', 'mw'],
    "ūrṣā": ['ap90', 'mw'],
    "ūsa": ['cped'],
    "ūsara": ['cped'],
    "ūta": ['ddsa', 'mw'],
    "ūti": ['bhs', 'cae', 'ddsa', 'gra', 'mw'],
    "ūtimatī": ['mw'],
    "ūtiḥ": ['ap90'],
    "ūtīka": ['mw'],
    "ūvadhya": ['ddsa', 'gra', 'mw'],
    "ūvarṇa": ['mw'],
    "ūvaṭa": ['mw'],
    "ūy": ['ap90', 'mw'],
    "ūḍha": ['ap90', 'cae', 'ddsa', 'mw'],
    "ūḍhabhārya": ['mw'],
    "ūḍhapūrva": ['mw'],
    "ūḍhapūrvā": ['cae', 'mw'],
    "ūḍharatha": ['mw'],
    "ūḍhavayas": ['mw'],
    "ūḍhaya": ['mw'],
    "ūḍhi": ['cae', 'ddsa', 'mw'],
    "ūḍhiḥ": ['ap90'],
    "ūḍhā": ['mw'],
    "ūḥ": ['ap90'],
    "ūṃ": ['mw'],
    "ūṅkh": ['gra'],
    "ūṇi": ['mw'],
    "ūṇītejas": ['mw'],
    "ūṣ": ['ap90', 'mw'],
    "ūṣa": ['cae', 'ddsa', 'mw'],
    "ūṣaka": ['cae', 'mw'],
    "ūṣakaṃ": ['ap90'],
    "ūṣapuṭa": ['mw'],
    "ūṣara": ['ap90', 'cae', 'mw'],
    "ūṣaraja": ['mw'],
    "ūṣarakṣetra": ['cae'],
    "ūṣarāya": ['mw'],
    "ūṣarāyate": ['ap90'],
    "ūṣarāyita": ['ddsa'],
    "ūṣasikata": ['mw'],
    "ūṣavat": ['ap90', 'mw'],
    "ūṣaḥ": ['ap90'],
    "ūṣaṇa": ['cae', 'mw'],
    "ūṣaṇaḥ": ['ap90'],
    "ūṣaṇā": ['mw'],
    "ūṣma": ['ap90', 'mw'],
    "ūṣmabhāga": ['mw'],
    "ūṣmagata": ['bhs'],
    "ūṣmaja": ['mw'],
    "ūṣmaka": ['mw'],
    "ūṣman": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ūṣmapa": ['cae', 'ddsa', 'mw'],
    "ūṣmapara": ['mw'],
    "ūṣmaprakṛti": ['mw'],
    "ūṣmapura": ['mw'],
    "ūṣmatva": ['mw'],
    "ūṣmavat": ['mw'],
    "ūṣmaṇa": ['ap90'],
    "ūṣmaṇia": ['gra'],
    "ūṣmaṇya": ['gra', 'mw'],
    "ūṣmopagama": ['mw'],
    "ūṣmā": ['mw'],
    "ūṣmānta": ['mw'],
    "ūṣmāntaḥstha": ['mw'],
    "ūṣmāpaha": ['mw'],
    "ūṣmāya": ['mw'],
    "ūṣmāyate": ['ap90'],
    "ūṣmāyaṇa": ['mw'],
    "ūṣus": ['ddsa'],
    "ūṣā": ['ap90', 'mw'],
    "ūṣī": ['ddsa'],
    "ūṭh": ['mw'],
    "ḍa": ['mw'],
    "ḍaha": ['bhs', 'cped'],
    "ḍaha(t)": ['cped'],
    "ḍahanta": ['cped'],
    "ḍahati": ['cped'],
    "ḍahetvā": ['cped'],
    "ḍahitvā": ['cped'],
    "ḍahu": ['mw'],
    "ḍahāla": ['mw'],
    "ḍahū": ['mw'],
    "ḍakkārī": ['ap90', 'mw'],
    "ḍakāra": ['mw'],
    "ḍalaka": ['mw'],
    "ḍalakaṃ": ['ap90'],
    "ḍalana": ['mw'],
    "ḍallaka": ['ddsa', 'mw'],
    "ḍallana": ['mw'],
    "ḍam": ['ap90', 'cae', 'ddsa', 'mw'],
    "ḍama": ['cae', 'ddsa', 'mw'],
    "ḍamara": ['cae', 'ddsa', 'mw'],
    "ḍamaraḥ": ['ap90'],
    "ḍamarin": ['cae', 'ddsa', 'mw'],
    "ḍamaru": ['ddsa', 'mw'],
    "ḍamaruka": ['mw'],
    "ḍamaruyantra": ['mw'],
    "ḍamaruḥ": ['ap90'],
    "ḍamaḥ": ['ap90'],
    "ḍamb": ['cae', 'ddsa', 'mw'],
    "ḍambara": ['cae', 'ddsa', 'mw'],
    "ḍambaranāman": ['mw'],
    "ḍambarasiṃha": ['mw'],
    "ḍambh": ['mw'],
    "ḍambha": ['ddsa', 'mw'],
    "ḍambhā": ['bhs', 'mw'],
    "ḍambura": ['mw'],
    "ḍamp": ['mw'],
    "ḍap": ['ap90', 'mw'],
    "ḍasati": ['cped'],
    "ḍasitabba": ['cped'],
    "ḍassati": ['cped'],
    "ḍauṇḍubha": ['cae', 'ddsa', 'mw'],
    "ḍavittha": ['cae', 'ddsa', 'mw'],
    "ḍavitthaḥ": ['ap90'],
    "ḍayana": ['mw'],
    "ḍayanaṃ": ['ap90'],
    "ḍayati": ['cped'],
    "ḍayhamāna": ['cped'],
    "ḍayhanta": ['cped'],
    "ḍayhati": ['cped'],
    "ḍayhittho": ['cped'],
    "ḍayhiṁsu": ['cped'],
    "ḍaḥ": ['ap90'],
    "ḍaṁsa": ['cped'],
    "ḍaṁsati": ['cped'],
    "ḍaṁsitabba": ['cped'],
    "ḍaṁsādhipātā": ['cped'],
    "ḍaṃb": ['ap90'],
    "ḍaṃbara": ['ap90'],
    "ḍaṃbh": ['ap90'],
    "ḍaṃp": ['ap90'],
    "ḍaṅgara": ['mw'],
    "ḍaṅgarī": ['mw'],
    "ḍaṅgārī": ['mw'],
    "ḍaṅkamāhātmya": ['mw'],
    "ḍaṭṭha": ['cped'],
    "ḍerikā": ['cae', 'mw'],
    "ḍeti": ['cped'],
    "ḍeṇḍima": ['cped'],
    "ḍha": ['mw'],
    "ḍhakka": ['cae', 'ddsa', 'mw'],
    "ḍhakkadeśīya": ['ddsa', 'mw'],
    "ḍhakkana": ['ddsa', 'mw'],
    "ḍhakkā": ['ap90', 'mw'],
    "ḍhakkārī": ['mw'],
    "ḍhakāra": ['mw'],
    "ḍhalita": ['bhs'],
    "ḍhauk": ['ap90', 'cae', 'ddsa', 'mw'],
    "ḍhaukana": ['cae', 'ddsa', 'mw'],
    "ḍhaukanaṃ": ['ap90'],
    "ḍhaukita": ['mw'],
    "ḍhaulaḥ": ['ap90'],
    "ḍhaḍḍhara": ['mw'],
    "ḍhaḥ": ['ap90'],
    "ḍhaṅka": ['mw'],
    "ḍhaṇṭī": ['mw'],
    "ḍhevvukā": ['mw'],
    "ḍheṅka": ['cae', 'ddsa', 'mw'],
    "ḍheṅkikā": ['mw'],
    "ḍheṅkikātāla": ['mw'],
    "ḍheṅkī": ['mw'],
    "ḍhillikā": ['mw'],
    "ḍhillī": ['mw'],
    "ḍhilī": ['mw'],
    "ḍhiṇḍhiṇikā": ['mw'],
    "ḍhola": ['cae', 'ddsa', 'mw'],
    "ḍholasamudrikā": ['mw'],
    "ḍholla": ['bhs'],
    "ḍhollarī": ['mw'],
    "ḍholāsamudra": ['mw'],
    "ḍhorasamudra": ['mw'],
    "ḍhuḍhi": ['mw'],
    "ḍhuṃḍhanaṃ": ['ap90'],
    "ḍhuṃḍhiḥ": ['ap90'],
    "ḍhuṇḍh": ['mw'],
    "ḍhuṇḍhana": ['mw'],
    "ḍhuṇḍhi": ['mw'],
    "ḍhuṇḍhikā": ['mw'],
    "ḍhuṇḍhirāja": ['mw'],
    "ḍhuṇḍhirājākhyāna": ['mw'],
    "ḍhuṇḍhita": ['mw'],
    "ḍhāla": ['cae', 'ddsa', 'mw'],
    "ḍhālayati": ['bhs'],
    "ḍhālaṃ": ['ap90'],
    "ḍhālin": ['ap90', 'cae', 'mw'],
    "ḍhāmarā": ['ap90', 'cae', 'ddsa', 'mw'],
    "ḍhārikā": ['mw'],
    "ḍikkarikā": ['mw'],
    "ḍikkarī": ['ap90'],
    "ḍilli": ['cae', 'ddsa', 'mw'],
    "ḍillī": ['cae', 'mw'],
    "ḍim": ['ap90', 'mw'],
    "ḍima": ['cae', 'ddsa', 'mw'],
    "ḍimaḥ": ['ap90'],
    "ḍimb": ['mw'],
    "ḍimba": ['bhs', 'cae', 'ddsa', 'mw'],
    "ḍimbara": ['bhs'],
    "ḍimbayuddha": ['mw'],
    "ḍimbh": ['mw'],
    "ḍimbha": ['cae', 'ddsa', 'mw'],
    "ḍimbhacakra": ['mw'],
    "ḍimbhaka": ['mw'],
    "ḍimbhalīlā": ['cae'],
    "ḍimbhā": ['mw'],
    "ḍimbhāḍimbha": ['mw'],
    "ḍimbikā": ['mw'],
    "ḍimbāhava": ['mw'],
    "ḍimp": ['mw'],
    "ḍimphika": ['bhs'],
    "ḍip": ['ap90', 'mw'],
    "ḍittha": ['cae', 'ddsa', 'mw'],
    "ḍitthatva": ['mw'],
    "ḍitthatā": ['mw'],
    "ḍitthaḥ": ['ap90'],
    "ḍiyati": ['cped'],
    "ḍiḍimāṇaka": ['mw'],
    "ḍiṃbaḥ": ['ap90'],
    "ḍiṃbhakaḥ": ['ap90'],
    "ḍiṃbhaḥ": ['ap90'],
    "ḍiṃbikā": ['ap90'],
    "ḍiṃgaraḥ": ['ap90'],
    "ḍiṃḍimaḥ": ['ap90'],
    "ḍiṃḍiraḥ": ['ap90'],
    "ḍiṃḍīraḥ": ['ap90'],
    "ḍiṅgara": ['mw'],
    "ḍiṇḍibha": ['mw'],
    "ḍiṇḍika": ['mw'],
    "ḍiṇḍima": ['cae', 'cped', 'ddsa', 'mw'],
    "ḍiṇḍimatva": ['mw'],
    "ḍiṇḍimeśvaratīrtha": ['mw'],
    "ḍiṇḍimāṇava": ['mw'],
    "ḍiṇḍira": ['mw'],
    "ḍiṇḍiramodaka": ['mw'],
    "ḍiṇḍiśa": ['mw'],
    "ḍiṇḍīra": ['mw'],
    "ḍolā": ['mw'],
    "ḍoma": ['mw'],
    "ḍomaḥ": ['ap90'],
    "ḍomba": ['cae', 'ddsa', 'mw'],
    "ḍombint": ['bhs'],
    "ḍombulī": ['mw'],
    "ḍombī": ['mw'],
    "ḍombīheruka": ['bhs'],
    "ḍora": ['mw'],
    "ḍoraka": ['mw'],
    "ḍoraḍī": ['mw'],
    "ḍoraḥ": ['ap90'],
    "ḍoḍa": ['mw'],
    "ḍoḍahī": ['mw'],
    "ḍoḍī": ['mw'],
    "ḍoḍīyā": ['mw'],
    "ḍoṅkāra": ['bhs'],
    "ḍula": ['mw'],
    "ḍuli": ['mw'],
    "ḍulikā": ['mw'],
    "ḍuliḥ": ['ap90'],
    "ḍulya": ['mw'],
    "ḍulī": ['mw'],
    "ḍumba": ['mw'],
    "ḍumbara": ['mw'],
    "ḍunduka": ['mw'],
    "ḍuḍubha": ['cae', 'mw'],
    "ḍuḍuma": ['cae'],
    "ḍuṃdukaḥ": ['ap90'],
    "ḍuṃḍubhaḥ": ['ap90'],
    "ḍuṃḍulaḥ": ['ap90'],
    "ḍuṇḍhi": ['mw'],
    "ḍuṇḍu": ['mw'],
    "ḍuṇḍubha": ['ddsa', 'mw'],
    "ḍuṇḍula": ['mw'],
    "ḍuṇḍura": ['mw'],
    "ḍval": ['ap90', 'cae', 'ddsa', 'mw'],
    "ḍā": ['mw'],
    "ḍābhī": ['mw'],
    "ḍāgineya": ['ddsa', 'mw'],
    "ḍāgineyaka": ['mw'],
    "ḍāginī": ['ddsa', 'mw'],
    "ḍāha": ['cped'],
    "ḍāhala": ['cae', 'mw'],
    "ḍāhalaḥ": ['ap90'],
    "ḍāhalādhīśa": ['mw'],
    "ḍāhuka": ['mw'],
    "ḍāhukaḥ": ['ap90'],
    "ḍāhāla": ['cae', 'mw'],
    "ḍāka": ['cped', 'mw'],
    "ḍākinī": ['ap90', 'cae', 'ddsa', 'mw'],
    "ḍākinītva": ['mw'],
    "ḍāla": ['cae', 'mw'],
    "ḍālacandra": ['mw'],
    "ḍālima": ['mw'],
    "ḍālimaḥ": ['ap90'],
    "ḍāmara": ['ap90', 'bhs', 'cae', 'ddsa', 'mw'],
    "ḍāmarabhairavatantra": ['mw'],
    "ḍāmaratantra": ['mw'],
    "ḍāmaratva": ['mw'],
    "ḍāmarava": ['mw'],
    "ḍāmarika": ['bhs'],
    "ḍāmbhiṭṭa": ['mw'],
    "ḍāmbhiṭṭatva": ['mw'],
    "ḍātkṛti": ['cae', 'ddsa', 'mw'],
    "ḍāṃkṛti": ['cae', 'mw'],
    "ḍāṃkṛtiḥ": ['ap90'],
    "ḍāṅgarī": ['mw'],
    "ḍāṅkṛti": ['ddsa'],
    "ḍī": ['ap90', 'cae', 'ddsa', 'mw'],
    "ḍīna": ['ap90', 'cae', 'ddsa', 'mw'],
    "ḍīnaḍīnaka": ['mw'],
    "ḍūlūvaiśvānara": ['mw'],
    "ḍūma": ['bhs'],
    "ḷ": ['ap90', 'mw'],
    "ḷaṅghāpeti": ['cped'],
    "ḷkāra": ['mw'],
    "ḷtaka": ['mw'],
    "ḷvarṇa": ['mw'],
    "ḷāpukaṭāha": ['cped'],
    "ḷṅ": ['ap90'],
    "ḷṭ": ['ap90'],
    "ḹ": ['ap90', 'mw'],
    "ṅa": ['mw'],
    "ṅakāra": ['mw'],
    "ṅaḥ": ['ap90'],
    "ṅu": ['ap90', 'mw'],
    "ṇa": ['mw'],
    "ṇakāra": ['mw'],
    "ṇaḥ": ['ap90'],
    "ṇi": ['ddsa'],
    "ṇit": ['ddsa'],
    "ṇvul": ['ddsa'],
    "ṇya": ['ddsa', 'mw'],
    "ṇyanta": ['ddsa'],
    "ṛ": ['ap90', 'cae', 'gra', 'mw'],
    "ṛbhu": ['ap90', 'cae', 'gra', 'mw'],
    "ṛbhukṣa": ['mw'],
    "ṛbhukṣan": ['cae', 'gra'],
    "ṛbhukṣaḥ": ['ap90'],
    "ṛbhukṣin": ['ap90', 'mw'],
    "ṛbhukṣā": ['cae', 'gra'],
    "ṛbhukṣīṇa": ['mw'],
    "ṛbhumat": ['gra', 'mw'],
    "ṛbhuṣṭhira": ['gra', 'mw'],
    "ṛbhva": ['ap90', 'cae', 'gra', 'mw'],
    "ṛbhvan": ['ap90', 'cae', 'gra', 'mw'],
    "ṛbhvas": ['cae', 'gra', 'mw'],
    "ṛbīsa": ['cae', 'gra', 'mw'],
    "ṛbīsapakva": ['mw'],
    "ṛbīsaṃ": ['ap90'],
    "ṛc": ['ap90', 'cae', 'gra', 'mw'],
    "ṛca": ['mw'],
    "ṛcas": ['ap90', 'gra'],
    "ṛcase": ['cae'],
    "ṛcatka": ['gra'],
    "ṛcch": ['ap90'],
    "ṛcchaka": ['mw'],
    "ṛcchakā": ['ap90'],
    "ṛccharā": ['ap90', 'mw'],
    "ṛcchā": ['mw'],
    "ṛceyu": ['mw'],
    "ṛch": ['gra', 'mw'],
    "ṛcābha": ['mw'],
    "ṛcīka": ['cae', 'mw'],
    "ṛcīkaḥ": ['ap90'],
    "ṛcīṣa": ['mw'],
    "ṛcīṣama": ['cae', 'gra', 'mw'],
    "ṛcīṣaḥ": ['ap90'],
    "ṛd": ['cae'],
    "ṛddha": ['ap90', 'cae', 'mw'],
    "ṛddhati": ['bhs'],
    "ṛddhi": ['bhs', 'cae', 'mw'],
    "ṛddhidatta": ['bhs'],
    "ṛddhika": ['bhs'],
    "ṛddhikāma": ['mw'],
    "ṛddhila": ['mw'],
    "ṛddhilakṣmī": ['mw'],
    "ṛddhilamātar": ['bhs'],
    "ṛddhimant": ['cae'],
    "ṛddhimat": ['ap90', 'mw'],
    "ṛddhiprātihārya": ['bhs'],
    "ṛddhipāda": ['bhs', 'mw'],
    "ṛddhipādanipāta": ['bhs'],
    "ṛddhita": ['mw'],
    "ṛddhivikrīḍita": ['bhs'],
    "ṛddhiḥ": ['ap90'],
    "ṛdh": ['ap90', 'cae', 'gra', 'mw'],
    "ṛdhad": ['mw'],
    "ṛdhadrī": ['gra', 'mw'],
    "ṛdhadvāra": ['gra', 'mw'],
    "ṛdhaj": ['ap90'],
    "ṛdhak": ['ap90', 'cae', 'gra', 'mw'],
    "ṛdhat": ['ap90'],
    "ṛdhaṅ": ['mw'],
    "ṛdhaṅmantra": ['mw'],
    "ṛdhmuka": ['mw'],
    "ṛdhuka": ['mw'],
    "ṛdhyati": ['bhs'],
    "ṛdu": ['gra'],
    "ṛdū": ['mw'],
    "ṛdūdara": ['ap90', 'cae', 'gra', 'mw'],
    "ṛdūpā": ['gra', 'mw'],
    "ṛdūvṛdh": ['gra', 'mw'],
    "ṛg": ['mw'],
    "ṛgarthasāra": ['mw'],
    "ṛgava": ['bhs'],
    "ṛgayana": ['mw'],
    "ṛgayanādi": ['mw'],
    "ṛgaśīti": ['mw'],
    "ṛgbhāj": ['mw'],
    "ṛgbhāṣya": ['mw'],
    "ṛgbrāhmaṇa": ['mw'],
    "ṛggaṇa": ['mw'],
    "ṛggāthā": ['mw'],
    "ṛghā": ['mw'],
    "ṛghāvan": ['cae', 'gra', 'mw'],
    "ṛghāvant": ['cae'],
    "ṛghāvat": ['ap90', 'gra', 'mw'],
    "ṛghāy": ['cae', 'gra'],
    "ṛghāya": ['mw'],
    "ṛghāyati": ['ap90'],
    "ṛgiti": ['bhs'],
    "ṛgma": ['ap90', 'mw'],
    "ṛgmat": ['ap90', 'mw'],
    "ṛgmin": ['cae', 'gra', 'mw'],
    "ṛgmiya": ['ap90', 'cae', 'gra', 'mw'],
    "ṛgmya": ['mw'],
    "ṛguttama": ['mw'],
    "ṛgveda": ['cae', 'mw'],
    "ṛgvedabhāṣya": ['mw'],
    "ṛgvedaprātiśākhya": ['mw'],
    "ṛgvedasaṃhitā": ['mw'],
    "ṛgvedavid": ['mw'],
    "ṛgvedin": ['mw'],
    "ṛgvedānukramaṇikā": ['mw'],
    "ṛgvedīya": ['mw'],
    "ṛgvid": ['mw'],
    "ṛgvidhāna": ['cae', 'mw'],
    "ṛgvirāma": ['mw'],
    "ṛgyajus": ['mw'],
    "ṛgyajuḥsāmaveda": ['mw'],
    "ṛgyajuḥsāmavedin": ['mw'],
    "ṛgyajuṣ": ['cae'],
    "ṛgyajuṣa": ['mw'],
    "ṛgātmaka": ['mw'],
    "ṛgāvānam": ['mw'],
    "ṛhant": ['cae'],
    "ṛhat": ['ap90', 'gra', 'mw'],
    "ṛj": ['ap90', 'cae', 'gra', 'mw'],
    "ṛjara": ['gra'],
    "ṛjiman": ['mw'],
    "ṛjipya": ['ap90', 'cae', 'gra', 'mw'],
    "ṛjiśvan": ['gra', 'mw'],
    "ṛjiṣṭha": ['mw'],
    "ṛjju": ['bhs'],
    "ṛjra": ['cae', 'gra', 'mw'],
    "ṛjraaśva": ['gra'],
    "ṛjrāśva": ['gra', 'mw'],
    "ṛju": ['ap90', 'cae', 'gra', 'mw'],
    "ṛjuac": ['gra'],
    "ṛjuañc": ['gra'],
    "ṛjubhāva": ['bhs'],
    "ṛjubuddhi": ['mw'],
    "ṛjudhā": ['ap90', 'mw'],
    "ṛjudārumaya": ['mw'],
    "ṛjudāsa": ['mw'],
    "ṛjudṛś": ['mw'],
    "ṛjuga": ['mw'],
    "ṛjugātha": ['gra', 'mw'],
    "ṛjugātratā": ['mw'],
    "ṛjuhasta": ['gra', 'mw'],
    "ṛjuka": ['bhs'],
    "ṛjukratu": ['gra', 'mw'],
    "ṛjukāya": ['mw'],
    "ṛjulekha": ['mw'],
    "ṛjulekhā": ['mw'],
    "ṛjumati": ['mw'],
    "ṛjumitākṣarā": ['mw'],
    "ṛjumuṣka": ['gra', 'mw'],
    "ṛjunīti": ['gra', 'mw'],
    "ṛjupakṣa": ['mw'],
    "ṛjupālikā": ['mw'],
    "ṛjuraśmi": ['mw'],
    "ṛjurohita": ['mw'],
    "ṛjusarpa": ['mw'],
    "ṛjutva": ['cae', 'mw'],
    "ṛjutā": ['ap90', 'cae', 'mw'],
    "ṛjuvani": ['gra', 'mw'],
    "ṛjuvyākaraṇa": ['mw'],
    "ṛjuyodhin": ['mw'],
    "ṛjvac": ['ap90', 'gra'],
    "ṛjvañc": ['mw'],
    "ṛjvāgata": ['mw'],
    "ṛjvāhva": ['mw'],
    "ṛjvālikhita": ['mw'],
    "ṛjvāyata": ['mw'],
    "ṛjvī": ['ap90', 'mw'],
    "ṛjīka": ['ap90', 'cae', 'gra', 'mw'],
    "ṛjīkṛtavant": ['bhs'],
    "ṛjīpin": ['gra', 'mw'],
    "ṛjīti": ['cae', 'gra', 'mw'],
    "ṛjītiḥ": ['ap90'],
    "ṛjīyas": ['gra', 'mw'],
    "ṛjīyaṃs": ['cae'],
    "ṛjīṣa": ['ap90', 'cae', 'gra', 'mw'],
    "ṛjīṣin": ['ap90', 'cae', 'gra', 'mw'],
    "ṛjīṣita": ['mw'],
    "ṛjū": ['mw'],
    "ṛjūka": ['mw'],
    "ṛjūkaraṇa": ['mw'],
    "ṛjūkṛ": ['ap90', 'mw'],
    "ṛjūkṛta": ['mw'],
    "ṛjūnas": ['gra', 'mw'],
    "ṛjūy": ['cae', 'gra'],
    "ṛjūyat": ['mw'],
    "ṛjūyati": ['ap90'],
    "ṛjūyu": ['ap90', 'cae', 'gra', 'mw'],
    "ṛjūyā": ['ap90', 'cae', 'gra', 'mw'],
    "ṛk": ['mw'],
    "ṛkchas": ['mw'],
    "ṛkpada": ['mw'],
    "ṛksama": ['mw'],
    "ṛksaṃhitā": ['cae', 'mw'],
    "ṛksaṃśita": ['mw'],
    "ṛksthā": ['mw'],
    "ṛksāma": ['gra', 'mw'],
    "ṛksāman": ['mw'],
    "ṛksāmaśṛṅga": ['mw'],
    "ṛkta": ['bhs'],
    "ṛktantra": ['mw'],
    "ṛktantravyākaraṇa": ['mw'],
    "ṛktas": ['cae', 'mw'],
    "ṛktha": ['mw'],
    "ṛkthabhāgin": ['mw'],
    "ṛkthabhāj": ['mw'],
    "ṛkthagrahaṇa": ['mw'],
    "ṛkthagrāha": ['mw'],
    "ṛkthahara": ['mw'],
    "ṛkthaṃ": ['ap90'],
    "ṛkthin": ['mw'],
    "ṛkthā": ['mw'],
    "ṛkthāda": ['mw'],
    "ṛkva": ['ap90', 'cae', 'gra', 'mw'],
    "ṛkvan": ['cae', 'gra', 'mw'],
    "ṛkvant": ['cae'],
    "ṛkvat": ['gra', 'mw'],
    "ṛkāra": ['cae', 'mw'],
    "ṛkśas": ['mw'],
    "ṛkṇa": ['ap90', 'mw'],
    "ṛkṇavaha": ['mw'],
    "ṛkṣa": ['cae', 'gra', 'mw'],
    "ṛkṣabila": ['mw'],
    "ṛkṣagandhikā": ['mw'],
    "ṛkṣagandhā": ['mw'],
    "ṛkṣagiri": ['mw'],
    "ṛkṣagrīva": ['mw'],
    "ṛkṣaharīśvara": ['mw'],
    "ṛkṣajihva": ['mw'],
    "ṛkṣakarṇī": ['mw'],
    "ṛkṣalā": ['ap90', 'mw'],
    "ṛkṣama": ['mw'],
    "ṛkṣamantra": ['mw'],
    "ṛkṣanātha": ['mw'],
    "ṛkṣapati": ['mw'],
    "ṛkṣara": ['cae', 'gra', 'mw'],
    "ṛkṣaraḥ": ['ap90'],
    "ṛkṣarāj": ['mw'],
    "ṛkṣarāja": ['cae', 'mw'],
    "ṛkṣavant": ['cae'],
    "ṛkṣavanta": ['mw'],
    "ṛkṣavarṇa": ['mw'],
    "ṛkṣavat": ['ap90', 'mw'],
    "ṛkṣavibhāvana": ['mw'],
    "ṛkṣaviḍambin": ['mw'],
    "ṛkṣaḥ": ['ap90'],
    "ṛkṣeśa": ['mw'],
    "ṛkṣeṣṭi": ['cae', 'mw'],
    "ṛkṣoda": ['mw'],
    "ṛkṣā": ['mw'],
    "ṛkṣī": ['mw'],
    "ṛkṣīka": ['ap90'],
    "ṛkṣīkā": ['cae', 'mw'],
    "ṛlla": ['bhs'],
    "ṛllaka": ['bhs', 'mw'],
    "ṛllakaḥ": ['ap90'],
    "ṛllarī": ['ap90', 'mw'],
    "ṛllīsaka": ['mw'],
    "ṛmph": ['mw'],
    "ṛph": ['ap90', 'mw'],
    "ṛt": ['ap90', 'mw'],
    "ṛta": ['ap90', 'cae', 'gra', 'mw'],
    "ṛtabhuj": ['mw'],
    "ṛtabhāga": ['mw'],
    "ṛtacit": ['gra', 'mw'],
    "ṛtadhvaja": ['mw'],
    "ṛtadhāman": ['mw'],
    "ṛtadhī": ['mw'],
    "ṛtadhīti": ['cae', 'gra', 'mw'],
    "ṛtadyumna": ['cae', 'gra', 'mw'],
    "ṛtajit": ['mw'],
    "ṛtajur": ['gra', 'mw'],
    "ṛtajya": ['gra', 'mw'],
    "ṛtajñā": ['cae', 'gra', 'mw'],
    "ṛtajā": ['cae', 'gra', 'mw'],
    "ṛtajāta": ['cae', 'gra', 'mw'],
    "ṛtajātasatya": ['gra', 'mw'],
    "ṛtaka": ['mw'],
    "ṛtam": ['mw'],
    "ṛtani": ['mw'],
    "ṛtanidhana": ['mw'],
    "ṛtanī": ['cae', 'gra'],
    "ṛtaparṇa": ['mw'],
    "ṛtapeya": ['mw'],
    "ṛtapeśas": ['gra', 'mw'],
    "ṛtaprajāta": ['cae', 'gra', 'mw'],
    "ṛtaprajātā": ['mw'],
    "ṛtapravīta": ['gra', 'mw'],
    "ṛtapsu": ['cae', 'gra', 'mw'],
    "ṛtapā": ['cae', 'gra', 'mw'],
    "ṛtapātra": ['mw'],
    "ṛtasad": ['cae', 'gra', 'mw'],
    "ṛtasadana": ['mw'],
    "ṛtasadanī": ['mw'],
    "ṛtasadhastha": ['mw'],
    "ṛtasap": ['mw'],
    "ṛtasatya": ['mw'],
    "ṛtasena": ['mw'],
    "ṛtaspati": ['gra', 'mw'],
    "ṛtaspatiḥ": ['ap90'],
    "ṛtaspṛś": ['cae', 'gra', 'mw'],
    "ṛtasthā": ['mw'],
    "ṛtastubh": ['gra', 'mw'],
    "ṛtasāman": ['mw'],
    "ṛtasāp": ['cae', 'gra'],
    "ṛtasāta": ['mw'],
    "ṛtavat": ['mw'],
    "ṛtavrata": ['mw'],
    "ṛtavya": ['ap90', 'mw'],
    "ṛtavyavat": ['mw'],
    "ṛtavyā": ['mw'],
    "ṛtavyātva": ['mw'],
    "ṛtavādin": ['mw'],
    "ṛtavāka": ['cae', 'gra', 'mw'],
    "ṛtavīrya": ['mw'],
    "ṛtay": ['cae', 'gra'],
    "ṛtaya": ['mw'],
    "ṛtayati": ['ap90'],
    "ṛtayu": ['ap90', 'cae', 'gra', 'mw'],
    "ṛtayuj": ['cae', 'gra', 'mw'],
    "ṛtayukti": ['gra', 'mw'],
    "ṛtayā": ['ap90', 'cae', 'gra', 'mw'],
    "ṛtaśrī": ['mw'],
    "ṛtaṃbhara": ['mw'],
    "ṛtaṃbharaprajña": ['mw'],
    "ṛtaṃbharaḥ": ['ap90'],
    "ṛtaṃbharā": ['mw'],
    "ṛtaṃjaya": ['mw'],
    "ṛte": ['ap90', 'cae', 'gra', 'mw'],
    "ṛtebarhiṣka": ['mw'],
    "ṛtebhaṅga": ['mw'],
    "ṛtejā": ['cae', 'gra', 'mw'],
    "ṛtekarmam": ['gra', 'mw'],
    "ṛtemūla": ['mw'],
    "ṛtena": ['ap90', 'mw'],
    "ṛterakṣas": ['mw'],
    "ṛtesphya": ['mw'],
    "ṛteyajñam": ['mw'],
    "ṛteyu": ['mw'],
    "ṛti": ['cae', 'gra', 'mw'],
    "ṛtiḥ": ['ap90'],
    "ṛtiṃkara": ['ap90', 'mw'],
    "ṛtodya": ['mw'],
    "ṛtokti": ['cae', 'mw'],
    "ṛtu": ['cae', 'gra', 'mw'],
    "ṛtubhāga": ['mw'],
    "ṛtubhāj": ['mw'],
    "ṛtucaryā": ['mw'],
    "ṛtudevata": ['mw'],
    "ṛtudhāman": ['mw'],
    "ṛtugamana": ['mw'],
    "ṛtugaṇa": ['mw'],
    "ṛtugraha": ['mw'],
    "ṛtugāmin": ['mw'],
    "ṛtuhoma": ['mw'],
    "ṛtuhārikā": ['mw'],
    "ṛtujit": ['mw'],
    "ṛtujuṣ": ['mw'],
    "ṛtuka": ['bhs'],
    "ṛtukarman": ['mw'],
    "ṛtuketulakṣaṇa": ['mw'],
    "ṛtukāla": ['cae', 'mw'],
    "ṛtuliṅga": ['cae', 'mw'],
    "ṛtulokā": ['mw'],
    "ṛtumant": ['cae'],
    "ṛtumat": ['ap90', 'mw'],
    "ṛtumatī": ['mw'],
    "ṛtumaya": ['mw'],
    "ṛtumaṅgala": ['cae', 'mw'],
    "ṛtumukha": ['mw'],
    "ṛtumukhin": ['mw'],
    "ṛtunātha": ['mw'],
    "ṛtupariṇāma": ['bhs'],
    "ṛtupariṇāmika": ['bhs'],
    "ṛtuparyaya": ['cae', 'mw'],
    "ṛtuparyāya": ['mw'],
    "ṛtuparṇa": ['cae', 'mw'],
    "ṛtupati": ['gra', 'mw'],
    "ṛtupaśu": ['mw'],
    "ṛtupraiṣa": ['mw'],
    "ṛtuprāpta": ['mw'],
    "ṛtupā": ['gra', 'mw'],
    "ṛtupātra": ['mw'],
    "ṛturāja": ['mw'],
    "ṛtusahasra": ['mw'],
    "ṛtusamaya": ['mw'],
    "ṛtusamāveśana": ['mw'],
    "ṛtusaṃdhi": ['mw'],
    "ṛtusaṃhāra": ['cae', 'mw'],
    "ṛtusevya": ['mw'],
    "ṛtusnāna": ['mw'],
    "ṛtusnātā": ['mw'],
    "ṛtusthalā": ['mw'],
    "ṛtusthā": ['mw'],
    "ṛtusātmya": ['mw'],
    "ṛtuthā": ['cae', 'gra', 'mw'],
    "ṛtuvelā": ['mw'],
    "ṛtuvyāvṛtti": ['mw'],
    "ṛtuvṛtti": ['mw'],
    "ṛtuyā": ['ap90'],
    "ṛtuyāja": ['mw'],
    "ṛtuyājin": ['mw'],
    "ṛtuyājyā": ['mw'],
    "ṛtuśas": ['cae', 'gra', 'mw'],
    "ṛtuśānti": ['mw'],
    "ṛtuḥ": ['ap90'],
    "ṛtuṣāman": ['mw'],
    "ṛtuṣṭhā": ['mw'],
    "ṛtuṣṭhāyajñāyajñīya": ['mw'],
    "ṛtva": ['cae', 'mw'],
    "ṛtvan": ['mw'],
    "ṛtvanta": ['cae', 'mw'],
    "ṛtvia": ['gra'],
    "ṛtvigāśis": ['mw'],
    "ṛtvij": ['ap90', 'cae', 'gra', 'mw'],
    "ṛtvik": ['mw'],
    "ṛtvikpatha": ['mw'],
    "ṛtvikphala": ['mw'],
    "ṛtviktva": ['mw'],
    "ṛtviya": ['ap90', 'cae', 'gra', 'mw'],
    "ṛtviyavat": ['mw'],
    "ṛtviyā": ['mw'],
    "ṛtviyāvat": ['gra', 'mw'],
    "ṛtvya": ['gra', 'mw'],
    "ṛtāmṛta": ['cae', 'mw'],
    "ṛtānṛta": ['mw'],
    "ṛtāvan": ['ap90', 'cae', 'gra', 'mw'],
    "ṛtāvasu": ['gra', 'mw'],
    "ṛtāvṛdh": ['ap90', 'cae', 'gra', 'mw'],
    "ṛtāy": ['cae', 'gra'],
    "ṛtāya": ['mw'],
    "ṛtāyin": ['gra', 'mw'],
    "ṛtāyu": ['ap90', 'gra', 'mw'],
    "ṛtāyus": ['mw'],
    "ṛtāṣah": ['mw'],
    "ṛtī": ['mw'],
    "ṛtīy": ['cae'],
    "ṛtīya": ['mw'],
    "ṛtīyati": ['ap90', 'bhs'],
    "ṛtīyā": ['ap90', 'mw'],
    "ṛtīṣah": ['ap90', 'cae', 'gra', 'mw'],
    "ṛtīṣāh": ['cae'],
    "ṛtūtsava": ['cae'],
    "ṛvarṇa": ['mw'],
    "ṛvraṭā": ['bhs'],
    "ṛñj": ['gra', 'mw'],
    "ṛñjasāna": ['cae', 'mw'],
    "ṛś": ['ap90', 'gra'],
    "ṛśa": ['mw'],
    "ṛśya": ['ap90', 'cae', 'gra', 'mw'],
    "ṛśyada": ['cae', 'gra', 'mw'],
    "ṛśyagandhā": ['mw'],
    "ṛśyagatā": ['mw'],
    "ṛśyajihva": ['mw'],
    "ṛśyaka": ['mw'],
    "ṛśyaketana": ['mw'],
    "ṛśyaketu": ['mw'],
    "ṛśyalobha": ['mw'],
    "ṛśyamūka": ['cae', 'mw'],
    "ṛśyapad": ['mw'],
    "ṛśyaproktā": ['mw'],
    "ṛśyaśṛṅga": ['cae', 'mw'],
    "ṛśyādi": ['mw'],
    "ṛśyāṅka": ['mw'],
    "ṛṃj": ['ap90'],
    "ṛṃjasāna": ['ap90'],
    "ṛṅ": ['mw'],
    "ṛṅga": ['mw'],
    "ṛṅmaya": ['mw'],
    "ṛṇ": ['mw'],
    "ṛṇa": ['ap90', 'cae', 'gra', 'mw'],
    "ṛṇabhaṅgādhyāya": ['mw'],
    "ṛṇaccheda": ['mw'],
    "ṛṇacit": ['gra', 'mw'],
    "ṛṇacyut": ['gra', 'mw'],
    "ṛṇada": ['mw'],
    "ṛṇadhara": ['bhs'],
    "ṛṇadāna": ['mw'],
    "ṛṇadāsa": ['mw'],
    "ṛṇadātṛ": ['mw'],
    "ṛṇadāyin": ['mw'],
    "ṛṇagraha": ['mw'],
    "ṛṇagrāhin": ['mw'],
    "ṛṇajya": ['mw'],
    "ṛṇakartṛ": ['cae', 'mw'],
    "ṛṇakāti": ['gra', 'mw'],
    "ṛṇalekhya": ['mw'],
    "ṛṇamatkuṇa": ['mw'],
    "ṛṇamocana": ['mw'],
    "ṛṇamocanatīrtha": ['mw'],
    "ṛṇamokṣa": ['mw'],
    "ṛṇamukti": ['mw'],
    "ṛṇamārgaṇa": ['mw'],
    "ṛṇanirmokṣa": ['mw'],
    "ṛṇapradātṛ": ['mw'],
    "ṛṇasamuddhāra": ['mw'],
    "ṛṇatā": ['mw'],
    "ṛṇavan": ['cae', 'mw'],
    "ṛṇavant": ['cae'],
    "ṛṇavat": ['ap90', 'mw'],
    "ṛṇayā": ['cae', 'gra', 'mw'],
    "ṛṇayāt": ['cae', 'mw'],
    "ṛṇayāvan": ['cae', 'gra', 'mw'],
    "ṛṇaśodhana": ['mw'],
    "ṛṇaṃcaya": ['gra', 'mw'],
    "ṛṇika": ['mw'],
    "ṛṇikaḥ": ['ap90'],
    "ṛṇin": ['ap90', 'cae', 'mw'],
    "ṛṇoddhāra": ['mw'],
    "ṛṇodgrahaṇa": ['mw'],
    "ṛṇādāna": ['cae', 'mw'],
    "ṛṇāntaka": ['mw'],
    "ṛṇāpakaraṇa": ['mw'],
    "ṛṇāpanayana": ['mw'],
    "ṛṇāpanodana": ['mw'],
    "ṛṇārṇa": ['mw'],
    "ṛṇāvan": ['cae', 'gra', 'mw'],
    "ṛṣ": ['ap90', 'cae', 'gra', 'mw'],
    "ṛṣabha": ['bhs', 'cae', 'gra', 'mw'],
    "ṛṣabhacarma": ['mw'],
    "ṛṣabhadatta": ['mw'],
    "ṛṣabhadeva": ['mw'],
    "ṛṣabhadhvaja": ['mw'],
    "ṛṣabhadvīpa": ['mw'],
    "ṛṣabhadāyin": ['mw'],
    "ṛṣabhagajavilasita": ['mw'],
    "ṛṣabhagāmin": ['bhs'],
    "ṛṣabhaikādaśa": ['mw'],
    "ṛṣabhaikādhika": ['mw'],
    "ṛṣabhaka": ['mw'],
    "ṛṣabhakaḥ": ['ap90'],
    "ṛṣabhakūṭa": ['mw'],
    "ṛṣabhanetra": ['bhs'],
    "ṛṣabhapañcāśikā": ['mw'],
    "ṛṣabhapūjā": ['mw'],
    "ṛṣabhastava": ['mw'],
    "ṛṣabhatara": ['mw'],
    "ṛṣabhataraḥ": ['ap90'],
    "ṛṣabhatā": ['mw'],
    "ṛṣabhavat": ['mw'],
    "ṛṣabhavikrama": ['mw'],
    "ṛṣabhaḥ": ['ap90'],
    "ṛṣabhendrarāja": ['bhs'],
    "ṛṣabhā": ['mw'],
    "ṛṣabhānana": ['mw'],
    "ṛṣabhī": ['mw'],
    "ṛṣadgu": ['mw'],
    "ṛṣi": ['bhs', 'cae', 'gra', 'mw'],
    "ṛṣibandhu": ['gra', 'mw'],
    "ṛṣibrāhmaṇa": ['mw'],
    "ṛṣicchandas": ['mw'],
    "ṛṣicodana": ['gra', 'mw'],
    "ṛṣicāndrāyaṇa": ['mw'],
    "ṛṣidatta": ['bhs'],
    "ṛṣideva": ['bhs', 'mw'],
    "ṛṣideśa": ['mw'],
    "ṛṣidroṇa": ['mw'],
    "ṛṣidviṣ": ['cae', 'gra', 'mw'],
    "ṛṣigaṇa": ['mw'],
    "ṛṣigiri": ['mw'],
    "ṛṣigupta": ['bhs', 'mw'],
    "ṛṣijāṅgalikī": ['mw'],
    "ṛṣika": ['mw'],
    "ṛṣikalpa": ['cae', 'mw'],
    "ṛṣikaḥ": ['ap90'],
    "ṛṣikulyā": ['mw'],
    "ṛṣikumāra": ['cae'],
    "ṛṣikuśa": ['bhs'],
    "ṛṣikā": ['mw'],
    "ṛṣikṛt": ['gra', 'mw'],
    "ṛṣila": ['bhs'],
    "ṛṣiloka": ['mw'],
    "ṛṣimanas": ['gra', 'mw'],
    "ṛṣimaṇḍala": ['mw'],
    "ṛṣimukha": ['mw'],
    "ṛṣipatana": ['bhs', 'mw'],
    "ṛṣipañcamī": ['mw'],
    "ṛṣipraśiṣṭa": ['mw'],
    "ṛṣiproktā": ['mw'],
    "ṛṣiputra": ['cae', 'mw'],
    "ṛṣiputraka": ['mw'],
    "ṛṣirakṣitikā": ['bhs'],
    "ṛṣisattama": ['mw'],
    "ṛṣisaṃhitā": ['mw'],
    "ṛṣistoma": ['mw'],
    "ṛṣisvara": ['gra', 'mw'],
    "ṛṣisvādhyāya": ['mw'],
    "ṛṣisāhvaya": ['mw'],
    "ṛṣitapastaptā": ['bhs'],
    "ṛṣitarpaṇa": ['mw'],
    "ṛṣitva": ['mw'],
    "ṛṣitīrtha": ['mw'],
    "ṛṣivadana": ['bhs'],
    "ṛṣivat": ['cae', 'mw'],
    "ṛṣivāṭa": ['mw'],
    "ṛṣiyajña": ['cae', 'mw'],
    "ṛṣiśrāddha": ['mw'],
    "ṛṣiśṛṅga": ['bhs', 'mw'],
    "ṛṣiḥ": ['ap90'],
    "ṛṣiṣah": ['gra', 'mw'],
    "ṛṣiṣāṇa": ['gra', 'mw'],
    "ṛṣiṣṭuta": ['gra', 'mw'],
    "ṛṣu": ['ap90', 'cae', 'gra', 'mw'],
    "ṛṣva": ['ap90', 'cae', 'gra', 'mw'],
    "ṛṣvaojas": ['gra'],
    "ṛṣvaujas": ['gra', 'mw'],
    "ṛṣvavīra": ['gra', 'mw'],
    "ṛṣya": ['mw'],
    "ṛṣyakaḥ": ['ap90'],
    "ṛṣyamūka": ['cae'],
    "ṛṣyaśṛṅga": ['cae'],
    "ṛṣyaḥ": ['ap90'],
    "ṛṣīka": ['bhs', 'mw'],
    "ṛṣīkaḥ": ['ap90'],
    "ṛṣītata": ['ap90'],
    "ṛṣīvaha": ['mw'],
    "ṛṣīvan": ['ap90'],
    "ṛṣīvat": ['ap90', 'gra', 'mw'],
    "ṛṣīvatī": ['mw'],
    "ṛṣṭa": ['bhs', 'mw'],
    "ṛṣṭi": ['cae', 'gra', 'mw'],
    "ṛṣṭika": ['mw'],
    "ṛṣṭimant": ['cae'],
    "ṛṣṭimat": ['ap90', 'gra', 'mw'],
    "ṛṣṭividyut": ['cae', 'gra', 'mw'],
    "ṛṣṭiḥ": ['ap90'],
    "ṛṣṭiṣeṇa": ['gra', 'mw'],
    "ṛṭiti": ['bhs'],
    "ṝ": ['ap90', 'mw'],
    "ṝkāra": ['mw'],
    "ṣa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ṣac": ['mw'],
    "ṣag": ['mw'],
    "ṣagh": ['mw'],
    "ṣahasāna": ['mw'],
    "ṣahasānuḥ": ['ap90'],
    "ṣahji": ['mw'],
    "ṣahjivilāsa": ['mw'],
    "ṣakāra": ['mw'],
    "ṣalāgru": ['mw'],
    "ṣal̤": ['mw'],
    "ṣal̤aha": ['mw'],
    "ṣarjūra": ['mw'],
    "ṣarājima": ['mw'],
    "ṣarāñjima": ['mw'],
    "ṣasa": ['mw'],
    "ṣatva": ['cae', 'ddsa', 'mw'],
    "ṣatvaṇatva": ['mw'],
    "ṣaḍ": ['mw'],
    "ṣaḍabhijña": ['bhs', 'mw'],
    "ṣaḍabhijñāta": ['mw'],
    "ṣaḍadhika": ['mw'],
    "ṣaḍadhikadaśan": ['mw'],
    "ṣaḍadhikadaśanāḍīcakra": ['mw'],
    "ṣaḍaga": ['mw'],
    "ṣaḍaha": ['cae', 'mw'],
    "ṣaḍahorātra": ['cae', 'mw'],
    "ṣaḍakṣa": ['cae', 'gra', 'mw'],
    "ṣaḍakṣara": ['cae', 'mw'],
    "ṣaḍakṣaramaya": ['mw'],
    "ṣaḍakṣarastotra": ['mw'],
    "ṣaḍakṣarī": ['bhs'],
    "ṣaḍakṣarīdeva": ['mw'],
    "ṣaḍakṣīṇa": ['mw'],
    "ṣaḍanvayamahāratna": ['mw'],
    "ṣaḍanvayaśāmbhavaraśmipūjākrama": ['mw'],
    "ṣaḍara": ['cae', 'gra', 'mw'],
    "ṣaḍaratni": ['mw'],
    "ṣaḍarca": ['cae', 'mw'],
    "ṣaḍarthanirṇaya": ['mw'],
    "ṣaḍarthasaṃkṣepa": ['mw'],
    "ṣaḍavatta": ['mw'],
    "ṣaḍaśra": ['mw'],
    "ṣaḍaśraka": ['mw'],
    "ṣaḍaśri": ['mw'],
    "ṣaḍaśrā": ['mw'],
    "ṣaḍaśva": ['cae', 'gra', 'mw'],
    "ṣaḍaśīta": ['mw'],
    "ṣaḍaśīti": ['mw'],
    "ṣaḍaśīticakra": ['mw'],
    "ṣaḍaśītimukha": ['mw'],
    "ṣaḍaśītitama": ['mw'],
    "ṣaḍaṃhri": ['cae', 'mw'],
    "ṣaḍaṃśa": ['cae', 'ddsa', 'mw'],
    "ṣaḍaṃśatā": ['mw'],
    "ṣaḍaṅga": ['bhs', 'cae', 'mw'],
    "ṣaḍaṅgaguggulu": ['mw'],
    "ṣaḍaṅgajit": ['mw'],
    "ṣaḍaṅgaka": ['mw'],
    "ṣaḍaṅgapānīya": ['mw'],
    "ṣaḍaṅgarudra": ['mw'],
    "ṣaḍaṅgasamanvāgata": ['mw'],
    "ṣaḍaṅgavid": ['cae', 'mw'],
    "ṣaḍaṅghri": ['cae', 'mw'],
    "ṣaḍaṅginī": ['mw'],
    "ṣaḍaṅguli": ['mw'],
    "ṣaḍaṅgulidatta": ['mw'],
    "ṣaḍaṅgī": ['mw'],
    "ṣaḍaṇḍa": ['mw'],
    "ṣaḍaṣṭaka": ['mw'],
    "ṣaḍbhuja": ['cae', 'mw'],
    "ṣaḍbhujā": ['mw'],
    "ṣaḍbhāga": ['cae', 'mw'],
    "ṣaḍbhāgabhāj": ['cae', 'mw'],
    "ṣaḍbhāgabhṛt": ['mw'],
    "ṣaḍbhāgadala": ['mw'],
    "ṣaḍbhāgīyā": ['mw'],
    "ṣaḍbhāvavādin": ['mw'],
    "ṣaḍbhāṣācandrikā": ['mw'],
    "ṣaḍbhāṣāmañjarī": ['mw'],
    "ṣaḍbhāṣāsubantarūpādarśa": ['mw'],
    "ṣaḍbhāṣāsubantādarśa": ['mw'],
    "ṣaḍbhāṣāvārttika": ['mw'],
    "ṣaḍbindu": ['mw'],
    "ṣaḍdarśana": ['cae', 'mw'],
    "ṣaḍdarśanacandrikā": ['mw'],
    "ṣaḍdarśanasamuccaya": ['mw'],
    "ṣaḍdarśanasaṃgrahavṛtti": ['mw'],
    "ṣaḍdarśanasaṃkṣepa": ['mw'],
    "ṣaḍdarśanasiddhāntasaṃgraha": ['mw'],
    "ṣaḍdarśanavicāra": ['mw'],
    "ṣaḍdarśanaviveka": ['mw'],
    "ṣaḍdarśanavṛtti": ['mw'],
    "ṣaḍdarśinīnighaṇṭu": ['mw'],
    "ṣaḍdarśinīprakaraṇa": ['mw'],
    "ṣaḍdaśana": ['mw'],
    "ṣaḍdevatya": ['mw'],
    "ṣaḍdhā": ['ap90', 'cae', 'mw'],
    "ṣaḍdhāra": ['mw'],
    "ṣaḍdurga": ['mw'],
    "ṣaḍgarbha": ['mw'],
    "ṣaḍgata": ['mw'],
    "ṣaḍgava": ['cae', 'ddsa', 'mw'],
    "ṣaḍgavīya": ['mw'],
    "ṣaḍgayā": ['mw'],
    "ṣaḍgaṇa": ['mw'],
    "ṣaḍgrahayogaśānti": ['mw'],
    "ṣaḍgrahaśānti": ['mw'],
    "ṣaḍgrantha": ['mw'],
    "ṣaḍgranthi": ['mw'],
    "ṣaḍgranthikā": ['mw'],
    "ṣaḍgranthā": ['mw'],
    "ṣaḍgranthī": ['mw'],
    "ṣaḍgurubhāṣya": ['mw'],
    "ṣaḍguruśiṣya": ['cae', 'mw'],
    "ṣaḍguṇa": ['cae', 'mw'],
    "ṣaḍguṇīkṛ": ['mw'],
    "ṣaḍi": ['bhs'],
    "ṣaḍika": ['mw'],
    "ṣaḍiḍa": ['mw'],
    "ṣaḍja": ['mw'],
    "ṣaḍjagrāma": ['mw'],
    "ṣaḍjamadhyā": ['mw'],
    "ṣaḍjāmareśvara": ['mw'],
    "ṣaḍlavaṇa": ['mw'],
    "ṣaḍrada": ['mw'],
    "ṣaḍrasa": ['mw'],
    "ṣaḍrasanighaṇṭa": ['mw'],
    "ṣaḍrasanighaṇṭu": ['mw'],
    "ṣaḍrasaratnamālā": ['mw'],
    "ṣaḍrasāsava": ['mw'],
    "ṣaḍratha": ['mw'],
    "ṣaḍratnakāvya": ['mw'],
    "ṣaḍrekhā": ['mw'],
    "ṣaḍrāgacandrodaya": ['mw'],
    "ṣaḍrātra": ['cae', 'mw'],
    "ṣaḍudyāma": ['mw'],
    "ṣaḍunnata": ['mw'],
    "ṣaḍunnayanamahātantra": ['mw'],
    "ṣaḍupasatka": ['mw'],
    "ṣaḍuttara": ['cae', 'mw'],
    "ṣaḍvadana": ['mw'],
    "ṣaḍvaktra": ['cae', 'mw'],
    "ṣaḍvaktropaniṣaddīpikā": ['mw'],
    "ṣaḍvaktrī": ['mw'],
    "ṣaḍvarga": ['cae', 'mw'],
    "ṣaḍvargaphala": ['mw'],
    "ṣaḍvargavaśya": ['mw'],
    "ṣaḍvargika": ['bhs', 'mw'],
    "ṣaḍvargīya": ['bhs', 'mw'],
    "ṣaḍvarṣikamaha": ['mw'],
    "ṣaḍvidha": ['cae', 'mw'],
    "ṣaḍvidhasāṃkhya": ['mw'],
    "ṣaḍvidhayogaphala": ['mw'],
    "ṣaḍvidhāna": ['cae', 'gra', 'mw'],
    "ṣaḍvidiksaṃdhāna": ['mw'],
    "ṣaḍvidyāgama": ['mw'],
    "ṣaḍvidyāgamasāṃkhyāyanatantra": ['mw'],
    "ṣaḍvikāram": ['mw'],
    "ṣaḍvindhyā": ['mw'],
    "ṣaḍviṃśa": ['cae', 'mw'],
    "ṣaḍviṃśabrāhmaṇa": ['cae', 'mw'],
    "ṣaḍviṃśaka": ['mw'],
    "ṣaḍviṃśat": ['cae', 'mw'],
    "ṣaḍviṃśati": ['cae', 'mw'],
    "ṣaḍviṃśatika": ['mw'],
    "ṣaḍviṃśatima": ['mw'],
    "ṣaḍviṃśatirātra": ['mw'],
    "ṣaḍviṃśatisūtra": ['mw'],
    "ṣaḍviṃśatitama": ['mw'],
    "ṣaḍviṃśatka": ['mw'],
    "ṣaḍviṣāṇa": ['mw'],
    "ṣaḍviṣāṇapāta": ['bhs'],
    "ṣaḍvālaka": ['bhs'],
    "ṣaḍvārgika": ['bhs', 'mw'],
    "ṣaḍvārṣikā": ['mw'],
    "ṣaḍvṛṣa": ['mw'],
    "ṣaḍyoga": ['mw'],
    "ṣaḍāhuti": ['mw'],
    "ṣaḍāhutika": ['mw'],
    "ṣaḍāmnāya": ['mw'],
    "ṣaḍāmnāyasaṃhitā": ['mw'],
    "ṣaḍāmnāyastava": ['mw'],
    "ṣaḍāmnāyaṣaḍdaśanasaṃkṣepavāda": ['mw'],
    "ṣaḍānana": ['cae', 'mw'],
    "ṣaḍāra": ['mw'],
    "ṣaḍātman": ['mw'],
    "ṣaḍāvali": ['mw'],
    "ṣaḍāyatana": ['mw'],
    "ṣaḍāyatanabhedaka": ['mw'],
    "ṣaḍāśīti": ['bhs'],
    "ṣaḍūna": ['cae', 'mw'],
    "ṣaḍūrmi": ['mw'],
    "ṣaḍūṣaṇa": ['mw'],
    "ṣaḍḍhotṛ": ['mw'],
    "ṣaḍḍhā": ['cae', 'mw'],
    "ṣaḍṛca": ['cae', 'mw'],
    "ṣaḍṛkṣa": ['mw'],
    "ṣaḍṛtu": ['mw'],
    "ṣaḍṛtusūkta": ['mw'],
    "ṣaḍṛtuvarṇana": ['mw'],
    "ṣaḍṛtuvinoda": ['mw'],
    "ṣaḷūnā": ['ddsa'],
    "ṣaṃḍakaḥ": ['ap90'],
    "ṣaṃḍaḥ": ['ap90'],
    "ṣaṃḍhaḥ": ['ap90'],
    "ṣaṃḍālī": ['ap90'],
    "ṣaṇ": ['mw'],
    "ṣaṇavati": ['ddsa'],
    "ṣaṇmatasthāpaka": ['mw'],
    "ṣaṇmayūkha": ['mw'],
    "ṣaṇmuhūrtī": ['mw'],
    "ṣaṇmukha": ['cae', 'mw'],
    "ṣaṇmukhakumāra": ['mw'],
    "ṣaṇmukhalakṣaṇa": ['mw'],
    "ṣaṇmukhavṛttinighaṇṭu": ['mw'],
    "ṣaṇmukhā": ['mw'],
    "ṣaṇmukhāgraja": ['mw'],
    "ṣaṇmukhī": ['mw'],
    "ṣaṇmāsa": ['cae', 'mw'],
    "ṣaṇmāsanicaya": ['cae', 'mw'],
    "ṣaṇmāsika": ['cae', 'mw'],
    "ṣaṇmāsya": ['cae', 'mw'],
    "ṣaṇmāsābhyantare": ['mw'],
    "ṣaṇmāsāt": ['mw'],
    "ṣaṇmāsī": ['mw'],
    "ṣaṇmātra": ['mw'],
    "ṣaṇḍa": ['cae', 'ddsa', 'mw'],
    "ṣaṇḍaka": ['mw'],
    "ṣaṇḍakāpālika": ['mw'],
    "ṣaṇḍatila": ['mw'],
    "ṣaṇḍatva": ['mw'],
    "ṣaṇḍatā": ['mw'],
    "ṣaṇḍatāyogya": ['mw'],
    "ṣaṇḍaya": ['mw'],
    "ṣaṇḍha": ['cae', 'ddsa', 'mw'],
    "ṣaṇḍhatila": ['mw'],
    "ṣaṇḍhatva": ['mw'],
    "ṣaṇḍhatā": ['mw'],
    "ṣaṇḍhaveṣa": ['mw'],
    "ṣaṇḍhay": ['cae'],
    "ṣaṇḍhaya": ['mw'],
    "ṣaṇḍhitā": ['mw'],
    "ṣaṇḍhī": ['mw'],
    "ṣaṇḍhīya": ['mw'],
    "ṣaṇḍika": ['cae', 'mw'],
    "ṣaṇḍālī": ['mw'],
    "ṣaṇḍāmaka": ['ddsa', 'mw'],
    "ṣaṇḍāmarka": ['mw'],
    "ṣaṇḍīya": ['mw'],
    "ṣaṇṇa": ['bhs'],
    "ṣaṇṇagarika": ['mw'],
    "ṣaṇṇagarī": ['mw'],
    "ṣaṇṇavata": ['mw'],
    "ṣaṇṇavati": ['cae', 'mw'],
    "ṣaṇṇavatitama": ['mw'],
    "ṣaṇṇavatiśrāddhanirṇaya": ['mw'],
    "ṣaṇṇavatiśrāddhaprayoga": ['mw'],
    "ṣaṇṇidhana": ['mw'],
    "ṣaṇṇivartanī": ['mw'],
    "ṣaṇṇābhi": ['mw'],
    "ṣaṇṇābhika": ['mw'],
    "ṣaṇṇālika": ['mw'],
    "ṣaṇṇāḍīcakra": ['mw'],
    "ṣaṣ": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ṣaṣk": ['mw'],
    "ṣaṣṭa": ['ddsa', 'mw'],
    "ṣaṣṭha": ['ap90', 'cae', 'ddsa', 'mw'],
    "ṣaṣṭhabhakta": ['cae', 'mw'],
    "ṣaṣṭhacandra": ['mw'],
    "ṣaṣṭhaka": ['mw'],
    "ṣaṣṭhakāla": ['mw'],
    "ṣaṣṭhakālopavāsa": ['mw'],
    "ṣaṣṭhama": ['cae', 'mw'],
    "ṣaṣṭhamī": ['mw'],
    "ṣaṣṭhavatī": ['mw'],
    "ṣaṣṭhikā": ['mw'],
    "ṣaṣṭhin": ['mw'],
    "ṣaṣṭhy": ['mw'],
    "ṣaṣṭhya": ['cae', 'ddsa', 'mw'],
    "ṣaṣṭhyarthadarpaṇa": ['mw'],
    "ṣaṣṭhyupākhyānastotra": ['mw'],
    "ṣaṣṭhyādikalpabodhana": ['mw'],
    "ṣaṣṭhādi": ['mw'],
    "ṣaṣṭhāhnika": ['mw'],
    "ṣaṣṭhānna": ['mw'],
    "ṣaṣṭhānnakāla": ['cae', 'mw'],
    "ṣaṣṭhānnakālaka": ['mw'],
    "ṣaṣṭhānnakālatā": ['mw'],
    "ṣaṣṭhānnakālika": ['mw'],
    "ṣaṣṭhāṃśa": ['cae', 'mw'],
    "ṣaṣṭhāṃśavṛtti": ['cae', 'mw'],
    "ṣaṣṭhī": ['ap90', 'bhs', 'ddsa', 'mw'],
    "ṣaṣṭhīdarpaṇa": ['mw'],
    "ṣaṣṭhīdevī": ['mw'],
    "ṣaṣṭhīdāsa": ['mw'],
    "ṣaṣṭhījāgara": ['mw'],
    "ṣaṣṭhījāgaraka": ['mw'],
    "ṣaṣṭhījāgaraṇamaha": ['mw'],
    "ṣaṣṭhījāya": ['mw'],
    "ṣaṣṭhīpriya": ['mw'],
    "ṣaṣṭhīpūjana": ['mw'],
    "ṣaṣṭhīpūjā": ['mw'],
    "ṣaṣṭhīpūjāvidhi": ['mw'],
    "ṣaṣṭhīsamāsa": ['mw'],
    "ṣaṣṭhītatpuruṣa": ['mw'],
    "ṣaṣṭhīvrata": ['mw'],
    "ṣaṣṭhīvratodyāpanavidhi": ['mw'],
    "ṣaṣṭi": ['cae', 'ddsa', 'gra', 'mw'],
    "ṣaṣṭibhāga": ['mw'],
    "ṣaṣṭidakṣiṇa": ['mw'],
    "ṣaṣṭidhā": ['cae', 'mw'],
    "ṣaṣṭidina": ['mw'],
    "ṣaṣṭihrada": ['mw'],
    "ṣaṣṭihāyana": ['cae', 'mw'],
    "ṣaṣṭija": ['mw'],
    "ṣaṣṭika": ['ap90', 'cae', 'mw'],
    "ṣaṣṭikodana": ['bhs'],
    "ṣaṣṭikya": ['mw'],
    "ṣaṣṭikyaṃ": ['ap90'],
    "ṣaṣṭilatā": ['mw'],
    "ṣaṣṭimatta": ['mw'],
    "ṣaṣṭipatha": ['mw'],
    "ṣaṣṭipathika": ['mw'],
    "ṣaṣṭipūrtiśānti": ['mw'],
    "ṣaṣṭirātra": ['mw'],
    "ṣaṣṭis": ['mw'],
    "ṣaṣṭisahasra": ['mw'],
    "ṣaṣṭisahasrin": ['mw'],
    "ṣaṣṭisaṃvatsara": ['mw'],
    "ṣaṣṭisaṃvatsaraphala": ['mw'],
    "ṣaṣṭisāhasra": ['mw'],
    "ṣaṣṭisāṃvatsarī": ['mw'],
    "ṣaṣṭitama": ['mw'],
    "ṣaṣṭitantra": ['mw'],
    "ṣaṣṭitriśata": ['mw'],
    "ṣaṣṭivarṣin": ['cae', 'mw'],
    "ṣaṣṭividyā": ['mw'],
    "ṣaṣṭivrata": ['mw'],
    "ṣaṣṭivāsaraja": ['mw'],
    "ṣaṣṭiyojana": ['mw'],
    "ṣaṣṭiyojanī": ['mw'],
    "ṣaṣṭiśata": ['mw'],
    "ṣaṣṭiśāli": ['mw'],
    "ṣaṣṭiḥ": ['ap90'],
    "ṣaṣṭo": ['bhs'],
    "ṣaṣṭy": ['mw'],
    "ṣaṣṭyabda": ['mw'],
    "ṣaṣṭyadhika": ['mw'],
    "ṣaṣṭyadhikaśata": ['mw'],
    "ṣaṣṭīṣṭaka": ['mw'],
    "ṣaṭ": ['mw'],
    "ṣaṭcakra": ['mw'],
    "ṣaṭcakrabheda": ['mw'],
    "ṣaṭcakrabhedavivṛtiṭīkā": ['mw'],
    "ṣaṭcakrabhedaṭippaṇī": ['mw'],
    "ṣaṭcakradhyānapaddhati": ['mw'],
    "ṣaṭcakradīpikā": ['mw'],
    "ṣaṭcakrakrama": ['mw'],
    "ṣaṭcakranilaya": ['mw'],
    "ṣaṭcakranirūpaṇa": ['mw'],
    "ṣaṭcakraprabheda": ['mw'],
    "ṣaṭcakrasvarūpa": ['mw'],
    "ṣaṭcakravivṛtiṭīkā": ['mw'],
    "ṣaṭcakropaniṣaddīpikā": ['mw'],
    "ṣaṭcakrādisaṃgraha": ['mw'],
    "ṣaṭcaraṇa": ['cae', 'mw'],
    "ṣaṭcaraṇatā": ['mw'],
    "ṣaṭcaraṇāya": ['mw'],
    "ṣaṭcatvāriṃśa": ['mw'],
    "ṣaṭcatvāriṃśaka": ['mw'],
    "ṣaṭcatvāriṃśat": ['mw'],
    "ṣaṭciti": ['mw'],
    "ṣaṭcitika": ['mw'],
    "ṣaṭka": ['ap90', 'cae', 'ddsa', 'mw'],
    "ṣaṭkala": ['mw'],
    "ṣaṭkamāsika": ['mw'],
    "ṣaṭkapañcāśikā": ['mw'],
    "ṣaṭkapāla": ['mw'],
    "ṣaṭkarmadīpikā": ['mw'],
    "ṣaṭkarmakṛt": ['mw'],
    "ṣaṭkarman": ['cae', 'mw'],
    "ṣaṭkarmaprayoga": ['mw'],
    "ṣaṭkarmavant": ['cae'],
    "ṣaṭkarmavat": ['mw'],
    "ṣaṭkarmavidhi": ['mw'],
    "ṣaṭkarmaviveka": ['mw'],
    "ṣaṭkarmavyākhyānacintāmaṇi": ['mw'],
    "ṣaṭkarṇa": ['cae', 'mw'],
    "ṣaṭkhaṇḍa": ['mw'],
    "ṣaṭkheṭaka": ['mw'],
    "ṣaṭkikā": ['bhs'],
    "ṣaṭkoṇa": ['mw'],
    "ṣaṭkukṣi": ['mw'],
    "ṣaṭkulīya": ['mw'],
    "ṣaṭkāra": ['mw'],
    "ṣaṭkāraka": ['mw'],
    "ṣaṭkārakabheda": ['mw'],
    "ṣaṭkārakapraticchandaka": ['mw'],
    "ṣaṭkārakapraticchandasa": ['mw'],
    "ṣaṭkārakavivecana": ['mw'],
    "ṣaṭkūṭaślokānāmarthāḥ": ['mw'],
    "ṣaṭkūṭā": ['mw'],
    "ṣaṭkṛtvas": ['cae', 'mw'],
    "ṣaṭpad": ['cae', 'mw'],
    "ṣaṭpada": ['cae', 'mw'],
    "ṣaṭpadajya": ['mw'],
    "ṣaṭpadapriya": ['mw'],
    "ṣaṭpadeṣṭa": ['mw'],
    "ṣaṭpadikā": ['mw'],
    "ṣaṭpadā": ['mw'],
    "ṣaṭpadābhidharma": ['mw'],
    "ṣaṭpadālī": ['mw'],
    "ṣaṭpadānandavardhana": ['mw'],
    "ṣaṭpadārthavivaraṇa": ['mw'],
    "ṣaṭpadātithi": ['mw'],
    "ṣaṭpadī": ['mw'],
    "ṣaṭpadīstotra": ['mw'],
    "ṣaṭpakṣa": ['mw'],
    "ṣaṭpalaka": ['mw'],
    "ṣaṭpalika": ['mw'],
    "ṣaṭpattra": ['cae', 'mw'],
    "ṣaṭpañcavarṣa": ['mw'],
    "ṣaṭpañcika": ['bhs'],
    "ṣaṭpañcāśa": ['mw'],
    "ṣaṭpañcāśaddhorāvṛtti": ['mw'],
    "ṣaṭpañcāśat": ['cae', 'mw'],
    "ṣaṭpañcāśatikahorā": ['mw'],
    "ṣaṭpañcāśatikā": ['mw'],
    "ṣaṭpañcāśattama": ['mw'],
    "ṣaṭpañcāśikā": ['mw'],
    "ṣaṭpañcāśikāvṛtti": ['mw'],
    "ṣaṭpitāputraka": ['mw'],
    "ṣaṭpiṇḍavidhi": ['mw'],
    "ṣaṭpragātha": ['mw'],
    "ṣaṭprajña": ['mw'],
    "ṣaṭpraśnopaniṣad": ['mw'],
    "ṣaṭpraśnopaniṣadbhāṣya": ['mw'],
    "ṣaṭpura": ['bhs', 'mw'],
    "ṣaṭputra": ['mw'],
    "ṣaṭpād": ['cae'],
    "ṣaṭpāda": ['cae', 'mw'],
    "ṣaṭpāramitānirdeśa": ['mw'],
    "ṣaṭpāramitāparipūrṇa": ['mw'],
    "ṣaṭpārāyaṇavidhi": ['mw'],
    "ṣaṭsahasra": ['cae', 'mw'],
    "ṣaṭsahasrakara": ['mw'],
    "ṣaṭsahasraśata": ['mw'],
    "ṣaṭsahasrī": ['mw'],
    "ṣaṭsapta": ['cae', 'mw'],
    "ṣaṭsaptata": ['mw'],
    "ṣaṭsaptati": ['mw'],
    "ṣaṭsaptatitama": ['mw'],
    "ṣaṭsthalamahiman": ['mw'],
    "ṣaṭsthalanirṇaya": ['mw'],
    "ṣaṭsthalānubhava": ['mw'],
    "ṣaṭsthānakavṛtti": ['mw'],
    "ṣaṭsāhasrī": ['mw'],
    "ṣaṭsūtra": ['mw'],
    "ṣaṭtakrataila": ['mw'],
    "ṣaṭtantrī": ['mw'],
    "ṣaṭtantrīsāra": ['mw'],
    "ṣaṭtaya": ['cae'],
    "ṣaṭtiladāna": ['mw'],
    "ṣaṭtilin": ['mw'],
    "ṣaṭtriṃśa": ['cae', 'gra', 'mw'],
    "ṣaṭtriṃśacchatya": ['mw'],
    "ṣaṭtriṃśad": ['mw'],
    "ṣaṭtriṃśadaha": ['mw'],
    "ṣaṭtriṃśadahaśas": ['mw'],
    "ṣaṭtriṃśadakṣara": ['mw'],
    "ṣaṭtriṃśaddīpikā": ['mw'],
    "ṣaṭtriṃśadiṣṭaka": ['mw'],
    "ṣaṭtriṃśadrātra": ['mw'],
    "ṣaṭtriṃśadvikrama": ['mw'],
    "ṣaṭtriṃśadābdika": ['mw'],
    "ṣaṭtriṃśadūna": ['mw'],
    "ṣaṭtriṃśan": ['mw'],
    "ṣaṭtriṃśanmata": ['mw'],
    "ṣaṭtriṃśat": ['cae', 'mw'],
    "ṣaṭtriṃśati": ['mw'],
    "ṣaṭtriṃśatka": ['mw'],
    "ṣaṭtriṃśatpadakajñāna": ['mw'],
    "ṣaṭtriṃśatsahasra": ['mw'],
    "ṣaṭtriṃśatsaṃvatsara": ['mw'],
    "ṣaṭtriṃśattattva": ['mw'],
    "ṣaṭtriṃśika": ['mw'],
    "ṣaṭtriṃśābdika": ['cae'],
    "ṣaṭtva": ['cae', 'mw'],
    "ṣaṭtāla": ['mw'],
    "ṣaṭśamī": ['mw'],
    "ṣaṭśas": ['cae', 'mw'],
    "ṣaṭśata": ['cae', 'mw'],
    "ṣaṭśatī": ['mw'],
    "ṣaṭśāstravicāra": ['mw'],
    "ṣaṭśāstrin": ['mw'],
    "ṣaṭṣaṣṭa": ['mw'],
    "ṣaṭṣaṣṭi": ['mw'],
    "ṣaṭṣaṣṭitama": ['mw'],
    "ṣaṭṣoḍaśin": ['mw'],
    "ṣaṭṭ": ['mw'],
    "ṣaṭṭaka": ['mw'],
    "ṣaṭṭaya": ['mw'],
    "ṣeḍaśāha": ['mw'],
    "ṣiḍga": ['cae', 'ddsa', 'mw'],
    "ṣiḍgaḥ": ['ap90'],
    "ṣo": ['mw'],
    "ṣodat": ['ap90'],
    "ṣol̤aśa": ['mw'],
    "ṣol̤aśan": ['mw'],
    "ṣol̤aśākṣara": ['mw'],
    "ṣoḍa": ['mw'],
    "ṣoḍanta": ['mw'],
    "ṣoḍat": ['mw'],
    "ṣoḍaśa": ['ap90', 'cae', 'ddsa', 'mw'],
    "ṣoḍaśabhedita": ['mw'],
    "ṣoḍaśabhuja": ['mw'],
    "ṣoḍaśabhujarāmadhyāna": ['mw'],
    "ṣoḍaśabhujā": ['mw'],
    "ṣoḍaśabhāga": ['mw'],
    "ṣoḍaśadala": ['mw'],
    "ṣoḍaśadhā": ['ap90', 'cae', 'mw'],
    "ṣoḍaśadāna": ['mw'],
    "ṣoḍaśagaṇapatidhyāna": ['mw'],
    "ṣoḍaśagaṇapatilakṣaṇa": ['mw'],
    "ṣoḍaśagṛhīta": ['mw'],
    "ṣoḍaśagṛhītārdha": ['mw'],
    "ṣoḍaśaka": ['mw'],
    "ṣoḍaśakala": ['mw'],
    "ṣoḍaśakalavidyā": ['mw'],
    "ṣoḍaśakalā": ['mw'],
    "ṣoḍaśakarmaprayoga": ['mw'],
    "ṣoḍaśakarmavidhi": ['mw'],
    "ṣoḍaśakāraṇajayamālā": ['mw'],
    "ṣoḍaśakāraṇapūjā": ['mw'],
    "ṣoḍaśakārikā": ['mw'],
    "ṣoḍaśakūrca": ['mw'],
    "ṣoḍaśalakṣaṇa": ['mw'],
    "ṣoḍaśama": ['cae', 'mw'],
    "ṣoḍaśamudrālakṣaṇa": ['mw'],
    "ṣoḍaśamātṛkā": ['mw'],
    "ṣoḍaśan": ['ap90', 'cae', 'ddsa', 'mw'],
    "ṣoḍaśanityatantra": ['mw'],
    "ṣoḍaśanyāsa": ['mw'],
    "ṣoḍaśapada": ['ddsa', 'mw'],
    "ṣoḍaśapakṣaśāyin": ['mw'],
    "ṣoḍaśarca": ['mw'],
    "ṣoḍaśartuniśā": ['mw'],
    "ṣoḍaśartvikkratu": ['mw'],
    "ṣoḍaśarājika": ['mw'],
    "ṣoḍaśarātra": ['mw'],
    "ṣoḍaśasahasra": ['mw'],
    "ṣoḍaśasāhasra": ['mw'],
    "ṣoḍaśatva": ['mw'],
    "ṣoḍaśavarṣa": ['mw'],
    "ṣoḍaśavidha": ['mw'],
    "ṣoḍaśavistṛta": ['mw'],
    "ṣoḍaśaśata": ['mw'],
    "ṣoḍaśi": ['mw'],
    "ṣoḍaśigraha": ['mw'],
    "ṣoḍaśika": ['ap90', 'mw'],
    "ṣoḍaśikā": ['mw'],
    "ṣoḍaśikāmra": ['mw'],
    "ṣoḍaśimat": ['mw'],
    "ṣoḍaśin": ['ap90', 'cae', 'ddsa', 'mw'],
    "ṣoḍaśiprayoga": ['mw'],
    "ṣoḍaśipātra": ['mw'],
    "ṣoḍaśistotra": ['mw'],
    "ṣoḍaśisāman": ['mw'],
    "ṣoḍaśitva": ['mw'],
    "ṣoḍaśiśastra": ['mw'],
    "ṣoḍaśopacāra": ['mw'],
    "ṣoḍaśāditantra": ['mw'],
    "ṣoḍaśākṣa": ['mw'],
    "ṣoḍaśākṣara": ['mw'],
    "ṣoḍaśāra": ['mw'],
    "ṣoḍaśārcis": ['mw'],
    "ṣoḍaśātmaka": ['mw'],
    "ṣoḍaśātman": ['mw'],
    "ṣoḍaśāvarta": ['mw'],
    "ṣoḍaśāyudhastuti": ['mw'],
    "ṣoḍaśāḍhakamaya": ['mw'],
    "ṣoḍaśāṃhri": ['mw'],
    "ṣoḍaśāṃśa": ['cae', 'mw'],
    "ṣoḍaśāṃśu": ['mw'],
    "ṣoḍaśāṅga": ['mw'],
    "ṣoḍaśāṅghri": ['mw'],
    "ṣoḍaśāṅgulaka": ['mw'],
    "ṣoḍaśī": ['mw'],
    "ṣoḍaśībilva": ['mw'],
    "ṣoḍhā": ['ap90', 'cae', 'ddsa', 'gra', 'mw'],
    "ṣoḍhāmukha": ['mw'],
    "ṣoḍhānyāsa": ['mw'],
    "ṣoḍhāvihita": ['mw'],
    "ṣoḍīya": ['mw'],
    "ṣu": ['ddsa', 'mw'],
    "ṣuduvadīna": ['mw'],
    "ṣukk": ['mw'],
    "ṣurājima": ['mw'],
    "ṣurāsāṇa": ['mw'],
    "ṣuḥ": ['ap90'],
    "ṣvakk": ['ap90', 'mw'],
    "ṣvask": ['mw'],
    "ṣvaṣk": ['mw'],
    "ṣāhavilāsa": ['mw'],
    "ṣāmila": ['mw'],
    "ṣārija": ['mw'],
    "ṣātvaṇatvika": ['mw'],
    "ṣāḍahika": ['mw'],
    "ṣāḍava": ['cae', 'ddsa', 'mw'],
    "ṣāḍavaḥ": ['ap90'],
    "ṣāḍavika": ['mw'],
    "ṣāḍaṇḍaka": ['mw'],
    "ṣāḍguṇya": ['cae', 'ddsa', 'mw'],
    "ṣāḍguṇyaguṇavedin": ['mw'],
    "ṣāḍguṇyaprayoga": ['mw'],
    "ṣāḍguṇyasaṃyuta": ['mw'],
    "ṣāḍguṇyavat": ['mw'],
    "ṣāḍguṇyaṃ": ['ap90'],
    "ṣāḍrasika": ['mw'],
    "ṣāḍvargika": ['mw'],
    "ṣāḍvidhya": ['ddsa', 'mw'],
    "ṣāṇmāsika": ['ap90', 'cae', 'ddsa', 'mw'],
    "ṣāṇmāsya": ['cae', 'mw'],
    "ṣāṇmāsyī": ['mw'],
    "ṣāṇmātura": ['mw'],
    "ṣāṇmāturaḥ": ['ap90'],
    "ṣāṇḍa": ['mw'],
    "ṣāṇḍaśa": ['mw'],
    "ṣāṇḍhya": ['mw'],
    "ṣāṣṭha": ['ap90', 'mw'],
    "ṣāṣṭhika": ['mw'],
    "ṣāṣṭika": ['mw'],
    "ṣāṣṭipatha": ['mw'],
    "ṣāṭ": ['ap90', 'gra', 'mw'],
    "ṣāṭkauśika": ['ap90', 'mw'],
    "ṣāṭkula": ['mw'],
    "ṣāṭpauruṣika": ['ap90', 'mw'],
    "ṣū": ['mw'],
    "ṣṇā": ['mw'],
    "ṣṭambh": ['mw'],
    "ṣṭheva": ['mw'],
    "ṣṭhevana": ['mw'],
    "ṣṭhevin": ['mw'],
    "ṣṭhevitavya": ['mw'],
    "ṣṭhevitṛ": ['mw'],
    "ṣṭhevya": ['mw'],
    "ṣṭhi": ['mw'],
    "ṣṭhiv": ['ap90', 'cae', 'ddsa', 'mw'],
    "ṣṭhu": ['ddsa', 'mw'],
    "ṣṭhyūta": ['ap90', 'ddsa', 'mw'],
    "ṣṭhyūti": ['mw'],
    "ṣṭhā": ['mw'],
    "ṣṭhīv": ['mw'],
    "ṣṭhīva": ['cae', 'mw'],
    "ṣṭhīvana": ['cae', 'ddsa', 'mw'],
    "ṣṭhīvanaṃ": ['ap90'],
    "ṣṭhīvi": ['cae', 'mw'],
    "ṣṭhīvin": ['cae', 'mw'],
    "ṣṭhīvī": ['mw'],
    "ṣṭyai": ['mw'],
    "ṣṭyuma": ['mw'],
    "ṣṭyūma": ['mw'],
    "ṭa": ['mw'],
    "ṭagara": ['ap90', 'mw'],
    "ṭakka": ['ddsa', 'mw'],
    "ṭakkadeśa": ['ddsa', 'mw'],
    "ṭakkadeśīya": ['mw'],
    "ṭakkarā": ['ddsa', 'mw'],
    "ṭakkibuddha": ['ddsa', 'mw'],
    "ṭakkirāja": ['bhs'],
    "ṭakva": ['mw'],
    "ṭakvara": ['mw'],
    "ṭakvaraḥ": ['ap90'],
    "ṭakāra": ['mw'],
    "ṭal": ['ap90', 'cae', 'ddsa', 'mw'],
    "ṭala": ['mw'],
    "ṭalana": ['mw'],
    "ṭalaḥ": ['ap90'],
    "ṭasat": ['cae', 'ddsa', 'mw'],
    "ṭasiti": ['mw'],
    "ṭauk": ['mw'],
    "ṭauṭeśa": ['mw'],
    "ṭavarga": ['mw'],
    "ṭavargīya": ['mw'],
    "ṭaḥ": ['ap90'],
    "ṭaṃgaḥ": ['ap90'],
    "ṭaṃgaṇaḥ": ['ap90'],
    "ṭaṃgā": ['ap90'],
    "ṭaṃk": ['ap90'],
    "ṭaṃkakaḥ": ['ap90'],
    "ṭaṃkanaṃ": ['ap90'],
    "ṭaṃkaḥ": ['ap90'],
    "ṭaṃkaṇaṃ": ['ap90'],
    "ṭaṃkaṭīkaḥ": ['ap90'],
    "ṭaṃkikā": ['ap90'],
    "ṭaṃkāra": ['cae', 'mw'],
    "ṭaṃkārarava": ['mw'],
    "ṭaṃkāravat": ['mw'],
    "ṭaṃkāraḥ": ['ap90'],
    "ṭaṃkārin": ['ap90'],
    "ṭaṃkārita": ['cae', 'mw'],
    "ṭaṃkārī": ['mw'],
    "ṭaṃkṛta": ['cae', 'mw'],
    "ṭaṅga": ['mw'],
    "ṭaṅgaṇa": ['mw'],
    "ṭaṅgaṇakṣāra": ['bhs'],
    "ṭaṅginī": ['mw'],
    "ṭaṅk": ['mw'],
    "ṭaṅka": ['cae', 'ddsa', 'mw'],
    "ṭaṅkaccheda": ['cae'],
    "ṭaṅkaka": ['mw'],
    "ṭaṅkakapati": ['mw'],
    "ṭaṅkakaśālā": ['mw'],
    "ṭaṅkana": ['mw'],
    "ṭaṅkapati": ['mw'],
    "ṭaṅkavat": ['mw'],
    "ṭaṅkay": ['cae'],
    "ṭaṅkaya": ['ddsa'],
    "ṭaṅkaśālā": ['mw'],
    "ṭaṅkaṇa": ['cae', 'ddsa', 'mw'],
    "ṭaṅkaṇakṣāra": ['mw'],
    "ṭaṅkaṭīka": ['mw'],
    "ṭaṅkikā": ['mw'],
    "ṭaṅkitamañca": ['cped'],
    "ṭaṅkā": ['mw'],
    "ṭaṅkānaka": ['mw'],
    "ṭaṅkāra": ['ddsa'],
    "ṭaṅkārita": ['ddsa'],
    "ṭaṇatkāra": ['mw'],
    "ṭaṇḍana": ['mw'],
    "ṭaṭarīsūrya": ['mw'],
    "ṭaṭṭanī": ['ap90', 'mw'],
    "ṭaṭṭarī": ['ap90', 'mw'],
    "ṭaṭṭura": ['mw'],
    "ṭaṭṭuraḥ": ['ap90'],
    "ṭeka": ['mw'],
    "ṭekārī": ['mw'],
    "ṭepana": ['mw'],
    "ṭepanaṃ": ['ap90'],
    "ṭera": ['ap90', 'mw'],
    "ṭeraka": ['mw'],
    "ṭerākṣa": ['bhs', 'mw'],
    "ṭeṇṭuka": ['mw'],
    "ṭha": ['mw'],
    "ṭhakka": ['mw'],
    "ṭhakkana": ['ddsa', 'mw'],
    "ṭhakkura": ['cae', 'ddsa', 'mw'],
    "ṭhakkuraḥ": ['ap90'],
    "ṭhakāra": ['cae', 'ddsa', 'mw'],
    "ṭhakāraya": ['mw'],
    "ṭhambhana": ['bhs'],
    "ṭhampimha": ['cped'],
    "ṭhapana": ['cped'],
    "ṭhapaniya": ['cped'],
    "ṭhapanīyapraśna": ['bhs'],
    "ṭhapayati": ['cped'],
    "ṭhapayitvā": ['cped'],
    "ṭhapenta": ['cped'],
    "ṭhapesi": ['cped'],
    "ṭhapesuṁ": ['cped'],
    "ṭhapetabba": ['cped'],
    "ṭhapeti": ['bhs', 'cped'],
    "ṭhapetvā": ['cped'],
    "ṭhapita": ['cped'],
    "ṭhapiyyati": ['cped'],
    "ṭhapīyati": ['cped'],
    "ṭhassanti": ['cped'],
    "ṭhassati": ['cped'],
    "ṭhatvā": ['cped'],
    "ṭhaḥ": ['ap90'],
    "ṭhaṃsarī": ['mw'],
    "ṭhaṭhaṃ": ['mw'],
    "ṭhepaka": ['mw'],
    "ṭhetkṛta": ['mw'],
    "ṭhevaka": ['mw'],
    "ṭhita": ['cped'],
    "ṭhitaka": ['cped'],
    "ṭhiti": ['cped'],
    "ṭhitibhāgiya": ['cped'],
    "ṭhitokāsa": ['cped'],
    "ṭhiṇṭhā": ['cae', 'ddsa', 'mw'],
    "ṭhiṇṭhākarāla": ['mw'],
    "ṭhoṇṭhapaddhati": ['mw'],
    "ṭhuṇṭhupaddhati": ['mw'],
    "ṭhālinī": ['ap90'],
    "ṭhāna": ['cped'],
    "ṭhānaso": ['cped'],
    "ṭhānāraha": ['cped'],
    "ṭhāpayati": ['cped'],
    "ṭhāpeti": ['cped'],
    "ṭhāra": ['cae', 'ddsa', 'mw'],
    "ṭhāraḥ": ['ap90'],
    "ṭhātabba": ['cped'],
    "ṭhāti": ['cped'],
    "ṭhātkāra": ['ddsa', 'mw'],
    "ṭhāyati": ['cped'],
    "ṭik": ['ap90', 'mw'],
    "ṭikka": ['ddsa', 'mw'],
    "ṭikkikā": ['mw'],
    "ṭillā": ['mw'],
    "ṭip": ['ap90', 'mw'],
    "ṭippanī": ['ap90', 'mw'],
    "ṭippaṇa": ['mw'],
    "ṭippaṇyāśaya": ['mw'],
    "ṭippaṇī": ['ap90', 'mw'],
    "ṭippiṭaka": ['bhs'],
    "ṭiriṭirā": ['mw'],
    "ṭivyaka": ['bhs'],
    "ṭiṇḍinikā": ['mw'],
    "ṭiṇḍiśa": ['mw'],
    "ṭiṇṭhiṇi": ['mw'],
    "ṭiṇṭhā": ['cae', 'ddsa', 'mw'],
    "ṭiṇṭiṇi": ['mw'],
    "ṭiṇṭiṇikā": ['mw'],
    "ṭiṇṭiṇīkā": ['mw'],
    "ṭiṭibha": ['bhs'],
    "ṭiṭibhaka": ['mw'],
    "ṭiṭibhaḥ": ['ap90'],
    "ṭiṭila": ['bhs', 'mw'],
    "ṭiṭṭibha": ['cae', 'ddsa', 'mw'],
    "ṭiṭṭibhaka": ['mw'],
    "ṭiṭṭibhaḥ": ['ap90'],
    "ṭiṭṭibhāsana": ['mw'],
    "ṭiṭṭibhī": ['mw'],
    "ṭolakamāhātmya": ['mw'],
    "ṭopara": ['cae', 'mw'],
    "ṭoḍara": ['mw'],
    "ṭoḍaraprakāśa": ['mw'],
    "ṭoḍarānanda": ['mw'],
    "ṭoṭa": ['ap90', 'mw'],
    "ṭoṭī": ['mw'],
    "ṭu": ['mw'],
    "ṭubduṣī": ['mw'],
    "ṭukkarī": ['mw'],
    "ṭulla": ['ddsa', 'mw'],
    "ṭunākā": ['mw'],
    "ṭupṭīkā": ['mw'],
    "ṭuḥ": ['ap90'],
    "ṭuṃṭuka": ['ap90'],
    "ṭuṇṭuka": ['mw'],
    "ṭuṇṭukā": ['mw'],
    "ṭuṭuka": ['mw'],
    "ṭval": ['ap90', 'mw'],
    "ṭvala": ['mw'],
    "ṭvāla": ['mw'],
    "ṭā": ['mw'],
    "ṭāka": ['mw'],
    "ṭāla": ['cae', 'mw'],
    "ṭāpara": ['mw'],
    "ṭāra": ['mw'],
    "ṭāraḥ": ['ap90'],
    "ṭāt": ['mw'],
    "ṭāṃkaraḥ": ['ap90'],
    "ṭāṃkaṃ": ['ap90'],
    "ṭāṃkāra": ['cae', 'mw'],
    "ṭāṃkāraḥ": ['ap90'],
    "ṭāṃkṛta": ['mw'],
    "ṭāṅka": ['ddsa', 'mw'],
    "ṭāṅkara": ['mw'],
    "ṭāṅkāra": ['ddsa'],
    "ṭīk": ['ap90', 'cae', 'ddsa', 'mw'],
    "ṭīkā": ['ap90', 'cae', 'ddsa', 'mw'],
    "ṭīkāsamuccaya": ['mw'],
    "ṭīkāsarvasva": ['mw'],
    "ṭītkāra": ['cae', 'ddsa', 'mw'],
    "ṭīṭa": ['mw'],
    "ṭīṭibha": ['ddsa', 'mw'],
    "ṭīṭibhasaras": ['mw'],
    "ṭīṭibhī": ['mw'],
}
